%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This is a synthetic power system network model that covers the geographic
%   footprint of the US Western Interconnect states (Washington, Oregon,
%   California, Nevada, Idaho, Montana, Wyoming, Utah, Colorado, Arizona and
%   New Mexico). The case is designed with a 500, 230, 138 and 69 kV
%   transmission network to serve a load that roughly mimics the actual
%   population of its geographic footprint. The synthetic transmission system
%   was designed by algorithms described in [1] to be statistically similar to
%   actual transmission system models but without modeling any actual lines.
%
%   One-line diagrams and other data formats available at:
%   https://github.com/WISPO-POP/SyntheticElectricNetworkModels
%   https://electricgrids.engr.tamu.edu
%
%   This synthetic dateset was developed as part of the ARPA-E GRID DATA
%   program as part of the EPIGRIDS project.
%
%   When publishing results based on this data, please cite:
%
%   [1] J. M. Snodgrass, "Tractable Algorithms for Constructing Electric Power Network Models,"
%      Ph.D. Thesis, The University of Wisconsin - Madison, 2021.
%
%   Copyright (c) 2022 by J. Snodgrass, S. Greene, B. Lesieutre, C. DeMarco
%   Licensed under the Creative Commons Attribution 4.0
%   International license, http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case20758_epigrids
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	58575	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58576	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58577	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58578	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58579	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58580	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58581	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58582	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58583	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58584	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58585	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58586	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58587	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58588	 1	 0.0	 0.0	 0.0	 71.54	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58589	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58590	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58591	 1	 0.0	 0.0	 0.0	 -250.53	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58592	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58593	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58594	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58595	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58596	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58597	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58598	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58599	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58600	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58601	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58602	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58603	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58604	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58605	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58606	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58607	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58608	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58609	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58610	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58611	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58612	 1	 0.0	 0.0	 0.0	 37.41	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58613	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58614	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58615	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58616	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58617	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58618	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58619	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58620	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58621	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58622	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58623	 1	 0.0	 0.0	 0.0	 -52.72	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58624	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58625	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58626	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58627	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58628	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58629	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58630	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58631	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58632	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58633	 1	 0.0	 0.0	 0.0	 35.2	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58634	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58635	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58636	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58637	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58638	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58639	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58640	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58641	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58642	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58643	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58644	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58645	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58646	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58647	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58648	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58649	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58650	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58651	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58652	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58653	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58654	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58655	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58656	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58657	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58658	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58659	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58660	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58661	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58662	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58663	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58664	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58665	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58666	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58667	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58668	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58669	 1	 0.0	 0.0	 0.0	 148.42	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58670	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58671	 1	 0.0	 0.0	 0.0	 52.05	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58672	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58673	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58674	 1	 0.0	 0.0	 0.0	 -14.09	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58675	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58676	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58677	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58678	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58679	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58680	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58681	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58682	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58683	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58684	 1	 0.0	 0.0	 0.0	 103.84	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58685	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58686	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58687	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58688	 1	 0.0	 0.0	 0.0	 49.27	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58689	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58690	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58691	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58692	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58693	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58694	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58695	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58696	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58697	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58698	 1	 0.0	 0.0	 0.0	 137.22	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58699	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58700	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58701	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58702	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58703	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58704	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58705	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58706	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58707	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58708	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58709	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58710	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58711	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58712	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58713	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58714	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58715	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58716	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58717	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58718	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58719	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58720	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58721	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58722	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58723	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58724	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58725	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58726	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58727	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58728	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58729	 1	 0.0	 0.0	 0.0	 10.11	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58730	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58731	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58732	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58733	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58734	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58735	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58736	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58737	 1	 0.0	 0.0	 0.0	 63.58	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58738	 2	 0.0	 0.0	 0.0	 -45.25	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58739	 1	 0.0	 0.0	 0.0	 100.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58740	 2	 0.0	 0.0	 0.0	 -476.73	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58741	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58742	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58743	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58744	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58745	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58746	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58747	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58748	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58749	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58750	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58751	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58752	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58753	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58754	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58755	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58756	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58757	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58758	 1	 0.0	 0.0	 0.0	 -24.08	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58759	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58760	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58761	 1	 0.0	 0.0	 0.0	 36.86	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58762	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58763	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58764	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58765	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58766	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58767	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58768	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58769	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58770	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58771	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58772	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58773	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58774	 1	 0.0	 0.0	 0.0	 -342.47	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58775	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58776	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58777	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58778	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58779	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58780	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58781	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58782	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58783	 1	 0.0	 0.0	 0.0	 -5.54	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58784	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58785	 1	 0.0	 0.0	 0.0	 37.37	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58786	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58787	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58788	 1	 0.0	 0.0	 0.0	 0.35	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58789	 1	 0.0	 0.0	 0.0	 22.64	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58790	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58791	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58792	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58793	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58794	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58795	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58796	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58797	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58798	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58799	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58800	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58801	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58802	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58803	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58804	 1	 10.13	 2.94	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58805	 1	 5.95	 1.06	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58806	 1	 3.11	 0.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58807	 1	 3.37	 0.88	 0.0	 -21.33	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58808	 1	 0.0	 0.0	 0.0	 13.27	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58809	 1	 10.33	 2.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58810	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58811	 1	 6.8	 1.15	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58812	 1	 4.86	 1.21	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58813	 1	 5.09	 0.93	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58814	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58815	 1	 6.53	 0.89	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58816	 1	 6.13	 1.82	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58817	 1	 4.63	 0.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58818	 1	 8.13	 2.34	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58819	 1	 11.31	 2.59	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58820	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58821	 1	 3.67	 0.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58822	 1	 7.38	 1.32	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58823	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58824	 1	 4.48	 1.01	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58825	 1	 6.86	 1.96	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58826	 1	 7.66	 2.25	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58827	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58828	 1	 8.38	 1.03	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58829	 1	 43.34	 9.46	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58830	 1	 0.0	 0.0	 0.0	 276.06	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58831	 1	 10.23	 3.12	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58832	 1	 5.24	 1.64	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58833	 1	 4.01	 1.24	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58834	 1	 16.58	 2.98	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58835	 1	 24.23	 3.94	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58836	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58837	 1	 6.08	 1.51	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58838	 1	 10.42	 1.6	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58839	 1	 9.52	 2.88	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58840	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58841	 1	 10.25	 2.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58842	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58843	 1	 12.37	 2.95	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58844	 1	 0.0	 0.0	 0.0	 71.5	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58845	 1	 7.14	 1.21	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58846	 1	 0.0	 0.0	 0.0	 -16.97	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58847	 1	 4.29	 0.92	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58848	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58849	 1	 23.73	 6.94	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58850	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58851	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58852	 1	 21.42	 6.01	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58853	 1	 11.45	 3.62	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58854	 1	 13.16	 2.56	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58855	 1	 7.13	 1.36	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58856	 1	 19.2	 5.3	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58857	 1	 22.96	 3.27	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58858	 1	 10.41	 1.96	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58859	 1	 17.26	 2.47	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58860	 1	 0.0	 0.0	 0.0	 -65.45	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58861	 1	 10.67	 1.45	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58862	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58863	 1	 4.25	 0.92	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58864	 1	 9.18	 1.77	 0.0	 6.08	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58865	 1	 18.89	 4.85	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58866	 1	 5.22	 0.8	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58867	 1	 3.01	 0.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58868	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58869	 1	 0.0	 0.0	 0.0	 -42.69	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58870	 1	 6.11	 0.91	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58871	 1	 3.85	 1.22	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58872	 1	 3.41	 0.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58873	 1	 7.98	 2.05	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58874	 1	 4.9	 1.22	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58875	 1	 6.53	 1.32	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58876	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58877	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58878	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58879	 1	 5.48	 1.46	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58880	 1	 3.75	 1.22	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58881	 1	 3.7	 0.63	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58882	 1	 3.39	 0.72	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58883	 1	 29.14	 4.81	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58884	 1	 2.01	 0.36	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58885	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58886	 1	 12.3	 3.58	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58887	 1	 0.0	 0.0	 0.0	 -89.84	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58888	 1	 67.41	 18.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58889	 1	 17.61	 3.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58890	 1	 2.82	 0.74	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58891	 1	 19.72	 5.28	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58892	 1	 8.65	 2.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58893	 1	 16.53	 3.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58894	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58895	 1	 20.91	 6.05	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58896	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58897	 1	 8.33	 1.37	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58898	 1	 11.3	 3.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58899	 1	 12.38	 2.06	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58900	 1	 4.7	 0.67	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58901	 1	 2.91	 0.61	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58902	 1	 10.42	 -3.68	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58903	 1	 0.0	 0.0	 0.0	 -100.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58904	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58905	 1	 9.66	 3.05	 0.0	 1.6	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58906	 1	 0.0	 0.0	 0.0	 34.18	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58907	 1	 16.37	 3.81	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58908	 1	 3.37	 0.71	 0.0	 -69.03	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58909	 1	 16.52	 4.04	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58910	 1	 5.88	 0.9	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58911	 1	 0.0	 0.0	 0.0	 -5.85	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58912	 1	 5.69	 1.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58913	 1	 10.42	 3.15	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58914	 1	 5.08	 1.47	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58915	 1	 5.8	 1.25	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58916	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58917	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58918	 1	 4.99	 1.38	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58919	 1	 5.75	 0.72	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58920	 1	 3.21	 0.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58921	 1	 6.07	 1.08	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58922	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58923	 1	 0.0	 0.0	 0.0	 27.4	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58924	 1	 3.97	 0.74	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58925	 1	 6.45	 1.25	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58926	 1	 22.93	 4.82	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58927	 1	 4.72	 0.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58928	 1	 10.76	 3.22	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58929	 1	 10.62	 1.44	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58930	 1	 6.33	 1.38	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58931	 1	 26.26	 6.68	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58932	 1	 3.04	 0.55	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58933	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58934	 1	 0.0	 0.0	 0.0	 -24.92	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58935	 1	 25.73	 7.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58936	 1	 1.62	 0.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58937	 1	 14.35	 3.2	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58938	 1	 4.57	 0.91	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58939	 1	 5.7	 1.35	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58940	 1	 0.0	 0.0	 0.0	 11.45	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58941	 1	 8.13	 2.32	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58942	 1	 4.86	 0.91	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58943	 1	 3.28	 0.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58944	 1	 8.14	 1.71	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58945	 1	 4.66	 1.04	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58946	 1	 9.26	 1.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58947	 1	 4.63	 0.8	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58948	 1	 13.03	 2.48	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58949	 1	 15.93	 2.74	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58950	 1	 12.27	 2.74	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58951	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58952	 1	 40.51	 9.11	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58953	 1	 9.29	 2.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58954	 1	 13.34	 2.5	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58955	 1	 10.37	 2.87	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58956	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58957	 1	 16.25	 4.55	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58958	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58959	 1	 8.92	 1.46	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58960	 1	 8.6	 2.32	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58961	 1	 4.58	 1.05	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58962	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58963	 1	 5.55	 0.88	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58964	 1	 8.94	 1.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58965	 1	 5.22	 0.8	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58966	 1	 0.0	 0.0	 0.0	 -36.59	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58967	 1	 0.0	 0.0	 0.0	 21.45	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58968	 1	 3.13	 0.7	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58969	 1	 12.61	 1.96	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58970	 1	 4.94	 0.79	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58971	 1	 9.83	 1.99	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58972	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58973	 1	 24.49	 -3.69	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58974	 1	 0.0	 0.0	 0.0	 -42.59	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58975	 1	 16.01	 4.89	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58976	 1	 10.6	 2.73	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58977	 1	 0.0	 0.0	 0.0	 -212.69	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58978	 1	 12.6	 3.56	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58979	 1	 21.37	 4.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58980	 1	 8.25	 1.4	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58981	 1	 18.47	 4.16	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58982	 1	 0.0	 0.0	 0.0	 2.42	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	58983	 1	 10.23	 1.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58984	 1	 11.18	 1.47	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58985	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58986	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58987	 1	 12.82	 2.83	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	58988	 1	 5.49	 0.84	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58989	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58990	 1	 6.99	 1.28	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58991	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58992	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58993	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58994	 1	 3.5	 0.88	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58995	 1	 23.8	 2.97	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58996	 1	 4.98	 0.63	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	58997	 1	 0.0	 0.0	 0.0	 -239.89	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	58998	 1	 0.0	 0.0	 0.0	 -170.45	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58999	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59000	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59001	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59002	 1	 5.41	 1.29	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59003	 1	 4.77	 1.21	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59004	 1	 5.27	 1.55	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59005	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59006	 1	 44.6	 9.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59007	 1	 13.27	 3.28	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59008	 1	 31.38	 6.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59009	 1	 51.06	 6.2	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59010	 1	 7.23	 2.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59011	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59012	 1	 16.32	 4.56	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59013	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59014	 1	 13.95	 4.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59015	 1	 20.71	 4.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59016	 1	 0.0	 0.0	 0.0	 -86.66	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59017	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59018	 1	 18.73	 4.18	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59019	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59020	 1	 5.06	 1.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59021	 1	 2.07	 0.37	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59022	 1	 9.04	 1.8	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59023	 1	 8.76	 2.02	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59024	 1	 6.93	 1.44	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59025	 1	 3.01	 0.66	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59026	 1	 3.4	 0.45	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59027	 1	 4.08	 0.79	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59028	 1	 7.82	 1.98	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59029	 1	 4.37	 1.13	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59030	 1	 10.97	 2.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59031	 1	 7.68	 1.88	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59032	 1	 9.33	 2.47	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59033	 1	 7.06	 1.42	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59034	 1	 9.29	 2.68	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59035	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59036	 1	 15.31	 4.16	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59037	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59038	 1	 10.87	 1.47	 0.0	 -1.25	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59039	 1	 2.5	 0.39	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59040	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59041	 1	 5.23	 1.42	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59042	 1	 14.91	 3.48	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59043	 1	 12.58	 2.01	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59044	 1	 0.03	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59045	 1	 8.84	 -0.9	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59046	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59047	 1	 7.82	 1.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59048	 1	 6.52	 1.67	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59049	 1	 13.73	 2.56	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59050	 1	 6.98	 1.18	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59051	 1	 4.95	 1.02	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59052	 1	 24.19	 4.98	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59053	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59054	 1	 6.81	 1.61	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59055	 1	 5.5	 1.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59056	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59057	 1	 11.66	 2.3	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59058	 1	 1.58	 0.47	 0.0	 -50.49	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59059	 1	 193.77	 58.88	 0.0	 32.99	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59060	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59061	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59062	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59063	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59064	 1	 4.81	 1.39	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59065	 1	 3.87	 1.24	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59066	 1	 5.35	 1.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59067	 1	 6.36	 1.74	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59068	 1	 8.08	 1.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59069	 1	 6.77	 0.85	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59070	 1	 61.65	 9.16	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59071	 1	 0.0	 0.0	 0.0	 -21.21	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59072	 1	 14.19	 2.63	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59073	 1	 0.0	 0.0	 0.0	 -75.38	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59074	 1	 5.59	 1.76	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59075	 1	 0.0	 0.0	 0.0	 -400.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59076	 1	 0.0	 0.0	 0.0	 -19.38	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59077	 1	 7.92	 1.35	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59078	 1	 19.5	 4.58	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59079	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59080	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59081	 1	 6.52	 1.41	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59082	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59083	 1	 5.92	 1.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59084	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59085	 1	 19.59	 5.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59086	 1	 16.56	 2.84	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59087	 1	 13.0	 3.81	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59088	 1	 5.66	 0.93	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59089	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59090	 1	 11.47	 3.26	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59091	 1	 49.95	 9.91	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59092	 1	 10.14	 1.57	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59093	 1	 1.83	 0.31	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59094	 1	 3.21	 0.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59095	 1	 0.0	 0.0	 0.0	 -121.1	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59096	 1	 3.9	 1.12	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59097	 1	 11.02	 1.99	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59098	 1	 2.13	 0.43	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59099	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59100	 1	 7.02	 1.73	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59101	 1	 0.0	 0.0	 0.0	 -81.51	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59102	 1	 10.4	 3.08	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59103	 1	 10.93	 1.67	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59104	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59105	 1	 0.0	 0.0	 0.0	 -20.97	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59106	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59107	 1	 4.37	 0.91	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59108	 1	 0.0	 0.0	 0.0	 -47.05	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59109	 1	 2.3	 0.38	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59110	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59111	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59112	 1	 1.8	 0.44	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59113	 1	 2.94	 0.94	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59114	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59115	 1	 3.25	 0.89	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59116	 1	 6.08	 0.86	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59117	 1	 3.43	 0.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59118	 1	 0.0	 0.0	 0.0	 -46.33	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59119	 1	 3.25	 1.02	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59120	 1	 2.24	 0.54	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59121	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59122	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59123	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59124	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59125	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59126	 1	 2.97	 0.59	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59127	 1	 8.42	 2.53	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59128	 1	 4.24	 1.26	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59129	 1	 5.64	 1.02	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59130	 1	 0.0	 0.0	 0.0	 -101.23	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59131	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59132	 1	 5.5	 1.11	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59133	 1	 0.0	 0.0	 0.0	 -126.27	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59134	 1	 9.58	 2.88	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59135	 1	 10.92	 2.73	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59136	 1	 11.16	 2.39	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59137	 1	 9.73	 1.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59138	 1	 38.32	 10.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59139	 1	 2.92	 0.58	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59140	 1	 0.0	 0.0	 0.0	 -49.34	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59141	 1	 17.96	 5.13	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59142	 1	 8.0	 1.01	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59143	 1	 3.01	 0.74	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59144	 1	 7.12	 2.17	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59145	 1	 6.86	 1.16	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59146	 1	 3.59	 0.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59147	 1	 5.72	 1.72	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59148	 1	 1.78	 0.43	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59149	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59150	 1	 7.4	 1.46	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59151	 1	 5.6	 -1.75	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59152	 1	 6.84	 1.9	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59153	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59154	 1	 13.09	 2.61	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59155	 1	 10.07	 2.46	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59156	 1	 4.95	 0.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59157	 1	 4.49	 0.88	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59158	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59159	 1	 0.0	 0.0	 0.0	 -54.89	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59160	 1	 0.0	 0.0	 0.0	 -181.4	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59161	 1	 7.12	 1.17	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59162	 1	 0.0	 0.0	 0.0	 -195.86	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59163	 1	 4.14	 1.12	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59164	 1	 7.73	 2.16	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59165	 1	 5.03	 1.55	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59166	 1	 12.52	 3.25	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59167	 1	 6.64	 1.82	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59168	 1	 22.75	 6.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59169	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59170	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59171	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59172	 1	 12.83	 3.26	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59173	 1	 9.55	 2.38	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59174	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59175	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59176	 1	 4.55	 1.1	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59177	 1	 5.98	 1.12	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59178	 1	 10.51	 2.87	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59179	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59180	 1	 19.61	 5.61	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59181	 1	 5.06	 0.7	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59182	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59183	 1	 0.0	 0.0	 0.0	 -93.57	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59184	 1	 0.0	 0.0	 0.0	 -172.41	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59185	 1	 12.85	 2.25	 0.0	 -14.39	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59186	 1	 2.48	 0.54	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59187	 1	 10.37	 3.17	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59188	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59189	 1	 9.67	 1.99	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59190	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59191	 1	 10.62	 3.08	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59192	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59193	 1	 6.42	 1.22	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59194	 1	 7.57	 2.3	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59195	 1	 3.77	 0.65	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59196	 1	 9.04	 2.87	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59197	 1	 5.35	 1.11	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59198	 1	 7.57	 0.97	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59199	 1	 7.61	 2.17	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59200	 1	 3.56	 3.18	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59201	 1	 2.61	 0.34	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59202	 1	 3.4	 0.74	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59203	 1	 0.0	 0.0	 0.0	 -229.1	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59204	 1	 26.47	 4.24	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59205	 1	 11.01	 1.36	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59206	 1	 0.03	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59207	 1	 2.57	 0.47	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59208	 1	 5.62	 1.57	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59209	 1	 6.07	 1.72	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59210	 1	 0.0	 0.0	 0.0	 -48.78	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59211	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59212	 1	 9.43	 1.47	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59213	 1	 3.49	 0.95	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59214	 1	 3.07	 0.65	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59215	 1	 4.83	 0.65	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59216	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59217	 1	 7.42	 1.65	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59218	 1	 5.16	 1.48	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59219	 1	 1.95	 0.5	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59220	 1	 1.9	 0.31	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59221	 1	 13.84	 1.99	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59222	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59223	 1	 10.69	 2.64	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59224	 1	 10.41	 1.57	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59225	 1	 8.57	 2.64	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59226	 1	 2.54	 0.65	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59227	 1	 13.64	 2.45	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59228	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59229	 1	 4.07	 0.82	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59230	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59231	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59232	 1	 10.35	 3.06	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59233	 1	 6.96	 1.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59234	 1	 9.03	 1.97	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59235	 1	 10.35	 1.77	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59236	 1	 17.7	 4.35	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59237	 1	 6.01	 0.93	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59238	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59239	 1	 37.15	 5.14	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59240	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59241	 1	 11.32	 1.65	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59242	 1	 12.9	 3.33	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59243	 1	 5.51	 1.71	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59244	 1	 5.95	 1.6	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59245	 1	 19.71	 4.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59246	 1	 4.31	 0.66	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59247	 1	 0.0	 0.0	 0.0	 -299.41	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59248	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59249	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59250	 1	 2.71	 0.49	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59251	 1	 0.0	 0.0	 0.0	 -170.86	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59252	 1	 17.14	 5.07	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59253	 1	 9.07	 1.18	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59254	 1	 12.87	 3.13	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59255	 1	 0.0	 0.0	 0.0	 -562.82	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59256	 1	 0.0	 0.0	 0.0	 -0.9	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59257	 1	 8.58	 1.68	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59258	 1	 4.06	 0.56	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59259	 1	 10.5	 3.24	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59260	 1	 4.97	 1.17	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59261	 1	 9.08	 1.47	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59262	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59263	 1	 4.03	 1.3	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59264	 1	 10.73	 3.26	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59265	 1	 5.67	 0.85	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59266	 1	 13.51	 3.25	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59267	 1	 8.55	 2.1	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59268	 1	 7.16	 1.83	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59269	 1	 8.31	 1.8	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59270	 1	 20.57	 4.25	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59271	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59272	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59273	 1	 12.66	 2.62	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59274	 1	 3.94	 0.99	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59275	 1	 3.97	 1.01	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59276	 1	 3.42	 0.7	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59277	 1	 8.17	 1.93	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59278	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59279	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59280	 1	 1.98	 0.36	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59281	 1	 0.99	 0.12	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59282	 1	 0.87	 0.22	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59283	 1	 0.0	 0.0	 0.0	 -25.93	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59284	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59285	 1	 4.72	 0.58	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59286	 1	 3.85	 1.13	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59287	 1	 2.71	 0.56	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59288	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59289	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59290	 1	 6.0	 1.57	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59291	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59292	 1	 9.34	 2.15	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59293	 1	 3.54	 0.95	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59294	 1	 11.49	 3.24	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59295	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59296	 1	 15.55	 4.33	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59297	 1	 11.29	 1.63	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59298	 1	 3.68	 0.6	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59299	 1	 1.84	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59300	 1	 3.55	 0.8	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59301	 1	 10.3	 2.95	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59302	 1	 5.65	 1.08	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59303	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59304	 1	 9.16	 2.1	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59306	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59307	 1	 4.71	 1.53	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59308	 1	 5.45	 0.98	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59309	 1	 4.54	 1.25	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59310	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59311	 1	 15.17	 4.6	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59312	 1	 14.83	 4.2	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59313	 1	 3.37	 1.05	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59314	 1	 5.03	 1.37	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59315	 1	 2.86	 0.75	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59316	 1	 18.15	 4.38	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59317	 1	 9.62	 2.44	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59318	 1	 4.08	 1.14	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59319	 1	 6.65	 1.54	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59320	 1	 13.29	 2.58	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59321	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59322	 1	 5.72	 1.63	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59323	 1	 47.97	 8.46	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59324	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59325	 1	 4.22	 0.75	 0.0	 -35.36	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59326	 1	 6.78	 0.88	 0.0	 -286.85	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59327	 1	 8.31	 1.82	 0.0	 -123.92	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59328	 1	 5.04	 0.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59329	 1	 4.08	 0.73	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59330	 1	 4.3	 0.5	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59331	 1	 8.34	 -2.52	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59332	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59333	 1	 0.69	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59334	 1	 0.96	 0.12	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59335	 1	 9.29	 2.71	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59336	 1	 6.13	 1.82	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59337	 1	 8.49	 1.94	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59338	 1	 0.0	 0.0	 0.0	 -147.75	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59339	 1	 1.77	 0.45	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59340	 1	 24.11	 7.33	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59341	 1	 0.0	 0.0	 0.0	 -256.81	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59342	 1	 6.03	 0.82	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59343	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59344	 1	 6.02	 1.85	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59345	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59346	 1	 8.3	 1.78	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59347	 1	 8.26	 1.93	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59348	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59349	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59350	 1	 10.36	 2.26	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59351	 1	 0.0	 0.0	 0.0	 352.38	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59352	 1	 22.5	 6.93	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59353	 1	 40.94	 8.54	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59354	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59355	 1	 9.26	 1.91	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59356	 1	 6.27	 1.76	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59357	 1	 7.15	 1.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59358	 1	 0.0	 0.0	 0.0	 81.45	 5	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59359	 1	 8.19	 1.64	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59360	 1	 10.07	 1.96	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59361	 1	 9.22	 1.52	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59362	 1	 19.45	 5.98	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59363	 1	 0.0	 0.0	 0.0	 -56.04	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59364	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59365	 1	 7.03	 2.13	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59366	 1	 8.07	 2.33	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59367	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59368	 1	 6.56	 1.96	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59369	 1	 6.53	 1.75	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59370	 1	 14.73	 4.28	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59371	 1	 17.08	 3.63	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59372	 1	 3.84	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59373	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59374	 1	 12.05	 3.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59375	 1	 5.79	 1.05	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59376	 1	 0.0	 0.0	 0.0	 -51.03	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59377	 1	 4.94	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59378	 1	 14.93	 2.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59379	 1	 6.16	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59380	 1	 8.06	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59381	 1	 3.92	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59382	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59383	 1	 5.22	 0.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59384	 1	 6.92	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59385	 1	 3.49	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59386	 1	 4.43	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59387	 1	 5.79	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59388	 1	 8.54	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59389	 1	 19.67	 2.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59390	 1	 4.8	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59391	 1	 7.29	 1.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59392	 1	 7.4	 1.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59393	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59394	 1	 12.69	 2.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59395	 1	 5.81	 0.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59396	 1	 6.01	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59397	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59398	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59399	 1	 5.07	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59400	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59401	 1	 9.0	 1.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59402	 1	 3.53	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59403	 1	 3.93	 0.74	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59404	 1	 6.91	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59405	 1	 2.47	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59406	 1	 6.57	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59407	 1	 2.74	 0.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59408	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59409	 1	 4.13	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59410	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59411	 1	 7.59	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59412	 1	 10.72	 2.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59413	 1	 6.79	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59414	 1	 4.96	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59415	 1	 6.75	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59416	 1	 7.57	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59417	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59418	 1	 13.72	 3.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59419	 1	 6.23	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59420	 1	 13.64	 3.86	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59421	 1	 5.75	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59422	 1	 5.54	 1.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59423	 1	 5.22	 0.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59424	 1	 7.02	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59425	 1	 6.47	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59426	 1	 5.78	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59427	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59428	 1	 15.47	 4.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59429	 1	 0.0	 0.0	 0.0	 59.74	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59430	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59431	 1	 3.84	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59432	 1	 6.61	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59433	 1	 5.86	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59434	 1	 5.95	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59435	 1	 13.08	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59436	 1	 6.54	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59437	 1	 0.0	 0.0	 0.0	 122.93	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59438	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59439	 1	 4.43	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59440	 1	 5.37	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59441	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59442	 1	 4.22	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59443	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59444	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59445	 1	 4.93	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59446	 1	 2.7	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59447	 1	 6.8	 1.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59448	 1	 4.3	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59449	 1	 7.08	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59450	 1	 4.11	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59451	 1	 7.13	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59452	 1	 6.1	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59453	 1	 3.74	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59454	 1	 4.34	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59455	 1	 7.74	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59456	 1	 7.25	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59457	 1	 8.52	 0.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59458	 1	 7.2	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59459	 1	 5.75	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59460	 1	 5.46	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59461	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59462	 1	 10.13	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59463	 1	 4.6	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59464	 1	 8.37	 1.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59465	 1	 9.73	 2.74	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59466	 1	 5.19	 0.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59467	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59468	 1	 3.23	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59469	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59470	 1	 8.3	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59471	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59472	 1	 3.34	 0.76	 0.0	 27.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59473	 1	 12.64	 3.3	 0.0	 10.1	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59474	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59475	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59476	 1	 6.43	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59477	 1	 6.84	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59478	 1	 13.13	 2.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59479	 1	 4.44	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59480	 1	 15.38	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59481	 1	 5.22	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59482	 1	 4.08	 0.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59483	 1	 5.9	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59484	 1	 5.55	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59485	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59486	 1	 4.95	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59487	 1	 14.11	 3.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59488	 1	 9.48	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59489	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59490	 1	 17.37	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59491	 1	 9.14	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59492	 1	 23.46	 3.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59493	 1	 11.12	 3.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59494	 1	 8.95	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59495	 1	 5.47	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59496	 1	 7.09	 1.52	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59497	 1	 12.37	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59498	 1	 2.6	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59499	 1	 4.91	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59500	 1	 10.21	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59501	 1	 13.65	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59502	 1	 3.14	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59503	 1	 7.69	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59504	 1	 4.54	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59505	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59506	 1	 5.46	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59507	 1	 13.27	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59508	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59509	 1	 7.68	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59510	 1	 12.59	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59511	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59512	 1	 8.22	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59513	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59514	 1	 5.14	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59515	 1	 6.7	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59516	 1	 10.01	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59517	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59518	 1	 5.92	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59519	 1	 3.28	 -4.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59520	 1	 5.96	 -3.9	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59521	 1	 11.19	 -3.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59522	 1	 5.35	 -3.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59523	 1	 3.69	 -3.92	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59524	 1	 9.46	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59525	 1	 9.28	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59526	 1	 10.92	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59527	 1	 11.03	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59528	 1	 13.1	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59529	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59530	 1	 2.61	 -3.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59531	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59532	 1	 8.58	 -3.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59533	 1	 11.71	 -3.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59534	 1	 15.41	 -3.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59535	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59536	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59537	 1	 8.21	 -3.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59538	 1	 12.75	 -3.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59539	 1	 1.76	 -3.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59540	 1	 14.25	 -3.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59541	 1	 9.96	 -3.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59542	 1	 12.84	 -3.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59543	 1	 9.73	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59544	 1	 5.31	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59545	 1	 6.66	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59546	 1	 4.23	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59547	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59548	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59549	 1	 10.29	 2.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59550	 1	 6.14	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59551	 1	 14.74	 4.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59552	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59553	 1	 7.06	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59554	 1	 3.9	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59555	 1	 15.03	 2.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59556	 1	 11.51	 1.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59557	 1	 13.19	 3.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59558	 1	 11.92	 2.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59559	 1	 0.0	 0.0	 0.0	 289.84	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59560	 1	 4.01	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59561	 1	 5.38	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59562	 1	 4.92	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59563	 1	 17.02	 3.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59564	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59565	 1	 0.0	 0.0	 0.0	 32.07	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59566	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59567	 1	 12.29	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59569	 1	 7.82	 -14.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59570	 1	 11.64	 2.16	 0.0	 43.41	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59571	 1	 0.0	 0.0	 0.0	 51.24	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59572	 1	 0.0	 0.0	 0.0	 -119.15	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59573	 1	 14.43	 4.0	 0.0	 -44.44	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59574	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59575	 1	 9.01	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59576	 1	 4.07	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59577	 1	 4.4	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59578	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59579	 1	 3.5	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59580	 1	 4.43	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59581	 1	 4.4	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59582	 1	 7.03	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59583	 1	 3.26	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59584	 1	 7.88	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59585	 1	 8.42	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59586	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59587	 1	 14.74	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59588	 1	 6.29	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59589	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59590	 1	 10.55	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59591	 1	 5.02	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59592	 1	 12.56	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59593	 1	 18.24	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59594	 1	 44.28	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59595	 1	 19.81	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59596	 1	 11.25	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59597	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59598	 1	 9.78	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59599	 1	 6.94	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59600	 1	 9.23	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59601	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59602	 1	 3.83	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59603	 1	 4.7	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59604	 1	 3.83	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59605	 1	 4.76	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59606	 1	 1.69	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59607	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59608	 1	 5.21	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59609	 1	 4.52	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59610	 1	 8.29	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59611	 1	 7.58	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59612	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59613	 1	 4.34	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59614	 1	 5.42	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59615	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59616	 1	 12.13	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59617	 1	 6.47	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59618	 1	 5.78	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59619	 1	 4.34	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59620	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59621	 1	 2.68	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59622	 1	 6.37	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59623	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59624	 1	 12.1	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59625	 1	 11.99	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59626	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59627	 1	 7.62	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59628	 1	 6.29	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59629	 1	 2.81	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59630	 1	 5.11	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59631	 1	 9.65	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59632	 1	 8.7	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59633	 1	 9.88	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59634	 1	 5.27	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59635	 1	 3.8	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59636	 1	 11.89	 -3.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59637	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59638	 1	 14.32	 -7.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59639	 1	 7.54	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59640	 1	 1.68	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59641	 1	 5.82	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59642	 1	 2.78	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59643	 1	 3.78	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59644	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59645	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59646	 1	 4.15	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59647	 1	 7.44	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59648	 1	 3.09	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59649	 1	 6.78	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59650	 1	 5.06	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59651	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59652	 1	 6.8	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59653	 1	 3.43	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59654	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59655	 1	 6.42	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59656	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59657	 1	 8.35	 -14.26	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59658	 1	 16.59	 -3.77	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59659	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59660	 1	 7.27	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59661	 1	 22.2	 3.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59662	 1	 4.01	 0.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59663	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59664	 1	 15.13	 2.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59665	 1	 3.68	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59666	 1	 4.6	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59667	 1	 5.28	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59668	 1	 3.06	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59669	 1	 4.87	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59670	 1	 2.6	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59671	 1	 1.59	 0.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59672	 1	 9.16	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59673	 1	 6.0	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59674	 1	 3.09	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59675	 1	 13.27	 4.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59676	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59677	 1	 7.86	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59678	 1	 5.1	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59679	 1	 5.91	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59680	 1	 7.57	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59681	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59682	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59683	 1	 4.35	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59684	 1	 6.35	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59685	 1	 10.35	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59686	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59687	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59688	 1	 5.6	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59689	 1	 3.69	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59690	 1	 10.76	 1.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59691	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59692	 1	 4.99	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59693	 1	 8.05	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59694	 1	 4.97	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59695	 1	 3.91	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59696	 1	 14.46	 4.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59697	 1	 6.17	 0.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59698	 1	 9.65	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59699	 1	 4.83	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59700	 1	 4.33	 0.67	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59701	 1	 4.84	 0.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59702	 1	 17.9	 5.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59703	 1	 4.79	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59704	 1	 17.3	 4.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59705	 1	 7.67	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59706	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59707	 1	 14.0	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59708	 1	 3.83	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59709	 1	 4.48	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59710	 1	 4.15	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59711	 1	 2.45	 0.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59712	 1	 6.06	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59713	 1	 6.54	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59714	 1	 5.59	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59715	 1	 9.51	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59716	 1	 3.38	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59717	 1	 3.82	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59718	 1	 3.61	 0.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59719	 1	 4.56	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59720	 1	 26.75	 8.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59721	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59722	 1	 12.59	 3.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59723	 1	 7.66	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59724	 1	 8.03	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59725	 1	 10.48	 2.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59726	 1	 4.8	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59727	 1	 4.64	 0.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59728	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59729	 1	 0.0	 0.0	 0.0	 85.89	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59730	 1	 9.15	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59731	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59732	 1	 3.25	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59733	 1	 4.48	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59734	 1	 3.34	 0.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59735	 1	 3.83	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59736	 1	 2.59	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59737	 1	 4.64	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59738	 1	 4.66	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59739	 1	 4.2	 0.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59740	 1	 4.93	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59741	 1	 4.86	 1.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59742	 1	 2.0	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59743	 1	 2.47	 0.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59744	 1	 5.15	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59745	 1	 3.76	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59746	 1	 1.82	 0.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59747	 1	 3.75	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59748	 1	 5.28	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59749	 1	 3.19	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59750	 1	 3.17	 0.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59751	 1	 4.82	 1.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59752	 1	 7.94	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59753	 1	 3.0	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59754	 1	 4.65	 1.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59755	 1	 4.68	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59756	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59757	 1	 3.5	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59758	 1	 2.78	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59759	 1	 5.27	 1.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59760	 1	 3.63	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59761	 1	 4.22	 0.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59762	 1	 0.05	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59763	 1	 55.03	 18.17	 0.0	 223.9	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59764	 1	 3.29	 0.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59765	 1	 9.95	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59766	 1	 8.87	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59767	 1	 6.79	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59768	 1	 8.26	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59769	 1	 18.06	 5.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59770	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59771	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59772	 1	 8.0	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59773	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59774	 1	 3.01	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59775	 1	 11.71	 3.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59776	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59777	 1	 8.86	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59778	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59779	 1	 23.05	 6.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59780	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59781	 1	 9.53	 2.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59782	 1	 6.86	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59783	 1	 13.04	 2.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59784	 1	 8.81	 2.45	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59785	 1	 9.61	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59786	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59787	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59788	 1	 10.37	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59789	 1	 2.33	 0.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59790	 1	 13.19	 2.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59791	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59792	 1	 7.77	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59793	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59794	 1	 6.41	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59795	 1	 7.62	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59796	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59797	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59798	 1	 8.54	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59799	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59800	 1	 5.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59801	 1	 5.12	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59802	 1	 4.97	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59803	 1	 6.03	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59804	 1	 5.85	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59805	 1	 4.96	 0.96	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59806	 1	 5.82	 1.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59807	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59808	 1	 8.14	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59809	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59810	 1	 8.41	 1.05	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59811	 1	 10.01	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59812	 1	 10.29	 2.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59813	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59814	 1	 4.17	 0.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59815	 1	 7.92	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59816	 1	 7.74	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59817	 1	 13.93	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59818	 1	 9.44	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59819	 1	 3.6	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59820	 1	 6.46	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59821	 1	 1.9	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59822	 1	 6.25	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59823	 1	 3.05	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59824	 1	 9.61	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59825	 1	 4.97	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59826	 1	 4.62	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59827	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59828	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59829	 1	 3.38	 0.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59830	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59831	 1	 3.92	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59832	 1	 1.76	 0.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59833	 1	 5.06	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59834	 1	 19.24	 3.28	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59835	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59836	 1	 8.46	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59837	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59838	 1	 10.7	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59839	 1	 9.03	 2.43	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59840	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59841	 1	 6.58	 0.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59842	 1	 6.05	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59843	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59844	 1	 4.14	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59845	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59846	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59847	 1	 6.39	 1.27	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59848	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59849	 1	 0.0	 0.0	 0.0	 -182.04	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59850	 1	 0.0	 0.0	 0.0	 -13.42	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59851	 1	 7.96	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59852	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59853	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59854	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59855	 1	 4.64	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59856	 1	 3.41	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59857	 1	 3.96	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59858	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59859	 1	 5.93	 1.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59860	 1	 6.42	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59861	 1	 4.86	 1.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59862	 1	 5.34	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59863	 1	 5.58	 1.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59864	 1	 5.07	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59865	 1	 4.91	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59866	 1	 5.8	 1.48	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59867	 1	 20.81	 3.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59868	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59869	 1	 11.61	 2.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59870	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59871	 1	 3.38	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59872	 1	 4.36	 1.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59873	 1	 4.06	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59874	 1	 7.36	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59875	 1	 3.14	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59876	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59877	 1	 4.5	 0.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59878	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59879	 1	 4.34	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59880	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59881	 1	 4.18	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59882	 1	 5.88	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59883	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59884	 1	 15.44	 3.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59885	 1	 5.87	 1.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59886	 1	 0.0	 0.0	 0.0	 -76.09	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59887	 1	 2.7	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59888	 1	 5.13	 0.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59889	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59890	 1	 8.62	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59891	 1	 3.93	 0.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59892	 1	 3.13	 0.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59893	 1	 4.24	 0.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59894	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59895	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59896	 1	 4.44	 1.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59897	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59898	 1	 5.39	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59899	 1	 4.5	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59900	 1	 4.44	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59901	 1	 3.81	 0.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59902	 1	 2.95	 0.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59903	 1	 3.65	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59904	 1	 4.12	 0.47	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59905	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59906	 1	 4.44	 1.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59907	 1	 6.43	 1.18	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59908	 1	 0.0	 0.0	 0.0	 64.05	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59909	 1	 9.38	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59910	 1	 2.18	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59911	 1	 9.48	 1.81	 0.0	 34.22	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59912	 1	 2.73	 0.42	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59913	 1	 6.82	 1.92	 0.0	 -160.66	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59914	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59915	 1	 5.29	 1.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59916	 1	 10.95	 1.47	 0.0	 -10.2	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59917	 1	 3.1	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59918	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59919	 1	 7.62	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59920	 1	 62.42	 18.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59921	 1	 6.99	 1.28	 0.0	 117.52	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59922	 1	 0.0	 0.0	 0.0	 108.02	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59923	 1	 0.0	 0.0	 0.0	 442.2	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59924	 1	 0.0	 0.0	 0.0	 144.56	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59925	 1	 5.36	 0.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59926	 1	 1.93	 0.49	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59927	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59928	 1	 6.41	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59929	 1	 8.54	 2.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59930	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59931	 1	 0.0	 0.0	 0.0	 -11.43	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59932	 1	 11.84	 3.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59933	 1	 2.38	 0.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59934	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59935	 1	 6.94	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59936	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59937	 1	 13.25	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59938	 1	 1.34	 0.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59939	 1	 3.08	 0.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59940	 1	 2.29	 0.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59941	 1	 3.1	 0.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59942	 1	 5.98	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59943	 1	 6.37	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59944	 1	 4.15	 1.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59945	 1	 3.98	 1.05	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59946	 1	 5.67	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59947	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59948	 1	 2.41	 0.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59949	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59950	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59951	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59952	 1	 2.5	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59953	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59954	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59955	 1	 9.18	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59956	 1	 4.59	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59957	 1	 6.88	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59958	 1	 0.0	 0.0	 0.0	 -152.86	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59959	 1	 144.8	 47.51	 0.0	 439.24	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	59960	 1	 5.04	 1.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59961	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59962	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59963	 1	 4.04	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59964	 1	 2.24	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59965	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59966	 1	 4.43	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59967	 1	 2.93	 0.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59968	 1	 10.17	 1.78	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59969	 1	 5.22	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59970	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59971	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59972	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59973	 1	 6.05	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59974	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59975	 1	 4.16	 0.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59976	 1	 4.63	 0.9	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59977	 1	 10.19	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59978	 1	 9.77	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59979	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59980	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59981	 1	 6.06	 1.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59982	 1	 6.25	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59983	 1	 10.49	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59984	 1	 4.84	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59985	 1	 6.85	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59986	 1	 6.02	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59987	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59988	 1	 4.87	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59989	 1	 5.37	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59990	 1	 8.48	 1.97	 0.0	 59.03	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59991	 1	 11.6	 1.77	 0.0	 73.45	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	59992	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	59993	 1	 6.18	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59994	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59995	 1	 8.55	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59996	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59997	 1	 9.08	 1.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59998	 1	 3.47	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	59999	 1	 6.16	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60000	 1	 3.49	 0.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60001	 1	 2.96	 0.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60002	 1	 4.14	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60003	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60004	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60005	 1	 4.8	 1.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60006	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60007	 1	 41.7	 9.5	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60008	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60009	 1	 6.08	 1.19	 0.0	 -193.5	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60010	 1	 4.89	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60011	 1	 4.76	 0.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60012	 1	 6.94	 1.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60013	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60014	 1	 6.49	 1.05	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60015	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60016	 1	 7.82	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60017	 1	 6.21	 1.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60018	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60019	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60020	 1	 15.18	 3.23	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60021	 1	 41.37	 12.19	 0.0	 100.92	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60022	 1	 5.85	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60023	 1	 9.22	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60024	 1	 9.96	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60025	 1	 11.5	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60026	 1	 7.44	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60027	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60028	 1	 12.01	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60029	 1	 18.87	 5.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60030	 1	 6.35	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60031	 1	 7.37	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60032	 1	 12.5	 3.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60033	 1	 7.83	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60034	 1	 0.0	 0.0	 0.0	 41.06	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60035	 1	 4.63	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60036	 1	 4.0	 1.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60037	 1	 3.34	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60038	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60039	 1	 4.55	 1.28	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60040	 1	 3.56	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60041	 1	 2.8	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60042	 1	 3.48	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60043	 1	 5.4	 1.16	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60044	 1	 0.0	 0.0	 0.0	 -51.89	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60045	 1	 9.71	 2.81	 0.0	 -112.22	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60046	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60047	 1	 13.04	 2.8	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60048	 1	 12.74	 3.36	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60049	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60050	 1	 4.88	 1.27	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60051	 1	 11.93	 2.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60052	 1	 12.64	 3.64	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60053	 1	 12.23	 -5.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60054	 1	 11.26	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60055	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60056	 1	 10.3	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60057	 1	 12.48	 2.13	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60058	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60059	 1	 5.75	 1.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60060	 1	 3.05	 0.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60061	 1	 8.97	 2.63	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60062	 1	 7.28	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60063	 1	 5.18	 0.88	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60064	 1	 4.84	 0.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60065	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60066	 1	 4.33	 0.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60067	 1	 5.79	 1.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60068	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60069	 1	 0.0	 0.0	 0.0	 -243.07	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60070	 1	 7.17	 1.77	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60071	 1	 2.87	 0.35	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60072	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60073	 1	 0.0	 0.0	 0.0	 194.1	 8	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60074	 1	 4.95	 1.19	 0.0	 -104.36	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60075	 1	 5.95	 1.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60076	 1	 11.64	 3.51	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60077	 1	 0.0	 0.0	 0.0	 9.3	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60078	 1	 5.07	 0.67	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60079	 1	 8.78	 1.86	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60080	 1	 5.01	 0.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60081	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60082	 1	 5.68	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60083	 1	 8.13	 1.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60084	 1	 3.68	 0.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60085	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60086	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60087	 1	 10.21	 2.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60088	 1	 4.93	 1.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60089	 1	 4.08	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60090	 1	 7.61	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60091	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60092	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60093	 1	 7.06	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60094	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60095	 1	 10.23	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60096	 1	 3.34	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60097	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60098	 1	 14.21	 3.24	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60099	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60100	 1	 9.08	 1.2	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60101	 1	 4.91	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60102	 1	 7.65	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60103	 1	 4.7	 1.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60104	 1	 11.44	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60105	 1	 7.53	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60106	 1	 4.01	 1.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60107	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60108	 1	 7.24	 0.78	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60109	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60110	 1	 6.51	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60111	 1	 6.58	 0.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60112	 1	 16.32	 3.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60113	 1	 10.16	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60114	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60115	 1	 3.5	 0.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60116	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60117	 1	 4.8	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60118	 1	 9.85	 2.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60119	 1	 4.25	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60120	 1	 10.3	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60121	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60122	 1	 8.14	 1.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60123	 1	 6.47	 0.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60124	 1	 5.43	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60125	 1	 6.02	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60126	 1	 8.5	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60127	 1	 5.52	 1.36	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60128	 1	 3.63	 0.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60129	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60130	 1	 5.95	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60131	 1	 4.11	 0.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60132	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60133	 1	 3.36	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60134	 1	 6.68	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60135	 1	 6.99	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60136	 1	 4.53	 1.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60137	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60138	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60139	 1	 8.22	 2.03	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60140	 1	 23.09	 6.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60141	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60142	 1	 2.03	 0.52	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60143	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60144	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60145	 1	 10.41	 3.01	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60146	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60147	 1	 4.22	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60148	 1	 3.67	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60149	 1	 12.94	 4.07	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60150	 1	 8.31	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60151	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60152	 1	 7.16	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60153	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60154	 1	 5.24	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60155	 1	 10.96	 3.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60156	 1	 5.31	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60157	 1	 4.62	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60158	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60159	 1	 6.68	 2.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60160	 1	 3.94	 0.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60161	 1	 8.54	 0.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60162	 1	 7.72	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60163	 1	 6.96	 1.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60164	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60165	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60166	 1	 3.05	 0.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60167	 1	 3.31	 0.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60168	 1	 10.24	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60169	 1	 1.93	 0.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60170	 1	 8.03	 1.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60171	 1	 12.46	 2.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60172	 1	 7.21	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60173	 1	 4.35	 0.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60174	 1	 4.42	 0.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60175	 1	 15.55	 3.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60176	 1	 6.89	 0.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60177	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60178	 1	 3.33	 0.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60179	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60180	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60181	 1	 5.26	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60182	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60183	 1	 7.57	 1.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60184	 1	 11.78	 1.65	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60185	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60186	 1	 10.79	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60187	 1	 2.53	 0.49	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60188	 1	 9.31	 1.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60189	 1	 10.86	 2.75	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60190	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60191	 1	 22.54	 4.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60192	 1	 6.6	 1.4	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60193	 1	 7.91	 1.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60194	 1	 7.59	 1.25	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60195	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60196	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60197	 1	 5.22	 1.1	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60198	 1	 6.44	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60199	 1	 7.57	 1.73	 0.0	 -6.92	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60200	 1	 6.28	 1.67	 0.0	 41.82	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60201	 1	 12.9	 2.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60202	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60203	 1	 8.82	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60204	 1	 7.52	 2.04	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60205	 1	 5.88	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60206	 1	 9.77	 2.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60207	 1	 2.51	 0.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60208	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60209	 1	 4.54	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60210	 1	 10.37	 2.2	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60211	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60212	 1	 9.61	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60213	 1	 5.67	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60214	 1	 4.34	 0.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60215	 1	 50.31	 16.94	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60216	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60217	 1	 2.56	 0.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60218	 1	 3.8	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60219	 1	 5.86	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60220	 1	 2.77	 0.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60221	 1	 3.6	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60222	 1	 10.07	 2.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60223	 1	 8.59	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60224	 1	 1.89	 0.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60225	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60226	 1	 5.14	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60227	 1	 3.45	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60228	 1	 10.97	 2.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60229	 1	 3.16	 0.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60230	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60231	 1	 5.86	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60232	 1	 7.42	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60233	 1	 7.39	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60234	 1	 9.5	 2.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60235	 1	 11.08	 2.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60236	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60237	 1	 5.44	 1.56	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60238	 1	 5.66	 0.67	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60239	 1	 0.0	 0.0	 0.0	 -71.5	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60240	 1	 0.0	 0.0	 0.0	 -92.75	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60241	 1	 3.61	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60242	 1	 13.2	 2.87	 0.0	 -64.68	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60243	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60244	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60245	 1	 6.94	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60246	 1	 4.21	 0.59	 0.0	 -82.32	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60247	 1	 4.4	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60248	 1	 8.76	 2.12	 0.0	 20.02	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60249	 1	 0.0	 0.0	 0.0	 13.45	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60250	 1	 0.0	 0.0	 0.0	 -131.92	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60251	 1	 9.97	 2.18	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60252	 1	 14.06	 4.02	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60253	 1	 19.22	 -10.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60254	 1	 3.39	 0.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60255	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60256	 1	 16.78	 4.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60257	 1	 15.94	 2.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60258	 1	 0.0	 0.0	 0.0	 -26.08	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60259	 1	 1.47	 0.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60260	 1	 9.29	 2.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60261	 1	 2.81	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60262	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60263	 1	 3.77	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60264	 1	 4.55	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60265	 1	 54.11	 14.76	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60266	 1	 7.75	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60267	 1	 6.26	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60268	 1	 4.36	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60269	 1	 5.31	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60270	 1	 7.9	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60271	 1	 9.35	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60272	 1	 5.42	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60273	 1	 7.87	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60274	 1	 4.08	 0.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60275	 1	 6.78	 1.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60276	 1	 3.45	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60277	 1	 6.77	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60278	 1	 9.43	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60279	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60280	 1	 6.0	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60281	 1	 3.99	 -3.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60282	 1	 2.42	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60283	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60284	 1	 4.25	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60285	 1	 6.55	 0.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60286	 1	 4.23	 1.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60287	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60288	 1	 2.68	 0.67	 0.0	 49.21	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60289	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60290	 1	 5.49	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60291	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60292	 1	 4.52	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60293	 1	 5.34	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60294	 1	 3.61	 0.59	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60295	 1	 6.11	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60296	 1	 3.82	 0.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60297	 1	 7.65	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60298	 1	 5.24	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60299	 1	 4.24	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60300	 1	 6.07	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60301	 1	 6.77	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60302	 1	 0.0	 0.0	 0.0	 277.48	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60303	 1	 7.74	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60304	 1	 5.54	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60305	 1	 8.9	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60306	 1	 2.67	 0.62	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60307	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60308	 1	 6.66	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60309	 1	 5.85	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60310	 1	 12.39	 3.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60311	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60312	 1	 3.55	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60313	 1	 10.26	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60314	 1	 4.84	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60315	 1	 3.93	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60316	 1	 5.53	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60317	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60318	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60319	 1	 6.34	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60320	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60321	 1	 6.48	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60322	 1	 5.37	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60323	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60324	 1	 6.95	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60325	 1	 4.28	 1.1	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60326	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60327	 1	 4.55	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60328	 1	 5.18	 1.21	 0.0	 -73.01	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60329	 1	 7.17	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60330	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60331	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60332	 1	 5.22	 0.74	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60333	 1	 73.6	 18.38	 0.0	 22.91	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60334	 1	 4.13	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60335	 1	 4.25	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60336	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60337	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60338	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60339	 1	 4.39	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60340	 1	 22.22	 5.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60341	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60342	 1	 12.82	 2.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60343	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60344	 1	 3.93	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60345	 1	 6.08	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60346	 1	 8.28	 1.67	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60347	 1	 11.19	 2.17	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60348	 1	 7.1	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60349	 1	 7.36	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60350	 1	 5.34	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60351	 1	 5.52	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60352	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60353	 1	 5.39	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60354	 1	 5.18	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60355	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60356	 1	 7.42	 1.96	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60357	 1	 8.06	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60358	 1	 0.0	 0.0	 0.0	 -233.7	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60359	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60360	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60361	 1	 6.99	 1.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60362	 1	 3.18	 0.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60363	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60364	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60365	 1	 5.88	 1.08	 0.0	 168.84	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60366	 1	 5.25	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60367	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60368	 1	 4.11	 0.69	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60369	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60370	 1	 40.6	 12.16	 0.0	 76.52	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60371	 1	 5.65	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60372	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60373	 1	 4.92	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60374	 1	 5.37	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60375	 1	 3.17	 0.6	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60376	 1	 2.19	 0.58	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60377	 1	 3.51	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60378	 1	 9.13	 2.65	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60379	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60380	 1	 3.0	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60381	 1	 52.38	 12.81	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60382	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60383	 1	 3.97	 0.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60384	 1	 2.48	 0.59	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60385	 1	 2.19	 0.51	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60386	 1	 7.29	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60387	 1	 14.6	 3.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60388	 1	 145.61	 25.75	 0.0	 -102.62	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60389	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60390	 1	 3.14	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60391	 1	 6.21	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60392	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60393	 1	 3.6	 0.75	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60394	 1	 5.2	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60395	 1	 2.26	 0.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60396	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60397	 1	 7.48	 1.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60398	 1	 7.79	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60399	 1	 2.65	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60400	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60401	 1	 5.92	 0.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60402	 1	 4.49	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60403	 1	 3.74	 0.53	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60404	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60405	 1	 0.0	 0.0	 0.0	 137.91	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60406	 1	 5.83	 0.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60407	 1	 3.33	 0.6	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60408	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60409	 1	 4.34	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60410	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60411	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60412	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60413	 1	 4.57	 1.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60414	 1	 20.95	 5.63	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60415	 1	 7.35	 1.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60416	 1	 4.86	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60417	 1	 4.95	 0.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60418	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60419	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60420	 1	 9.5	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60421	 1	 4.12	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60422	 1	 5.87	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60423	 1	 0.0	 0.0	 0.0	 -83.74	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60424	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60425	 1	 7.98	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60426	 1	 14.11	 3.77	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60427	 1	 5.27	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60428	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60429	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60430	 1	 4.43	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60431	 1	 8.19	 2.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60432	 1	 8.41	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60433	 1	 20.53	 4.84	 0.0	 -75.08	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60434	 1	 20.16	 4.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60435	 1	 6.04	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60436	 1	 0.0	 0.0	 0.0	 -124.79	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60437	 1	 0.0	 0.0	 0.0	 -38.17	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60438	 1	 3.78	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60439	 1	 4.96	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60440	 1	 17.55	 4.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60441	 1	 7.92	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60442	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60443	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60444	 1	 47.03	 10.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60445	 1	 4.67	 1.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60446	 1	 13.23	 3.09	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60447	 1	 64.15	 19.63	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60448	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60449	 1	 7.47	 1.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60450	 1	 8.04	 1.8	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60451	 1	 2.78	 0.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60452	 1	 23.13	 6.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60453	 1	 11.35	 2.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60454	 1	 5.02	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60455	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60456	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60457	 1	 10.52	 1.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60458	 1	 8.77	 2.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60459	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60460	 1	 12.74	 3.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60461	 1	 10.68	 2.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60462	 1	 5.81	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60463	 1	 11.44	 3.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60464	 1	 52.26	 16.97	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60465	 1	 10.17	 2.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60466	 1	 11.14	 3.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60467	 1	 23.44	 5.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60468	 1	 3.04	 0.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60469	 1	 3.62	 0.44	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60470	 1	 39.02	 12.06	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60471	 1	 5.63	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60472	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60473	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60474	 1	 3.62	 0.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60475	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60476	 1	 5.1	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60477	 1	 3.41	 0.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60478	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60479	 1	 6.12	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60480	 1	 5.19	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60481	 1	 6.13	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60482	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60483	 1	 5.22	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60484	 1	 4.24	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60485	 1	 4.58	 0.52	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60486	 1	 3.45	 0.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60487	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60488	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60489	 1	 4.87	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60490	 1	 3.23	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60491	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60492	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60493	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60494	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60495	 1	 3.52	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60496	 1	 6.13	 1.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60497	 1	 12.09	 2.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60498	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60499	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60500	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60501	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60502	 1	 3.68	 0.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60503	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60504	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60505	 1	 2.95	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60506	 1	 2.41	 0.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60507	 1	 2.64	 0.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60508	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60509	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60510	 1	 7.9	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60511	 1	 6.2	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60512	 1	 2.97	 0.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60513	 1	 6.2	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60514	 1	 6.4	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60515	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60516	 1	 6.25	 1.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60517	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60518	 1	 5.16	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60519	 1	 4.88	 1.26	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60520	 1	 6.52	 0.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60521	 1	 3.79	 0.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60522	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60523	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60524	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60525	 1	 7.4	 1.34	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60526	 1	 6.26	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60527	 1	 7.94	 2.16	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60528	 1	 7.24	 0.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60529	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60530	 1	 9.5	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60531	 1	 4.4	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60532	 1	 6.55	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60533	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60534	 1	 3.9	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60535	 1	 3.4	 0.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60536	 1	 4.36	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60537	 1	 9.75	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60538	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60539	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60540	 1	 5.36	 0.61	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60541	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60542	 1	 3.62	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60543	 1	 4.02	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60544	 1	 0.0	 0.0	 0.0	 339.9	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60545	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60546	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60547	 1	 6.12	 1.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60548	 1	 4.8	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60549	 1	 10.46	 2.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60550	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60551	 1	 0.0	 0.0	 0.0	 96.27	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60552	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60553	 1	 8.87	 2.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60554	 1	 14.26	 3.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60555	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60556	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60557	 1	 44.48	 14.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60558	 1	 8.52	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60559	 1	 8.81	 2.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60560	 1	 6.61	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60561	 1	 7.05	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60562	 1	 3.73	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60563	 1	 5.87	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60564	 1	 17.79	 3.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60565	 1	 18.74	 4.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60566	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60567	 1	 5.26	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60568	 1	 10.8	 2.1	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60569	 1	 19.82	 4.1	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60570	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60571	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60572	 1	 4.66	 0.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60573	 1	 5.87	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60574	 1	 15.6	 4.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60575	 1	 5.42	 1.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60576	 1	 5.3	 1.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60577	 1	 6.12	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60578	 1	 8.62	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60579	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60580	 1	 6.29	 1.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60581	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60582	 1	 9.06	 2.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60583	 1	 6.01	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60584	 1	 9.29	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60585	 1	 20.83	 5.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60586	 1	 7.57	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60587	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60588	 1	 5.1	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60589	 1	 6.26	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60590	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60591	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60592	 1	 5.5	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60593	 1	 147.55	 21.32	 0.0	 400.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60594	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60595	 1	 10.69	 3.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60596	 1	 6.26	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60597	 1	 7.01	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60598	 1	 6.15	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60599	 1	 10.27	 2.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60600	 1	 93.62	 27.11	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60601	 1	 8.26	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60602	 1	 5.84	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60603	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60604	 1	 6.42	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60605	 1	 9.22	 1.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60606	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60607	 1	 6.82	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60608	 1	 13.25	 3.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60609	 1	 9.09	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60610	 1	 4.89	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60611	 1	 4.65	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60612	 1	 39.38	 12.56	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60613	 1	 0.0	 0.0	 0.0	 900.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60614	 1	 6.33	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60615	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60616	 1	 6.73	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60617	 1	 5.32	 1.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60618	 1	 0.0	 0.0	 0.0	 -160.08	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60619	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60620	 1	 5.36	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60621	 1	 8.43	 2.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60622	 1	 5.06	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60623	 1	 8.1	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60624	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60625	 1	 11.19	 2.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60626	 1	 8.39	 1.02	 0.0	 94.98	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60627	 1	 3.72	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60628	 1	 2.98	 0.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60629	 1	 5.2	 1.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60630	 1	 6.99	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60631	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60632	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60633	 1	 7.04	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60634	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60635	 1	 4.39	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60636	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60637	 1	 6.48	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60638	 1	 5.37	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60639	 1	 8.31	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60640	 1	 8.53	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60641	 1	 5.09	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60642	 1	 5.55	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60643	 1	 4.77	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60644	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60645	 1	 10.73	 1.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60646	 1	 23.91	 4.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60647	 1	 9.34	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60648	 1	 6.15	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60649	 1	 19.07	 2.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60650	 1	 11.62	 3.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60651	 1	 5.99	 1.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60652	 1	 16.66	 4.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60653	 1	 5.83	 0.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60654	 1	 8.17	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60655	 1	 9.88	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60656	 1	 8.06	 2.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60657	 1	 5.99	 0.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60658	 1	 6.61	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60659	 1	 5.15	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60660	 1	 9.96	 2.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60661	 1	 5.57	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60662	 1	 4.83	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60663	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60664	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60665	 1	 7.85	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60666	 1	 10.91	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60667	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60668	 1	 6.68	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60669	 1	 4.2	 0.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60670	 1	 4.63	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60671	 1	 3.85	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60672	 1	 11.14	 2.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60673	 1	 5.83	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60674	 1	 25.55	 4.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60675	 1	 3.25	 0.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60676	 1	 7.08	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60677	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60678	 1	 4.3	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60679	 1	 8.05	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60680	 1	 6.76	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60681	 1	 8.28	 2.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60682	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60683	 1	 5.99	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60684	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60685	 1	 4.62	 0.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60686	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60687	 1	 7.11	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60688	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60689	 1	 56.76	 18.4	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60690	 1	 7.23	 2.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60691	 1	 6.63	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60692	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60693	 1	 9.33	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60694	 1	 12.2	 3.06	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60695	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60696	 1	 3.53	 0.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60697	 1	 13.38	 3.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60698	 1	 5.06	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60699	 1	 5.67	 1.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60700	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60701	 1	 4.25	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60702	 1	 5.05	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60703	 1	 10.12	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60704	 1	 14.47	 2.13	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60705	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60706	 1	 4.22	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60707	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60708	 1	 7.16	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60709	 1	 7.58	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60710	 1	 6.39	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60711	 1	 6.22	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60712	 1	 7.98	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60713	 1	 9.5	 2.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60714	 1	 9.64	 2.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60715	 1	 77.97	 26.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60716	 1	 16.55	 4.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60717	 1	 10.28	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60718	 1	 6.13	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60719	 1	 7.1	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60720	 1	 6.41	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60721	 1	 6.41	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60722	 1	 3.89	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60723	 1	 5.36	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60724	 1	 4.61	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60725	 1	 6.45	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60726	 1	 6.96	 1.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60727	 1	 7.15	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60728	 1	 10.73	 2.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60729	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60730	 1	 0.0	 0.0	 0.0	 292.71	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60731	 1	 32.17	 5.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60732	 1	 0.0	 0.0	 0.0	 -1.81	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60733	 1	 6.94	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60734	 1	 4.84	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60735	 1	 6.65	 1.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60736	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60737	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60738	 1	 4.36	 0.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60739	 1	 4.22	 0.92	 0.0	 41.21	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60740	 1	 0.0	 0.0	 0.0	 -198.97	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60741	 1	 9.09	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60742	 1	 8.2	 2.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60743	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60744	 1	 5.73	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60745	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60746	 1	 6.44	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60747	 1	 3.66	 0.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60748	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60749	 1	 8.94	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60750	 1	 4.99	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60751	 1	 6.13	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60752	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60753	 1	 0.0	 0.0	 0.0	 30.73	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60754	 1	 8.22	 1.51	 0.0	 -98.41	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60755	 1	 14.13	 2.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60756	 1	 8.92	 2.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60757	 1	 6.1	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60758	 1	 12.62	 3.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60759	 1	 9.41	 2.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60760	 1	 7.79	 2.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60761	 1	 9.56	 2.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60762	 1	 5.11	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60763	 1	 8.69	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60764	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60765	 1	 8.77	 2.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60766	 1	 5.38	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60767	 1	 10.91	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60768	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60769	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60770	 1	 0.0	 0.0	 0.0	 305.48	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60771	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60772	 1	 6.1	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60773	 1	 4.67	 0.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60774	 1	 4.38	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60775	 1	 4.88	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60776	 1	 6.64	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60777	 1	 7.0	 1.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60778	 1	 6.21	 1.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60779	 1	 6.24	 0.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60780	 1	 4.87	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60781	 1	 8.91	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60782	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60783	 1	 7.39	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60784	 1	 8.03	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60785	 1	 6.48	 0.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60786	 1	 36.46	 9.66	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60787	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60788	 1	 11.06	 2.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60789	 1	 5.85	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60790	 1	 12.46	 2.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60791	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60792	 1	 10.16	 2.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60793	 1	 7.14	 1.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60794	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60795	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60796	 1	 6.57	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60797	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60798	 1	 9.46	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60799	 1	 5.78	 1.23	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60800	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60801	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60802	 1	 6.69	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60803	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60804	 1	 6.83	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60805	 1	 5.99	 0.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60806	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60807	 1	 6.56	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60808	 1	 14.74	 4.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60809	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60810	 1	 5.08	 0.69	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60811	 1	 0.0	 0.0	 0.0	 49.38	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60812	 1	 12.93	 3.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60813	 1	 7.08	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60814	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60815	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60816	 1	 22.02	 5.2	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60817	 1	 5.74	 1.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60818	 1	 8.29	 2.3	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60819	 1	 25.39	 5.53	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60820	 1	 6.93	 1.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60821	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60822	 1	 8.49	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60823	 1	 8.24	 2.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60824	 1	 8.1	 1.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60825	 1	 5.83	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60826	 1	 2.85	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60827	 1	 6.43	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60828	 1	 14.59	 4.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60829	 1	 4.91	 0.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60830	 1	 12.11	 2.01	 0.0	 20.58	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60831	 1	 6.03	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60832	 1	 7.09	 0.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60833	 1	 5.9	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60834	 1	 4.64	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60835	 1	 7.8	 2.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60836	 1	 8.25	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60837	 1	 4.16	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60838	 1	 9.51	 2.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60839	 1	 6.84	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60840	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60841	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60842	 1	 4.32	 1.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60843	 1	 8.39	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60844	 1	 5.63	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60845	 1	 4.26	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60846	 1	 4.44	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60847	 1	 9.35	 2.27	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60848	 1	 8.55	 1.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60849	 1	 5.26	 0.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60850	 1	 4.41	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60851	 1	 4.55	 0.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60852	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60853	 1	 5.87	 -2.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60854	 1	 6.6	 1.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60855	 1	 16.95	 4.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60856	 1	 9.2	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60857	 1	 0.0	 0.0	 0.0	 123.79	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60858	 1	 3.62	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60859	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60860	 1	 0.0	 0.0	 0.0	 51.08	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60861	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60862	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60863	 1	 4.87	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60864	 1	 7.53	 2.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60865	 1	 5.71	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60866	 1	 8.05	 1.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60867	 1	 46.99	 11.25	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60868	 1	 7.3	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60869	 1	 0.0	 0.0	 0.0	 1.57	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60870	 1	 6.01	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60871	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60872	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60873	 1	 6.68	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60874	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60875	 1	 5.16	 0.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60876	 1	 6.52	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60877	 1	 3.72	 0.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60878	 1	 6.74	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60879	 1	 6.1	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60880	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60881	 1	 4.42	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60882	 1	 4.34	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60883	 1	 4.53	 1.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60884	 1	 7.74	 1.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60885	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60886	 1	 6.84	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60887	 1	 8.84	 2.48	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60888	 1	 3.5	 0.71	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60889	 1	 17.46	 4.42	 0.0	 22.69	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60890	 1	 9.83	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60891	 1	 0.0	 0.0	 0.0	 48.51	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60892	 1	 8.6	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60893	 1	 10.28	 2.72	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60894	 1	 2.69	 0.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60895	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60896	 1	 6.24	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60897	 1	 5.25	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60898	 1	 4.8	 0.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60899	 1	 6.28	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60900	 1	 7.04	 1.38	 0.0	 -323.28	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60901	 1	 4.7	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60902	 1	 3.67	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60903	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60904	 1	 8.93	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60905	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60906	 1	 3.94	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60907	 1	 162.94	 43.72	 0.0	 600.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60908	 1	 8.25	 1.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60909	 1	 9.2	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60910	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60911	 1	 7.38	 1.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60912	 1	 0.0	 0.0	 0.0	 48.38	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60913	 1	 5.49	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60914	 1	 7.96	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60915	 1	 6.52	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60916	 1	 6.57	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60917	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60918	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60919	 1	 8.67	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60920	 1	 20.7	 6.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60921	 1	 11.01	 2.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60922	 1	 8.23	 2.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60923	 1	 5.58	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60924	 1	 4.89	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60925	 1	 6.8	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60926	 1	 3.44	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60927	 1	 5.22	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60928	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60929	 1	 8.83	 1.83	 0.0	 100.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60930	 1	 4.86	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60931	 1	 6.48	 1.0	 0.0	 100.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60932	 1	 15.66	 4.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60933	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60934	 1	 13.81	 3.75	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60935	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60936	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60937	 1	 9.62	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60938	 1	 14.22	 2.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60939	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60940	 1	 4.7	 0.8	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60941	 1	 6.65	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60942	 1	 4.89	 1.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60943	 1	 4.55	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60944	 1	 7.56	 1.71	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60945	 1	 7.32	 1.23	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60946	 1	 3.97	 0.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60947	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60948	 1	 13.83	 3.25	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60949	 1	 7.35	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60950	 1	 6.38	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60951	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60952	 1	 7.57	 1.26	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60953	 1	 7.71	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60954	 1	 17.05	 4.63	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60955	 1	 11.42	 3.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60956	 1	 37.86	 5.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60957	 1	 9.84	 1.9	 0.0	 -18.13	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60958	 1	 26.23	 8.12	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60959	 1	 4.08	 0.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60960	 1	 4.98	 0.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60961	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60962	 1	 10.14	 2.3	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60963	 1	 2.98	 0.42	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60964	 1	 4.92	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60965	 1	 0.0	 0.0	 0.0	 -184.41	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60966	 1	 11.49	 2.49	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60967	 1	 7.22	 2.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60968	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60969	 1	 6.94	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60970	 1	 0.0	 0.0	 0.0	 -44.63	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60971	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60972	 1	 6.88	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60973	 1	 11.1	 2.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60974	 1	 5.92	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60975	 1	 6.38	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60976	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60977	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60978	 1	 14.02	 -8.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60979	 1	 4.03	 0.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60980	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60981	 1	 0.0	 0.0	 0.0	 200.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60982	 1	 9.45	 3.02	 0.0	 -19.17	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60983	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60984	 1	 0.8	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60985	 1	 12.26	 3.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60986	 1	 8.04	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60987	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60988	 1	 6.48	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60989	 1	 16.38	 4.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60990	 1	 2.27	 0.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60991	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60992	 1	 6.01	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60993	 1	 7.34	 2.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60994	 1	 6.68	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60995	 1	 4.36	 0.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60996	 1	 5.95	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	60997	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60998	 1	 26.42	 6.8	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60999	 1	 10.54	 2.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61000	 1	 7.11	 -3.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61001	 1	 2.98	 0.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61002	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61003	 1	 7.26	 2.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61004	 1	 11.96	 3.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61005	 1	 2.87	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61006	 1	 5.05	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61007	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61008	 1	 5.72	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61009	 1	 6.7	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61010	 1	 8.61	 1.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61011	 1	 2.29	 0.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61012	 1	 3.81	 0.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61013	 1	 3.04	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61014	 1	 0.0	 0.0	 0.0	 20.16	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61015	 1	 15.73	 4.11	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61016	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61017	 1	 2.98	 0.37	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61018	 1	 2.85	 0.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61019	 1	 0.0	 0.0	 0.0	 378.82	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61020	 1	 7.79	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61021	 1	 4.41	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61022	 1	 4.87	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61023	 1	 7.62	 1.89	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61024	 1	 9.19	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61025	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61026	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61027	 1	 6.14	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61028	 1	 7.8	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61029	 1	 4.77	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61030	 1	 5.04	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61031	 1	 8.52	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61032	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61033	 1	 7.3	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61034	 1	 7.36	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61035	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61036	 1	 13.0	 1.8	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61037	 1	 9.31	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61038	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61039	 1	 10.3	 2.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61040	 1	 4.81	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61041	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61042	 1	 4.94	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61043	 1	 6.64	 1.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61044	 1	 8.54	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61045	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61046	 1	 67.04	 9.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61047	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61048	 1	 7.55	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61049	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61050	 1	 5.28	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61051	 1	 5.23	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61052	 1	 7.61	 1.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61053	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61054	 1	 10.62	 2.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61055	 1	 6.16	 1.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61056	 1	 6.24	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61057	 1	 10.14	 3.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61058	 1	 6.27	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61059	 1	 4.16	 0.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61060	 1	 4.17	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61061	 1	 5.2	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61062	 1	 10.29	 1.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61063	 1	 5.94	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61064	 1	 4.93	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61065	 1	 8.64	 1.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61066	 1	 6.97	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61067	 1	 6.11	 1.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61068	 1	 6.22	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61069	 1	 9.52	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61070	 1	 3.36	 0.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61071	 1	 5.51	 1.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61072	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61073	 1	 4.53	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61074	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61075	 1	 5.13	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61076	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61077	 1	 3.83	 0.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61078	 1	 6.16	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61079	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61080	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61081	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61082	 1	 4.92	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61083	 1	 8.62	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61084	 1	 8.65	 2.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61085	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61086	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61087	 1	 6.88	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61088	 1	 7.43	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61089	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61090	 1	 5.81	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61091	 1	 24.52	 5.77	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61092	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61093	 1	 6.31	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61094	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61095	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61096	 1	 7.09	 1.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61097	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61098	 1	 7.45	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61099	 1	 6.99	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61100	 1	 6.39	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61101	 1	 8.93	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61102	 1	 14.33	 4.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61103	 1	 4.56	 0.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61104	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61105	 1	 6.77	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61106	 1	 6.14	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61107	 1	 4.16	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61108	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61109	 1	 8.58	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61110	 1	 7.56	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61111	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61112	 1	 5.49	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61113	 1	 9.59	 2.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61114	 1	 10.51	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61115	 1	 6.2	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61116	 1	 7.27	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61117	 1	 8.68	 2.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61118	 1	 5.07	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61119	 1	 7.65	 0.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61120	 1	 9.78	 2.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61121	 1	 3.46	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61122	 1	 5.26	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61123	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61124	 1	 5.17	 0.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61125	 1	 8.54	 2.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61126	 1	 6.55	 1.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61127	 1	 6.81	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61128	 1	 8.73	 1.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61129	 1	 6.97	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61130	 1	 7.72	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61131	 1	 4.57	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61132	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61133	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61134	 1	 9.22	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61135	 1	 2.79	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61136	 1	 4.2	 0.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61137	 1	 4.82	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61138	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61139	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61140	 1	 3.82	 0.48	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61141	 1	 5.76	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61142	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61143	 1	 5.34	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61144	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61145	 1	 13.71	 3.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61146	 1	 3.43	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61147	 1	 8.33	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61148	 1	 5.9	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61149	 1	 3.16	 0.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61150	 1	 244.78	 76.89	 0.0	 249.57	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61151	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61152	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61153	 1	 5.89	 1.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61154	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61155	 1	 6.51	 1.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61156	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61157	 1	 7.8	 1.43	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61158	 1	 7.04	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61159	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61160	 1	 3.89	 0.42	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61161	 1	 5.34	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61162	 1	 5.78	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61163	 1	 7.77	 2.2	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61164	 1	 6.09	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61165	 1	 7.57	 1.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61166	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61167	 1	 13.43	 3.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61168	 1	 4.47	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61169	 1	 10.98	 2.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61170	 1	 4.1	 0.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61171	 1	 9.57	 2.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61172	 1	 51.78	 13.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61173	 1	 5.93	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61174	 1	 9.28	 2.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61175	 1	 5.67	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61176	 1	 7.56	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61177	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61178	 1	 5.87	 0.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61179	 1	 11.07	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61180	 1	 3.15	 0.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61181	 1	 0.0	 0.0	 0.0	 -141.82	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61182	 1	 12.15	 2.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61183	 1	 10.88	 2.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61184	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61185	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61186	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61187	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61188	 1	 13.47	 3.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61189	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61190	 1	 4.81	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61191	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61192	 1	 6.58	 1.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61193	 1	 5.02	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61194	 1	 4.43	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61195	 1	 4.12	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61196	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61197	 1	 8.65	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61198	 1	 3.47	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61199	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61200	 1	 5.51	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61201	 1	 4.39	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61202	 1	 86.17	 15.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61203	 1	 8.06	 1.34	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61204	 1	 5.87	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61205	 1	 4.42	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61206	 1	 6.63	 1.49	 0.0	 -42.47	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61207	 1	 7.51	 1.84	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61208	 1	 2.95	 0.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61209	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61210	 1	 28.51	 4.27	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61211	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61212	 1	 5.23	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61213	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61214	 1	 0.0	 0.0	 0.0	 -145.24	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61215	 1	 10.03	 2.78	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61216	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61217	 1	 6.04	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61218	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61219	 1	 5.0	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61220	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61221	 1	 5.41	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61222	 1	 9.9	 2.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61223	 1	 0.0	 0.0	 0.0	 23.51	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61224	 1	 0.26	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61225	 1	 0.83	 0.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61226	 1	 7.98	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61227	 1	 7.28	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61228	 1	 3.53	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61229	 1	 3.68	 0.61	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61230	 1	 36.75	 7.07	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61231	 1	 8.74	 2.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61232	 1	 3.99	 0.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61233	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61234	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61235	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61236	 1	 6.19	 -3.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61237	 1	 3.69	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61238	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61239	 1	 7.26	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61240	 1	 3.82	 0.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61241	 1	 10.08	 2.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61242	 1	 7.36	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61243	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61244	 1	 35.49	 10.61	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61245	 1	 7.68	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61246	 1	 2.76	 0.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61247	 1	 7.0	 1.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61248	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61249	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61250	 1	 4.37	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61251	 1	 7.05	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61252	 1	 8.15	 1.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61253	 1	 7.15	 0.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61254	 1	 9.05	 2.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61255	 1	 16.72	 4.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61256	 1	 12.25	 3.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61257	 1	 5.06	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61258	 1	 6.13	 0.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61259	 1	 6.65	 0.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61260	 1	 7.68	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61261	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61262	 1	 0.0	 0.0	 0.0	 136.41	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61263	 1	 14.78	 4.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61264	 1	 7.11	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61265	 1	 10.86	 2.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61266	 1	 8.45	 1.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61267	 1	 3.71	 0.48	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61268	 1	 6.32	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61269	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61270	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61271	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61272	 1	 7.09	 1.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61273	 1	 5.18	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61274	 1	 6.08	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61275	 1	 9.13	 1.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61276	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61277	 1	 12.64	 2.67	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61278	 1	 14.63	 4.58	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61279	 1	 8.37	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61280	 1	 9.27	 2.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61281	 1	 6.49	 1.86	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61282	 1	 10.04	 2.85	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61283	 1	 5.78	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61284	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61285	 1	 9.0	 2.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61286	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61287	 1	 16.33	 4.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61288	 1	 7.09	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61289	 1	 7.87	 2.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61290	 1	 10.47	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61291	 1	 6.38	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61292	 1	 10.99	 3.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61293	 1	 7.96	 1.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61294	 1	 5.61	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61295	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61296	 1	 7.79	 2.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61297	 1	 5.16	 0.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61298	 1	 4.91	 0.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61299	 1	 7.95	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61300	 1	 4.49	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61301	 1	 4.82	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61302	 1	 6.68	 1.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61303	 1	 5.56	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61304	 1	 8.38	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61305	 1	 10.18	 2.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61306	 1	 8.09	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61307	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61308	 1	 13.19	 2.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61309	 1	 5.24	 0.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61310	 1	 8.88	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61311	 1	 8.49	 0.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61312	 1	 7.56	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61313	 1	 6.71	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61314	 1	 4.72	 0.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61315	 1	 6.15	 0.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61316	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61317	 1	 3.19	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61318	 1	 5.55	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61319	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61320	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61321	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61322	 1	 5.55	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61323	 1	 7.64	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61324	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61325	 1	 13.43	 2.98	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61326	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61327	 1	 4.73	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61328	 1	 0.0	 0.0	 0.0	 144.06	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61329	 1	 6.97	 1.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61330	 1	 13.49	 2.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61331	 1	 0.0	 0.0	 0.0	 32.13	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61332	 1	 6.22	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61333	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61334	 1	 6.15	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61335	 1	 6.35	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61336	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61337	 1	 2.78	 0.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61338	 1	 2.95	 0.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61339	 1	 6.16	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61340	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61341	 1	 6.1	 0.88	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61342	 1	 7.07	 1.72	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61343	 1	 2.49	 0.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61344	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61345	 1	 6.81	 1.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61346	 1	 4.11	 1.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61347	 1	 6.1	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61348	 1	 4.03	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61349	 1	 27.85	 3.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61350	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61351	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61352	 1	 7.92	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61353	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61354	 1	 6.21	 1.41	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61355	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61356	 1	 4.94	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61357	 1	 4.37	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61358	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61359	 1	 4.36	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61360	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61361	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61362	 1	 7.18	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61363	 1	 11.95	 2.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61364	 1	 9.27	 1.86	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61365	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61366	 1	 0.0	 0.0	 0.0	 49.73	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61367	 1	 11.12	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61368	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61369	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61370	 1	 6.86	 1.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61371	 1	 4.44	 0.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61372	 1	 6.67	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61373	 1	 12.46	 3.63	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61374	 1	 5.19	 1.48	 0.0	 13.4	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61375	 1	 9.57	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61376	 1	 7.33	 2.08	 0.0	 -100.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61377	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61378	 1	 4.8	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61379	 1	 0.08	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61380	 1	 5.76	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61381	 1	 6.34	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61382	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61383	 1	 4.35	 0.95	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61384	 1	 4.24	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61385	 1	 0.0	 0.0	 0.0	 -3.33	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61386	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61387	 1	 9.48	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61388	 1	 6.62	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61389	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61390	 1	 3.11	 0.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61391	 1	 4.39	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61392	 1	 10.86	 1.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61393	 1	 10.07	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61394	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61395	 1	 4.48	 1.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61396	 1	 5.95	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61397	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61398	 1	 3.74	 0.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61399	 1	 5.64	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61400	 1	 10.04	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61401	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61402	 1	 6.14	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61403	 1	 3.77	 0.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61404	 1	 3.79	 0.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61405	 1	 5.75	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61406	 1	 10.91	 2.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61407	 1	 15.21	 3.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61408	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61409	 1	 1.94	 0.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61410	 1	 2.27	 0.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61411	 1	 5.67	 1.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61412	 1	 2.57	 0.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61413	 1	 5.27	 0.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61414	 1	 5.23	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61415	 1	 5.77	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61416	 1	 3.96	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61417	 1	 5.15	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61418	 1	 3.89	 0.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61419	 1	 7.87	 1.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61420	 1	 4.1	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61421	 1	 6.74	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61422	 1	 4.57	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61423	 1	 8.34	 1.69	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61424	 1	 4.74	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61425	 1	 8.55	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61426	 1	 5.51	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61427	 1	 3.6	 0.77	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61428	 1	 8.42	 1.89	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61429	 1	 7.94	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61430	 1	 15.36	 4.37	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61431	 1	 9.34	 2.47	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61432	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61433	 1	 7.75	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61434	 1	 4.27	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61435	 1	 4.44	 0.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61436	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61437	 1	 7.07	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61438	 1	 2.53	 0.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61439	 1	 8.39	 1.17	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61440	 1	 4.95	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61441	 1	 9.71	 2.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61442	 1	 5.08	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61443	 1	 43.88	 9.09	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61444	 1	 10.17	 2.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61445	 1	 7.91	 1.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61446	 1	 0.0	 0.0	 0.0	 12.69	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61447	 1	 1.7	 0.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61448	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61449	 1	 11.72	 2.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61450	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61451	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61452	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61453	 1	 5.79	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61454	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61455	 1	 0.0	 0.0	 0.0	 -4.14	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61456	 1	 9.87	 1.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61457	 1	 7.73	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61458	 1	 10.14	 2.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61459	 1	 4.8	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61460	 1	 5.02	 0.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61461	 1	 4.95	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61462	 1	 2.86	 0.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61463	 1	 4.73	 0.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61464	 1	 3.66	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61465	 1	 5.64	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61466	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61467	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61468	 1	 18.3	 5.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61469	 1	 13.53	 3.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61470	 1	 22.02	 5.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61471	 1	 5.09	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61472	 1	 5.58	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61473	 1	 10.56	 2.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61474	 1	 6.67	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61475	 1	 52.08	 11.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61476	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61477	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61478	 1	 11.33	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61479	 1	 14.12	 3.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61480	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61481	 1	 4.59	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61482	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61483	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61484	 1	 46.45	 15.84	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61485	 1	 2.73	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61486	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61487	 1	 17.78	 3.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61488	 1	 6.54	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61489	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61490	 1	 11.31	 2.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61491	 1	 3.71	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61492	 1	 8.46	 2.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61493	 1	 1.96	 0.4	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61494	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61495	 1	 5.83	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61496	 1	 0.0	 0.0	 0.0	 -51.21	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61497	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61498	 1	 7.17	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61499	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61500	 1	 5.85	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61501	 1	 4.55	 0.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61502	 1	 10.62	 2.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61503	 1	 8.92	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61504	 1	 8.56	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61505	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61506	 1	 12.17	 2.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61507	 1	 10.5	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61508	 1	 8.81	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61509	 1	 5.47	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61510	 1	 46.18	 11.12	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61511	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61512	 1	 6.64	 1.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61513	 1	 7.62	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61514	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61515	 1	 10.35	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61516	 1	 8.6	 2.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61517	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61518	 1	 6.37	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61519	 1	 4.28	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61520	 1	 10.39	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61521	 1	 11.32	 3.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61522	 1	 4.16	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61523	 1	 6.59	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61524	 1	 6.56	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61525	 1	 8.83	 2.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61526	 1	 10.27	 2.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61527	 1	 5.37	 1.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61528	 1	 3.01	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61529	 1	 12.92	 2.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61530	 1	 7.55	 1.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61531	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61532	 1	 10.26	 2.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61533	 1	 3.48	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61534	 1	 6.09	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61535	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61536	 1	 8.23	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61537	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61538	 1	 4.24	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61539	 1	 9.16	 1.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61540	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61541	 1	 9.48	 2.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61542	 1	 6.23	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61543	 1	 3.14	 0.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61544	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61545	 1	 10.23	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61546	 1	 5.95	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61547	 1	 54.22	 18.42	 0.0	 -81.12	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61548	 1	 8.52	 2.1	 0.0	 -76.68	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61549	 1	 13.06	 2.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61550	 1	 10.95	 2.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61551	 1	 6.28	 1.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61552	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61553	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61554	 1	 6.79	 1.45	 0.0	 63.73	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61555	 1	 5.25	 0.73	 0.0	 0.75	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61556	 1	 9.42	 1.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61557	 1	 4.74	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61558	 1	 0.0	 0.0	 0.0	 10.4	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61559	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61560	 1	 0.0	 0.0	 0.0	 39.6	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61561	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61562	 1	 13.86	 4.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61563	 1	 12.37	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61564	 1	 6.77	 1.77	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61565	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61566	 1	 16.02	 3.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61567	 1	 11.49	 3.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61568	 1	 7.39	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61569	 1	 5.6	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61570	 1	 9.3	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61571	 1	 10.48	 1.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61572	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61573	 1	 18.0	 4.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61574	 1	 20.72	 4.13	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61575	 1	 8.91	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61576	 1	 4.47	 1.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61577	 1	 12.3	 2.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61578	 1	 20.95	 4.26	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61579	 1	 14.11	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61580	 1	 6.84	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61581	 1	 17.23	 4.7	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61582	 1	 19.31	 3.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61583	 1	 6.27	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61584	 1	 17.35	 3.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61585	 1	 0.0	 0.0	 0.0	 -103.24	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61586	 1	 12.24	 1.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61587	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61588	 1	 10.15	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61589	 1	 5.8	 1.56	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61590	 1	 1.47	 0.41	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61591	 1	 2.27	 0.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61592	 1	 7.0	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61593	 1	 46.55	 15.67	 0.0	 38.92	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61594	 1	 8.89	 2.38	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61595	 1	 0.0	 0.0	 0.0	 -10.29	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61596	 1	 9.55	 2.79	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61597	 1	 3.57	 0.73	 0.0	 -76.15	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61598	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61599	 1	 15.39	 4.24	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61600	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61601	 1	 16.79	 4.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61602	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61603	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61604	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61605	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61606	 1	 8.74	 1.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61607	 1	 7.52	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61608	 1	 9.46	 2.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61609	 1	 17.57	 2.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61610	 1	 7.33	 1.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61611	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61612	 1	 4.71	 0.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61613	 1	 6.95	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61614	 1	 21.43	 5.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61615	 1	 5.66	 1.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61616	 1	 11.15	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61617	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61618	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61619	 1	 0.0	 0.0	 0.0	 27.4	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61620	 1	 8.29	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61621	 1	 10.49	 3.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61622	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61623	 1	 0.0	 0.0	 0.0	 74.89	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61624	 1	 13.61	 3.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61625	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61626	 1	 14.29	 3.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61627	 1	 9.87	 2.34	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61628	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61629	 1	 17.78	 3.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61630	 1	 2.49	 0.52	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61631	 1	 12.57	 1.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61632	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61633	 1	 4.71	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61634	 1	 6.38	 1.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61635	 1	 9.41	 2.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61636	 1	 0.0	 0.0	 0.0	 21.69	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61637	 1	 0.0	 0.0	 0.0	 15.29	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61638	 1	 7.22	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61639	 1	 6.8	 1.54	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61640	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61641	 1	 5.19	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61642	 1	 28.58	 8.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61643	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61644	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61645	 1	 23.92	 6.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61646	 1	 24.08	 5.15	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61647	 1	 7.72	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61648	 1	 0.0	 0.0	 0.0	 -19.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61649	 1	 6.09	 1.27	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61650	 1	 5.78	 1.08	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61651	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61652	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61653	 1	 10.98	 1.63	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61654	 1	 5.06	 1.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61655	 1	 10.11	 2.3	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61656	 1	 14.36	 3.3	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61657	 1	 6.66	 1.86	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61658	 1	 10.64	 2.33	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61659	 1	 7.8	 2.13	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61660	 1	 0.0	 0.0	 0.0	 -502.94	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61661	 1	 74.34	 16.46	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61662	 1	 19.28	 -10.39	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61663	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61664	 1	 9.23	 1.21	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61665	 1	 12.77	 3.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61666	 1	 16.04	 2.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61667	 1	 72.99	 21.86	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61668	 1	 0.0	 0.0	 0.0	 -51.25	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61669	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61670	 1	 11.32	 2.98	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61671	 1	 29.1	 5.05	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61672	 1	 7.31	 0.97	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61673	 1	 0.0	 0.0	 0.0	 82.11	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61674	 1	 5.72	 0.72	 0.0	 -138.93	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61675	 1	 0.0	 0.0	 0.0	 -115.82	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61676	 1	 0.0	 0.0	 0.0	 -129.77	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61677	 1	 0.0	 0.0	 0.0	 -34.85	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61678	 1	 8.14	 2.28	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61679	 1	 7.26	 1.22	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61680	 1	 6.36	 1.47	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61681	 1	 66.32	 18.24	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61682	 1	 3.57	 0.79	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61683	 1	 11.44	 2.32	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61684	 1	 14.16	 3.2	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61685	 1	 0.0	 0.0	 0.0	 -385.86	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61686	 1	 20.13	 6.21	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61687	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61688	 1	 10.16	 3.22	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61689	 1	 5.07	 1.31	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61690	 1	 8.23	 1.88	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61691	 1	 14.83	 2.16	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61692	 1	 0.0	 0.0	 0.0	 -3.59	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61693	 1	 6.03	 0.58	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61694	 1	 5.42	 0.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61695	 1	 30.56	 6.66	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61696	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61697	 1	 225.12	 77.35	 0.0	 83.19	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61698	 1	 17.76	 2.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61699	 1	 11.89	 1.71	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61700	 1	 60.86	 17.16	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61701	 1	 15.39	 3.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61702	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61703	 1	 40.96	 13.23	 0.0	 31.64	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61704	 1	 5.89	 1.07	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61705	 1	 5.21	 1.03	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61706	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61707	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61708	 1	 10.06	 1.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61709	 1	 14.05	 2.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61710	 1	 14.26	 4.16	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61711	 1	 6.79	 1.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61712	 1	 8.86	 1.97	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61713	 1	 9.08	 1.11	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61714	 1	 10.9	 1.62	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61715	 1	 0.0	 0.0	 0.0	 39.04	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61716	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61717	 1	 6.29	 1.82	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61718	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61719	 1	 18.42	 5.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61720	 1	 0.0	 0.0	 0.0	 -1.47	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61721	 1	 9.53	 2.17	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61722	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61723	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61724	 1	 7.37	 1.55	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61725	 1	 11.59	 2.9	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61726	 1	 6.73	 1.29	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61727	 1	 12.97	 2.05	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61728	 1	 5.97	 1.43	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61729	 1	 10.7	 1.47	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61730	 1	 8.76	 1.84	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61731	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61732	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61733	 1	 9.75	 1.46	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61734	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61735	 1	 30.63	 6.69	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61736	 1	 63.57	 17.04	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61737	 1	 6.42	 1.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61738	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61739	 1	 139.19	 45.41	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61740	 1	 11.55	 3.2	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61741	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61742	 1	 19.59	 4.92	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61743	 1	 40.09	 14.07	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61744	 1	 20.05	 2.81	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61745	 1	 15.93	 2.12	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61746	 1	 9.47	 3.04	 0.0	 -31.44	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61747	 1	 27.88	 5.2	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61748	 1	 15.12	 2.7	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61749	 1	 5.7	 0.9	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61750	 1	 10.06	 1.86	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61751	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61752	 1	 0.0	 0.0	 0.0	 -51.53	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61753	 1	 0.0	 0.0	 0.0	 -90.91	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61754	 1	 0.0	 0.0	 0.0	 3.24	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61755	 1	 13.85	 2.07	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61756	 1	 0.0	 0.0	 0.0	 19.67	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61757	 1	 10.97	 2.88	 0.0	 -1.64	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61758	 1	 6.15	 1.23	 0.0	 -3.52	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61759	 1	 12.73	 3.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61760	 1	 16.22	 4.38	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61761	 1	 14.24	 2.54	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61762	 1	 14.55	 3.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61763	 1	 8.54	 2.34	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61764	 1	 0.0	 0.0	 0.0	 -39.5	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61765	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61766	 1	 105.2	 39.94	 0.0	 25.56	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61767	 1	 42.96	 11.38	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61768	 1	 17.51	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61769	 1	 4.87	 0.75	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61770	 1	 11.4	 1.12	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61771	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61772	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61773	 1	 0.0	 0.0	 0.0	 -19.04	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61774	 1	 41.45	 5.77	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61775	 1	 17.05	 4.61	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61776	 1	 8.96	 1.79	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61777	 1	 46.31	 14.32	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61778	 1	 0.0	 0.0	 0.0	 -74.75	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61779	 1	 0.0	 0.0	 0.0	 2.75	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61780	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61781	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61782	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61783	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61784	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61785	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61786	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61787	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61788	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61789	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61790	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61791	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61792	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61793	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61794	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61795	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61796	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61797	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61798	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61799	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61800	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61801	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61802	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61803	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61804	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61805	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61807	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61808	 1	 0.0	 0.0	 0.0	 39.69	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61809	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61810	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61811	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61813	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61814	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61815	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61816	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61817	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61818	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61819	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61820	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61821	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61822	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61823	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61824	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61825	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61826	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61827	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61828	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61829	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61830	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61831	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61832	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61833	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61834	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61835	 1	 0.0	 0.0	 0.0	 242.29	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61836	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61837	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61838	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61839	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61840	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61841	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61842	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61843	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61844	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61845	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61846	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61847	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61848	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61849	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61850	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61851	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61852	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61853	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61854	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61855	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61856	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61857	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61858	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61859	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61860	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61861	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61862	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61863	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61864	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61865	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61866	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61867	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61868	 1	 0.0	 0.0	 0.0	 251.74	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61869	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61870	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61871	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61872	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61873	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61874	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61875	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61876	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61877	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61878	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61879	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61880	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61881	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61882	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61883	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61884	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61885	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61886	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61887	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61888	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61889	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61890	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61891	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61892	 1	 0.0	 0.0	 0.0	 32.01	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61893	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61894	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61895	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61896	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61897	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61898	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61899	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61900	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61901	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61902	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61903	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61904	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61905	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61906	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61907	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61908	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61909	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61910	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61911	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61912	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61913	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61914	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61915	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61916	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61917	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61918	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61919	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61920	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61921	 1	 0.0	 0.0	 0.0	 108.03	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61922	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61923	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61924	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61925	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61926	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61927	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61928	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61929	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61930	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61931	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61932	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61933	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61934	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61935	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61936	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61937	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61938	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61939	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61940	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61941	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61942	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61943	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61944	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61945	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61946	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61947	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61948	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61949	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61950	 1	 0.0	 0.0	 0.0	 180.38	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	61951	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61952	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61953	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61954	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61955	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61956	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61957	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	61958	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61959	 1	 0.0	 0.0	 0.0	 52.34	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61960	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61961	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61962	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61963	 1	 1.8	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61964	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61967	 1	 5.5	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61968	 1	 5.24	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61970	 1	 7.05	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61972	 1	 5.75	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61974	 1	 4.07	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61975	 1	 15.03	 2.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61976	 1	 4.64	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61977	 1	 0.0	 0.0	 0.0	 -71.12	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	61978	 1	 7.16	 1.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61979	 1	 20.39	 4.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61980	 1	 4.74	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61981	 1	 5.77	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61982	 1	 6.66	 -4.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61983	 1	 6.96	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61984	 1	 56.56	 10.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61985	 1	 4.99	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61986	 1	 3.29	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61987	 1	 9.22	 2.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61988	 1	 5.56	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61989	 1	 6.08	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61990	 1	 6.04	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61991	 1	 5.17	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61992	 1	 3.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61993	 1	 2.35	 0.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61997	 1	 5.28	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61998	 1	 6.04	 1.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	61999	 1	 5.38	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62000	 1	 5.27	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62003	 1	 4.88	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62005	 1	 6.1	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62007	 1	 8.08	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62008	 1	 6.3	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62009	 1	 4.94	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62010	 1	 6.8	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62012	 1	 9.4	 -3.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62013	 1	 10.96	 -3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62014	 1	 6.9	 -3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62016	 1	 6.23	 -3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62017	 1	 4.47	 -3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62019	 1	 8.8	 -3.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62020	 1	 13.92	 -3.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62021	 1	 6.4	 -3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62023	 1	 10.34	 -3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62024	 1	 6.13	 -3.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62025	 1	 11.55	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62026	 1	 3.94	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62028	 1	 7.44	 -3.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62029	 1	 11.28	 2.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62030	 1	 0.0	 0.0	 0.0	 -152.77	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62031	 1	 32.02	 6.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62032	 1	 14.03	 2.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62033	 1	 0.0	 0.0	 0.0	 45.66	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62034	 1	 0.0	 0.0	 0.0	 -29.28	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62035	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62036	 1	 6.92	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62037	 1	 11.73	 -27.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62038	 1	 5.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62039	 1	 3.37	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62040	 1	 2.54	 0.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62042	 1	 3.78	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62043	 1	 5.73	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62044	 1	 8.81	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62046	 1	 3.49	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62047	 1	 18.47	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62048	 1	 5.09	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62052	 1	 22.25	 3.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62054	 1	 6.65	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62055	 1	 5.46	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62056	 1	 6.54	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62057	 1	 5.76	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62058	 1	 4.58	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62060	 1	 5.65	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62061	 1	 5.97	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62062	 1	 5.15	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62063	 1	 12.43	 3.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62064	 1	 5.45	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62066	 1	 3.26	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62068	 1	 2.1	 0.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62070	 1	 3.19	 -1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62074	 1	 26.13	 7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62075	 1	 5.94	 1.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62077	 1	 6.07	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62078	 1	 5.68	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62079	 1	 0.0	 0.0	 0.0	 51.3	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62080	 1	 7.33	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62083	 1	 3.46	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62084	 1	 3.54	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62085	 1	 9.19	 1.21	 0.0	 -17.33	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62086	 1	 4.64	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62087	 1	 14.69	 4.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62090	 1	 6.02	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62091	 1	 6.5	 1.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62095	 1	 3.48	 0.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62096	 1	 2.7	 0.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62097	 1	 5.7	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62099	 1	 4.29	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62100	 1	 4.06	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62101	 1	 6.33	 1.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62102	 1	 12.71	 2.29	 0.0	 -84.11	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62103	 1	 9.24	 2.21	 0.0	 48.88	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62104	 1	 6.91	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62105	 1	 8.38	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62106	 1	 0.0	 0.0	 0.0	 1.59	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62107	 1	 8.79	 0.97	 0.0	 661.36	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	62108	 1	 0.0	 0.0	 0.0	 163.96	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	62109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62111	 1	 7.69	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62113	 1	 8.04	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62115	 1	 5.6	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62116	 1	 4.69	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62118	 1	 4.03	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62120	 1	 6.06	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62121	 1	 15.85	 3.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62123	 1	 7.45	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62127	 1	 4.3	 0.66	 0.0	 -40.33	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62128	 1	 0.0	 0.0	 0.0	 -82.97	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62129	 1	 7.67	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62131	 1	 2.0	 0.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62132	 1	 11.51	 2.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62133	 1	 10.61	 2.27	 0.0	 11.77	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62134	 1	 0.0	 0.0	 0.0	 70.13	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62135	 1	 8.5	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62137	 1	 6.32	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62139	 1	 7.44	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62141	 1	 4.71	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62142	 1	 6.37	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62144	 1	 8.49	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62145	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62146	 1	 2.84	 0.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62147	 1	 4.52	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62149	 1	 5.4	 1.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62150	 1	 4.48	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62151	 1	 5.39	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62152	 1	 2.42	 0.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62154	 1	 0.0	 0.0	 0.0	 131.04	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62155	 1	 5.66	 1.12	 0.0	 5.61	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62156	 1	 35.9	 10.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62157	 1	 3.73	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62158	 1	 4.23	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62160	 1	 7.11	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62161	 1	 2.25	 0.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62164	 1	 4.49	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62165	 1	 10.34	 1.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62166	 1	 4.86	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62168	 1	 4.96	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62169	 1	 4.27	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62170	 1	 7.68	 1.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62171	 1	 2.51	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62174	 1	 3.91	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62175	 1	 4.84	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62179	 1	 7.11	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62180	 1	 5.15	 1.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62182	 1	 7.25	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62184	 1	 7.71	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62185	 1	 8.25	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62186	 1	 5.06	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62188	 1	 3.57	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62190	 1	 7.24	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62191	 1	 4.96	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62192	 1	 5.77	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62194	 1	 5.56	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62196	 1	 2.99	 0.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62197	 1	 5.34	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62199	 1	 2.94	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62200	 1	 4.37	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62201	 1	 2.67	 0.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62202	 1	 4.76	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62204	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62205	 1	 2.71	 0.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62206	 1	 0.0	 0.0	 0.0	 -23.87	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62207	 1	 7.0	 1.65	 0.0	 3.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62208	 1	 6.26	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62209	 1	 8.57	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62210	 1	 8.88	 2.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62211	 1	 6.16	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62213	 1	 2.73	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62214	 1	 3.73	 0.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62215	 1	 3.24	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62217	 1	 5.5	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62218	 1	 0.0	 0.0	 0.0	 -43.72	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62219	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62225	 1	 5.71	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62226	 1	 6.77	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62227	 1	 7.53	 1.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62228	 1	 9.23	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62229	 1	 10.05	 1.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62230	 1	 9.37	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62232	 1	 4.71	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62233	 1	 5.18	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62234	 1	 3.71	 0.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62235	 1	 6.21	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62236	 1	 6.05	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62238	 1	 4.61	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62239	 1	 5.56	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62240	 1	 4.48	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62241	 1	 5.19	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62243	 1	 3.2	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62244	 1	 4.7	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62245	 1	 3.96	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62246	 1	 6.04	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62247	 1	 6.42	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62248	 1	 15.34	 4.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62249	 1	 8.91	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62250	 1	 7.73	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62251	 1	 5.45	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62252	 1	 39.65	 14.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62253	 1	 5.98	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62254	 1	 6.03	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62256	 1	 5.03	 1.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62257	 1	 3.49	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62258	 1	 5.27	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62259	 1	 6.63	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62260	 1	 10.11	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62262	 1	 5.63	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62263	 1	 7.15	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62264	 1	 5.32	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62265	 1	 4.25	 0.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62266	 1	 7.46	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62267	 1	 7.18	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62268	 1	 3.44	 0.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62269	 1	 5.11	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62270	 1	 8.36	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62271	 1	 7.19	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62272	 1	 6.41	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62273	 1	 4.3	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62274	 1	 4.75	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62275	 1	 7.77	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62279	 1	 9.42	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62280	 1	 6.2	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62281	 1	 5.44	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62283	 1	 8.95	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62284	 1	 7.38	 1.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62285	 1	 5.74	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62286	 1	 4.04	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62287	 1	 5.73	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62288	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62289	 1	 4.41	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62290	 1	 7.57	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62292	 1	 7.65	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62293	 1	 6.16	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62294	 1	 8.78	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62297	 1	 4.51	 0.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62298	 1	 6.96	 1.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62299	 1	 15.5	 4.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62302	 1	 6.21	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62303	 1	 7.42	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62304	 1	 4.65	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62305	 1	 4.79	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62306	 1	 7.77	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62309	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62310	 1	 5.61	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62311	 1	 5.91	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62312	 1	 2.5	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62313	 1	 3.92	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62314	 1	 4.89	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62316	 1	 9.09	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62318	 1	 7.98	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62322	 1	 5.67	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62324	 1	 5.8	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62325	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62326	 1	 6.58	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62327	 1	 3.55	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62328	 1	 6.89	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62329	 1	 5.68	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62330	 1	 3.44	 0.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62331	 1	 9.25	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62332	 1	 6.78	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62333	 1	 4.73	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62334	 1	 4.84	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62335	 1	 3.08	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62337	 1	 4.79	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62339	 1	 4.22	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62341	 1	 10.11	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62342	 1	 6.12	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62343	 1	 2.28	 0.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62344	 1	 3.49	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62345	 1	 3.78	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62347	 1	 3.9	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62348	 1	 7.66	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62350	 1	 4.82	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62351	 1	 5.27	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62352	 1	 6.58	 1.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62354	 1	 1.38	 0.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62355	 1	 3.39	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62356	 1	 5.73	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62358	 1	 9.92	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62359	 1	 8.74	 1.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62360	 1	 5.33	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62367	 1	 6.12	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62369	 1	 5.67	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62370	 1	 6.78	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62372	 1	 3.96	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62374	 1	 6.06	 1.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62375	 1	 7.58	 2.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62376	 1	 3.54	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62377	 1	 7.58	 1.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62378	 1	 4.72	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62380	 1	 3.8	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62382	 1	 6.38	 1.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62383	 1	 3.63	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62384	 1	 9.17	 2.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62385	 1	 4.73	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62386	 1	 8.19	 2.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62387	 1	 7.79	 1.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62388	 1	 3.75	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62389	 1	 6.2	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62390	 1	 0.0	 0.0	 0.0	 203.09	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62391	 1	 13.74	 2.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62392	 1	 12.23	 2.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62393	 1	 6.32	 1.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62394	 1	 6.01	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62395	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62397	 1	 4.66	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62400	 1	 4.36	 1.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62401	 1	 3.31	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62402	 1	 4.36	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62403	 1	 4.9	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62404	 1	 5.8	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62405	 1	 9.62	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62406	 1	 5.48	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62407	 1	 5.26	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62410	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62411	 1	 4.34	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62413	 1	 4.47	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62417	 1	 5.88	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62419	 1	 7.41	 1.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62420	 1	 8.47	 1.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62421	 1	 6.75	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62423	 1	 3.78	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62424	 1	 8.61	 2.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62425	 1	 11.14	 2.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62426	 1	 6.0	 1.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62427	 1	 7.35	 1.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62429	 1	 10.98	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62430	 1	 4.22	 0.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62433	 1	 12.43	 3.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62434	 1	 3.32	 0.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62435	 1	 34.87	 9.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62437	 1	 6.14	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62440	 1	 6.44	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62441	 1	 5.86	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62442	 1	 7.24	 1.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62443	 1	 11.37	 2.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62444	 1	 5.33	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62447	 1	 5.73	 1.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62450	 1	 8.81	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62451	 1	 206.54	 83.73	 0.0	 382.96	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	62452	 1	 12.13	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62453	 1	 46.51	 15.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62454	 1	 3.43	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62456	 1	 11.68	 2.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62457	 1	 15.24	 2.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62458	 1	 4.38	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62459	 1	 8.71	 2.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62461	 1	 3.27	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62464	 1	 3.09	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62465	 1	 5.04	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62467	 1	 4.98	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62469	 1	 9.27	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62470	 1	 39.46	 9.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62471	 1	 31.55	 9.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62472	 1	 22.76	 6.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62475	 1	 10.57	 3.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62476	 1	 6.5	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62479	 1	 7.84	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62481	 1	 15.19	 4.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62482	 1	 25.58	 8.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62485	 1	 38.96	 13.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62488	 1	 4.53	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62493	 1	 7.84	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62497	 1	 41.93	 11.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62498	 1	 12.14	 3.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62500	 1	 8.37	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62501	 1	 7.32	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62502	 1	 11.0	 3.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62503	 1	 8.36	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62505	 1	 6.01	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62506	 1	 6.4	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62507	 1	 6.77	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62508	 1	 5.01	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62509	 1	 4.06	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62510	 1	 3.62	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62511	 1	 6.29	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62512	 1	 3.83	 0.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62513	 1	 5.7	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62514	 1	 8.64	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62515	 1	 9.56	 2.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62516	 1	 5.08	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62517	 1	 12.88	 3.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62518	 1	 4.26	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62519	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62521	 1	 5.6	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62522	 1	 2.6	 0.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62523	 1	 10.22	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62524	 1	 7.58	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62525	 1	 4.07	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62526	 1	 2.37	 0.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62527	 1	 5.42	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62529	 1	 7.92	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62530	 1	 5.54	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62531	 1	 4.04	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62533	 1	 5.87	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62535	 1	 4.91	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62536	 1	 2.05	 0.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62537	 1	 3.84	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62538	 1	 4.55	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62539	 1	 0.63	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62540	 1	 0.0	 0.0	 0.0	 200.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62541	 1	 47.12	 11.49	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62542	 1	 10.32	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62543	 1	 4.78	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62544	 1	 40.13	 14.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62545	 1	 0.0	 0.0	 0.0	 119.86	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62546	 1	 4.62	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62547	 1	 8.68	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62548	 1	 5.64	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62549	 1	 12.05	 3.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62550	 1	 5.84	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62551	 1	 46.18	 10.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62552	 1	 9.74	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62553	 1	 6.95	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62554	 1	 5.25	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62555	 1	 8.24	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62556	 1	 6.9	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62557	 1	 6.85	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62558	 1	 5.35	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62560	 1	 7.3	 2.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62561	 1	 2.59	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62562	 1	 5.75	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62563	 1	 2.53	 0.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62564	 1	 3.45	 0.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62565	 1	 4.09	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62566	 1	 8.03	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62567	 1	 6.08	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62568	 1	 4.82	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62569	 1	 5.24	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62570	 1	 4.1	 0.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62571	 1	 4.67	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62573	 1	 3.69	 0.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62574	 1	 4.87	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62576	 1	 7.26	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62578	 1	 7.69	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62580	 1	 5.65	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62581	 1	 3.27	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62582	 1	 6.23	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62583	 1	 4.78	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62584	 1	 6.79	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62585	 1	 6.3	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62586	 1	 7.95	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62587	 1	 2.81	 0.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62588	 1	 2.98	 0.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62589	 1	 8.74	 2.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62590	 1	 3.2	 0.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62591	 1	 4.54	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62592	 1	 4.68	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62593	 1	 3.83	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62594	 1	 4.44	 0.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62595	 1	 4.83	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62596	 1	 12.16	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62597	 1	 5.92	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62598	 1	 10.98	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62599	 1	 9.69	 2.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62602	 1	 9.44	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62603	 1	 7.07	 1.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62604	 1	 42.5	 6.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62605	 1	 13.34	 3.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62606	 1	 3.31	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62607	 1	 8.9	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62608	 1	 7.14	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62610	 1	 3.36	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62611	 1	 7.09	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62613	 1	 7.28	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62614	 1	 11.2	 -7.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62615	 1	 2.76	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62616	 1	 7.92	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62619	 1	 4.88	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62621	 1	 7.59	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62622	 1	 7.11	 1.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62623	 1	 76.09	 12.74	 0.0	 26.8	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	62624	 1	 0.0	 0.0	 0.0	 94.79	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	62625	 1	 6.88	 1.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62627	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62628	 1	 10.62	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62629	 1	 7.4	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62630	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62631	 1	 10.17	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62632	 1	 5.46	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62633	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62634	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62635	 1	 27.37	 9.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62636	 1	 22.77	 6.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62637	 1	 6.61	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62638	 1	 9.15	 2.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62639	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62641	 1	 7.93	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62642	 1	 9.02	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62643	 1	 1.76	 0.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62644	 1	 6.69	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62645	 1	 5.66	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62646	 1	 5.12	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62647	 1	 4.04	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62648	 1	 4.01	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62649	 1	 6.81	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62650	 1	 2.94	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62651	 1	 3.27	 0.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62652	 1	 7.5	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62653	 1	 40.18	 7.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62654	 1	 4.12	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62655	 1	 8.02	 2.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62656	 1	 5.16	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62657	 1	 6.38	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62658	 1	 5.92	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62659	 1	 4.15	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62660	 1	 3.23	 0.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62661	 1	 4.16	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62662	 1	 5.93	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62663	 1	 5.36	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62664	 1	 2.54	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62665	 1	 6.25	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62666	 1	 6.26	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62667	 1	 7.01	 2.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62668	 1	 8.29	 1.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62669	 1	 6.49	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62670	 1	 10.46	 1.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62671	 1	 3.91	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62672	 1	 4.62	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62673	 1	 7.26	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62674	 1	 6.35	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62675	 1	 6.11	 1.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62676	 1	 6.83	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62677	 1	 4.07	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62678	 1	 6.75	 1.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62679	 1	 4.13	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62680	 1	 6.13	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62681	 1	 3.92	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62682	 1	 3.41	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62683	 1	 9.11	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62684	 1	 4.22	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62685	 1	 4.3	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62686	 1	 5.09	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62688	 1	 8.07	 2.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62690	 1	 8.16	 2.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62691	 1	 5.22	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62693	 1	 9.11	 2.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62696	 1	 8.36	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62697	 1	 5.25	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62698	 1	 4.72	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62699	 1	 5.99	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62700	 1	 6.94	 1.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62701	 1	 4.19	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62702	 1	 5.27	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62703	 1	 5.86	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62704	 1	 5.61	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62705	 1	 6.74	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62706	 1	 15.1	 4.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62707	 1	 12.29	 3.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62708	 1	 6.51	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62709	 1	 7.75	 1.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62710	 1	 7.24	 1.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62711	 1	 4.86	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62712	 1	 9.73	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62713	 1	 4.21	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62714	 1	 11.95	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62716	 1	 4.19	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62717	 1	 10.06	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62718	 1	 8.8	 2.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62719	 1	 3.67	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62720	 1	 4.73	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62721	 1	 2.8	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62722	 1	 3.98	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62723	 1	 8.62	 2.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62724	 1	 4.95	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62725	 1	 4.15	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62726	 1	 5.18	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62727	 1	 3.79	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62728	 1	 8.49	 1.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62729	 1	 4.75	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62731	 1	 11.29	 2.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62732	 1	 16.24	 4.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62733	 1	 7.84	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62735	 1	 9.79	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62736	 1	 10.26	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62739	 1	 5.92	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62740	 1	 4.95	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62742	 1	 11.71	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62744	 1	 5.79	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62745	 1	 5.79	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62746	 1	 5.93	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62747	 1	 7.11	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62749	 1	 4.36	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62750	 1	 6.09	 1.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62751	 1	 6.36	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62752	 1	 6.58	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62753	 1	 6.97	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62755	 1	 5.04	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62756	 1	 5.28	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62757	 1	 3.47	 0.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62759	 1	 5.15	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62760	 1	 7.31	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62761	 1	 3.37	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62762	 1	 4.18	 0.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62763	 1	 4.91	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62764	 1	 4.84	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62765	 1	 5.49	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62766	 1	 3.16	 0.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62767	 1	 8.51	 2.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62768	 1	 5.94	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62769	 1	 4.69	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62770	 1	 4.59	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62771	 1	 4.29	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62772	 1	 5.03	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62773	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62774	 1	 4.54	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62776	 1	 5.4	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62777	 1	 1.27	 0.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62778	 1	 6.07	 1.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62779	 1	 4.1	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62780	 1	 6.21	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62781	 1	 7.25	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62782	 1	 6.23	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62785	 1	 6.61	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62786	 1	 8.93	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62787	 1	 9.04	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62788	 1	 11.24	 3.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62789	 1	 9.61	 1.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62790	 1	 7.7	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62791	 1	 5.81	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62792	 1	 8.81	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62793	 1	 10.42	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62794	 1	 9.96	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62795	 1	 7.6	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62796	 1	 11.99	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62797	 1	 11.12	 3.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62798	 1	 8.42	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62799	 1	 12.33	 2.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62800	 1	 1.51	 0.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62801	 1	 9.0	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62803	 1	 5.85	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62804	 1	 8.03	 1.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62805	 1	 7.41	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62806	 1	 8.21	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62807	 1	 4.31	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62808	 1	 10.02	 2.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62809	 1	 2.81	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62810	 1	 3.73	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62812	 1	 5.97	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62813	 1	 8.04	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62814	 1	 6.44	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62815	 1	 3.8	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62816	 1	 8.12	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62817	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62819	 1	 3.09	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62820	 1	 4.17	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62823	 1	 5.84	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62824	 1	 3.13	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62825	 1	 2.59	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62826	 1	 3.02	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62827	 1	 2.75	 0.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62828	 1	 3.36	 0.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62829	 1	 6.7	 1.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62830	 1	 4.05	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62831	 1	 9.95	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62832	 1	 4.6	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62833	 1	 4.66	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62834	 1	 5.14	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62835	 1	 6.71	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62836	 1	 5.57	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62838	 1	 5.63	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62839	 1	 6.53	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62840	 1	 6.04	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62841	 1	 4.18	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62842	 1	 4.07	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62843	 1	 6.98	 1.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62844	 1	 9.97	 2.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62845	 1	 44.4	 12.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62846	 1	 5.59	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62847	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62848	 1	 7.57	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62849	 1	 3.86	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62850	 1	 17.92	 4.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62851	 1	 2.69	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62852	 1	 3.21	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62853	 1	 3.52	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62854	 1	 5.85	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62855	 1	 3.41	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62858	 1	 5.93	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62861	 1	 3.26	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62863	 1	 9.04	 2.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62864	 1	 8.38	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62865	 1	 8.79	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62866	 1	 6.39	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62867	 1	 5.2	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62868	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62869	 1	 3.0	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62870	 1	 3.2	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62871	 1	 4.07	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62872	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62873	 1	 5.01	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62876	 1	 3.9	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62877	 1	 4.61	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62878	 1	 6.43	 1.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62879	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62880	 1	 4.86	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62882	 1	 8.54	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62883	 1	 7.7	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62884	 1	 10.87	 3.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62885	 1	 3.26	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62886	 1	 7.48	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62887	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62888	 1	 4.73	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62889	 1	 3.68	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62890	 1	 8.91	 2.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62891	 1	 4.53	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62892	 1	 5.49	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62893	 1	 12.27	 2.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62894	 1	 3.72	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62895	 1	 4.15	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62896	 1	 5.54	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62897	 1	 6.99	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62898	 1	 0.25	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62899	 1	 18.66	 4.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62900	 1	 4.82	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62902	 1	 2.96	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62903	 1	 8.58	 1.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62904	 1	 5.88	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62906	 1	 4.51	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62907	 1	 6.34	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62908	 1	 40.51	 13.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62909	 1	 8.89	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62910	 1	 9.46	 1.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62911	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62912	 1	 5.76	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62913	 1	 7.97	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62914	 1	 4.91	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62915	 1	 7.15	 1.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62916	 1	 40.62	 6.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62917	 1	 3.55	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62918	 1	 7.2	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62919	 1	 2.85	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62920	 1	 4.75	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62921	 1	 5.12	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62922	 1	 3.58	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62923	 1	 6.33	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62924	 1	 4.13	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62925	 1	 7.92	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62926	 1	 12.56	 3.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62927	 1	 5.76	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62929	 1	 2.36	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62930	 1	 5.02	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62931	 1	 7.2	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62932	 1	 5.01	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62933	 1	 3.69	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62934	 1	 4.62	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62935	 1	 3.41	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62936	 1	 4.81	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62937	 1	 5.5	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62938	 1	 14.73	 3.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62939	 1	 4.23	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62940	 1	 3.58	 0.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62941	 1	 2.89	 0.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62942	 1	 3.38	 0.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62943	 1	 6.24	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62944	 1	 1.75	 0.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62945	 1	 6.7	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62946	 1	 3.3	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62947	 1	 4.61	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62948	 1	 5.6	 1.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62949	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62950	 1	 5.09	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62951	 1	 4.73	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62952	 1	 8.08	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62953	 1	 6.05	 -0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62954	 1	 4.86	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62955	 1	 5.05	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62956	 1	 9.05	 2.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62957	 1	 6.79	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62960	 1	 5.92	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62961	 1	 6.61	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62962	 1	 4.66	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62963	 1	 7.75	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62964	 1	 9.34	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62965	 1	 8.29	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62966	 1	 4.54	 0.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62967	 1	 4.37	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62968	 1	 7.79	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62969	 1	 4.43	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62970	 1	 7.03	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62971	 1	 3.14	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62972	 1	 6.94	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62973	 1	 5.18	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62974	 1	 4.02	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62975	 1	 10.46	 2.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62976	 1	 8.71	 2.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62977	 1	 7.22	 -4.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62978	 1	 3.14	 0.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62979	 1	 3.09	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62981	 1	 0.17	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62982	 1	 3.96	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62983	 1	 0.0	 0.0	 0.0	 13.79	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	62984	 1	 1.11	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62986	 1	 0.31	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62987	 1	 51.78	 17.49	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62989	 1	 0.61	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62993	 1	 12.69	 -1.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62996	 1	 2.11	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	62997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62998	 1	 4.43	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62999	 1	 7.26	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63000	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63001	 1	 4.37	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63002	 1	 4.28	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63004	 1	 5.86	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63007	 1	 4.7	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63008	 1	 7.15	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63009	 1	 4.06	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63010	 1	 8.08	 1.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63011	 1	 2.03	 0.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63012	 1	 34.98	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63013	 1	 4.92	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63014	 1	 6.04	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63015	 1	 7.79	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63016	 1	 6.35	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63019	 1	 7.18	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63020	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63021	 1	 6.19	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63022	 1	 4.83	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63023	 1	 4.88	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63024	 1	 7.14	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63025	 1	 6.35	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63026	 1	 6.42	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63027	 1	 11.03	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63028	 1	 6.4	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63030	 1	 47.76	 8.07	 0.0	 33.96	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63031	 1	 0.0	 0.0	 0.0	 -3.01	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63032	 1	 6.18	 1.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63033	 1	 8.19	 -11.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63034	 1	 1.71	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63035	 1	 3.68	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63036	 1	 4.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63037	 1	 4.53	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63038	 1	 5.09	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63039	 1	 3.14	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63041	 1	 5.09	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63042	 1	 8.67	 1.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63043	 1	 3.56	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63045	 1	 2.7	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63046	 1	 6.18	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63047	 1	 2.64	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63049	 1	 7.58	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63050	 1	 0.0	 0.0	 0.0	 100.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63052	 1	 4.6	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63054	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63056	 1	 3.88	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63057	 1	 2.17	 0.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63058	 1	 5.61	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63060	 1	 1.86	 0.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63061	 1	 5.38	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63062	 1	 2.77	 0.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63064	 1	 6.32	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63065	 1	 3.05	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63066	 1	 7.19	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63067	 1	 1.91	 0.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63068	 1	 6.54	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63069	 1	 12.91	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63071	 1	 13.13	 3.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63072	 1	 15.5	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63074	 1	 4.06	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63075	 1	 4.08	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63076	 1	 14.74	 3.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63077	 1	 8.53	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63079	 1	 7.73	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63080	 1	 8.75	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63081	 1	 7.12	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63082	 1	 6.19	 1.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63083	 1	 3.58	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63084	 1	 8.03	 1.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63085	 1	 4.56	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63086	 1	 10.52	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63088	 1	 0.0	 0.0	 0.0	 -117.51	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63089	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63090	 1	 7.59	 1.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63091	 1	 13.36	 3.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63093	 1	 14.42	 1.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63094	 1	 4.74	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63095	 1	 6.96	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63096	 1	 7.61	 1.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63098	 1	 8.31	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63099	 1	 3.73	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63100	 1	 7.81	 1.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63101	 1	 4.68	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63102	 1	 8.43	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63103	 1	 5.38	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63104	 1	 6.23	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63105	 1	 5.34	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63106	 1	 2.65	 0.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63107	 1	 9.22	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63108	 1	 3.29	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63109	 1	 7.47	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63110	 1	 5.15	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63111	 1	 8.49	 2.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63112	 1	 10.31	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63113	 1	 3.3	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63115	 1	 11.0	 3.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63116	 1	 8.96	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63117	 1	 6.52	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63119	 1	 5.46	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63120	 1	 8.07	 1.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63122	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63123	 1	 6.0	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63124	 1	 3.06	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63127	 1	 5.51	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63128	 1	 8.3	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63129	 1	 5.79	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63130	 1	 4.16	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63131	 1	 5.39	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63133	 1	 3.18	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63134	 1	 10.06	 1.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63135	 1	 4.21	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63136	 1	 7.29	 1.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63137	 1	 5.77	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63140	 1	 7.25	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63141	 1	 8.22	 1.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63142	 1	 6.97	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63143	 1	 2.57	 0.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63144	 1	 5.71	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63145	 1	 5.73	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63146	 1	 5.48	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63147	 1	 3.91	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63148	 1	 4.48	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63149	 1	 3.32	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63150	 1	 3.33	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63151	 1	 3.31	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63152	 1	 3.39	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63153	 1	 6.38	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63155	 1	 6.2	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63156	 1	 5.07	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63157	 1	 3.61	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63158	 1	 5.2	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63159	 1	 5.11	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63160	 1	 2.22	 0.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63161	 1	 5.96	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63162	 1	 2.53	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63163	 1	 3.85	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63164	 1	 1.76	 0.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63165	 1	 5.53	 1.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63166	 1	 2.79	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63167	 1	 5.36	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63168	 1	 6.26	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63169	 1	 5.5	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63170	 1	 6.81	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63171	 1	 8.14	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63173	 1	 4.35	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63174	 1	 3.37	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63175	 1	 5.14	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63177	 1	 4.35	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63178	 1	 4.29	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63179	 1	 6.95	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63180	 1	 3.45	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63181	 1	 38.5	 9.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63182	 1	 5.19	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63183	 1	 10.03	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63184	 1	 11.9	 3.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63185	 1	 4.12	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63186	 1	 3.62	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63187	 1	 8.85	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63188	 1	 6.19	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63190	 1	 2.78	 0.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63191	 1	 8.46	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63192	 1	 6.87	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63193	 1	 1.13	 0.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63194	 1	 14.19	 3.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63195	 1	 3.55	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63196	 1	 2.38	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63197	 1	 5.18	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63198	 1	 7.42	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63199	 1	 5.55	 0.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63200	 1	 4.42	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63202	 1	 3.73	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63203	 1	 5.15	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63204	 1	 7.55	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63206	 1	 3.09	 0.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63207	 1	 2.35	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63208	 1	 4.66	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63209	 1	 14.03	 2.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63210	 1	 3.88	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63211	 1	 11.43	 2.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63212	 1	 1.93	 0.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63214	 1	 1.54	 0.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63215	 1	 4.53	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63216	 1	 8.93	 1.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63217	 1	 3.86	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63218	 1	 7.21	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63219	 1	 8.09	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63220	 1	 3.73	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63221	 1	 3.65	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63222	 1	 3.8	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63223	 1	 4.62	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63224	 1	 8.13	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63225	 1	 7.18	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63226	 1	 10.76	 2.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63227	 1	 6.06	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63228	 1	 4.94	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63229	 1	 5.18	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63231	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63233	 1	 3.91	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63234	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63235	 1	 4.45	 1.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63236	 1	 0.0	 0.0	 0.0	 11.46	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63237	 1	 54.7	 12.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63238	 1	 5.33	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63240	 1	 14.9	 4.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63241	 1	 10.12	 2.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63242	 1	 6.65	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63243	 1	 9.92	 2.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63244	 1	 3.85	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63245	 1	 7.54	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63247	 1	 6.4	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63248	 1	 3.77	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63249	 1	 7.17	 1.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63250	 1	 2.97	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63251	 1	 3.83	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63252	 1	 5.38	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63253	 1	 2.0	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63255	 1	 3.56	 0.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63258	 1	 2.62	 0.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63259	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63261	 1	 1.46	 0.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63263	 1	 4.34	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63264	 1	 2.96	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63265	 1	 3.35	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63266	 1	 1.34	 0.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63267	 1	 5.78	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63268	 1	 8.12	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63270	 1	 4.91	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63271	 1	 5.87	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63272	 1	 4.69	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63273	 1	 7.43	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63274	 1	 6.23	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63277	 1	 4.6	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63279	 1	 7.6	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63280	 1	 8.28	 2.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63281	 1	 3.48	 0.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63282	 1	 5.23	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63283	 1	 7.94	 1.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63284	 1	 5.4	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63285	 1	 12.89	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63286	 1	 2.3	 0.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63287	 1	 2.77	 0.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63288	 1	 8.63	 1.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63289	 1	 1.55	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63290	 1	 4.06	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63291	 1	 2.7	 0.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63292	 1	 5.67	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63293	 1	 4.28	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63294	 1	 3.76	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63295	 1	 4.99	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63296	 1	 54.99	 8.73	 0.0	 16.57	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63297	 1	 83.58	 28.22	 0.0	 178.32	 1	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	63298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63300	 1	 3.6	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63301	 1	 1.48	 0.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63302	 1	 1.61	 0.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63303	 1	 10.63	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63304	 1	 3.77	 0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63305	 1	 3.98	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63306	 1	 6.35	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63307	 1	 7.54	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63308	 1	 18.0	 2.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63309	 1	 6.06	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63310	 1	 13.29	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63311	 1	 1.93	 0.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63312	 1	 9.71	 1.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63313	 1	 9.67	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63314	 1	 5.1	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63315	 1	 7.43	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63318	 1	 2.64	 0.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63319	 1	 2.92	 0.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63320	 1	 6.28	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63322	 1	 4.22	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63323	 1	 3.3	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63324	 1	 5.38	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63325	 1	 5.05	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63326	 1	 6.28	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63327	 1	 5.71	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63328	 1	 8.42	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63329	 1	 4.23	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63330	 1	 9.22	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63331	 1	 10.39	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63332	 1	 3.61	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63333	 1	 5.64	 0.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63334	 1	 5.96	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63335	 1	 20.2	 5.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63336	 1	 15.4	 3.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63337	 1	 7.82	 2.23	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63338	 1	 18.82	 2.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63339	 1	 9.03	 1.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63340	 1	 7.27	 1.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63341	 1	 12.43	 2.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63343	 1	 12.17	 3.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63344	 1	 17.88	 5.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63345	 1	 2.45	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63349	 1	 8.03	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63350	 1	 6.35	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63351	 1	 6.8	 1.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63355	 1	 46.15	 11.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63357	 1	 8.93	 1.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63358	 1	 3.22	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63359	 1	 3.67	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63361	 1	 9.15	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63362	 1	 5.56	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63363	 1	 5.94	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63364	 1	 6.82	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63365	 1	 3.13	 0.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63366	 1	 6.01	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63367	 1	 5.88	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63369	 1	 5.09	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63370	 1	 9.99	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63372	 1	 10.14	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63373	 1	 2.14	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63374	 1	 7.98	 2.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63375	 1	 11.99	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63376	 1	 5.73	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63377	 1	 2.69	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63379	 1	 5.6	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63380	 1	 19.72	 3.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63381	 1	 3.97	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63382	 1	 2.96	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63383	 1	 1.43	 0.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63384	 1	 12.94	 3.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63385	 1	 12.36	 2.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63387	 1	 5.43	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63388	 1	 3.95	 -5.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63389	 1	 9.88	 2.68	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63390	 1	 7.64	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63391	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63392	 1	 7.25	 -3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63394	 1	 16.78	 -0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63395	 1	 7.69	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63396	 1	 5.62	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63398	 1	 5.44	 -3.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63399	 1	 10.43	 -3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63401	 1	 6.83	 -0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63402	 1	 4.31	 -0.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63403	 1	 5.28	 -3.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63404	 1	 8.43	 -3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63405	 1	 5.07	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63406	 1	 4.24	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63407	 1	 8.69	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63409	 1	 8.95	 1.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63410	 1	 5.66	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63413	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63414	 1	 5.51	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63415	 1	 3.16	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63417	 1	 4.6	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63420	 1	 5.24	 -3.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63421	 1	 7.81	 -3.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63423	 1	 6.07	 -3.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63424	 1	 3.04	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63428	 1	 8.7	 -3.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63429	 1	 6.98	 -3.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63430	 1	 6.3	 -3.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63431	 1	 11.78	 -3.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63432	 1	 13.69	 3.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63433	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63434	 1	 6.22	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63435	 1	 5.79	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63439	 1	 5.03	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63440	 1	 3.61	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63442	 1	 7.27	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63443	 1	 10.26	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63445	 1	 4.71	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63446	 1	 3.34	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63447	 1	 3.64	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63448	 1	 9.33	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63450	 1	 3.36	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63451	 1	 18.97	 3.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63452	 1	 5.72	 1.23	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63453	 1	 6.56	 1.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63454	 1	 6.2	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63455	 1	 8.76	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63456	 1	 3.37	 0.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63457	 1	 5.92	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63458	 1	 14.22	 3.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63459	 1	 8.53	 1.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63460	 1	 7.59	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63461	 1	 3.03	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63465	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63466	 1	 3.77	 0.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63467	 1	 4.09	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63468	 1	 3.74	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63469	 1	 3.07	 0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63470	 1	 2.33	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63471	 1	 3.31	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63474	 1	 6.48	 1.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63475	 1	 5.82	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63476	 1	 8.6	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63477	 1	 5.88	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63478	 1	 6.21	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63480	 1	 10.27	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63481	 1	 1.4	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63482	 1	 15.03	 3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63483	 1	 0.0	 0.0	 0.0	 157.44	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63484	 1	 4.0	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63485	 1	 0.57	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63486	 1	 14.23	 3.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63487	 1	 6.73	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63488	 1	 8.53	 2.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63489	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63490	 1	 5.7	 1.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63491	 1	 6.81	 1.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63492	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63493	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63494	 1	 0.0	 0.0	 0.0	 202.52	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63495	 1	 47.03	 14.29	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63496	 1	 8.68	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63497	 1	 14.09	 3.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63498	 1	 9.35	 2.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63499	 1	 9.98	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63500	 1	 5.46	 1.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63501	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63502	 1	 40.11	 10.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63503	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63504	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63505	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63506	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63507	 1	 4.26	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63508	 1	 67.76	 9.04	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63509	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63510	 1	 8.66	 1.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63511	 1	 5.13	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63512	 1	 8.06	 2.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63513	 1	 5.75	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63514	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63515	 1	 6.05	 1.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63516	 1	 6.24	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63517	 1	 3.56	 0.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63518	 1	 5.76	 1.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63519	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63520	 1	 3.0	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63521	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63522	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63523	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63524	 1	 0.55	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63525	 1	 5.44	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63526	 1	 7.99	 1.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63527	 1	 5.38	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63528	 1	 12.25	 1.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63529	 1	 9.21	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63530	 1	 9.04	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63531	 1	 78.18	 22.38	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63532	 1	 9.19	 2.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63533	 1	 52.89	 9.53	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63534	 1	 0.0	 0.0	 0.0	 11.18	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63535	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63536	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63537	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63538	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63539	 1	 5.1	 1.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63540	 1	 3.88	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63541	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63542	 1	 7.51	 1.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63543	 1	 3.96	 1.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63544	 1	 3.77	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63545	 1	 11.84	 3.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63546	 1	 5.33	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63547	 1	 5.67	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63548	 1	 6.07	 1.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63549	 1	 5.87	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63550	 1	 5.02	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63551	 1	 8.79	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63552	 1	 7.14	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63553	 1	 2.83	 0.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63554	 1	 8.7	 2.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63555	 1	 5.81	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63556	 1	 7.92	 2.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63557	 1	 9.66	 2.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63558	 1	 5.29	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63559	 1	 2.58	 0.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63560	 1	 5.83	 0.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63561	 1	 7.11	 1.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63562	 1	 4.24	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63563	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63564	 1	 5.95	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63565	 1	 4.53	 1.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63566	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63567	 1	 4.84	 0.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63568	 1	 3.98	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63569	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63570	 1	 73.0	 21.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63571	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63572	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63573	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63574	 1	 13.69	 2.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63575	 1	 4.09	 0.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63576	 1	 23.98	 7.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63577	 1	 4.52	 1.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63578	 1	 0.0	 0.0	 0.0	 120.78	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63579	 1	 4.99	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63580	 1	 6.2	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63581	 1	 8.89	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63582	 1	 2.33	 0.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63583	 1	 11.5	 3.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63584	 1	 2.94	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63585	 1	 2.36	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63586	 1	 56.58	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63587	 1	 9.77	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63588	 1	 2.01	 0.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63589	 1	 9.82	 2.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63590	 1	 0.0	 0.0	 0.0	 140.44	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63591	 1	 12.03	 3.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63592	 1	 11.47	 3.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63593	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63594	 1	 7.11	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63595	 1	 4.52	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63596	 1	 7.99	 1.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63597	 1	 2.91	 0.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63598	 1	 3.49	 1.02	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63599	 1	 0.0	 0.0	 0.0	 205.09	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63600	 1	 3.7	 0.99	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63601	 1	 2.06	 0.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63602	 1	 2.94	 0.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63603	 1	 3.55	 0.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63604	 1	 6.91	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63605	 1	 10.36	 2.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63606	 1	 8.05	 2.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63607	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63608	 1	 3.6	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63609	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63610	 1	 4.12	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63611	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63612	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63613	 1	 1.55	 0.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63614	 1	 18.79	 2.96	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63615	 1	 2.85	 0.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63616	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63617	 1	 2.77	 0.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63618	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63619	 1	 5.14	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63620	 1	 22.29	 2.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63621	 1	 9.2	 2.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63622	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63623	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63624	 1	 4.57	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63625	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63626	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63627	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63628	 1	 4.42	 1.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63629	 1	 2.44	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63630	 1	 4.29	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63631	 1	 6.86	 1.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63632	 1	 8.61	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63633	 1	 5.21	 1.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63634	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63635	 1	 7.6	 1.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63636	 1	 5.4	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63637	 1	 4.66	 0.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63638	 1	 15.15	 4.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63639	 1	 7.15	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63640	 1	 10.19	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63641	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63642	 1	 1.97	 0.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63643	 1	 8.71	 1.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63644	 1	 12.48	 3.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63645	 1	 6.62	 1.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63646	 1	 0.0	 0.0	 0.0	 -58.4	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63647	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63648	 1	 3.72	 0.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63649	 1	 4.93	 1.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63650	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63651	 1	 3.33	 0.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63652	 1	 4.29	 0.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63653	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63654	 1	 9.85	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63655	 1	 2.09	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63656	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63657	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63658	 1	 5.99	 1.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63659	 1	 4.22	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63660	 1	 3.31	 0.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63661	 1	 4.84	 1.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63662	 1	 8.22	 2.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63663	 1	 8.7	 2.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63664	 1	 14.7	 4.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63665	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63666	 1	 4.1	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63667	 1	 7.5	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63668	 1	 8.98	 2.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63669	 1	 3.77	 0.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63670	 1	 3.66	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63671	 1	 8.96	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63672	 1	 8.56	 2.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63673	 1	 6.53	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63674	 1	 3.75	 0.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63675	 1	 7.58	 1.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63676	 1	 2.58	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63677	 1	 5.09	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63678	 1	 3.87	 0.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63679	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63680	 1	 8.87	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63681	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63682	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63683	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63684	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63685	 1	 6.84	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63686	 1	 1.96	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63687	 1	 7.92	 1.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63688	 1	 3.73	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63689	 1	 5.1	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63690	 1	 3.85	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63691	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63692	 1	 5.73	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63693	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63694	 1	 6.13	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63695	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63696	 1	 6.26	 1.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63697	 1	 6.87	 1.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63698	 1	 3.7	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63699	 1	 5.01	 1.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63700	 1	 4.61	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63701	 1	 3.07	 0.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63702	 1	 3.77	 0.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63703	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63704	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63705	 1	 2.81	 0.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63706	 1	 2.3	 0.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63707	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63708	 1	 7.59	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63709	 1	 3.0	 0.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63710	 1	 4.59	 1.07	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63711	 1	 3.65	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63712	 1	 5.7	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63713	 1	 2.39	 0.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63714	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63715	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63716	 1	 5.89	 0.88	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63717	 1	 2.72	 0.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63718	 1	 5.7	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63719	 1	 1.45	 0.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63720	 1	 2.76	 0.63	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63721	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63722	 1	 4.48	 1.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63723	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63724	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63725	 1	 1.68	 0.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63726	 1	 5.26	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63727	 1	 4.15	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63728	 1	 3.07	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63729	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63730	 1	 2.79	 0.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63731	 1	 7.76	 1.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63732	 1	 7.87	 2.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63733	 1	 14.3	 3.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63734	 1	 6.53	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63735	 1	 2.51	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63736	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63737	 1	 3.92	 0.75	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63738	 1	 3.93	 0.67	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63739	 1	 7.3	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63740	 1	 10.35	 1.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63741	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63742	 1	 5.49	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63743	 1	 7.68	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63744	 1	 3.23	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63745	 1	 3.87	 1.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63746	 1	 5.85	 0.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63747	 1	 3.7	 1.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63748	 1	 10.99	 2.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63749	 1	 107.22	 16.59	 0.0	 147.83	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	63750	 1	 11.66	 2.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63751	 1	 11.9	 2.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63752	 1	 6.76	 1.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63753	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63754	 1	 5.06	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63755	 1	 5.14	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63756	 1	 3.91	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63757	 1	 5.36	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63758	 1	 3.67	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63759	 1	 9.84	 2.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63760	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63761	 1	 2.34	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63762	 1	 5.06	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63763	 1	 1.9	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63764	 1	 16.03	 4.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63765	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63766	 1	 40.29	 10.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63767	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63768	 1	 1.54	 0.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63769	 1	 14.58	 3.48	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63770	 1	 11.59	 2.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63771	 1	 6.82	 0.84	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63772	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63773	 1	 5.17	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63774	 1	 4.78	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63775	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63776	 1	 3.38	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63777	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63778	 1	 4.51	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63779	 1	 2.12	 0.61	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63780	 1	 1.25	 0.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63781	 1	 8.24	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63782	 1	 4.87	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63783	 1	 6.94	 1.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63784	 1	 52.28	 10.75	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63785	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63786	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63787	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63788	 1	 17.79	 4.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63789	 1	 4.27	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63790	 1	 7.46	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63791	 1	 5.46	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63792	 1	 9.17	 2.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63793	 1	 20.43	 6.23	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63794	 1	 9.8	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63795	 1	 23.86	 5.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63796	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63797	 1	 3.45	 0.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63798	 1	 3.3	 0.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63799	 1	 6.41	 1.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63800	 1	 33.31	 7.07	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63801	 1	 2.01	 0.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63802	 1	 13.12	 2.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63803	 1	 6.36	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63804	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63805	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63806	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63807	 1	 6.37	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63808	 1	 3.38	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63809	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63810	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63811	 1	 1.92	 0.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63812	 1	 7.92	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63813	 1	 6.57	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63814	 1	 3.5	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63815	 1	 6.12	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63816	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63817	 1	 3.22	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63818	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63819	 1	 5.05	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63820	 1	 4.87	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63821	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63822	 1	 41.01	 9.08	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63823	 1	 1.4	 0.42	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63824	 1	 2.4	 0.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63825	 1	 5.8	 0.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63826	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63827	 1	 5.54	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63828	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63829	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63830	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63831	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63832	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63833	 1	 7.36	 -5.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63834	 1	 3.66	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63835	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63836	 1	 4.01	 -4.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63837	 1	 3.2	 -3.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63838	 1	 5.85	 1.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63839	 1	 5.74	 1.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63840	 1	 7.25	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63841	 1	 5.39	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63842	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63843	 1	 10.05	 2.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63844	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63845	 1	 11.24	 2.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63846	 1	 5.66	 1.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63847	 1	 5.79	 1.74	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63848	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63849	 1	 12.5	 3.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63850	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63851	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63852	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63853	 1	 5.39	 1.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63854	 1	 7.87	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63855	 1	 2.36	 0.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63856	 1	 7.28	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63857	 1	 5.04	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63858	 1	 7.78	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63859	 1	 8.06	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63860	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63861	 1	 5.6	 1.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63862	 1	 7.79	 1.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63863	 1	 5.93	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63864	 1	 3.36	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63865	 1	 27.22	 6.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63866	 1	 5.66	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63867	 1	 10.48	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63868	 1	 7.44	 1.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63869	 1	 19.77	 4.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63870	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63871	 1	 3.94	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63872	 1	 53.41	 9.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63873	 1	 52.83	 14.55	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63874	 1	 45.84	 10.34	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63875	 1	 7.13	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63876	 1	 19.34	 2.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63877	 1	 14.57	 3.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63878	 1	 49.53	 13.21	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63879	 1	 5.58	 1.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63880	 1	 13.15	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63881	 1	 45.18	 10.63	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63882	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63883	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63884	 1	 7.99	 2.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63885	 1	 3.79	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63886	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63887	 1	 9.05	 2.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63888	 1	 9.99	 1.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63889	 1	 9.54	 2.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63890	 1	 9.86	 2.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63891	 1	 7.27	 0.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63892	 1	 5.18	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63893	 1	 6.86	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63894	 1	 6.16	 1.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63895	 1	 7.76	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63896	 1	 10.1	 2.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63897	 1	 6.97	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63898	 1	 10.43	 2.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63899	 1	 7.25	 2.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63900	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63901	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63902	 1	 4.4	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63903	 1	 4.67	 0.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63904	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63905	 1	 2.95	 0.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63906	 1	 8.19	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63907	 1	 0.0	 0.0	 0.0	 185.43	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63908	 1	 12.22	 1.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63909	 1	 7.32	 2.01	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63910	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63911	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63912	 1	 6.44	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63913	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63914	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63915	 1	 10.79	 1.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63916	 1	 9.12	 2.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63917	 1	 3.14	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63918	 1	 5.21	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63919	 1	 4.2	 0.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63920	 1	 5.42	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63921	 1	 10.31	 2.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63922	 1	 78.72	 12.88	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63923	 1	 51.96	 8.01	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63924	 1	 4.67	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63925	 1	 4.19	 0.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63926	 1	 0.0	 0.0	 0.0	 16.63	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	63927	 1	 26.88	 4.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63928	 1	 10.78	 2.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63929	 1	 9.03	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63930	 1	 13.3	 3.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63931	 1	 4.01	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63932	 1	 5.3	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63933	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63934	 1	 6.07	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63935	 1	 5.43	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63936	 1	 8.09	 1.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63937	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63938	 1	 7.41	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63939	 1	 5.81	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63940	 1	 6.37	 0.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63941	 1	 4.64	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63942	 1	 7.47	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63943	 1	 8.51	 2.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63944	 1	 6.31	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63945	 1	 9.3	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63946	 1	 3.32	 0.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63947	 1	 8.49	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63948	 1	 13.55	 2.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63949	 1	 8.42	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63950	 1	 5.04	 1.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63951	 1	 13.07	 2.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63952	 1	 13.74	 3.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63953	 1	 2.47	 0.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63954	 1	 6.34	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63955	 1	 2.67	 0.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63956	 1	 3.66	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63957	 1	 15.43	 4.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63958	 1	 8.19	 1.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63959	 1	 7.11	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63960	 1	 11.12	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63961	 1	 11.3	 1.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63962	 1	 6.25	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63963	 1	 15.78	 3.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63964	 1	 6.94	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63965	 1	 5.09	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63966	 1	 6.07	 1.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63967	 1	 4.64	 1.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63968	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63969	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63970	 1	 3.37	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63971	 1	 4.7	 0.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63972	 1	 9.89	 2.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63973	 1	 5.95	 1.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63974	 1	 6.09	 1.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63975	 1	 10.43	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63976	 1	 7.07	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63977	 1	 8.05	 2.04	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63978	 1	 5.97	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63979	 1	 10.07	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63980	 1	 5.15	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63981	 1	 1.73	 0.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63982	 1	 8.07	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63983	 1	 13.37	 3.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63984	 1	 3.61	 0.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63985	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63986	 1	 4.05	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63987	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63988	 1	 5.12	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63989	 1	 41.03	 7.94	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63990	 1	 70.48	 20.08	 0.0	 139.19	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	63991	 1	 3.8	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63992	 1	 8.09	 1.93	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63993	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63994	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63995	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63996	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63997	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63998	 1	 5.33	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	63999	 1	 5.67	 1.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64000	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64001	 1	 4.82	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64002	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64003	 1	 6.08	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64004	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64005	 1	 3.05	 0.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64006	 1	 6.97	 1.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64007	 1	 2.05	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64008	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64009	 1	 3.18	 0.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64010	 1	 4.73	 0.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64011	 1	 4.16	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64012	 1	 2.6	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64013	 1	 6.65	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64014	 1	 3.26	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64015	 1	 3.11	 0.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64016	 1	 7.57	 1.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64017	 1	 3.61	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64018	 1	 7.47	 2.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64019	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64020	 1	 6.13	 1.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64021	 1	 4.64	 0.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64022	 1	 7.32	 1.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64023	 1	 2.32	 0.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64024	 1	 4.44	 0.53	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64025	 1	 4.19	 0.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64026	 1	 3.18	 0.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64027	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64028	 1	 41.09	 5.49	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64029	 1	 4.87	 1.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64030	 1	 5.4	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64031	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64032	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64033	 1	 8.25	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64034	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64035	 1	 8.28	 1.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64036	 1	 6.38	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64037	 1	 4.7	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64038	 1	 7.22	 1.63	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64039	 1	 7.99	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64040	 1	 3.12	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64041	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64042	 1	 13.83	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64043	 1	 1.98	 0.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64044	 1	 6.6	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64045	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64046	 1	 9.61	 1.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64047	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	64048	 1	 8.34	 2.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64049	 1	 3.39	 0.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64050	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64051	 1	 5.73	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64052	 1	 4.58	 0.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64053	 1	 1.46	 0.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64054	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64055	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64056	 1	 2.71	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64057	 1	 7.16	 2.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64058	 1	 5.97	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64059	 1	 14.66	 2.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64060	 1	 1.04	 0.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64061	 1	 3.61	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64062	 1	 10.37	 2.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64063	 1	 3.29	 0.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64064	 1	 1.22	 0.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64065	 1	 9.87	 2.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64066	 1	 4.39	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64067	 1	 4.55	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64068	 1	 6.57	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64069	 1	 1.66	 0.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64070	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64071	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64072	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64073	 1	 2.68	 0.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64074	 1	 5.57	 1.69	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64075	 1	 3.31	 0.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64076	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64077	 1	 9.29	 2.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64078	 1	 8.19	 1.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64079	 1	 71.89	 13.71	 0.0	 106.81	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	64080	 1	 4.01	 0.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64081	 1	 3.73	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64082	 1	 2.84	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64083	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64084	 1	 3.18	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64085	 1	 1.99	 0.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64086	 1	 3.8	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64087	 1	 3.76	 -5.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64088	 1	 3.94	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64089	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64090	 1	 7.32	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64091	 1	 7.52	 1.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64092	 1	 5.95	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64093	 1	 6.78	 2.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64094	 1	 1.33	 0.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64095	 1	 1.76	 0.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64096	 1	 4.43	 1.26	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64097	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64098	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64099	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64100	 1	 17.85	 2.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64101	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64102	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64103	 1	 2.84	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64104	 1	 7.54	 2.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64105	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64106	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64107	 1	 15.29	 4.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64108	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64109	 1	 9.3	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64110	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64111	 1	 11.97	 3.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64112	 1	 4.86	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64113	 1	 5.71	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64114	 1	 4.97	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64115	 1	 4.38	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64116	 1	 0.0	 0.0	 0.0	 -92.99	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	64117	 1	 4.48	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64118	 1	 9.35	 2.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64119	 1	 4.05	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64120	 1	 13.1	 4.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64121	 1	 11.59	 3.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64122	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	64123	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64124	 1	 3.88	 0.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64125	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64126	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64127	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64128	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64129	 1	 37.17	 7.47	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64130	 1	 2.46	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64131	 1	 4.67	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64132	 1	 6.68	 1.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64133	 1	 5.41	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64134	 1	 7.09	 1.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64135	 1	 11.97	 2.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64136	 1	 6.46	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64137	 1	 92.66	 28.03	 0.0	 108.25	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	64138	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64139	 1	 12.35	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64140	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64141	 1	 2.63	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64142	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64143	 1	 6.42	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64144	 1	 17.53	 3.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64145	 1	 4.68	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64146	 1	 3.92	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64147	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64148	 1	 5.28	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64149	 1	 1.84	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64150	 1	 5.26	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64151	 1	 7.17	 0.87	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64152	 1	 6.71	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64153	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64154	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64155	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64156	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64157	 1	 16.65	 4.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64158	 1	 6.77	 1.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64159	 1	 9.76	 2.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64160	 1	 6.19	 1.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64161	 1	 8.06	 2.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64162	 1	 8.11	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64163	 1	 5.24	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64164	 1	 7.98	 1.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64165	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64166	 1	 4.22	 1.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64167	 1	 7.29	 2.09	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64168	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64169	 1	 7.47	 2.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64170	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64171	 1	 5.38	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64172	 1	 4.05	 0.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64173	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64174	 1	 3.72	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64175	 1	 12.65	 2.89	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64176	 1	 25.49	 3.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64177	 1	 6.76	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64178	 1	 6.64	 1.92	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64179	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64180	 1	 7.01	 1.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64181	 1	 8.62	 2.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64182	 1	 3.42	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64183	 1	 6.01	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64184	 1	 2.43	 0.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64185	 1	 10.47	 3.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64186	 1	 3.43	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64187	 1	 4.5	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64188	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64189	 1	 4.34	 0.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64190	 1	 6.45	 1.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64191	 1	 6.78	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64192	 1	 8.92	 2.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64193	 1	 10.58	 3.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64194	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64195	 1	 8.95	 2.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64196	 1	 9.21	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64197	 1	 8.9	 2.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64198	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64199	 1	 3.85	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64200	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64201	 1	 4.69	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64202	 1	 15.01	 2.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64203	 1	 11.37	 3.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64204	 1	 6.39	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64205	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64206	 1	 10.87	 1.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64207	 1	 4.43	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64208	 1	 6.39	 1.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64209	 1	 8.48	 1.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64210	 1	 11.2	 2.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64211	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64212	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64213	 1	 7.45	 1.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64214	 1	 11.22	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64215	 1	 1.42	 0.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64216	 1	 2.62	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64217	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64218	 1	 7.43	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64219	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64220	 1	 11.88	 3.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64221	 1	 5.92	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64222	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64223	 1	 9.25	 1.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64224	 1	 6.51	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64225	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64226	 1	 5.0	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64227	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64228	 1	 10.52	 2.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64229	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64230	 1	 11.05	 2.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64231	 1	 10.41	 1.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64232	 1	 11.33	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64233	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64234	 1	 13.88	 1.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64235	 1	 5.6	 1.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64236	 1	 1.45	 0.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64237	 1	 1.13	 0.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64238	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64239	 1	 6.61	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64240	 1	 9.73	 2.31	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64241	 1	 3.63	 0.63	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64242	 1	 3.49	 0.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64243	 1	 87.78	 20.68	 0.0	 200.0	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	64244	 1	 4.21	 0.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64245	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64246	 1	 5.44	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64247	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64248	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64249	 1	 3.56	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64250	 1	 1.81	 0.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64251	 1	 10.92	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64252	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64253	 1	 7.46	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64254	 1	 10.36	 2.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64255	 1	 3.86	 0.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64256	 1	 3.23	 0.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64257	 1	 12.25	 2.48	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64258	 1	 15.28	 3.41	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64259	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64260	 1	 5.32	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64261	 1	 1.94	 0.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64262	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64263	 1	 15.35	 3.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64264	 1	 4.16	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64265	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64266	 1	 4.08	 0.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64267	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64268	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64269	 1	 2.44	 0.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64270	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64271	 1	 0.0	 0.0	 0.0	 136.06	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	64272	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64273	 1	 13.15	 3.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64274	 1	 11.63	 2.53	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64275	 1	 1.98	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64276	 1	 9.24	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64277	 1	 8.0	 1.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64278	 1	 6.53	 0.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64279	 1	 3.08	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64280	 1	 5.23	 1.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64281	 1	 8.67	 2.57	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64282	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64283	 1	 7.13	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64284	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64285	 1	 5.49	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64286	 1	 4.46	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64287	 1	 5.06	 1.5	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64288	 1	 13.05	 3.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64289	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64290	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64291	 1	 8.36	 1.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64292	 1	 52.75	 8.63	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64293	 1	 13.6	 4.04	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64294	 1	 7.83	 1.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64295	 1	 4.26	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64296	 1	 6.9	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64297	 1	 4.35	 0.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64298	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64299	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64300	 1	 5.83	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64301	 1	 10.24	 2.55	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64302	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64303	 1	 15.12	 4.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64304	 1	 14.72	 3.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64305	 1	 12.15	 1.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64306	 1	 4.15	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64307	 1	 4.65	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64308	 1	 7.23	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64309	 1	 17.58	 2.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64310	 1	 3.97	 1.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64311	 1	 11.33	 2.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64312	 1	 3.79	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64313	 1	 8.54	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64314	 1	 5.41	 1.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64315	 1	 6.0	 1.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64316	 1	 3.96	 1.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64317	 1	 5.21	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64318	 1	 3.45	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64319	 1	 13.44	 3.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64320	 1	 2.56	 0.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64321	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64322	 1	 5.35	 1.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64323	 1	 3.36	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64324	 1	 7.69	 1.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64325	 1	 11.57	 3.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64326	 1	 2.18	 0.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64327	 1	 7.39	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64328	 1	 5.66	 0.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64329	 1	 4.69	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64330	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64331	 1	 8.22	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64332	 1	 10.16	 2.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64333	 1	 6.06	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64334	 1	 4.21	 1.04	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64335	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64336	 1	 3.43	 0.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64337	 1	 2.64	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64338	 1	 9.07	 2.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64339	 1	 3.77	 0.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64340	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64341	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64342	 1	 4.35	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64343	 1	 5.21	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64344	 1	 4.0	 0.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64345	 1	 4.24	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64346	 1	 7.76	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64347	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64348	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64349	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64350	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64351	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64352	 1	 4.52	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64353	 1	 7.41	 2.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64354	 1	 4.91	 0.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64355	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64356	 1	 6.11	 1.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64357	 1	 5.02	 1.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64358	 1	 3.11	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64359	 1	 3.65	 0.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64360	 1	 3.08	 0.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64361	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64362	 1	 6.5	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64363	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64364	 1	 7.6	 2.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64365	 1	 7.66	 1.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64366	 1	 5.17	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64367	 1	 5.75	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64368	 1	 5.67	 1.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64369	 1	 3.52	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64370	 1	 8.84	 2.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64371	 1	 3.45	 0.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64372	 1	 11.68	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64373	 1	 6.98	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64374	 1	 3.99	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64375	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64376	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64377	 1	 3.01	 0.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64378	 1	 3.15	 0.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64379	 1	 7.76	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64380	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64381	 1	 8.12	 1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64382	 1	 5.0	 0.68	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64383	 1	 10.11	 3.25	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64384	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	64385	 1	 7.6	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64386	 1	 15.44	 3.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64387	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64388	 1	 4.89	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64389	 1	 6.84	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64390	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64391	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64392	 1	 4.79	 0.56	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64393	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64394	 1	 22.24	 6.54	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64395	 1	 13.66	 4.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64396	 1	 2.16	 0.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64397	 1	 3.91	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64398	 1	 0.0	 0.0	 0.0	 107.45	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	64399	 1	 1.57	 0.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64400	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64401	 1	 6.03	 0.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64402	 1	 3.08	 0.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64403	 1	 4.04	 1.02	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64404	 1	 6.57	 1.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64405	 1	 7.13	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64406	 1	 3.14	 0.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64407	 1	 7.06	 1.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64408	 1	 6.07	 1.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64409	 1	 15.32	 4.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64410	 1	 3.88	 0.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64411	 1	 13.07	 3.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64412	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64413	 1	 7.95	 2.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64414	 1	 4.56	 0.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64415	 1	 8.61	 2.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64416	 1	 5.37	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64417	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64418	 1	 5.14	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64419	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64420	 1	 4.22	 0.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64421	 1	 6.48	 1.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64422	 1	 3.44	 0.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64423	 1	 5.7	 1.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64424	 1	 3.71	 0.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64425	 1	 2.17	 0.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64426	 1	 10.39	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64427	 1	 5.93	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64428	 1	 7.49	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64429	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64430	 1	 3.54	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64431	 1	 12.91	 3.72	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64432	 1	 17.96	 3.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64433	 1	 7.2	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64434	 1	 6.67	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64435	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64436	 1	 3.11	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64437	 1	 3.17	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64438	 1	 4.35	 0.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64439	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64440	 1	 10.44	 3.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64441	 1	 5.79	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64442	 1	 3.57	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64443	 1	 0.0	 0.0	 0.0	 47.59	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	64444	 1	 8.55	 2.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64445	 1	 10.78	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64446	 1	 4.73	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64447	 1	 7.13	 1.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64448	 1	 12.78	 2.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64449	 1	 9.14	 1.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64450	 1	 8.19	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64451	 1	 4.23	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64452	 1	 4.98	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64453	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64454	 1	 5.02	 1.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64455	 1	 2.14	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64456	 1	 6.04	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64457	 1	 4.96	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64458	 1	 1.72	 0.47	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64459	 1	 4.23	 0.79	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64460	 1	 18.36	 3.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64461	 1	 12.45	 3.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64462	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64463	 1	 6.94	 1.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64464	 1	 8.26	 2.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64465	 1	 10.62	 -6.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64466	 1	 10.03	 2.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64467	 1	 0.08	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64468	 1	 4.11	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64469	 1	 2.77	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64470	 1	 3.9	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64471	 1	 2.63	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64472	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64473	 1	 10.89	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64474	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64475	 1	 4.32	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64476	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64477	 1	 4.46	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64478	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64479	 1	 26.75	 5.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64480	 1	 6.63	 1.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64481	 1	 9.61	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64482	 1	 4.05	 0.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64483	 1	 6.76	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64484	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64485	 1	 5.12	 1.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64486	 1	 4.45	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64487	 1	 8.05	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64488	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64489	 1	 57.35	 12.26	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64490	 1	 54.23	 14.36	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64491	 1	 5.14	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64492	 1	 11.15	 3.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64493	 1	 10.82	 2.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64494	 1	 4.84	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64495	 1	 2.6	 0.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64496	 1	 14.72	 4.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64497	 1	 4.79	 0.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64498	 1	 6.4	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64499	 1	 8.84	 2.48	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64500	 1	 4.07	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64501	 1	 16.13	 2.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64502	 1	 31.46	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64503	 1	 19.58	 4.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64504	 1	 6.11	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64505	 1	 6.23	 1.11	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64506	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64507	 1	 6.34	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64508	 1	 10.42	 2.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64509	 1	 7.42	 1.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64510	 1	 8.56	 2.28	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64511	 1	 0.88	 0.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64512	 1	 7.82	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64513	 1	 7.38	 1.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64514	 1	 12.86	 3.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64515	 1	 6.42	 1.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64516	 1	 1.42	 0.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64517	 1	 3.12	 0.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64518	 1	 4.38	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64519	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64520	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64521	 1	 5.79	 1.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64522	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64523	 1	 7.8	 1.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64524	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64525	 1	 6.5	 1.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64526	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64527	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64528	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64529	 1	 3.34	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64530	 1	 5.69	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64531	 1	 4.96	 0.79	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64532	 1	 6.03	 1.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64533	 1	 3.99	 0.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64534	 1	 9.07	 2.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64535	 1	 13.33	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64536	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64537	 1	 5.92	 1.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64538	 1	 41.92	 10.16	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64539	 1	 15.02	 -5.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64540	 1	 1.61	 0.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64541	 1	 4.86	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64542	 1	 4.54	 0.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64543	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64544	 1	 10.49	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64545	 1	 10.59	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64546	 1	 9.62	 2.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64547	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64548	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64549	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64550	 1	 3.17	 0.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64551	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64552	 1	 2.4	 0.58	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64553	 1	 2.6	 0.72	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64554	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64555	 1	 7.77	 2.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64556	 1	 12.3	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64557	 1	 3.94	 1.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64558	 1	 7.18	 1.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64559	 1	 7.75	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64560	 1	 8.39	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64561	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64562	 1	 6.96	 1.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64563	 1	 7.09	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64564	 1	 7.83	 1.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64565	 1	 4.2	 0.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64566	 1	 2.33	 0.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64567	 1	 2.5	 0.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64568	 1	 3.17	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64569	 1	 11.89	 2.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64570	 1	 2.53	 0.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64571	 1	 5.43	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64572	 1	 11.7	 3.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64573	 1	 0.66	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64574	 1	 6.16	 1.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64575	 1	 2.62	 0.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64576	 1	 4.87	 1.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64577	 1	 5.01	 1.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64578	 1	 3.87	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64579	 1	 1.78	 0.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64580	 1	 3.29	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64581	 1	 1.66	 0.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64582	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64583	 1	 1.85	 0.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64584	 1	 1.91	 0.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64585	 1	 5.64	 1.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64586	 1	 3.14	 0.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64587	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64588	 1	 5.28	 0.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64589	 1	 1.64	 0.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64590	 1	 4.42	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64591	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64592	 1	 7.42	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64593	 1	 5.37	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64594	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64595	 1	 6.86	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64596	 1	 13.7	 3.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64597	 1	 5.0	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64598	 1	 3.16	 0.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64599	 1	 3.16	 0.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64600	 1	 20.32	 5.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64601	 1	 3.32	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64602	 1	 2.22	 0.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64603	 1	 2.12	 0.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64604	 1	 3.44	 1.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64605	 1	 3.82	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64606	 1	 2.15	 0.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64607	 1	 2.55	 0.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64608	 1	 2.5	 0.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64609	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64610	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64611	 1	 4.5	 1.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64612	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64613	 1	 3.31	 0.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64614	 1	 3.75	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64615	 1	 4.16	 0.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64616	 1	 8.74	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64617	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64618	 1	 88.45	 17.59	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64619	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64620	 1	 13.28	 3.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64621	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64622	 1	 4.03	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64623	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64624	 1	 2.65	 0.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64625	 1	 4.92	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64626	 1	 6.15	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64627	 1	 6.69	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64628	 1	 4.33	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64629	 1	 5.61	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64630	 1	 6.5	 1.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64631	 1	 5.31	 1.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64632	 1	 5.88	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64633	 1	 5.06	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64634	 1	 0.8	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64635	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64636	 1	 1.58	 0.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64637	 1	 3.68	 0.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64638	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64639	 1	 5.59	 1.45	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64640	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64641	 1	 12.0	 2.89	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64642	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64643	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64644	 1	 6.0	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64645	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64646	 1	 6.75	 1.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64647	 1	 5.62	 1.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64648	 1	 4.49	 1.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64649	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64650	 1	 0.72	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64651	 1	 7.09	 0.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64652	 1	 8.13	 2.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64653	 1	 13.98	 4.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64654	 1	 3.07	 0.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64655	 1	 1.59	 0.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64656	 1	 2.69	 0.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64657	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64658	 1	 3.07	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64659	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64660	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64661	 1	 20.62	 -3.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64662	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64663	 1	 0.56	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64664	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64665	 1	 15.98	 3.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64666	 1	 4.09	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64667	 1	 5.04	 0.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64668	 1	 9.53	 1.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64669	 1	 10.91	 2.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64670	 1	 7.12	 1.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64671	 1	 4.85	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64672	 1	 6.21	 0.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64673	 1	 2.37	 0.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64674	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64675	 1	 2.29	 0.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64676	 1	 3.22	 0.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64677	 1	 4.92	 -7.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64678	 1	 2.05	 0.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64679	 1	 1.74	 0.48	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64680	 1	 4.69	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64681	 1	 3.24	 0.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64682	 1	 3.71	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64683	 1	 3.13	 0.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64684	 1	 2.99	 0.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64685	 1	 2.58	 0.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64686	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64687	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64688	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64689	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	64690	 1	 6.92	 1.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64691	 1	 14.47	 3.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64692	 1	 16.88	 4.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64693	 1	 12.32	 3.62	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64694	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64695	 1	 7.2	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64696	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64697	 1	 13.01	 2.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64698	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64699	 1	 1.65	 0.44	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64700	 1	 2.48	 0.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64701	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64702	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64703	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64704	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64705	 1	 0.28	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64706	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64707	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64708	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64709	 1	 0.98	 0.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64710	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64711	 1	 0.58	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64712	 1	 0.76	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64713	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	64714	 1	 4.65	 1.27	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64715	 1	 0.87	 0.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64716	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64717	 1	 12.5	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64718	 1	 43.55	 5.86	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64719	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64720	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64721	 1	 8.47	 2.49	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64722	 1	 3.81	 0.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64723	 1	 2.66	 0.34	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64724	 1	 4.14	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64725	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64726	 1	 1.15	 0.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64727	 1	 12.66	 3.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64728	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64729	 1	 32.87	 7.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64730	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64731	 1	 38.64	 10.74	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64732	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64733	 1	 10.93	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64734	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64735	 1	 37.05	 8.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64736	 1	 1.22	 0.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64737	 1	 68.23	 25.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64738	 1	 0.0	 0.0	 0.0	 36.26	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	64739	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64740	 1	 4.32	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64741	 1	 6.03	 1.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64742	 1	 4.35	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64743	 1	 5.09	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64744	 1	 3.31	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64745	 1	 3.22	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64746	 1	 4.13	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64747	 1	 7.38	 2.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64748	 1	 4.2	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64749	 1	 8.91	 2.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64750	 1	 4.03	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64751	 1	 2.92	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64752	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64753	 1	 2.01	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64754	 1	 4.22	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64755	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64756	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64757	 1	 4.34	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64758	 1	 4.5	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64759	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64760	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	64761	 1	 3.6	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64762	 1	 1.87	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64763	 1	 3.22	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64764	 1	 2.51	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64765	 1	 2.84	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64766	 1	 1.67	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64767	 1	 2.22	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64768	 1	 1.96	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64769	 1	 2.76	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64770	 1	 2.37	 0.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64771	 1	 2.63	 0.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64772	 1	 8.14	 2.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64773	 1	 2.87	 0.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64774	 1	 2.76	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64775	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64776	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64777	 1	 1.55	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64778	 1	 4.29	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64779	 1	 5.17	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64780	 1	 4.21	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64781	 1	 4.25	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64782	 1	 3.36	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64783	 1	 5.32	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64784	 1	 3.97	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64785	 1	 3.22	 0.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64786	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64787	 1	 1.56	 0.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64788	 1	 5.37	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64789	 1	 2.32	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64790	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64791	 1	 6.74	 2.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64792	 1	 2.91	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64793	 1	 3.23	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64794	 1	 2.76	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64795	 1	 2.2	 0.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64796	 1	 1.34	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64797	 1	 3.88	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64798	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64799	 1	 3.63	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64800	 1	 3.38	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64801	 1	 3.63	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64802	 1	 2.13	 0.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64803	 1	 1.98	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64804	 1	 2.42	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64805	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64806	 1	 5.89	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64807	 1	 2.33	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64808	 1	 5.08	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64809	 1	 5.33	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64810	 1	 3.88	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64811	 1	 11.93	 2.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64812	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64813	 1	 4.3	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64814	 1	 3.98	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64815	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64816	 1	 3.01	 0.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64817	 1	 9.38	 3.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64818	 1	 2.21	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64819	 1	 3.51	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64820	 1	 5.16	 1.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64821	 1	 3.24	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64822	 1	 3.4	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64823	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64824	 1	 3.37	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64825	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64826	 1	 2.86	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64827	 1	 8.17	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64828	 1	 1.67	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64829	 1	 1.08	 0.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64830	 1	 4.16	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64831	 1	 2.87	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64832	 1	 2.11	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64833	 1	 2.16	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64834	 1	 2.35	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64835	 1	 2.94	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64836	 1	 4.33	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64837	 1	 5.01	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64838	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64839	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64840	 1	 1.18	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64841	 1	 2.23	 0.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64842	 1	 2.11	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64843	 1	 2.08	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64844	 1	 2.63	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64845	 1	 3.06	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64846	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64847	 1	 2.58	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64848	 1	 4.41	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64849	 1	 3.83	 1.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64850	 1	 4.95	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64851	 1	 1.84	 0.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64852	 1	 2.64	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64853	 1	 4.43	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64854	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64855	 1	 2.64	 0.47	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64856	 1	 4.29	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64857	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64858	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64859	 1	 3.36	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64860	 1	 6.24	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64861	 1	 12.64	 4.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64862	 1	 3.36	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64863	 1	 4.38	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64864	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64865	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64866	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64867	 1	 1.74	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64868	 1	 3.18	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64869	 1	 3.34	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64870	 1	 2.95	 0.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64871	 1	 1.5	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64872	 1	 2.53	 0.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64873	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64874	 1	 3.44	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64875	 1	 2.15	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64876	 1	 1.59	 0.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64877	 1	 3.22	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64878	 1	 3.59	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64879	 1	 3.37	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64880	 1	 3.63	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64881	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64882	 1	 2.06	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64883	 1	 3.03	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64884	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64885	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64886	 1	 1.39	 0.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64887	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64888	 1	 3.02	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64889	 1	 0.0	 0.0	 0.0	 -1.36	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	64890	 1	 3.8	 -1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64891	 1	 2.42	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64892	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64893	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64894	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64895	 1	 1.18	 0.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64896	 1	 2.71	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64897	 1	 4.01	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64898	 1	 5.43	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64899	 1	 4.52	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64900	 1	 2.26	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64901	 1	 1.86	 0.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64902	 1	 3.23	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64903	 1	 4.54	 1.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64904	 1	 3.0	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64905	 1	 5.07	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64906	 1	 3.68	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64907	 1	 2.89	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64908	 1	 4.07	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64909	 1	 5.39	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64910	 1	 3.46	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64911	 1	 2.7	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64912	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64913	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64914	 1	 2.74	 0.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64915	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64916	 1	 3.84	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64917	 1	 2.85	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64918	 1	 3.31	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64919	 1	 4.24	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64920	 1	 2.11	 0.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64921	 1	 1.78	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64922	 1	 2.18	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64923	 1	 1.63	 0.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64924	 1	 1.42	 0.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64925	 1	 3.49	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64926	 1	 3.9	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64927	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64928	 1	 4.42	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64929	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64930	 1	 2.17	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64931	 1	 1.67	 0.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64932	 1	 4.26	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64933	 1	 2.89	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64934	 1	 1.51	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64935	 1	 4.46	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64936	 1	 5.76	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64937	 1	 3.83	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64938	 1	 2.66	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64939	 1	 2.9	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64940	 1	 2.17	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64941	 1	 3.45	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64942	 1	 2.67	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64943	 1	 3.87	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64944	 1	 2.61	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64945	 1	 4.43	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64946	 1	 2.72	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64947	 1	 1.31	 0.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64948	 1	 3.66	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64949	 1	 2.93	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64950	 1	 3.76	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64951	 1	 3.45	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64952	 1	 2.64	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64953	 1	 2.12	 0.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64954	 1	 2.48	 0.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64955	 1	 3.64	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64956	 1	 1.68	 0.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64957	 1	 3.93	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64958	 1	 2.58	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64959	 1	 2.46	 0.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64960	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64961	 1	 2.44	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64962	 1	 2.04	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64963	 1	 4.31	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64964	 1	 4.13	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64965	 1	 2.93	 0.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64966	 1	 4.55	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64967	 1	 2.12	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64968	 1	 2.84	 0.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64969	 1	 3.44	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64970	 1	 2.4	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64971	 1	 2.86	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64972	 1	 2.19	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64973	 1	 4.77	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64974	 1	 3.03	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64975	 1	 4.8	 1.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64976	 1	 2.24	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64977	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	64978	 1	 4.18	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64979	 1	 3.94	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64980	 1	 1.86	 0.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64981	 1	 4.18	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64982	 1	 3.72	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64983	 1	 6.98	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64984	 1	 3.57	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64985	 1	 3.22	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64986	 1	 5.1	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64987	 1	 1.97	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64988	 1	 6.41	 1.44	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64989	 1	 3.05	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64990	 1	 3.83	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64991	 1	 5.22	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64992	 1	 3.18	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64993	 1	 3.24	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64994	 1	 4.51	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64995	 1	 5.16	 1.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64996	 1	 2.5	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64997	 1	 2.85	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64998	 1	 2.02	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	64999	 1	 4.32	 1.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65000	 1	 1.83	 0.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65001	 1	 2.4	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65002	 1	 2.1	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65003	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65004	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65005	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65006	 1	 4.94	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65007	 1	 5.55	 2.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65008	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65009	 1	 7.02	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65010	 1	 5.65	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65011	 1	 6.1	 1.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65012	 1	 2.61	 0.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65013	 1	 3.66	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65014	 1	 2.19	 0.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65015	 1	 4.82	 1.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65016	 1	 4.29	 1.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65017	 1	 4.18	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65018	 1	 4.9	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65019	 1	 0.0	 0.0	 0.0	 -262.06	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65020	 1	 3.45	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65021	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65022	 1	 4.63	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65023	 1	 4.77	 1.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65024	 1	 3.09	 0.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65025	 1	 2.06	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65026	 1	 2.91	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65027	 1	 3.03	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65028	 1	 4.07	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65029	 1	 1.91	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65030	 1	 3.14	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65031	 1	 2.24	 0.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65032	 1	 2.68	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65033	 1	 4.44	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65034	 1	 3.93	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65035	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65036	 1	 3.69	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65037	 1	 3.29	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65038	 1	 17.11	 6.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65039	 1	 5.41	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65040	 1	 3.06	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65041	 1	 4.46	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65042	 1	 4.08	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65043	 1	 1.4	 0.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65044	 1	 3.04	 0.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65045	 1	 2.65	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65046	 1	 15.97	 4.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65047	 1	 3.5	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65048	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65049	 1	 7.82	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65050	 1	 5.64	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65051	 1	 2.21	 0.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65052	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65053	 1	 4.63	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65054	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65055	 1	 3.51	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65056	 1	 4.85	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65057	 1	 5.53	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65058	 1	 2.4	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65059	 1	 2.45	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65060	 1	 2.69	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65061	 1	 2.26	 0.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65062	 1	 3.08	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65063	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65064	 1	 1.92	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65065	 1	 2.34	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65066	 1	 2.07	 0.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65067	 1	 2.27	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65068	 1	 2.99	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65069	 1	 3.35	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65070	 1	 4.42	 1.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65071	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65072	 1	 3.16	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65073	 1	 3.09	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65074	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65075	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65076	 1	 2.83	 1.13	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65077	 1	 3.48	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65078	 1	 1.83	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65079	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65080	 1	 2.57	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65081	 1	 2.08	 0.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65082	 1	 9.07	 -3.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65083	 1	 3.83	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65084	 1	 8.72	 2.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65085	 1	 4.35	 1.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65086	 1	 3.2	 1.22	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65087	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65088	 1	 3.41	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65089	 1	 4.07	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65090	 1	 2.53	 0.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65091	 1	 0.0	 0.0	 0.0	 67.03	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65092	 1	 2.15	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65093	 1	 3.09	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65094	 1	 2.82	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65095	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65096	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65097	 1	 1.95	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65098	 1	 2.01	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65099	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65100	 1	 1.95	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65101	 1	 3.69	 1.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65102	 1	 3.61	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65103	 1	 4.5	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65104	 1	 2.33	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65105	 1	 2.13	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65106	 1	 2.01	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65107	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65108	 1	 1.53	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65109	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65110	 1	 3.84	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65111	 1	 2.92	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65112	 1	 2.17	 0.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65113	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65114	 1	 1.72	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65115	 1	 2.3	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65116	 1	 3.97	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65117	 1	 3.67	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65118	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65119	 1	 3.57	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65120	 1	 3.43	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65121	 1	 2.4	 0.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65122	 1	 3.62	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65123	 1	 2.29	 0.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65124	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65125	 1	 3.69	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65126	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65127	 1	 2.33	 0.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65128	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65129	 1	 2.2	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65130	 1	 5.09	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65131	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65132	 1	 2.66	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65133	 1	 3.44	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65134	 1	 3.8	 1.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65135	 1	 4.49	 1.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65136	 1	 3.42	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65137	 1	 3.51	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65138	 1	 2.9	 0.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65139	 1	 8.59	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65140	 1	 5.05	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65141	 1	 3.35	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65142	 1	 3.02	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65143	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65144	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65145	 1	 4.72	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65146	 1	 2.47	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65147	 1	 0.0	 0.0	 0.0	 200.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65148	 1	 1.29	 0.52	 0.0	 -20.33	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65149	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	65150	 1	 1.55	 0.51	 0.0	 -59.37	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65151	 1	 0.0	 0.0	 0.0	 9.03	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65152	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65153	 1	 0.0	 0.0	 0.0	 100.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65154	 1	 1.54	 0.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65155	 1	 4.93	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65156	 1	 5.08	 1.51	 0.0	 -78.28	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65157	 1	 8.14	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65158	 1	 0.0	 0.0	 0.0	 -18.51	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65159	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65160	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65161	 1	 2.61	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65162	 1	 3.8	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65163	 1	 3.46	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65164	 1	 2.57	 0.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65165	 1	 2.94	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65166	 1	 3.12	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65167	 1	 3.09	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65168	 1	 3.47	 0.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65169	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65170	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65171	 1	 2.59	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65172	 1	 4.56	 1.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65173	 1	 2.53	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65174	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65175	 1	 4.09	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65176	 1	 3.43	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65177	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65178	 1	 4.89	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65179	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65180	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65181	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65182	 1	 2.13	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65183	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65184	 1	 2.89	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65185	 1	 2.75	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65186	 1	 2.69	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65187	 1	 2.92	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65188	 1	 4.07	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65189	 1	 4.36	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65190	 1	 6.22	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65191	 1	 3.75	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65192	 1	 1.31	 0.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65193	 1	 2.2	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65194	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65195	 1	 3.06	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65196	 1	 3.33	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65197	 1	 2.05	 0.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65198	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65199	 1	 2.7	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65200	 1	 2.95	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65201	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65202	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65203	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65204	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65205	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65206	 1	 2.38	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65207	 1	 25.04	 9.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65208	 1	 1.57	 0.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65209	 1	 1.89	 0.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65210	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65211	 1	 42.97	 13.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65212	 1	 2.75	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65213	 1	 4.44	 1.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65214	 1	 4.01	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65215	 1	 2.96	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65216	 1	 2.0	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65217	 1	 3.42	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65218	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65219	 1	 20.57	 3.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65220	 1	 3.84	 1.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65221	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65222	 1	 3.53	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65223	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65224	 1	 7.82	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65225	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65226	 1	 7.19	 1.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65227	 1	 9.12	 2.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65228	 1	 3.09	 0.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65229	 1	 6.45	 2.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65230	 1	 5.59	 1.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65231	 1	 11.64	 3.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65232	 1	 7.39	 1.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65233	 1	 3.45	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65234	 1	 11.74	 4.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65235	 1	 1.19	 0.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65236	 1	 3.48	 1.12	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65237	 1	 1.64	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65238	 1	 58.13	 17.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65239	 1	 32.53	 7.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65240	 1	 2.79	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65241	 1	 1.65	 0.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65242	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65243	 1	 5.71	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65244	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65245	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65246	 1	 10.84	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65247	 1	 6.73	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65248	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65249	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65250	 1	 42.25	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65251	 1	 33.58	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65252	 1	 6.13	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65253	 1	 31.84	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65254	 1	 7.24	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65255	 1	 5.68	 -3.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65256	 1	 5.38	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65257	 1	 0.0	 0.0	 0.0	 -178.38	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65258	 1	 162.27	 40.32	 0.0	 34.91	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65259	 1	 31.76	 9.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65260	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65261	 1	 2.58	 0.79	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65262	 1	 68.99	 23.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65263	 1	 0.0	 0.0	 0.0	 -252.05	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	65264	 1	 20.47	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65265	 1	 37.58	 12.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65266	 1	 11.02	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65267	 1	 0.0	 0.0	 0.0	 293.59	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	65268	 1	 7.57	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65269	 1	 32.88	 10.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65270	 1	 0.0	 0.0	 0.0	 100.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65271	 1	 26.0	 9.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65272	 1	 55.32	 16.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65273	 1	 38.31	 10.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65274	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65275	 1	 0.0	 0.0	 0.0	 130.04	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	65276	 1	 1.6	 0.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65277	 1	 39.95	 -3.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65278	 1	 53.22	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65279	 1	 0.0	 0.0	 0.0	 -217.43	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65280	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65281	 1	 9.8	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65282	 1	 3.94	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65283	 1	 9.43	 1.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65284	 1	 3.69	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65285	 1	 6.73	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65286	 1	 33.21	 11.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65287	 1	 56.59	 8.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65288	 1	 133.47	 33.84	 0.0	 300.0	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	65289	 1	 7.76	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65290	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65291	 1	 4.4	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65292	 1	 3.79	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65293	 1	 3.81	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65294	 1	 4.67	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65295	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65296	 1	 7.99	 2.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65297	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65298	 1	 3.95	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65299	 1	 3.75	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65300	 1	 2.36	 0.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65301	 1	 2.72	 -6.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65302	 1	 5.73	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65303	 1	 4.73	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65304	 1	 2.12	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65305	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65306	 1	 2.19	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65307	 1	 4.06	 1.02	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65308	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65309	 1	 2.74	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65310	 1	 3.2	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65311	 1	 3.69	 0.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65312	 1	 4.18	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65313	 1	 2.6	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65314	 1	 4.37	 1.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65315	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65316	 1	 2.49	 0.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65317	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65318	 1	 2.75	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65319	 1	 2.88	 0.46	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65320	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65321	 1	 4.73	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65322	 1	 2.15	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65323	 1	 2.48	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65324	 1	 3.96	 0.93	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65325	 1	 2.78	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65326	 1	 10.82	 3.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65327	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65328	 1	 14.97	 5.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65329	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65330	 1	 3.93	 1.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65331	 1	 3.55	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65332	 1	 4.41	 -8.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65333	 1	 1.77	 0.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65334	 1	 10.62	 2.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65335	 1	 3.72	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65336	 1	 3.4	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65337	 1	 8.3	 2.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65338	 1	 2.72	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65339	 1	 3.7	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65340	 1	 3.29	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65341	 1	 2.41	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65342	 1	 3.4	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65343	 1	 3.09	 0.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65344	 1	 3.55	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65345	 1	 1.89	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65346	 1	 3.65	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65347	 1	 2.28	 0.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65348	 1	 17.96	 5.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65349	 1	 5.44	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65350	 1	 3.8	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65351	 1	 3.77	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65352	 1	 3.17	 1.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65353	 1	 2.72	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65354	 1	 3.32	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65355	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65356	 1	 4.71	 1.23	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65357	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65358	 1	 2.43	 0.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65359	 1	 3.65	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65360	 1	 3.77	 1.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65361	 1	 3.59	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65362	 1	 3.37	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65363	 1	 4.84	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65364	 1	 3.83	 1.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65365	 1	 2.59	 0.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65366	 1	 4.21	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65367	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65368	 1	 0.0	 0.0	 0.0	 200.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65369	 1	 1.56	 0.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65370	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65371	 1	 2.82	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65372	 1	 3.78	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65373	 1	 4.34	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65374	 1	 4.13	 -5.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65375	 1	 3.32	 0.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65376	 1	 2.67	 0.42	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65377	 1	 0.91	 0.36	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65378	 1	 3.13	 1.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65379	 1	 1.91	 0.6	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65380	 1	 2.89	 0.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65381	 1	 27.16	 2.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65382	 1	 3.43	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65383	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65384	 1	 3.07	 0.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65385	 1	 2.81	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65386	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65387	 1	 2.57	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65388	 1	 3.8	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65389	 1	 3.18	 1.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65390	 1	 1.94	 0.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65391	 1	 2.08	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65392	 1	 4.4	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65393	 1	 1.62	 0.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65394	 1	 37.94	 8.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65395	 1	 48.28	 17.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65396	 1	 0.01	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65397	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65398	 1	 30.96	 -3.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65399	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65400	 1	 16.84	 4.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65401	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65402	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65403	 1	 0.0	 0.0	 0.0	 56.87	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65404	 1	 16.17	 5.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65405	 1	 7.89	 2.04	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65406	 1	 31.15	 8.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65407	 1	 8.38	 2.89	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65408	 1	 3.15	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65409	 1	 6.18	 2.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65410	 1	 41.43	 16.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65411	 1	 3.61	 1.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65412	 1	 0.0	 0.0	 0.0	 107.94	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65413	 1	 3.05	 0.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65414	 1	 7.24	 1.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65415	 1	 4.13	 0.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65416	 1	 5.75	 0.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65417	 1	 3.88	 0.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65418	 1	 2.34	 0.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65419	 1	 6.83	 1.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65420	 1	 5.86	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65421	 1	 5.01	 1.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65422	 1	 4.5	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65423	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65424	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65425	 1	 2.89	 0.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65426	 1	 3.41	 0.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65427	 1	 19.69	 4.27	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65428	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65429	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65430	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65431	 1	 5.65	 1.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65432	 1	 4.66	 0.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65433	 1	 6.14	 1.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65434	 1	 4.66	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65435	 1	 6.61	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65436	 1	 4.36	 1.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65437	 1	 6.68	 1.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65438	 1	 4.92	 0.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65439	 1	 4.49	 0.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65440	 1	 7.39	 1.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65441	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65442	 1	 14.28	 3.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65443	 1	 7.29	 1.12	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65444	 1	 7.53	 1.96	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65445	 1	 8.99	 1.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65446	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65447	 1	 10.3	 1.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65448	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65449	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65450	 1	 10.26	 1.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65451	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65452	 1	 15.94	 3.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65453	 1	 6.74	 1.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65454	 1	 5.1	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65455	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65456	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65457	 1	 15.03	 3.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65458	 1	 23.07	 5.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65459	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65460	 1	 17.34	 4.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65461	 1	 7.22	 0.89	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65462	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65463	 1	 3.5	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65464	 1	 0.0	 0.0	 0.0	 39.69	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65465	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65466	 1	 6.43	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65467	 1	 6.82	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65468	 1	 6.45	 1.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65469	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65470	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65471	 1	 3.35	 0.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65472	 1	 9.25	 2.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65473	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65474	 1	 7.89	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65475	 1	 12.41	 1.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65476	 1	 7.16	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65477	 1	 13.62	 2.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65478	 1	 24.06	 7.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65479	 1	 1.85	 0.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65480	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65481	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65482	 1	 8.79	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65483	 1	 4.96	 0.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65484	 1	 4.1	 0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65485	 1	 7.02	 1.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65486	 1	 10.61	 2.66	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65487	 1	 100.58	 29.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65488	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65489	 1	 9.96	 1.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65490	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65491	 1	 8.48	 1.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65492	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65493	 1	 10.79	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65494	 1	 5.17	 0.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65495	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65496	 1	 4.7	 0.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65497	 1	 7.48	 0.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65498	 1	 8.28	 1.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65499	 1	 12.86	 2.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65500	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65501	 1	 5.9	 0.82	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65502	 1	 7.31	 1.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65503	 1	 3.5	 0.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65504	 1	 7.2	 1.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65505	 1	 3.48	 0.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65506	 1	 5.51	 0.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65507	 1	 4.55	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65508	 1	 10.18	 2.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65509	 1	 15.4	 4.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65510	 1	 64.13	 19.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65511	 1	 0.0	 0.0	 0.0	 120.39	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65512	 1	 3.13	 0.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65513	 1	 5.49	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65514	 1	 3.57	 0.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65515	 1	 6.56	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65516	 1	 4.55	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65517	 1	 5.04	 1.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65518	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65519	 1	 145.53	 28.33	 0.0	 -3.35	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	65520	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65521	 1	 5.53	 1.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65522	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65523	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65524	 1	 5.25	 1.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65525	 1	 6.6	 1.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65526	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65527	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65528	 1	 9.89	 2.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65529	 1	 9.51	 1.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65530	 1	 8.89	 1.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65531	 1	 6.5	 1.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65532	 1	 10.24	 2.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65533	 1	 3.96	 0.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65534	 1	 8.97	 1.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65535	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65536	 1	 5.13	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65537	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65538	 1	 2.76	 0.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65539	 1	 2.12	 0.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65540	 1	 6.7	 1.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65541	 1	 8.18	 1.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65542	 1	 9.04	 1.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65543	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65544	 1	 3.89	 0.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65545	 1	 1.94	 0.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65546	 1	 6.28	 1.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65547	 1	 6.32	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65548	 1	 11.33	 2.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65549	 1	 21.33	 3.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65550	 1	 50.71	 13.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65551	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65552	 1	 3.86	 0.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65553	 1	 10.01	 1.54	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65554	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65555	 1	 8.32	 1.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65556	 1	 7.31	 1.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65557	 1	 10.32	 2.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65558	 1	 6.54	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65559	 1	 7.64	 1.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65560	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65561	 1	 7.31	 0.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65562	 1	 13.4	 3.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65563	 1	 3.81	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65564	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65565	 1	 7.11	 1.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65566	 1	 8.05	 1.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65567	 1	 6.66	 0.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65568	 1	 4.28	 0.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65569	 1	 9.5	 1.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65570	 1	 5.94	 0.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65571	 1	 3.41	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65572	 1	 5.87	 0.78	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65573	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65574	 1	 13.09	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65575	 1	 3.84	 0.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65576	 1	 6.26	 1.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65577	 1	 5.79	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65578	 1	 40.88	 11.68	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65579	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65580	 1	 15.65	 2.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65581	 1	 7.64	 1.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65582	 1	 8.23	 2.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65583	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65584	 1	 2.44	 0.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65585	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65586	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65587	 1	 4.11	 0.98	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65588	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65589	 1	 11.1	 2.1	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65590	 1	 5.36	 -3.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65591	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65592	 1	 14.97	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65593	 1	 10.09	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65594	 1	 4.96	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65595	 1	 4.77	 0.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65596	 1	 10.02	 1.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65597	 1	 3.95	 0.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65598	 1	 8.21	 1.77	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65599	 1	 6.58	 0.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65600	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65601	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65602	 1	 8.06	 0.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65603	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65604	 1	 24.81	 4.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65605	 1	 2.48	 0.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65606	 1	 4.56	 0.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65607	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65608	 1	 5.52	 0.68	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65609	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	65610	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65611	 1	 5.17	 1.2	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65612	 1	 3.79	 0.44	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65613	 1	 7.65	 1.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65614	 1	 3.55	 0.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65615	 1	 5.27	 0.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65616	 1	 7.73	 1.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65617	 1	 3.92	 0.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65618	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65619	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65620	 1	 3.44	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65621	 1	 4.58	 0.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65622	 1	 6.32	 0.59	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65623	 1	 18.28	 3.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65624	 1	 4.87	 0.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65625	 1	 13.86	 2.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65626	 1	 5.09	 1.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65627	 1	 8.26	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65628	 1	 8.99	 1.35	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65629	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65630	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65631	 1	 7.15	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65632	 1	 7.78	 1.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65633	 1	 32.42	 7.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65634	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65635	 1	 104.3	 22.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65636	 1	 1.9	 0.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65637	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65638	 1	 4.86	 0.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65639	 1	 4.21	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65640	 1	 6.46	 1.27	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65641	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65642	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65643	 1	 10.3	 2.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65644	 1	 4.55	 0.92	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65645	 1	 6.65	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65646	 1	 17.08	 3.8	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65647	 1	 2.76	 0.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65648	 1	 5.05	 0.52	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65649	 1	 7.45	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65650	 1	 4.67	 0.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65651	 1	 5.71	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65652	 1	 3.72	 0.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65653	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65654	 1	 0.0	 0.0	 0.0	 -121.34	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65655	 1	 76.42	 22.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65656	 1	 80.05	 27.55	 0.0	 -27.48	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65657	 1	 93.69	 14.36	 0.0	 -214.56	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65658	 1	 7.78	 1.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65659	 1	 2.93	 0.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65660	 1	 2.42	 0.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65661	 1	 8.95	 2.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65662	 1	 12.1	 1.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65663	 1	 3.45	 0.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65664	 1	 5.26	 1.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65665	 1	 10.59	 2.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65666	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65667	 1	 16.48	 4.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65668	 1	 2.62	 0.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65669	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65670	 1	 4.72	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65671	 1	 12.47	 1.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65672	 1	 10.41	 1.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65673	 1	 4.39	 0.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65674	 1	 3.93	 0.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65675	 1	 7.01	 1.47	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65676	 1	 4.31	 0.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65677	 1	 6.15	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65678	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65679	 1	 1.67	 0.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65680	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65681	 1	 2.61	 0.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65682	 1	 2.98	 0.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65683	 1	 24.96	 7.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65684	 1	 54.58	 15.87	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65685	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65686	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65687	 1	 3.95	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65688	 1	 89.62	 25.31	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65689	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65690	 1	 9.31	 2.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65691	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65692	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65693	 1	 3.38	 0.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65694	 1	 4.31	 0.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65695	 1	 5.99	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65696	 1	 112.01	 18.86	 0.0	 271.66	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65697	 1	 6.44	 1.31	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65698	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65699	 1	 4.88	 0.71	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65700	 1	 2.71	 0.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65701	 1	 13.6	 3.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65702	 1	 15.34	 4.02	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65703	 1	 3.22	 -9.37	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65704	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65705	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65706	 1	 4.05	 0.82	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65707	 1	 50.29	 12.66	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65708	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65709	 1	 7.85	 1.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65710	 1	 5.44	 0.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65711	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65712	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65713	 1	 14.55	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65714	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65715	 1	 6.79	 1.73	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65716	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65717	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65718	 1	 2.47	 0.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65719	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65720	 1	 4.43	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65721	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65722	 1	 2.2	 -3.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65723	 1	 2.51	 -3.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65724	 1	 2.61	 -3.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65725	 1	 5.22	 -2.61	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65726	 1	 4.23	 -2.82	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65727	 1	 3.65	 0.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65728	 1	 5.67	 0.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65729	 1	 7.94	 0.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65730	 1	 11.09	 2.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65731	 1	 45.67	 11.85	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65732	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65733	 1	 10.63	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65734	 1	 8.18	 -1.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65735	 1	 3.66	 0.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65736	 1	 13.37	 2.14	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65737	 1	 4.06	 0.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65738	 1	 5.02	 0.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65739	 1	 5.65	 1.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65740	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65741	 1	 3.81	 -3.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65742	 1	 5.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65743	 1	 10.14	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65744	 1	 6.28	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65745	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65746	 1	 5.94	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65747	 1	 7.58	 1.82	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65748	 1	 36.1	 9.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65749	 1	 7.4	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65750	 1	 8.46	 1.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65751	 1	 5.64	 0.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65752	 1	 4.83	 0.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65753	 1	 62.81	 19.4	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65754	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65755	 1	 22.72	 3.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65756	 1	 5.26	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65757	 1	 4.7	 0.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65758	 1	 8.19	 0.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65759	 1	 57.02	 9.07	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65760	 1	 7.36	 1.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65761	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65762	 1	 6.02	 1.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65763	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65764	 1	 6.81	 1.01	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65765	 1	 45.62	 11.35	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65766	 1	 13.21	 2.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65767	 1	 7.87	 1.81	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65768	 1	 4.39	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65769	 1	 10.09	 2.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65770	 1	 4.86	 1.04	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65771	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65772	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65773	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65774	 1	 2.31	 0.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65775	 1	 7.86	 1.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65776	 1	 3.79	 0.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65777	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65778	 1	 7.67	 1.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65779	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65780	 1	 4.88	 0.99	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65781	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65782	 1	 13.24	 3.66	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65783	 1	 6.33	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65784	 1	 10.69	 2.14	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65785	 1	 3.6	 0.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65786	 1	 12.33	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65787	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65788	 1	 4.63	 0.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65789	 1	 7.13	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65790	 1	 11.56	 3.5	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65791	 1	 0.0	 0.0	 0.0	 -359.34	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	65792	 1	 0.0	 0.0	 0.0	 15.47	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65793	 1	 13.11	 2.17	 0.0	 -109.38	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65794	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65795	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65796	 1	 5.17	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65797	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65798	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65799	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65800	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65801	 1	 55.86	 8.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65802	 1	 8.47	 1.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65803	 1	 54.29	 15.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65804	 1	 8.32	 2.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65805	 1	 11.32	 2.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65806	 1	 3.04	 0.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65807	 1	 3.71	 0.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65808	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65809	 1	 2.99	 0.56	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65810	 1	 5.74	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65811	 1	 8.2	 1.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65812	 1	 2.18	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65813	 1	 41.43	 10.71	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65814	 1	 12.86	 2.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65815	 1	 5.77	 1.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65816	 1	 12.71	 2.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65817	 1	 7.03	 1.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65818	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65819	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65820	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65821	 1	 5.99	 1.21	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65822	 1	 5.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65823	 1	 4.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65824	 1	 3.06	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65825	 1	 4.81	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65826	 1	 3.17	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65827	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65828	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65829	 1	 3.66	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65830	 1	 5.26	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65831	 1	 5.15	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65832	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65833	 1	 4.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65834	 1	 7.88	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65835	 1	 3.56	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65836	 1	 4.86	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65837	 1	 8.67	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65838	 1	 44.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65839	 1	 3.22	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65840	 1	 6.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65841	 1	 8.41	 0.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65842	 1	 1.87	 0.29	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65843	 1	 9.17	 1.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65844	 1	 7.84	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65845	 1	 1.32	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65846	 1	 6.37	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65847	 1	 1.44	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65848	 1	 3.14	 0.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65849	 1	 48.61	 10.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65850	 1	 3.73	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65851	 1	 2.4	 0.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65852	 1	 1.55	 0.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65853	 1	 6.52	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65854	 1	 5.35	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65855	 1	 3.31	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65856	 1	 2.91	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65857	 1	 1.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65858	 1	 6.29	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65859	 1	 2.2	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65860	 1	 6.5	 0.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65861	 1	 3.62	 0.68	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65862	 1	 3.07	 0.59	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65863	 1	 6.32	 1.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65864	 1	 3.25	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65865	 1	 10.01	 2.84	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65866	 1	 2.26	 0.38	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65867	 1	 4.47	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65868	 1	 1.81	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65869	 1	 4.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65870	 1	 4.8	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65871	 1	 1.04	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65872	 1	 6.96	 -8.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65873	 1	 5.12	 0.91	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65874	 1	 9.46	 2.58	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65875	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65876	 1	 1.76	 0.33	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65877	 1	 5.81	 1.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65878	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65879	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65880	 1	 6.08	 0.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65881	 1	 4.41	 0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65882	 1	 2.12	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65883	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65884	 1	 8.2	 -3.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65885	 1	 3.39	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65886	 1	 15.71	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65887	 1	 7.27	 -3.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65888	 1	 5.51	 0.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65889	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65890	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65891	 1	 5.57	 1.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65892	 1	 11.25	 2.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65893	 1	 0.95	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65894	 1	 5.49	 0.87	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65895	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65896	 1	 5.19	 1.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65897	 1	 8.34	 1.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65898	 1	 5.7	 0.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65899	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65900	 1	 5.82	 0.95	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65901	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65902	 1	 3.44	 0.63	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65903	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65904	 1	 8.95	 1.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65905	 1	 8.38	 2.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65906	 1	 3.02	 0.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65907	 1	 23.23	 4.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65908	 1	 4.47	 1.27	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65909	 1	 6.46	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65910	 1	 11.71	 1.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65911	 1	 5.55	 0.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65912	 1	 3.87	 1.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65913	 1	 155.31	 31.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65914	 1	 20.09	 4.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65915	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65916	 1	 40.99	 5.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65917	 1	 40.04	 5.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65918	 1	 3.73	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65919	 1	 3.12	 0.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65920	 1	 4.04	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65921	 1	 2.79	 0.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65922	 1	 3.39	 0.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65923	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65924	 1	 19.65	 4.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65925	 1	 2.04	 0.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65926	 1	 7.97	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65927	 1	 15.67	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65928	 1	 40.35	 11.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65929	 1	 5.32	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65930	 1	 2.34	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65931	 1	 11.75	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65932	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65933	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65934	 1	 6.47	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65935	 1	 3.39	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65936	 1	 2.04	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65937	 1	 4.3	 0.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65938	 1	 2.76	 0.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65939	 1	 3.89	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65940	 1	 6.08	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65941	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65942	 1	 7.03	 1.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65943	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65944	 1	 11.45	 2.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65945	 1	 8.18	 2.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65946	 1	 5.81	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65947	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65948	 1	 1.53	 0.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65949	 1	 0.08	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65950	 1	 7.09	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65951	 1	 4.51	 1.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65952	 1	 7.63	 1.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65953	 1	 23.82	 6.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65954	 1	 34.97	 6.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65955	 1	 2.87	 0.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65956	 1	 4.98	 1.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65957	 1	 6.27	 0.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65958	 1	 7.03	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65959	 1	 0.0	 0.0	 0.0	 97.4	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	65960	 1	 5.0	 1.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65961	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65962	 1	 3.68	 0.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65963	 1	 5.79	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65964	 1	 11.23	 3.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65965	 1	 12.8	 3.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65966	 1	 7.92	 2.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65967	 1	 15.33	 2.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65968	 1	 4.98	 0.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65969	 1	 6.86	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65970	 1	 3.74	 0.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65971	 1	 53.59	 14.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65972	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65973	 1	 3.35	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65974	 1	 6.99	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65975	 1	 5.49	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65976	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65977	 1	 2.34	 0.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65978	 1	 4.21	 0.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65979	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65980	 1	 5.94	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65981	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65982	 1	 3.58	 0.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65983	 1	 5.79	 1.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65984	 1	 57.84	 13.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65985	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65986	 1	 11.78	 3.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65987	 1	 5.12	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65988	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65989	 1	 3.95	 0.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65990	 1	 3.77	 0.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65991	 1	 4.01	 0.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65992	 1	 26.84	 5.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65993	 1	 1.61	 0.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65994	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65995	 1	 3.0	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65996	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65997	 1	 2.99	 0.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	65998	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65999	 1	 8.86	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66000	 1	 3.79	 0.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66001	 1	 5.38	 1.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66002	 1	 3.35	 0.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66003	 1	 3.67	 0.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66004	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66005	 1	 4.74	 1.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66006	 1	 0.0	 0.0	 0.0	 445.86	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66007	 1	 58.29	 11.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66008	 1	 58.05	 9.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66009	 1	 6.48	 1.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66010	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66011	 1	 18.58	 4.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66012	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66013	 1	 10.68	 2.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66014	 1	 2.97	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66015	 1	 10.81	 3.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66016	 1	 0.0	 0.0	 0.0	 246.24	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66017	 1	 7.61	 1.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66018	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66019	 1	 17.0	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66020	 1	 5.54	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66021	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66022	 1	 22.05	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66023	 1	 3.49	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66024	 1	 12.67	 2.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66025	 1	 5.69	 1.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66026	 1	 33.41	 9.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66027	 1	 4.34	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66028	 1	 23.78	 5.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66029	 1	 0.0	 0.0	 0.0	 -47.71	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66030	 1	 5.13	 0.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66031	 1	 6.4	 -0.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66032	 1	 8.54	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66033	 1	 3.09	 0.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66034	 1	 8.94	 2.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66035	 1	 40.1	 8.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66036	 1	 1.07	 0.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66037	 1	 1.87	 0.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66038	 1	 3.11	 0.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66039	 1	 87.37	 13.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66040	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66041	 1	 15.93	 -7.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66042	 1	 3.92	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66043	 1	 4.1	 0.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66044	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66045	 1	 0.0	 0.0	 0.0	 -38.29	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66046	 1	 3.43	 0.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66047	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66048	 1	 5.61	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66049	 1	 2.41	 0.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66050	 1	 4.21	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66051	 1	 4.78	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66052	 1	 31.24	 8.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66053	 1	 5.93	 1.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66054	 1	 6.24	 1.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66055	 1	 5.46	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66056	 1	 9.03	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66057	 1	 6.33	 0.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66058	 1	 5.1	 0.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66059	 1	 4.23	 0.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66060	 1	 3.71	 0.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66061	 1	 41.98	 12.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66062	 1	 12.37	 2.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66063	 1	 4.76	 0.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66064	 1	 16.77	 2.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66065	 1	 0.0	 0.0	 0.0	 72.61	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66066	 1	 14.51	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66067	 1	 51.5	 9.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66068	 1	 2.92	 0.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66069	 1	 6.87	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66070	 1	 4.92	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66071	 1	 5.31	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66072	 1	 4.57	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66073	 1	 3.97	 1.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66074	 1	 2.71	 0.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66075	 1	 2.87	 0.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66076	 1	 2.49	 0.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66077	 1	 3.54	 0.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66078	 1	 4.09	 0.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66079	 1	 2.69	 0.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66080	 1	 5.71	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66081	 1	 3.74	 0.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66082	 1	 1.51	 0.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66083	 1	 4.05	 0.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66084	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66085	 1	 3.06	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66086	 1	 17.19	 3.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66087	 1	 3.81	 0.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66088	 1	 3.97	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66089	 1	 5.45	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66090	 1	 5.51	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66091	 1	 4.72	 0.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66092	 1	 6.24	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66093	 1	 6.73	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66094	 1	 4.03	 0.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66095	 1	 3.42	 0.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66096	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66097	 1	 4.54	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66098	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66099	 1	 4.06	 0.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66100	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66101	 1	 5.18	 0.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66102	 1	 4.81	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66103	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66104	 1	 2.07	 0.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66105	 1	 4.45	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66106	 1	 4.72	 0.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66107	 1	 2.76	 0.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66108	 1	 3.84	 0.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66109	 1	 1.9	 0.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66110	 1	 8.85	 1.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66111	 1	 60.37	 15.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66112	 1	 50.53	 12.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66113	 1	 6.94	 1.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66114	 1	 3.97	 1.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66115	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66116	 1	 4.39	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66117	 1	 4.58	 0.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66118	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66119	 1	 3.97	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66120	 1	 4.04	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66121	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66122	 1	 5.25	 1.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66123	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66124	 1	 4.17	 1.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66125	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66126	 1	 5.64	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66127	 1	 3.15	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66128	 1	 7.65	 1.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66129	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66130	 1	 6.73	 0.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66131	 1	 3.74	 0.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66132	 1	 5.66	 0.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66133	 1	 4.63	 0.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66134	 1	 11.55	 2.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66135	 1	 13.73	 2.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66136	 1	 3.96	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66137	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66138	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66139	 1	 5.23	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66140	 1	 3.78	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66141	 1	 3.69	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66142	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66143	 1	 2.28	 0.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66144	 1	 3.87	 0.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66145	 1	 2.9	 0.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66146	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66147	 1	 2.33	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66148	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66149	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66150	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66151	 1	 7.26	 0.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66152	 1	 5.42	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66153	 1	 4.09	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66154	 1	 3.52	 0.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66155	 1	 4.25	 0.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66156	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66157	 1	 14.05	 2.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66158	 1	 4.01	 0.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66159	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66160	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66161	 1	 4.93	 1.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66162	 1	 4.34	 0.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66163	 1	 4.04	 0.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66164	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66165	 1	 4.51	 1.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66166	 1	 4.64	 0.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66167	 1	 5.13	 1.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66168	 1	 4.08	 0.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66169	 1	 6.83	 1.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66170	 1	 4.52	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66171	 1	 3.6	 0.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66172	 1	 5.07	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66173	 1	 3.47	 1.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66174	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66175	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66176	 1	 4.86	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66177	 1	 5.46	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66178	 1	 7.02	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66179	 1	 4.34	 0.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66180	 1	 4.08	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66181	 1	 3.42	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66182	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66183	 1	 5.25	 0.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66184	 1	 5.89	 1.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66185	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66186	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66187	 1	 3.15	 0.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66188	 1	 10.51	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66189	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66190	 1	 3.33	 0.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66191	 1	 22.65	 5.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66192	 1	 5.73	 1.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66193	 1	 48.02	 8.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66194	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66195	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66196	 1	 3.43	 1.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66197	 1	 7.64	 2.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66198	 1	 13.83	 3.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66199	 1	 5.65	 1.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66200	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66201	 1	 6.97	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66202	 1	 2.25	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66203	 1	 2.14	 0.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66204	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66205	 1	 5.33	 1.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66206	 1	 4.98	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66207	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66208	 1	 2.76	 0.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66209	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66210	 1	 5.4	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66211	 1	 4.31	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66212	 1	 5.04	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66213	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66214	 1	 6.51	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66215	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66216	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66217	 1	 0.0	 0.0	 0.0	 65.85	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66218	 1	 4.81	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66219	 1	 3.42	 0.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66220	 1	 3.99	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66221	 1	 2.62	 0.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66222	 1	 8.28	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66223	 1	 5.82	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66224	 1	 5.26	 1.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66225	 1	 3.59	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66226	 1	 2.69	 0.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66227	 1	 2.69	 0.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66228	 1	 3.54	 0.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66229	 1	 4.2	 1.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66230	 1	 4.23	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66231	 1	 2.07	 0.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66232	 1	 4.57	 0.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66233	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66234	 1	 6.85	 1.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66235	 1	 3.7	 0.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66236	 1	 4.93	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66237	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66238	 1	 84.8	 20.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66239	 1	 0.0	 0.0	 0.0	 13.59	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66240	 1	 85.2	 23.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66241	 1	 3.25	 0.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66242	 1	 7.9	 2.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66243	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66244	 1	 0.0	 0.0	 0.0	 159.25	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66245	 1	 7.47	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66246	 1	 27.05	 7.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66247	 1	 3.13	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66248	 1	 7.77	 2.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66249	 1	 65.5	 16.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66250	 1	 78.78	 12.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66251	 1	 4.08	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66252	 1	 2.81	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66253	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66254	 1	 0.0	 0.0	 0.0	 -37.45	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66255	 1	 10.39	 2.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66256	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66257	 1	 8.85	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66258	 1	 6.75	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66259	 1	 0.0	 0.0	 0.0	 -37.31	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66260	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66261	 1	 10.91	 2.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66262	 1	 5.94	 1.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66263	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66264	 1	 3.78	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66265	 1	 2.1	 0.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66266	 1	 38.3	 7.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66267	 1	 3.89	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66268	 1	 3.66	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66269	 1	 0.08	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66270	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66271	 1	 5.5	 1.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66272	 1	 3.65	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66273	 1	 1.94	 0.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66274	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66275	 1	 2.44	 0.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66276	 1	 2.08	 0.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66277	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66278	 1	 0.0	 0.0	 0.0	 20.36	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66279	 1	 3.81	 1.14	 0.0	 -55.2	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66280	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66281	 1	 0.0	 0.0	 0.0	 12.81	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66282	 1	 0.0	 0.0	 0.0	 -48.97	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66283	 1	 4.78	 1.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66284	 1	 0.0	 0.0	 0.0	 141.21	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66285	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66286	 1	 9.0	 1.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66287	 1	 8.41	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66288	 1	 4.23	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66289	 1	 14.0	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66290	 1	 25.35	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66291	 1	 7.69	 1.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66292	 1	 7.22	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66293	 1	 21.45	 5.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66294	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66295	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66296	 1	 4.33	 0.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66297	 1	 2.72	 0.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66298	 1	 3.09	 0.37	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66299	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66300	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66301	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66302	 1	 2.6	 0.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66303	 1	 6.49	 1.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66304	 1	 3.06	 0.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66305	 1	 2.29	 0.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66306	 1	 2.74	 0.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66307	 1	 1.66	 0.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66308	 1	 6.81	 1.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66309	 1	 5.65	 1.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66310	 1	 0.0	 0.0	 0.0	 -24.51	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66311	 1	 2.98	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66312	 1	 2.3	 0.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66313	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66314	 1	 4.84	 1.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66315	 1	 4.08	 0.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66316	 1	 2.56	 0.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66317	 1	 2.19	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66318	 1	 2.3	 0.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66319	 1	 1.97	 0.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66320	 1	 5.07	 1.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66321	 1	 7.39	 2.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66322	 1	 4.2	 0.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66323	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66324	 1	 2.31	 0.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66325	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66326	 1	 1.97	 0.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66327	 1	 2.47	 0.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66328	 1	 2.67	 0.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66329	 1	 2.21	 0.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66330	 1	 3.39	 0.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66331	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66332	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66333	 1	 3.53	 0.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66334	 1	 5.51	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66335	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66336	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66337	 1	 2.87	 0.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66338	 1	 2.74	 0.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66339	 1	 3.42	 0.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66340	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66341	 1	 4.67	 0.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66342	 1	 3.25	 0.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66343	 1	 2.72	 0.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66344	 1	 3.44	 0.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66345	 1	 4.51	 1.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66346	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66347	 1	 1.63	 0.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66348	 1	 6.89	 1.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66349	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66350	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66351	 1	 2.23	 0.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66352	 1	 0.0	 0.0	 0.0	 2.26	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66353	 1	 2.77	 0.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66354	 1	 3.1	 0.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66355	 1	 2.58	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66356	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66357	 1	 3.52	 0.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66358	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66359	 1	 16.79	 4.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66360	 1	 2.37	 0.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66361	 1	 5.64	 1.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66362	 1	 0.0	 0.0	 0.0	 248.75	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66363	 1	 38.56	 10.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66364	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66365	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66366	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66367	 1	 2.55	 0.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66368	 1	 2.99	 0.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66369	 1	 2.9	 0.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66370	 1	 2.72	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66371	 1	 2.47	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66372	 1	 2.65	 0.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66373	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66374	 1	 3.93	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66375	 1	 3.21	 0.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66376	 1	 5.0	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66377	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66378	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66379	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66380	 1	 5.29	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66381	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66382	 1	 5.91	 0.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66383	 1	 4.72	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66384	 1	 3.93	 0.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66385	 1	 5.74	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66386	 1	 6.36	 1.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66387	 1	 1.16	 0.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66388	 1	 5.11	 0.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66389	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66390	 1	 3.65	 0.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66391	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66392	 1	 4.65	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66393	 1	 5.72	 1.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66394	 1	 3.84	 0.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66395	 1	 4.98	 1.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66396	 1	 1.96	 0.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66397	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66398	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66399	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66400	 1	 3.01	 0.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66401	 1	 4.21	 1.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66402	 1	 3.44	 0.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66403	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66404	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66405	 1	 13.63	 3.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66406	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66407	 1	 3.4	 0.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66408	 1	 3.08	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66409	 1	 7.54	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66410	 1	 4.5	 0.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66411	 1	 2.65	 0.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66412	 1	 2.01	 0.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66413	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66414	 1	 3.77	 0.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66415	 1	 19.88	 2.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66416	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66417	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66418	 1	 1.37	 0.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66419	 1	 17.23	 5.37	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66420	 1	 3.64	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66421	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66422	 1	 6.1	 1.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66423	 1	 9.31	 2.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66424	 1	 3.4	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66425	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66426	 1	 3.93	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66427	 1	 11.5	 2.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66428	 1	 2.31	 0.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66429	 1	 17.78	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66430	 1	 5.6	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66431	 1	 7.44	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66432	 1	 5.79	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66433	 1	 7.76	 1.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66434	 1	 21.64	 3.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66435	 1	 12.75	 3.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66436	 1	 6.13	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66437	 1	 22.44	 4.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66438	 1	 3.3	 0.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66439	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66440	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66441	 1	 5.59	 1.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66442	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66443	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66444	 1	 4.56	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66445	 1	 6.07	 0.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66446	 1	 15.17	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66447	 1	 2.4	 0.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66448	 1	 11.7	 2.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66449	 1	 3.23	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66450	 1	 3.63	 0.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66451	 1	 3.69	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66452	 1	 3.55	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66453	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66454	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66455	 1	 4.89	 1.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66456	 1	 3.37	 0.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66457	 1	 2.36	 0.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66458	 1	 7.24	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66459	 1	 4.41	 1.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66460	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66461	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66462	 1	 2.2	 0.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66463	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66464	 1	 2.39	 0.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66465	 1	 8.9	 2.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66466	 1	 7.39	 0.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66467	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66468	 1	 4.67	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66469	 1	 0.0	 0.0	 0.0	 147.63	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66470	 1	 6.01	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66471	 1	 5.21	 0.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66472	 1	 3.3	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66473	 1	 2.13	 0.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66474	 1	 3.3	 0.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66475	 1	 7.29	 1.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66476	 1	 5.22	 0.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66477	 1	 6.65	 1.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66478	 1	 0.0	 0.0	 0.0	 52.22	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66479	 1	 56.82	 13.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66480	 1	 5.95	 1.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66481	 1	 6.96	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66482	 1	 22.53	 6.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66483	 1	 8.72	 1.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66484	 1	 1.66	 0.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66485	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66486	 1	 2.65	 0.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66487	 1	 8.67	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66488	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66489	 1	 5.54	 1.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66490	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66491	 1	 3.34	 0.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66492	 1	 5.46	 1.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66493	 1	 4.08	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66494	 1	 5.67	 1.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66495	 1	 2.3	 0.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66496	 1	 6.68	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66497	 1	 3.77	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66498	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66499	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66500	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66501	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66502	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66503	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66504	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66505	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66506	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66507	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66508	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66509	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66510	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66511	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66512	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66513	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66514	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66515	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66516	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66517	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66518	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66519	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66520	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66521	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66522	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66523	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66524	 2	 0.0	 0.0	 0.0	 140.49	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66525	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66526	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66527	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66528	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66529	 2	 0.0	 0.0	 0.0	 -74.82	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66530	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66531	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66532	 2	 0.0	 0.0	 0.0	 640.87	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66533	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66534	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66535	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66536	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66537	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66538	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66539	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66540	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66541	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66542	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66543	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66544	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66545	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66546	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66547	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66548	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66549	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66550	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66551	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66552	 2	 0.0	 0.0	 0.0	 277.77	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66553	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66554	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66555	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66556	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66557	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66558	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66559	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66560	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66561	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66562	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66563	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66564	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66565	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66566	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66567	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66568	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66569	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66570	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66571	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66572	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66573	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66574	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66575	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66576	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66577	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66578	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66579	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66580	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66581	 2	 0.0	 0.0	 0.0	 65.1	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66582	 2	 0.0	 0.0	 0.0	 65.1	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66583	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66584	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66585	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66586	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66587	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66588	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66589	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66590	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66591	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66592	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66593	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66594	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66595	 2	 0.0	 -20.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66596	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66597	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66598	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66599	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66600	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66601	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66602	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66603	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66604	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66605	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66606	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66607	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66608	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66609	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66610	 1	 0.0	 0.0	 0.0	 20.67	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66611	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66612	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66613	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66614	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66615	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66616	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66617	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66618	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66619	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66620	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66621	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66622	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66623	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66624	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66625	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66626	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66627	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66628	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66629	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66630	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66631	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66632	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66633	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66634	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66635	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66636	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66637	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66638	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66639	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66640	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66641	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66642	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66643	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66644	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66645	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66646	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66647	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66648	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66649	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66650	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66651	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66652	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66653	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66654	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66655	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66656	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66657	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66658	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66659	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66660	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66661	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66662	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66663	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66664	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66665	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66666	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66667	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66668	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66669	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66670	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66671	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66672	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66673	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66674	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66675	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66676	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66677	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66678	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66679	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66680	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66681	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66682	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66683	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66684	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66685	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66686	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66687	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66688	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66689	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66690	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66691	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66692	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66693	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66694	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66695	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66696	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66697	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66698	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66699	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66700	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66701	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66702	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66703	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66704	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66705	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66706	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66707	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66708	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66709	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66710	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66711	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66712	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66713	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66714	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66715	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66716	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66717	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66718	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66719	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66720	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66721	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66722	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66723	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66724	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66725	 1	 0.0	 0.0	 0.0	 28.04	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66726	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66727	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66728	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66729	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66730	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	66731	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66732	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66733	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66734	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66735	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66736	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66737	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66738	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66739	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66740	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66741	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66742	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66743	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66744	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66745	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66746	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66747	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66748	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66749	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66750	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66751	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66752	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66753	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66754	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66755	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66756	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66757	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66758	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66759	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66760	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66761	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66762	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66763	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66764	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66765	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66766	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66767	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66768	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66769	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66770	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66771	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66772	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66773	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66774	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66775	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66776	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66777	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66778	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66779	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66780	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66781	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66782	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66783	 1	 0.0	 0.0	 0.0	 100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66784	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66785	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66786	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66787	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66788	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66789	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66790	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66791	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66792	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66793	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66794	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66795	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66796	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66797	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66798	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66799	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66800	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66801	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66802	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66803	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66804	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66805	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66806	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66807	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66808	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66809	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66810	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66811	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66812	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66813	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66814	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66815	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66816	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66817	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66818	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66819	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66820	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66821	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66822	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66823	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66824	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66825	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66826	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66827	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66828	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66829	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66830	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66831	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66832	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66833	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66834	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66835	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66836	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66837	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66838	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66839	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66840	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66841	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66842	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66843	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66844	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66845	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66846	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66847	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66848	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66849	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66850	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66851	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66852	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66853	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66854	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66855	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66856	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66857	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66858	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66859	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66860	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66861	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66862	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66863	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66864	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66865	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66866	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66867	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66868	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66869	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66870	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66871	 1	 4.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66872	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66873	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66874	 1	 0.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66875	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66876	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66877	 1	 1.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66878	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66879	 1	 5.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66880	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66881	 1	 9.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66882	 1	 6.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66883	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66884	 1	 4.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66885	 1	 16.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66886	 1	 0.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66887	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66888	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66889	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66890	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66891	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66892	 1	 5.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66893	 1	 7.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66894	 1	 5.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66895	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66896	 1	 6.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66897	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66898	 1	 9.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66899	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66900	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66901	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66902	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66903	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66904	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66905	 1	 6.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66906	 1	 6.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66907	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66908	 1	 4.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66909	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66910	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66911	 1	 0.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66912	 1	 5.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66913	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66914	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66915	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66916	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66917	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66918	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66919	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66920	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66921	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66922	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66923	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66924	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66925	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66926	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66927	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66928	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66929	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66930	 1	 14.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66931	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66932	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66933	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66934	 1	 1.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66935	 1	 1.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66936	 1	 5.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66937	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66938	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66939	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66940	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66941	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66942	 1	 3.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66943	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66944	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66945	 1	 5.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66946	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66947	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66948	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66949	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66950	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66951	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66952	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66953	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66954	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66955	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66956	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66957	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66958	 1	 3.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66959	 1	 6.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66960	 1	 4.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66961	 1	 6.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66962	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66963	 1	 33.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66964	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66965	 1	 1.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66966	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66967	 1	 5.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66968	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66969	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66970	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66971	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66972	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66973	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66974	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66975	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66976	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66977	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66978	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66979	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66980	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66981	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	66982	 1	 6.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66983	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66984	 1	 5.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66985	 1	 0.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66986	 1	 1.72	 -0.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66987	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66988	 1	 1.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66989	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66990	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66991	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66992	 1	 1.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66993	 1	 4.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66994	 1	 0.0	 0.0	 0.0	 -41.3	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	66995	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66996	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66997	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66998	 1	 4.5	 -26.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	66999	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67000	 1	 6.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67001	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67002	 1	 5.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67003	 1	 8.23	 -20.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67004	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67005	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67006	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67007	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67008	 1	 2.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67009	 1	 13.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67010	 1	 4.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67011	 1	 4.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67012	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67013	 1	 1.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67014	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67015	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67016	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67017	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67018	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67019	 1	 5.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67020	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67021	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67022	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67023	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67024	 1	 4.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67025	 1	 12.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67026	 1	 9.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67027	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67028	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67029	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67030	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67031	 1	 4.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67032	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67033	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67034	 1	 7.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67035	 1	 4.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67036	 1	 5.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67037	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67038	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67039	 1	 16.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67040	 1	 5.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67041	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67042	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67043	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67044	 1	 1.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67045	 1	 4.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67046	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67047	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67048	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67049	 1	 13.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67050	 1	 4.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67051	 1	 5.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67052	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67053	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67054	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67055	 1	 4.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67056	 1	 44.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67057	 1	 8.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67058	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67059	 1	 9.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67060	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67061	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67062	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67063	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67064	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67065	 1	 8.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67066	 1	 16.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67067	 1	 5.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67068	 1	 11.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67069	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67070	 1	 11.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67071	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67072	 1	 6.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67073	 1	 3.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67074	 1	 4.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67075	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67076	 1	 3.73	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67077	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67078	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67079	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67080	 1	 10.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67081	 1	 7.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67082	 1	 5.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67083	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67084	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67085	 1	 4.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67086	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67087	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67088	 1	 4.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67089	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67090	 1	 7.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67091	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67092	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67093	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67094	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67095	 1	 6.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67096	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67097	 1	 4.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67098	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67099	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67100	 1	 0.0	 0.0	 0.0	 234.29	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	67101	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67102	 1	 6.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67103	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67104	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67105	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67106	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67107	 1	 2.07	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67108	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67109	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67110	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67111	 1	 1.99	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67112	 1	 6.47	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67113	 1	 4.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67114	 1	 0.0	 0.0	 0.0	 1.36	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67115	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67116	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67117	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67118	 1	 1.42	 0.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67119	 1	 5.7	 3.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67120	 1	 0.0	 0.0	 0.0	 92.38	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67121	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67122	 1	 1.87	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67123	 1	 2.67	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67124	 1	 3.16	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67125	 1	 5.29	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67126	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67127	 1	 1.6	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67128	 1	 9.28	 8.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67129	 1	 2.86	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67130	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67131	 1	 2.46	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67132	 1	 2.59	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67133	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67134	 1	 1.53	 0.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67135	 1	 7.1	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67136	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67137	 1	 2.83	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67138	 1	 3.13	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67139	 1	 0.0	 0.0	 0.0	 100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67140	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67141	 1	 2.51	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67142	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67143	 1	 3.78	 2.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67144	 1	 3.02	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67145	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67146	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67147	 1	 3.79	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67148	 1	 2.28	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67149	 1	 15.39	 9.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67150	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67151	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67152	 1	 1.97	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67153	 1	 4.13	 2.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67154	 1	 1.96	 0.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67155	 1	 3.34	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67156	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67157	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67158	 1	 4.9	 2.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67159	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67160	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67161	 1	 2.67	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67162	 1	 2.86	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67163	 1	 2.71	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67164	 1	 4.02	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67165	 1	 3.88	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67166	 1	 1.51	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67167	 1	 3.67	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67168	 1	 0.0	 0.0	 0.0	 68.16	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67169	 1	 3.17	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67170	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67171	 1	 3.07	 1.75	 0.0	 48.82	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67172	 1	 1.89	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67173	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67174	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67175	 1	 2.57	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67176	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67177	 1	 7.74	 4.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67178	 1	 4.0	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67179	 1	 18.29	 10.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67180	 1	 2.67	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67181	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67182	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67183	 1	 14.24	 8.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67184	 1	 6.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67185	 1	 11.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67186	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67187	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67188	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67189	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67190	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67191	 1	 8.38	 4.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67192	 1	 5.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67193	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67194	 1	 3.44	 2.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67195	 1	 6.07	 4.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67196	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67197	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67198	 1	 11.58	 5.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67199	 1	 7.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67200	 1	 4.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67201	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67202	 1	 7.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67203	 1	 4.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67204	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67205	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67206	 1	 1.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67207	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67208	 1	 90.87	 64.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67209	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67210	 1	 4.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67211	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67212	 1	 7.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67213	 1	 11.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67214	 1	 1.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67215	 1	 3.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67216	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67217	 1	 7.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67218	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67219	 1	 1.61	 0.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67220	 1	 1.52	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67221	 1	 5.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67222	 1	 11.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67223	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67224	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67225	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67226	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67227	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67228	 1	 3.43	 -20.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67229	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67230	 1	 4.19	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67231	 1	 1.72	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67232	 1	 4.1	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67233	 1	 4.63	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67234	 1	 9.97	 8.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67235	 1	 5.13	 3.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67236	 1	 7.75	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67237	 1	 4.64	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67238	 1	 4.44	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67239	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67240	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67241	 1	 5.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67242	 1	 4.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67243	 1	 4.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67244	 1	 10.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67245	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67246	 1	 10.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67247	 1	 5.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67248	 1	 5.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67249	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67250	 1	 4.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67251	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67252	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67253	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67254	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67255	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67256	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67257	 1	 5.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67258	 1	 7.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67259	 1	 10.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67260	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67261	 1	 12.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67262	 1	 6.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67263	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67264	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67265	 1	 5.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67266	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67267	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67268	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67269	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67270	 1	 9.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67271	 1	 13.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67272	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67273	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67274	 1	 8.52	 5.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67275	 1	 1.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67276	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67277	 1	 5.51	 3.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67278	 1	 8.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67279	 1	 1.68	 0.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67280	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67281	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67282	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67283	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67284	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67285	 1	 4.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67286	 1	 2.37	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67287	 1	 7.5	 6.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67288	 1	 4.38	 -21.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67289	 1	 7.4	 -11.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67290	 1	 3.77	 1.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67291	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67292	 1	 4.72	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67293	 1	 8.69	 4.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67294	 1	 2.66	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67295	 1	 6.69	 5.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67296	 1	 2.46	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67297	 1	 2.22	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67298	 1	 1.23	 0.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67299	 1	 0.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67300	 1	 5.66	 4.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67301	 1	 6.75	 4.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67302	 1	 9.27	 -12.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67303	 1	 4.89	 3.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67304	 1	 3.08	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67305	 1	 5.06	 3.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67306	 1	 6.66	 5.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67307	 1	 5.71	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67308	 1	 4.44	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67309	 1	 5.57	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67310	 1	 8.96	 5.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67311	 1	 6.48	 4.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67312	 1	 7.92	 5.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67313	 1	 14.21	 7.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67314	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67315	 1	 3.93	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67316	 1	 6.86	 4.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67317	 1	 3.66	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67318	 1	 6.06	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67319	 1	 2.1	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67320	 1	 4.12	 -10.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67321	 1	 2.17	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67322	 1	 2.11	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67323	 1	 5.81	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67324	 1	 45.31	 52.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67325	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67326	 1	 5.73	 3.41	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67327	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67328	 1	 2.52	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67329	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67330	 1	 3.11	 -12.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67331	 1	 2.72	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67332	 1	 2.69	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67333	 1	 10.55	 7.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67334	 1	 10.14	 6.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67335	 1	 2.33	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67336	 1	 19.5	 12.22	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67337	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67338	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67339	 1	 6.91	 5.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67340	 1	 15.45	 7.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67341	 1	 8.85	 4.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67342	 1	 4.44	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67343	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67344	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67345	 1	 0.93	 0.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67346	 1	 2.88	 1.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67347	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67348	 1	 6.45	 7.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67349	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67350	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67351	 1	 0.0	 0.0	 0.0	 200.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	67352	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67353	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67354	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67355	 1	 6.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67356	 1	 72.17	 63.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67357	 1	 6.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67358	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67359	 1	 11.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67360	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67361	 1	 6.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67362	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67363	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67364	 1	 4.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67365	 1	 5.2	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67366	 1	 7.8	 4.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67367	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67368	 1	 2.17	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67369	 1	 0.0	 0.0	 0.0	 -89.26	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67370	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67371	 1	 5.7	 3.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67372	 1	 4.04	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67373	 1	 5.33	 3.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67374	 1	 5.07	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67375	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67376	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67377	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67378	 1	 2.83	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67379	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67380	 1	 2.71	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67381	 1	 5.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67382	 1	 3.77	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67383	 1	 6.23	 4.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67384	 1	 7.55	 3.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67385	 1	 1.94	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67386	 1	 8.38	 4.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67387	 1	 1.54	 0.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67388	 1	 9.03	 4.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67389	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67390	 1	 3.33	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67391	 1	 1.76	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67392	 1	 11.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67393	 1	 2.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67394	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67395	 1	 4.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67396	 1	 7.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67397	 1	 8.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67398	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67399	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67400	 1	 7.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67401	 1	 6.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67402	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67403	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67404	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67405	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67406	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67407	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67408	 1	 6.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67409	 1	 14.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67410	 1	 6.84	 -0.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67411	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67412	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67413	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67414	 1	 5.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67415	 1	 1.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67416	 1	 17.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67417	 1	 9.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67418	 1	 6.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67419	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67420	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67421	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67422	 1	 2.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67423	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67424	 1	 3.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67425	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67426	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67427	 1	 5.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67428	 1	 1.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67429	 1	 3.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67430	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67431	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67432	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67433	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67434	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67435	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67436	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67437	 1	 3.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67438	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67439	 1	 8.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67440	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67441	 1	 8.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67442	 1	 4.43	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67443	 1	 4.48	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67444	 1	 3.67	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67445	 1	 5.24	 1.85	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67446	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67447	 1	 7.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67448	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67449	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67450	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67451	 1	 5.64	 3.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67452	 1	 8.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67453	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67454	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67455	 1	 3.4	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67456	 1	 5.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67457	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67458	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67459	 1	 31.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67460	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67461	 1	 5.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67462	 1	 1.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67463	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67464	 1	 5.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67465	 1	 6.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67466	 1	 4.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67467	 1	 6.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67468	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67469	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67470	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67471	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67472	 1	 11.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67473	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67474	 1	 22.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67475	 1	 14.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67476	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67477	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67478	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67479	 1	 6.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67480	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67481	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67482	 1	 8.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67483	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67484	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67485	 1	 6.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67486	 1	 4.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67487	 1	 5.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67488	 1	 4.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67489	 1	 6.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67490	 1	 5.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67491	 1	 6.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67492	 1	 0.0	 0.0	 0.0	 600.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	67493	 1	 5.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67494	 1	 25.08	 18.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67495	 1	 9.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67496	 1	 5.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67497	 1	 4.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67498	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67499	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67500	 1	 0.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67501	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67502	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67503	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67504	 1	 3.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67505	 1	 0.93	 0.66	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67506	 1	 1.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67507	 1	 0.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67508	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67509	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67510	 1	 40.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67511	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67512	 1	 5.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67513	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67514	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67515	 1	 7.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67516	 1	 5.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67517	 1	 5.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67518	 1	 1.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67519	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67520	 1	 1.81	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67521	 1	 1.59	 0.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67522	 1	 6.9	 4.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67523	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67524	 1	 1.68	 0.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67525	 1	 1.4	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67526	 1	 1.71	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67527	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67528	 1	 5.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67529	 1	 5.91	 3.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67530	 1	 4.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67531	 1	 13.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67532	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67533	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67534	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67535	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67536	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67537	 1	 6.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67538	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67539	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67540	 1	 1.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67541	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67542	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67543	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67544	 1	 7.94	 5.29	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67545	 1	 3.58	 -16.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67546	 1	 8.75	 6.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67547	 1	 3.11	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67548	 1	 5.13	 3.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67549	 1	 4.07	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67550	 1	 1.26	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67551	 1	 1.38	 0.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67552	 1	 3.98	 2.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67553	 1	 8.77	 6.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67554	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67555	 1	 2.98	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67556	 1	 3.42	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67557	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67558	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67559	 1	 0.98	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67560	 1	 2.23	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67561	 1	 6.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67562	 1	 6.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67563	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67564	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67565	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67566	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67567	 1	 9.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67568	 1	 7.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67569	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67570	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67571	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67572	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67573	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67574	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67575	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67576	 1	 4.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67577	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67578	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67579	 1	 9.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67580	 1	 1.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67581	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67582	 1	 6.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67583	 1	 7.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67584	 1	 1.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67585	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67586	 1	 4.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67587	 1	 71.73	 54.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67588	 1	 4.63	 3.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67589	 1	 10.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67590	 1	 8.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67591	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67592	 1	 9.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67593	 1	 4.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67594	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67595	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67596	 1	 7.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67597	 1	 4.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67598	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67599	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67600	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67601	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67602	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67603	 1	 5.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67604	 1	 4.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67605	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67606	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67607	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67608	 1	 6.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67609	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67610	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67611	 1	 7.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67612	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67613	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67614	 1	 3.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67615	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67616	 1	 5.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67617	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67618	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67619	 1	 6.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67620	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67621	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67622	 1	 7.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67623	 1	 5.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67624	 1	 3.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67625	 1	 7.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67626	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67627	 1	 3.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67628	 1	 6.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67629	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67630	 1	 10.13	 -23.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67631	 1	 7.95	 5.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67632	 1	 10.89	 5.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67633	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67634	 1	 15.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67635	 1	 9.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67636	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67637	 1	 4.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67638	 1	 4.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67639	 1	 17.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67640	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67641	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67642	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67643	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67644	 1	 4.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67645	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67646	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67647	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67648	 1	 3.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67649	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67650	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67651	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67652	 1	 4.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67653	 1	 10.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67654	 1	 8.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67655	 1	 7.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67656	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67657	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67658	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67659	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67660	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67661	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67662	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67663	 1	 3.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67664	 1	 0.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67665	 1	 7.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67666	 1	 10.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67667	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67668	 1	 4.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67669	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67670	 1	 5.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67671	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67672	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67673	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67674	 1	 4.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67675	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67676	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67677	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67678	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67679	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67680	 1	 4.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67681	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67682	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67683	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67684	 1	 4.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67685	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67686	 1	 3.79	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67687	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67688	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67689	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67690	 1	 6.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67691	 1	 0.0	 0.0	 0.0	 55.24	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67692	 1	 5.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67693	 1	 4.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67694	 1	 1.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67695	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67696	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67697	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67698	 1	 0.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67699	 1	 7.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67700	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67701	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67702	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67703	 1	 7.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67704	 1	 5.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67705	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67706	 1	 4.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67707	 1	 6.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67708	 1	 6.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67709	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67710	 1	 8.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67711	 1	 10.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67712	 1	 7.88	 5.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67713	 1	 4.05	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67714	 1	 4.8	 3.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67715	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67716	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67717	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67718	 1	 4.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67719	 1	 11.68	 5.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67720	 1	 7.43	 -12.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67721	 1	 3.24	 -22.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67722	 1	 4.24	 3.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67723	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67724	 1	 9.98	 5.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67725	 1	 8.8	 3.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67726	 1	 3.98	 -14.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67727	 1	 0.0	 0.0	 0.0	 -8.58	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67728	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67729	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67730	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67731	 1	 6.31	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67732	 1	 7.73	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67733	 1	 8.39	 3.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67734	 1	 5.75	 4.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67735	 1	 2.27	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67736	 1	 3.15	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67737	 1	 4.53	 2.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67738	 1	 7.52	 4.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67739	 1	 17.15	 10.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67740	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67741	 1	 4.13	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67742	 1	 6.27	 4.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67743	 1	 3.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67744	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67745	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67746	 1	 5.57	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67747	 1	 7.94	 6.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67748	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67749	 1	 2.73	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67750	 1	 10.64	 8.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67751	 1	 9.3	 6.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67752	 1	 6.74	 4.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67753	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67754	 1	 4.02	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67755	 1	 11.55	 -20.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67756	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67757	 1	 1.92	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67758	 1	 4.97	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67759	 1	 6.18	 3.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67760	 1	 14.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67761	 1	 5.06	 4.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67762	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67763	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	67764	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67765	 1	 4.7	 3.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67766	 1	 12.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67767	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67768	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67769	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67770	 1	 8.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67771	 1	 5.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67772	 1	 4.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67773	 1	 8.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67774	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67775	 1	 7.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67776	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67777	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67778	 1	 6.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67779	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67780	 1	 4.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67781	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67782	 1	 3.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67783	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67784	 1	 4.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67785	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67786	 1	 8.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67787	 1	 10.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67788	 1	 8.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67789	 1	 4.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67790	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67791	 1	 4.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67792	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67793	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67794	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67795	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67796	 1	 7.08	 5.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67797	 1	 4.1	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67798	 1	 1.99	 1.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67799	 1	 1.52	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67800	 1	 5.65	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67801	 1	 5.74	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67802	 1	 9.0	 -13.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67803	 1	 4.44	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67804	 1	 1.07	 0.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67805	 1	 5.49	 3.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67806	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67807	 1	 5.54	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67808	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67809	 1	 5.08	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67810	 1	 10.3	 3.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67811	 1	 6.18	 4.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67812	 1	 6.69	 -24.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67813	 1	 4.58	 3.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67814	 1	 16.23	 12.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67815	 1	 2.3	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67816	 1	 4.5	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67817	 1	 5.83	 -19.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67818	 1	 9.13	 5.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67819	 1	 1.85	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67820	 1	 5.08	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67821	 1	 8.97	 6.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67822	 1	 5.1	 3.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67823	 1	 10.21	 8.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67824	 1	 2.71	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67825	 1	 4.32	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67826	 1	 1.78	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67827	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67828	 1	 1.37	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67829	 1	 1.24	 0.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67830	 1	 7.65	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67831	 1	 2.59	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67832	 1	 7.97	 4.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67833	 1	 29.13	 33.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67834	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67835	 1	 7.47	 -12.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67836	 1	 4.21	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67837	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67838	 1	 4.39	 2.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67839	 1	 4.02	 2.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67840	 1	 1.92	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67841	 1	 8.81	 6.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67842	 1	 0.0	 0.0	 0.0	 134.19	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	67843	 1	 12.12	 8.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67844	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67845	 1	 3.2	 -20.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67846	 1	 2.74	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67847	 1	 4.52	 2.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67848	 1	 7.15	 5.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67849	 1	 1.81	 1.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67850	 1	 2.61	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67851	 1	 1.9	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67852	 1	 3.68	 -14.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67853	 1	 1.88	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67854	 1	 7.54	 -14.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67855	 1	 8.57	 4.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67856	 1	 3.05	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67857	 1	 4.78	 3.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67858	 1	 2.44	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67859	 1	 2.83	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67860	 1	 3.53	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67861	 1	 7.94	 4.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67862	 1	 8.15	 5.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67863	 1	 9.67	 7.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67864	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67865	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67866	 1	 5.76	 2.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67867	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67868	 1	 7.49	 3.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67869	 1	 7.58	 4.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67870	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67871	 1	 3.19	 1.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67872	 1	 3.62	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67873	 1	 20.99	 18.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67874	 1	 6.86	 4.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67875	 1	 10.59	 5.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67876	 1	 6.55	 2.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67877	 1	 3.55	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67878	 1	 4.94	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67879	 1	 2.52	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67880	 1	 11.07	 8.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67881	 1	 2.29	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67882	 1	 3.91	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67883	 1	 2.27	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67884	 1	 5.07	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67885	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67886	 1	 6.1	 3.67	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67887	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67888	 1	 3.25	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67889	 1	 3.42	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67890	 1	 3.96	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67891	 1	 3.85	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67892	 1	 4.78	 2.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67893	 1	 2.57	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67894	 1	 11.19	 4.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67895	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67896	 1	 6.01	 3.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67897	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67898	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67899	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67900	 1	 5.92	 4.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67901	 1	 5.21	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67902	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67903	 1	 24.45	 20.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67904	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67905	 1	 12.25	 7.08	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67906	 1	 1.87	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67907	 1	 13.16	 9.32	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67908	 1	 8.43	 6.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67909	 1	 14.97	 11.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67910	 1	 5.19	 -20.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67911	 1	 57.9	 44.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67912	 1	 2.35	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67913	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67914	 1	 5.63	 5.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67915	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67916	 1	 2.19	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67917	 1	 12.02	 15.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67918	 1	 4.27	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67919	 1	 8.61	 3.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67920	 1	 7.51	 5.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67921	 1	 8.5	 6.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67922	 1	 4.71	 2.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67923	 1	 11.86	 9.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67924	 1	 6.55	 4.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67925	 1	 1.86	 0.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67926	 1	 2.21	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67927	 1	 6.66	 4.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67928	 1	 5.72	 4.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67929	 1	 18.19	 8.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67930	 1	 6.61	 4.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67931	 1	 6.0	 4.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67932	 1	 4.69	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67933	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67934	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67935	 1	 5.21	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67936	 1	 7.0	 5.23	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67937	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67938	 1	 18.86	 7.03	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67939	 1	 3.2	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67940	 1	 0.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67941	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67942	 1	 5.71	 1.73	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67943	 1	 2.47	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67944	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67945	 1	 4.1	 2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67946	 1	 4.75	 3.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67947	 1	 5.49	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67948	 1	 7.65	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67949	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67950	 1	 2.59	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67951	 1	 5.67	 2.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67952	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67953	 1	 7.98	 5.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67954	 1	 85.02	 62.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67955	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67956	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67957	 1	 5.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67958	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67959	 1	 5.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67960	 1	 3.51	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67961	 1	 5.42	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67962	 1	 2.34	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67963	 1	 2.82	 3.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67964	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67965	 1	 5.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67966	 1	 4.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67967	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67968	 1	 2.95	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67969	 1	 4.74	 2.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67970	 1	 5.31	 5.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67971	 1	 2.72	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67972	 1	 13.25	 10.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67973	 1	 3.41	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67974	 1	 7.34	 -7.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67975	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67976	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	67977	 1	 4.45	 3.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67978	 1	 3.48	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67979	 1	 4.91	 3.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67980	 1	 6.19	 3.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67981	 1	 3.43	 2.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67982	 1	 2.33	 0.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67983	 1	 7.39	 9.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67984	 1	 5.2	 3.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67985	 1	 1.5	 0.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67986	 1	 15.56	 -27.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67987	 1	 8.14	 6.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67988	 1	 6.95	 2.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67989	 1	 9.37	 4.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67990	 1	 6.82	 5.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67991	 1	 3.41	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67992	 1	 6.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67993	 1	 3.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67994	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67995	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67996	 1	 8.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67997	 1	 11.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67998	 1	 10.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	67999	 1	 6.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68000	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68001	 1	 7.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68002	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68003	 1	 7.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68004	 1	 7.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68005	 1	 4.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68006	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68007	 1	 21.75	 15.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68008	 1	 21.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68009	 1	 60.47	 47.19	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68010	 1	 3.1	 0.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68011	 1	 3.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68012	 1	 4.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68013	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68014	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68015	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68016	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68017	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68018	 1	 7.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68019	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68020	 1	 7.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68021	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68022	 1	 5.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68023	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68024	 1	 4.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68025	 1	 6.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68026	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68027	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68028	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68029	 1	 7.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68030	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68031	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68032	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68033	 1	 1.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68034	 1	 39.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68035	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68036	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68037	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68038	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68039	 1	 2.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68040	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68041	 1	 0.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68042	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68043	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68044	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68045	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68046	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68047	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68048	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68049	 1	 5.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68050	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68051	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68052	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68053	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68054	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68055	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68056	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68057	 1	 9.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68058	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68059	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68060	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68061	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68062	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68063	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68064	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68065	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68066	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68067	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68068	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68069	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68070	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68071	 1	 4.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68072	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68073	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68074	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68075	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68076	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68077	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68078	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68079	 1	 2.39	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68080	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68081	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68082	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68083	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68084	 1	 6.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68085	 1	 4.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68086	 1	 1.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68087	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68088	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68089	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68090	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68091	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68092	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68093	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68094	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68095	 1	 1.08	 0.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68096	 1	 2.68	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68097	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68098	 1	 1.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68099	 1	 4.11	 3.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68100	 1	 2.39	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68101	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68102	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68103	 1	 1.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68104	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68105	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68106	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68107	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68108	 1	 4.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68109	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68110	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68111	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68112	 1	 3.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68113	 1	 6.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68114	 1	 4.26	 3.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68115	 1	 3.88	 2.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68116	 1	 2.58	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68117	 1	 4.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68118	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68119	 1	 5.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68120	 1	 2.64	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68121	 1	 1.37	 0.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68122	 1	 1.83	 0.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68123	 1	 2.4	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68124	 1	 2.7	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68125	 1	 2.0	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68126	 1	 1.88	 1.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68127	 1	 4.99	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68128	 1	 3.94	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68129	 1	 5.96	 5.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68130	 1	 6.38	 3.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68131	 1	 3.3	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68132	 1	 0.0	 0.0	 0.0	 253.09	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	68133	 1	 6.38	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68134	 1	 3.03	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68135	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68136	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68137	 1	 0.0	 0.0	 0.0	 -100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68138	 1	 4.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68139	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68140	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68141	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68142	 1	 6.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68143	 1	 2.52	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68144	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68145	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68146	 1	 5.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68147	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68148	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68149	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68150	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68151	 1	 4.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68152	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68153	 1	 6.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68154	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68155	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68156	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68157	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68158	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68159	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68160	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68161	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68162	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68163	 1	 4.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68164	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68165	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68166	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68167	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68168	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68169	 1	 1.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68170	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68171	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68172	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68173	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68174	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68175	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68176	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68177	 1	 5.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68178	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68179	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68180	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68181	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68182	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68183	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68184	 1	 5.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68185	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68186	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68187	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68188	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68189	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68190	 1	 6.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68191	 1	 1.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68192	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68193	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68194	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68195	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68196	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68197	 1	 10.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68198	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68199	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68200	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68201	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68202	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68203	 1	 7.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68204	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68205	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68206	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68207	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68208	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68209	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68210	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68211	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68212	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68213	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68214	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68215	 1	 2.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68216	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68217	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68218	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68219	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68220	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68221	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68222	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68223	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68224	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68225	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68226	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68227	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68228	 1	 1.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68229	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68230	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68231	 1	 1.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68232	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68233	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68234	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68235	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68236	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68237	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68238	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68239	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68240	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68241	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68242	 1	 5.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68243	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68244	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68245	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68246	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68247	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68248	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68249	 1	 4.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68250	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68251	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68252	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68253	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68254	 1	 4.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68255	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68256	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68257	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68258	 1	 1.62	 -2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68259	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68260	 1	 1.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68261	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68262	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68263	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68264	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68265	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68266	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68267	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68268	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68269	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68270	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68271	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68272	 1	 1.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68273	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68274	 1	 3.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68275	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68276	 1	 2.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68277	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68278	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68279	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68280	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68281	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68282	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68283	 1	 3.5	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68284	 1	 4.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68285	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68286	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68287	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68288	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68289	 1	 4.39	 3.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68290	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68291	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68292	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68293	 1	 2.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68294	 1	 1.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68295	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68296	 1	 6.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68297	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68298	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68299	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68300	 1	 1.97	 1.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68301	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68302	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68303	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68304	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68305	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68306	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68307	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68308	 1	 2.74	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68309	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68310	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68311	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68312	 1	 2.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68313	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68314	 1	 3.11	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68315	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68316	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68317	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68318	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68319	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68320	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68321	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68322	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68323	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68324	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68325	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68326	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68327	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68328	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68329	 1	 4.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68330	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68331	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68332	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68333	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68334	 1	 6.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68335	 1	 3.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68336	 1	 3.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68337	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68338	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68339	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68340	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68341	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68342	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68343	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68344	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68345	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68346	 1	 0.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68347	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68348	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68349	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68350	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68351	 1	 2.34	 1.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68352	 1	 2.43	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68353	 1	 4.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68354	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68355	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68356	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68357	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68358	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68359	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68360	 1	 3.02	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68361	 1	 1.42	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68362	 1	 1.71	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68363	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68364	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68365	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68366	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68367	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68368	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68369	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68370	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68371	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68372	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68373	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68374	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68375	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68376	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68377	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68378	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68379	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68380	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68381	 1	 1.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68382	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68383	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68384	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68385	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68386	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68387	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68388	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68389	 1	 4.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68390	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68391	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68392	 1	 3.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68393	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68394	 1	 1.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68395	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68396	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68397	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68398	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68399	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68400	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68401	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68402	 1	 2.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68403	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68404	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68405	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68406	 1	 1.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68407	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68408	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68409	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68410	 1	 1.79	 -34.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68411	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68412	 1	 1.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68413	 1	 1.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68414	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68415	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68416	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68417	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68418	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68419	 1	 1.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68420	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68421	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68422	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68423	 1	 1.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68424	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68425	 1	 4.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68426	 1	 8.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68427	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68428	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68429	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68430	 1	 1.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68431	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68432	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68433	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68434	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68435	 1	 1.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68436	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68437	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68438	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68439	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68440	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68441	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68442	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68443	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68444	 1	 1.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68445	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68446	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68447	 1	 5.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68448	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68449	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68450	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68451	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68452	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68453	 1	 3.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68454	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68455	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68456	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68457	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68458	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68459	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68460	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68461	 1	 4.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68462	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68463	 1	 5.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68464	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68465	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68466	 1	 1.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68467	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68468	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68469	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68470	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68471	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68472	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68473	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68474	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68475	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68476	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68477	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68478	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68479	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68480	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68481	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68482	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68483	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68484	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68485	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68486	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68487	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68488	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68489	 1	 1.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68490	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68491	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68492	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68493	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68494	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68495	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68496	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68497	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68498	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68499	 1	 3.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68500	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68501	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68502	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68503	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68504	 1	 1.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68505	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68506	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68507	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68508	 1	 1.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68509	 1	 1.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68510	 1	 1.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68511	 1	 3.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68512	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68513	 1	 1.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68514	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68515	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68516	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68517	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68518	 1	 5.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68519	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68520	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68521	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68522	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68523	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68524	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68525	 1	 4.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68526	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68527	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68528	 1	 1.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68529	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68530	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68531	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68532	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68533	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68534	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68535	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68536	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68537	 1	 1.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68538	 1	 4.54	 -8.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68539	 1	 5.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68540	 1	 5.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68541	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68542	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68543	 1	 11.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68544	 1	 4.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68545	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68546	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68547	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68548	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68549	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68550	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68551	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68552	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68553	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68554	 1	 1.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68555	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68556	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68557	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68558	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68559	 1	 1.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68560	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68561	 1	 7.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68562	 1	 1.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68563	 1	 0.0	 0.0	 0.0	 170.34	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	68564	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68565	 1	 18.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68566	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68567	 1	 4.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68568	 1	 6.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68569	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68570	 1	 4.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68571	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68572	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68573	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68574	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68575	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68576	 1	 11.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68577	 1	 1.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68578	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68579	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68580	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68581	 1	 4.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68582	 1	 1.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68583	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68584	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68585	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68586	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68587	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68588	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68589	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68590	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68591	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68592	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68593	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68594	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68595	 1	 2.25	 -41.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68596	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68597	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68598	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68599	 1	 1.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68600	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68601	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68602	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68603	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68604	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68605	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68606	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68607	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68608	 1	 1.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68609	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68610	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68611	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68612	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68613	 1	 2.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68614	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68615	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68616	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68617	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68618	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68619	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68620	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68621	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68622	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68623	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68624	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68625	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68626	 1	 1.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68627	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68628	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68629	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68630	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68631	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68632	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68633	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68634	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68635	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68636	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68637	 1	 1.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68638	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68639	 1	 2.09	 -8.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68640	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68641	 1	 1.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68642	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68643	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68644	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68645	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68646	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68647	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68648	 1	 2.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68649	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68650	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68651	 1	 2.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68652	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68653	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68654	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68655	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68656	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68657	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68658	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68659	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68660	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68661	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68662	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68663	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68664	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68665	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68666	 1	 3.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68667	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68668	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68669	 1	 1.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68670	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68671	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68672	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68673	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68674	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68675	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68676	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68677	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68678	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68679	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68680	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68681	 1	 2.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68682	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68683	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68684	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68685	 1	 4.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68686	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68687	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68688	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68689	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68690	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68691	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68692	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68693	 1	 1.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68694	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68695	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68696	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68697	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68698	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68699	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68700	 1	 4.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68701	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68702	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68703	 1	 1.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68704	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68705	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68706	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68707	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68708	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68709	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68710	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68711	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68712	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68713	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68714	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68715	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68716	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68717	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68718	 1	 6.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68719	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68720	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68721	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68722	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68723	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68724	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68725	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68726	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68727	 1	 5.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68728	 1	 1.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68729	 1	 1.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68730	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68731	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68732	 1	 1.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68733	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68734	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68735	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68736	 1	 7.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68737	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68738	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68739	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68740	 1	 3.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68741	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68742	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68743	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68744	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68745	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68746	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68747	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68748	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68749	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68750	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68751	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68752	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68753	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68754	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68755	 1	 2.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68756	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68757	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68758	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68759	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68760	 1	 3.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68761	 1	 1.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68762	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68763	 1	 5.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68764	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68765	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68766	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68767	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68768	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68769	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68770	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68771	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68772	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68773	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68774	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68775	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68776	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68777	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68778	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68779	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68780	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68781	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68782	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68783	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68784	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68785	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68786	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68787	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68788	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68789	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68790	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68791	 1	 1.34	 0.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68792	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68793	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68794	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68795	 1	 3.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68796	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68797	 1	 1.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68798	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68799	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68800	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68801	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68802	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68803	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68804	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68805	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68806	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68807	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68808	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68809	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68810	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68811	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68812	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68813	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68814	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68815	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68816	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68817	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68818	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68819	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68820	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68821	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68822	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68823	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68824	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68825	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68826	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68827	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68828	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68829	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68830	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68831	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68832	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68833	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68834	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68835	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68836	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68837	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68838	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68839	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68840	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68841	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68842	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68843	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68844	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68845	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68846	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68847	 1	 2.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68848	 1	 1.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68849	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68850	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68851	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68852	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68853	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68854	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68855	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68856	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68857	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68858	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68859	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68860	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68861	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68862	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68863	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68864	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68865	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68866	 1	 1.56	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68867	 1	 2.17	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68868	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68869	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68870	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68871	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68872	 1	 2.12	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68873	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68874	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68875	 1	 1.43	 0.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68876	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68877	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68878	 1	 1.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68879	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68880	 1	 4.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68881	 1	 11.57	 -29.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68882	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68883	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68884	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68885	 1	 1.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68886	 1	 0.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68887	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68888	 1	 4.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68889	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68890	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68891	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68892	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68893	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68894	 1	 2.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68895	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68896	 1	 1.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68897	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68898	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68899	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68900	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68901	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68902	 1	 3.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68903	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68904	 1	 2.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68905	 1	 4.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68906	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68907	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68908	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68909	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68910	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68911	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68912	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68913	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68914	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68915	 1	 1.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68916	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68917	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68918	 1	 3.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68919	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68920	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68921	 1	 1.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68922	 1	 1.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68923	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68924	 1	 1.79	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68925	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68926	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68927	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68928	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68929	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68930	 1	 3.06	 -12.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68931	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68932	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68933	 1	 2.51	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68934	 1	 1.78	 0.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68935	 1	 1.63	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68936	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68937	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68938	 1	 1.88	 0.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68939	 1	 4.73	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68940	 1	 1.84	 0.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68941	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68942	 1	 0.0	 0.0	 0.0	 -8.78	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68943	 1	 1.27	 0.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68944	 1	 1.35	 1.02	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68945	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68946	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68947	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68948	 1	 3.5	 4.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68949	 1	 0.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68950	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68951	 1	 2.18	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68952	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68953	 1	 2.51	 1.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68954	 1	 3.33	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68955	 1	 2.77	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68956	 1	 7.64	 3.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68957	 1	 3.1	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68958	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68959	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68960	 1	 2.24	 1.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68961	 1	 3.87	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68962	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68963	 1	 2.63	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68964	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68965	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68966	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68967	 1	 5.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68968	 1	 1.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68969	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68970	 1	 0.0	 0.0	 0.0	 -10.07	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	68971	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68972	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68973	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68974	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68975	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68976	 1	 4.36	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68977	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68978	 1	 4.53	 1.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68979	 1	 8.63	 5.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68980	 1	 1.76	 1.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68981	 1	 5.36	 4.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68982	 1	 2.63	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68983	 1	 1.16	 0.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68984	 1	 2.04	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68985	 1	 4.17	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68986	 1	 8.97	 8.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68987	 1	 3.82	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68988	 1	 1.28	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68989	 1	 2.81	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68990	 1	 2.85	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68991	 1	 2.87	 2.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68992	 1	 2.24	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68993	 1	 2.02	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68994	 1	 6.46	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68995	 1	 3.06	 -30.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68996	 1	 5.12	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68997	 1	 2.23	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68998	 1	 3.05	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	68999	 1	 3.62	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69000	 1	 2.09	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69001	 1	 9.52	 7.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69002	 1	 1.94	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69003	 1	 3.59	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69004	 1	 4.67	 -22.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69005	 1	 2.06	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69006	 1	 1.49	 0.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69007	 1	 2.81	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69008	 1	 5.48	 3.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69009	 1	 4.44	 -4.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69010	 1	 2.16	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69011	 1	 2.58	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69012	 1	 2.77	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69013	 1	 4.36	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69014	 1	 1.88	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69015	 1	 1.86	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69016	 1	 2.58	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69017	 1	 2.05	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69018	 1	 3.82	 -28.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69019	 1	 1.25	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69020	 1	 1.9	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69021	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69022	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69023	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69024	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69025	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69026	 1	 4.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69027	 1	 5.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69028	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69029	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69030	 1	 6.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69031	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69032	 1	 4.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69033	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69034	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69035	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69036	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69037	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69038	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69039	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69040	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69041	 1	 0.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69042	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69043	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69044	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69045	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69046	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69047	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69048	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69049	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69050	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69051	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69052	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69053	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69054	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69055	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69056	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69057	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69058	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69059	 1	 6.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69060	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69061	 1	 2.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69062	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69063	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69064	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69065	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69066	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69067	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69068	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69069	 1	 7.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69070	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69071	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69072	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69073	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69074	 1	 6.45	 -39.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69075	 1	 8.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69076	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69077	 1	 8.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69078	 1	 4.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69079	 1	 4.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69080	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69081	 1	 4.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69082	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69083	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69084	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69085	 1	 6.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69086	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69087	 1	 6.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69088	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69089	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69090	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69091	 1	 5.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69092	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69093	 1	 3.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69094	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69095	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69096	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69097	 1	 1.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69098	 1	 7.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69099	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69100	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69101	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69102	 1	 1.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69103	 1	 6.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69104	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69105	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69106	 1	 5.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69107	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69108	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69109	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69110	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69111	 1	 6.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69112	 1	 1.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69113	 1	 10.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69114	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69115	 1	 1.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69116	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69117	 1	 8.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69118	 1	 4.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69119	 1	 8.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69120	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69121	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69122	 1	 4.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69123	 1	 4.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69124	 1	 4.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69125	 1	 5.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69126	 1	 4.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69127	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69128	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69129	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69130	 1	 3.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69131	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69132	 1	 7.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69133	 1	 7.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69134	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69135	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69136	 1	 4.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69137	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69138	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69139	 1	 2.98	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69140	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69141	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69142	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69143	 1	 4.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69144	 1	 6.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69145	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69146	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69147	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69148	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69149	 1	 5.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69150	 1	 1.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69151	 1	 5.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69152	 1	 6.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69153	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69154	 1	 6.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69155	 1	 7.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69156	 1	 4.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69157	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69158	 1	 2.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69159	 1	 1.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69160	 1	 9.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69161	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69162	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69163	 1	 4.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69164	 1	 6.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69165	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69166	 1	 4.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69167	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69168	 1	 8.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69169	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69170	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69171	 1	 3.35	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69172	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69173	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69174	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69175	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69176	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69177	 1	 1.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69178	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69179	 1	 0.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69180	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69181	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69182	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69183	 1	 7.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69184	 1	 6.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69185	 1	 6.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69186	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69187	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69188	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69189	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69190	 1	 4.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69191	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69192	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69193	 1	 3.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69194	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69195	 1	 5.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69196	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69197	 1	 4.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69198	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69199	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69200	 1	 0.0	 0.0	 0.0	 42.33	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69201	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69202	 1	 7.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69203	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69204	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69205	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69206	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69207	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69208	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69209	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69210	 1	 4.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69211	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69212	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69213	 1	 6.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69214	 1	 5.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69215	 1	 4.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69216	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69217	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69218	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69219	 1	 3.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69220	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69221	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69222	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69223	 1	 6.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69224	 1	 4.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69225	 1	 4.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69226	 1	 4.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69227	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69228	 1	 6.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69229	 1	 9.08	 -4.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69230	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69231	 1	 1.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69232	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69233	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69234	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69235	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69236	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69237	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69238	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69239	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69240	 1	 6.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69241	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69242	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69243	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69244	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69245	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69246	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69247	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69248	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69249	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69250	 1	 5.2	 -1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69251	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69252	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69253	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69254	 1	 3.01	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69255	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69256	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69257	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69258	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69259	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69260	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69261	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69262	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69263	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69264	 1	 1.33	 0.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69265	 1	 2.01	 0.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69266	 1	 1.86	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69267	 1	 3.54	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69268	 1	 3.27	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69269	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69270	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69271	 1	 2.94	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69272	 1	 0.0	 0.0	 0.0	 95.77	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	69273	 1	 35.31	 50.1	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69274	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69275	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69276	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69277	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69278	 1	 3.13	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69279	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69280	 1	 4.05	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69281	 1	 3.05	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69282	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69283	 1	 1.5	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69284	 1	 1.97	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69285	 1	 1.56	 0.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69286	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69287	 1	 2.71	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69288	 1	 1.59	 0.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69289	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69290	 1	 1.41	 0.67	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69291	 1	 1.53	 0.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69292	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69293	 1	 0.0	 0.0	 0.0	 140.47	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69294	 1	 1.73	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69295	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69296	 1	 0.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69297	 1	 2.13	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69298	 1	 1.77	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69299	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69300	 1	 4.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69301	 1	 5.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69302	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69303	 1	 11.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69304	 1	 8.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69305	 1	 0.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69306	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69307	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69308	 1	 5.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69309	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69310	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69311	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69312	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69313	 1	 7.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69314	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69315	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69316	 1	 5.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69317	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69318	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69319	 1	 7.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69320	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69321	 1	 6.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69322	 1	 7.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69323	 1	 14.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69324	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69325	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69326	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69327	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69328	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69329	 1	 5.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69330	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69331	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69332	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69333	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69334	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69335	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69336	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69337	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69338	 1	 12.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69339	 1	 4.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69340	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69341	 1	 4.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69342	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69343	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69344	 1	 6.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69345	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69346	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69347	 1	 5.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69348	 1	 7.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69349	 1	 4.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69350	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69351	 1	 9.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69352	 1	 4.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69353	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69354	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69355	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69356	 1	 1.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69357	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69358	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69359	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69360	 1	 5.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69361	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69362	 1	 4.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69363	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69364	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69366	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69367	 1	 5.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69368	 1	 7.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69369	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69370	 1	 3.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69371	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69372	 1	 1.35	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69373	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69374	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69375	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69376	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69377	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69378	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69379	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69380	 1	 5.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69381	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69382	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69383	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69384	 1	 5.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69385	 1	 5.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69386	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69387	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69388	 1	 3.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69389	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69390	 1	 2.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69391	 1	 3.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69392	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69393	 1	 0.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69394	 1	 3.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69395	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69396	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69397	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69398	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69399	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69400	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69401	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69402	 1	 3.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69403	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69404	 1	 6.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69405	 1	 1.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69406	 1	 9.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69407	 1	 4.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69408	 1	 6.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69409	 1	 7.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69410	 1	 1.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69411	 1	 5.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69412	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69413	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69414	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69415	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69416	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69417	 1	 5.56	 -7.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69418	 1	 4.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69419	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69420	 1	 5.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69421	 1	 4.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69422	 1	 5.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69423	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69424	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69425	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69426	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69427	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69428	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69429	 1	 1.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69430	 1	 1.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69431	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69432	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69433	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69434	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69435	 1	 5.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69436	 1	 4.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69437	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69438	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69439	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69440	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69441	 1	 5.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69442	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69443	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69444	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69445	 1	 1.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69446	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69447	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69448	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69449	 1	 4.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69450	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69451	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69452	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69453	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69454	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69455	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69456	 1	 5.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69457	 1	 2.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69458	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69459	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69460	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69461	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69462	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69463	 1	 1.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69464	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69465	 1	 1.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69466	 1	 3.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69467	 1	 1.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69468	 1	 4.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69469	 1	 5.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69470	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69471	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69472	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69473	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69474	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69475	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69476	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69477	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69478	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69479	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69480	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69481	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69482	 1	 2.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69483	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69484	 1	 6.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69485	 1	 1.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69486	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69487	 1	 2.01	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69488	 1	 3.7	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69489	 1	 5.45	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69490	 1	 9.72	 -15.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69491	 1	 6.19	 5.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69492	 1	 2.38	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69493	 1	 2.52	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69494	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69495	 1	 4.49	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69496	 1	 11.3	 7.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69497	 1	 3.87	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69498	 1	 4.4	 3.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69499	 1	 1.77	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69500	 1	 4.7	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69501	 1	 2.95	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69502	 1	 4.21	 2.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69503	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69504	 1	 1.8	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69505	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69506	 1	 3.78	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69507	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69508	 1	 2.4	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69509	 1	 2.01	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69510	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69511	 1	 2.36	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69512	 1	 2.54	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69513	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69514	 1	 5.54	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69515	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69516	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69517	 1	 5.66	 4.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69518	 1	 2.69	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69519	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69520	 1	 2.29	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69521	 1	 1.91	 0.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69522	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69523	 1	 3.75	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69524	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69525	 1	 0.0	 0.0	 0.0	 50.94	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69526	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69527	 1	 18.1	 22.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69528	 1	 2.71	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69529	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69530	 1	 3.95	 2.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69531	 1	 2.41	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69532	 1	 1.62	 0.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69533	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69534	 1	 2.24	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69535	 1	 2.3	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69536	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69537	 1	 1.74	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69538	 1	 3.94	 2.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69539	 1	 3.97	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69540	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69541	 1	 3.74	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69542	 1	 3.02	 1.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69543	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69544	 1	 3.57	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69545	 1	 2.27	 0.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69546	 1	 3.25	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69547	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69548	 1	 2.18	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69549	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69550	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69551	 1	 30.78	 40.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69552	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69553	 1	 2.8	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69554	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69555	 1	 0.0	 0.0	 0.0	 143.13	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69556	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69557	 1	 1.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69558	 1	 8.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69559	 1	 4.26	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69560	 1	 5.57	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69561	 1	 4.1	 2.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69562	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69563	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69564	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69565	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69566	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69567	 1	 7.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69568	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69569	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69570	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69571	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69572	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69573	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69574	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69575	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69576	 1	 5.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69577	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69578	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69579	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69580	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69581	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69582	 1	 9.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69583	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69584	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69585	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69586	 1	 2.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69587	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69588	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69589	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69590	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69591	 1	 3.47	 -5.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69592	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69593	 1	 2.17	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69594	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69595	 1	 2.78	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69596	 1	 7.18	 4.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69597	 1	 1.83	 0.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69598	 1	 15.17	 17.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69599	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69600	 1	 0.0	 0.0	 0.0	 -16.22	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69601	 1	 0.0	 0.0	 0.0	 300.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	69602	 1	 0.0	 0.0	 0.0	 82.13	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	69603	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69604	 1	 4.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69605	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69606	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69607	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69608	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69609	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69610	 1	 5.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69611	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69612	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69613	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69614	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69615	 1	 1.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69616	 1	 1.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69617	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69618	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69619	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69620	 1	 1.19	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69621	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69622	 1	 5.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69623	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69624	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69625	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69626	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69627	 1	 0.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69628	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69629	 1	 4.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69630	 1	 6.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69631	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69632	 1	 1.73	 0.61	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69633	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69634	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69635	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69636	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69637	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69638	 1	 2.92	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69639	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69640	 1	 3.32	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69641	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69642	 1	 3.77	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69643	 1	 3.25	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69644	 1	 2.14	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69645	 1	 3.21	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69646	 1	 3.69	 2.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69647	 1	 7.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69648	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69649	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69650	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69651	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69652	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69653	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69654	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69655	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69656	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69657	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69658	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69659	 1	 6.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69660	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69661	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69662	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69663	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69664	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69665	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69666	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69667	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69668	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69669	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69670	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69671	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69672	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69673	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69674	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69675	 1	 3.02	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69676	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69677	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69678	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69679	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69680	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69681	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69682	 1	 23.61	 -15.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69683	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69684	 1	 3.92	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69685	 1	 18.75	 22.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69686	 1	 8.8	 9.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69687	 1	 4.8	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69688	 1	 5.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69689	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69690	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69691	 1	 3.4	 2.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69692	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69693	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69694	 1	 1.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69695	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69696	 1	 3.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69697	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69698	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69699	 1	 4.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69700	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69701	 1	 17.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69702	 1	 20.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69703	 1	 23.01	 19.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69704	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69705	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69706	 1	 4.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69707	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69708	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69709	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69710	 1	 4.32	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69711	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69712	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69713	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69714	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69715	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69716	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69717	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69718	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69719	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69720	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69721	 1	 4.23	 2.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69722	 1	 4.52	 3.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69723	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69724	 1	 2.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69725	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69726	 1	 4.52	 6.17	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69727	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69728	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69729	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69730	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69731	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69732	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69733	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69734	 1	 11.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69735	 1	 3.64	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69736	 1	 0.0	 0.0	 0.0	 -11.5	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69737	 1	 20.97	 19.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69738	 1	 11.91	 7.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69739	 1	 4.21	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69740	 1	 8.92	 3.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69741	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69742	 1	 3.22	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69743	 1	 9.83	 4.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69744	 1	 2.3	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69745	 1	 7.25	 7.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69746	 1	 4.34	 4.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69747	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69748	 1	 3.03	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69749	 1	 5.05	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69750	 1	 5.26	 3.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69751	 1	 4.84	 3.08	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69752	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69753	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69754	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69755	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69756	 1	 2.62	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69757	 1	 0.94	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69758	 1	 7.21	 5.73	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69759	 1	 1.42	 0.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69760	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69761	 1	 13.66	 10.73	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69762	 1	 2.17	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69763	 1	 4.48	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69764	 1	 3.13	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69765	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69766	 1	 3.54	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69767	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69768	 1	 2.74	 1.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69769	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69770	 1	 6.34	 3.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69771	 1	 0.0	 0.0	 0.0	 100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69772	 1	 12.46	 11.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69773	 1	 3.16	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69774	 1	 7.18	 5.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69775	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69776	 1	 2.12	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69777	 1	 6.76	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69778	 1	 2.86	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69779	 1	 2.16	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69780	 1	 2.6	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69781	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69782	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69783	 1	 2.78	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69784	 1	 3.21	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69785	 1	 2.51	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69786	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69787	 1	 5.68	 4.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69788	 1	 2.57	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69789	 1	 2.4	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69790	 1	 2.92	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69791	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69792	 1	 2.54	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69793	 1	 3.37	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69794	 1	 4.01	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69795	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69796	 1	 5.76	 4.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69797	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69798	 1	 0.0	 0.0	 0.0	 100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69799	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69800	 1	 2.27	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69801	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69802	 1	 1.44	 0.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69803	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69804	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69805	 1	 2.69	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69806	 1	 3.78	 2.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69807	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69808	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69809	 1	 9.55	 8.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69810	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69811	 1	 3.62	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69812	 1	 2.73	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69813	 1	 6.0	 3.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69814	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69815	 1	 1.17	 0.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69816	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69817	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69818	 1	 2.29	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69819	 1	 2.19	 1.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69820	 1	 2.53	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69821	 1	 4.09	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69822	 1	 2.33	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69823	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69824	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69825	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69826	 1	 4.09	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69827	 1	 3.5	 3.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69828	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69829	 1	 1.21	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69830	 1	 2.73	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69831	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69832	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69833	 1	 3.58	 1.45	 0.0	 48.26	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69834	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69835	 1	 0.0	 0.0	 0.0	 -27.63	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69836	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69837	 1	 5.1	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69838	 1	 3.85	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69839	 1	 3.2	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69840	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69841	 1	 6.25	 2.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69842	 1	 5.93	 3.78	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69843	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69844	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69845	 1	 4.58	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69846	 1	 2.28	 1.02	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69847	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69848	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69849	 1	 3.83	 2.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69850	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69851	 1	 3.48	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69852	 1	 1.91	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69853	 1	 3.48	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69854	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69855	 1	 6.22	 4.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69856	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69857	 1	 1.99	 0.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69858	 1	 4.66	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69859	 1	 2.05	 0.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69860	 1	 3.52	 2.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69861	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69862	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69863	 1	 1.69	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69864	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69865	 1	 34.25	 29.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69866	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69867	 1	 3.38	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69868	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69869	 1	 5.19	 2.69	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69870	 1	 2.81	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69871	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69872	 1	 4.87	 2.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69873	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69874	 1	 3.9	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69875	 1	 2.72	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69876	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69877	 1	 4.6	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69878	 1	 2.13	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69879	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69880	 1	 6.75	 5.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69881	 1	 2.81	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69882	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69883	 1	 0.99	 0.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69884	 1	 4.8	 2.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69885	 1	 2.18	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69886	 1	 2.49	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69887	 1	 1.84	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69888	 1	 4.3	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69889	 1	 6.95	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69890	 1	 3.87	 2.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69891	 1	 0.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69892	 1	 3.63	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69893	 1	 10.03	 7.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69894	 1	 2.31	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69895	 1	 2.3	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69896	 1	 0.99	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69897	 1	 1.73	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69898	 1	 3.0	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69899	 1	 3.98	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69900	 1	 2.2	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69901	 1	 2.77	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69902	 1	 2.33	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69903	 1	 1.08	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69904	 1	 2.49	 1.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69905	 1	 5.09	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69906	 1	 3.61	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69907	 1	 3.72	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69908	 1	 4.23	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69909	 1	 6.03	 4.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69910	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69911	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69912	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69913	 1	 2.3	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69914	 1	 2.07	 0.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69915	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69916	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69917	 1	 2.87	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69918	 1	 2.12	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69919	 1	 4.34	 2.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69920	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69921	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69922	 1	 4.09	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69923	 1	 0.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69924	 1	 0.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69925	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69926	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69927	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69928	 1	 5.68	 3.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69929	 1	 4.2	 2.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69930	 1	 3.36	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69931	 1	 2.3	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69932	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69933	 1	 5.54	 4.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69934	 1	 3.27	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69935	 1	 3.76	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69936	 1	 4.02	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69937	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69938	 1	 2.68	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69939	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69940	 1	 3.12	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69941	 1	 2.49	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69942	 1	 2.01	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69943	 1	 1.67	 0.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69944	 1	 3.73	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69945	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69946	 1	 7.88	 -9.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69947	 1	 4.4	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69948	 1	 2.19	 1.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69949	 1	 2.72	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69950	 1	 2.91	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69951	 1	 2.53	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69952	 1	 2.34	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69953	 1	 2.4	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69954	 1	 2.15	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69955	 1	 2.22	 1.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69956	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69957	 1	 2.36	 0.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69958	 1	 2.29	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69959	 1	 2.95	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69960	 1	 3.25	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69961	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69962	 1	 1.9	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69963	 1	 5.76	 4.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69964	 1	 3.77	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69965	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69966	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69967	 1	 1.88	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69968	 1	 2.58	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69969	 1	 0.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69970	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	69971	 1	 4.08	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69972	 1	 1.72	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69973	 1	 3.05	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69974	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69975	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69976	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69977	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69978	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69979	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69980	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69981	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69982	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69983	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69984	 1	 1.7	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69985	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69986	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69987	 1	 1.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69988	 1	 2.15	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69989	 1	 1.77	 0.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69990	 1	 1.87	 1.02	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69991	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69992	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69993	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69994	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69995	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69996	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69997	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69998	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	69999	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70000	 1	 1.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70001	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70002	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70003	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70004	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70005	 1	 4.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70006	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70007	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70008	 1	 3.44	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70009	 1	 2.85	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70010	 1	 2.25	 1.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70011	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70012	 1	 1.54	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70013	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70014	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70015	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70016	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70017	 1	 3.19	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70018	 1	 3.06	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70019	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70020	 1	 6.99	 4.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70021	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70022	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70023	 1	 2.52	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70024	 1	 3.34	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70025	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70026	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70027	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70028	 1	 2.42	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70029	 1	 3.9	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70030	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70031	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70032	 1	 11.48	 9.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70033	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70034	 1	 2.28	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70035	 1	 27.36	 29.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70036	 1	 3.96	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70037	 1	 3.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70038	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70039	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70040	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70041	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70042	 1	 5.57	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70043	 1	 2.97	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70044	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70045	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70046	 1	 1.69	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70047	 1	 2.87	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70048	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70049	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70050	 1	 3.68	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70051	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70052	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70053	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70054	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70055	 1	 2.65	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70056	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70057	 1	 1.9	 0.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70058	 1	 3.09	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70059	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70060	 1	 3.92	 2.45	 0.0	 -358.82	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70061	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70062	 1	 0.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70063	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70064	 1	 3.01	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70065	 1	 4.13	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70066	 1	 13.33	 9.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70067	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70068	 1	 2.08	 0.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70069	 1	 2.95	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70070	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70071	 1	 3.13	 2.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70072	 1	 4.67	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70073	 1	 3.51	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70074	 1	 4.68	 2.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70075	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70076	 1	 1.5	 0.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70077	 1	 3.73	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70078	 1	 0.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70079	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70080	 1	 2.11	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70081	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70082	 1	 4.44	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70083	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70084	 1	 3.98	 -0.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70085	 1	 2.7	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70086	 1	 2.6	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70087	 1	 3.56	 -1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70088	 1	 5.19	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70089	 1	 1.83	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70090	 1	 2.85	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70091	 1	 4.07	 2.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70092	 1	 2.21	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70093	 1	 4.76	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70094	 1	 8.79	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70095	 1	 0.0	 0.0	 0.0	 -200.73	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70096	 1	 8.13	 5.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70097	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70098	 1	 10.01	 6.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70099	 1	 2.35	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70100	 1	 3.92	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70101	 1	 2.15	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70102	 1	 6.08	 4.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70103	 1	 2.42	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70104	 1	 8.2	 4.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70105	 1	 0.0	 0.0	 0.0	 -61.74	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70106	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70107	 1	 2.67	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70108	 1	 3.25	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70109	 1	 35.93	 46.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70110	 1	 5.23	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70111	 1	 3.26	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70112	 1	 2.41	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70113	 1	 7.6	 5.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70114	 1	 5.6	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70115	 1	 2.47	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70116	 1	 3.82	 1.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70117	 1	 6.4	 3.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70118	 1	 3.23	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70119	 1	 3.67	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70120	 1	 4.12	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70121	 1	 6.18	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70122	 1	 2.5	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70123	 1	 2.78	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70124	 1	 3.09	 -30.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70125	 1	 1.84	 1.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70126	 1	 2.79	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70127	 1	 3.52	 -2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70128	 1	 2.4	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70129	 1	 1.02	 0.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70130	 1	 2.78	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70131	 1	 2.65	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70132	 1	 2.31	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70133	 1	 2.2	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70134	 1	 0.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70135	 1	 4.47	 2.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70136	 1	 4.24	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70137	 1	 2.74	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70138	 1	 4.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70139	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70140	 1	 4.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70141	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70142	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70143	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70144	 1	 4.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70145	 1	 2.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70146	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70147	 1	 6.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70148	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70149	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70150	 1	 4.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70151	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70152	 1	 6.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70153	 1	 2.24	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70154	 1	 1.58	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70155	 1	 3.59	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70156	 1	 3.89	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70157	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70158	 1	 3.74	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70159	 1	 6.35	 4.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70160	 1	 3.34	 2.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70161	 1	 7.83	 6.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70162	 1	 3.95	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70163	 1	 8.2	 6.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70164	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70165	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70166	 1	 0.0	 0.0	 0.0	 53.06	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70167	 1	 5.51	 2.17	 0.0	 2.85	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70168	 1	 3.25	 1.67	 0.0	 6.18	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70169	 1	 4.62	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70170	 1	 2.42	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70171	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70172	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70173	 1	 5.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70174	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70175	 1	 6.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70176	 1	 5.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70177	 1	 7.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70178	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70179	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70180	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70181	 1	 8.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70182	 1	 5.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70183	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70184	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70185	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70186	 1	 0.0	 0.0	 0.0	 20.26	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70187	 1	 3.05	 1.69	 0.0	 20.84	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70188	 1	 5.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70189	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70190	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70191	 1	 1.95	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70192	 1	 5.74	 5.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70193	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70194	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70195	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70196	 1	 0.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70197	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70198	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70199	 1	 2.3	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70200	 1	 4.87	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70201	 1	 6.05	 4.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70202	 1	 5.09	 4.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70203	 1	 2.2	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70204	 1	 0.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70205	 1	 3.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70206	 1	 4.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70207	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70208	 1	 7.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70209	 1	 4.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70210	 1	 5.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70211	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70212	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70213	 1	 4.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70214	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70215	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70216	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70217	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70218	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70219	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70220	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70221	 1	 3.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70222	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70223	 1	 4.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70224	 1	 5.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70225	 1	 5.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70226	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70227	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70228	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70229	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70230	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70231	 1	 6.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70232	 1	 1.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70233	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70234	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70235	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70236	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70237	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70238	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70239	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70240	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70241	 1	 0.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70242	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70243	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70244	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70245	 1	 3.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70246	 1	 8.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70247	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70248	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70249	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70250	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70251	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70252	 1	 4.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70253	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70254	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70255	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70256	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70257	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70258	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70259	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70260	 1	 5.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70261	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70262	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70263	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70264	 1	 5.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70265	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70266	 1	 6.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70267	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70268	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70269	 1	 6.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70270	 1	 7.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70271	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70272	 1	 0.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70273	 1	 7.44	 -5.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70274	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70275	 1	 6.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70276	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70277	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70278	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70279	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70280	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70281	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70282	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70283	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70284	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70285	 1	 0.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70286	 1	 0.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70287	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70288	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70289	 1	 0.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70290	 1	 0.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70291	 1	 4.43	 3.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70292	 1	 3.06	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70293	 1	 2.98	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70294	 1	 4.55	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70295	 1	 1.1	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70296	 1	 4.17	 1.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70297	 1	 3.31	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70298	 1	 0.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70299	 1	 3.15	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70300	 1	 1.93	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70301	 1	 4.35	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70302	 1	 4.73	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70303	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70304	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70305	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70306	 1	 6.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70307	 1	 4.51	 2.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70308	 1	 4.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70309	 1	 2.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70310	 1	 0.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70311	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70312	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70313	 1	 7.36	 2.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70314	 1	 5.72	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70315	 1	 1.91	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70316	 1	 2.23	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70317	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70318	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70319	 1	 14.04	 6.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70320	 1	 0.0	 0.0	 0.0	 155.8	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70321	 1	 1.76	 0.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70322	 1	 4.42	 2.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70323	 1	 2.62	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70324	 1	 2.48	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70325	 1	 2.48	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70326	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70327	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70328	 1	 3.01	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70329	 1	 3.89	 2.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70330	 1	 0.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70331	 1	 6.92	 3.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70332	 1	 5.2	 3.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70333	 1	 5.0	 2.73	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70334	 1	 4.54	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70335	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70336	 1	 5.18	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70337	 1	 5.24	 3.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70338	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70339	 1	 7.54	 3.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70340	 1	 5.04	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70341	 1	 1.97	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70342	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70343	 1	 3.18	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70344	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70345	 1	 3.91	 -11.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70346	 1	 2.76	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70347	 1	 10.92	 8.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70348	 1	 1.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70349	 1	 1.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70350	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70351	 1	 1.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70352	 1	 10.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70353	 1	 0.0	 0.0	 0.0	 -379.52	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70354	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70355	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70356	 1	 27.37	 30.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70357	 1	 0.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70358	 1	 0.41	 0.0	 0.0	 -187.4	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70359	 1	 15.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70360	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70361	 1	 0.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70362	 1	 0.0	 0.0	 0.0	 -292.05	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70363	 1	 40.99	 28.29	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70364	 1	 21.6	 24.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70366	 1	 0.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70367	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70368	 1	 0.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70369	 1	 0.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70370	 1	 0.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70371	 1	 0.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70372	 1	 41.38	 43.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70373	 1	 0.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70374	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70375	 1	 24.49	 36.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70376	 1	 59.69	 25.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70377	 1	 70.91	 33.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70378	 1	 8.42	 7.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70379	 1	 10.2	 7.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70380	 1	 6.7	 5.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70381	 1	 4.16	 2.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70382	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70383	 1	 5.04	 3.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70384	 1	 8.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70385	 1	 9.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70386	 1	 13.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70387	 1	 2.46	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70388	 1	 14.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70389	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70390	 1	 6.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70391	 1	 10.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70392	 1	 12.69	 12.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70393	 1	 4.76	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70394	 1	 4.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70395	 1	 2.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70396	 1	 3.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70397	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70398	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70399	 1	 8.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70400	 1	 14.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70401	 1	 9.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70402	 1	 9.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70403	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70404	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70405	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70406	 1	 5.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70407	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70408	 1	 5.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70409	 1	 6.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70410	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70411	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70412	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70413	 1	 5.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70414	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70415	 1	 4.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70416	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70417	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70418	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70419	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70420	 1	 8.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70421	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70422	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70423	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70424	 1	 5.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70425	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70426	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70427	 1	 5.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70428	 1	 2.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70429	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70430	 1	 2.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70431	 1	 5.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70432	 1	 1.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70433	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70434	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70435	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70436	 1	 5.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70437	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70438	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70439	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70440	 1	 1.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70441	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70442	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70443	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70444	 1	 6.48	 -11.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70445	 1	 5.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70446	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70447	 1	 6.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70448	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70449	 1	 1.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70450	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70451	 1	 5.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70452	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70453	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70454	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70455	 1	 9.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70456	 1	 7.47	 4.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70457	 1	 1.82	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70458	 1	 2.97	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70459	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70460	 1	 4.27	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70461	 1	 9.36	 5.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70462	 1	 2.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70463	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70464	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70465	 1	 5.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70466	 1	 7.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70467	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70468	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70469	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70470	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70471	 1	 9.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70472	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70473	 1	 6.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70474	 1	 5.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70475	 1	 3.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70476	 1	 8.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70477	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70478	 1	 12.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70479	 1	 13.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70480	 1	 5.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70481	 1	 3.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70482	 1	 4.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70483	 1	 1.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70484	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70485	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70486	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70487	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70488	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70489	 1	 9.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70490	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70491	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70492	 1	 5.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70493	 1	 4.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70494	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70495	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70496	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70497	 1	 8.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70498	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70499	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70500	 1	 11.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70501	 1	 5.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70502	 1	 8.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70503	 1	 5.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70504	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70505	 1	 6.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70506	 1	 4.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70507	 1	 5.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70508	 1	 13.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70509	 1	 6.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70510	 1	 5.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70511	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70512	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70513	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70514	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70515	 1	 4.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70516	 1	 5.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70517	 1	 5.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70518	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70519	 1	 5.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70520	 1	 2.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70521	 1	 15.45	 10.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70522	 1	 15.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70523	 1	 12.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70524	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70525	 1	 11.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70526	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70527	 1	 2.28	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70528	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70529	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70530	 1	 5.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70531	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70532	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70533	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70534	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70535	 1	 8.63	 5.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70536	 1	 10.29	 4.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70537	 1	 9.22	 -17.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70538	 1	 1.62	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70539	 1	 5.29	 3.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70540	 1	 5.77	 3.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70541	 1	 1.68	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70542	 1	 4.14	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70543	 1	 2.53	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70544	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70545	 1	 2.44	 0.75	 0.0	 283.76	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70546	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70547	 1	 3.86	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70548	 1	 3.11	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70549	 1	 3.38	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70550	 1	 2.82	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70551	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70552	 1	 2.56	 1.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70553	 1	 2.87	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70554	 1	 1.6	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70555	 1	 3.18	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70556	 1	 1.27	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70557	 1	 2.44	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70558	 1	 4.75	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70559	 1	 3.47	 2.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70560	 1	 5.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70561	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70562	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70563	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70564	 1	 4.29	 3.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70565	 1	 5.66	 3.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70566	 1	 13.29	 9.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70567	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70568	 1	 2.36	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70569	 1	 3.31	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70570	 1	 3.63	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70571	 1	 2.97	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70572	 1	 2.55	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70573	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70574	 1	 2.14	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70575	 1	 3.09	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70576	 1	 5.41	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70577	 1	 3.22	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70578	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70579	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70580	 1	 3.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70581	 1	 5.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70582	 1	 6.77	 4.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70583	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70584	 1	 4.79	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70585	 1	 3.92	 2.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70586	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70587	 1	 3.26	 1.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70588	 1	 12.42	 6.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70589	 1	 6.32	 3.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70590	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70591	 1	 4.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70592	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70593	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70594	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70595	 1	 0.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70596	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70597	 1	 4.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70598	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70599	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70600	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70601	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70602	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70603	 1	 5.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70604	 1	 1.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70605	 1	 9.37	 -33.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70606	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70607	 1	 6.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70608	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70609	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70610	 1	 11.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70611	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70612	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70613	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70614	 1	 3.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70615	 1	 2.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70616	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70617	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70618	 1	 3.24	 1.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70619	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70620	 1	 1.29	 0.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70621	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70622	 1	 4.58	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70623	 1	 6.57	 -14.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70624	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70625	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70626	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	70627	 1	 4.09	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70628	 1	 4.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70629	 1	 9.91	 5.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70630	 1	 0.47	 0.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70631	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70632	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70633	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70634	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70635	 1	 1.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70636	 1	 3.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70637	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70638	 1	 6.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70639	 1	 4.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70640	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70641	 1	 7.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70642	 1	 3.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70643	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70644	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70645	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70646	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70647	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70648	 1	 4.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70649	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70650	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70651	 1	 9.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70652	 1	 7.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70653	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70654	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70655	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70656	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70657	 1	 0.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70658	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70659	 1	 5.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70660	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70661	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70662	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70663	 1	 0.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70664	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70665	 1	 3.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70666	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70667	 1	 7.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70668	 1	 4.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70669	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70670	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70671	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70672	 1	 5.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70673	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70674	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70675	 1	 1.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70676	 1	 2.77	 1.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70677	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70678	 1	 4.16	 -13.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70679	 1	 7.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70680	 1	 4.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70681	 1	 10.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70682	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70683	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70684	 1	 3.69	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70685	 1	 5.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70686	 1	 6.19	 3.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70687	 1	 2.26	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70688	 1	 3.01	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70689	 1	 3.22	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70690	 1	 7.13	 3.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70691	 1	 4.13	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70692	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70693	 1	 8.41	 4.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70694	 1	 2.86	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70695	 1	 2.24	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70696	 1	 4.94	 3.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70697	 1	 5.37	 3.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70698	 1	 4.94	 4.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70699	 1	 5.08	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70700	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70701	 1	 1.56	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70702	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70703	 1	 6.64	 5.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70704	 1	 9.25	 9.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70705	 1	 5.83	 4.29	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70706	 1	 4.03	 2.71	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70707	 1	 2.39	 1.64	 0.0	 66.47	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70708	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70709	 1	 5.39	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70710	 1	 2.26	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70711	 1	 5.33	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70712	 1	 3.04	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70713	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70714	 1	 4.74	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70715	 1	 3.46	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70716	 1	 5.81	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70717	 1	 4.17	 3.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70718	 1	 2.07	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70719	 1	 1.84	 1.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70720	 1	 2.87	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70721	 1	 7.85	 7.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70722	 1	 4.25	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70723	 1	 2.61	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70724	 1	 5.69	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70725	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70726	 1	 2.65	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70727	 1	 1.12	 0.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70728	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70729	 1	 3.83	 3.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70730	 1	 0.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70731	 1	 5.81	 4.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70732	 1	 7.62	 5.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70733	 1	 0.0	 0.0	 0.0	 177.7	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70734	 1	 4.97	 4.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70735	 1	 3.01	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70736	 1	 3.43	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70737	 1	 2.28	 0.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70738	 1	 6.29	 4.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70739	 1	 2.35	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70740	 1	 60.54	 54.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70741	 1	 3.69	 2.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70742	 1	 2.64	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70743	 1	 1.63	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70744	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70745	 1	 7.8	 6.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70746	 1	 3.47	 1.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70747	 1	 6.8	 0.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70748	 1	 5.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70749	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70750	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70751	 1	 6.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70752	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70753	 1	 16.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70754	 1	 9.03	 4.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70755	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70756	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70757	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70758	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70759	 1	 5.75	 -2.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70760	 1	 5.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70761	 1	 1.59	 -3.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70762	 1	 1.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70763	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70764	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70765	 1	 1.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70766	 1	 2.1	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70767	 1	 3.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70768	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70769	 1	 4.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70770	 1	 5.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70771	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70772	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70773	 1	 2.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70774	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70775	 1	 1.7	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70776	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70777	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70778	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70779	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70780	 1	 2.17	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70781	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70782	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70783	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70784	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70785	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70786	 1	 0.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70787	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70788	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70789	 1	 6.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70790	 1	 6.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70791	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70792	 1	 8.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70793	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70794	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70795	 1	 6.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70796	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70797	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70798	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70799	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70800	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70801	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70802	 1	 1.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70803	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70804	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70805	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70806	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70807	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70808	 1	 0.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70809	 1	 4.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70810	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70811	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70812	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70813	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70814	 1	 3.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70815	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70816	 1	 4.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70817	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70818	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70819	 1	 6.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70820	 1	 5.21	 -40.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70821	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70822	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70823	 1	 6.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70824	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70825	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70826	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70827	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70828	 1	 3.12	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70829	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70830	 1	 2.85	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70831	 1	 3.88	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70832	 1	 2.89	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70833	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70834	 1	 3.85	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70835	 1	 1.9	 0.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70836	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70837	 1	 3.49	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70838	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70839	 1	 2.4	 1.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70840	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70841	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70842	 1	 4.66	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70843	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70844	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70845	 1	 4.35	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70846	 1	 5.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70847	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70848	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70849	 1	 7.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70850	 1	 2.38	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70851	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70852	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70853	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70854	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70855	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70856	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70857	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70858	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70859	 1	 2.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70860	 1	 4.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70861	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70862	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70863	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70864	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70865	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70866	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70867	 1	 10.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70868	 1	 8.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70869	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70870	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70871	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70872	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70873	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70874	 1	 7.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70875	 1	 1.67	 0.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70876	 1	 12.18	 4.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70877	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70878	 1	 8.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70879	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70880	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70881	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70882	 1	 8.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70883	 1	 9.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70884	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70885	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70886	 1	 2.81	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70887	 1	 1.61	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70888	 1	 3.86	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70889	 1	 3.15	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70890	 1	 3.9	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70891	 1	 4.26	 2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70892	 1	 6.61	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70893	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70894	 1	 2.03	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70895	 1	 1.67	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70896	 1	 5.98	 4.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70897	 1	 1.99	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70898	 1	 3.55	 2.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70899	 1	 10.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70900	 1	 9.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70901	 1	 2.82	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70902	 1	 6.71	 5.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70903	 1	 1.68	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70904	 1	 8.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70905	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70906	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70907	 1	 1.98	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70908	 1	 6.3	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70909	 1	 12.02	 6.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70910	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70911	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70912	 1	 5.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70913	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70914	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70915	 1	 1.34	 0.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70916	 1	 3.23	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70917	 1	 1.73	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70918	 1	 1.28	 0.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70919	 1	 0.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70920	 1	 1.59	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70921	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70922	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70923	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70924	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70925	 1	 1.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70926	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70927	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70928	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70929	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70930	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70931	 1	 1.37	 0.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70932	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70933	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70934	 1	 3.34	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70935	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70936	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70937	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70938	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70939	 1	 1.56	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70940	 1	 3.4	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70941	 1	 2.24	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70942	 1	 3.06	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70943	 1	 2.5	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70944	 1	 1.33	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70945	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70946	 1	 3.07	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70947	 1	 0.91	 0.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70948	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70949	 1	 1.83	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70950	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70951	 1	 1.27	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70952	 1	 1.84	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70953	 1	 2.02	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70954	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70955	 1	 3.85	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70956	 1	 3.03	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70957	 1	 4.08	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70958	 1	 1.99	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70959	 1	 9.72	 9.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70960	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70961	 1	 5.19	 3.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70962	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70963	 1	 5.78	 3.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70964	 1	 1.72	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70965	 1	 2.14	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70966	 1	 1.37	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70967	 1	 3.06	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70968	 1	 5.36	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70969	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70970	 1	 10.83	 4.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70971	 1	 2.98	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70972	 1	 2.68	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70973	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70974	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70975	 1	 9.03	 5.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70976	 1	 4.05	 3.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70977	 1	 20.8	 30.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70978	 1	 4.0	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70979	 1	 4.4	 3.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70980	 1	 6.57	 3.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70981	 1	 3.91	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70982	 1	 2.53	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70983	 1	 0.0	 0.0	 0.0	 48.81	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70984	 1	 4.72	 3.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70985	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70986	 1	 1.94	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70987	 1	 1.86	 0.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70988	 1	 2.99	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70989	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70990	 1	 2.14	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70991	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70992	 1	 5.11	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70993	 1	 4.45	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70994	 1	 3.23	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70995	 1	 2.94	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70996	 1	 3.32	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70997	 1	 3.25	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70998	 1	 4.61	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	70999	 1	 4.72	 2.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71000	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71001	 1	 3.46	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71002	 1	 2.75	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71003	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71004	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71005	 1	 2.98	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71006	 1	 2.64	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71007	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71008	 1	 3.2	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71009	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71010	 1	 4.52	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71011	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71012	 1	 6.86	 3.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71013	 1	 2.97	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71014	 1	 2.91	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71015	 1	 3.88	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71016	 1	 4.62	 3.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71017	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71018	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71019	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71020	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71021	 1	 2.26	 0.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71022	 1	 3.18	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71023	 1	 6.82	 6.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71024	 1	 2.91	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71025	 1	 4.04	 2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71026	 1	 2.02	 0.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71027	 1	 2.65	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71028	 1	 2.3	 0.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71029	 1	 0.0	 0.0	 0.0	 600.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	71030	 1	 2.34	 1.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71031	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71032	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71033	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71034	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71035	 1	 5.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71036	 1	 1.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71037	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71038	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71039	 1	 5.61	 3.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71040	 1	 2.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71041	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71042	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71043	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71044	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71045	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71046	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71047	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71048	 1	 2.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71049	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71050	 1	 3.04	 1.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71051	 1	 3.68	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71052	 1	 9.21	 3.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71053	 1	 12.04	 9.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71054	 1	 7.19	 5.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71055	 1	 4.92	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71056	 1	 3.63	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71057	 1	 4.44	 2.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71058	 1	 0.0	 0.0	 0.0	 100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71059	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71060	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71061	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71062	 1	 6.63	 5.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71063	 1	 32.3	 33.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71064	 1	 3.05	 2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71065	 1	 3.16	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71066	 1	 2.28	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71067	 1	 7.13	 3.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71068	 1	 4.23	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71069	 1	 4.5	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71070	 1	 2.6	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71071	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71072	 1	 8.25	 5.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71073	 1	 6.79	 3.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71074	 1	 5.24	 3.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71075	 1	 3.37	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71076	 1	 5.36	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71077	 1	 4.75	 3.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71078	 1	 6.62	 4.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71079	 1	 5.48	 3.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71080	 1	 4.63	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71081	 1	 5.03	 3.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71082	 1	 3.02	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71083	 1	 4.44	 3.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71084	 1	 4.0	 3.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71085	 1	 3.64	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71086	 1	 2.44	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71087	 1	 9.61	 10.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71088	 1	 6.23	 4.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71089	 1	 6.05	 4.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71090	 1	 2.56	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71091	 1	 4.0	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71092	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71093	 1	 5.12	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71094	 1	 2.05	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71095	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71096	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71097	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71098	 1	 4.83	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71099	 1	 2.62	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71100	 1	 2.63	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71101	 1	 6.68	 5.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71102	 1	 7.5	 6.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71103	 1	 3.32	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71104	 1	 2.44	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71105	 1	 4.62	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71106	 1	 4.88	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71107	 1	 5.33	 -15.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71108	 1	 4.48	 -21.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71109	 1	 5.21	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71110	 1	 2.45	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71111	 1	 3.94	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71112	 1	 2.52	 0.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71113	 1	 2.0	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71114	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71115	 1	 3.33	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71116	 1	 2.0	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71117	 1	 3.87	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71118	 1	 3.04	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71119	 1	 2.76	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71120	 1	 1.86	 0.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71121	 1	 3.25	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71122	 1	 4.43	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71123	 1	 3.63	 -1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71124	 1	 2.56	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71125	 1	 3.26	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71126	 1	 5.58	 2.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71127	 1	 3.99	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71128	 1	 4.27	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71129	 1	 6.34	 4.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71130	 1	 2.55	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71131	 1	 4.08	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71132	 1	 4.48	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71133	 1	 5.36	 3.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71134	 1	 2.88	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71135	 1	 4.58	 2.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71136	 1	 3.71	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71137	 1	 5.38	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71138	 1	 2.78	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71139	 1	 3.34	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71140	 1	 4.58	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71141	 1	 4.76	 3.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71142	 1	 6.13	 4.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71143	 1	 5.0	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71144	 1	 3.9	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71145	 1	 3.39	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71146	 1	 1.92	 0.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71147	 1	 3.18	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71148	 1	 5.76	 4.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71149	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71150	 1	 2.59	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71151	 1	 3.49	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71152	 1	 2.51	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71153	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71154	 1	 3.16	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71155	 1	 1.44	 0.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71156	 1	 3.42	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71157	 1	 2.49	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71158	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71159	 1	 1.8	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71160	 1	 2.54	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71161	 1	 1.98	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71162	 1	 3.68	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71163	 1	 0.0	 0.0	 0.0	 48.68	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71164	 1	 2.36	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71165	 1	 3.26	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71166	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71167	 1	 1.86	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71168	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71169	 1	 3.56	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71170	 1	 2.09	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71171	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71172	 1	 2.3	 0.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71173	 1	 3.32	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71174	 1	 2.98	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71175	 1	 4.14	 3.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71176	 1	 2.79	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71177	 1	 2.0	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71178	 1	 2.49	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71179	 1	 3.18	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71180	 1	 1.74	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71181	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71182	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71183	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71184	 1	 3.13	 2.22	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71185	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71186	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71187	 1	 1.21	 0.66	 0.0	 100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71188	 1	 3.97	 2.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71189	 1	 4.45	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71190	 1	 2.16	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71191	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71192	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71193	 1	 2.68	 1.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71194	 1	 3.69	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71195	 1	 2.26	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71196	 1	 2.63	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71197	 1	 4.24	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71198	 1	 3.54	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71199	 1	 5.44	 3.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71200	 1	 2.64	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71201	 1	 9.25	 7.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71202	 1	 2.8	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71203	 1	 2.66	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71204	 1	 2.25	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71205	 1	 7.45	 4.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71206	 1	 3.62	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71207	 1	 0.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71208	 1	 2.27	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71209	 1	 1.79	 0.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71210	 1	 2.06	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71211	 1	 1.64	 0.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71212	 1	 2.15	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71213	 1	 1.03	 0.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71214	 1	 2.84	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71215	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71216	 1	 2.72	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71217	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	71218	 1	 2.15	 1.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71219	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71220	 1	 3.08	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71221	 1	 4.77	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71222	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71223	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71224	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71225	 1	 3.5	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71226	 1	 2.78	 1.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71227	 1	 4.82	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71228	 1	 4.68	 3.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71229	 1	 2.29	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71230	 1	 2.86	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71231	 1	 2.98	 1.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71232	 1	 1.64	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71233	 1	 2.47	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71234	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71235	 1	 1.39	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71236	 1	 2.32	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71237	 1	 3.03	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71238	 1	 3.57	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71239	 1	 3.03	 1.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71240	 1	 4.98	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71241	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71242	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71243	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71244	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71245	 1	 1.73	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71246	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	71247	 1	 4.07	 2.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71248	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71249	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71250	 1	 6.71	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71251	 1	 2.64	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71252	 1	 3.19	 3.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71253	 1	 3.22	 1.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71254	 1	 3.47	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71255	 1	 1.29	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71256	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71257	 1	 4.36	 3.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71258	 1	 3.52	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71259	 1	 3.35	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71260	 1	 4.14	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71261	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71262	 1	 2.22	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71263	 1	 4.33	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71264	 1	 8.87	 6.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71265	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71266	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71267	 1	 4.84	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71268	 1	 4.76	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71269	 1	 2.99	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71270	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71271	 1	 8.99	 3.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71272	 1	 2.08	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71273	 1	 1.78	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71274	 1	 3.69	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71275	 1	 4.35	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71276	 1	 8.42	 6.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71277	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71278	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71279	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71280	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71281	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71282	 1	 5.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71283	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71284	 1	 4.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71285	 1	 7.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71286	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71287	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71288	 1	 5.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71289	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71290	 1	 6.57	 -18.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71291	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71292	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71293	 1	 21.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71294	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71295	 1	 7.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71296	 1	 7.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71297	 1	 13.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71298	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71299	 1	 10.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71300	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71301	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71302	 1	 4.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71303	 1	 0.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71304	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71305	 1	 8.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71306	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71307	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71308	 1	 4.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71309	 1	 13.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71310	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71311	 1	 5.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71312	 1	 5.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71313	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71314	 1	 5.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71315	 1	 4.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71316	 1	 6.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71317	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71318	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71319	 1	 8.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71320	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71321	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71322	 1	 8.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71323	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	71324	 1	 5.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71325	 1	 5.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71326	 1	 9.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71327	 1	 7.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71328	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71329	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71330	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71331	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71332	 1	 4.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71333	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71334	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71335	 1	 3.17	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71336	 1	 5.92	 -18.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71337	 1	 5.24	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71338	 1	 0.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71339	 1	 8.52	 -8.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71340	 1	 2.08	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71341	 1	 4.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71342	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71343	 1	 5.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71344	 1	 10.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71345	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71346	 1	 5.43	 -14.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71347	 1	 6.34	 -12.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71348	 1	 6.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71349	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71350	 1	 7.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71351	 1	 4.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71352	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71353	 1	 4.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71354	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71355	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71356	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71357	 1	 1.45	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71358	 1	 1.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71359	 1	 4.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71360	 1	 5.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71361	 1	 3.91	 2.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71362	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71363	 1	 0.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71364	 1	 2.22	 1.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71366	 1	 2.75	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71367	 1	 7.17	 5.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71368	 1	 5.74	 4.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71369	 1	 5.12	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71370	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71371	 1	 3.41	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71372	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71373	 1	 1.99	 1.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71374	 1	 1.64	 0.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71375	 1	 3.32	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71376	 1	 3.57	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71377	 1	 11.43	 -12.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71378	 1	 3.02	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71379	 1	 2.5	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71380	 1	 8.2	 4.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71381	 1	 8.33	 4.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71382	 1	 11.44	 10.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71383	 1	 5.69	 3.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71384	 1	 3.86	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71385	 1	 4.79	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71386	 1	 4.89	 3.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71387	 1	 3.55	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71388	 1	 3.79	 2.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71389	 1	 1.65	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71390	 1	 1.46	 0.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71391	 1	 4.18	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71392	 1	 4.42	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71393	 1	 10.0	 12.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71394	 1	 3.67	 1.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71395	 1	 3.08	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71396	 1	 2.18	 1.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71397	 1	 2.47	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71398	 1	 2.3	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71399	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71400	 1	 3.63	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71401	 1	 1.67	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71402	 1	 2.86	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71403	 1	 2.9	 1.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71404	 1	 4.21	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71405	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71406	 1	 6.47	 4.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71407	 1	 4.32	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71408	 1	 7.74	 4.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71409	 1	 1.96	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71410	 1	 2.77	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71411	 1	 1.91	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71412	 1	 2.01	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71413	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71414	 1	 5.39	 4.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71415	 1	 4.1	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71416	 1	 6.3	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71417	 1	 8.96	 6.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71418	 1	 3.77	 2.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71419	 1	 2.01	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71420	 1	 3.37	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71421	 1	 1.75	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71422	 1	 1.44	 0.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71423	 1	 1.74	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71424	 1	 3.49	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71425	 1	 5.79	 -16.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71426	 1	 2.8	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71427	 1	 7.74	 5.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71428	 1	 2.31	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71429	 1	 2.75	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71430	 1	 1.36	 0.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71431	 1	 5.51	 4.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71432	 1	 5.02	 3.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71433	 1	 5.84	 4.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71434	 1	 1.27	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71435	 1	 2.28	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71436	 1	 2.08	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71437	 1	 1.91	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71438	 1	 1.22	 0.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71439	 1	 3.16	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71440	 1	 7.81	 8.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71441	 1	 2.22	 0.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71442	 1	 4.43	 3.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71443	 1	 2.15	 0.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71444	 1	 4.37	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71445	 1	 2.5	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71446	 1	 2.38	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71447	 1	 1.54	 0.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71448	 1	 3.23	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71449	 1	 3.54	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71450	 1	 3.19	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71451	 1	 4.76	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71452	 1	 6.34	 4.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71453	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71454	 1	 6.74	 5.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71455	 1	 2.13	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71456	 1	 4.39	 3.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71457	 1	 42.16	 29.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71458	 1	 11.02	 5.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71459	 1	 2.41	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71460	 1	 5.82	 2.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71461	 1	 4.14	 3.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71462	 1	 3.54	 2.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71463	 1	 1.92	 0.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71464	 1	 3.0	 1.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71465	 1	 2.26	 0.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71466	 1	 1.16	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71467	 1	 5.66	 3.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71468	 1	 6.25	 4.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71469	 1	 6.42	 4.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71470	 1	 1.8	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71471	 1	 5.07	 3.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71472	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71473	 1	 1.62	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71474	 1	 4.91	 3.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71475	 1	 5.87	 4.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71476	 1	 6.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71477	 1	 8.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71478	 1	 2.97	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71479	 1	 3.97	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71480	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71481	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71482	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71483	 1	 7.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71484	 1	 4.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71485	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71486	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71487	 1	 6.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71488	 1	 4.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71489	 1	 10.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71490	 1	 4.96	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71491	 1	 1.56	 0.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71492	 1	 1.25	 0.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71493	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71494	 1	 2.99	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71495	 1	 4.37	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71496	 1	 2.12	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71497	 1	 3.92	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71498	 1	 3.56	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71499	 1	 8.24	 5.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71500	 1	 1.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71501	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71502	 1	 3.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71503	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71504	 1	 5.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71505	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71506	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71507	 1	 1.62	 -14.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71508	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71509	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71510	 1	 1.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71511	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71512	 1	 7.28	 -26.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71513	 1	 10.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71514	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71515	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71516	 1	 4.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71517	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71518	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71519	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71520	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71521	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71522	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71523	 1	 2.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71524	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71525	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71526	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71527	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71528	 1	 4.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71529	 1	 6.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71530	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71531	 1	 5.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71532	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71533	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71534	 1	 5.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71535	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71536	 1	 3.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71537	 1	 4.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71538	 1	 3.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71539	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71540	 1	 5.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71541	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71542	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71543	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71544	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71545	 1	 5.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71546	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71547	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71548	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71549	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71550	 1	 2.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71551	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71552	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71553	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71554	 1	 5.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71555	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71556	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71557	 1	 4.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71558	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71559	 1	 0.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71560	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71561	 1	 6.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71562	 1	 1.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71563	 1	 4.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71564	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71565	 1	 8.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71566	 1	 7.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71567	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71568	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71569	 1	 10.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71570	 1	 7.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71571	 1	 3.39	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71572	 1	 6.3	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71573	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71574	 1	 3.39	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71575	 1	 2.63	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71576	 1	 2.65	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71577	 1	 2.85	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71578	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71579	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71580	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71581	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71582	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71583	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71584	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71585	 1	 5.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71586	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71587	 1	 5.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71588	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71589	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71590	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71591	 1	 6.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71592	 1	 4.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71593	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71594	 1	 7.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71595	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71596	 1	 10.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71597	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71598	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71599	 1	 5.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71600	 1	 4.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71601	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71602	 1	 3.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71603	 1	 5.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71604	 1	 5.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71605	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71606	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71607	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71608	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71609	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71610	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71611	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71612	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71613	 1	 4.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71614	 1	 3.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71615	 1	 4.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71616	 1	 5.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71617	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71618	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71619	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71620	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71621	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71622	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71623	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71624	 1	 1.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71625	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71626	 1	 8.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71627	 1	 9.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71628	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71629	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71630	 1	 5.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71631	 1	 8.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71632	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71633	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71634	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71635	 1	 7.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71636	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71637	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71638	 1	 4.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71639	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71640	 1	 4.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71641	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71642	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71643	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71644	 1	 4.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71645	 1	 1.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71646	 1	 5.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71647	 1	 3.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71648	 1	 1.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71649	 1	 4.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71650	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71651	 1	 5.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71652	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71653	 1	 0.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71654	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71655	 1	 4.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71656	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71657	 1	 3.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71658	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71659	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71660	 1	 5.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71661	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71662	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71663	 1	 4.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71664	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71665	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71666	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71667	 1	 4.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71668	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71669	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71670	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71671	 1	 5.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71672	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71673	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71674	 1	 6.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71675	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71676	 1	 3.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71677	 1	 1.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71678	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71679	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71680	 1	 1.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71681	 1	 5.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71682	 1	 4.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71683	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71684	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71685	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71686	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71687	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71688	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71689	 1	 0.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71690	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71691	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71692	 1	 3.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71693	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71694	 1	 4.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71695	 1	 5.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71696	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71697	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71698	 1	 5.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71699	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71700	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71701	 1	 4.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71702	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71703	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71704	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71705	 1	 3.48	 -32.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71706	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71707	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71708	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71709	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71710	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71711	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71712	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71713	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71714	 1	 4.71	 -15.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71715	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71716	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71717	 1	 1.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71718	 1	 1.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71719	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71720	 1	 5.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71721	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71722	 1	 1.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71723	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71724	 1	 6.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71725	 1	 1.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71726	 1	 1.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71727	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71728	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71729	 1	 5.72	 -28.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71730	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71731	 1	 1.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71732	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71733	 1	 5.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71734	 1	 8.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71735	 1	 0.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71736	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71737	 1	 1.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71738	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71739	 1	 3.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71740	 1	 5.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71741	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71742	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71743	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71744	 1	 8.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71745	 1	 4.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71746	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71747	 1	 8.68	 3.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71748	 1	 8.26	 -16.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71749	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71750	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71751	 1	 4.6	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71752	 1	 3.79	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71753	 1	 1.45	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71754	 1	 4.96	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71755	 1	 2.74	 -12.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71756	 1	 7.33	 -37.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71757	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71758	 1	 2.91	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71759	 1	 1.59	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71760	 1	 1.66	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71761	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71762	 1	 2.33	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71763	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71764	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71765	 1	 6.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71766	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71767	 1	 6.93	 4.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71768	 1	 5.43	 4.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71769	 1	 7.67	 5.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71770	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71771	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71772	 1	 19.7	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71773	 1	 1.71	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71774	 1	 1.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71775	 1	 0.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71776	 1	 6.24	 2.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71777	 1	 3.4	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71778	 1	 2.07	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71779	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71780	 1	 3.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71781	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71782	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71783	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71784	 1	 4.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71785	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71786	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71787	 1	 5.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71788	 1	 8.64	 3.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71789	 1	 7.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71790	 1	 8.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71791	 1	 5.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71792	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71793	 1	 11.0	 7.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71794	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71795	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71796	 1	 11.99	 -8.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71797	 1	 5.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71798	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71799	 1	 6.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71800	 1	 5.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71801	 1	 0.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71802	 1	 6.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71803	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71804	 1	 4.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71805	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71806	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71807	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71808	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71809	 1	 1.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71810	 1	 6.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71811	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71812	 1	 4.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71813	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71814	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71815	 1	 3.68	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71816	 1	 1.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71817	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71818	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71819	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71820	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71821	 1	 3.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71822	 1	 1.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71823	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71824	 1	 7.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71825	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71826	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71827	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71828	 1	 5.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71829	 1	 7.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71830	 1	 8.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71831	 1	 7.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71832	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71833	 1	 3.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71834	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71835	 1	 6.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71836	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71837	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71838	 1	 0.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71839	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71840	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71841	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71842	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71843	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71844	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71845	 1	 1.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71846	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71847	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71848	 1	 2.63	 -2.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71849	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71850	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71851	 1	 1.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71852	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71853	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71854	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71855	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71856	 1	 1.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71857	 1	 5.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71858	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71859	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71860	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71861	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71862	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71863	 1	 4.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71864	 1	 1.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71865	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71866	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71867	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71868	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71869	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71870	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71871	 1	 4.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71872	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71873	 1	 12.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71874	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71875	 1	 6.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71876	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71877	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71878	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71879	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71880	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71881	 1	 4.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71882	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71883	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71884	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71885	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71886	 1	 6.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71887	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71888	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71889	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71890	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71891	 1	 4.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71892	 1	 14.57	 -60.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71893	 1	 7.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71894	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71895	 1	 1.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71896	 1	 4.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71897	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71898	 1	 8.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71899	 1	 6.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71900	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71901	 1	 1.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71902	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71903	 1	 8.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71904	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71905	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71906	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71907	 1	 4.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71908	 1	 3.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71909	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71910	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71911	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71912	 1	 1.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71913	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71914	 1	 5.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71915	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71916	 1	 1.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71917	 1	 4.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71918	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71919	 1	 5.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71920	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71921	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71922	 1	 5.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71923	 1	 4.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71924	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71925	 1	 6.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71926	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71927	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71928	 1	 10.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71929	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71930	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71931	 1	 4.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71932	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71933	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71934	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71935	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71936	 1	 4.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71937	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71938	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71939	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71940	 1	 4.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71941	 1	 10.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71942	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71943	 1	 7.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71944	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71945	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71946	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71947	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71948	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71949	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71950	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71951	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71952	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71953	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71954	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71955	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71956	 1	 14.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71957	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71958	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71959	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71960	 1	 6.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71961	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71962	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71963	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71964	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71965	 1	 5.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71966	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71967	 1	 3.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71968	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71969	 1	 1.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71970	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71971	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71972	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71973	 1	 3.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71974	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71975	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71976	 1	 6.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71977	 1	 9.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71978	 1	 4.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71979	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71980	 1	 3.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71981	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71982	 1	 5.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71983	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71984	 1	 4.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71985	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71986	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71987	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71988	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71989	 1	 4.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71990	 1	 2.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71991	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71992	 1	 2.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71993	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71994	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71995	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71996	 1	 3.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71997	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71998	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	71999	 1	 4.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72000	 1	 4.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72001	 1	 1.74	 -2.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72002	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72003	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72004	 1	 4.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72005	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72006	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72007	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72008	 1	 6.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72009	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72010	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72011	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72012	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72013	 1	 6.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72014	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72015	 1	 6.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72016	 1	 4.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72017	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72018	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72019	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72020	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72021	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72022	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72023	 1	 3.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72024	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72025	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72026	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72027	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72028	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72029	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72030	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72031	 1	 7.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72032	 1	 4.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72033	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72034	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72035	 1	 6.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72036	 1	 1.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72037	 1	 1.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72038	 1	 6.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72039	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72040	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72041	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72042	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72043	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72044	 1	 9.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72045	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72046	 1	 7.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72047	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72048	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72049	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72050	 1	 3.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72051	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72052	 1	 4.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72053	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72054	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72055	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72056	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72057	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72058	 1	 2.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72059	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72060	 1	 7.81	 -35.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72061	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72062	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72063	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72064	 1	 8.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72065	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72066	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72067	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72068	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72069	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72070	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72071	 1	 1.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72072	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72073	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72074	 1	 35.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72075	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72076	 1	 5.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72077	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72078	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72079	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72080	 1	 4.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72081	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72082	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72083	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72084	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72085	 1	 5.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72086	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72087	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72088	 1	 7.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72089	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72090	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72091	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72092	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72093	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72094	 1	 1.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72095	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72096	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72097	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72098	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72099	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72100	 1	 2.38	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72101	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72102	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72103	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72104	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72105	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72106	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72107	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72108	 1	 6.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72109	 1	 7.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72110	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72111	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72112	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72113	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72114	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72115	 1	 5.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72116	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72117	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72118	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72119	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72120	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72121	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72122	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72123	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72124	 1	 2.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72125	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72126	 1	 3.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72127	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72128	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72129	 1	 4.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72130	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72131	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72132	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72133	 1	 9.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72134	 1	 5.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72135	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72136	 1	 5.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72137	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72138	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72139	 1	 5.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72140	 1	 1.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72141	 1	 6.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72142	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72143	 1	 0.0	 0.0	 0.0	 -47.7	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72144	 1	 4.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72145	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72146	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72147	 1	 3.78	 2.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72148	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72149	 1	 3.57	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72150	 1	 1.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72151	 1	 8.72	 3.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72152	 1	 6.59	 -15.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72153	 1	 5.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72154	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72155	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72156	 1	 7.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72157	 1	 5.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72158	 1	 3.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72159	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72160	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72161	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72162	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72163	 1	 3.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72164	 1	 6.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72165	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72166	 1	 4.18	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72167	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72168	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72169	 1	 26.02	 29.99	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72170	 1	 5.35	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72171	 1	 4.68	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72172	 1	 3.14	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72173	 1	 2.52	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72174	 1	 1.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72175	 1	 4.25	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72176	 1	 2.88	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72177	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72178	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72179	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72180	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72181	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72182	 1	 5.07	 -13.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72183	 1	 4.09	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72184	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72185	 1	 5.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72186	 1	 5.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72187	 1	 2.89	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72188	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72189	 1	 2.71	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72190	 1	 8.05	 5.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72191	 1	 2.43	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72192	 1	 4.01	 4.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72193	 1	 3.43	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72194	 1	 2.87	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72195	 1	 2.28	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72196	 1	 2.24	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72197	 1	 2.85	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72198	 1	 2.28	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72199	 1	 4.32	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72200	 1	 2.11	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72201	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72202	 1	 2.52	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72203	 1	 2.81	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72204	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72205	 1	 3.98	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72206	 1	 3.56	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72207	 1	 2.16	 1.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72208	 1	 2.12	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72209	 1	 3.25	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72210	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72211	 1	 2.74	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72212	 1	 3.6	 2.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72213	 1	 4.08	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72214	 1	 3.01	 2.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72215	 1	 2.88	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72216	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72217	 1	 2.79	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72218	 1	 3.01	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72219	 1	 2.64	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72220	 1	 3.79	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72221	 1	 3.19	 2.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72222	 1	 2.08	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72223	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72224	 1	 2.77	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72225	 1	 7.1	 5.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72226	 1	 5.87	 4.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72227	 1	 4.62	 3.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72228	 1	 5.47	 3.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72229	 1	 1.93	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72230	 1	 2.54	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72231	 1	 2.34	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72232	 1	 4.48	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72233	 1	 2.08	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72234	 1	 2.81	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72235	 1	 3.6	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72236	 1	 3.22	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72237	 1	 2.61	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72238	 1	 5.62	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72239	 1	 4.41	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72240	 1	 2.64	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72241	 1	 4.13	 2.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72242	 1	 2.8	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72243	 1	 2.93	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72244	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72245	 1	 4.72	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72246	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72247	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72248	 1	 8.58	 5.27	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72249	 1	 4.45	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72250	 1	 3.31	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72251	 1	 2.18	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72252	 1	 2.85	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72253	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72254	 1	 3.01	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72255	 1	 7.45	 5.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72256	 1	 0.0	 0.0	 0.0	 265.9	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72257	 1	 0.0	 0.0	 0.0	 -127.54	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72258	 1	 3.62	 2.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72259	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72260	 1	 4.79	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72261	 1	 12.6	 4.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72262	 1	 7.48	 5.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72263	 1	 2.85	 1.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72264	 1	 2.87	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72265	 1	 6.33	 5.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72266	 1	 9.65	 11.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72267	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72268	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72269	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72270	 1	 3.79	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72271	 1	 2.76	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72272	 1	 3.93	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72273	 1	 3.78	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72274	 1	 3.0	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72275	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72276	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72277	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72278	 1	 3.48	 2.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72279	 1	 1.92	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72280	 1	 3.02	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72281	 1	 5.52	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72282	 1	 3.59	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72283	 1	 3.24	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72284	 1	 2.53	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72285	 1	 3.56	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72286	 1	 4.79	 3.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72287	 1	 4.07	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72288	 1	 5.2	 3.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72289	 1	 4.54	 2.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72290	 1	 2.18	 0.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72291	 1	 2.59	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72292	 1	 2.47	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72293	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72294	 1	 5.03	 3.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72295	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72296	 1	 3.71	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72297	 1	 3.99	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72298	 1	 4.91	 4.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72299	 1	 2.41	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72300	 1	 2.24	 1.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72301	 1	 4.41	 2.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72302	 1	 3.82	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72303	 1	 4.4	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72304	 1	 2.31	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72305	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72306	 1	 2.78	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72307	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72308	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72309	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72310	 1	 2.95	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72311	 1	 3.22	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72312	 1	 7.83	 5.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72313	 1	 0.0	 0.0	 0.0	 800.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	72314	 1	 6.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72315	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72316	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72317	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72318	 1	 4.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72319	 1	 2.26	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72320	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72321	 1	 2.5	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72322	 1	 2.72	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72323	 1	 3.2	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72324	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72325	 1	 4.75	 -24.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72326	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72327	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72328	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72329	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72330	 1	 4.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72331	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72332	 1	 5.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72333	 1	 4.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72334	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72335	 1	 5.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72336	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72337	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72338	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72339	 1	 4.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72340	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72341	 1	 5.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72342	 1	 5.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72343	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72344	 1	 4.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72345	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72346	 1	 2.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72347	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72348	 1	 6.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72349	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72350	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72351	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72352	 1	 7.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72353	 1	 2.71	 0.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72354	 1	 2.6	 0.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72355	 1	 2.58	 -6.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72356	 1	 3.44	 2.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72357	 1	 6.88	 3.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72358	 1	 2.18	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72359	 1	 1.41	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72360	 1	 4.79	 4.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72361	 1	 2.03	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72362	 1	 2.32	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72363	 1	 5.79	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72364	 1	 3.29	 3.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72366	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72367	 1	 8.98	 3.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72368	 1	 2.32	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72369	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72370	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72371	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72372	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72373	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72374	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72375	 1	 4.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72376	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72377	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72378	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72379	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72380	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72381	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72382	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72383	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72384	 1	 6.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72385	 1	 4.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72386	 1	 5.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72387	 1	 3.47	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72388	 1	 1.71	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72389	 1	 5.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72390	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72391	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72392	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72393	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72394	 1	 4.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72395	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72396	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72397	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72398	 1	 5.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72399	 1	 9.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72400	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72401	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72402	 1	 3.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72403	 1	 3.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72404	 1	 5.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72405	 1	 4.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72406	 1	 3.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72407	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72408	 1	 12.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72409	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72410	 1	 5.45	 4.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72411	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72412	 1	 23.41	 24.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72413	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72414	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72415	 1	 2.61	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72416	 1	 1.31	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72417	 1	 0.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72418	 1	 4.27	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72419	 1	 8.33	 5.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72420	 1	 5.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72421	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72422	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72423	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72424	 1	 6.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72425	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72426	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72427	 1	 4.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72428	 1	 5.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72429	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72430	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72431	 1	 5.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72432	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72433	 1	 5.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72434	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72435	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72436	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72437	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72438	 1	 4.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72439	 1	 13.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72440	 1	 5.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72441	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72442	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72443	 1	 4.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72444	 1	 5.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72445	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72446	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72447	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72448	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72449	 1	 9.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72450	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72451	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72452	 1	 5.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72453	 1	 3.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72454	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72455	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72456	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72457	 1	 7.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72458	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72459	 1	 23.76	 18.8	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72460	 1	 16.25	 11.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72461	 1	 3.09	 -1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72462	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72463	 1	 10.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72464	 1	 5.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72465	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72466	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72467	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72468	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72469	 1	 4.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72470	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72471	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72472	 1	 1.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72473	 1	 3.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72474	 1	 1.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72475	 1	 5.06	 2.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72476	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72477	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72478	 1	 2.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72479	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72480	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72481	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72482	 1	 0.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72483	 1	 2.44	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72484	 1	 1.29	 0.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72485	 1	 4.66	 -19.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72486	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72487	 1	 1.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72488	 1	 0.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72489	 1	 1.09	 0.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72490	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72491	 1	 1.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72492	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72493	 1	 1.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72494	 1	 5.51	 3.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72495	 1	 4.29	 3.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72496	 1	 5.48	 4.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72497	 1	 7.24	 4.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72498	 1	 4.24	 2.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72499	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72500	 1	 9.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72501	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72502	 1	 10.99	 5.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72503	 1	 4.57	 -20.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72504	 1	 0.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72505	 1	 13.65	 12.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72506	 1	 4.42	 3.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72507	 1	 0.0	 0.0	 0.0	 20.03	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72508	 1	 16.04	 8.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72509	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72510	 1	 0.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72511	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72512	 1	 18.3	 11.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72513	 1	 1.77	 1.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72514	 1	 1.89	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72515	 1	 2.44	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72516	 1	 6.3	 3.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72517	 1	 6.89	 2.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72518	 1	 1.72	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72519	 1	 4.67	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72520	 1	 1.81	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72521	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72522	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72523	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72524	 1	 2.62	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72525	 1	 3.24	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72526	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72527	 1	 2.1	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72528	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72529	 1	 5.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72530	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72531	 1	 4.77	 2.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72532	 1	 1.42	 0.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72533	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72534	 1	 1.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72535	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72536	 1	 4.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72537	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72538	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72539	 1	 5.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72540	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72541	 1	 2.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72542	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72543	 1	 5.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72544	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72545	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72546	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72547	 1	 7.63	 -5.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72548	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72549	 1	 2.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72550	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72551	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72552	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72553	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72554	 1	 6.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72555	 1	 5.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72556	 1	 4.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72557	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72558	 1	 6.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72559	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72560	 1	 6.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72561	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72562	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72563	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72564	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72565	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72566	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72567	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72568	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72569	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72570	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72571	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72572	 1	 2.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72573	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72574	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72575	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72576	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72577	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72578	 1	 3.51	 2.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72579	 1	 5.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72580	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72581	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72582	 1	 1.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72583	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72584	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72585	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72586	 1	 2.94	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72587	 1	 2.02	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72588	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72589	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72590	 1	 7.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72591	 1	 5.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72592	 1	 4.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72593	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72594	 1	 3.51	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72595	 1	 9.05	 4.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72596	 1	 2.71	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72597	 1	 2.45	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72598	 1	 5.76	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72599	 1	 3.04	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72600	 1	 5.19	 3.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72601	 1	 3.28	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72602	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72603	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72604	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72605	 1	 2.68	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72606	 1	 1.39	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72607	 1	 1.17	 0.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72608	 1	 2.05	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72609	 1	 4.13	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72610	 1	 3.4	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72611	 1	 0.0	 0.0	 0.0	 100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72612	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72613	 1	 9.98	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72614	 1	 8.54	 3.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72615	 1	 7.19	 5.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72616	 1	 0.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72617	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72618	 1	 1.04	 0.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72619	 1	 8.22	 4.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72620	 1	 1.57	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72621	 1	 2.01	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72622	 1	 4.26	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72623	 1	 7.06	 4.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72624	 1	 3.7	 1.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72625	 1	 16.72	 10.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72626	 1	 5.43	 -33.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72627	 1	 1.92	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72628	 1	 5.7	 4.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72629	 1	 2.61	 1.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72630	 1	 1.42	 0.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72631	 1	 3.51	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72632	 1	 2.75	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72633	 1	 3.31	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72634	 1	 1.0	 0.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72635	 1	 3.69	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72636	 1	 3.69	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72637	 1	 4.83	 2.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72638	 1	 6.65	 2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72639	 1	 2.4	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72640	 1	 2.16	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72641	 1	 11.72	 4.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72642	 1	 4.11	 2.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72643	 1	 1.76	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72644	 1	 6.07	 4.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72645	 1	 4.22	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72646	 1	 5.54	 3.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72647	 1	 1.22	 0.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72648	 1	 2.84	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72649	 1	 2.96	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72650	 1	 4.39	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72651	 1	 3.38	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72652	 1	 5.86	 -4.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72653	 1	 1.59	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72654	 1	 2.38	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72655	 1	 21.42	 11.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72656	 1	 1.44	 0.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72657	 1	 2.96	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72658	 1	 2.7	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72659	 1	 1.39	 0.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72660	 1	 5.23	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72661	 1	 1.07	 0.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72662	 1	 6.97	 4.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72663	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72664	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72665	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72666	 1	 2.73	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72667	 1	 1.29	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72668	 1	 6.86	 3.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72669	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72670	 1	 1.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72671	 1	 2.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72672	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72673	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72674	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72675	 1	 2.21	 1.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72676	 1	 2.7	 1.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72677	 1	 3.92	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72678	 1	 16.67	 18.45	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72679	 1	 3.07	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72680	 1	 2.54	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72681	 1	 4.46	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72682	 1	 0.0	 0.0	 0.0	 37.8	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72683	 1	 4.72	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72684	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72685	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72686	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72687	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72688	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72689	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72690	 1	 6.23	 4.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72691	 1	 6.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72692	 1	 11.23	 7.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72693	 1	 3.53	 -33.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72694	 1	 2.75	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72695	 1	 2.88	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72696	 1	 2.51	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72697	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72698	 1	 3.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72699	 1	 3.18	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72700	 1	 7.61	 4.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72701	 1	 4.51	 3.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72702	 1	 4.75	 2.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72703	 1	 3.42	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72704	 1	 3.49	 1.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72705	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72706	 1	 0.0	 0.0	 0.0	 43.07	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72707	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72708	 1	 0.0	 0.0	 0.0	 -53.05	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72709	 1	 2.02	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72710	 1	 1.3	 0.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72711	 1	 3.41	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72712	 1	 2.13	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72713	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72714	 1	 5.03	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72715	 1	 3.65	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72716	 1	 5.37	 3.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72717	 1	 1.86	 0.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72718	 1	 4.41	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72719	 1	 2.12	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72720	 1	 2.49	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72721	 1	 3.59	 2.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72722	 1	 8.5	 6.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72723	 1	 2.6	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72724	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72725	 1	 3.78	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72726	 1	 3.93	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72727	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72728	 1	 2.47	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72729	 1	 5.15	 3.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72730	 1	 14.92	 -12.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72731	 1	 2.89	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72732	 1	 9.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72733	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72734	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72735	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72736	 1	 9.87	 7.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72737	 1	 2.66	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72738	 1	 2.75	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72739	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72740	 1	 6.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72741	 1	 7.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72742	 1	 3.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72743	 1	 2.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72744	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72745	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72746	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72747	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72748	 1	 3.63	 2.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72749	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72750	 1	 9.9	 7.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72751	 1	 3.47	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72752	 1	 4.33	 -12.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72753	 1	 2.85	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72754	 1	 2.26	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72755	 1	 5.99	 4.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72756	 1	 4.25	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72757	 1	 2.96	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72758	 1	 3.29	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72759	 1	 2.92	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72760	 1	 3.77	 2.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72761	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72762	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72763	 1	 11.28	 6.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72764	 1	 1.55	 0.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72765	 1	 17.76	 7.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72766	 1	 4.75	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72767	 1	 3.14	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72768	 1	 3.73	 2.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72769	 1	 1.79	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72770	 1	 3.32	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72771	 1	 4.0	 2.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72772	 1	 2.28	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72773	 1	 1.39	 0.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72774	 1	 3.19	 -9.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72775	 1	 1.51	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72776	 1	 6.75	 5.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72777	 1	 1.74	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72778	 1	 3.61	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72779	 1	 3.09	 1.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72780	 1	 2.58	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72781	 1	 1.99	 1.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72782	 1	 50.46	 24.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72783	 1	 5.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72784	 1	 4.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72785	 1	 7.82	 3.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72786	 1	 2.93	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72787	 1	 3.48	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72788	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72789	 1	 4.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72790	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72791	 1	 1.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72792	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72793	 1	 3.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72794	 1	 0.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72795	 1	 2.58	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72796	 1	 2.88	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72797	 1	 6.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72798	 1	 6.72	 3.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72799	 1	 5.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72800	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72801	 1	 11.08	 7.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72802	 1	 3.31	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72803	 1	 2.09	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72804	 1	 2.96	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72805	 1	 7.66	 5.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72806	 1	 6.1	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72807	 1	 11.37	 6.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72808	 1	 4.09	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72809	 1	 6.39	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72810	 1	 3.65	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72811	 1	 6.37	 5.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72812	 1	 4.03	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72813	 1	 2.71	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72814	 1	 2.38	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72815	 1	 2.88	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72816	 1	 2.81	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72817	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72818	 1	 4.56	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72819	 1	 3.48	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72820	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72821	 1	 6.51	 4.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72822	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72823	 1	 0.0	 0.0	 0.0	 -200.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72824	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72825	 1	 2.74	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72826	 1	 7.51	 3.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72827	 1	 4.84	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72828	 1	 2.41	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72829	 1	 3.07	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72830	 1	 3.49	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72831	 1	 1.16	 0.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72832	 1	 3.66	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72833	 1	 1.01	 0.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72834	 1	 2.89	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72835	 1	 7.61	 2.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72836	 1	 6.79	 4.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72837	 1	 4.11	 3.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72838	 1	 3.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72839	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72840	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72841	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72842	 1	 5.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72843	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72844	 1	 5.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72845	 1	 5.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72846	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72847	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72848	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72849	 1	 2.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72850	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72851	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72852	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72853	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72854	 1	 9.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72855	 1	 2.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72856	 1	 3.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72857	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72858	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72859	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72860	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72861	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72862	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72863	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72864	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72865	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72866	 1	 4.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72867	 1	 8.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72868	 1	 4.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72869	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72870	 1	 5.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72871	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72872	 1	 5.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72873	 1	 9.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72874	 1	 3.94	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72875	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72876	 1	 3.27	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72877	 1	 2.07	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72878	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72879	 1	 6.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72880	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72881	 1	 1.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72882	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72883	 1	 1.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72884	 1	 5.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72885	 1	 1.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72886	 1	 9.05	 -8.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72887	 1	 4.65	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72888	 1	 2.96	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72889	 1	 2.12	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72890	 1	 2.56	 1.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72891	 1	 3.09	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72892	 1	 3.13	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72893	 1	 4.81	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72894	 1	 4.43	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72895	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72896	 1	 0.0	 0.0	 0.0	 800.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	72897	 1	 4.32	 2.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72898	 1	 5.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72899	 1	 4.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72900	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72901	 1	 5.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72902	 1	 1.85	 1.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72903	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72904	 1	 3.95	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72905	 1	 1.74	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72906	 1	 7.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72907	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72908	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72909	 1	 2.42	 1.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72910	 1	 3.58	 2.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72911	 1	 0.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72912	 1	 9.35	 6.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72913	 1	 5.77	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72914	 1	 6.96	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72915	 1	 5.59	 2.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72916	 1	 7.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72917	 1	 9.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72918	 1	 4.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72919	 1	 7.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72920	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72921	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72922	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72923	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72924	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72925	 1	 7.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72926	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72927	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72928	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72929	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72930	 1	 5.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72931	 1	 5.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72932	 1	 6.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72933	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72934	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72935	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72936	 1	 9.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72937	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72938	 1	 8.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72939	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72940	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72941	 1	 3.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72942	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72943	 1	 1.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72944	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72945	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72946	 1	 4.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72947	 1	 7.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72948	 1	 7.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72949	 1	 8.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72950	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72951	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72952	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72953	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72954	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72955	 1	 5.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72956	 1	 17.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72957	 1	 4.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72958	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72959	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72960	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72961	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72962	 1	 7.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72963	 1	 7.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72964	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72965	 1	 3.83	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72966	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72967	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72968	 1	 4.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72969	 1	 6.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72970	 1	 2.72	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72971	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72972	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72973	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72974	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72975	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72976	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72977	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72978	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72979	 1	 4.8	 3.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72980	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72981	 1	 3.04	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72982	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	72983	 1	 4.39	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72984	 1	 1.75	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72985	 1	 5.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72986	 1	 3.09	 1.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72987	 1	 4.28	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72988	 1	 4.53	 3.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72989	 1	 10.64	 8.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72990	 1	 12.42	 8.27	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72991	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72992	 1	 1.79	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72993	 1	 4.47	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72994	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72995	 1	 1.05	 0.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72996	 1	 5.61	 2.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72997	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	72998	 1	 7.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	72999	 1	 7.1	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73000	 1	 2.15	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73001	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73002	 1	 5.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73003	 1	 8.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73004	 1	 7.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73005	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73006	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73007	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73008	 1	 4.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73009	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73010	 1	 5.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73011	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73012	 1	 1.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73013	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73014	 1	 4.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73015	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73016	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73017	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73018	 1	 4.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73019	 1	 0.0	 0.0	 0.0	 -64.11	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73020	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73021	 1	 4.53	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73022	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73023	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73024	 1	 5.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73025	 1	 8.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73026	 1	 5.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73027	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73028	 1	 1.56	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73029	 1	 5.64	 -18.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73030	 1	 3.59	 2.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73031	 1	 3.37	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73032	 1	 8.91	 7.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73033	 1	 1.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73034	 1	 1.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73035	 1	 6.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73036	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73037	 1	 5.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73038	 1	 2.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73039	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73040	 1	 5.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73041	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73042	 1	 7.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73043	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73044	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73045	 1	 5.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73046	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73047	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73048	 1	 7.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73049	 1	 4.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73050	 1	 5.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73051	 1	 8.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73052	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73053	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73054	 1	 2.15	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73055	 1	 6.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73056	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73057	 1	 2.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73058	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73059	 1	 9.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73060	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73061	 1	 6.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73062	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73063	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73064	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73065	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73066	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73067	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73068	 1	 6.4	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73069	 1	 6.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73070	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73071	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73072	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73073	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73074	 1	 6.11	 4.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73075	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73076	 1	 4.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73077	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73078	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73079	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73080	 1	 5.86	 3.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73081	 1	 1.94	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73082	 1	 1.84	 0.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73083	 1	 1.85	 1.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73084	 1	 4.03	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73085	 1	 2.78	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73086	 1	 5.07	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73087	 1	 3.85	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73088	 1	 4.24	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73089	 1	 1.31	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73090	 1	 3.72	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73091	 1	 4.49	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73092	 1	 9.06	 3.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73093	 1	 2.15	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73094	 1	 15.17	 8.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73095	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73096	 1	 5.34	 3.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73097	 1	 8.72	 3.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73098	 1	 30.66	 27.51	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73099	 1	 2.85	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73100	 1	 2.21	 -26.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73101	 1	 1.15	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73102	 1	 6.58	 3.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73103	 1	 2.65	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73104	 1	 3.39	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73105	 1	 8.53	 -13.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73106	 1	 3.91	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73107	 1	 3.75	 2.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73108	 1	 2.24	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73109	 1	 3.03	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73110	 1	 6.15	 3.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73111	 1	 3.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73112	 1	 3.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73113	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73114	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73115	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73116	 1	 8.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73117	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73118	 1	 15.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73119	 1	 2.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73120	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73121	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73122	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73123	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73124	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73125	 1	 10.11	 5.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73126	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73127	 1	 3.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73128	 1	 8.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73129	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73130	 1	 4.37	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73131	 1	 9.35	 7.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73132	 1	 1.67	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73133	 1	 8.45	 -4.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73134	 1	 4.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73135	 1	 7.47	 -12.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73136	 1	 2.02	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73137	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73138	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73139	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	73140	 1	 7.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73141	 1	 3.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73142	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73143	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73144	 1	 6.44	 2.89	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73145	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73146	 1	 4.05	 -13.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73147	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73148	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73149	 1	 6.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73150	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73151	 1	 4.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73152	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73153	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73154	 1	 0.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73155	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73156	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73157	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73158	 1	 4.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73159	 1	 4.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73160	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73161	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73162	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73163	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73164	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73165	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73166	 1	 2.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73167	 1	 1.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73168	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73169	 1	 1.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73170	 1	 7.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73171	 1	 4.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73172	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73173	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73174	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73175	 1	 1.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73176	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73177	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73178	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73179	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73180	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73181	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73182	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73183	 1	 7.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73184	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73185	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73186	 1	 10.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73187	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73188	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73189	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73190	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73191	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73192	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73193	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73194	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73195	 1	 5.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73196	 1	 5.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73197	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73198	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73199	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73200	 1	 2.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73201	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73202	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73203	 1	 3.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73204	 1	 13.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73205	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73206	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73207	 1	 11.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73208	 1	 5.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73209	 1	 15.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73210	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73211	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73212	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73213	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73214	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73215	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73216	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73217	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73218	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73219	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73220	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73221	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73222	 1	 1.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73223	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73224	 1	 3.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73225	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73226	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73227	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73228	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73229	 1	 9.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73230	 1	 1.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73231	 1	 2.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73232	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73233	 1	 8.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73234	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73235	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73236	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73237	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73238	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73239	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73240	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73241	 1	 2.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73242	 1	 5.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73243	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73244	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73245	 1	 1.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73246	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73247	 1	 4.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73248	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73249	 1	 1.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73250	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73251	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73252	 1	 2.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73253	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73254	 1	 5.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73255	 1	 1.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73256	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73257	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73258	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73259	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73260	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73261	 1	 6.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73262	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73263	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73264	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73265	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73266	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73267	 1	 1.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73268	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73269	 1	 1.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73270	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73271	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73272	 1	 2.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73273	 1	 3.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73274	 1	 3.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73275	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73276	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73277	 1	 2.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73278	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73279	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73280	 1	 6.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73281	 1	 6.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73282	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73283	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73284	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73285	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73286	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73287	 1	 4.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73288	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73289	 1	 6.84	 -11.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73290	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73291	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73292	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73293	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73294	 1	 4.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73295	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73296	 1	 4.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73297	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73298	 1	 5.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73299	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73300	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73301	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73302	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73303	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73304	 1	 4.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73305	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73306	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73307	 1	 4.7	 -13.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73308	 1	 1.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73309	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73310	 1	 5.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73311	 1	 1.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73312	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73313	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73314	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73315	 1	 2.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73316	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73317	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73318	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73319	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73320	 1	 6.62	 -2.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73321	 1	 11.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73322	 1	 2.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73323	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73324	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73325	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73326	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73327	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73328	 1	 3.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73329	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	73330	 1	 0.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73331	 1	 1.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73332	 1	 0.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73333	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73334	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73335	 1	 13.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73336	 1	 5.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73337	 1	 5.25	 3.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73338	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73339	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73340	 1	 3.33	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73341	 1	 8.74	 6.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73342	 1	 0.0	 0.0	 0.0	 15.63	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73343	 1	 6.19	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73344	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73345	 1	 2.79	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73346	 1	 6.45	 4.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73347	 1	 4.5	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73348	 1	 11.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73349	 1	 2.55	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73350	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73351	 1	 9.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73352	 1	 11.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73353	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73354	 1	 8.74	 8.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73355	 1	 3.48	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73356	 1	 8.41	 3.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73357	 1	 4.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73358	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73359	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73360	 1	 8.99	 6.51	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73361	 1	 2.19	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73362	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73363	 1	 2.43	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73364	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73365	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73366	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73367	 1	 2.86	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73368	 1	 3.48	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73369	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73370	 1	 7.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73371	 1	 6.54	 4.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73372	 1	 2.87	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73373	 1	 10.28	 4.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73374	 1	 10.72	 6.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73375	 1	 4.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73376	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73377	 1	 8.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73378	 1	 1.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73379	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73380	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73381	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73382	 1	 2.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73383	 1	 1.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73384	 1	 4.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73385	 1	 5.98	 3.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73386	 1	 2.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73387	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73388	 1	 1.38	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73389	 1	 3.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73390	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73391	 1	 1.55	 1.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73392	 1	 1.41	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73393	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73394	 1	 3.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73395	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73396	 1	 2.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73397	 1	 9.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73398	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73399	 1	 7.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73400	 1	 26.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73401	 1	 18.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73402	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73403	 1	 9.64	 9.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73404	 1	 7.49	 4.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73405	 1	 3.76	 2.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73406	 1	 39.55	 34.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73407	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73408	 1	 8.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73409	 1	 12.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73410	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73411	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73412	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73413	 1	 7.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73414	 1	 8.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73415	 1	 0.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73416	 1	 5.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73417	 1	 7.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73418	 1	 10.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73419	 1	 7.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73420	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73421	 1	 4.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73422	 1	 4.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73423	 1	 7.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73424	 1	 7.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73425	 1	 13.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73426	 1	 4.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73427	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73428	 1	 9.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73429	 1	 6.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73430	 1	 4.05	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73431	 1	 8.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73432	 1	 12.45	 8.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73433	 1	 11.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73434	 1	 6.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73435	 1	 7.26	 4.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73436	 1	 10.33	 -19.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73437	 1	 5.31	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73438	 1	 5.11	 3.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73439	 1	 7.57	 5.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73440	 1	 5.63	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73441	 1	 17.95	 8.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73442	 1	 5.3	 1.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73443	 1	 10.29	 6.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73444	 1	 0.0	 0.0	 0.0	 124.3	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73445	 1	 7.19	 5.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73446	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73447	 1	 2.99	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73448	 1	 1.1	 0.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73449	 1	 5.88	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73450	 1	 4.4	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73451	 1	 3.26	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73452	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73453	 1	 20.74	 14.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73454	 1	 2.49	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73455	 1	 4.53	 3.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73456	 1	 3.92	 2.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73457	 1	 6.28	 5.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73458	 1	 48.19	 38.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73459	 1	 34.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73460	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73461	 1	 5.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73462	 1	 5.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73463	 1	 6.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73464	 1	 5.16	 2.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73465	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73466	 1	 7.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73467	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73468	 1	 4.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73469	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73470	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73471	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73472	 1	 10.47	 7.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73473	 1	 20.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73474	 1	 12.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73475	 1	 5.88	 3.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73476	 1	 1.6	 0.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73477	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	73478	 1	 12.24	 9.55	 0.0	 282.72	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	73479	 1	 6.19	 4.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73480	 1	 5.12	 3.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73481	 1	 3.44	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73482	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73483	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73484	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73485	 1	 5.62	 3.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73486	 1	 2.27	 0.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73487	 1	 4.61	 3.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73488	 1	 3.79	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73489	 1	 2.24	 1.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73490	 1	 5.96	 -16.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73491	 1	 3.49	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73492	 1	 6.47	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73493	 1	 4.12	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73494	 1	 2.59	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73495	 1	 2.51	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73496	 1	 8.28	 4.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73497	 1	 6.93	 4.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73498	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73499	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73500	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73501	 1	 3.11	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73502	 1	 1.43	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73503	 1	 9.63	 8.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73504	 1	 5.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73505	 1	 4.83	 3.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73506	 1	 8.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73507	 1	 4.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73508	 1	 9.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73509	 1	 2.87	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73510	 1	 9.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73511	 1	 5.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73512	 1	 4.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73513	 1	 4.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73514	 1	 9.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73515	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73516	 1	 5.65	 3.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73517	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73518	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73519	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73520	 1	 6.86	 4.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73521	 1	 6.11	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73522	 1	 9.27	 7.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73523	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	73524	 1	 0.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73525	 1	 6.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73526	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73527	 1	 16.37	 13.61	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73528	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73529	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73530	 1	 1.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73531	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73532	 1	 3.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73533	 1	 7.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73534	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73535	 1	 6.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73536	 1	 4.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73537	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73538	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73539	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73540	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73541	 1	 5.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73542	 1	 4.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73543	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73544	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73545	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73546	 1	 7.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73547	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73548	 1	 2.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73549	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73550	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73551	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73552	 1	 4.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73553	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73554	 1	 10.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73555	 1	 0.0	 0.0	 0.0	 61.65	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73556	 1	 6.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73557	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73558	 1	 7.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73559	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73560	 1	 3.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73561	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73562	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73563	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73564	 1	 1.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73565	 1	 4.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73566	 1	 2.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73567	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73568	 1	 1.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73569	 1	 4.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73570	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73571	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73572	 1	 9.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73573	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73574	 1	 12.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73575	 1	 13.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73576	 1	 1.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73577	 1	 1.77	 0.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73578	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73579	 1	 4.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73580	 1	 1.77	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73581	 1	 7.86	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73582	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73583	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73584	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73585	 1	 9.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73586	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73587	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73588	 1	 2.75	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73589	 1	 1.48	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73590	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73591	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73592	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73593	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73594	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73595	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73596	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73597	 1	 4.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73598	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73599	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73600	 1	 3.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73601	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73602	 1	 1.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73603	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73604	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73605	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73606	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73607	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73608	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73609	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73610	 1	 1.63	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73611	 1	 7.06	 2.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73612	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73613	 1	 1.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73614	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73615	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73616	 1	 2.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73617	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73618	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73619	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73620	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73621	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73622	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73623	 1	 4.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73624	 1	 7.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73625	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73626	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73627	 1	 3.47	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73628	 1	 0.0	 0.0	 0.0	 132.23	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73629	 1	 7.15	 4.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73630	 1	 6.78	 5.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73631	 1	 3.03	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73632	 1	 1.58	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73633	 1	 2.43	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73634	 1	 1.42	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73635	 1	 1.11	 0.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73636	 1	 3.18	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73637	 1	 2.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73638	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73639	 1	 2.03	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73640	 1	 3.01	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73641	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73642	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73643	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73644	 1	 8.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73645	 1	 25.53	 10.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73646	 1	 5.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73647	 1	 5.98	 2.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73648	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73649	 1	 7.62	 6.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73650	 1	 4.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73651	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73652	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73653	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73654	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73655	 1	 3.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73656	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73657	 1	 2.68	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73658	 1	 4.34	 2.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73659	 1	 3.68	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73660	 1	 1.7	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73661	 1	 1.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73662	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73663	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73664	 1	 9.65	 7.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73665	 1	 4.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73666	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73667	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73668	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73669	 1	 1.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73670	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73671	 1	 2.61	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73672	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73673	 1	 4.16	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73674	 1	 2.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73675	 1	 5.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73676	 1	 9.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73677	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73678	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73679	 1	 7.7	 3.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73680	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73681	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73682	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73683	 1	 15.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73684	 1	 0.0	 0.0	 0.0	 11.75	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73685	 1	 0.0	 0.0	 0.0	 29.24	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73686	 1	 2.16	 0.66	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73687	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73688	 1	 1.66	 0.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73689	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73690	 1	 2.97	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73691	 1	 2.01	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73692	 1	 4.47	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73693	 1	 2.85	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73694	 1	 3.4	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73695	 1	 4.96	 3.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73696	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73697	 1	 0.0	 0.0	 0.0	 59.8	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73698	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73699	 1	 2.39	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73700	 1	 2.69	 1.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73701	 1	 2.35	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73702	 1	 4.11	 2.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73703	 1	 2.18	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73704	 1	 5.78	 3.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73705	 1	 1.66	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73706	 1	 3.48	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73707	 1	 4.66	 2.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73708	 1	 6.43	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73709	 1	 7.45	 6.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73710	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73711	 1	 3.7	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73712	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73713	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73714	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73715	 1	 5.81	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73716	 1	 0.0	 0.0	 0.0	 14.59	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73717	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73718	 1	 7.76	 8.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73719	 1	 9.42	 6.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73720	 1	 4.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73721	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73722	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73723	 1	 13.72	 13.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73724	 1	 2.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73725	 1	 1.93	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73726	 1	 3.1	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73727	 1	 2.08	 1.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73728	 1	 8.7	 5.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73729	 1	 2.61	 1.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73730	 1	 4.66	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73731	 1	 3.14	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73732	 1	 5.1	 4.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73733	 1	 13.94	 8.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73734	 1	 4.08	 2.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73735	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73736	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73737	 1	 0.0	 0.0	 0.0	 59.94	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73738	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73739	 1	 6.36	 4.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73740	 1	 4.48	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73741	 1	 12.09	 11.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73742	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73743	 1	 0.0	 0.0	 0.0	 47.98	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73744	 1	 5.31	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73745	 1	 5.74	 3.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73746	 1	 4.28	 3.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73747	 1	 2.92	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73748	 1	 1.41	 0.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73749	 1	 2.26	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73750	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73751	 1	 1.43	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73752	 1	 4.88	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73753	 1	 2.96	 1.25	 0.0	 21.49	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73754	 1	 4.7	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73755	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73756	 1	 3.9	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73757	 1	 1.94	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73758	 1	 4.94	 4.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73759	 1	 0.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73760	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73761	 1	 2.92	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73762	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73763	 1	 1.98	 0.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73764	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73765	 1	 10.06	 8.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73766	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73767	 1	 2.86	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73768	 1	 4.35	 3.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73769	 1	 2.68	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73770	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73771	 1	 3.34	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73772	 1	 1.16	 0.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73773	 1	 11.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73774	 1	 7.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73775	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73776	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73777	 1	 5.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73778	 1	 4.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73779	 1	 13.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73780	 1	 8.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73781	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73782	 1	 3.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73783	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73784	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73785	 1	 4.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73786	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73787	 1	 4.42	 -12.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73788	 1	 1.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73789	 1	 2.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73790	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73791	 1	 4.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73792	 1	 4.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73793	 1	 3.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73794	 1	 8.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73795	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73796	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73797	 1	 5.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73798	 1	 5.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73799	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73800	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73801	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73802	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73803	 1	 5.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73804	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73805	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73806	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73807	 1	 7.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73808	 1	 5.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73809	 1	 10.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73810	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73811	 1	 4.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73812	 1	 7.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73813	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73814	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73815	 1	 2.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73816	 1	 5.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73817	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73818	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73819	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73820	 1	 5.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73821	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73822	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73823	 1	 9.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73824	 1	 5.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73825	 1	 2.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73826	 1	 4.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73827	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73828	 1	 6.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73829	 1	 5.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73830	 1	 3.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73831	 1	 4.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73832	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73833	 1	 17.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73834	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73835	 1	 4.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73836	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73837	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73838	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73839	 1	 2.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73840	 1	 5.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73841	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73842	 1	 7.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73843	 1	 2.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73844	 1	 2.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73845	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73846	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73847	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73848	 1	 1.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73849	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73850	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73851	 1	 4.19	 -13.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73852	 1	 2.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73853	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73854	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73855	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73856	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73857	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73858	 1	 2.39	 1.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73859	 1	 7.03	 5.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73860	 1	 1.53	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73861	 1	 2.59	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73862	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73863	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73864	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73865	 1	 2.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73866	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73867	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73868	 1	 4.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73869	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73870	 1	 1.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73871	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73872	 1	 1.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73873	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73874	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73875	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73876	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73877	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73878	 1	 3.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73879	 1	 1.72	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73880	 1	 3.54	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73881	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73882	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73883	 1	 3.72	 2.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73884	 1	 1.43	 0.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73885	 1	 5.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73886	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73887	 1	 8.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73888	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73889	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73890	 1	 6.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73891	 1	 5.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73892	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73893	 1	 3.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73894	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73895	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73896	 1	 5.75	 4.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73897	 1	 2.85	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73898	 1	 3.72	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73899	 1	 3.42	 2.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73900	 1	 3.17	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73901	 1	 2.54	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73902	 1	 3.36	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73903	 1	 0.0	 0.0	 0.0	 57.91	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73904	 1	 4.6	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73905	 1	 1.4	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73906	 1	 3.81	 2.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73907	 1	 21.43	 25.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73908	 1	 3.54	 2.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73909	 1	 5.0	 3.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73910	 1	 2.84	 1.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73911	 1	 3.62	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73912	 1	 2.98	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73913	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73914	 1	 2.47	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73915	 1	 4.78	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73916	 1	 0.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73917	 1	 3.0	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73918	 1	 3.53	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73919	 1	 2.67	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73920	 1	 1.87	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73921	 1	 1.15	 0.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73922	 1	 40.5	 52.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73923	 1	 8.43	 7.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73924	 1	 0.0	 0.0	 0.0	 35.96	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73925	 1	 4.14	 3.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73926	 1	 0.0	 0.0	 0.0	 56.54	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73927	 1	 63.05	 62.51	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73928	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73929	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73930	 1	 5.76	 3.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73931	 1	 4.38	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73932	 1	 2.03	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73933	 1	 5.52	 2.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73934	 1	 40.38	 45.97	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73935	 1	 84.08	 103.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73936	 1	 0.0	 0.0	 0.0	 -55.57	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73937	 1	 4.8	 4.67	 0.0	 35.17	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73938	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73939	 1	 15.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73940	 1	 0.0	 0.0	 0.0	 298.57	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	73941	 1	 10.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73942	 1	 2.24	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73943	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73944	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73945	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73946	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	73947	 1	 6.76	 5.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73948	 1	 2.48	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73949	 1	 9.83	 7.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73950	 1	 3.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73951	 1	 5.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73952	 1	 8.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73953	 1	 4.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73954	 1	 7.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73955	 1	 5.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73956	 1	 3.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73957	 1	 4.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73958	 1	 7.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73959	 1	 5.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73960	 1	 6.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73961	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73962	 1	 5.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73963	 1	 4.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73964	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73965	 1	 4.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73966	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73967	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73968	 1	 6.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73969	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73970	 1	 6.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73971	 1	 4.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73972	 1	 1.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73973	 1	 6.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73974	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73975	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73976	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73977	 1	 5.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73978	 1	 4.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73979	 1	 11.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73980	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73981	 1	 5.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73982	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73983	 1	 6.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73984	 1	 7.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73985	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	73986	 1	 6.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73987	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73988	 1	 3.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73989	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73990	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73991	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73992	 1	 3.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73993	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73994	 1	 5.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73995	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73996	 1	 6.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73997	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73998	 1	 4.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	73999	 1	 6.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74000	 1	 7.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74001	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74002	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74003	 1	 3.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74004	 1	 2.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74005	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74006	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74007	 1	 7.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74008	 1	 1.89	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74009	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74010	 1	 8.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74011	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74012	 1	 5.75	 4.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74013	 1	 3.32	 2.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74014	 1	 2.64	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74015	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74016	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74017	 1	 4.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74018	 1	 6.47	 3.3	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74019	 1	 2.38	 1.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74020	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74021	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74022	 1	 8.01	 6.03	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74023	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74024	 1	 2.91	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74025	 1	 2.57	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74026	 1	 5.46	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74027	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74028	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74029	 1	 0.0	 0.0	 0.0	 133.56	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74030	 1	 3.45	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74031	 1	 3.36	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74032	 1	 7.8	 3.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74033	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74034	 1	 4.67	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74035	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74036	 1	 3.28	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74037	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74038	 1	 8.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74039	 1	 4.47	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74040	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74041	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74042	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74043	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74044	 1	 4.21	 2.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74045	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74046	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74047	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74048	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74049	 1	 6.04	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74050	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74051	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74052	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74053	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74054	 1	 4.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74055	 1	 2.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74056	 1	 1.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74057	 1	 2.81	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74058	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74059	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74060	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74061	 1	 5.42	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74062	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74063	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74064	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74065	 1	 1.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74066	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74067	 1	 6.21	 3.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74068	 1	 3.44	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74069	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74070	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74071	 1	 7.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74072	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74073	 1	 10.46	 4.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74074	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74075	 1	 6.06	 2.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74076	 1	 3.19	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74077	 1	 1.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74078	 1	 4.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74079	 1	 32.75	 15.71	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74080	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74081	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74082	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74083	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74084	 1	 7.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74085	 1	 1.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74086	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74087	 1	 5.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74088	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74089	 1	 3.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74090	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74091	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74092	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74093	 1	 7.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74094	 1	 5.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74095	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74096	 1	 4.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74097	 1	 2.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74098	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74099	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74100	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74101	 1	 1.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74102	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74103	 1	 6.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74104	 1	 6.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74105	 1	 1.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74106	 1	 2.13	 1.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74107	 1	 8.02	 7.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74108	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74109	 1	 1.7	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74110	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74111	 1	 2.21	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74112	 1	 1.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74113	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74114	 1	 4.15	 1.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74115	 1	 1.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74116	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74117	 1	 4.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74118	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74119	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74120	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74121	 1	 0.0	 0.0	 0.0	 -200.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74122	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74123	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74124	 1	 5.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74125	 1	 7.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74126	 1	 2.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74127	 1	 8.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74128	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74129	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74130	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74131	 1	 4.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74132	 1	 5.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74133	 1	 5.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74134	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74135	 1	 5.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74136	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74137	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74138	 1	 2.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74139	 1	 5.24	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74140	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74141	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74142	 1	 6.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74143	 1	 3.96	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74144	 1	 6.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74145	 1	 1.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74146	 1	 8.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74147	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74148	 1	 6.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74149	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74150	 1	 4.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74151	 1	 4.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74152	 1	 11.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74153	 1	 5.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74154	 1	 7.99	 -11.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74155	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74156	 1	 4.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74157	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74158	 1	 4.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74159	 1	 7.84	 5.84	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74160	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74161	 1	 6.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74162	 1	 7.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74163	 1	 9.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74164	 1	 4.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74165	 1	 13.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74166	 1	 5.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74167	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74168	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74169	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74170	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74171	 1	 5.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74172	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74173	 1	 12.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74174	 1	 66.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74175	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74176	 1	 3.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74177	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74178	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74179	 1	 3.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74180	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74181	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74182	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74183	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74184	 1	 4.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74185	 1	 4.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74186	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74187	 1	 12.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74188	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74189	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74190	 1	 1.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74191	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74192	 1	 11.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74193	 1	 5.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74194	 1	 5.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74195	 1	 1.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74196	 1	 1.35	 0.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74197	 1	 0.0	 0.0	 0.0	 -15.87	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74198	 1	 3.77	 2.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74199	 1	 8.5	 4.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74200	 1	 10.02	 8.77	 0.0	 -100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74201	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74202	 1	 3.76	 2.34	 0.0	 -100.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74203	 1	 5.07	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74204	 1	 0.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74205	 1	 2.49	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74206	 1	 2.28	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74207	 1	 2.92	 1.67	 0.0	 -126.54	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74208	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74209	 1	 1.43	 0.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74210	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74211	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74212	 1	 2.41	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74213	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74214	 1	 5.32	 -18.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74215	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74216	 1	 3.64	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74217	 1	 4.28	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74218	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74219	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74220	 1	 1.61	 0.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74221	 1	 2.43	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74222	 1	 5.8	 3.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74223	 1	 3.1	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74224	 1	 1.19	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74225	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74226	 1	 3.32	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74227	 1	 1.19	 0.5	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74228	 1	 1.28	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74229	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74230	 1	 3.3	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74231	 1	 4.13	 3.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74232	 1	 6.32	 4.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74233	 1	 1.95	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74234	 1	 4.02	 3.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74235	 1	 3.5	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74236	 1	 2.84	 -13.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74237	 1	 6.08	 4.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74238	 1	 3.1	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74239	 1	 5.14	 -18.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74240	 1	 4.78	 2.3	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74241	 1	 2.41	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74242	 1	 1.06	 0.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74243	 1	 9.9	 -20.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74244	 1	 2.41	 1.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74245	 1	 9.23	 7.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74246	 1	 1.62	 0.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74247	 1	 2.38	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74248	 1	 4.44	 3.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74249	 1	 1.95	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74250	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74251	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74252	 1	 11.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74253	 1	 6.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74254	 1	 3.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74255	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74256	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74257	 1	 9.31	 6.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74258	 1	 3.4	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74259	 1	 2.01	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74260	 1	 2.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74261	 1	 1.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74262	 1	 13.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74263	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74264	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74265	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74266	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74267	 1	 1.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74268	 1	 2.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74269	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74270	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74271	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74272	 1	 7.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74273	 1	 8.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74274	 1	 3.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74275	 1	 4.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74276	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74277	 1	 7.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74278	 1	 1.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74279	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74280	 1	 8.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74281	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74282	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74283	 1	 1.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74284	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74285	 1	 5.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74286	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74287	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74288	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74289	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74290	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74291	 1	 72.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74292	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74293	 1	 7.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74294	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74295	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74296	 1	 3.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74297	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74298	 1	 13.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74299	 1	 13.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74300	 1	 10.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74301	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74302	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74303	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74304	 1	 3.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74305	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74306	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74307	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74308	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74309	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74310	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74311	 1	 22.66	 10.67	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74312	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74313	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74314	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74315	 1	 6.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74316	 1	 4.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74317	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74318	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74319	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74320	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74321	 1	 11.41	 4.23	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74322	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74323	 1	 6.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74324	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74325	 1	 1.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74326	 1	 5.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74327	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74328	 1	 1.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74329	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74330	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74331	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74332	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74333	 1	 4.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74334	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74335	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74336	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74337	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74338	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74339	 1	 4.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74340	 1	 9.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74341	 1	 10.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74342	 1	 3.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74343	 1	 9.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74344	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74345	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74346	 1	 4.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74347	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74348	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74349	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74350	 1	 13.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74351	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74352	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74353	 1	 7.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74354	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74355	 1	 21.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74356	 1	 7.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74357	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74358	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74359	 1	 5.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74360	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74361	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74362	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74363	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74364	 1	 7.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74365	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74366	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74367	 1	 9.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74368	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74369	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74370	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74371	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74372	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74373	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74374	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74375	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74376	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74377	 1	 2.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74378	 1	 7.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74379	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74380	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74381	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74382	 1	 5.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74383	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74384	 1	 5.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74385	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74386	 1	 4.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74387	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74388	 1	 2.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74389	 1	 5.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74390	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74391	 1	 8.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74392	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74393	 1	 5.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74394	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74395	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74396	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74397	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74398	 1	 8.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74399	 1	 5.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74400	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74401	 1	 7.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74402	 1	 8.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74403	 1	 4.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74404	 1	 6.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74405	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74406	 1	 4.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74407	 1	 10.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74408	 1	 4.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74409	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74410	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74411	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74412	 1	 19.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74413	 1	 16.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74414	 1	 13.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74415	 1	 4.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74416	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74417	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74418	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74419	 1	 12.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74420	 1	 5.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74421	 1	 7.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74422	 1	 6.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74423	 1	 6.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74424	 1	 3.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74425	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74426	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74427	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74428	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74429	 1	 11.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74430	 1	 7.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74431	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74432	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74433	 1	 3.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74434	 1	 4.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74435	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74436	 1	 5.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74437	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74438	 1	 3.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74439	 1	 5.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74440	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74441	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74442	 1	 1.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74443	 1	 6.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74444	 1	 5.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74445	 1	 8.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74446	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74447	 1	 2.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74448	 1	 1.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74449	 1	 4.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74450	 1	 5.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74451	 1	 7.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74452	 1	 4.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74453	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74454	 1	 5.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74455	 1	 6.16	 3.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74456	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74457	 1	 7.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74458	 1	 11.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74459	 1	 19.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74460	 1	 7.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74461	 1	 2.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74462	 1	 6.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74463	 1	 5.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74464	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74465	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74466	 1	 13.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74467	 1	 19.62	 -16.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74468	 1	 8.82	 6.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74469	 1	 4.81	 2.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74470	 1	 4.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74471	 1	 12.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74472	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74473	 1	 5.11	 4.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74474	 1	 24.05	 -62.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74475	 1	 11.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74476	 1	 7.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74477	 1	 4.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74478	 1	 4.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74479	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74480	 1	 6.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74481	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74482	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74483	 1	 7.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74484	 1	 2.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74485	 1	 6.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74486	 1	 3.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74487	 1	 9.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74488	 1	 8.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74489	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74490	 1	 6.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74491	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74492	 1	 10.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74493	 1	 16.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74494	 1	 4.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74495	 1	 6.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74496	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74497	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74498	 1	 6.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74499	 1	 18.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74500	 1	 5.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74501	 1	 26.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74502	 1	 5.16	 -7.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74503	 1	 2.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74504	 1	 2.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74505	 1	 9.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74506	 1	 4.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74507	 1	 8.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74508	 1	 7.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74509	 1	 2.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74510	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74511	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74512	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74513	 1	 6.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74514	 1	 7.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74515	 1	 1.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74516	 1	 8.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74517	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74518	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74519	 1	 5.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74520	 1	 6.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74521	 1	 12.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74522	 1	 2.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74523	 1	 6.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74524	 1	 9.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74525	 1	 6.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74526	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74527	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74528	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74529	 1	 14.22	 -21.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74530	 1	 13.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74531	 1	 19.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74532	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74533	 1	 16.18	 -19.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74534	 1	 7.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74535	 1	 6.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74536	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74537	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74538	 1	 5.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74539	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74540	 1	 10.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74541	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74542	 1	 9.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74543	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74544	 1	 4.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74545	 1	 7.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74546	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74547	 1	 7.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74548	 1	 4.84	 3.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74549	 1	 5.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74550	 1	 8.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74551	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74552	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74553	 1	 1.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74554	 1	 5.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74555	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74556	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74557	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74558	 1	 9.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74559	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74560	 1	 4.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74561	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74562	 1	 5.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74563	 1	 5.08	 -23.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74564	 1	 3.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74565	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74566	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74567	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74568	 1	 5.46	 -26.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74569	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74570	 1	 3.6	 2.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74571	 1	 4.66	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74572	 1	 3.41	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74573	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74574	 1	 5.42	 3.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74575	 1	 8.14	 5.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74576	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74577	 1	 8.68	 9.05	 0.0	 200.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74578	 1	 2.62	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74579	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74580	 1	 12.81	 4.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74581	 1	 4.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74582	 1	 6.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74583	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74584	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74585	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74586	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74587	 1	 6.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74588	 1	 1.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74589	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74590	 1	 5.44	 4.29	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74591	 1	 4.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74592	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74593	 1	 6.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74594	 1	 6.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74595	 1	 5.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74596	 1	 3.81	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74597	 1	 4.03	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74598	 1	 6.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74599	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74600	 1	 0.0	 0.0	 0.0	 215.15	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74601	 1	 12.67	 7.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74602	 1	 2.39	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74603	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74604	 1	 5.77	 3.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74605	 1	 5.99	 3.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74606	 1	 4.89	 3.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74607	 1	 14.37	 11.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74608	 1	 5.89	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74609	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74610	 1	 8.39	 4.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74611	 1	 4.54	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74612	 1	 5.21	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74613	 1	 5.21	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74614	 1	 7.72	 2.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74615	 1	 3.85	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74616	 1	 3.28	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74617	 1	 5.42	 3.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74618	 1	 2.45	 0.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74619	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74620	 1	 6.31	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74621	 1	 4.62	 3.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74622	 1	 3.26	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74623	 1	 10.19	 7.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74624	 1	 2.46	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74625	 1	 2.62	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74626	 1	 2.23	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74627	 1	 5.54	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74628	 1	 2.31	 1.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74629	 1	 3.65	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74630	 1	 3.53	 2.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74631	 1	 7.0	 4.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74632	 1	 2.17	 1.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74633	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74634	 1	 4.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74635	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74636	 1	 4.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74637	 1	 6.94	 3.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74638	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74639	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74640	 1	 4.12	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74641	 1	 2.82	 0.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74642	 1	 3.49	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74643	 1	 1.8	 0.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74644	 1	 11.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74645	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74646	 1	 9.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74647	 1	 10.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74648	 1	 1.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74649	 1	 8.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74650	 1	 4.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74651	 1	 12.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74652	 1	 7.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74653	 1	 4.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74654	 1	 7.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74655	 1	 5.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74656	 1	 3.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74657	 1	 0.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74658	 1	 11.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74659	 1	 2.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74660	 1	 6.8	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74661	 1	 13.09	 6.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74662	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74663	 1	 9.04	 4.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74664	 1	 4.43	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74665	 1	 4.43	 2.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74666	 1	 4.09	 2.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74667	 1	 4.77	 2.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74668	 1	 9.45	 4.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74669	 1	 3.19	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74670	 1	 10.2	 7.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74671	 1	 3.75	 1.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74672	 1	 6.28	 4.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74673	 1	 3.58	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74674	 1	 1.73	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74675	 1	 7.2	 6.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74676	 1	 3.51	 1.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74677	 1	 7.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74678	 1	 5.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74679	 1	 5.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74680	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74681	 1	 5.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74682	 1	 8.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74683	 1	 8.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74684	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74685	 1	 5.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74686	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74687	 1	 3.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74688	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74689	 1	 1.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74690	 1	 3.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74691	 1	 3.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74692	 1	 4.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74693	 1	 3.48	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74694	 1	 5.11	 3.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74695	 1	 6.08	 5.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74696	 1	 3.28	 2.84	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74697	 1	 5.34	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74698	 1	 1.55	 1.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74699	 1	 3.54	 2.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74700	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74701	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74702	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74703	 1	 2.53	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74704	 1	 5.11	 3.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74705	 1	 1.25	 0.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74706	 1	 1.66	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74707	 1	 1.8	 0.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74708	 1	 3.2	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74709	 1	 2.97	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74710	 1	 1.45	 0.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74711	 1	 0.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74712	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74713	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74714	 1	 4.93	 2.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74715	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74716	 1	 3.08	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74717	 1	 6.78	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74718	 1	 0.0	 0.0	 0.0	 -185.1	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74719	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74720	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74721	 1	 2.42	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74722	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74723	 1	 3.2	 2.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74724	 1	 2.25	 1.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74725	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74726	 1	 2.41	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74727	 1	 9.99	 -11.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74728	 1	 5.69	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74729	 1	 2.98	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74730	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74731	 1	 2.92	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74732	 1	 3.63	 2.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74733	 1	 3.5	 2.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74734	 1	 4.15	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74735	 1	 8.2	 5.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74736	 1	 4.0	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74737	 1	 4.51	 3.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74738	 1	 2.67	 1.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74739	 1	 8.27	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74740	 1	 2.17	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74741	 1	 4.12	 -16.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74742	 1	 2.11	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74743	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74744	 1	 1.34	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74745	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74746	 1	 49.0	 41.79	 0.0	 117.77	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74747	 1	 1.43	 0.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74748	 1	 2.97	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74749	 1	 2.48	 1.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74750	 1	 12.16	 15.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74751	 1	 2.16	 1.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74752	 1	 2.09	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74753	 1	 4.17	 -13.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74754	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74755	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74756	 1	 5.24	 3.69	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74757	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74758	 1	 3.26	 2.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74759	 1	 2.53	 1.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74760	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74761	 1	 1.62	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74762	 1	 3.8	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74763	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74764	 1	 8.14	 6.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74765	 1	 3.3	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74766	 1	 2.35	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74767	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74768	 1	 3.65	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74769	 1	 1.87	 0.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74770	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74771	 1	 1.61	 0.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74772	 1	 2.08	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74773	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74774	 1	 1.51	 0.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74775	 1	 6.99	 3.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74776	 1	 6.23	 4.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74777	 1	 3.34	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74778	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74779	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74780	 1	 3.92	 1.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74781	 1	 1.64	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74782	 1	 0.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74783	 1	 1.96	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74784	 1	 4.95	 3.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74785	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	74786	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74787	 1	 3.27	 1.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74788	 1	 2.76	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74789	 1	 3.44	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74790	 1	 2.62	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74791	 1	 5.72	 4.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74792	 1	 1.91	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74793	 1	 4.65	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74794	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74795	 1	 4.44	 3.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74796	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74797	 1	 1.66	 0.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74798	 1	 0.0	 0.0	 0.0	 16.47	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74799	 1	 1.44	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74800	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74801	 1	 3.41	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74802	 1	 3.04	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74803	 1	 1.15	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74804	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74805	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74806	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74807	 1	 3.54	 2.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74808	 1	 2.01	 0.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74809	 1	 3.27	 1.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74810	 1	 1.1	 0.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74811	 1	 3.25	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74812	 1	 2.65	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74813	 1	 3.56	 2.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74814	 1	 0.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74815	 1	 3.48	 2.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74816	 1	 1.25	 0.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74817	 1	 4.51	 3.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74818	 1	 12.54	 8.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74819	 1	 3.01	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74820	 1	 7.43	 4.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74821	 1	 7.81	 6.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74822	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74823	 1	 6.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74824	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74825	 1	 2.44	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74826	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74827	 1	 2.12	 0.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74828	 1	 5.41	 4.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74829	 1	 3.1	 2.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74830	 1	 1.35	 0.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74831	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74832	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74833	 1	 3.33	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74834	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74835	 1	 1.95	 0.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74836	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74837	 1	 2.05	 1.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74838	 1	 2.1	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74839	 1	 3.71	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74840	 1	 2.72	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74841	 1	 11.76	 5.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74842	 1	 5.18	 2.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74843	 1	 4.86	 3.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74844	 1	 3.23	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74845	 1	 2.25	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74846	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74847	 1	 12.92	 9.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74848	 1	 4.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74849	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74850	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74851	 1	 0.0	 0.0	 0.0	 13.41	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	74852	 1	 5.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74853	 1	 8.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74854	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74855	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74856	 1	 6.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74857	 1	 3.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74858	 1	 15.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74859	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74860	 1	 1.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74861	 1	 1.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74862	 1	 4.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74863	 1	 2.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74864	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74865	 1	 1.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74866	 1	 9.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74867	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74868	 1	 5.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74869	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74870	 1	 7.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74871	 1	 6.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74872	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74873	 1	 4.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74874	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74875	 1	 5.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74876	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74877	 1	 11.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74878	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74879	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74880	 1	 4.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74881	 1	 2.83	 -19.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74882	 1	 1.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74883	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74884	 1	 9.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74885	 1	 50.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74886	 1	 10.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74887	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74888	 1	 6.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74889	 1	 16.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74890	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74891	 1	 3.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74892	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74893	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74894	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74895	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74896	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74897	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74898	 1	 8.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74899	 1	 3.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74900	 1	 11.68	 -10.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	74901	 1	 7.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74902	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75433	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75434	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75435	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75436	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75437	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75438	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75439	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75440	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75441	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75442	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75443	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75444	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75445	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75446	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75447	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75448	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75449	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75450	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75451	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75452	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75453	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75454	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75455	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75456	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75457	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75458	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75459	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75460	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75461	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75462	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75463	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75464	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75465	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75466	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75467	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75468	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75469	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75470	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75471	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75472	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75473	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75474	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75475	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75476	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75477	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75478	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75479	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75480	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75481	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75482	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75483	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75484	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75485	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75486	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75487	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75488	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75489	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75490	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75491	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75492	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75493	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75494	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75495	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75496	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75497	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75498	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75499	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75500	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75501	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75502	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75503	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75504	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75505	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75506	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75507	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75508	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75509	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75510	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75511	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75512	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75513	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75514	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75515	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75516	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75517	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75518	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75519	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75520	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75521	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75522	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75523	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75524	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75525	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75526	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75527	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75528	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75529	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75530	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75531	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75532	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75533	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75534	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75535	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75536	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75537	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75538	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75539	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75540	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75541	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75542	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75543	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75544	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75545	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75546	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75547	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75548	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75549	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75550	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75551	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75552	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75553	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75554	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75555	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75556	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75557	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75558	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75559	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75560	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75561	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75562	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75563	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75564	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75565	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75566	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75567	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75568	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75569	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75570	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75571	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75572	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75573	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75574	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75575	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75576	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75577	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75578	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75579	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75580	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75581	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75582	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75583	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75584	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75585	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75586	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75587	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75588	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75589	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75590	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75591	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75592	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75593	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75594	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75595	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75596	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75597	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75598	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75599	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75600	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75601	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75602	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75603	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75604	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75605	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75606	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75607	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75608	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75609	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75610	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75611	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75612	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75613	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75614	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75615	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75616	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75617	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75618	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75619	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75620	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75621	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75622	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75623	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75624	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75625	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75626	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75627	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75628	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75629	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75630	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75631	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75632	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75633	 1	 21.41	 3.46	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75634	 1	 8.78	 1.87	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75635	 1	 6.41	 1.73	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75636	 1	 9.92	 1.45	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75637	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75638	 1	 33.39	 5.13	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75639	 1	 6.15	 1.21	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75640	 1	 8.8	 1.62	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75641	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75642	 1	 209.94	 40.04	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75643	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75644	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75645	 1	 19.31	 2.78	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75646	 1	 5.24	 1.55	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75647	 1	 13.46	 1.82	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75648	 1	 10.26	 1.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75649	 1	 8.79	 2.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75650	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75651	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75652	 1	 9.33	 1.99	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75653	 1	 30.76	 8.83	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75654	 1	 15.98	 4.17	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75655	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75656	 1	 45.11	 5.48	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75657	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75658	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75659	 1	 26.76	 7.85	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75660	 1	 15.9	 3.4	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75661	 1	 21.76	 4.67	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75662	 1	 5.91	 1.19	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75663	 1	 12.82	 1.74	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75664	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75665	 1	 34.65	 4.63	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75666	 1	 8.93	 1.46	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75667	 1	 7.85	 1.71	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75668	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75669	 1	 8.74	 2.48	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75670	 1	 39.05	 9.62	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75671	 1	 3.25	 0.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75672	 1	 38.67	 5.53	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75673	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75674	 1	 10.94	 2.89	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75675	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75676	 1	 5.87	 1.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75677	 1	 13.59	 3.87	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75678	 1	 7.88	 2.17	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75679	 1	 3.07	 0.86	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75680	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75681	 1	 56.83	 13.45	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75682	 1	 24.03	 7.13	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75683	 1	 10.94	 2.62	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75684	 1	 108.22	 20.55	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75685	 1	 32.03	 5.9	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75686	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75687	 1	 37.22	 10.29	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75688	 1	 37.11	 9.43	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75689	 1	 15.54	 4.68	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75690	 1	 18.91	 4.72	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75691	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75692	 1	 74.12	 20.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75693	 1	 36.66	 6.8	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75694	 1	 5.11	 1.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75695	 1	 9.75	 1.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75696	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75697	 1	 54.88	 13.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75698	 1	 2.11	 0.6	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75699	 1	 8.26	 1.27	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75700	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75701	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75702	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75703	 1	 18.69	 5.56	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75704	 1	 30.02	 5.2	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75705	 1	 12.35	 3.24	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75706	 1	 30.33	 6.45	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75707	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75708	 1	 1.6	 0.44	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75709	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75710	 1	 11.2	 1.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75711	 1	 8.52	 1.25	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75712	 1	 6.91	 2.18	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75713	 1	 14.7	 1.97	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75714	 1	 5.76	 1.56	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75715	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75716	 1	 26.67	 5.76	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75717	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75718	 1	 13.88	 4.31	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75719	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75720	 1	 45.02	 9.91	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75721	 1	 9.55	 2.69	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75722	 1	 6.86	 0.95	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75723	 1	 22.54	 5.17	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75724	 1	 7.13	 0.84	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75725	 1	 6.75	 1.94	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75726	 1	 22.89	 2.65	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75727	 1	 19.09	 3.98	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75728	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75729	 1	 17.92	 2.59	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75730	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75731	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75732	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75733	 1	 11.05	 1.95	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75734	 1	 16.28	 4.47	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75735	 1	 11.86	 3.36	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75736	 1	 20.36	 3.18	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75737	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75738	 1	 12.94	 4.04	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75739	 1	 24.19	 2.97	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75740	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75741	 1	 83.13	 23.57	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75742	 1	 29.4	 5.03	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75743	 1	 17.43	 4.75	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75744	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75745	 1	 12.15	 2.97	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75746	 1	 10.0	 1.81	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75747	 1	 9.87	 2.08	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75748	 1	 24.69	 5.94	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75749	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75750	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75751	 1	 11.3	 3.42	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75752	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75753	 1	 12.65	 2.58	 0.0	 0.0	 4	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75754	 1	 3.74	 0.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75755	 1	 7.55	 1.94	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75756	 1	 9.76	 1.82	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75757	 1	 4.61	 1.14	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75758	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75759	 1	 5.14	 1.42	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75760	 1	 8.86	 1.11	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75761	 1	 1.88	 0.51	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75762	 1	 21.63	 3.53	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75763	 1	 2.83	 0.53	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75764	 1	 23.29	 6.99	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75765	 1	 10.83	 2.81	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75766	 1	 11.13	 2.58	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75767	 1	 4.67	 0.96	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75768	 1	 12.52	 3.79	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75769	 1	 9.42	 2.34	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75770	 1	 16.24	 2.89	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75771	 1	 74.98	 22.46	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75772	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75773	 1	 11.74	 2.98	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75774	 1	 3.8	 0.55	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75775	 1	 13.95	 2.69	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75776	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75777	 1	 22.07	 7.15	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75778	 1	 18.98	 2.39	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75779	 1	 20.45	 3.55	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75780	 1	 73.59	 16.57	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75781	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75782	 1	 12.03	 1.67	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75783	 1	 25.89	 7.65	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75784	 1	 16.08	 3.99	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75785	 1	 9.27	 2.44	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75786	 1	 14.92	 2.67	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75787	 1	 10.63	 2.75	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75788	 1	 13.05	 3.62	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75789	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75790	 1	 14.18	 2.03	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75791	 1	 27.09	 6.54	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75792	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75793	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75794	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75795	 1	 26.65	 6.46	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75796	 1	 17.8	 4.84	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75797	 1	 8.29	 1.45	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75798	 1	 10.44	 2.34	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75799	 1	 15.64	 2.91	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75800	 1	 11.29	 2.44	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75801	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75802	 1	 30.21	 9.59	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75803	 1	 12.54	 2.42	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75804	 1	 6.3	 1.93	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75805	 1	 26.25	 6.2	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75806	 1	 5.48	 1.19	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75807	 1	 36.11	 8.01	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75808	 1	 6.8	 1.94	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75809	 1	 5.58	 1.8	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75810	 1	 5.36	 2.88	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75811	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75812	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75813	 1	 4.14	 1.07	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75814	 1	 4.17	 0.95	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75815	 1	 91.33	 18.87	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75816	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75817	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75818	 1	 36.67	 5.62	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75819	 1	 13.91	 2.24	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75820	 1	 8.25	 1.82	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75821	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75822	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75823	 1	 30.44	 8.62	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75824	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75825	 1	 9.58	 2.46	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75826	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75827	 1	 13.2	 2.3	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75828	 1	 12.66	 2.49	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75829	 1	 9.27	 2.05	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75830	 1	 19.51	 2.63	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75831	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75832	 1	 1.79	 0.58	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75833	 1	 6.6	 1.24	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75834	 1	 25.32	 6.74	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75835	 1	 27.91	 4.94	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75836	 1	 22.15	 5.02	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75837	 1	 22.96	 4.29	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75838	 1	 7.12	 1.34	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75839	 1	 10.24	 2.16	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75840	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75841	 1	 29.11	 4.81	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75842	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75843	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75844	 1	 25.54	 5.37	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75845	 1	 3.69	 0.88	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75846	 1	 100.79	 14.73	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75847	 1	 16.67	 4.16	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75848	 1	 6.84	 1.31	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75849	 1	 7.5	 1.67	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75850	 1	 4.25	 1.02	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75851	 1	 183.45	 41.6	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75852	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75853	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75854	 1	 15.29	 4.05	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75855	 1	 78.85	 21.27	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75856	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75857	 1	 5.89	 1.81	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75858	 1	 18.93	 5.11	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75859	 1	 3.88	 1.03	 0.0	 0.0	 5	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75860	 1	 7.18	 1.62	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75861	 1	 9.63	 3.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75862	 1	 15.03	 3.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75863	 1	 25.03	 5.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75864	 1	 10.98	 2.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75865	 1	 8.68	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75866	 1	 5.5	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75867	 1	 14.88	 4.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75868	 1	 11.78	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75869	 1	 27.49	 5.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75870	 1	 17.3	 2.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75871	 1	 48.0	 15.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75872	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75873	 1	 6.68	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75874	 1	 18.58	 4.81	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75875	 1	 16.79	 3.59	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75876	 1	 9.96	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75877	 1	 10.37	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75878	 1	 12.65	 3.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75879	 1	 9.57	 2.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75880	 1	 10.95	 1.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75881	 1	 6.28	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75882	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75883	 1	 6.05	 1.33	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75884	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75885	 1	 23.99	 6.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75886	 1	 8.22	 1.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75887	 1	 23.55	 7.19	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75888	 1	 2.51	 0.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75889	 1	 19.75	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75890	 1	 20.99	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75891	 1	 18.3	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75892	 1	 4.81	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75893	 1	 11.33	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75894	 1	 14.34	 -3.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75895	 1	 21.1	 -3.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75896	 1	 17.18	 -3.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75897	 1	 14.16	 -3.96	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75898	 1	 5.76	 0.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75899	 1	 11.85	 2.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75900	 1	 13.41	 3.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75901	 1	 43.58	 14.27	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75902	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75903	 1	 11.9	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75904	 1	 37.24	 12.32	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75905	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75906	 1	 12.34	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75907	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75908	 1	 15.02	 0.0	 0.0	 45.71	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75909	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75910	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75911	 1	 12.53	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75912	 1	 19.12	 2.97	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75913	 1	 10.15	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75914	 1	 14.47	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75915	 1	 7.01	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75916	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75917	 1	 22.87	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75918	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75919	 1	 6.08	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75920	 1	 10.46	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75921	 1	 3.88	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75922	 1	 10.31	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75923	 1	 9.37	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75924	 1	 11.52	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75925	 1	 5.1	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75926	 1	 14.36	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75927	 1	 29.23	 -7.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75928	 1	 24.64	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75929	 1	 21.7	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75930	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75931	 1	 19.21	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75932	 1	 11.85	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75933	 1	 21.62	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75934	 1	 8.16	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75935	 1	 7.56	 2.06	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75936	 1	 10.63	 2.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75937	 1	 6.25	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75938	 1	 6.14	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75939	 1	 17.24	 5.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75940	 1	 5.31	 1.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75941	 1	 30.49	 6.94	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75942	 1	 9.33	 2.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75943	 1	 17.7	 5.57	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75944	 1	 12.22	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75945	 1	 40.43	 13.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75946	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75947	 1	 16.73	 4.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75948	 1	 24.94	 -9.7	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75949	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	75950	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75951	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75952	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75953	 1	 15.68	 4.79	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75954	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75955	 1	 32.3	 10.37	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75956	 1	 20.66	 6.77	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75957	 1	 11.27	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75958	 1	 34.17	 4.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75959	 1	 19.27	 3.42	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75960	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75961	 1	 16.86	 3.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75962	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75963	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75964	 1	 12.49	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75965	 1	 16.72	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75966	 1	 19.86	 3.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75967	 1	 5.3	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75968	 1	 14.6	 2.09	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75969	 1	 34.38	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75970	 1	 6.61	 0.93	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75971	 1	 11.01	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75972	 1	 5.71	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75973	 1	 8.52	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75974	 1	 20.31	 3.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75975	 1	 9.53	 1.34	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75976	 1	 11.72	 1.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75977	 1	 16.01	 4.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75978	 1	 8.16	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75979	 1	 5.88	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75980	 1	 16.05	 2.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75981	 1	 8.15	 2.05	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75982	 1	 7.18	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75983	 1	 87.89	 16.22	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75984	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75985	 1	 16.22	 3.34	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	75986	 1	 11.08	 1.58	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75987	 1	 10.89	 3.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75988	 1	 32.74	 7.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75989	 1	 6.47	 1.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75990	 1	 21.15	 5.72	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75991	 1	 6.4	 0.87	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75992	 1	 11.44	 3.48	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75993	 1	 9.62	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75994	 1	 9.31	 2.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75995	 1	 9.86	 2.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75996	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	75997	 1	 38.45	 12.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75998	 1	 5.16	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	75999	 1	 3.33	 0.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76000	 1	 4.27	 1.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76001	 1	 8.25	 0.98	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76002	 1	 4.56	 0.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76003	 1	 9.85	 2.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76004	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76005	 1	 5.13	 1.23	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76006	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76007	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76008	 1	 8.97	 2.56	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76009	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76010	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76011	 1	 5.59	 0.69	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76012	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76013	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76014	 1	 225.87	 40.15	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76015	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76016	 1	 18.16	 2.7	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76017	 1	 6.05	 0.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76018	 1	 14.81	 2.92	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76019	 1	 20.02	 5.74	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76020	 1	 19.4	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76021	 1	 18.85	 4.66	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76022	 1	 6.6	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76023	 1	 6.85	 1.13	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76024	 1	 9.19	 1.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76025	 1	 3.3	 0.43	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76026	 1	 3.49	 0.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76027	 1	 5.38	 0.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76028	 1	 118.21	 40.33	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76029	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76030	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76031	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76032	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76033	 1	 6.37	 0.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76034	 1	 7.85	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76035	 1	 5.85	 1.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76036	 1	 9.28	 2.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76037	 1	 6.58	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76038	 1	 7.53	 1.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76039	 1	 8.94	 1.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76040	 1	 6.32	 1.47	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76041	 1	 11.74	 2.61	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76042	 1	 7.99	 1.22	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76043	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76044	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76045	 1	 12.05	 2.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76046	 1	 6.34	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76047	 1	 12.37	 2.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76048	 1	 7.83	 2.07	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76049	 1	 9.61	 2.64	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76050	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76051	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76052	 1	 13.5	 2.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76053	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76054	 1	 9.69	 2.63	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76055	 1	 7.93	 1.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76056	 1	 9.3	 1.73	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76057	 1	 3.29	 0.85	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76058	 1	 21.47	 3.17	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76059	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76060	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76061	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76062	 1	 7.53	 1.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76063	 1	 8.08	 1.91	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76064	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76065	 1	 31.46	 5.27	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76066	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76067	 1	 13.6	 3.34	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76068	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76069	 1	 9.46	 3.08	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76070	 1	 16.67	 2.14	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76071	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76072	 1	 14.63	 2.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76073	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76074	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76075	 1	 8.79	 2.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76076	 1	 29.02	 9.35	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76077	 1	 8.49	 1.68	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76078	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76079	 1	 11.55	 2.56	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76080	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76081	 1	 8.53	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76082	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76083	 1	 15.61	 5.09	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76084	 1	 13.46	 3.31	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76085	 1	 16.98	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76086	 1	 8.25	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76087	 1	 19.65	 5.51	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76088	 1	 9.19	 1.83	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76089	 1	 10.36	 1.5	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76090	 1	 12.76	 3.75	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76091	 1	 12.07	 2.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76092	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76093	 1	 28.96	 9.32	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76094	 1	 4.99	 0.84	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76095	 1	 10.99	 2.76	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76096	 1	 10.86	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76097	 1	 13.18	 2.02	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76098	 1	 15.47	 4.6	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76099	 1	 5.26	 1.24	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76100	 1	 6.26	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76101	 1	 7.72	 1.95	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76102	 1	 4.97	 1.12	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76103	 1	 29.1	 6.11	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76104	 1	 17.81	 4.31	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76105	 1	 15.15	 1.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76106	 1	 6.95	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76107	 1	 8.86	 2.46	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76108	 1	 12.69	 2.55	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76109	 1	 15.72	 1.99	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76110	 1	 26.34	 4.9	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76111	 1	 15.97	 3.25	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76112	 1	 4.77	 0.82	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76113	 1	 4.24	 0.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76114	 1	 12.49	 3.29	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76115	 1	 7.69	 2.1	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76116	 1	 16.94	 3.97	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76117	 1	 24.85	 6.88	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76118	 1	 10.19	 2.3	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76119	 1	 10.41	 1.81	 0.0	 0.0	 8	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76120	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76121	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76122	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76123	 1	 27.51	 5.56	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76124	 1	 5.21	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76125	 1	 30.02	 8.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76126	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76127	 1	 9.56	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76128	 1	 8.78	 2.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76129	 1	 15.62	 3.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76130	 1	 16.4	 5.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76131	 1	 54.13	 11.09	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76132	 1	 11.96	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76133	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76134	 1	 27.32	 3.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76135	 1	 11.34	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76136	 1	 18.01	 5.4	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76137	 1	 4.96	 1.34	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76138	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76139	 1	 24.94	 6.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76140	 1	 16.41	 3.25	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76141	 1	 12.09	 3.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76142	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76143	 1	 8.38	 1.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76144	 1	 6.7	 0.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76145	 1	 6.37	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76146	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76147	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76148	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76149	 1	 18.01	 4.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76150	 1	 7.53	 1.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76151	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76152	 1	 46.25	 10.13	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76153	 1	 7.38	 1.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76154	 1	 5.62	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76155	 1	 6.12	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76156	 1	 8.75	 2.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76157	 1	 7.13	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76158	 1	 7.71	 1.18	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76159	 1	 7.05	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76160	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76161	 1	 6.56	 1.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76162	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76163	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76164	 1	 8.94	 1.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76165	 1	 7.86	 1.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76166	 1	 9.18	 2.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76167	 1	 6.53	 1.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76168	 1	 2.78	 0.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76169	 1	 7.75	 1.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76170	 1	 11.18	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76171	 1	 8.12	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76172	 1	 7.52	 2.28	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76173	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76174	 1	 6.57	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76175	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76176	 1	 8.16	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76177	 1	 9.32	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76178	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76179	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76180	 1	 13.25	 2.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76181	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76182	 1	 13.35	 4.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76183	 1	 3.64	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76184	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76185	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76186	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76187	 1	 14.17	 3.4	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76188	 1	 20.29	 6.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76189	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76190	 1	 5.53	 1.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76191	 1	 8.0	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76192	 1	 5.43	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76193	 1	 8.06	 1.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76194	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76195	 1	 22.03	 5.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76196	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76197	 1	 27.92	 6.31	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76198	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76199	 1	 73.79	 20.54	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76200	 1	 7.06	 1.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76201	 1	 14.87	 2.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76202	 1	 20.47	 3.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76203	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76204	 1	 12.2	 2.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76205	 1	 5.0	 0.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76206	 1	 7.95	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76207	 1	 69.35	 16.38	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76208	 1	 9.31	 2.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76209	 1	 11.52	 2.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76210	 1	 28.97	 5.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76211	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76212	 1	 8.0	 2.11	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76213	 1	 12.63	 3.33	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76214	 1	 21.11	 3.53	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76215	 1	 9.07	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76216	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76217	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76218	 1	 13.63	 3.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76219	 1	 11.03	 2.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76220	 1	 15.52	 3.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76221	 1	 29.33	 3.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76222	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76223	 1	 9.07	 1.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76224	 1	 6.27	 1.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76225	 1	 6.8	 1.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76226	 1	 5.82	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76227	 1	 5.13	 1.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76228	 1	 4.57	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76229	 1	 6.23	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76230	 1	 7.8	 2.01	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76231	 1	 13.08	 3.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76232	 1	 31.08	 7.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76233	 1	 18.19	 5.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76234	 1	 11.0	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76235	 1	 4.75	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76236	 1	 8.79	 1.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76237	 1	 7.4	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76238	 1	 18.12	 3.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76239	 1	 7.19	 1.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76240	 1	 3.99	 0.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76241	 1	 11.27	 2.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76242	 1	 7.48	 1.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76243	 1	 6.07	 1.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76244	 1	 4.4	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76245	 1	 7.84	 1.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76246	 1	 7.65	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76247	 1	 14.72	 2.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76248	 1	 10.01	 2.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76249	 1	 14.25	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76250	 1	 10.29	 2.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76251	 1	 8.49	 1.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76252	 1	 74.91	 24.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76253	 1	 15.93	 3.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76254	 1	 18.68	 5.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76255	 1	 11.18	 2.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76256	 1	 80.08	 15.42	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76257	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76258	 1	 32.56	 7.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76259	 1	 27.6	 8.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76260	 1	 26.29	 8.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76261	 1	 5.65	 1.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76262	 1	 22.82	 5.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76263	 1	 23.47	 4.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76264	 1	 14.77	 2.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76265	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76266	 1	 27.11	 8.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76267	 1	 5.4	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76268	 1	 6.93	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76269	 1	 4.74	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76270	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76271	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76272	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76273	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76274	 1	 15.94	 3.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76275	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76276	 1	 17.17	 3.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76277	 1	 5.98	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76278	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76279	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76280	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76281	 1	 159.49	 52.53	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76282	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76283	 1	 13.73	 3.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76284	 1	 55.28	 17.87	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76285	 1	 12.09	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76286	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76287	 1	 12.59	 2.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76288	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76289	 1	 8.66	 2.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76290	 1	 6.23	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76291	 1	 9.85	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76292	 1	 8.03	 2.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76293	 1	 12.58	 3.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76294	 1	 16.2	 3.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76295	 1	 28.51	 4.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76296	 1	 27.47	 4.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76297	 1	 8.03	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76298	 1	 14.04	 3.44	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76299	 1	 3.77	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76300	 1	 13.58	 3.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76301	 1	 8.12	 1.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76302	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76303	 1	 15.4	 3.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76304	 1	 5.53	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76305	 1	 5.27	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76306	 1	 6.06	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76307	 1	 7.63	 1.91	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76308	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76309	 1	 15.12	 2.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76310	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76311	 1	 90.26	 21.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76312	 1	 56.35	 10.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76313	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76314	 1	 7.92	 1.47	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76315	 1	 5.94	 1.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76316	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76317	 1	 21.31	 7.18	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76318	 1	 8.12	 2.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76319	 1	 14.71	 4.57	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76320	 1	 18.35	 3.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76321	 1	 26.3	 4.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76322	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76323	 1	 68.09	 13.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76324	 1	 15.39	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76325	 1	 14.71	 1.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76326	 1	 9.58	 1.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76327	 1	 204.82	 38.55	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76328	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76329	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76330	 1	 10.37	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76331	 1	 12.89	 2.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76332	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76333	 1	 9.69	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76334	 1	 8.71	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76335	 1	 7.13	 2.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76336	 1	 8.22	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76337	 1	 9.46	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76338	 1	 7.32	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76339	 1	 7.61	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76340	 1	 6.25	 1.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76341	 1	 17.92	 3.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76342	 1	 7.16	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76343	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76344	 1	 78.42	 21.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76345	 1	 9.07	 2.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76346	 1	 8.04	 1.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76347	 1	 11.5	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76348	 1	 9.22	 2.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76349	 1	 17.07	 5.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76350	 1	 6.16	 1.14	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76351	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76352	 1	 7.7	 1.57	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76353	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76354	 1	 18.3	 3.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76355	 1	 16.34	 2.98	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76356	 1	 7.27	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76357	 1	 8.66	 2.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76358	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76359	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76360	 1	 37.78	 6.73	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76361	 1	 6.59	 1.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76362	 1	 6.71	 0.79	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76363	 1	 32.97	 7.37	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76364	 1	 7.49	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76365	 1	 7.96	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76366	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76367	 1	 3.94	 0.76	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76368	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76369	 1	 6.66	 1.85	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76370	 1	 11.89	 2.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76371	 1	 7.89	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76372	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76373	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76374	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76375	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76376	 1	 8.26	 2.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76377	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76378	 1	 88.42	 20.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76379	 1	 8.6	 2.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76380	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76381	 1	 20.29	 5.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76382	 1	 8.44	 2.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76383	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76384	 1	 20.01	 4.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76385	 1	 11.64	 3.29	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76386	 1	 9.93	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76387	 1	 5.16	 0.55	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76388	 1	 13.41	 2.16	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76389	 1	 8.34	 1.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76390	 1	 19.89	 5.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76391	 1	 11.63	 3.62	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76392	 1	 16.8	 5.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76393	 1	 5.0	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76394	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76395	 1	 21.4	 4.74	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76396	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76397	 1	 5.37	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76398	 1	 23.22	 5.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76399	 1	 6.12	 1.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76400	 1	 10.82	 2.92	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76401	 1	 0.81	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76402	 1	 13.27	 2.23	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76403	 1	 19.93	 4.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76404	 1	 8.47	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76405	 1	 14.03	 3.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76406	 1	 29.57	 4.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76407	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76408	 1	 4.97	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76409	 1	 6.0	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76410	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76411	 1	 337.44	 113.19	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76412	 1	 6.38	 0.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76413	 1	 4.35	 1.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76414	 1	 10.46	 2.89	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76415	 1	 9.1	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76416	 1	 26.35	 5.36	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76417	 1	 4.92	 1.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76418	 1	 9.64	 2.7	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76419	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76420	 1	 21.14	 3.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76421	 1	 11.89	 2.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76422	 1	 11.23	 1.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76423	 1	 5.87	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76424	 1	 5.78	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76425	 1	 14.88	 2.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76426	 1	 11.03	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76427	 1	 13.24	 2.49	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76428	 1	 10.94	 3.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76429	 1	 10.7	 2.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76430	 1	 7.82	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76431	 1	 5.89	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76432	 1	 8.58	 1.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76433	 1	 6.19	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76434	 1	 8.9	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76435	 1	 14.19	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76436	 1	 7.28	 0.93	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76437	 1	 9.81	 2.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76438	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76439	 1	 20.98	 4.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76440	 1	 9.82	 2.61	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76441	 1	 6.64	 1.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76442	 1	 8.26	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76443	 1	 7.33	 1.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76444	 1	 10.82	 2.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76445	 1	 6.3	 0.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76446	 1	 14.35	 4.05	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76447	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76448	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76449	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76450	 1	 7.97	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76451	 1	 6.68	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76452	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76453	 1	 18.05	 2.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76454	 1	 5.56	 0.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76455	 1	 5.25	 1.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76456	 1	 6.9	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76457	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76458	 1	 14.15	 4.09	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76459	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76460	 1	 53.7	 11.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76461	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76462	 1	 26.32	 6.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76463	 1	 3.04	 0.64	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76464	 1	 5.84	 1.52	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76465	 1	 7.05	 1.58	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76466	 1	 15.87	 2.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76467	 1	 9.82	 2.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76468	 1	 6.91	 0.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76469	 1	 14.77	 4.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76470	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76471	 1	 6.19	 0.84	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76472	 1	 9.5	 1.94	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76473	 1	 21.92	 5.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76474	 1	 38.95	 12.4	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76475	 1	 12.81	 1.62	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76476	 1	 10.58	 2.32	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76477	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76478	 1	 8.24	 1.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76479	 1	 9.87	 2.66	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76480	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76481	 1	 30.16	 4.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76482	 1	 8.06	 1.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76483	 1	 22.23	 4.45	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76484	 1	 15.53	 4.71	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76485	 1	 16.03	 2.69	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76486	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76487	 1	 7.28	 1.75	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76488	 1	 6.2	 1.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76489	 1	 8.65	 1.42	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76490	 1	 87.33	 16.57	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76491	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76492	 1	 13.43	 3.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76493	 1	 24.82	 4.86	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76494	 1	 2.99	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76495	 1	 10.14	 1.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76496	 1	 5.0	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76497	 1	 30.21	 5.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76498	 1	 15.46	 2.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76499	 1	 33.63	 10.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76500	 1	 10.53	 3.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76501	 1	 10.34	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76502	 1	 7.25	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76503	 1	 3.66	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76504	 1	 14.94	 2.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76505	 1	 24.58	 4.65	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76506	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76507	 1	 6.24	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76508	 1	 5.37	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76509	 1	 12.18	 3.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76510	 1	 7.87	 1.99	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76511	 1	 9.65	 2.17	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76512	 1	 8.42	 1.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76513	 1	 8.98	 0.96	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76514	 1	 7.64	 2.13	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76515	 1	 10.55	 1.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76516	 1	 9.22	 2.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76517	 1	 6.84	 1.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76518	 1	 4.79	 0.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76519	 1	 10.99	 3.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76520	 1	 6.03	 0.87	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76521	 1	 7.53	 0.85	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76522	 1	 12.7	 2.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76523	 1	 35.12	 10.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76524	 1	 19.73	 3.6	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76525	 1	 11.33	 2.78	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76526	 1	 5.78	 1.45	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76527	 1	 6.2	 1.35	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76528	 1	 6.06	 1.59	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76529	 1	 13.58	 3.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76530	 1	 7.27	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76531	 1	 17.29	 4.15	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76532	 1	 7.66	 1.88	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76533	 1	 10.24	 2.41	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76534	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76535	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76536	 1	 9.68	 1.08	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76537	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76538	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76539	 1	 126.55	 36.1	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76540	 1	 13.49	 3.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76541	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76542	 1	 20.9	 6.51	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76543	 1	 7.83	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76544	 1	 6.29	 1.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76545	 1	 7.53	 1.27	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76546	 1	 64.35	 20.74	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76547	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76548	 1	 8.23	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76549	 1	 10.58	 1.9	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76550	 1	 23.46	 4.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76551	 1	 9.62	 2.34	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76552	 1	 14.96	 3.22	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76553	 1	 17.28	 2.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76554	 1	 21.45	 4.82	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76555	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76556	 1	 25.92	 6.76	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76557	 1	 5.35	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76558	 1	 5.16	 1.2	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76559	 1	 8.89	 1.5	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76560	 1	 15.38	 3.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76561	 1	 15.61	 4.38	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76562	 1	 20.93	 6.03	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76563	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76564	 1	 7.88	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76565	 1	 10.27	 2.24	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76566	 1	 5.71	 1.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76567	 1	 14.6	 3.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76568	 1	 21.57	 5.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76569	 1	 4.95	 1.19	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76570	 1	 5.35	 0.98	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76571	 1	 10.63	 1.95	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76572	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76573	 1	 17.1	 3.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76574	 1	 12.39	 2.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76575	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76576	 1	 12.03	 2.43	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76577	 1	 30.37	 9.63	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76578	 1	 49.34	 13.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76579	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76580	 1	 28.17	 8.39	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76581	 1	 19.06	 6.06	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76582	 1	 6.57	 1.46	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76583	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76584	 1	 112.2	 19.07	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76585	 1	 12.68	 1.67	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76586	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76587	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76588	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76589	 1	 8.19	 2.28	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76590	 1	 14.86	 3.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76591	 1	 12.33	 3.77	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76592	 1	 20.09	 3.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76593	 1	 17.74	 4.28	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76594	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76595	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76596	 1	 22.3	 5.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76597	 1	 17.47	 4.81	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76598	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76599	 1	 10.54	 1.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76600	 1	 9.69	 2.72	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76601	 1	 13.47	 3.8	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76602	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76603	 1	 11.09	 3.12	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76604	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76605	 1	 15.34	 3.21	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76606	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76607	 1	 32.84	 8.04	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76608	 1	 18.51	 3.25	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76609	 1	 18.67	 5.43	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76610	 1	 16.32	 3.11	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76611	 1	 10.61	 1.87	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76612	 1	 6.51	 0.76	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76613	 1	 16.21	 4.26	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76614	 1	 29.89	 8.12	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76615	 1	 22.09	 4.48	 0.0	 0.0	 10	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76616	 1	 61.92	 23.6	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76617	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76618	 1	 11.0	 1.63	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76619	 1	 12.19	 2.49	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76620	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76621	 1	 118.03	 26.39	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76622	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76623	 1	 14.88	 3.32	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76624	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76625	 1	 199.74	 53.55	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76626	 1	 26.96	 6.8	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76627	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76628	 1	 16.01	 4.11	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76629	 1	 46.88	 8.9	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76630	 1	 5.6	 0.57	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76631	 1	 31.99	 10.25	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76632	 1	 117.65	 24.95	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76633	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76634	 1	 16.89	 3.57	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76635	 1	 76.94	 27.81	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76636	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76637	 1	 18.13	 2.69	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76638	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76639	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76640	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76641	 1	 15.5	 1.94	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76642	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76643	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76644	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76645	 1	 11.7	 1.77	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76646	 1	 14.53	 4.23	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76647	 1	 263.14	 80.66	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76648	 1	 17.66	 4.75	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76649	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76650	 1	 27.22	 6.19	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76651	 1	 37.99	 5.93	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76652	 1	 18.18	 4.04	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76653	 1	 16.77	 3.47	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76654	 1	 6.94	 1.13	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76655	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76656	 1	 8.64	 1.94	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76657	 1	 23.25	 7.84	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76658	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76659	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76660	 1	 22.08	 7.27	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76661	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76662	 1	 25.16	 6.85	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76663	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76664	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76665	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76666	 1	 22.15	 7.08	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76667	 1	 78.08	 17.71	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76668	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76669	 1	 19.14	 6.37	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76670	 1	 31.88	 9.16	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76671	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76672	 1	 138.55	 29.97	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76673	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76674	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76675	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76676	 1	 20.3	 5.59	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76677	 1	 17.72	 3.62	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76678	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76679	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76680	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76681	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76682	 1	 32.21	 6.93	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76683	 1	 21.71	 5.88	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76684	 1	 98.97	 33.35	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76685	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76686	 1	 15.38	 2.95	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76687	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76688	 1	 126.76	 44.59	 0.0	 0.0	 11	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76691	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76693	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76707	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76719	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76725	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76727	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76728	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76731	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76733	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76738	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76739	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76741	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76742	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76743	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76744	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76745	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76746	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76747	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76748	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76749	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76750	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76751	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76752	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76753	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76754	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76755	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76756	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76757	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76758	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76759	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76760	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76761	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76762	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76763	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76764	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76765	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76766	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76767	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76768	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76769	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76770	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76771	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76772	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76773	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76774	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76775	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76776	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76777	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76778	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76779	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76780	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76781	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76782	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76783	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76784	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76785	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76786	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76787	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76788	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76789	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76790	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76791	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76792	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76793	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76794	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76795	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76796	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76797	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76798	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76799	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76800	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76801	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76802	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76803	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76804	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76805	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76806	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76807	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76808	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76809	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76810	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76811	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76812	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76813	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76814	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76815	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76816	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76817	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76818	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76819	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76820	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76821	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76822	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76823	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76824	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76825	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76826	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76827	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76828	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76829	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76830	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76831	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76832	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76833	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76834	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76835	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76836	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76837	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76838	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76839	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76840	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76841	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76842	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76843	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76844	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76845	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76846	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76847	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76848	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76849	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76850	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76851	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76852	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76853	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76854	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76855	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76856	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76857	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76858	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76859	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76860	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76861	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76862	 1	 6.58	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76863	 1	 8.31	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76864	 1	 6.85	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76865	 1	 7.94	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76866	 1	 15.07	 4.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76867	 1	 16.61	 3.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76868	 1	 8.72	 2.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76869	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76870	 1	 14.87	 4.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76871	 1	 5.31	 1.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76872	 1	 8.16	 1.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76873	 1	 8.74	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76874	 1	 9.31	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76875	 1	 11.17	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76876	 1	 11.29	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76877	 1	 4.65	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76878	 1	 13.28	 -3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76879	 1	 27.77	 -3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76880	 1	 13.28	 -3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76881	 1	 3.6	 -3.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76882	 1	 17.19	 3.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76883	 1	 4.8	 0.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76884	 1	 12.04	 2.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76885	 1	 7.28	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76886	 1	 9.4	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76887	 1	 2.18	 0.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76888	 1	 7.85	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76889	 1	 6.86	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76890	 1	 8.35	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76891	 1	 1.92	 0.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76892	 1	 8.93	 2.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76893	 1	 3.69	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76894	 1	 21.24	 5.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76895	 1	 0.89	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76896	 1	 12.76	 3.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76897	 1	 10.45	 2.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76898	 1	 9.22	 2.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76899	 1	 10.37	 2.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76900	 1	 7.24	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76901	 1	 13.72	 3.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76902	 1	 1.93	 0.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76903	 1	 9.93	 1.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76904	 1	 4.26	 0.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76905	 1	 4.77	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76906	 1	 3.77	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76907	 1	 1.68	 0.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76908	 1	 7.71	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76909	 1	 9.75	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76910	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76911	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	76912	 1	 6.49	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76914	 1	 9.03	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76915	 1	 8.48	 2.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76916	 1	 9.07	 1.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76917	 1	 12.94	 4.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76918	 1	 5.69	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76919	 1	 10.88	 2.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76920	 1	 16.3	 3.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76921	 1	 5.81	 0.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76922	 1	 6.57	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76923	 1	 5.91	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76925	 1	 5.32	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76926	 1	 6.68	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76927	 1	 34.41	 9.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76929	 1	 7.77	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76930	 1	 3.68	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76931	 1	 9.22	 1.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76932	 1	 7.48	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76933	 1	 9.03	 2.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76935	 1	 5.16	 1.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76936	 1	 13.4	 3.82	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	76938	 1	 7.38	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76941	 1	 15.19	 4.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76942	 1	 6.28	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76943	 1	 14.6	 4.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76944	 1	 8.93	 1.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76945	 1	 6.74	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76946	 1	 5.27	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76947	 1	 6.46	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76948	 1	 3.01	 0.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76949	 1	 5.21	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76950	 1	 10.43	 2.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76951	 1	 6.95	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76952	 1	 6.97	 0.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76953	 1	 6.38	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76954	 1	 5.64	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76955	 1	 7.9	 1.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76956	 1	 6.42	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76957	 1	 6.74	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76958	 1	 7.12	 1.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76959	 1	 7.46	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76960	 1	 20.13	 5.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76961	 1	 7.13	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	76963	 1	 41.14	 12.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76964	 1	 4.8	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76965	 1	 9.03	 2.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76966	 1	 7.44	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76967	 1	 10.16	 2.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76968	 1	 6.87	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76969	 1	 4.97	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76970	 1	 4.04	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76971	 1	 5.07	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76972	 1	 21.72	 3.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76974	 1	 11.48	 3.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76975	 1	 12.43	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76976	 1	 3.85	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76977	 1	 7.98	 1.26	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76978	 1	 14.67	 2.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76979	 1	 9.79	 3.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76980	 1	 6.29	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76981	 1	 14.35	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76982	 1	 4.46	 0.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76983	 1	 15.23	 1.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76984	 1	 5.35	 1.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76985	 1	 6.72	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76986	 1	 7.98	 1.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76987	 1	 3.66	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76988	 1	 9.81	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76989	 1	 11.05	 2.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76990	 1	 7.56	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76991	 1	 10.08	 2.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76992	 1	 5.39	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76993	 1	 6.91	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76994	 1	 8.03	 2.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76995	 1	 4.17	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76996	 1	 4.66	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76997	 1	 7.24	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76998	 1	 5.08	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	76999	 1	 7.26	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77000	 1	 6.5	 1.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77001	 1	 5.29	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77002	 1	 6.01	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77003	 1	 6.92	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77004	 1	 7.83	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77005	 1	 7.32	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77006	 1	 13.54	 3.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77007	 1	 17.34	 3.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77008	 1	 6.53	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77009	 1	 10.75	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77010	 1	 8.68	 2.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77011	 1	 2.11	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77012	 1	 7.87	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77013	 1	 10.54	 1.75	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77014	 1	 43.76	 13.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77016	 1	 9.6	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77017	 1	 6.0	 1.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77018	 1	 9.14	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77019	 1	 6.54	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77020	 1	 25.63	 3.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77021	 1	 7.54	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77022	 1	 11.22	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77023	 1	 6.95	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77024	 1	 6.65	 1.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77025	 1	 8.51	 0.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77026	 1	 5.53	 1.63	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77027	 1	 9.52	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77028	 1	 19.64	 -3.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77029	 1	 4.26	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77030	 1	 7.31	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77031	 1	 13.01	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77033	 1	 7.13	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77034	 1	 5.73	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77035	 1	 7.86	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77036	 1	 9.55	 1.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77037	 1	 3.05	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77038	 1	 11.73	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77039	 1	 31.61	 9.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77042	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77043	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77045	 1	 9.98	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77046	 1	 3.04	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77047	 1	 4.95	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77048	 1	 11.39	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77049	 1	 3.16	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77050	 1	 4.96	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77052	 1	 20.89	 7.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77053	 1	 24.27	 8.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77054	 1	 12.05	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77055	 1	 10.39	 3.32	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77056	 1	 10.68	 2.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77057	 1	 26.09	 9.11	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77058	 1	 27.26	 4.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77059	 1	 15.13	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77060	 1	 13.47	 -3.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77061	 1	 24.93	 6.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77062	 1	 11.4	 2.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77063	 1	 7.59	 1.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77064	 1	 6.08	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77065	 1	 8.18	 1.55	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77066	 1	 18.87	 2.95	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77067	 1	 5.74	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77069	 1	 4.86	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77070	 1	 8.41	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77071	 1	 9.28	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77072	 1	 10.66	 3.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77073	 1	 6.5	 0.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77074	 1	 6.06	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77075	 1	 6.95	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77076	 1	 49.36	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77080	 1	 51.18	 15.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77083	 1	 9.58	 2.83	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77084	 1	 3.78	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77085	 1	 7.67	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77086	 1	 11.64	 2.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77087	 1	 7.52	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77088	 1	 13.07	 2.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77089	 1	 10.42	 3.16	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77091	 1	 15.16	 3.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77092	 1	 7.82	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77093	 1	 8.2	 2.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77094	 1	 6.85	 0.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77095	 1	 7.76	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77099	 1	 68.53	 22.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77101	 1	 10.11	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77102	 1	 21.21	 4.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77103	 1	 6.54	 1.48	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77104	 1	 4.42	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77105	 1	 9.96	 2.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77106	 1	 9.52	 2.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77107	 1	 13.16	 2.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77108	 1	 11.32	 2.92	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77109	 1	 8.95	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77110	 1	 21.2	 5.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77112	 1	 24.56	 4.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77113	 1	 22.17	 6.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77114	 1	 16.55	 4.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77115	 1	 29.17	 9.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77116	 1	 26.61	 7.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77117	 1	 12.77	 3.08	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77118	 1	 8.45	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77119	 1	 7.82	 0.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77120	 1	 9.07	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77121	 1	 6.45	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77122	 1	 10.43	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77123	 1	 10.72	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77124	 1	 5.35	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77125	 1	 8.37	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77126	 1	 8.01	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77127	 1	 7.45	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77128	 1	 11.46	 2.24	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77129	 1	 6.75	 1.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77130	 1	 7.57	 1.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77131	 1	 11.15	 2.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77132	 1	 20.47	 6.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77133	 1	 9.19	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77134	 1	 7.33	 1.66	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77136	 1	 8.7	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77137	 1	 5.6	 0.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77138	 1	 7.13	 1.78	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77139	 1	 4.08	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77140	 1	 4.6	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77141	 1	 11.89	 2.42	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77142	 1	 9.83	 2.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77143	 1	 9.16	 1.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77144	 1	 11.89	 1.96	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77145	 1	 9.32	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77146	 1	 5.12	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77147	 1	 4.99	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77148	 1	 9.86	 1.98	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77149	 1	 17.83	 3.14	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77150	 1	 8.36	 1.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77152	 1	 8.04	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77154	 1	 16.29	 3.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77155	 1	 7.56	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77156	 1	 11.17	 2.97	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77157	 1	 10.09	 1.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77158	 1	 19.79	 7.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77159	 1	 64.88	 22.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77160	 1	 23.7	 4.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77162	 1	 11.16	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77163	 1	 5.68	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77164	 1	 4.0	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77165	 1	 2.34	 0.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77166	 1	 6.05	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77167	 1	 11.69	 2.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77168	 1	 5.18	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77170	 1	 8.91	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77171	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77172	 1	 10.7	 3.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77174	 1	 5.73	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77175	 1	 21.9	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77176	 1	 8.04	 1.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77177	 1	 7.96	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77178	 1	 14.93	 2.86	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77182	 1	 33.86	 10.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77183	 1	 9.07	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77184	 1	 3.79	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77185	 1	 9.16	 2.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77186	 1	 39.78	 12.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77187	 1	 8.09	 1.77	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77188	 1	 11.52	 2.38	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77189	 1	 5.9	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77190	 1	 8.84	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77191	 1	 2.34	 0.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77192	 1	 7.67	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77193	 1	 6.71	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77194	 1	 7.22	 2.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77195	 1	 4.43	 0.99	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77196	 1	 23.98	 7.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77197	 1	 38.82	 13.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77198	 1	 26.03	 9.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77199	 1	 16.14	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77200	 1	 16.78	 2.69	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77201	 1	 13.48	 2.28	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77202	 1	 9.18	 2.53	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77203	 1	 13.79	 2.25	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77204	 1	 7.69	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77205	 1	 21.23	 4.17	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77206	 1	 11.56	 2.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77207	 1	 6.01	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77208	 1	 15.13	 4.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77209	 1	 8.71	 1.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77210	 1	 7.22	 -0.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77211	 1	 10.94	 2.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77212	 1	 15.72	 4.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77214	 1	 18.2	 5.57	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77215	 1	 5.87	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77216	 1	 7.52	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77217	 1	 4.32	 0.47	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77218	 1	 17.8	 2.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77219	 1	 12.1	 3.84	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77220	 1	 9.97	 1.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77221	 1	 8.91	 1.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77223	 1	 47.08	 12.6	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77225	 1	 8.4	 1.71	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77226	 1	 15.01	 3.94	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77227	 1	 2.28	 0.39	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77228	 1	 5.82	 1.23	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77229	 1	 8.22	 1.46	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77230	 1	 4.91	 0.85	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77231	 1	 3.22	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77232	 1	 2.74	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77233	 1	 8.77	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77234	 1	 2.86	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77235	 1	 5.8	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77236	 1	 5.71	 1.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77241	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77243	 1	 16.29	 4.05	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77244	 1	 5.4	 1.45	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77245	 1	 14.11	 3.12	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77246	 1	 10.54	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77247	 1	 6.25	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77248	 1	 12.76	 3.18	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77249	 1	 10.47	 2.37	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77250	 1	 6.08	 1.29	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77251	 1	 9.75	 1.27	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77252	 1	 15.94	 2.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77253	 1	 3.72	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77254	 1	 4.8	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77256	 1	 10.52	 3.01	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77257	 1	 8.86	 1.43	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77258	 1	 22.53	 6.13	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77259	 1	 6.78	 1.33	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77260	 1	 17.86	 5.89	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77261	 1	 21.45	 4.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77262	 1	 13.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77263	 1	 8.92	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77264	 1	 24.96	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77265	 1	 9.86	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77266	 1	 12.81	 2.15	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77267	 1	 4.6	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77268	 1	 6.13	 1.49	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77269	 1	 8.17	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77270	 1	 4.45	 1.04	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77271	 1	 11.63	 2.07	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77272	 1	 10.16	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77273	 1	 6.6	 -3.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77274	 1	 5.69	 -3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77275	 1	 6.94	 -3.87	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77276	 1	 21.49	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77277	 1	 16.37	 5.06	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77278	 1	 7.29	 1.67	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77279	 1	 4.01	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77280	 1	 1.64	 0.34	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77281	 1	 3.57	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77282	 1	 5.92	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77283	 1	 10.41	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77285	 1	 13.31	 3.74	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77286	 1	 4.49	 0.81	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77287	 1	 12.0	 1.91	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77288	 1	 26.25	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77289	 1	 7.6	 0.88	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77290	 1	 13.18	 3.59	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77291	 1	 9.67	 1.76	 0.0	 0.0	 1	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77292	 1	 81.84	 32.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77293	 1	 17.31	 4.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77294	 1	 22.09	 5.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77295	 1	 35.67	 10.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77296	 1	 67.98	 17.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77297	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77298	 1	 8.64	 1.31	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77299	 1	 7.33	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77300	 1	 7.37	 2.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77301	 1	 23.53	 4.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77302	 1	 28.97	 6.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77303	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77304	 1	 2.08	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77305	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77306	 1	 31.05	 8.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77307	 1	 3.09	 0.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77308	 1	 1.27	 0.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77309	 1	 3.32	 0.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77310	 1	 6.79	 1.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77311	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77312	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77313	 1	 185.97	 38.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77314	 1	 9.98	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77315	 1	 14.45	 3.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77316	 1	 4.11	 1.11	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77317	 1	 4.04	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77318	 1	 19.03	 3.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77319	 1	 10.64	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77320	 1	 2.82	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77321	 1	 25.05	 3.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77322	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77323	 1	 6.33	 1.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77324	 1	 9.83	 2.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77325	 1	 13.73	 3.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77326	 1	 111.68	 28.88	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77327	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77328	 1	 69.42	 10.91	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77329	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77330	 1	 12.03	 2.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77331	 1	 71.51	 19.94	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77332	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77333	 1	 8.15	 1.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77334	 1	 12.7	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77335	 1	 16.52	 4.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77336	 1	 4.48	 1.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77337	 1	 12.12	 2.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77338	 1	 31.89	 3.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77339	 1	 20.99	 3.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77340	 1	 10.36	 2.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77341	 1	 19.1	 4.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77342	 1	 3.72	 1.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77343	 1	 8.12	 1.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77344	 1	 6.16	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77345	 1	 36.21	 4.7	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77346	 1	 19.16	 5.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77347	 1	 7.76	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77348	 1	 11.59	 1.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77349	 1	 16.04	 3.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77350	 1	 6.53	 0.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77351	 1	 5.66	 1.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77352	 1	 16.47	 4.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77353	 1	 10.21	 1.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77354	 1	 12.45	 2.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77355	 1	 8.68	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77356	 1	 10.59	 2.21	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77357	 1	 7.4	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77358	 1	 3.12	 0.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77359	 1	 7.87	 2.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77360	 1	 7.39	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77361	 1	 7.25	 0.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77362	 1	 3.83	 0.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77363	 1	 11.53	 2.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77364	 1	 5.29	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77365	 1	 6.13	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77366	 1	 7.15	 2.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77367	 1	 6.72	 1.19	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77368	 1	 6.76	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77369	 1	 11.82	 3.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77370	 1	 6.46	 1.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77371	 1	 14.57	 3.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77372	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77373	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77374	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77375	 1	 3.38	 0.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77376	 1	 5.2	 0.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77377	 1	 28.42	 3.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77378	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77379	 1	 15.07	 3.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77380	 1	 7.05	 2.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77381	 1	 4.64	 1.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77382	 1	 10.23	 1.96	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77383	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77384	 1	 6.21	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77385	 1	 11.07	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77386	 1	 11.83	 3.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77387	 1	 6.26	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77388	 1	 10.3	 2.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77389	 1	 9.68	 2.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77390	 1	 25.86	 5.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77391	 1	 3.73	 0.73	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77392	 1	 12.45	 2.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77393	 1	 7.22	 1.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77394	 1	 8.25	 1.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77395	 1	 10.29	 2.74	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77396	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77397	 1	 13.59	 4.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77398	 1	 28.53	 3.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77399	 1	 5.11	 0.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77400	 1	 12.84	 3.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77401	 1	 5.03	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77402	 1	 6.15	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77403	 1	 5.97	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77404	 1	 5.36	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77405	 1	 9.68	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77406	 1	 14.42	 3.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77407	 1	 10.27	 2.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77408	 1	 7.33	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77409	 1	 5.26	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77410	 1	 16.63	 4.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77411	 1	 22.88	 5.67	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77412	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77413	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77414	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77415	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77416	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77417	 1	 5.71	 1.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77418	 1	 4.58	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77419	 1	 4.24	 0.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77420	 1	 8.64	 1.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77421	 1	 5.87	 1.26	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77422	 1	 5.1	 1.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77423	 1	 89.83	 17.07	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77424	 1	 5.31	 1.53	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77425	 1	 6.44	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77426	 1	 7.44	 1.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77427	 1	 17.15	 4.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77428	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77429	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77430	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77431	 1	 50.35	 15.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77432	 1	 15.03	 2.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77433	 1	 9.84	 1.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77434	 1	 4.77	 -0.2	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77435	 1	 5.14	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77436	 1	 6.63	 1.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77437	 1	 37.85	 5.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77438	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77439	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77440	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77441	 1	 17.02	 2.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77442	 1	 4.88	 1.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77443	 1	 6.5	 1.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77444	 1	 5.98	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77445	 1	 8.29	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77446	 1	 23.52	 6.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77447	 1	 4.43	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77448	 1	 7.01	 2.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77449	 1	 8.03	 2.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77450	 1	 8.8	 1.15	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77451	 1	 6.45	 1.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77452	 1	 5.78	 1.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77453	 1	 25.48	 5.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77454	 1	 8.27	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77455	 1	 0.62	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77456	 1	 9.74	 2.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77457	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77458	 1	 16.95	 3.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77459	 1	 3.92	 1.17	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77460	 1	 12.21	 3.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77461	 1	 5.92	 1.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77462	 1	 5.98	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77463	 1	 3.7	 0.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77464	 1	 5.95	 0.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77465	 1	 5.37	 1.05	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77466	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77467	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77468	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77469	 1	 5.1	 1.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77470	 1	 8.65	 2.14	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77471	 1	 12.73	 3.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77472	 1	 10.63	 3.1	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77473	 1	 26.05	 7.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77474	 1	 17.86	 3.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77475	 1	 11.04	 3.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77476	 1	 6.84	 1.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77477	 1	 23.38	 4.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77478	 1	 13.8	 3.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77479	 1	 13.41	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77480	 1	 17.77	 2.41	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77481	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77482	 1	 33.28	 8.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77483	 1	 16.63	 4.6	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77484	 1	 9.23	 2.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77485	 1	 10.67	 1.3	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77486	 1	 13.86	 4.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77487	 1	 9.04	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77488	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77489	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77490	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77491	 1	 29.73	 6.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77492	 1	 4.27	 0.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77493	 1	 12.45	 2.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77494	 1	 7.6	 1.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77495	 1	 9.39	 2.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77496	 1	 9.83	 2.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77497	 1	 9.48	 2.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77498	 1	 28.42	 4.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77499	 1	 4.64	 0.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77500	 1	 11.81	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77501	 1	 6.52	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77502	 1	 10.06	 2.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77503	 1	 16.31	 3.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77504	 1	 6.18	 1.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77505	 1	 9.63	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77506	 1	 13.51	 3.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77507	 1	 16.4	 4.55	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77508	 1	 13.52	 3.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77509	 1	 5.88	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77510	 1	 14.59	 3.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77511	 1	 4.58	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77512	 1	 6.46	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77513	 1	 16.58	 4.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77514	 1	 8.36	 1.88	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77515	 1	 32.45	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77516	 1	 6.27	 1.01	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77517	 1	 8.76	 2.37	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77518	 1	 8.04	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77519	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77520	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77521	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77522	 1	 3.96	 0.56	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77523	 1	 6.35	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77524	 1	 11.24	 3.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77525	 1	 10.88	 3.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77526	 1	 8.13	 1.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77527	 1	 22.54	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77528	 1	 9.44	 2.24	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77529	 1	 11.99	 2.89	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77530	 1	 17.1	 4.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77531	 1	 10.52	 1.28	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77532	 1	 48.5	 9.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77533	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77534	 1	 30.9	 9.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77535	 1	 10.27	 2.79	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77536	 1	 2.74	 0.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77537	 1	 31.37	 5.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77538	 1	 13.83	 3.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77539	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77540	 1	 5.44	 0.65	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77541	 1	 11.34	 3.34	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77542	 1	 19.8	 4.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77543	 1	 11.47	 2.62	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77544	 1	 4.84	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77545	 1	 10.39	 2.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77546	 1	 30.71	 8.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77547	 1	 11.15	 1.58	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77548	 1	 3.56	 0.86	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77549	 1	 7.05	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77550	 1	 25.76	 5.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77551	 1	 4.54	 0.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77552	 1	 4.46	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77553	 1	 7.71	 1.85	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77554	 1	 3.19	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77555	 1	 9.27	 2.18	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77556	 1	 6.1	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77557	 1	 27.95	 6.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77558	 1	 16.9	 -1.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77559	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77560	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77561	 1	 5.39	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77562	 1	 9.39	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77563	 1	 4.07	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77564	 1	 6.87	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77565	 1	 7.12	 1.61	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77566	 1	 125.53	 23.02	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77567	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77568	 1	 3.01	 0.54	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77569	 1	 3.46	 0.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77570	 1	 6.94	 1.77	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77571	 1	 6.85	 1.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77572	 1	 26.57	 5.97	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77573	 1	 33.43	 7.02	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77574	 1	 25.57	 3.35	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77575	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77576	 1	 41.37	 10.95	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77577	 1	 16.63	 4.51	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77578	 1	 3.04	 0.69	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77579	 1	 3.83	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77580	 1	 16.34	 4.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77581	 1	 3.93	 1.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77582	 1	 20.18	 4.83	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77583	 1	 16.11	 3.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77584	 1	 11.16	 2.68	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77585	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77586	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77587	 1	 6.94	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77588	 1	 8.47	 1.81	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77589	 1	 18.43	 4.57	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77590	 1	 11.57	 3.47	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77591	 1	 5.6	 1.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77592	 1	 29.61	 4.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77593	 1	 10.91	 3.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77594	 1	 5.52	 0.92	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77595	 1	 15.77	 3.04	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77596	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77597	 1	 22.97	 4.78	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77598	 1	 10.79	 1.91	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77599	 1	 5.37	 0.76	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77600	 1	 7.21	 1.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77601	 1	 3.89	 0.94	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77602	 1	 11.6	 2.4	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77603	 1	 34.59	 7.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77604	 1	 6.1	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77605	 1	 8.3	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77606	 1	 9.11	 1.59	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77607	 1	 4.42	 1.03	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77608	 1	 20.61	 6.29	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77609	 1	 21.82	 3.22	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77610	 1	 20.63	 6.42	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77611	 1	 21.98	 3.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77612	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77613	 1	 11.89	 2.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77614	 1	 18.32	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77615	 1	 34.51	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77616	 1	 1.9	 0.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77617	 1	 5.17	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77618	 1	 28.25	 4.13	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77619	 1	 7.64	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77620	 1	 7.17	 1.39	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77621	 1	 8.06	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77622	 1	 3.66	 0.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77623	 1	 5.25	 1.5	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77624	 1	 5.82	 1.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77625	 1	 19.38	 4.84	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77626	 1	 8.57	 2.16	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77627	 1	 26.67	 6.44	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77628	 1	 13.46	 4.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77629	 1	 11.91	 1.8	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77630	 1	 13.4	 2.27	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77631	 1	 1.95	 0.43	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77632	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77633	 1	 25.64	 6.46	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77634	 1	 14.74	 4.41	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77635	 1	 35.16	 10.06	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77636	 1	 6.23	 1.72	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77637	 1	 5.67	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77638	 1	 5.64	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77639	 1	 13.64	 4.07	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77640	 1	 11.64	 3.25	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77641	 1	 3.18	 0.75	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77642	 1	 4.5	 0.9	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77643	 1	 1.31	 0.36	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77644	 1	 6.66	 1.23	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77645	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77646	 1	 15.86	 2.66	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77647	 1	 15.75	 4.09	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77648	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77649	 1	 33.56	 8.12	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77650	 1	 2.12	 0.32	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77651	 1	 7.4	 1.93	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77652	 1	 12.8	 3.82	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77653	 1	 19.88	 3.98	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77654	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77655	 1	 25.44	 6.07	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77656	 1	 19.36	 6.83	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77657	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77659	 1	 62.77	 11.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77660	 1	 8.31	 1.87	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77661	 1	 12.51	 3.73	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77662	 1	 2.82	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77663	 1	 5.38	 2.18	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77664	 1	 4.55	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77665	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77666	 1	 18.87	 7.26	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77667	 1	 6.46	 1.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77668	 1	 6.72	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77669	 1	 4.85	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77670	 1	 3.68	 1.15	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77671	 1	 3.88	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77672	 1	 2.33	 0.49	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77673	 1	 19.51	 3.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77674	 1	 4.97	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77675	 1	 5.49	 1.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77676	 1	 2.31	 0.71	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77677	 1	 2.7	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77678	 1	 3.03	 1.09	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77679	 1	 4.48	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77680	 1	 4.42	 1.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77681	 1	 6.08	 1.16	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77682	 1	 4.03	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77683	 1	 3.59	 0.99	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77684	 1	 3.05	 0.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77685	 1	 3.45	 1.37	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77686	 1	 3.8	 0.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77687	 1	 6.88	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77688	 1	 3.51	 1.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77689	 1	 19.54	 3.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77690	 1	 4.61	 1.65	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77691	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77692	 1	 35.27	 13.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77693	 1	 4.95	 1.9	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77694	 1	 3.3	 1.2	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77695	 1	 1.68	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77696	 1	 4.28	 1.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77697	 1	 1.55	 0.43	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77698	 1	 4.14	 1.14	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77699	 1	 4.89	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77700	 1	 5.94	 1.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77701	 1	 3.14	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77702	 1	 8.24	 3.24	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77703	 1	 5.68	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77704	 1	 3.96	 1.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77705	 1	 4.43	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77706	 1	 7.83	 2.33	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77707	 1	 63.08	 23.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77708	 1	 28.52	 7.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77709	 1	 7.03	 2.39	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77710	 1	 8.26	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77711	 1	 7.21	 1.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77712	 1	 6.12	 2.34	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77713	 1	 4.81	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77714	 1	 4.91	 1.3	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77715	 1	 4.57	 1.82	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77716	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77717	 1	 12.13	 4.52	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77718	 1	 4.45	 1.7	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77719	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77720	 1	 8.52	 3.05	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77721	 1	 211.33	 46.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77722	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77723	 1	 10.03	 2.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77724	 1	 3.89	 1.59	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77725	 1	 4.61	 1.01	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77726	 1	 2.81	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77727	 1	 1.83	 0.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77728	 1	 1.64	 0.55	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77729	 1	 4.9	 1.91	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77730	 1	 3.2	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77731	 1	 4.0	 0.78	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77732	 1	 5.36	 2.08	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77733	 1	 6.4	 2.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77734	 1	 14.88	 5.28	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77735	 1	 5.78	 2.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77736	 1	 2.95	 0.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77737	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77738	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77739	 1	 8.38	 2.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77740	 1	 1.2	 0.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77741	 1	 3.8	 1.38	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77742	 1	 6.55	 2.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77743	 1	 3.92	 1.27	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77744	 1	 5.83	 1.41	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77745	 1	 3.13	 0.61	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77746	 1	 6.7	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77747	 1	 3.34	 0.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77748	 1	 2.68	 0.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77749	 1	 11.07	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77750	 1	 4.63	 1.48	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77751	 1	 2.54	 0.58	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77752	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77753	 1	 10.66	 2.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77754	 1	 5.93	 1.54	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77755	 1	 5.13	 1.31	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77756	 1	 3.05	 0.84	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77757	 1	 4.8	 1.8	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77758	 1	 3.26	 0.81	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77759	 1	 5.86	 1.94	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77760	 1	 6.6	 1.57	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77761	 1	 4.2	 0.96	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77762	 1	 2.23	 0.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77763	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77764	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77765	 1	 20.34	 3.25	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77766	 1	 5.38	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77767	 1	 10.56	 1.92	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77768	 1	 23.92	 8.17	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77769	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77770	 1	 18.79	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77771	 1	 20.74	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77772	 1	 15.28	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77773	 1	 8.8	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77774	 1	 4.96	 1.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77775	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77776	 1	 61.77	 21.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77777	 1	 12.68	 4.06	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77778	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77779	 1	 10.41	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77780	 1	 193.15	 76.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77781	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77782	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77783	 1	 98.17	 30.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77784	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77785	 1	 24.53	 8.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77786	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77787	 1	 165.61	 68.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77788	 1	 27.49	 10.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77789	 1	 19.42	 5.95	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77790	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77791	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77792	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77793	 1	 22.75	 5.68	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77794	 1	 11.96	 3.85	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77795	 1	 4.49	 1.75	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77796	 1	 3.25	 0.69	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77797	 1	 3.09	 0.98	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77798	 1	 12.02	 3.21	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77799	 1	 5.01	 1.45	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77800	 1	 5.58	 1.86	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77801	 1	 13.9	 4.03	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77802	 1	 9.56	 3.64	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77803	 1	 14.03	 3.11	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77804	 1	 24.61	 8.66	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77805	 1	 10.04	 2.53	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77806	 1	 184.37	 54.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77807	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77808	 1	 5.45	 1.63	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77809	 1	 6.14	 2.35	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77810	 1	 3.49	 0.77	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77811	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77812	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77813	 1	 1.73	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77814	 1	 18.85	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77815	 1	 21.46	 3.4	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77816	 1	 21.66	 8.5	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77817	 1	 92.98	 16.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77818	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77819	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77820	 1	 83.31	 27.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77821	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77822	 1	 4.26	 0.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77823	 1	 4.0	 0.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77824	 1	 10.22	 2.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77825	 1	 9.28	 2.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77826	 1	 13.1	 3.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77827	 1	 8.96	 2.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77828	 1	 15.74	 3.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77829	 1	 14.67	 2.4	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77830	 1	 10.61	 1.32	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77831	 1	 20.32	 5.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77832	 1	 6.27	 1.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77833	 1	 11.63	 2.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77834	 1	 11.28	 1.89	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77835	 1	 7.39	 1.65	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77836	 1	 48.17	 14.44	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77837	 1	 28.54	 5.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77838	 1	 13.9	 3.28	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77839	 1	 9.19	 2.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77840	 1	 17.96	 4.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77841	 1	 34.47	 4.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77842	 1	 28.02	 7.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77843	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77844	 1	 36.22	 9.5	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77845	 1	 15.71	 2.74	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77846	 1	 8.58	 2.16	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77847	 1	 7.89	 1.75	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77848	 1	 14.88	 3.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77849	 1	 193.88	 60.96	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77850	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77851	 1	 26.82	 3.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77852	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77853	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77854	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77855	 1	 7.88	 1.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77856	 1	 5.48	 0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77857	 1	 5.92	 1.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77858	 1	 7.41	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77859	 1	 8.99	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77860	 1	 10.34	 1.6	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77861	 1	 4.59	 0.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77862	 1	 8.18	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77863	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77864	 1	 8.5	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77865	 1	 8.84	 1.85	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77866	 1	 6.68	 1.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77867	 1	 18.71	 3.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77868	 1	 17.97	 5.17	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77869	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77870	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77871	 1	 21.13	 5.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77872	 1	 3.39	 0.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77873	 1	 11.71	 1.86	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77874	 1	 9.35	 1.19	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77875	 1	 8.92	 2.12	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77876	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77877	 1	 20.53	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77878	 1	 17.18	 3.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77879	 1	 7.53	 1.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77880	 1	 26.33	 7.84	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77881	 1	 7.22	 1.51	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77882	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77883	 1	 33.58	 9.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77884	 1	 7.43	 1.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77885	 1	 14.25	 3.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77886	 1	 4.73	 0.98	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77887	 1	 20.95	 6.06	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77888	 1	 14.92	 2.25	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77889	 1	 8.21	 1.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77890	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77891	 1	 3.79	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77892	 1	 8.99	 1.63	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77893	 1	 32.6	 7.07	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77894	 1	 14.21	 3.83	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77895	 1	 147.39	 42.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77896	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77897	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77898	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77899	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77900	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77901	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77902	 1	 2.6	 0.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77903	 1	 29.16	 7.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77904	 1	 31.2	 5.14	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77905	 1	 30.22	 7.42	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77906	 1	 6.99	 1.3	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77907	 1	 4.17	 0.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77908	 1	 7.12	 1.72	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77909	 1	 10.63	 1.41	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77910	 1	 17.76	 4.57	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77911	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77912	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77913	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77914	 1	 13.9	 3.7	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77915	 1	 7.36	 0.9	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77916	 1	 1.7	 0.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77917	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77918	 1	 16.1	 4.54	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77919	 1	 9.07	 1.67	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77920	 1	 3.57	 0.45	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77921	 1	 17.68	 5.09	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77922	 1	 9.11	 1.96	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77923	 1	 15.13	 2.78	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77924	 1	 15.7	 2.22	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77925	 1	 7.03	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77926	 1	 13.44	 3.53	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77927	 1	 9.8	 2.43	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77928	 1	 14.22	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77929	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77930	 1	 11.3	 1.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77931	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77932	 1	 6.12	 1.03	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77933	 1	 6.0	 1.11	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77934	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77935	 1	 7.16	 0.93	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77936	 1	 11.18	 1.49	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77937	 1	 13.35	 2.05	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77938	 1	 4.29	 0.69	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77939	 1	 3.48	 0.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77940	 1	 3.0	 0.35	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77941	 1	 6.02	 0.94	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77942	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77943	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77944	 1	 143.55	 42.06	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77945	 1	 2.45	 0.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77946	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	77947	 1	 11.12	 1.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77948	 1	 14.83	 2.88	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77949	 1	 6.72	 1.18	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77950	 1	 34.03	 7.8	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77951	 1	 3.99	 0.62	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77952	 1	 9.17	 2.36	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77953	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77954	 1	 8.81	 1.97	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77955	 1	 18.14	 5.48	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77956	 1	 7.76	 1.24	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77957	 1	 2.86	 0.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77958	 1	 6.96	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77959	 1	 7.42	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77960	 1	 14.99	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77961	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77962	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77963	 1	 3.01	 0.55	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77964	 1	 4.86	 1.39	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77965	 1	 10.03	 1.76	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77966	 1	 16.24	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77967	 1	 9.83	 1.15	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77968	 1	 11.72	 1.34	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77969	 1	 8.27	 1.73	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77970	 1	 9.09	 2.23	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77971	 1	 5.51	 1.08	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77972	 1	 12.88	 3.31	 0.0	 0.0	 7	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77973	 1	 12.49	 2.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77974	 1	 7.55	 1.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77975	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77976	 1	 30.63	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77977	 1	 29.47	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77978	 1	 9.87	 1.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77979	 1	 4.65	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77980	 1	 18.01	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77981	 1	 50.66	 14.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77982	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77983	 1	 10.34	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77984	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77985	 1	 14.94	 1.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77986	 1	 6.97	 2.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77987	 1	 5.09	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77988	 1	 1.99	 0.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77989	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77990	 1	 7.82	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77991	 1	 6.43	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77992	 1	 21.21	 4.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77993	 1	 4.51	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77994	 1	 3.23	 0.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77995	 1	 10.57	 1.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77996	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77997	 1	 255.97	 60.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77998	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	77999	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78000	 1	 7.5	 0.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78001	 1	 19.75	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78002	 1	 9.8	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78003	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78004	 1	 18.37	 5.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78005	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78006	 1	 33.12	 9.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78007	 1	 14.89	 3.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78008	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78009	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78010	 1	 8.62	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78011	 1	 6.62	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78012	 1	 7.5	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78013	 1	 5.46	 1.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78014	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78015	 1	 21.97	 3.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78016	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78017	 1	 9.44	 2.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78018	 1	 4.84	 0.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78019	 1	 3.89	 0.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78020	 1	 9.58	 1.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78021	 1	 5.83	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78022	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78023	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78024	 1	 8.25	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78025	 1	 5.77	 1.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78026	 1	 4.59	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78027	 1	 24.95	 4.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78028	 1	 13.57	 3.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78029	 1	 21.62	 3.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78030	 1	 4.63	 1.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78031	 1	 5.7	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78032	 1	 2.53	 0.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78033	 1	 2.91	 0.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78034	 1	 5.26	 0.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78035	 1	 5.14	 1.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78036	 1	 5.41	 1.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78037	 1	 6.56	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78038	 1	 14.09	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78039	 1	 8.2	 2.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78040	 1	 5.99	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78041	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78042	 1	 18.9	 5.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78043	 1	 4.22	 1.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78044	 1	 7.12	 0.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78045	 1	 11.69	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78046	 1	 10.68	 2.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78047	 1	 16.66	 4.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78048	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78049	 1	 6.15	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78050	 1	 3.93	 0.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78051	 1	 4.09	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78052	 1	 4.67	 0.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78053	 1	 5.94	 0.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78054	 1	 10.04	 1.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78055	 1	 18.7	 4.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78056	 1	 2.47	 0.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78057	 1	 4.69	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78058	 1	 23.26	 6.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78059	 1	 6.48	 1.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78060	 1	 7.68	 2.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78061	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78062	 1	 60.45	 12.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78063	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78064	 1	 18.54	 5.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78065	 1	 374.53	 75.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78066	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78067	 1	 8.49	 2.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78068	 1	 15.94	 4.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78069	 1	 7.05	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78070	 1	 4.61	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78071	 1	 10.11	 2.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78072	 1	 11.99	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78073	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78074	 1	 11.42	 3.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78075	 1	 3.79	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78076	 1	 5.07	 0.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78077	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	78078	 1	 205.42	 28.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78079	 1	 14.33	 2.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78080	 1	 128.19	 26.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78081	 1	 7.8	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78082	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78083	 1	 1.99	 0.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78084	 1	 8.53	 1.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78085	 1	 16.71	 3.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78086	 1	 6.46	 1.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78087	 1	 4.9	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78088	 1	 7.28	 1.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78089	 1	 2.8	 0.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78090	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78091	 1	 40.65	 7.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78092	 1	 3.98	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78093	 1	 2.89	 0.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78094	 1	 2.72	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78095	 1	 12.4	 1.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78096	 1	 3.66	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78097	 1	 6.43	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78098	 1	 7.4	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78099	 1	 5.76	 1.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78100	 1	 4.97	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78101	 1	 10.37	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78102	 1	 4.07	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78103	 1	 91.39	 21.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78104	 1	 5.61	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78105	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78106	 1	 23.59	 3.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78107	 1	 55.91	 13.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78108	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78109	 1	 18.79	 3.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78110	 1	 5.47	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78111	 1	 3.12	 0.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78112	 1	 4.15	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78113	 1	 6.96	 1.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78114	 1	 4.76	 1.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78115	 1	 6.72	 1.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78116	 1	 6.89	 2.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78117	 1	 14.45	 1.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78118	 1	 6.23	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78119	 1	 7.91	 2.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78120	 1	 7.49	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78121	 1	 17.56	 3.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78122	 1	 7.29	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78123	 1	 4.13	 1.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78124	 1	 3.5	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78125	 1	 2.43	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78126	 1	 14.33	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78127	 1	 8.61	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78128	 1	 0.79	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78129	 1	 4.67	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78130	 1	 23.62	 4.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78131	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78132	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78133	 1	 28.36	 5.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78134	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78135	 1	 5.6	 1.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78136	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78137	 1	 8.21	 1.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78138	 1	 23.12	 4.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78139	 1	 24.49	 3.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78140	 1	 19.49	 4.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78141	 1	 15.71	 3.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78142	 1	 2.77	 0.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78143	 1	 2.38	 0.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78144	 1	 88.57	 18.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78145	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78146	 1	 43.74	 9.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78147	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78148	 1	 3.47	 0.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78149	 1	 12.55	 2.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78150	 1	 5.77	 1.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78151	 1	 11.34	 2.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78152	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78153	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78154	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78155	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78156	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78157	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78158	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78159	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78160	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78161	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78162	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78163	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78164	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78165	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78166	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78167	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78168	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78169	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78170	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78171	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78172	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78173	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78174	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78175	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78176	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78177	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78178	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78179	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78180	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78181	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78182	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78183	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78184	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78185	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78186	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78187	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78188	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78189	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78190	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78191	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78192	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78193	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78194	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78195	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78196	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78197	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78198	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78199	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78200	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78201	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78202	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78203	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78204	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78205	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78206	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78207	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78208	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78209	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78210	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78211	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78212	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78213	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78214	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78215	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78216	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78217	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78218	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78219	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78220	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78221	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78222	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78223	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78224	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78225	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78226	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78227	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78228	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78229	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78230	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78231	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78232	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78233	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78234	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78235	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78236	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78237	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78238	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78239	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78240	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78241	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78242	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78243	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78244	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78245	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78246	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78247	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78248	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78249	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78250	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78251	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78252	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78253	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78254	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78255	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78256	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78257	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78258	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78259	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78260	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78261	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78262	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78263	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78264	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78265	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78266	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78267	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78268	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78269	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78270	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78271	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78272	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78273	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78274	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78275	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78276	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78277	 2	 0.0	 -99.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78278	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78279	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78280	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78281	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78282	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78283	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78284	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78285	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78286	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78287	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78288	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78289	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78290	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78291	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78292	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78293	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78294	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78295	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78296	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78297	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78298	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78299	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78300	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78301	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78302	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78303	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78304	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78305	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78306	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78307	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78308	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78309	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78310	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78311	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78312	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78313	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78314	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78315	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78316	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78317	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78318	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78319	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78320	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78321	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78322	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78323	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78324	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78325	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78326	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78327	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78328	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78329	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78330	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78331	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78332	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78333	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78334	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78335	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78336	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78337	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78338	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78339	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78340	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78341	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78342	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78343	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78344	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78345	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78346	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78347	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78348	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78349	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78350	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78351	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78352	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78353	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78354	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78355	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78356	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78357	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78358	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78359	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78360	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78361	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78362	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78363	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78364	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78366	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78367	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78368	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78369	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78370	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78371	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78372	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78373	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78374	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78375	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78376	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78377	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78378	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78379	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78380	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78381	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78382	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78383	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78384	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78385	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78386	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78387	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78388	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78389	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78390	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78391	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78392	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78393	 1	 3.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78394	 1	 1.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78395	 1	 1.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78396	 1	 17.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78397	 1	 21.44	 -27.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78398	 1	 14.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78399	 1	 3.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78400	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78401	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78402	 1	 6.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78403	 1	 8.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78404	 1	 2.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78405	 1	 3.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78406	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78407	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78408	 1	 33.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78409	 1	 10.66	 -1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78410	 1	 12.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78411	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78412	 1	 2.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78413	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78414	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78415	 1	 12.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78416	 1	 4.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78417	 1	 6.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78418	 1	 5.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78419	 1	 13.87	 -12.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78420	 1	 7.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78421	 1	 7.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78422	 1	 63.4	 79.83	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78423	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78424	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78425	 1	 2.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78426	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78427	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78428	 1	 38.76	 39.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78429	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78430	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78431	 1	 25.6	 34.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78432	 1	 4.41	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78433	 1	 6.1	 5.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78434	 1	 9.51	 4.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78435	 1	 4.91	 3.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78436	 1	 4.88	 3.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78437	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78438	 1	 123.29	 126.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78439	 1	 3.96	 2.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78440	 1	 1.97	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78441	 1	 6.35	 4.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78442	 1	 14.28	 9.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78443	 1	 8.84	 4.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78444	 1	 5.43	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78445	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78446	 1	 8.07	 6.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78447	 1	 5.08	 3.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78448	 1	 5.47	 2.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78449	 1	 4.99	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78450	 1	 2.24	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78451	 1	 3.53	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78452	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78453	 1	 2.36	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78454	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78455	 1	 2.87	 1.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78456	 1	 10.37	 6.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78457	 1	 9.56	 8.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78458	 1	 21.67	 21.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78459	 1	 16.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78460	 1	 16.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78461	 1	 13.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78462	 1	 9.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78463	 1	 13.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78464	 1	 7.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78465	 1	 4.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78466	 1	 9.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78467	 1	 10.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78468	 1	 2.51	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78469	 1	 11.32	 -12.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78470	 1	 21.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78471	 1	 13.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78472	 1	 7.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78473	 1	 6.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78474	 1	 5.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78475	 1	 11.22	 10.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78476	 1	 8.14	 6.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78477	 1	 11.47	 6.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78478	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78479	 1	 9.88	 9.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78480	 1	 3.58	 2.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78481	 1	 4.89	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78482	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78483	 1	 9.89	 5.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78484	 1	 3.8	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78485	 1	 3.29	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78486	 1	 9.38	 6.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78487	 1	 4.37	 2.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78488	 1	 8.62	 6.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78489	 1	 10.33	 9.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78490	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78491	 1	 68.75	 43.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78492	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78493	 1	 10.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78494	 1	 14.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78495	 1	 12.29	 6.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78496	 1	 7.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78497	 1	 5.22	 3.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78498	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78499	 1	 37.73	 21.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78500	 1	 15.42	 12.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78501	 1	 9.64	 7.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78502	 1	 7.03	 2.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78503	 1	 29.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78504	 1	 16.64	 8.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78505	 1	 5.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78506	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78507	 1	 3.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78508	 1	 10.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78509	 1	 7.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78510	 1	 4.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78511	 1	 8.18	 4.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78512	 1	 8.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78513	 1	 120.18	 65.96	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78514	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78515	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78516	 1	 9.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78517	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78518	 1	 1.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78519	 1	 7.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78520	 1	 6.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78521	 1	 7.42	 5.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78522	 1	 7.02	 2.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78523	 1	 2.92	 -15.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78524	 1	 5.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78525	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78526	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78527	 1	 5.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78528	 1	 7.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78529	 1	 11.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78530	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78531	 1	 22.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78532	 1	 12.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78533	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78534	 1	 21.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78535	 1	 15.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78536	 1	 11.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78537	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78538	 1	 7.79	 6.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78539	 1	 1.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78540	 1	 5.65	 4.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78541	 1	 4.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78542	 1	 4.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78543	 1	 3.49	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78544	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78545	 1	 8.79	 8.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78546	 1	 7.8	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78547	 1	 6.94	 5.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78548	 1	 13.01	 8.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78549	 1	 11.39	 11.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78550	 1	 14.12	 10.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78551	 1	 16.14	 -1.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78552	 1	 13.93	 12.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78553	 1	 10.05	 10.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78554	 1	 12.0	 6.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78555	 1	 13.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78556	 1	 4.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78557	 1	 13.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78558	 1	 4.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78559	 1	 8.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78560	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78561	 1	 7.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78562	 1	 22.43	 15.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78563	 1	 11.61	 8.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78564	 1	 3.0	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78565	 1	 2.6	 1.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78566	 1	 4.24	 1.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78567	 1	 82.84	 41.67	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78568	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78569	 1	 3.35	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78570	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78571	 1	 25.66	 18.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78572	 1	 5.34	 3.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78573	 1	 13.51	 5.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78574	 1	 10.26	 7.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78575	 1	 6.23	 3.35	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78576	 1	 4.01	 2.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78577	 1	 4.97	 3.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78578	 1	 13.64	 10.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78579	 1	 7.45	 4.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78580	 1	 12.29	 7.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78581	 1	 6.42	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78582	 1	 22.92	 10.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78583	 1	 9.99	 5.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78584	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78585	 1	 9.41	 3.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78586	 1	 6.29	 5.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78587	 1	 5.01	 3.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78588	 1	 5.66	 3.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78589	 1	 20.0	 11.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78590	 1	 7.61	 4.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78591	 1	 13.89	 20.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78592	 1	 6.53	 5.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78593	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78594	 1	 6.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78595	 1	 25.24	 14.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78596	 1	 11.54	 16.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78597	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78598	 1	 20.07	 17.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78599	 1	 10.12	 8.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78600	 1	 16.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78601	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78602	 1	 14.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78603	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78604	 1	 5.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78605	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78606	 1	 3.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78607	 1	 23.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78608	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78609	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78610	 1	 6.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78611	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78612	 1	 1.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78613	 1	 3.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78614	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78615	 1	 9.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78616	 1	 5.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78617	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78618	 1	 2.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78619	 1	 3.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78620	 1	 13.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78621	 1	 2.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78622	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78623	 1	 21.13	 31.45	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78624	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78625	 1	 8.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78626	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78627	 1	 11.81	 15.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78628	 1	 3.24	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78629	 1	 5.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78630	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78631	 1	 25.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78632	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78633	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78634	 1	 8.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78635	 1	 1.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78636	 1	 6.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78637	 1	 3.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78638	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78639	 1	 0.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78640	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78641	 1	 1.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78642	 1	 3.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78643	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78644	 1	 4.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78645	 1	 1.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78646	 1	 11.04	 -2.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78647	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78648	 1	 17.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78649	 1	 3.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78650	 1	 5.28	 -4.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78651	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78652	 1	 17.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78653	 1	 3.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78654	 1	 3.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78655	 1	 5.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78656	 1	 6.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78657	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78658	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78659	 1	 5.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78660	 1	 2.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78661	 1	 5.57	 4.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78662	 1	 3.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78663	 1	 3.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78664	 1	 5.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78665	 1	 10.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78666	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78667	 1	 4.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78668	 1	 6.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78669	 1	 2.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78670	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78671	 1	 5.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78672	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78673	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78674	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78675	 1	 3.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78676	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78677	 1	 3.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78678	 1	 5.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78679	 1	 6.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78680	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78681	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78682	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78683	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78684	 1	 15.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78685	 1	 1.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78686	 1	 3.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78687	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78688	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78689	 1	 4.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78690	 1	 3.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78691	 1	 10.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78692	 1	 3.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78693	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78694	 1	 2.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78695	 1	 30.45	 26.43	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78696	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78697	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78698	 1	 14.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78699	 1	 12.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78700	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78701	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78702	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78703	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78704	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78705	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78706	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78707	 1	 2.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78708	 1	 1.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78709	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78710	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78711	 1	 3.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78712	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78713	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78714	 1	 3.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78715	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78716	 1	 2.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78717	 1	 1.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78718	 1	 2.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78719	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78720	 1	 2.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78721	 1	 4.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78722	 1	 7.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78723	 1	 1.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78724	 1	 1.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78725	 1	 3.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78726	 1	 2.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78727	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78728	 1	 9.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78729	 1	 4.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78730	 1	 13.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78731	 1	 6.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78732	 1	 6.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78733	 1	 2.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78734	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78735	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78736	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78737	 1	 2.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78738	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78739	 1	 4.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78740	 1	 3.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78741	 1	 4.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78742	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78743	 1	 1.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78744	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78745	 1	 2.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78746	 1	 5.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78747	 1	 2.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78748	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78749	 1	 2.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78750	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78751	 1	 2.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78752	 1	 2.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78753	 1	 11.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78754	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78755	 1	 2.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78756	 1	 3.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78757	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78758	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78759	 1	 2.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78760	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78761	 1	 1.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78762	 1	 2.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78763	 1	 3.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78764	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78765	 1	 5.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78766	 1	 2.24	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78767	 1	 1.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78768	 1	 1.76	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78769	 1	 3.66	 2.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78770	 1	 2.03	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78771	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78772	 1	 4.28	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78773	 1	 1.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78774	 1	 3.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78775	 1	 4.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78776	 1	 2.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78777	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78778	 1	 8.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78779	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78780	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78781	 1	 3.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78782	 1	 1.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78783	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78784	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78785	 1	 2.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78786	 1	 2.1	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78787	 1	 1.61	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78788	 1	 4.57	 3.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78789	 1	 2.65	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78790	 1	 3.23	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78791	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78792	 1	 6.66	 6.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78793	 1	 2.77	 2.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78794	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78795	 1	 2.43	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78796	 1	 3.64	 3.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78797	 1	 1.94	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78798	 1	 7.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78799	 1	 24.0	 28.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78800	 1	 7.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78801	 1	 13.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78802	 1	 2.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78803	 1	 5.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78804	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78805	 1	 4.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78806	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78807	 1	 14.68	 -8.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78808	 1	 6.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78809	 1	 18.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78810	 1	 3.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78811	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78812	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78813	 1	 10.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78814	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78815	 1	 16.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78816	 1	 4.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78817	 1	 5.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78818	 1	 7.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78819	 1	 7.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78820	 1	 18.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78821	 1	 9.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78822	 1	 11.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78823	 1	 3.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78824	 1	 3.64	 1.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78825	 1	 1.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78826	 1	 3.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78827	 1	 19.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78828	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78829	 1	 27.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78830	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78831	 1	 3.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78832	 1	 11.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78833	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78834	 1	 17.66	 15.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78835	 1	 5.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78836	 1	 4.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78837	 1	 3.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78838	 1	 22.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78839	 1	 2.88	 2.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78840	 1	 2.67	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78841	 1	 68.42	 59.23	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78842	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78843	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78844	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78845	 1	 6.22	 6.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78846	 1	 11.04	 6.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78847	 1	 4.71	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78848	 1	 2.93	 2.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78849	 1	 2.46	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78850	 1	 2.86	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78851	 1	 3.22	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78852	 1	 3.84	 2.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78853	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78854	 1	 3.81	 1.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78855	 1	 2.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78856	 1	 2.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78857	 1	 11.98	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78858	 1	 10.31	 5.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78859	 1	 2.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78860	 1	 8.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78861	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78862	 1	 10.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78863	 1	 24.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78864	 1	 9.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78865	 1	 6.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78866	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78867	 1	 4.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78868	 1	 3.37	 -7.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78869	 1	 4.48	 3.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78870	 1	 2.68	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78871	 1	 5.31	 3.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78872	 1	 8.4	 5.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78873	 1	 5.9	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78874	 1	 3.58	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78875	 1	 10.23	 8.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78876	 1	 12.13	 9.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78877	 1	 18.67	 16.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78878	 1	 6.26	 5.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78879	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78880	 1	 38.11	 33.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78881	 1	 3.8	 2.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78882	 1	 30.52	 28.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78883	 1	 3.39	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78884	 1	 2.92	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78885	 1	 8.4	 6.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78886	 1	 5.08	 3.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78887	 1	 7.38	 3.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78888	 1	 3.87	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78889	 1	 1.51	 0.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78890	 1	 6.44	 2.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78891	 1	 3.8	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78892	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78893	 1	 47.65	 53.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78894	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78895	 1	 11.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78896	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78897	 1	 19.49	 10.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78898	 1	 19.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78899	 1	 67.68	 61.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78900	 1	 42.14	 61.71	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78901	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78902	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78903	 1	 116.31	 94.66	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	78904	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78905	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78906	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78907	 1	 13.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78908	 1	 7.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78909	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78910	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78911	 1	 5.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78912	 1	 2.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78913	 1	 1.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78914	 1	 6.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78915	 1	 3.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78916	 1	 5.34	 3.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78917	 1	 3.39	 2.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78918	 1	 6.43	 4.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78919	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78920	 1	 3.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78921	 1	 5.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78922	 1	 2.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78923	 1	 2.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78924	 1	 7.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78925	 1	 2.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78926	 1	 4.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78927	 1	 3.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78928	 1	 5.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78929	 1	 5.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78930	 1	 2.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78931	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78932	 1	 24.47	 26.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78933	 1	 3.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78934	 1	 8.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78935	 1	 19.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78936	 1	 6.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78937	 1	 4.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78938	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78939	 1	 5.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78940	 1	 6.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78941	 1	 14.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78942	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78943	 1	 4.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78944	 1	 3.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78945	 1	 6.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78946	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78947	 1	 3.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78948	 1	 12.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78949	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78950	 1	 46.78	 50.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78951	 1	 12.83	 9.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78952	 1	 13.87	 12.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78953	 1	 6.2	 4.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78954	 1	 5.58	 3.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78955	 1	 9.17	 7.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78956	 1	 13.2	 14.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78957	 1	 3.98	 2.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78958	 1	 3.57	 2.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78959	 1	 7.96	 6.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78960	 1	 2.89	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78961	 1	 3.71	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78962	 1	 12.29	 9.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78963	 1	 6.15	 3.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78964	 1	 4.46	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78965	 1	 7.14	 3.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78966	 1	 14.42	 9.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78967	 1	 4.65	 3.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78968	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78969	 1	 7.54	 4.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78970	 1	 3.93	 2.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78971	 1	 3.45	 2.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78972	 1	 10.5	 11.1	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78973	 1	 2.59	 1.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78974	 1	 12.37	 14.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78975	 1	 3.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78976	 1	 14.2	 23.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78977	 1	 7.85	 6.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78978	 1	 2.45	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78979	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78980	 1	 1.25	 0.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78981	 1	 3.53	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78982	 1	 4.59	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78983	 1	 2.76	 1.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78984	 1	 2.82	 1.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78985	 1	 9.43	 7.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78986	 1	 2.19	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78987	 1	 1.88	 0.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78988	 1	 6.05	 7.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78989	 1	 3.68	 2.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78990	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78991	 1	 15.53	 10.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78992	 1	 6.46	 5.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78993	 1	 3.33	 2.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78994	 1	 5.36	 4.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78995	 1	 4.81	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78996	 1	 2.15	 1.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78997	 1	 3.24	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78998	 1	 2.91	 2.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	78999	 1	 5.19	 4.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79000	 1	 2.85	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79001	 1	 2.93	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79002	 1	 4.73	 3.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79003	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79004	 1	 3.54	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79005	 1	 6.26	 2.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79006	 1	 7.58	 4.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79007	 1	 4.81	 3.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79008	 1	 5.55	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79009	 1	 10.95	 4.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79010	 1	 4.72	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79011	 1	 17.18	 15.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79012	 1	 24.41	 17.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79013	 1	 6.14	 4.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79014	 1	 1.62	 1.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79015	 1	 4.8	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79016	 1	 6.38	 4.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79017	 1	 5.34	 4.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79018	 1	 0.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79019	 1	 4.34	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79020	 1	 4.87	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79021	 1	 3.46	 2.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79022	 1	 6.08	 5.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79023	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79024	 1	 11.02	 11.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79025	 1	 4.65	 2.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79026	 1	 4.18	 1.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79027	 1	 2.96	 1.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79028	 1	 3.84	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79029	 1	 4.82	 3.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79030	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79031	 1	 9.54	 4.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79032	 1	 3.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79033	 1	 3.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79034	 1	 2.52	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79035	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79036	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79037	 1	 1.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79038	 1	 6.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79039	 1	 12.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79040	 1	 4.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79041	 1	 5.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79042	 1	 2.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79043	 1	 7.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79044	 1	 7.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79045	 1	 23.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79046	 1	 2.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79047	 1	 4.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79048	 1	 7.06	 4.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79049	 1	 3.33	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79050	 1	 5.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79051	 1	 8.19	 6.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79052	 1	 7.03	 3.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79053	 1	 2.13	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79054	 1	 3.06	 1.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79055	 1	 2.27	 1.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79056	 1	 10.98	 10.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79057	 1	 8.01	 5.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79058	 1	 2.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79059	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79060	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79061	 1	 3.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79062	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79063	 1	 7.85	 7.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79064	 1	 3.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79065	 1	 4.19	 2.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79066	 1	 2.12	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79067	 1	 3.8	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79068	 1	 3.44	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79069	 1	 6.4	 2.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79070	 1	 4.0	 3.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79071	 1	 4.94	 3.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79072	 1	 9.39	 10.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79073	 1	 6.16	 5.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79074	 1	 4.09	 2.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79075	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79076	 1	 10.57	 6.76	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79077	 1	 10.47	 3.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79078	 1	 2.19	 1.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79079	 1	 2.5	 1.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79080	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79081	 1	 6.28	 2.4	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79082	 1	 4.94	 3.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79083	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79084	 1	 37.21	 45.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79085	 1	 3.5	 1.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79086	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79087	 1	 49.23	 43.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79088	 1	 9.23	 8.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79089	 1	 6.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79090	 1	 10.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79091	 1	 4.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79092	 1	 3.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79093	 1	 3.97	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79094	 1	 12.39	 9.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79095	 1	 9.89	 7.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79096	 1	 9.62	 7.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79097	 1	 4.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79098	 1	 9.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79099	 1	 4.81	 2.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79100	 1	 5.51	 3.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79101	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79102	 1	 4.5	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79103	 1	 6.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79104	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79105	 1	 7.0	 3.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79106	 1	 3.41	 2.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79107	 1	 8.13	 6.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79108	 1	 7.78	 4.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79109	 1	 2.59	 2.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79110	 1	 4.47	 3.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79111	 1	 6.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79112	 1	 7.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79113	 1	 3.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79114	 1	 6.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79115	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79116	 1	 22.22	 17.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79117	 1	 5.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79118	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79119	 1	 3.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79120	 1	 17.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79121	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79122	 1	 3.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79123	 1	 0.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79124	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79125	 1	 6.52	 3.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79126	 1	 3.72	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79127	 1	 31.73	 39.91	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79128	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79129	 1	 7.13	 3.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79130	 1	 11.62	 9.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79131	 1	 10.05	 10.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79132	 1	 4.85	 2.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79133	 1	 5.73	 3.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79134	 1	 6.15	 4.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79135	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79136	 1	 81.64	 80.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79137	 1	 13.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79138	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79139	 1	 30.67	 33.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79140	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79141	 1	 17.74	 15.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79142	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79143	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79144	 1	 35.7	 31.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79145	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79146	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79147	 1	 10.76	 4.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79148	 1	 25.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79149	 1	 14.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79150	 1	 19.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79151	 1	 10.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79152	 1	 10.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79153	 1	 4.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79154	 1	 12.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79155	 1	 9.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79156	 1	 15.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79157	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79158	 1	 35.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79159	 1	 9.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79160	 1	 10.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79161	 1	 3.52	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79162	 1	 9.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79163	 1	 9.7	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79164	 1	 5.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79165	 1	 9.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79166	 1	 8.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79167	 1	 6.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79168	 1	 5.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79169	 1	 7.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79170	 1	 11.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79171	 1	 6.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79172	 1	 14.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79173	 1	 8.84	 6.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79174	 1	 5.27	 -19.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79175	 1	 10.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79176	 1	 2.35	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79177	 1	 7.65	 4.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79178	 1	 4.06	 2.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79179	 1	 6.05	 3.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79180	 1	 8.63	 5.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79181	 1	 8.95	 9.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79182	 1	 5.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79183	 1	 7.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79184	 1	 5.46	 2.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79185	 1	 5.67	 2.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79186	 1	 17.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79187	 1	 7.82	 4.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79188	 1	 29.25	 26.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79189	 1	 6.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79190	 1	 14.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79191	 1	 2.18	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79192	 1	 2.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79193	 1	 4.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79194	 1	 16.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79195	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79196	 1	 3.7	 2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79197	 1	 6.61	 4.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79198	 1	 4.38	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79199	 1	 2.71	 0.93	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79200	 1	 9.06	 7.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79201	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79202	 1	 8.1	 10.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79203	 1	 2.38	 1.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79204	 1	 3.55	 2.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79205	 1	 4.05	 1.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79206	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79207	 1	 36.28	 24.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79208	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79209	 1	 7.42	 3.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79210	 1	 2.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79211	 1	 2.23	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79212	 1	 2.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79213	 1	 6.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79214	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79215	 1	 11.83	 4.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79216	 1	 4.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79217	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79218	 1	 4.6	 3.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79219	 1	 6.07	 3.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79220	 1	 11.59	 6.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79221	 1	 6.69	 2.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79222	 1	 9.92	 7.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79223	 1	 3.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79224	 1	 9.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79225	 1	 11.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79226	 1	 8.06	 8.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79227	 1	 17.75	 10.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79228	 1	 21.92	 27.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79229	 1	 3.5	 1.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79230	 1	 5.13	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79231	 1	 6.91	 4.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79232	 1	 4.04	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79233	 1	 3.32	 2.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79234	 1	 4.18	 1.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79235	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79236	 1	 8.92	 10.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79237	 1	 5.38	 5.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79238	 1	 3.22	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79239	 1	 5.18	 3.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79240	 1	 4.51	 1.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79241	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79242	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79243	 1	 23.96	 32.96	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79244	 1	 12.32	 6.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79245	 1	 5.28	 2.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79246	 1	 25.55	 26.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79247	 1	 4.05	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79248	 1	 7.45	 7.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79249	 1	 5.9	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79250	 1	 5.04	 3.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79251	 1	 8.35	 5.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79252	 1	 6.38	 4.13	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79253	 1	 4.9	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79254	 1	 67.08	 50.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79255	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79256	 1	 4.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79257	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79258	 1	 40.56	 49.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79259	 1	 4.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79260	 1	 5.23	 3.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79261	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79262	 1	 9.06	 6.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79263	 1	 11.39	 7.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79264	 1	 2.77	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79265	 1	 9.8	 6.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79266	 1	 6.56	 2.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79267	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79268	 1	 16.75	 18.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79269	 1	 3.01	 1.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79270	 1	 3.33	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79271	 1	 3.79	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79272	 1	 12.89	 13.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79273	 1	 7.07	 5.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79274	 1	 3.82	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79275	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79276	 1	 3.89	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79277	 1	 2.55	 1.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79278	 1	 2.28	 1.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79279	 1	 3.01	 1.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79280	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79281	 1	 8.34	 7.34	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79282	 1	 3.01	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79283	 1	 4.04	 2.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79284	 1	 24.07	 16.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79285	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79286	 1	 8.66	 7.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79287	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79288	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79289	 1	 17.46	 15.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79290	 1	 3.93	 2.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79291	 1	 6.7	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79292	 1	 6.59	 2.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79293	 1	 2.93	 1.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79294	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79295	 1	 2.94	 2.12	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79296	 1	 3.49	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79297	 1	 8.42	 7.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79298	 1	 3.3	 1.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79299	 1	 4.7	 2.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79300	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79301	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79302	 1	 7.71	 7.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79303	 1	 5.85	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79304	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79305	 1	 4.22	 2.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79306	 1	 6.37	 4.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79307	 1	 2.71	 1.44	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79308	 1	 14.59	 14.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79309	 1	 6.84	 5.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79310	 1	 3.34	 3.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79311	 1	 8.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79312	 1	 6.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79313	 1	 17.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79314	 1	 3.89	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79315	 1	 2.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79316	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79317	 1	 17.31	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79318	 1	 16.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79319	 1	 12.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79320	 1	 3.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79321	 1	 10.08	 7.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79322	 1	 5.03	 3.66	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79323	 1	 7.38	 9.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79324	 1	 4.61	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79325	 1	 4.25	 3.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79326	 1	 13.3	 5.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79327	 1	 18.4	 9.29	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79328	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79329	 1	 5.79	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79330	 1	 15.86	 13.87	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79331	 1	 2.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79332	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79333	 1	 18.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79334	 1	 9.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79335	 1	 7.82	 5.22	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79336	 1	 14.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79337	 1	 19.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79338	 1	 11.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79339	 1	 6.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79340	 1	 5.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79341	 1	 1.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79342	 1	 3.73	 -24.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79343	 1	 6.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79344	 1	 6.92	 3.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79345	 1	 4.89	 3.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79346	 1	 22.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79347	 1	 8.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79348	 1	 7.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79349	 1	 20.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79350	 1	 8.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79351	 1	 10.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79352	 1	 6.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79353	 1	 7.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79354	 1	 5.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79355	 1	 4.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79356	 1	 3.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79357	 1	 3.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79358	 1	 5.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79359	 1	 3.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79360	 1	 7.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79361	 1	 6.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79362	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79363	 1	 27.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79364	 1	 7.66	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79365	 1	 9.36	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79366	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79367	 1	 8.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79368	 1	 1.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79369	 1	 3.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79370	 1	 1.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79371	 1	 3.27	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79372	 1	 5.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79373	 1	 4.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79374	 1	 6.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79375	 1	 3.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79376	 1	 6.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79377	 1	 3.44	 1.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79378	 1	 5.92	 3.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79379	 1	 8.86	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79380	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79381	 1	 4.81	 3.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79382	 1	 5.31	 3.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79383	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79384	 1	 18.54	 20.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79385	 1	 23.36	 28.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79386	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79387	 1	 9.68	 7.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79388	 1	 4.46	 2.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79389	 1	 7.56	 3.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79390	 1	 4.55	 2.16	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79391	 1	 10.71	 14.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79392	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79393	 1	 28.38	 29.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79394	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79395	 1	 46.01	 39.64	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79396	 1	 15.09	 21.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79397	 1	 6.99	 3.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79398	 1	 4.4	 1.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79399	 1	 27.08	 18.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79400	 1	 14.19	 12.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79401	 1	 9.2	 10.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79402	 1	 9.89	 6.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79403	 1	 66.21	 44.51	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79404	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79405	 1	 14.97	 9.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79406	 1	 6.76	 4.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79407	 1	 5.72	 4.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79408	 1	 6.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79409	 1	 12.61	 6.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79410	 1	 5.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79411	 1	 4.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79412	 1	 5.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79413	 1	 6.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79414	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79415	 1	 11.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79416	 1	 19.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79417	 1	 8.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79418	 1	 18.39	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79419	 1	 14.07	 8.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79420	 1	 4.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79421	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79422	 1	 63.4	 46.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79423	 1	 12.3	 7.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79424	 1	 8.05	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79425	 1	 2.27	 1.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79426	 1	 3.52	 1.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79427	 1	 3.21	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79428	 1	 5.24	 3.32	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79429	 1	 5.95	 1.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79430	 1	 1.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79431	 1	 37.89	 20.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79432	 1	 12.84	 6.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79433	 1	 5.89	 3.36	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79434	 1	 4.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79435	 1	 8.84	 6.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79436	 1	 6.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79437	 1	 30.11	 14.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79438	 1	 6.88	 4.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79439	 1	 5.62	 2.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79440	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79441	 1	 55.2	 49.48	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79442	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79443	 1	 9.41	 5.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79444	 1	 8.31	 4.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79445	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79446	 1	 4.94	 2.08	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79447	 1	 87.31	 44.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79448	 1	 13.31	 9.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79449	 1	 3.5	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79450	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79451	 1	 28.49	 16.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79452	 1	 7.04	 3.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79453	 1	 17.92	 9.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79454	 1	 28.35	 29.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79455	 1	 2.94	 1.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79456	 1	 20.83	 10.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79457	 1	 3.18	 1.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79458	 1	 20.77	 13.78	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79459	 1	 7.82	 5.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79460	 1	 3.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79461	 1	 18.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79462	 1	 6.67	 4.14	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79463	 1	 42.03	 26.53	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79464	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79465	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79466	 1	 7.44	 4.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79467	 1	 4.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79468	 1	 22.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79469	 1	 6.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79470	 1	 5.62	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79471	 1	 2.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79472	 1	 5.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79473	 1	 4.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79474	 1	 6.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79475	 1	 5.33	 4.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79476	 1	 6.48	 4.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79477	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79478	 1	 13.14	 10.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79479	 1	 7.68	 6.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79480	 1	 8.34	 6.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79481	 1	 9.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79482	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79483	 1	 13.1	 6.2	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79484	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79485	 1	 48.55	 21.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79486	 1	 9.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79487	 1	 19.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79488	 1	 13.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79489	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79490	 1	 3.65	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79491	 1	 3.76	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79492	 1	 8.95	 5.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79493	 1	 10.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79494	 1	 21.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79495	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79496	 1	 22.38	 11.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79497	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79498	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79499	 1	 24.0	 27.33	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79500	 1	 8.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79501	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79502	 1	 23.67	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79503	 1	 10.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79504	 1	 5.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79505	 1	 5.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79506	 1	 15.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79507	 1	 9.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79508	 1	 4.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79509	 1	 8.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79510	 1	 4.77	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79511	 1	 4.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79512	 1	 3.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79513	 1	 5.91	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79514	 1	 7.92	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79515	 1	 7.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79516	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79517	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79518	 1	 19.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79519	 1	 6.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79520	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79521	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79522	 1	 35.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79523	 1	 21.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79524	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79525	 1	 58.61	 30.89	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79526	 1	 9.23	 7.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79527	 1	 18.24	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79528	 1	 7.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79529	 1	 7.69	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79530	 1	 2.56	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79531	 1	 9.27	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79532	 1	 20.57	 28.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79533	 1	 3.13	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79534	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79535	 1	 23.05	 15.82	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79536	 1	 11.58	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79537	 1	 13.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79538	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79539	 1	 59.81	 57.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79540	 1	 7.1	 4.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79541	 1	 3.28	 2.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79542	 1	 21.26	 17.71	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79543	 1	 6.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79544	 1	 7.95	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79545	 1	 3.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79546	 1	 12.76	 7.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79547	 1	 14.76	 10.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79548	 1	 8.52	 6.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79549	 1	 8.36	 5.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79550	 1	 12.02	 9.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79551	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79552	 1	 12.65	 15.75	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79553	 1	 9.22	 3.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79554	 1	 9.13	 5.94	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79555	 1	 7.34	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79556	 1	 10.21	 4.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79557	 1	 4.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79558	 1	 7.64	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79559	 1	 13.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79560	 1	 18.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79561	 1	 11.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79562	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79563	 1	 78.64	 31.9	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79564	 1	 4.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79565	 1	 8.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79566	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79567	 1	 20.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79568	 1	 4.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79569	 1	 10.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79570	 1	 5.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79571	 1	 7.54	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79572	 1	 11.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79573	 1	 3.37	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79574	 1	 3.08	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79575	 1	 4.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79576	 1	 8.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79577	 1	 4.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79578	 1	 6.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79579	 1	 6.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79580	 1	 2.83	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79581	 1	 1.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79582	 1	 21.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79583	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79584	 1	 32.47	 35.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79585	 1	 4.92	 5.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79586	 1	 8.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79587	 1	 19.87	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79588	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79589	 1	 13.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79590	 1	 5.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79591	 1	 16.71	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79592	 1	 16.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79593	 1	 4.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79594	 1	 6.4	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79595	 1	 8.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79596	 1	 27.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79597	 1	 5.07	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79598	 1	 4.77	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79599	 1	 5.51	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79600	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79601	 1	 8.95	 5.06	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79602	 1	 4.25	 1.5	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79603	 1	 11.66	 8.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79604	 1	 9.32	 4.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79605	 1	 6.22	 3.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79606	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79607	 1	 7.14	 5.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79608	 1	 2.39	 2.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79609	 1	 10.73	 8.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79610	 1	 5.4	 2.68	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79611	 1	 4.8	 2.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79612	 1	 4.76	 3.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79613	 1	 5.69	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79614	 1	 5.67	 4.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79615	 1	 18.6	 6.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79616	 1	 6.54	 2.67	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79617	 1	 100.04	 43.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79618	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79619	 1	 10.52	 8.03	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79620	 1	 2.23	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79621	 1	 19.91	 9.6	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79622	 1	 2.67	 1.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79623	 1	 8.22	 6.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79624	 1	 13.92	 8.46	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79625	 1	 6.16	 4.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79626	 1	 18.25	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79627	 1	 6.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79628	 1	 23.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79629	 1	 7.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79630	 1	 4.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79631	 1	 2.89	 1.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79632	 1	 2.21	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79633	 1	 4.4	 2.63	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79634	 1	 8.48	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79635	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79636	 1	 32.6	 16.21	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79637	 1	 4.2	 1.54	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79638	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79639	 1	 10.36	 3.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79640	 1	 24.23	 17.1	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79641	 1	 25.28	 11.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79642	 1	 10.7	 8.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79643	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79644	 1	 39.01	 52.61	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79645	 1	 15.71	 15.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79646	 1	 124.08	 91.56	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79647	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79648	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79649	 1	 6.34	 3.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79650	 1	 9.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79651	 1	 3.01	 1.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79652	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79653	 1	 6.55	 4.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79654	 1	 3.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79655	 1	 14.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79656	 1	 1.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79657	 1	 1.35	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79658	 1	 3.45	 2.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79659	 1	 9.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79660	 1	 7.41	 5.77	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79661	 1	 10.91	 4.47	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79662	 1	 3.04	 2.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79663	 1	 8.79	 5.99	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79664	 1	 8.03	 5.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79665	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79666	 1	 52.58	 70.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79667	 1	 14.24	 15.83	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79668	 1	 11.78	 9.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79669	 1	 8.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79670	 1	 5.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79671	 1	 3.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79672	 1	 1.79	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79673	 1	 13.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79674	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79675	 1	 6.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79676	 1	 5.26	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79677	 1	 6.41	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79678	 1	 6.15	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79679	 1	 5.51	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79680	 1	 5.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79681	 1	 11.55	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79682	 1	 9.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79683	 1	 3.96	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79684	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79685	 1	 8.95	 10.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79686	 1	 2.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79687	 1	 4.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79688	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79689	 1	 15.99	 10.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79690	 1	 2.22	 1.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79691	 1	 1.99	 1.52	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79692	 1	 6.63	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79693	 1	 5.04	 4.09	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79694	 1	 8.85	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79695	 1	 8.47	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79696	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79697	 1	 21.81	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79698	 1	 12.56	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79699	 1	 11.09	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79700	 1	 4.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79701	 1	 13.12	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79702	 1	 9.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79703	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79704	 1	 17.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79705	 1	 1.61	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79706	 1	 5.38	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79707	 1	 3.35	 2.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79708	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79709	 1	 8.72	 4.7	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79710	 1	 7.38	 3.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79711	 1	 5.13	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79712	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79713	 1	 11.98	 8.58	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79714	 1	 4.63	 1.91	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79715	 1	 5.05	 2.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79716	 1	 5.11	 3.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79717	 1	 1.91	 0.86	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79718	 1	 4.05	 3.37	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79719	 1	 6.0	 7.07	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79720	 1	 6.97	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79721	 1	 9.95	 10.74	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79722	 1	 5.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79723	 1	 2.78	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79724	 1	 4.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79725	 1	 16.22	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79726	 1	 2.94	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79727	 1	 3.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79728	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79729	 1	 2.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79730	 1	 2.49	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79731	 1	 3.02	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79732	 1	 24.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79733	 1	 4.45	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79734	 1	 7.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79735	 1	 14.44	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79736	 1	 2.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79737	 1	 8.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79738	 1	 5.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79739	 1	 11.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79740	 1	 18.43	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79741	 1	 23.63	 14.41	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79742	 1	 7.74	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79743	 1	 8.5	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79744	 1	 14.8	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79745	 1	 19.9	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79746	 1	 10.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79747	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79748	 1	 31.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79749	 1	 25.3	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79750	 1	 16.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79751	 1	 4.72	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79752	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79753	 1	 28.42	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79754	 1	 7.11	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79755	 1	 8.75	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79756	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79757	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79758	 1	 30.03	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79759	 1	 12.2	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79760	 1	 16.17	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79761	 1	 21.6	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79762	 1	 6.24	 4.78	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79763	 1	 3.16	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79764	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79765	 1	 23.11	 -14.28	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79766	 1	 6.46	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79767	 1	 5.04	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79768	 1	 13.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79769	 1	 10.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79770	 1	 6.4	 4.98	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79771	 1	 10.82	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79772	 1	 18.06	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79773	 1	 5.29	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79774	 1	 10.68	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79775	 1	 8.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79776	 1	 5.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79777	 1	 5.88	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79778	 1	 7.73	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79779	 1	 10.48	 8.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79780	 1	 13.76	 9.45	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79781	 1	 5.57	 3.62	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79782	 1	 3.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79783	 1	 1.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79784	 1	 15.28	 10.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79785	 1	 9.09	 7.61	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79786	 1	 14.05	 9.38	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79787	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79788	 1	 31.81	 30.49	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79789	 1	 3.19	 1.8	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79790	 1	 6.08	 4.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79791	 1	 5.3	 3.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79792	 1	 17.03	 12.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79793	 1	 5.01	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79794	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79795	 1	 13.39	 10.57	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79796	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79797	 1	 10.31	 5.18	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79798	 1	 8.11	 5.53	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79799	 1	 3.87	 2.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79800	 1	 8.89	 5.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79801	 1	 3.36	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79802	 1	 3.88	 2.72	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79803	 1	 12.81	 10.39	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79804	 1	 12.95	 10.42	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79805	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79806	 1	 33.2	 31.01	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79807	 1	 5.7	 2.56	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79808	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79809	 1	 9.86	 7.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79810	 1	 2.6	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79811	 1	 12.28	 5.19	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79812	 1	 3.6	 2.17	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79813	 1	 3.62	 1.23	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79814	 1	 3.79	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79815	 1	 25.12	 11.92	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79816	 1	 8.2	 5.43	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79817	 1	 8.16	 7.05	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79818	 1	 2.93	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79819	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79820	 1	 17.68	 17.3	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79821	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79822	 1	 6.98	 5.31	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79823	 1	 7.51	 3.09	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79824	 1	 21.95	 12.11	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79825	 1	 5.09	 4.79	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79826	 1	 4.31	 3.26	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79827	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	79828	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79829	 1	 22.44	 19.59	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79830	 1	 3.39	 1.95	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79831	 1	 6.2	 2.88	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79832	 1	 12.11	 8.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79833	 1	 13.33	 9.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79834	 1	 3.99	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79835	 1	 1.6	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79836	 1	 3.36	 1.24	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79837	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79838	 1	 17.79	 8.85	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79839	 1	 6.8	 3.25	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79840	 1	 4.86	 -7.02	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79841	 1	 9.74	 7.73	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79842	 1	 8.28	 5.69	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79843	 1	 3.82	 1.97	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79844	 1	 3.41	 1.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79845	 1	 20.16	 13.84	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79846	 1	 29.28	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79847	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79848	 1	 29.57	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79849	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79850	 1	 61.14	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79851	 1	 6.84	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79852	 1	 18.33	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79853	 1	 13.32	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79854	 1	 11.99	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79855	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79856	 1	 9.19	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79857	 1	 6.1	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79858	 1	 4.53	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79859	 1	 3.93	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79860	 1	 7.59	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79861	 1	 5.04	 3.55	 0.0	 0.0	 2	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	79862	 1	 0.0	 0.0	 0.0	 275.82	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	79863	 1	 0.0	 0.0	 0.0	 -172.67	 6	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	79865	 1	 0.0	 0.0	 0.0	 -177.7	 3	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	79866	 1	 0.0	 0.0	 0.0	 300.0	 2	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin	Pc1	Pc2	Qc1min	Qc1max	Qc2min	Qc2max	ramp_agc	ramp_10	ramp_30	ramp_q	apf
mpc.gen = [
	58576	 108.0	 0.0	 59.5	 -59.5	 1.0	 100.0	 1	 108.0	 108.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58577	 102.35	 16.55	 71.7	 -38.6	 1.0	 100.0	 1	 115.7	 89.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.7;
	58578	 53.5	 0.0	 35.2	 -35.2	 1.0	 100.0	 1	 107.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	58578	 53.5	 0.0	 35.2	 -35.2	 1.0	 100.0	 1	 107.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	58578	 53.5	 0.0	 35.2	 -35.2	 1.0	 100.0	 1	 107.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	58578	 53.5	 0.0	 35.2	 -35.2	 1.0	 100.0	 1	 107.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	58580	 105.0	 0.0	 34.5	 -34.5	 1.0	 100.0	 1	 105.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	58580	 105.0	 0.0	 34.5	 -34.5	 1.0	 100.0	 1	 105.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	58580	 105.0	 0.0	 34.5	 -34.5	 1.0	 100.0	 1	 105.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	58580	 105.0	 0.0	 34.5	 -34.5	 1.0	 100.0	 1	 105.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	58580	 105.0	 0.0	 34.5	 -34.5	 1.0	 100.0	 1	 105.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	58581	 82.8	 0.0	 45.6	 -45.6	 1.0	 100.0	 1	 82.8	 82.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5;
	58582	 68.55	 13.05	 56.4	 -30.3	 1.0	 100.0	 1	 91.0	 46.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.0;
	58583	 33.55	 4.35	 27.7	 -19.0	 1.0	 100.0	 1	 57.1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.1;
	58583	 7.365	 1.53	 7.2	 -4.14	 1.0	 100.0	 1	 12.44	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.44;
	58583	 7.365	 1.53	 7.2	 -4.14	 1.0	 100.0	 1	 12.44	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.44;
	58583	 7.365	 1.53	 7.2	 -4.14	 1.0	 100.0	 1	 12.44	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.44;
	58583	 7.365	 1.53	 7.2	 -4.14	 1.0	 100.0	 1	 12.44	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.44;
	58583	 7.365	 1.53	 7.2	 -4.14	 1.0	 100.0	 1	 12.44	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.44;
	58583	 7.365	 1.53	 7.2	 -4.14	 1.0	 100.0	 1	 12.44	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.44;
	58583	 7.365	 1.53	 7.2	 -4.14	 1.0	 100.0	 1	 12.44	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.44;
	58584	 77.0	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58584	 53.4	 5.8	 37.2	 -25.6	 1.0	 100.0	 1	 76.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.8;
	58584	 71.9	 8.6	 55.1	 -37.9	 1.0	 100.0	 1	 113.8	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.8;
	58584	 71.95	 8.6	 55.2	 -38.0	 1.0	 100.0	 1	 113.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.9;
	58584	 71.95	 8.6	 55.2	 -38.0	 1.0	 100.0	 1	 113.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.9;
	58585	 45.0	 5.1	 32.9	 -22.7	 1.0	 100.0	 1	 68.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0;
	58586	 31.25	 0.0	 20.5	 -20.5	 1.0	 100.0	 1	 62.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	58586	 31.25	 0.0	 20.5	 -20.5	 1.0	 100.0	 1	 62.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	58586	 31.25	 0.0	 20.5	 -20.5	 1.0	 100.0	 1	 62.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	58586	 31.25	 0.0	 20.5	 -20.5	 1.0	 100.0	 1	 62.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58587	 4.05	 1.275	 4.58	 -2.03	 1.0	 100.0	 1	 6.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58589	 25.7	 3.8	 24.4	 -16.8	 1.0	 100.0	 1	 50.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	58589	 35.8	 5.35	 34.2	 -23.5	 1.0	 100.0	 1	 70.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.6;
	58589	 43.8	 6.5	 41.9	 -28.9	 1.0	 100.0	 1	 86.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.6;
	58590	 34.5	 0.0	 10.2	 -10.2	 1.0	 100.0	 1	 50.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	58592	 34.55	 3.45	 22.3	 -15.4	 1.0	 100.0	 1	 46.1	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.1;
	58593	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58593	 20.0	 0.0	 13.1	 -13.1	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58593	 21.75	 0.0	 14.3	 -14.3	 1.0	 100.0	 1	 43.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.5;
	58593	 21.75	 0.0	 14.3	 -14.3	 1.0	 100.0	 1	 43.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.5;
	58594	 5.3	 2.0	 7.2	 -3.2	 1.0	 100.0	 1	 9.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	58594	 5.3	 2.0	 7.2	 -3.2	 1.0	 100.0	 1	 9.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	58594	 5.3	 2.0	 7.2	 -3.2	 1.0	 100.0	 1	 9.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	58594	 5.3	 2.0	 7.2	 -3.2	 1.0	 100.0	 1	 9.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58595	 3.11	 0.0	 2.01	 -2.01	 1.0	 100.0	 1	 4.57	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.57;
	58598	 24.0	 0.0	 11.9	 -11.9	 1.0	 100.0	 1	 24.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	58599	 4.5	 1.665	 6.0	 -2.67	 1.0	 100.0	 1	 8.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	58599	 4.5	 1.665	 6.0	 -2.67	 1.0	 100.0	 1	 8.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	58599	 4.5	 1.665	 6.0	 -2.67	 1.0	 100.0	 1	 8.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 57.5	 0.0	 28.3	 -28.3	 1.0	 100.0	 1	 86.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 51.4	 0.0	 25.6	 -25.6	 1.0	 100.0	 1	 78.0	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	58601	 57.25	 0.0	 29.5	 -29.5	 1.0	 100.0	 1	 89.7	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.7;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58601	 50.56	 0.0	 24.92	 -24.92	 1.0	 100.0	 1	 75.82	 25.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.82;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 33.35	 4.05	 25.9	 -17.8	 1.0	 100.0	 1	 53.5	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.5;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.65	 4.7	 30.1	 -20.7	 1.0	 100.0	 1	 62.1	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 37.645	 0.0	 24.04	 -24.04	 1.0	 100.0	 1	 58.1	 17.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 44.85	 0.0	 21.9	 -21.9	 1.0	 100.0	 1	 66.5	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.5;
	58602	 33.35	 4.05	 25.9	 -17.8	 1.0	 100.0	 1	 53.5	 13.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.5;
	58603	 366.1	 0.0	 211.1	 -211.1	 1.0	 100.0	 1	 642.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 642.2;
	58604	 132.75	 12.9	 82.8	 -57.0	 1.0	 100.0	 1	 171.0	 94.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 171.0;
	58604	 235.5	 23.55	 151.1	 -104.0	 1.0	 100.0	 1	 312.0	 159.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 312.0;
	58605	 177.2	 37.9	 163.9	 -88.1	 1.0	 100.0	 1	 264.4	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 264.4;
	58605	 146.25	 30.45	 131.7	 -70.8	 1.0	 100.0	 1	 212.5	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.5;
	58605	 146.25	 30.45	 131.7	 -70.8	 1.0	 100.0	 1	 212.5	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.5;
	58606	 151.75	 0.0	 41.5	 -41.5	 1.0	 100.0	 1	 204.5	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.5;
	58606	 151.75	 0.0	 41.5	 -41.5	 1.0	 100.0	 1	 204.5	 99.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.5;
	58606	 85.55	 0.0	 21.5	 -21.5	 1.0	 100.0	 1	 106.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.1;
	58606	 85.55	 0.0	 21.5	 -21.5	 1.0	 100.0	 1	 106.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.1;
	58607	 137.85	 0.0	 26.5	 -26.5	 1.0	 100.0	 1	 185.7	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.7;
	58607	 64.3	 0.0	 11.5	 -11.5	 1.0	 100.0	 1	 80.6	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.6;
	58608	 127.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	58608	 92.0	 8.85	 56.7	 -39.0	 1.0	 100.0	 1	 117.0	 67.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0;
	58609	 125.75	 23.15	 100.1	 -53.8	 1.0	 100.0	 1	 161.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.5;
	58609	 125.75	 23.15	 100.1	 -53.8	 1.0	 100.0	 1	 161.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.5;
	58609	 114.25	 25.55	 110.6	 -59.5	 1.0	 100.0	 1	 178.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58610	 93.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58611	 65.25	 9.85	 63.2	 -43.5	 1.0	 100.0	 1	 130.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.5;
	58611	 65.25	 9.85	 63.2	 -43.5	 1.0	 100.0	 1	 130.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.5;
	58611	 65.25	 9.85	 63.2	 -43.5	 1.0	 100.0	 1	 130.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.5;
	58614	 56.75	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	58614	 65.5	 9.85	 63.0	 -43.3	 1.0	 100.0	 1	 130.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	58614	 65.5	 9.85	 63.0	 -43.3	 1.0	 100.0	 1	 130.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	58615	 86.4	 0.0	 47.6	 -47.6	 1.0	 100.0	 1	 86.4	 86.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	58616	 41.32	 0.0	 45.4	 -45.4	 1.0	 100.0	 1	 41.32	 41.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0;
	58617	 40.28	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 40.28	 40.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.7;
	58618	 80.4	 7.6	 48.7	 -33.5	 1.0	 100.0	 1	 80.4	 80.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	58619	 41.52	 0.0	 43.6	 -43.6	 1.0	 100.0	 1	 41.52	 41.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.9;
	58620	 39.48	 0.0	 43.5	 -43.5	 1.0	 100.0	 1	 39.48	 39.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.7;
	58621	 78.96	 0.0	 43.5	 -43.5	 1.0	 100.0	 1	 78.96	 78.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.7;
	58622	 77.6	 0.0	 42.8	 -42.8	 1.0	 100.0	 1	 77.6	 77.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.0;
	58624	 30.0	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 30.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	58625	 28.8	 0.0	 28.5	 -28.5	 1.0	 100.0	 1	 28.8	 28.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 52.15	 0.0	 26.5	 -26.5	 1.0	 100.0	 1	 80.5	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.5;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58626	 46.9	 0.0	 23.0	 -23.0	 1.0	 100.0	 1	 70.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	58627	 93.2	 13.3	 85.4	 -58.8	 1.0	 100.0	 1	 176.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.4;
	58627	 36.65	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3;
	58627	 36.65	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3;
	58627	 36.65	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3;
	58627	 36.65	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3;
	58627	 36.65	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3;
	58627	 36.65	 5.15	 33.1	 -22.8	 1.0	 100.0	 1	 68.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.3;
	58628	 9.815	 12.2	 12.2	 12.2	 1.0	 100.0	 1	 16.25	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	58628	 9.815	 12.2	 12.2	 12.2	 1.0	 100.0	 1	 16.25	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	58628	 9.815	 12.2	 12.2	 12.2	 1.0	 100.0	 1	 16.25	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	58628	 9.815	 12.2	 12.2	 12.2	 1.0	 100.0	 1	 16.25	 3.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	58628	 24.0	 30.0	 30.0	 30.0	 1.0	 100.0	 1	 40.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58629	 32.1	 17.2	 17.2	 17.2	 1.0	 100.0	 1	 52.2	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2;
	58629	 32.1	 17.2	 17.2	 17.2	 1.0	 100.0	 1	 52.2	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2;
	58631	 50.0	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	58631	 50.0	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	58632	 24.2	 0.0	 15.9	 -15.9	 1.0	 100.0	 1	 48.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.4;
	58632	 25.15	 0.0	 16.5	 -16.5	 1.0	 100.0	 1	 50.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.3;
	58634	 22.4	 19.5	 19.5	 19.5	 1.0	 100.0	 1	 42.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.8;
	58635	 7.1	 8.8	 8.8	 8.8	 1.0	 100.0	 1	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2;
	58635	 7.1	 8.8	 8.8	 8.8	 1.0	 100.0	 1	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2;
	58635	 7.1	 8.8	 8.8	 8.8	 1.0	 100.0	 1	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2;
	58636	 16.8	 0.0	 16.2	 -16.2	 1.0	 100.0	 1	 16.8	 16.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0;
	58636	 25.6	 0.0	 24.9	 -24.9	 1.0	 100.0	 1	 25.6	 25.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	58637	 9.33	 10.0	 10.0	 10.0	 1.0	 100.0	 1	 13.33	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.33;
	58637	 9.33	 10.0	 10.0	 10.0	 1.0	 100.0	 1	 13.33	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.33;
	58637	 9.33	 10.0	 10.0	 10.0	 1.0	 100.0	 1	 13.33	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.33;
	58638	 40.0	 13.1	 13.1	 13.1	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58638	 40.0	 13.1	 13.1	 13.1	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58639	 40.0	 13.1	 13.1	 13.1	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58639	 40.0	 13.1	 13.1	 13.1	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58639	 40.0	 13.1	 13.1	 13.1	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58640	 19.25	 12.7	 12.7	 12.7	 1.0	 100.0	 1	 38.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5;
	58641	 10.325	 4.65	 4.65	 4.65	 1.0	 100.0	 1	 18.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.65;
	58641	 10.325	 4.65	 4.65	 4.65	 1.0	 100.0	 1	 18.65	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.65;
	58642	 4.385	 3.85	 3.85	 3.85	 1.0	 100.0	 1	 6.1	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58642	 4.385	 3.85	 3.85	 3.85	 1.0	 100.0	 1	 6.1	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58642	 4.385	 3.85	 3.85	 3.85	 1.0	 100.0	 1	 6.1	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58642	 4.385	 3.85	 3.85	 3.85	 1.0	 100.0	 1	 6.1	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58642	 4.385	 3.85	 3.85	 3.85	 1.0	 100.0	 1	 6.1	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58642	 4.385	 3.85	 3.85	 3.85	 1.0	 100.0	 1	 6.1	 2.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.1;
	58643	 20.0	 22.3	 22.3	 22.3	 1.0	 100.0	 1	 36.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	58644	 21.2	 15.7	 15.7	 15.7	 1.0	 100.0	 1	 32.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.4;
	58644	 21.2	 15.7	 15.7	 15.7	 1.0	 100.0	 1	 32.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.4;
	58644	 27.5	 21.8	 21.8	 21.8	 1.0	 100.0	 1	 45.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	58645	 8.0	 3.325	 12.0	 -5.35	 1.0	 100.0	 1	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	58645	 8.0	 3.325	 12.0	 -5.35	 1.0	 100.0	 1	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	58646	 15.0	 0.0	 4.95	 -4.95	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	58646	 15.0	 0.0	 4.95	 -4.95	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	58647	 18.7	 4.2	 18.2	 -9.8	 1.0	 100.0	 1	 29.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	58647	 18.7	 4.2	 18.2	 -9.8	 1.0	 100.0	 1	 29.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	58647	 18.7	 4.2	 18.2	 -9.8	 1.0	 100.0	 1	 29.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	58647	 18.7	 4.2	 18.2	 -9.8	 1.0	 100.0	 1	 29.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	58648	 12.75	 4.25	 4.25	 4.25	 1.0	 100.0	 1	 13.0	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	58648	 12.75	 4.25	 4.25	 4.25	 1.0	 100.0	 1	 13.0	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	58649	 13.0	 16.1	 16.1	 16.1	 1.0	 100.0	 1	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0;
	58650	 14.75	 3.65	 15.8	 -8.5	 1.0	 100.0	 1	 25.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5;
	58650	 14.75	 3.65	 15.8	 -8.5	 1.0	 100.0	 1	 25.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5;
	58651	 10.48	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 10.48	 10.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	58652	 19.68	 0.0	 9.7	 -9.7	 1.0	 100.0	 1	 19.68	 19.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6;
	58652	 20.16	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 20.16	 20.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2;
	58653	 24.45	 8.1	 8.1	 8.1	 1.0	 100.0	 1	 24.5	 24.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	58653	 24.45	 8.1	 8.1	 8.1	 1.0	 100.0	 1	 24.5	 24.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	58654	 9.8	 0.0	 9.7	 -9.7	 1.0	 100.0	 1	 9.8	 9.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	58655	 17.85	 0.0	 7.8	 -7.8	 1.0	 100.0	 1	 23.7	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.7;
	58656	 12.8	 10.5	 10.5	 10.5	 1.0	 100.0	 1	 21.6	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	58657	 10.75	 13.0	 13.0	 13.0	 1.0	 100.0	 1	 21.0	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	58658	 10.0	 0.0	 3.3	 -3.3	 1.0	 100.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	58658	 10.0	 0.0	 3.3	 -3.3	 1.0	 100.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 53.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.5;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 53.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.5;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 53.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.5;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	58659	 300.0	 0.0	 121.8	 -121.8	 1.0	 100.0	 1	 600.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 600.0;
	58659	 300.0	 0.0	 121.8	 -121.8	 1.0	 100.0	 1	 600.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 600.0;
	58659	 300.0	 0.0	 121.8	 -121.8	 1.0	 100.0	 1	 600.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 600.0;
	58659	 402.5	 0.0	 163.5	 -163.5	 1.0	 100.0	 1	 805.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 805.0;
	58659	 402.5	 0.0	 163.5	 -163.5	 1.0	 100.0	 1	 805.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 805.0;
	58659	 402.5	 0.0	 163.5	 -163.5	 1.0	 100.0	 1	 805.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 805.0;
	58659	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 53.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.5;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58659	 120.28	 0.0	 39.14	 -39.14	 1.0	 100.0	 1	 240.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 240.56;
	58660	 660.0	 0.0	 273.5	 -273.5	 1.0	 100.0	 1	 1200.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	58661	 44.65	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 28.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	58661	 44.65	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 28.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	58661	 44.65	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 28.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	58661	 44.65	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 28.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	58661	 489.95	 0.0	 264.9	 -264.9	 1.0	 100.0	 1	 729.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 729.9;
	58661	 482.45	 0.0	 264.9	 -264.9	 1.0	 100.0	 1	 729.9	 235.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 729.9;
	58661	 61.2	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 42.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	58664	 165.0	 32.9	 142.5	 -76.7	 1.0	 100.0	 1	 230.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0;
	58664	 167.0	 33.5	 145.0	 -78.0	 1.0	 100.0	 1	 234.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.0;
	58664	 167.0	 33.5	 145.0	 -78.0	 1.0	 100.0	 1	 234.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.0;
	58665	 151.73	 15.4	 98.8	 -68.0	 1.0	 100.0	 1	 151.73	 151.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	58666	 111.44	 15.05	 96.4	 -66.3	 1.0	 100.0	 1	 111.44	 111.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0;
	58667	 143.5	 119.0	 119.0	 119.0	 1.0	 100.0	 1	 192.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0;
	58667	 95.65	 41.5	 41.5	 41.5	 1.0	 100.0	 1	 126.3	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.3;
	58668	 155.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 186.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.0;
	58668	 99.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 133.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0;
	58670	 137.5	 25.1	 108.5	 -58.3	 1.0	 100.0	 1	 175.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0;
	58670	 137.5	 25.1	 108.5	 -58.3	 1.0	 100.0	 1	 175.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0;
	58670	 200.0	 42.95	 185.9	 -100.0	 1.0	 100.0	 1	 300.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	58672	 79.2	 0.0	 52.1	 -52.1	 1.0	 100.0	 1	 158.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 158.4;
	58672	 79.2	 0.0	 52.1	 -52.1	 1.0	 100.0	 1	 158.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 158.4;
	58672	 80.75	 0.0	 53.1	 -53.1	 1.0	 100.0	 1	 161.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.5;
	58672	 80.75	 0.0	 53.1	 -53.1	 1.0	 100.0	 1	 161.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.5;
	58672	 119.7	 0.0	 78.7	 -78.7	 1.0	 100.0	 1	 239.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4;
	58672	 119.7	 0.0	 78.7	 -78.7	 1.0	 100.0	 1	 239.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.4;
	58673	 125.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 150.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	58673	 117.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 150.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	58675	 109.04	 0.0	 60.1	 -60.1	 1.0	 100.0	 1	 109.04	 109.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.3;
	58676	 97.35	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 59.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58676	 97.35	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 59.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58676	 97.35	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 59.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58676	 93.15	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 51.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58676	 93.15	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 51.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58676	 93.15	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 51.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58677	 127.0	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 119.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58677	 99.15	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 63.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58677	 99.15	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 63.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58677	 99.15	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 63.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58677	 94.4	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 53.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58677	 94.4	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 53.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58678	 122.5	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58678	 96.25	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 57.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58678	 96.25	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 57.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58678	 96.25	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 57.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58678	 90.7	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 46.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58678	 90.7	 0.0	 44.4	 -44.4	 1.0	 100.0	 1	 135.0	 46.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	58679	 74.5	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58679	 80.2	 0.0	 41.2	 -41.2	 1.0	 100.0	 1	 125.4	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.4;
	58679	 80.2	 0.0	 41.2	 -41.2	 1.0	 100.0	 1	 125.4	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.4;
	58679	 74.5	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58679	 74.5	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58679	 74.5	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58679	 74.5	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58679	 74.5	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58679	 74.5	 0.0	 37.5	 -37.5	 1.0	 100.0	 1	 114.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	58679	 80.2	 0.0	 41.2	 -41.2	 1.0	 100.0	 1	 125.4	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.4;
	58679	 80.2	 0.0	 41.2	 -41.2	 1.0	 100.0	 1	 125.4	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.4;
	58680	 56.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	58680	 56.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	58680	 56.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	58680	 56.25	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	58681	 80.56	 44.4	 44.4	 44.4	 1.0	 100.0	 1	 80.56	 80.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.7;
	58682	 63.3	 0.0	 43.6	 -43.6	 1.0	 100.0	 1	 63.3	 63.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.9;
	58683	 78.24	 7.4	 47.4	 -32.6	 1.0	 100.0	 1	 78.24	 78.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.8;
	58685	 65.45	 46.4	 46.4	 46.4	 1.0	 100.0	 1	 95.9	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.9;
	58685	 65.45	 46.4	 46.4	 46.4	 1.0	 100.0	 1	 95.9	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.9;
	58685	 61.85	 45.4	 45.4	 45.4	 1.0	 100.0	 1	 93.7	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.7;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 73.9	 0.0	 32.1	 -32.1	 1.0	 100.0	 1	 97.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.8;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 72.5	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58686	 73.9	 0.0	 32.1	 -32.1	 1.0	 100.0	 1	 97.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.8;
	58687	 80.0	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 90.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	58687	 62.85	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 90.0	 35.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	58687	 62.85	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 90.0	 35.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	58687	 76.6	 0.0	 36.5	 -36.5	 1.0	 100.0	 1	 111.0	 42.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 111.0;
	58687	 76.6	 0.0	 36.5	 -36.5	 1.0	 100.0	 1	 111.0	 42.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 111.0;
	58687	 76.6	 0.0	 36.5	 -36.5	 1.0	 100.0	 1	 111.0	 42.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 111.0;
	58689	 72.0	 0.0	 39.7	 -39.7	 1.0	 100.0	 1	 72.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	58690	 46.95	 6.75	 43.1	 -29.6	 1.0	 100.0	 1	 88.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.9;
	58690	 46.95	 6.75	 43.1	 -29.6	 1.0	 100.0	 1	 88.9	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.9;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 67.9	 0.0	 29.0	 -29.0	 1.0	 100.0	 1	 88.2	 47.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58691	 95.0	 0.0	 31.2	 -31.2	 1.0	 100.0	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58692	 28.85	 2.85	 18.3	 -12.6	 1.0	 100.0	 1	 37.7	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.7;
	58692	 68.9	 6.6	 42.5	 -29.3	 1.0	 100.0	 1	 87.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.8;
	58693	 44.8	 6.4	 41.0	 -28.2	 1.0	 100.0	 1	 84.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.6;
	58693	 44.8	 6.4	 41.0	 -28.2	 1.0	 100.0	 1	 84.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.6;
	58694	 41.4	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 80.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.8;
	58695	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	58695	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	58695	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58696	 66.2	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 77.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.4;
	58699	 24.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58699	 7.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.8	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	58699	 7.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.8	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	58699	 7.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.8	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	58699	 7.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.8	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	58699	 7.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.8	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	58700	 39.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 64.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0;
	58701	 33.25	 8.8	 38.1	 -20.5	 1.0	 100.0	 1	 61.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	58702	 9.0	 0.0	 6.17	 -6.17	 1.0	 100.0	 1	 14.85	 3.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	58702	 9.0	 0.0	 6.17	 -6.17	 1.0	 100.0	 1	 14.85	 3.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	58702	 9.0	 0.0	 6.17	 -6.17	 1.0	 100.0	 1	 14.85	 3.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	58702	 9.0	 0.0	 6.17	 -6.17	 1.0	 100.0	 1	 14.85	 3.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	58702	 18.7	 2.35	 15.2	 -10.5	 1.0	 100.0	 1	 31.4	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4;
	58703	 39.45	 28.5	 28.5	 28.5	 1.0	 100.0	 1	 58.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9;
	58703	 39.45	 28.5	 28.5	 28.5	 1.0	 100.0	 1	 58.9	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9;
	58703	 84.55	 62.5	 62.5	 62.5	 1.0	 100.0	 1	 129.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.1;
	58703	 84.55	 62.5	 62.5	 62.5	 1.0	 100.0	 1	 129.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.1;
	58704	 31.35	 16.7	 16.7	 16.7	 1.0	 100.0	 1	 50.7	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.7;
	58705	 40.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	58707	 30.0	 15.1	 15.1	 15.1	 1.0	 100.0	 1	 46.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	58707	 30.0	 15.1	 15.1	 15.1	 1.0	 100.0	 1	 46.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	58708	 9.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	58708	 9.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	58708	 9.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	58708	 9.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	58709	 22.5	 9.4	 33.8	 -15.0	 1.0	 100.0	 1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	58709	 22.5	 9.4	 33.8	 -15.0	 1.0	 100.0	 1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	58709	 22.5	 9.4	 33.8	 -15.0	 1.0	 100.0	 1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	58710	 35.2	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 35.2	 35.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	58710	 182.88	 17.25	 110.7	 -76.2	 1.0	 100.0	 1	 182.88	 182.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.6;
	58711	 26.46	 23.6	 23.6	 23.6	 1.0	 100.0	 1	 42.0	 10.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0;
	58712	 24.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	58712	 24.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	58712	 24.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	58712	 24.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	58713	 30.7	 3.0	 19.1	 -13.1	 1.0	 100.0	 1	 39.4	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.4;
	58713	 30.2	 3.0	 19.1	 -13.1	 1.0	 100.0	 1	 39.4	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.4;
	58713	 30.2	 3.0	 19.1	 -13.1	 1.0	 100.0	 1	 39.4	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.4;
	58713	 44.1	 4.4	 28.2	 -19.4	 1.0	 100.0	 1	 58.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.2;
	58715	 18.0	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	58715	 18.0	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	58716	 23.5	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	58716	 23.5	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	58719	 26.3	 6.15	 22.2	 -9.9	 1.0	 100.0	 1	 29.6	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.6;
	58719	 26.3	 6.15	 22.2	 -9.9	 1.0	 100.0	 1	 29.6	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.6;
	58720	 20.5	 17.4	 17.4	 17.4	 1.0	 100.0	 1	 28.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	58721	 15.25	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 27.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	58722	 17.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 27.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	58722	 17.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 27.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	58722	 17.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 27.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	58723	 41.8	 22.6	 22.6	 22.6	 1.0	 100.0	 1	 46.6	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.6;
	58723	 41.8	 22.6	 22.6	 22.6	 1.0	 100.0	 1	 46.6	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.6;
	58723	 41.8	 22.6	 22.6	 22.6	 1.0	 100.0	 1	 46.6	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.6;
	58723	 17.0	 13.1	 13.1	 13.1	 1.0	 100.0	 1	 27.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	58724	 14.9	 8.8	 8.8	 8.8	 1.0	 100.0	 1	 26.8	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.8;
	58726	 15.0	 3.7	 16.1	 -8.7	 1.0	 100.0	 1	 26.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0;
	58727	 14.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 25.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	58727	 14.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 25.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	58728	 4.1	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1;
	58728	 4.1	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1;
	58728	 4.1	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1;
	58728	 4.1	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1;
	58728	 4.1	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1;
	58728	 4.1	 0.855	 3.08	 -1.37	 1.0	 100.0	 1	 4.1	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.1;
	58730	 6.05	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	58730	 6.05	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	58731	 3.015	 3.08	 3.08	 3.08	 1.0	 100.0	 1	 5.7	 0.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	58731	 3.015	 3.08	 3.08	 3.08	 1.0	 100.0	 1	 5.7	 0.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	58731	 3.015	 3.08	 3.08	 3.08	 1.0	 100.0	 1	 5.7	 0.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	58731	 3.015	 3.08	 3.08	 3.08	 1.0	 100.0	 1	 5.7	 0.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	58732	 11.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58732	 11.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58732	 11.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58732	 11.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 15.35	 1.55	 10.0	 -6.9	 1.0	 100.0	 1	 20.7	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	58733	 15.35	 1.55	 10.0	 -6.9	 1.0	 100.0	 1	 20.7	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	58733	 15.35	 1.55	 10.0	 -6.9	 1.0	 100.0	 1	 20.7	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	58733	 16.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58733	 16.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58733	 16.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58733	 16.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58733	 16.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58733	 16.25	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 30.65	 0.0	 16.9	 -16.9	 1.0	 100.0	 1	 51.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	58733	 15.35	 1.55	 10.0	 -6.9	 1.0	 100.0	 1	 20.7	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	58735	 344.15	 0.0	 177.4	 -177.4	 1.0	 100.0	 1	 608.3	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 608.3;
	58735	 344.15	 0.0	 199.9	 -199.9	 1.0	 100.0	 1	 608.3	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 608.3;
	58735	 344.15	 0.0	 199.9	 -199.9	 1.0	 100.0	 1	 608.3	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 608.3;
	58735	 348.5	 0.0	 202.8	 -202.8	 1.0	 100.0	 1	 617.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 617.0;
	58736	 400.0	 43.05	 276.1	 -190.0	 1.0	 100.0	 1	 570.0	 230.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.0;
	58736	 385.0	 43.05	 276.1	 -190.0	 1.0	 100.0	 1	 570.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.0;
	58736	 385.0	 43.05	 276.1	 -190.0	 1.0	 100.0	 1	 570.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.0;
	58738	 160.0	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 160.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	58740	 94.3	 19.15	 82.8	 -44.5	 1.0	 100.0	 1	 133.6	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.6;
	58740	 94.3	 19.15	 82.8	 -44.5	 1.0	 100.0	 1	 133.6	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.6;
	58740	 187.5	 19.25	 123.5	 -85.0	 1.0	 100.0	 1	 255.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 255.0;
	58740	 290.0	 30.2	 193.7	 -133.3	 1.0	 100.0	 1	 400.0	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 400.0;
	58741	 93.75	 8.75	 56.2	 -38.7	 1.0	 100.0	 1	 116.0	 71.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 116.0;
	58742	 92.64	 8.75	 56.1	 -38.6	 1.0	 100.0	 1	 92.64	 92.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.8;
	58743	 82.64	 7.8	 50.0	 -34.4	 1.0	 100.0	 1	 82.64	 82.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.3;
	58744	 82.64	 7.8	 50.0	 -34.4	 1.0	 100.0	 1	 82.64	 82.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.3;
	58745	 79.2	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 79.2	 79.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.0;
	58746	 78.5	 7.15	 46.0	 -31.7	 1.0	 100.0	 1	 95.0	 62.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	58748	 73.6	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 57.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	58749	 64.0	 0.0	 31.6	 -31.6	 1.0	 100.0	 1	 64.0	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	58750	 48.8	 0.0	 24.1	 -24.1	 1.0	 100.0	 1	 48.8	 48.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	58751	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 17.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.2;
	58751	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 17.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.2;
	58751	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 17.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.2;
	58752	 40.0	 0.0	 19.8	 -19.8	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	58753	 33.6	 0.0	 16.6	 -16.6	 1.0	 100.0	 1	 33.6	 33.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0;
	58754	 33.12	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 33.12	 33.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4;
	58755	 4.29	 1.21	 4.7	 -2.28	 1.0	 100.0	 1	 6.83	 1.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	58755	 4.29	 1.21	 4.7	 -2.28	 1.0	 100.0	 1	 6.83	 1.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	58755	 4.29	 1.21	 4.7	 -2.28	 1.0	 100.0	 1	 6.83	 1.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	58755	 4.29	 1.21	 4.7	 -2.28	 1.0	 100.0	 1	 6.83	 1.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	58755	 4.29	 1.21	 4.7	 -2.28	 1.0	 100.0	 1	 6.83	 1.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	58755	 4.29	 1.21	 4.7	 -2.28	 1.0	 100.0	 1	 6.83	 1.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	58756	 32.56	 3.05	 19.7	 -13.6	 1.0	 100.0	 1	 32.56	 32.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7;
	58756	 82.64	 7.8	 50.0	 -34.4	 1.0	 100.0	 1	 82.64	 82.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.3;
	58757	 32.35	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 24.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	58759	 6.0	 0.9	 5.8	 -4.0	 1.0	 100.0	 1	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	58759	 6.0	 0.9	 5.8	 -4.0	 1.0	 100.0	 1	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	58759	 6.0	 0.9	 5.8	 -4.0	 1.0	 100.0	 1	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	58760	 33.0	 5.15	 22.3	 -12.0	 1.0	 100.0	 1	 36.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	58760	 33.0	 5.15	 22.3	 -12.0	 1.0	 100.0	 1	 36.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	58760	 33.0	 5.15	 22.3	 -12.0	 1.0	 100.0	 1	 36.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	58762	 16.7	 0.0	 11.0	 -11.0	 1.0	 100.0	 1	 33.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4;
	58762	 16.7	 0.0	 11.0	 -11.0	 1.0	 100.0	 1	 33.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4;
	58764	 23.76	 2.25	 14.4	 -9.9	 1.0	 100.0	 1	 23.76	 23.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7;
	58765	 23.52	 0.0	 11.6	 -11.6	 1.0	 100.0	 1	 23.52	 23.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	58766	 19.84	 0.0	 9.8	 -9.8	 1.0	 100.0	 1	 19.84	 19.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.8;
	58767	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58767	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58767	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58768	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58768	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58768	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58769	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58769	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58769	 4.0	 1.565	 5.63	 -2.5	 1.0	 100.0	 1	 7.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	58770	 15.35	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.7	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.7;
	58771	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 20.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	58771	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 20.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	58772	 16.24	 1.5	 9.8	 -6.8	 1.0	 100.0	 1	 16.24	 16.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.3;
	58772	 82.64	 7.8	 50.0	 -34.4	 1.0	 100.0	 1	 82.64	 82.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.3;
	58773	 147.2	 111.2	 111.2	 111.2	 1.0	 100.0	 1	 179.4	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.4;
	58773	 93.55	 75.7	 75.7	 75.7	 1.0	 100.0	 1	 122.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.1;
	58775	 92.72	 0.0	 54.9	 -54.9	 1.0	 100.0	 1	 92.72	 92.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.5;
	58776	 45.05	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.1;
	58776	 45.05	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.1;
	58776	 45.05	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.1;
	58776	 45.05	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.1;
	58776	 112.5	 17.0	 109.0	 -75.0	 1.0	 100.0	 1	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.0;
	58777	 90.0	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 90.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	58777	 90.0	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 90.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	58777	 220.0	 0.0	 72.3	 -72.3	 1.0	 100.0	 1	 220.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.0;
	58779	 51.6	 0.0	 25.5	 -25.5	 1.0	 100.0	 1	 51.6	 51.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.5;
	58780	 7.5	 1.95	 8.9	 -5.0	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	58780	 7.5	 1.95	 8.9	 -5.0	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	58780	 7.5	 1.95	 8.9	 -5.0	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	58780	 7.5	 1.95	 8.9	 -5.0	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	58781	 39.7	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.4;
	58781	 38.7	 4.5	 28.8	 -19.8	 1.0	 100.0	 1	 59.4	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.4;
	58781	 51.6	 5.55	 35.5	 -24.4	 1.0	 100.0	 1	 73.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.2;
	58781	 51.6	 5.55	 35.5	 -24.4	 1.0	 100.0	 1	 73.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.2;
	58782	 23.3	 0.0	 15.3	 -15.3	 1.0	 100.0	 1	 46.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.6;
	58784	 22.15	 14.6	 14.6	 14.6	 1.0	 100.0	 1	 44.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.3;
	58786	 14.0	 1.05	 6.77	 -4.67	 1.0	 100.0	 1	 14.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	58786	 14.0	 1.05	 6.77	 -4.67	 1.0	 100.0	 1	 14.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	58786	 14.0	 1.05	 6.77	 -4.67	 1.0	 100.0	 1	 14.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	58787	 8.015	 0.97	 6.17	 -4.23	 1.0	 100.0	 1	 12.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7;
	58787	 8.015	 0.97	 6.17	 -4.23	 1.0	 100.0	 1	 12.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7;
	58787	 8.015	 0.97	 6.17	 -4.23	 1.0	 100.0	 1	 12.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7;
	58790	 5.0	 0.75	 4.83	 -3.33	 1.0	 100.0	 1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	58790	 5.0	 0.75	 4.83	 -3.33	 1.0	 100.0	 1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	58790	 5.0	 0.75	 4.83	 -3.33	 1.0	 100.0	 1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	58791	 3.465	 0.65	 3.6	 -2.3	 1.0	 100.0	 1	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.93;
	58791	 3.465	 0.65	 3.6	 -2.3	 1.0	 100.0	 1	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.93;
	58791	 3.465	 0.65	 3.6	 -2.3	 1.0	 100.0	 1	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.93;
	58791	 3.465	 0.65	 3.6	 -2.3	 1.0	 100.0	 1	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.93;
	58792	 13.8	 0.0	 11.8	 -11.8	 1.0	 100.0	 1	 27.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	58792	 13.8	 0.0	 11.8	 -11.8	 1.0	 100.0	 1	 27.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	58792	 13.8	 0.0	 11.8	 -11.8	 1.0	 100.0	 1	 27.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	58793	 6.25	 0.0	 4.1	 -4.1	 1.0	 100.0	 1	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	58793	 6.25	 0.0	 4.1	 -4.1	 1.0	 100.0	 1	 12.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	58794	 12.5	 2.95	 14.2	 -8.3	 1.0	 100.0	 1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	58794	 12.5	 2.95	 14.2	 -8.3	 1.0	 100.0	 1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	58794	 12.5	 2.95	 14.2	 -8.3	 1.0	 100.0	 1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	58795	 23.4	 11.3	 11.3	 11.3	 1.0	 100.0	 1	 23.4	 23.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	58796	 14.6	 0.0	 8.9	 -8.9	 1.0	 100.0	 1	 14.6	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	58797	 8.44	 0.0	 8.3	 -8.3	 1.0	 100.0	 1	 8.44	 8.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	58798	 8.44	 0.0	 8.3	 -8.3	 1.0	 100.0	 1	 8.44	 8.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	58799	 14.0	 8.3	 8.3	 8.3	 1.0	 100.0	 1	 14.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	58800	 14.0	 8.3	 8.3	 8.3	 1.0	 100.0	 1	 14.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	58802	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	58802	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	61780	 756.6	 105.95	 679.6	 -467.7	 1.0	 100.0	 1	 1403.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61780	 756.6	 105.95	 679.6	 -467.7	 1.0	 100.0	 1	 1403.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61780	 756.6	 105.95	 679.6	 -467.7	 1.0	 100.0	 1	 1403.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61781	 564.05	 60.65	 389.0	 -267.7	 1.0	 100.0	 1	 803.1	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 803.1;
	61781	 564.05	 60.65	 389.0	 -267.7	 1.0	 100.0	 1	 803.1	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 803.1;
	61781	 564.05	 60.65	 389.0	 -267.7	 1.0	 100.0	 1	 803.1	 325.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 803.1;
	61782	 339.9	 32.05	 205.7	 -141.6	 1.0	 100.0	 1	 424.8	 255.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 424.8;
	61782	 364.05	 34.6	 221.9	 -152.7	 1.0	 100.0	 1	 458.1	 270.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 458.1;
	61782	 359.05	 34.6	 221.9	 -152.7	 1.0	 100.0	 1	 458.1	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 458.1;
	61782	 317.4	 32.05	 205.7	 -141.6	 1.0	 100.0	 1	 424.8	 210.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 424.8;
	61783	 230.45	 31.0	 199.0	 -137.0	 1.0	 100.0	 1	 410.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.9;
	61783	 230.45	 31.0	 199.0	 -137.0	 1.0	 100.0	 1	 410.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.9;
	61784	 124.4	 12.1	 77.5	 -53.3	 1.0	 100.0	 1	 160.0	 88.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 160.0;
	61784	 123.55	 12.1	 77.5	 -53.3	 1.0	 100.0	 1	 160.0	 87.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 160.0;
	61784	 122.95	 12.1	 77.5	 -53.3	 1.0	 100.0	 1	 160.0	 85.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 160.0;
	61784	 209.55	 21.25	 136.4	 -93.9	 1.0	 100.0	 1	 281.7	 137.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.7;
	61784	 208.55	 21.25	 136.4	 -93.9	 1.0	 100.0	 1	 281.7	 135.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.7;
	61784	 208.5	 21.25	 136.4	 -93.9	 1.0	 100.0	 1	 281.7	 135.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.7;
	61785	 170.5	 33.8	 146.3	 -78.7	 1.0	 100.0	 1	 236.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0;
	61785	 170.5	 33.8	 146.3	 -78.7	 1.0	 100.0	 1	 236.0	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0;
	61785	 148.0	 33.8	 146.3	 -78.7	 1.0	 100.0	 1	 236.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0;
	61786	 127.0	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	61786	 127.0	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	61786	 11.2	 1.55	 9.9	 -6.8	 1.0	 100.0	 1	 20.4	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.4;
	61786	 32.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61786	 50.8	 11.7	 50.6	 -27.2	 1.0	 100.0	 1	 81.6	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6;
	61786	 42.85	 5.95	 38.1	 -26.2	 1.0	 100.0	 1	 78.7	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.7;
	61787	 191.0	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.0;
	61787	 141.5	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0;
	61787	 141.5	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0;
	61788	 150.0	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 113.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0;
	61788	 150.0	 26.8	 115.9	 -62.3	 1.0	 100.0	 1	 187.0	 113.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.0;
	61788	 171.05	 38.95	 168.6	 -90.7	 1.0	 100.0	 1	 272.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 272.1;
	61789	 142.65	 26.5	 114.8	 -61.8	 1.0	 100.0	 1	 185.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.3;
	61789	 142.65	 26.5	 114.8	 -61.8	 1.0	 100.0	 1	 185.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.3;
	61789	 185.5	 45.95	 198.9	 -107.0	 1.0	 100.0	 1	 321.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 321.0;
	61790	 142.65	 26.5	 114.8	 -61.8	 1.0	 100.0	 1	 185.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.3;
	61790	 142.65	 26.5	 114.8	 -61.8	 1.0	 100.0	 1	 185.3	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.3;
	61790	 185.5	 45.95	 198.9	 -107.0	 1.0	 100.0	 1	 321.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 321.0;
	61791	 128.3	 26.0	 112.5	 -60.5	 1.0	 100.0	 1	 181.6	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.6;
	61791	 128.3	 26.0	 112.5	 -60.5	 1.0	 100.0	 1	 181.6	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.6;
	61791	 128.3	 26.0	 112.5	 -60.5	 1.0	 100.0	 1	 181.6	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.6;
	61791	 131.25	 26.85	 116.2	 -62.5	 1.0	 100.0	 1	 187.5	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 187.5;
	61791	 102.0	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	61791	 102.0	 29.2	 126.4	 -68.0	 1.0	 100.0	 1	 204.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	61792	 135.5	 25.2	 109.1	 -58.7	 1.0	 100.0	 1	 176.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.0;
	61792	 135.8	 25.25	 109.4	 -58.9	 1.0	 100.0	 1	 176.6	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6;
	61792	 183.4	 43.2	 187.0	 -100.6	 1.0	 100.0	 1	 301.8	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 301.8;
	61793	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61793	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61793	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61793	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61793	 158.5	 38.85	 168.0	 -90.3	 1.0	 100.0	 1	 271.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	61793	 158.5	 38.85	 168.0	 -90.3	 1.0	 100.0	 1	 271.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	61794	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61794	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61794	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61794	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61794	 158.5	 38.85	 168.0	 -90.3	 1.0	 100.0	 1	 271.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	61794	 158.5	 38.85	 168.0	 -90.3	 1.0	 100.0	 1	 271.0	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	61795	 64.4	 15.55	 67.4	 -36.3	 1.0	 100.0	 1	 108.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.8;
	61795	 64.4	 15.55	 67.4	 -36.3	 1.0	 100.0	 1	 108.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.8;
	61795	 66.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61795	 106.65	 24.8	 107.4	 -57.8	 1.0	 100.0	 1	 173.3	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	61795	 16.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	61795	 16.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	61796	 33.15	 4.55	 29.2	 -20.1	 1.0	 100.0	 1	 60.3	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.3;
	61796	 33.15	 4.55	 29.2	 -20.1	 1.0	 100.0	 1	 60.3	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.3;
	61796	 29.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	61796	 130.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	61796	 19.25	 4.95	 21.4	 -11.5	 1.0	 100.0	 1	 34.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.5;
	61796	 38.75	 10.55	 45.6	 -24.5	 1.0	 100.0	 1	 73.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.5;
	61796	 106.0	 17.45	 75.6	 -40.7	 1.0	 100.0	 1	 122.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0;
	61797	 78.5	 0.0	 51.6	 -51.6	 1.0	 100.0	 1	 157.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.0;
	61797	 82.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	61797	 82.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	61797	 82.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	61797	 82.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	61797	 82.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	61797	 82.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	61797	 82.5	 0.0	 54.2	 -54.2	 1.0	 100.0	 1	 165.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	61798	 121.9	 22.0	 95.3	 -51.3	 1.0	 100.0	 1	 153.8	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 153.8;
	61798	 121.9	 22.0	 95.3	 -51.3	 1.0	 100.0	 1	 153.8	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 153.8;
	61798	 121.9	 22.0	 95.3	 -51.3	 1.0	 100.0	 1	 153.8	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 153.8;
	61798	 90.55	 19.45	 84.3	 -45.4	 1.0	 100.0	 1	 136.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.1;
	61798	 187.25	 45.05	 194.9	 -104.8	 1.0	 100.0	 1	 314.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 314.5;
	61798	 71.75	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5;
	61798	 71.75	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5;
	61798	 71.75	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5;
	61798	 71.75	 7.8	 50.1	 -34.5	 1.0	 100.0	 1	 103.5	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5;
	61799	 71.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61799	 193.65	 0.0	 113.3	 -113.3	 1.0	 100.0	 1	 312.3	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 312.3;
	61799	 181.95	 21.8	 139.9	 -96.3	 1.0	 100.0	 1	 288.9	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 288.9;
	61799	 254.5	 31.25	 200.5	 -138.0	 1.0	 100.0	 1	 414.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 414.0;
	61801	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	61801	 65.5	 13.05	 56.4	 -30.3	 1.0	 100.0	 1	 91.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.0;
	61801	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	61801	 134.75	 26.4	 114.3	 -61.5	 1.0	 100.0	 1	 184.5	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.5;
	61801	 134.75	 26.4	 114.3	 -61.5	 1.0	 100.0	 1	 184.5	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.5;
	61801	 22.3	 6.35	 27.6	 -14.9	 1.0	 100.0	 1	 44.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.6;
	61801	 100.3	 28.7	 124.3	 -66.9	 1.0	 100.0	 1	 200.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.6;
	61801	 91.0	 9.95	 63.9	 -44.0	 1.0	 100.0	 1	 132.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.0;
	61801	 71.0	 9.95	 63.9	 -44.0	 1.0	 100.0	 1	 132.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.0;
	61801	 71.0	 9.95	 63.9	 -44.0	 1.0	 100.0	 1	 132.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.0;
	61802	 62.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	61803	 113.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 113.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61803	 113.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 113.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61803	 161.87	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 160.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2;
	61803	 76.25	 6.1	 39.0	 -26.8	 1.0	 100.0	 1	 80.5	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.5;
	61803	 66.86	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 62.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2;
	61803	 66.86	 5.4	 34.5	 -23.7	 1.0	 100.0	 1	 71.2	 62.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2;
	61804	 52.08	 0.0	 25.7	 -25.7	 1.0	 100.0	 1	 52.08	 52.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.1;
	61805	 50.4	 0.0	 24.9	 -24.9	 1.0	 100.0	 1	 50.4	 50.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61807	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61809	 32.15	 4.1	 26.3	 -18.1	 1.0	 100.0	 1	 54.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.3;
	61810	 69.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61810	 69.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61810	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	61810	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	61811	 78.125	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 31.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	61811	 78.125	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 31.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	61811	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	61811	 28.55	 7.6	 32.9	 -17.7	 1.0	 100.0	 1	 53.1	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	61811	 59.15	 5.9	 37.9	 -26.1	 1.0	 100.0	 1	 78.3	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.3;
	61813	 10.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	61813	 10.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	61813	 10.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	61813	 10.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	61814	 23.0	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	61815	 6.45	 0.75	 4.8	 -3.3	 1.0	 100.0	 1	 9.9	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	61815	 6.45	 0.75	 4.8	 -3.3	 1.0	 100.0	 1	 9.9	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	61815	 6.45	 0.75	 4.8	 -3.3	 1.0	 100.0	 1	 9.9	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	61815	 89.9	 7.5	 48.3	 -33.3	 1.0	 100.0	 1	 99.8	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.8;
	61818	 14.05	 1.95	 12.6	 -8.7	 1.0	 100.0	 1	 26.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1;
	61819	 12.8	 1.75	 11.4	 -7.9	 1.0	 100.0	 1	 23.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.6;
	61819	 12.8	 1.75	 11.4	 -7.9	 1.0	 100.0	 1	 23.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.6;
	61819	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61819	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61819	 44.35	 6.55	 42.0	 -28.9	 1.0	 100.0	 1	 86.7	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.7;
	61819	 38.7	 5.5	 35.1	 -24.1	 1.0	 100.0	 1	 72.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.4;
	61819	 38.7	 5.5	 35.1	 -24.1	 1.0	 100.0	 1	 72.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.4;
	61819	 13.65	 1.95	 12.3	 -8.4	 1.0	 100.0	 1	 25.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.3;
	61820	 428.65	 41.7	 267.5	 -184.1	 1.0	 100.0	 1	 552.3	 305.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 552.3;
	61821	 288.2	 33.7	 216.2	 -148.8	 1.0	 100.0	 1	 446.4	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.4;
	61821	 288.2	 33.7	 216.2	 -148.8	 1.0	 100.0	 1	 446.4	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.4;
	61821	 332.4	 0.0	 166.1	 -166.1	 1.0	 100.0	 1	 534.8	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 534.8;
	61822	 653.4	 122.7	 531.0	 -285.6	 1.0	 100.0	 1	 856.8	 450.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 856.8;
	61822	 298.0	 29.9	 191.8	 -132.0	 1.0	 100.0	 1	 396.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 396.0;
	61822	 291.25	 54.8	 237.1	 -127.5	 1.0	 100.0	 1	 382.5	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 382.5;
	61823	 225.66	 22.65	 145.5	 -100.2	 1.0	 100.0	 1	 225.66	 225.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.5;
	61824	 66.65	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3;
	61824	 66.65	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3;
	61824	 66.65	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3;
	61824	 66.65	 12.75	 55.3	 -29.8	 1.0	 100.0	 1	 89.3	 44.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.3;
	61824	 107.3	 21.4	 92.7	 -49.9	 1.0	 100.0	 1	 149.6	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.6;
	61824	 214.3	 42.05	 182.0	 -97.9	 1.0	 100.0	 1	 293.6	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 293.6;
	61825	 153.5	 15.65	 100.3	 -69.0	 1.0	 100.0	 1	 207.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 207.0;
	61825	 28.9	 5.4	 23.4	 -12.6	 1.0	 100.0	 1	 37.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.8;
	61825	 28.9	 5.4	 23.4	 -12.6	 1.0	 100.0	 1	 37.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.8;
	61826	 160.8	 15.15	 97.3	 -67.0	 1.0	 100.0	 1	 160.8	 160.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.0;
	61827	 151.78	 15.05	 96.6	 -66.5	 1.0	 100.0	 1	 151.78	 151.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.5;
	61828	 134.45	 123.3	 123.3	 123.3	 1.0	 100.0	 1	 198.9	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	61828	 133.95	 123.3	 123.3	 123.3	 1.0	 100.0	 1	 198.9	 69.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	61829	 138.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	61829	 138.5	 28.2	 122.1	 -65.7	 1.0	 100.0	 1	 197.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	61830	 153.35	 27.45	 118.8	 -63.9	 1.0	 100.0	 1	 191.7	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.7;
	61830	 38.65	 4.45	 28.7	 -19.8	 1.0	 100.0	 1	 59.3	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.3;
	61831	 142.5	 0.0	 69.0	 -69.0	 1.0	 100.0	 1	 190.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.0;
	61831	 200.2	 20.8	 133.4	 -91.8	 1.0	 100.0	 1	 275.4	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 275.4;
	61832	 120.05	 25.05	 108.5	 -58.4	 1.0	 100.0	 1	 175.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.1;
	61832	 120.05	 25.05	 108.5	 -58.4	 1.0	 100.0	 1	 175.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.1;
	61832	 120.05	 25.05	 108.5	 -58.4	 1.0	 100.0	 1	 175.1	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.1;
	61832	 97.65	 20.1	 87.0	 -46.8	 1.0	 100.0	 1	 140.3	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.3;
	61832	 96.15	 20.1	 87.0	 -46.8	 1.0	 100.0	 1	 140.3	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.3;
	61832	 190.8	 49.05	 212.3	 -114.2	 1.0	 100.0	 1	 342.6	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 342.6;
	61833	 128.55	 25.05	 108.5	 -58.4	 1.0	 100.0	 1	 175.1	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.1;
	61833	 128.55	 25.05	 108.5	 -58.4	 1.0	 100.0	 1	 175.1	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.1;
	61833	 199.45	 48.0	 207.6	 -111.6	 1.0	 100.0	 1	 334.9	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 334.9;
	61834	 103.68	 0.0	 71.4	 -71.4	 1.0	 100.0	 1	 103.68	 103.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 162.0;
	61837	 115.0	 11.3	 72.6	 -50.0	 1.0	 100.0	 1	 150.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	61837	 115.0	 11.3	 72.6	 -50.0	 1.0	 100.0	 1	 150.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	61838	 137.25	 24.45	 105.7	 -56.8	 1.0	 100.0	 1	 170.5	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.5;
	61838	 86.875	 23.4	 88.5	 -41.7	 1.0	 100.0	 1	 125.0	 48.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	61838	 86.875	 23.4	 88.5	 -41.7	 1.0	 100.0	 1	 125.0	 48.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	61838	 297.9	 54.55	 236.0	 -126.9	 1.0	 100.0	 1	 380.8	 215.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 380.8;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61839	 6.3	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61840	 4.65	 1.19	 4.28	 -1.9	 1.0	 100.0	 1	 5.7	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	61841	 20.45	 0.0	 12.9	 -12.9	 1.0	 100.0	 1	 28.45	 12.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	61841	 20.45	 0.0	 12.9	 -12.9	 1.0	 100.0	 1	 28.45	 12.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	61841	 20.45	 0.0	 12.9	 -12.9	 1.0	 100.0	 1	 28.45	 12.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	61841	 20.45	 0.0	 12.9	 -12.9	 1.0	 100.0	 1	 28.45	 12.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	61842	 50.0	 0.0	 32.9	 -32.9	 1.0	 100.0	 1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	61842	 50.0	 0.0	 32.9	 -32.9	 1.0	 100.0	 1	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	61843	 43.3	 6.5	 41.9	 -28.9	 1.0	 100.0	 1	 86.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.6;
	61843	 43.3	 6.5	 41.9	 -28.9	 1.0	 100.0	 1	 86.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.6;
	61844	 31.5	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0;
	61844	 72.6	 12.05	 52.1	 -28.0	 1.0	 100.0	 1	 84.0	 61.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0;
	61845	 58.55	 11.05	 47.8	 -25.7	 1.0	 100.0	 1	 77.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	61845	 58.55	 11.05	 47.8	 -25.7	 1.0	 100.0	 1	 77.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	61846	 58.55	 11.05	 47.8	 -25.7	 1.0	 100.0	 1	 77.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	61846	 58.55	 11.05	 47.8	 -25.7	 1.0	 100.0	 1	 77.1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	61847	 32.46	 0.0	 29.6	 -29.6	 1.0	 100.0	 1	 32.46	 32.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	61848	 33.4	 32.1	 32.1	 32.1	 1.0	 100.0	 1	 51.8	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.8;
	61848	 43.05	 44.1	 44.1	 44.1	 1.0	 100.0	 1	 71.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1;
	61848	 43.05	 44.1	 44.1	 44.1	 1.0	 100.0	 1	 71.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1;
	61849	 43.05	 10.2	 44.1	 -23.7	 1.0	 100.0	 1	 71.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1;
	61849	 43.05	 10.2	 44.1	 -23.7	 1.0	 100.0	 1	 71.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1;
	61850	 44.85	 4.85	 31.3	 -21.6	 1.0	 100.0	 1	 64.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.7;
	61850	 44.85	 4.85	 31.3	 -21.6	 1.0	 100.0	 1	 64.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.7;
	61851	 48.0	 0.0	 23.7	 -23.7	 1.0	 100.0	 1	 48.0	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	61852	 12.6	 2.835	 12.3	 -6.63	 1.0	 100.0	 1	 19.87	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.87;
	61852	 12.6	 2.835	 12.3	 -6.63	 1.0	 100.0	 1	 19.87	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.87;
	61852	 12.6	 2.835	 12.3	 -6.63	 1.0	 100.0	 1	 19.87	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.87;
	61853	 41.1	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 52.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2;
	61853	 41.1	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 52.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2;
	61853	 44.25	 8.4	 36.3	 -19.5	 1.0	 100.0	 1	 58.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5;
	61853	 44.25	 8.4	 36.3	 -19.5	 1.0	 100.0	 1	 58.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5;
	61853	 44.25	 8.4	 36.3	 -19.5	 1.0	 100.0	 1	 58.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5;
	61853	 44.25	 8.4	 36.3	 -19.5	 1.0	 100.0	 1	 58.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5;
	61853	 44.25	 8.4	 36.3	 -19.5	 1.0	 100.0	 1	 58.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5;
	61854	 40.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.8	 40.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0;
	61855	 30.2	 3.8	 24.4	 -16.8	 1.0	 100.0	 1	 50.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	61855	 30.2	 3.8	 24.4	 -16.8	 1.0	 100.0	 1	 50.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	61856	 95.0	 9.95	 63.9	 -44.0	 1.0	 100.0	 1	 132.0	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.0;
	61856	 39.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	61856	 56.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	61857	 7.5	 1.135	 7.27	 -5.0	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61857	 7.5	 1.135	 7.27	 -5.0	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61857	 7.5	 1.135	 7.27	 -5.0	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61858	 21.6	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2;
	61858	 21.6	 3.25	 20.9	 -14.4	 1.0	 100.0	 1	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2;
	61859	 21.5	 15.6	 15.6	 15.6	 1.0	 100.0	 1	 43.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0;
	61859	 21.5	 15.6	 15.6	 15.6	 1.0	 100.0	 1	 43.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0;
	61860	 49.5	 46.5	 46.5	 46.5	 1.0	 100.0	 1	 75.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	61860	 25.83	 24.9	 24.9	 24.9	 1.0	 100.0	 1	 40.2	 11.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2;
	61861	 27.0	 24.3	 24.3	 24.3	 1.0	 100.0	 1	 40.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	61861	 75.94	 68.2	 68.2	 68.2	 1.0	 100.0	 1	 112.5	 39.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	61862	 19.1	 0.0	 12.6	 -12.6	 1.0	 100.0	 1	 38.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	61863	 26.5	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	61863	 26.5	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	61863	 26.5	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	61863	 26.5	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	61863	 26.5	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	61863	 26.5	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	61864	 25.0	 22.9	 22.9	 22.9	 1.0	 100.0	 1	 37.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0;
	61865	 19.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 33.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	61866	 23.76	 0.0	 11.7	 -11.7	 1.0	 100.0	 1	 23.76	 23.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7;
	61867	 14.0	 13.6	 13.6	 13.6	 1.0	 100.0	 1	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	61869	 15.8	 12.9	 12.9	 12.9	 1.0	 100.0	 1	 26.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6;
	61869	 15.8	 12.9	 12.9	 12.9	 1.0	 100.0	 1	 26.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6;
	61870	 15.8	 12.9	 12.9	 12.9	 1.0	 100.0	 1	 26.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6;
	61871	 10.6	 1.375	 7.15	 -4.4	 1.0	 100.0	 1	 10.6	 10.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25;
	61871	 10.6	 1.375	 7.15	 -4.4	 1.0	 100.0	 1	 10.6	 10.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.25;
	61872	 6.5	 0.975	 6.3	 -4.35	 1.0	 100.0	 1	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	61872	 6.5	 0.975	 6.3	 -4.35	 1.0	 100.0	 1	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	61873	 17.5	 15.5	 15.5	 15.5	 1.0	 100.0	 1	 25.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	61875	 14.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	61876	 23.4	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8;
	61876	 23.4	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8;
	61876	 34.5	 5.3	 22.9	 -12.3	 1.0	 100.0	 1	 37.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0;
	61876	 21.815	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 19.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8;
	61876	 21.815	 3.4	 14.7	 -7.9	 1.0	 100.0	 1	 23.8	 19.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8;
	61876	 26.0	 5.3	 22.9	 -12.3	 1.0	 100.0	 1	 37.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0;
	61876	 24.0	 7.9	 28.5	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	61876	 60.0	 18.75	 67.5	 -30.0	 1.0	 100.0	 1	 90.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	61877	 8.625	 1.6	 6.95	 -3.75	 1.0	 100.0	 1	 11.25	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25;
	61877	 8.625	 1.6	 6.95	 -3.75	 1.0	 100.0	 1	 11.25	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.25;
	61878	 18.0	 0.0	 8.9	 -8.9	 1.0	 100.0	 1	 18.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	61878	 121.44	 0.0	 66.9	 -66.9	 1.0	 100.0	 1	 121.44	 121.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 151.8;
	61879	 11.5	 15.0	 15.0	 15.0	 1.0	 100.0	 1	 20.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	61880	 259.5	 27.85	 178.7	 -123.0	 1.0	 100.0	 1	 369.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 369.0;
	61880	 259.5	 27.85	 178.7	 -123.0	 1.0	 100.0	 1	 369.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 369.0;
	61880	 352.5	 41.9	 268.8	 -185.0	 1.0	 100.0	 1	 555.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 555.0;
	61880	 352.5	 41.9	 268.8	 -185.0	 1.0	 100.0	 1	 555.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 555.0;
	61881	 173.5	 19.4	 124.5	 -85.7	 1.0	 100.0	 1	 257.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 257.0;
	61882	 163.2	 15.4	 98.8	 -68.0	 1.0	 100.0	 1	 163.2	 163.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	61883	 159.3	 37.9	 164.0	 -88.2	 1.0	 100.0	 1	 264.6	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 264.6;
	61883	 153.45	 14.9	 95.4	 -65.6	 1.0	 100.0	 1	 196.9	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.9;
	61883	 153.45	 14.9	 95.4	 -65.6	 1.0	 100.0	 1	 196.9	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.9;
	61884	 132.05	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 190.0	 74.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.0;
	61884	 132.05	 14.35	 92.0	 -63.3	 1.0	 100.0	 1	 190.0	 74.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.0;
	61884	 591.05	 61.75	 396.2	 -272.7	 1.0	 100.0	 1	 818.1	 364.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 818.1;
	61884	 591.05	 61.75	 396.2	 -272.7	 1.0	 100.0	 1	 818.1	 364.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 818.1;
	61884	 176.115	 19.1	 122.7	 -84.5	 1.0	 100.0	 1	 253.4	 98.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 253.4;
	61885	 128.5	 13.35	 85.7	 -59.0	 1.0	 100.0	 1	 177.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 177.0;
	61885	 80.0	 15.75	 68.2	 -36.7	 1.0	 100.0	 1	 110.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0;
	61886	 152.5	 25.1	 108.5	 -58.3	 1.0	 100.0	 1	 175.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0;
	61886	 152.5	 25.1	 108.5	 -58.3	 1.0	 100.0	 1	 175.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 175.0;
	61886	 215.0	 42.95	 185.9	 -100.0	 1.0	 100.0	 1	 300.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	61887	 119.75	 0.0	 52.4	 -52.4	 1.0	 100.0	 1	 159.5	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5;
	61888	 115.0	 93.0	 93.0	 93.0	 1.0	 100.0	 1	 150.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	61889	 106.95	 9.6	 61.5	 -42.3	 1.0	 100.0	 1	 126.9	 87.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.9;
	61889	 106.95	 9.6	 61.5	 -42.3	 1.0	 100.0	 1	 126.9	 87.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.9;
	61890	 96.0	 0.0	 52.9	 -52.9	 1.0	 100.0	 1	 96.0	 96.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	61891	 81.92	 0.0	 45.2	 -45.2	 1.0	 100.0	 1	 81.92	 81.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.4;
	61893	 72.0	 0.0	 39.7	 -39.7	 1.0	 100.0	 1	 72.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	61894	 74.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61894	 73.45	 6.55	 42.1	 -29.0	 1.0	 100.0	 1	 86.9	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.9;
	61895	 21.0	 2.85	 18.2	 -12.5	 1.0	 100.0	 1	 37.5	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	61895	 30.25	 5.25	 28.5	 -18.0	 1.0	 100.0	 1	 54.0	 6.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	61896	 106.25	 12.55	 80.6	 -55.5	 1.0	 100.0	 1	 166.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.5;
	61896	 35.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	61896	 35.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	61897	 35.75	 6.65	 28.8	 -15.5	 1.0	 100.0	 1	 46.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	61897	 35.75	 6.65	 28.8	 -15.5	 1.0	 100.0	 1	 46.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	61897	 35.75	 6.65	 28.8	 -15.5	 1.0	 100.0	 1	 46.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	61897	 35.75	 6.65	 28.8	 -15.5	 1.0	 100.0	 1	 46.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61898	 1.765	 0.63	 2.27	 -1.01	 1.0	 100.0	 1	 3.03	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.03;
	61899	 15.0	 7.27	 7.27	 7.27	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61899	 15.0	 7.27	 7.27	 7.27	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61899	 15.0	 7.27	 7.27	 7.27	 1.0	 100.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61900	 28.0	 27.3	 27.3	 27.3	 1.0	 100.0	 1	 44.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	61900	 28.0	 27.3	 27.3	 27.3	 1.0	 100.0	 1	 44.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	61900	 41.5	 40.9	 40.9	 40.9	 1.0	 100.0	 1	 66.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0;
	61901	 13.5	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	61901	 26.0	 8.35	 30.0	 -13.3	 1.0	 100.0	 1	 40.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	61902	 15.3	 2.3	 14.8	 -10.2	 1.0	 100.0	 1	 30.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61903	 28.2	 2.3	 14.7	 -10.1	 1.0	 100.0	 1	 30.4	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	61903	 28.2	 2.3	 14.7	 -10.1	 1.0	 100.0	 1	 30.4	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	61903	 28.2	 2.3	 14.7	 -10.1	 1.0	 100.0	 1	 30.4	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	61903	 28.2	 2.3	 14.7	 -10.1	 1.0	 100.0	 1	 30.4	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	61904	 10.5	 7.25	 7.25	 7.25	 1.0	 100.0	 1	 15.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61904	 10.5	 7.25	 7.25	 7.25	 1.0	 100.0	 1	 15.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61905	 4.65	 0.0	 3.67	 -3.67	 1.0	 100.0	 1	 9.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3;
	61905	 4.65	 0.0	 3.67	 -3.67	 1.0	 100.0	 1	 9.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3;
	61905	 4.65	 0.0	 3.67	 -3.67	 1.0	 100.0	 1	 9.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3;
	61906	 8.19	 1.55	 7.35	 -4.25	 1.0	 100.0	 1	 12.75	 3.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.75;
	61906	 8.19	 1.55	 7.35	 -4.25	 1.0	 100.0	 1	 12.75	 3.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.75;
	61906	 9.15	 2.575	 9.25	 -4.1	 1.0	 100.0	 1	 12.3	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	61906	 9.15	 2.575	 9.25	 -4.1	 1.0	 100.0	 1	 12.3	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	61907	 20.0	 9.7	 9.7	 9.7	 1.0	 100.0	 1	 20.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	61908	 16.0	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	61908	 48.0	 0.0	 23.7	 -23.7	 1.0	 100.0	 1	 48.0	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	61909	 582.08	 66.35	 405.4	 -272.7	 1.0	 100.0	 1	 818.1	 346.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 818.1;
	61909	 582.08	 66.35	 405.4	 -272.7	 1.0	 100.0	 1	 818.1	 346.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 818.1;
	61910	 20.4	 13.5	 13.5	 13.5	 1.0	 100.0	 1	 27.8	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.8;
	61910	 80.48	 57.93	 57.93	 57.93	 1.0	 100.0	 1	 119.63	 41.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.63;
	61910	 20.4	 13.5	 13.5	 13.5	 1.0	 100.0	 1	 27.8	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.8;
	61910	 35.4	 24.1	 24.1	 24.1	 1.0	 100.0	 1	 49.8	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	61910	 39.25	 29.3	 29.3	 29.3	 1.0	 100.0	 1	 60.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61910	 39.25	 29.3	 29.3	 29.3	 1.0	 100.0	 1	 60.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61910	 39.25	 29.3	 29.3	 29.3	 1.0	 100.0	 1	 60.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61910	 39.25	 29.3	 29.3	 29.3	 1.0	 100.0	 1	 60.5	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61910	 80.48	 57.93	 57.93	 57.93	 1.0	 100.0	 1	 119.63	 41.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.63;
	61910	 80.48	 57.93	 57.93	 57.93	 1.0	 100.0	 1	 119.63	 41.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.63;
	61911	 183.6	 20.95	 134.3	 -92.4	 1.0	 100.0	 1	 277.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 277.2;
	61911	 189.9	 21.9	 140.4	 -96.6	 1.0	 100.0	 1	 289.8	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.8;
	61912	 161.0	 18.25	 117.2	 -80.7	 1.0	 100.0	 1	 242.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.0;
	61913	 187.4	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	61913	 187.4	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	61913	 145.75	 28.85	 124.9	 -67.2	 1.0	 100.0	 1	 201.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.5;
	61913	 145.75	 28.85	 124.9	 -67.2	 1.0	 100.0	 1	 201.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.5;
	61913	 145.75	 28.85	 124.9	 -67.2	 1.0	 100.0	 1	 201.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.5;
	61913	 145.75	 28.85	 124.9	 -67.2	 1.0	 100.0	 1	 201.5	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.5;
	61914	 157.65	 38.7	 167.5	 -90.1	 1.0	 100.0	 1	 270.3	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.3;
	61914	 143.6	 28.25	 122.2	 -65.7	 1.0	 100.0	 1	 197.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.2;
	61914	 143.6	 28.25	 122.2	 -65.7	 1.0	 100.0	 1	 197.2	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.2;
	61915	 139.0	 25.5	 110.3	 -59.3	 1.0	 100.0	 1	 178.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.0;
	61915	 139.0	 25.5	 110.3	 -59.3	 1.0	 100.0	 1	 178.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.0;
	61915	 221.2	 47.6	 206.0	 -110.8	 1.0	 100.0	 1	 332.4	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 332.4;
	61916	 132.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61916	 132.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	61916	 153.8	 19.05	 122.3	 -84.2	 1.0	 100.0	 1	 252.6	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 252.6;
	61917	 130.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	61917	 130.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	61917	 153.0	 28.1	 121.5	 -65.3	 1.0	 100.0	 1	 196.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0;
	61918	 30.75	 0.0	 12.5	 -12.5	 1.0	 100.0	 1	 61.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 63.5	 0.0	 31.8	 -31.8	 1.0	 100.0	 1	 127.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0;
	61918	 63.5	 0.0	 31.8	 -31.8	 1.0	 100.0	 1	 127.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.0;
	61918	 65.0	 27.1	 97.5	 -43.3	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 34.25	 0.0	 13.9	 -13.9	 1.0	 100.0	 1	 68.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.5;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61918	 65.0	 0.0	 26.4	 -26.4	 1.0	 100.0	 1	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 0.0	 0.0	 6.3	 -2.8	 1.0	 100.0	 0	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 0.0	 0.0	 6.3	 -2.8	 1.0	 100.0	 0	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 0.0	 0.0	 6.3	 -2.8	 1.0	 100.0	 0	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 0.0	 0.0	 6.3	 -2.8	 1.0	 100.0	 0	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 0.0	 0.0	 6.3	 -2.8	 1.0	 100.0	 0	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61919	 7.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	61920	 66.5	 16.5	 71.3	 -38.3	 1.0	 100.0	 1	 115.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	61920	 66.5	 16.5	 71.3	 -38.3	 1.0	 100.0	 1	 115.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	61922	 54.45	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 38.7	 5.5	 35.1	 -24.1	 1.0	 100.0	 1	 72.4	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.4;
	61922	 68.75	 7.0	 44.8	 -30.8	 1.0	 100.0	 1	 92.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.5;
	61922	 68.75	 7.0	 44.8	 -30.8	 1.0	 100.0	 1	 92.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.5;
	61922	 68.75	 7.0	 44.8	 -30.8	 1.0	 100.0	 1	 92.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.5;
	61922	 68.75	 7.0	 44.8	 -30.8	 1.0	 100.0	 1	 92.5	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.5;
	61922	 68.2	 7.9	 50.6	 -34.8	 1.0	 100.0	 1	 104.4	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.4;
	61922	 68.2	 7.9	 50.6	 -34.8	 1.0	 100.0	 1	 104.4	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.4;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61922	 55.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61923	 52.43	 46.9	 46.9	 46.9	 1.0	 100.0	 1	 81.6	 23.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6;
	61923	 63.75	 48.2	 48.2	 48.2	 1.0	 100.0	 1	 85.0	 42.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	61924	 65.75	 7.7	 49.2	 -33.8	 1.0	 100.0	 1	 101.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.5;
	61924	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	61925	 40.73	 46.9	 46.9	 46.9	 1.0	 100.0	 1	 75.7	 5.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61926	 72.0	 35.8	 35.8	 35.8	 1.0	 100.0	 1	 74.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0;
	61926	 72.0	 35.8	 35.8	 35.8	 1.0	 100.0	 1	 74.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0;
	61926	 72.0	 35.8	 35.8	 35.8	 1.0	 100.0	 1	 74.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0;
	61928	 32.75	 16.9	 16.9	 16.9	 1.0	 100.0	 1	 60.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	61929	 4.8	 4.64	 4.64	 4.64	 1.0	 100.0	 1	 9.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61929	 4.8	 4.64	 4.64	 4.64	 1.0	 100.0	 1	 9.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61929	 4.8	 4.64	 4.64	 4.64	 1.0	 100.0	 1	 9.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61929	 4.8	 4.64	 4.64	 4.64	 1.0	 100.0	 1	 9.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61929	 4.8	 4.64	 4.64	 4.64	 1.0	 100.0	 1	 9.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	61931	 39.05	 6.5	 28.0	 -15.0	 1.0	 100.0	 1	 45.1	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.1;
	61931	 39.05	 6.5	 28.0	 -15.0	 1.0	 100.0	 1	 45.1	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.1;
	61931	 29.5	 5.3	 22.9	 -12.3	 1.0	 100.0	 1	 37.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0;
	61932	 7.46	 4.43	 4.43	 4.43	 1.0	 100.0	 1	 8.22	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.23;
	61932	 7.46	 4.43	 4.43	 4.43	 1.0	 100.0	 1	 8.22	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.23;
	61932	 7.46	 4.43	 4.43	 4.43	 1.0	 100.0	 1	 8.22	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.23;
	61932	 7.46	 4.43	 4.43	 4.43	 1.0	 100.0	 1	 8.22	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.23;
	61933	 11.4	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 7.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61933	 11.4	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 7.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61934	 11.45	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 7.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61934	 11.45	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 7.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61936	 10.875	 9.75	 9.75	 9.75	 1.0	 100.0	 1	 13.0	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	61936	 10.875	 9.75	 9.75	 9.75	 1.0	 100.0	 1	 13.0	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	61937	 75.9	 9.05	 58.0	 -39.9	 1.0	 100.0	 1	 119.8	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.8;
	61937	 181.0	 44.7	 193.4	 -104.0	 1.0	 100.0	 1	 312.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 312.0;
	61937	 9.0	 1.725	 7.6	 -4.15	 1.0	 100.0	 1	 12.5	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	61937	 9.0	 1.725	 7.6	 -4.15	 1.0	 100.0	 1	 12.5	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	61937	 127.8	 22.25	 96.4	 -51.9	 1.0	 100.0	 1	 155.6	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.6;
	61937	 127.8	 22.25	 96.4	 -51.9	 1.0	 100.0	 1	 155.6	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.6;
	61937	 34.35	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 18.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	61937	 49.7	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 24.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	61937	 52.35	 10.0	 43.2	 -23.2	 1.0	 100.0	 1	 69.7	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.7;
	61937	 33.6	 7.2	 31.1	 -16.7	 1.0	 100.0	 1	 50.2	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.2;
	61938	 5.95	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	61938	 5.95	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	61939	 9.0	 2.45	 8.8	 -3.9	 1.0	 100.0	 1	 11.75	 6.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.75;
	61939	 9.0	 2.45	 8.8	 -3.9	 1.0	 100.0	 1	 11.75	 6.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.75;
	61941	 20.6	 1.7	 10.8	 -7.4	 1.0	 100.0	 1	 22.2	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2;
	61941	 20.6	 1.7	 10.8	 -7.4	 1.0	 100.0	 1	 22.2	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2;
	61941	 20.6	 1.7	 10.8	 -7.4	 1.0	 100.0	 1	 22.2	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2;
	61941	 17.35	 2.25	 14.4	 -9.9	 1.0	 100.0	 1	 29.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7;
	61942	 11.15	 7.0	 7.0	 7.0	 1.0	 100.0	 1	 21.3	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3;
	61942	 11.15	 7.0	 7.0	 7.0	 1.0	 100.0	 1	 21.3	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3;
	61942	 11.15	 7.0	 7.0	 7.0	 1.0	 100.0	 1	 21.3	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3;
	61943	 6.925	 2.1	 7.55	 -3.35	 1.0	 100.0	 1	 10.05	 3.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.05;
	61943	 6.925	 2.1	 7.55	 -3.35	 1.0	 100.0	 1	 10.05	 3.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.05;
	61944	 570.0	 61.9	 397.1	 -273.3	 1.0	 100.0	 1	 820.0	 320.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 820.0;
	61944	 570.0	 61.9	 397.1	 -273.3	 1.0	 100.0	 1	 820.0	 320.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 820.0;
	61945	 373.6	 0.0	 191.3	 -191.3	 1.0	 100.0	 1	 527.2	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 527.2;
	61945	 347.0	 0.0	 207.5	 -207.5	 1.0	 100.0	 1	 525.0	 169.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 525.0;
	61945	 317.0	 0.0	 207.5	 -207.5	 1.0	 100.0	 1	 525.0	 109.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 525.0;
	61946	 354.75	 0.0	 50.1	 -50.1	 1.0	 100.0	 1	 499.5	 210.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 499.5;
	61947	 330.65	 0.0	 230.6	 -230.6	 1.0	 100.0	 1	 541.3	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 541.3;
	61947	 308.0	 37.45	 240.2	 -165.3	 1.0	 100.0	 1	 496.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 496.0;
	61948	 130.24	 15.4	 98.6	 -67.8	 1.0	 100.0	 1	 130.24	 130.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.5;
	61949	 195.5	 18.95	 121.6	 -83.7	 1.0	 100.0	 1	 251.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 251.0;
	61949	 161.5	 15.3	 98.3	 -67.7	 1.0	 100.0	 1	 203.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.0;
	61949	 161.5	 15.3	 98.3	 -67.7	 1.0	 100.0	 1	 203.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.0;
	61951	 79.3	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	61951	 50.0	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	61952	 79.3	 19.15	 82.8	 -44.5	 1.0	 100.0	 1	 133.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.6;
	61952	 47.75	 10.1	 43.7	 -23.5	 1.0	 100.0	 1	 70.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.5;
	61952	 47.5	 15.65	 56.3	 -25.0	 1.0	 100.0	 1	 75.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	61952	 40.5	 10.15	 44.0	 -23.7	 1.0	 100.0	 1	 71.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0;
	61952	 40.5	 10.15	 44.0	 -23.7	 1.0	 100.0	 1	 71.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0;
	61952	 40.5	 10.15	 44.0	 -23.7	 1.0	 100.0	 1	 71.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0;
	61953	 25.3	 3.8	 24.5	 -16.9	 1.0	 100.0	 1	 50.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6;
	61953	 25.3	 3.8	 24.5	 -16.9	 1.0	 100.0	 1	 50.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6;
	61953	 25.3	 3.8	 24.5	 -16.9	 1.0	 100.0	 1	 50.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6;
	61954	 9.0	 2.285	 9.9	 -5.33	 1.0	 100.0	 1	 16.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	61954	 9.0	 2.285	 9.9	 -5.33	 1.0	 100.0	 1	 16.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	61954	 9.0	 2.285	 9.9	 -5.33	 1.0	 100.0	 1	 16.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	61956	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 14.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	61956	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 14.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	61956	 10.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 14.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	61958	 68.5	 11.75	 50.8	 -27.3	 1.0	 100.0	 1	 82.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0;
	61958	 21.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	61958	 21.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	61958	 38.5	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	61958	 17.45	 4.55	 19.7	 -10.6	 1.0	 100.0	 1	 31.8	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.8;
	61960	 7.5	 11.25	 11.25	 11.25	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61960	 7.5	 11.25	 11.25	 11.25	 1.0	 100.0	 1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	61961	 5.625	 1.35	 4.87	 -2.17	 1.0	 100.0	 1	 6.5	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5;
	61961	 5.625	 1.35	 4.87	 -2.17	 1.0	 100.0	 1	 6.5	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5;
	61961	 5.625	 1.35	 4.87	 -2.17	 1.0	 100.0	 1	 6.5	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5;
	61961	 5.625	 1.35	 4.87	 -2.17	 1.0	 100.0	 1	 6.5	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.5;
	61962	 9.75	 2.625	 9.4	 -4.15	 1.0	 100.0	 1	 12.5	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	61962	 9.75	 2.625	 9.4	 -4.15	 1.0	 100.0	 1	 12.5	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	66499	 579.5	 87.5	 561.3	 -386.3	 1.0	 100.0	 1	 1159.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	66499	 582.0	 87.9	 563.8	 -388.0	 1.0	 100.0	 1	 1164.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	66500	 822.71	 529.8	 529.8	 529.8	 1.0	 100.0	 1	 1127.0	 518.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	66500	 822.71	 0.0	 529.8	 -529.8	 1.0	 100.0	 1	 1127.0	 518.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	66501	 453.0	 115.4	 499.5	 -268.7	 1.0	 100.0	 1	 806.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 806.0;
	66501	 428.0	 115.4	 499.5	 -268.7	 1.0	 100.0	 1	 806.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 806.0;
	66502	 289.75	 30.9	 198.3	 -136.5	 1.0	 100.0	 1	 409.5	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.5;
	66502	 289.75	 30.9	 198.3	 -136.5	 1.0	 100.0	 1	 409.5	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.5;
	66503	 210.015	 33.6	 186.9	 -119.7	 1.0	 100.0	 1	 359.0	 61.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 359.0;
	66503	 210.015	 33.6	 186.9	 -119.7	 1.0	 100.0	 1	 359.0	 61.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 359.0;
	66504	 217.0	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0;
	66504	 217.0	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0;
	66504	 217.0	 26.5	 170.0	 -117.0	 1.0	 100.0	 1	 351.0	 83.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0;
	66505	 181.0	 165.6	 165.6	 165.6	 1.0	 100.0	 1	 342.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 342.0;
	66505	 181.0	 178.0	 178.0	 178.0	 1.0	 100.0	 1	 342.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 342.0;
	66506	 179.0	 161.3	 161.3	 161.3	 1.0	 100.0	 1	 333.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 333.0;
	66506	 179.0	 161.3	 161.3	 161.3	 1.0	 100.0	 1	 333.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 333.0;
	66507	 266.0	 161.0	 161.0	 161.0	 1.0	 100.0	 1	 266.0	 266.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 332.5;
	66508	 418.05	 56.7	 363.8	 -250.4	 1.0	 100.0	 1	 751.1	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 751.1;
	66508	 185.7	 46.75	 202.3	 -108.8	 1.0	 100.0	 1	 326.4	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 326.4;
	66508	 185.7	 46.75	 202.3	 -108.8	 1.0	 100.0	 1	 326.4	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 326.4;
	66509	 220.0	 0.0	 108.9	 -108.9	 1.0	 100.0	 1	 300.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	66509	 220.0	 0.0	 108.9	 -108.9	 1.0	 100.0	 1	 300.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	66509	 220.0	 0.0	 108.9	 -108.9	 1.0	 100.0	 1	 300.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	66509	 220.0	 0.0	 108.9	 -108.9	 1.0	 100.0	 1	 300.0	 140.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	66510	 183.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 247.4	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.4;
	66511	 377.0	 53.0	 340.0	 -234.0	 1.0	 100.0	 1	 702.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 702.0;
	66511	 377.0	 53.0	 340.0	 -234.0	 1.0	 100.0	 1	 702.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 702.0;
	66511	 156.5	 33.35	 144.4	 -77.7	 1.0	 100.0	 1	 233.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	66511	 156.5	 33.35	 144.4	 -77.7	 1.0	 100.0	 1	 233.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	66511	 156.5	 33.35	 144.4	 -77.7	 1.0	 100.0	 1	 233.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	66511	 156.5	 33.35	 144.4	 -77.7	 1.0	 100.0	 1	 233.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	66511	 146.5	 33.35	 144.4	 -77.7	 1.0	 100.0	 1	 233.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	66511	 146.5	 33.35	 144.4	 -77.7	 1.0	 100.0	 1	 233.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	66512	 140.625	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 225.0	 56.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.0;
	66512	 141.875	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 227.0	 56.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 227.0;
	66512	 119.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 218.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	66512	 119.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 218.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	66513	 161.0	 0.0	 69.7	 -69.7	 1.0	 100.0	 1	 212.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	66513	 161.0	 0.0	 69.7	 -69.7	 1.0	 100.0	 1	 212.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	66513	 133.5	 0.0	 69.7	 -69.7	 1.0	 100.0	 1	 212.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	66514	 193.0	 43.8	 189.6	 -102.0	 1.0	 100.0	 1	 306.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 306.0;
	66514	 168.5	 30.35	 131.4	 -70.7	 1.0	 100.0	 1	 212.0	 125.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	66514	 163.5	 30.35	 131.4	 -70.7	 1.0	 100.0	 1	 212.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	66514	 164.25	 30.55	 132.3	 -71.2	 1.0	 100.0	 1	 213.5	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.5;
	66515	 139.1	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2;
	66515	 139.1	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2;
	66515	 134.15	 30.55	 132.2	 -71.1	 1.0	 100.0	 1	 213.3	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.3;
	66516	 157.5	 123.9	 123.9	 123.9	 1.0	 100.0	 1	 200.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	66516	 157.5	 123.9	 123.9	 123.9	 1.0	 100.0	 1	 200.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	66516	 147.5	 145.6	 145.6	 145.6	 1.0	 100.0	 1	 235.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.0;
	66517	 109.9	 15.1	 96.8	 -66.6	 1.0	 100.0	 1	 199.8	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.8;
	66518	 132.5	 17.0	 109.0	 -75.0	 1.0	 100.0	 1	 225.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.0;
	66518	 144.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0;
	66518	 144.5	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 199.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0;
	66519	 180.25	 40.15	 173.8	 -93.5	 1.0	 100.0	 1	 280.5	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 280.5;
	66519	 151.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	66519	 151.95	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	66520	 170.35	 140.8	 140.8	 140.8	 1.0	 100.0	 1	 290.7	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 290.7;
	66520	 141.95	 123.3	 123.3	 123.3	 1.0	 100.0	 1	 198.9	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	66520	 141.95	 123.3	 123.3	 123.3	 1.0	 100.0	 1	 198.9	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	66521	 124.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7;
	66521	 151.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 104.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	66522	 140.0	 142.5	 142.5	 142.5	 1.0	 100.0	 1	 230.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0;
	66522	 140.0	 142.5	 142.5	 142.5	 1.0	 100.0	 1	 230.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0;
	66522	 143.9	 113.3	 113.3	 113.3	 1.0	 100.0	 1	 182.8	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.8;
	66522	 143.9	 113.3	 113.3	 113.3	 1.0	 100.0	 1	 182.8	 105.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.8;
	66522	 168.65	 163.8	 163.8	 163.8	 1.0	 100.0	 1	 264.3	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 264.3;
	66522	 200.655	 178.6	 178.6	 178.6	 1.0	 100.0	 1	 343.0	 58.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 343.0;
	66522	 200.655	 178.6	 178.6	 178.6	 1.0	 100.0	 1	 343.0	 58.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 343.0;
	66523	 32.75	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66523	 141.4	 113.3	 113.3	 113.3	 1.0	 100.0	 1	 182.8	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.8;
	66523	 141.4	 113.3	 113.3	 113.3	 1.0	 100.0	 1	 182.8	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.8;
	66523	 162.2	 163.9	 163.9	 163.9	 1.0	 100.0	 1	 264.4	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 264.4;
	66524	 146.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 182.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.0;
	66524	 146.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 182.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 182.0;
	66524	 143.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 227.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 227.0;
	66525	 145.75	 112.5	 112.5	 112.5	 1.0	 100.0	 1	 181.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.5;
	66525	 145.75	 112.5	 112.5	 112.5	 1.0	 100.0	 1	 181.5	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.5;
	66525	 194.7	 216.5	 216.5	 216.5	 1.0	 100.0	 1	 349.4	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 349.4;
	66526	 141.5	 83.8	 83.8	 83.8	 1.0	 100.0	 1	 173.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.0;
	66526	 141.5	 83.8	 83.8	 83.8	 1.0	 100.0	 1	 173.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.0;
	66526	 141.5	 83.8	 83.8	 83.8	 1.0	 100.0	 1	 173.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.0;
	66526	 196.5	 25.15	 161.3	 -111.0	 1.0	 100.0	 1	 333.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 333.0;
	66527	 165.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	66527	 165.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	66527	 175.0	 27.25	 117.8	 -63.3	 1.0	 100.0	 1	 190.0	 160.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.0;
	66528	 129.0	 24.05	 104.1	 -56.0	 1.0	 100.0	 1	 168.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 168.0;
	66528	 129.0	 24.05	 104.1	 -56.0	 1.0	 100.0	 1	 168.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 168.0;
	66528	 124.0	 24.05	 104.1	 -56.0	 1.0	 100.0	 1	 168.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 168.0;
	66528	 117.5	 26.5	 114.7	 -61.7	 1.0	 100.0	 1	 185.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0;
	66528	 70.0	 12.9	 55.8	 -30.0	 1.0	 100.0	 1	 90.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	66529	 128.85	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 167.7	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.7;
	66529	 128.85	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 167.7	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.7;
	66529	 160.35	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 270.0	 50.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 270.0;
	66530	 115.0	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	66530	 115.0	 23.65	 102.3	 -55.0	 1.0	 100.0	 1	 165.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0;
	66530	 149.5	 32.8	 141.9	 -76.3	 1.0	 100.0	 1	 229.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.0;
	66531	 112.3	 34.3	 123.5	 -54.9	 1.0	 100.0	 1	 164.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.6;
	66531	 112.3	 34.3	 123.5	 -54.9	 1.0	 100.0	 1	 164.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.6;
	66531	 112.3	 34.3	 123.5	 -54.9	 1.0	 100.0	 1	 164.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.6;
	66531	 112.3	 34.3	 123.5	 -54.9	 1.0	 100.0	 1	 164.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 164.6;
	66531	 124.6	 39.4	 141.9	 -63.1	 1.0	 100.0	 1	 189.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.2;
	66531	 124.6	 39.4	 141.9	 -63.1	 1.0	 100.0	 1	 189.2	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.2;
	66532	 86.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 163.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2;
	66532	 86.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 163.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2;
	66532	 312.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 495.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 495.0;
	66532	 312.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 495.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 495.0;
	66533	 104.1	 101.1	 101.1	 101.1	 1.0	 100.0	 1	 163.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2;
	66533	 104.1	 101.1	 101.1	 101.1	 1.0	 100.0	 1	 163.2	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2;
	66533	 279.9	 240.6	 240.6	 240.6	 1.0	 100.0	 1	 496.8	 63.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 496.8;
	66534	 79.25	 11.9	 76.3	 -52.5	 1.0	 100.0	 1	 157.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.5;
	66534	 79.25	 11.9	 76.3	 -52.5	 1.0	 100.0	 1	 157.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.5;
	66535	 83.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 156.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.0;
	66535	 83.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 156.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.0;
	66535	 282.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 495.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 495.0;
	66535	 282.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 495.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 495.0;
	66535	 165.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 310.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 310.0;
	66535	 160.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 310.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 310.0;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 27.1	 3.85	 24.8	 -17.1	 1.0	 100.0	 1	 51.2	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.2;
	66536	 27.1	 3.85	 24.8	 -17.1	 1.0	 100.0	 1	 51.2	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.2;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66536	 15.65	 3.475	 12.52	 -5.57	 1.0	 100.0	 1	 16.7	 14.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.7;
	66537	 120.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 120.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	66538	 120.0	 0.0	 66.1	 -66.1	 1.0	 100.0	 1	 120.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	66539	 116.64	 0.0	 64.3	 -64.3	 1.0	 100.0	 1	 116.64	 116.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 145.8;
	66540	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 142.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.0;
	66540	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 142.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.0;
	66540	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 142.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.0;
	66540	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 142.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.0;
	66540	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 142.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.0;
	66541	 72.25	 10.55	 67.6	 -46.5	 1.0	 100.0	 1	 139.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.5;
	66542	 119.0	 135.1	 135.1	 135.1	 1.0	 100.0	 1	 218.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	66542	 119.0	 135.1	 135.1	 135.1	 1.0	 100.0	 1	 218.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	66542	 74.0	 85.5	 85.5	 85.5	 1.0	 100.0	 1	 138.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 138.0;
	66543	 108.0	 0.0	 59.5	 -59.5	 1.0	 100.0	 1	 108.0	 108.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	66544	 36.2	 26.3	 26.3	 26.3	 1.0	 100.0	 1	 42.4	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	66544	 36.2	 26.3	 26.3	 26.3	 1.0	 100.0	 1	 42.4	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	66544	 30.15	 25.0	 25.0	 25.0	 1.0	 100.0	 1	 40.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.3;
	66544	 108.1	 83.2	 83.2	 83.2	 1.0	 100.0	 1	 134.2	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.2;
	66545	 67.0	 43.7	 43.7	 43.7	 1.0	 100.0	 1	 133.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0;
	66545	 67.0	 43.7	 43.7	 43.7	 1.0	 100.0	 1	 133.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0;
	66546	 64.75	 41.6	 41.6	 41.6	 1.0	 100.0	 1	 126.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.5;
	66546	 64.75	 41.6	 41.6	 41.6	 1.0	 100.0	 1	 126.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.5;
	66547	 45.6	 7.9	 34.2	 -18.4	 1.0	 100.0	 1	 55.2	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.2;
	66547	 86.85	 8.95	 57.5	 -39.6	 1.0	 100.0	 1	 118.7	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.7;
	66548	 58.95	 8.9	 57.1	 -39.3	 1.0	 100.0	 1	 117.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.9;
	66549	 116.0	 0.0	 38.5	 -38.5	 1.0	 100.0	 1	 117.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0;
	66549	 116.0	 0.0	 38.5	 -38.5	 1.0	 100.0	 1	 117.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0;
	66549	 116.0	 0.0	 38.5	 -38.5	 1.0	 100.0	 1	 117.0	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0;
	66549	 97.35	 13.95	 60.5	 -32.6	 1.0	 100.0	 1	 97.7	 97.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	66549	 97.35	 13.95	 60.5	 -32.6	 1.0	 100.0	 1	 97.7	 97.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	66549	 97.35	 13.95	 60.5	 -32.6	 1.0	 100.0	 1	 97.7	 97.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	66550	 65.0	 68.2	 68.2	 68.2	 1.0	 100.0	 1	 110.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0;
	66550	 65.0	 68.2	 68.2	 68.2	 1.0	 100.0	 1	 110.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0;
	66550	 65.0	 68.2	 68.2	 68.2	 1.0	 100.0	 1	 110.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0;
	66550	 163.0	 148.2	 148.2	 148.2	 1.0	 100.0	 1	 306.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 306.0;
	66550	 182.8	 167.4	 167.4	 167.4	 1.0	 100.0	 1	 345.6	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 345.6;
	66551	 79.0	 52.3	 52.3	 52.3	 1.0	 100.0	 1	 108.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	66551	 79.0	 52.3	 52.3	 52.3	 1.0	 100.0	 1	 108.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	66551	 79.0	 52.3	 52.3	 52.3	 1.0	 100.0	 1	 108.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	66551	 79.0	 52.3	 52.3	 52.3	 1.0	 100.0	 1	 108.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	66552	 73.65	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 82.3	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.3;
	66552	 43.1	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 53.7	 32.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.7;
	66552	 43.1	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 53.7	 32.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.7;
	66553	 80.96	 0.0	 44.6	 -44.6	 1.0	 100.0	 1	 80.96	 80.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.2;
	66554	 52.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 95.0	 9.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	66554	 52.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 95.0	 9.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	66555	 68.45	 13.6	 58.8	 -31.6	 1.0	 100.0	 1	 94.9	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.9;
	66555	 68.45	 13.6	 58.8	 -31.6	 1.0	 100.0	 1	 94.9	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.9;
	66555	 74.4	 15.9	 68.7	 -36.9	 1.0	 100.0	 1	 110.8	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.8;
	66556	 47.3	 7.15	 45.8	 -31.5	 1.0	 100.0	 1	 94.5	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.5;
	66557	 49.5	 13.15	 57.0	 -30.7	 1.0	 100.0	 1	 92.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	66558	 49.5	 13.15	 57.0	 -30.7	 1.0	 100.0	 1	 92.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	66560	 45.0	 29.6	 29.6	 29.6	 1.0	 100.0	 1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	66560	 45.0	 29.6	 29.6	 29.6	 1.0	 100.0	 1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	66561	 30.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66561	 87.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 90.0	 85.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	66562	 32.125	 31.0	 31.0	 31.0	 1.0	 100.0	 1	 50.0	 14.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66562	 50.8	 50.6	 50.6	 50.6	 1.0	 100.0	 1	 81.6	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6;
	66562	 28.25	 21.4	 21.4	 21.4	 1.0	 100.0	 1	 34.5	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.5;
	66562	 68.95	 12.85	 55.7	 -30.0	 1.0	 100.0	 1	 89.9	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.9;
	66563	 12.165	 0.0	 8.35	 -8.35	 1.0	 100.0	 1	 22.1	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.1;
	66563	 12.165	 0.0	 8.35	 -8.35	 1.0	 100.0	 1	 22.1	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.1;
	66563	 12.165	 0.0	 8.35	 -8.35	 1.0	 100.0	 1	 22.1	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.1;
	66563	 12.165	 0.0	 8.35	 -8.35	 1.0	 100.0	 1	 22.1	 2.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.1;
	66564	 51.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 88.2	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	66564	 51.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 88.2	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	66565	 37.75	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66565	 37.75	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66565	 37.75	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66565	 37.75	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66565	 37.75	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66565	 60.65	 52.9	 52.9	 52.9	 1.0	 100.0	 1	 85.3	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	66565	 60.65	 52.9	 52.9	 52.9	 1.0	 100.0	 1	 85.3	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	66565	 44.5	 56.3	 56.3	 56.3	 1.0	 100.0	 1	 75.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66566	 41.15	 9.35	 40.5	 -21.8	 1.0	 100.0	 1	 65.3	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3;
	66566	 50.5	 11.75	 50.8	 -27.3	 1.0	 100.0	 1	 82.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0;
	66566	 79.0	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 73.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	66566	 100.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	66566	 100.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	66566	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	66566	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	66566	 62.5	 6.45	 41.2	 -28.3	 1.0	 100.0	 1	 85.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	66567	 71.2	 52.3	 52.3	 52.3	 1.0	 100.0	 1	 84.4	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.4;
	66567	 71.2	 52.3	 52.3	 52.3	 1.0	 100.0	 1	 84.4	 58.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.4;
	66568	 41.75	 6.3	 40.4	 -27.8	 1.0	 100.0	 1	 83.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5;
	66568	 42.55	 6.4	 41.2	 -28.4	 1.0	 100.0	 1	 85.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.1;
	66569	 24.25	 18.6	 18.6	 18.6	 1.0	 100.0	 1	 38.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5;
	66569	 24.25	 18.6	 18.6	 18.6	 1.0	 100.0	 1	 38.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5;
	66569	 75.0	 39.7	 39.7	 39.7	 1.0	 100.0	 1	 82.0	 68.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0;
	66569	 75.0	 39.7	 39.7	 39.7	 1.0	 100.0	 1	 82.0	 68.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0;
	66569	 75.0	 39.7	 39.7	 39.7	 1.0	 100.0	 1	 82.0	 68.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0;
	66569	 75.0	 39.7	 39.7	 39.7	 1.0	 100.0	 1	 82.0	 68.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.0;
	66570	 40.95	 6.2	 39.7	 -27.3	 1.0	 100.0	 1	 81.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.9;
	66571	 40.9	 0.0	 26.6	 -26.6	 1.0	 100.0	 1	 80.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.8;
	66571	 40.9	 0.0	 26.6	 -26.6	 1.0	 100.0	 1	 80.8	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.8;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66572	 4.81	 1.19	 4.29	 -1.91	 1.0	 100.0	 1	 5.71	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.71;
	66573	 39.6	 6.0	 38.4	 -26.4	 1.0	 100.0	 1	 79.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.2;
	66574	 39.95	 0.0	 25.9	 -25.9	 1.0	 100.0	 1	 78.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.9;
	66574	 39.95	 0.0	 25.9	 -25.9	 1.0	 100.0	 1	 78.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.9;
	66575	 39.2	 0.0	 25.8	 -25.8	 1.0	 100.0	 1	 78.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.4;
	66575	 39.2	 0.0	 25.8	 -25.8	 1.0	 100.0	 1	 78.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.4;
	66576	 44.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 78.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	66577	 38.6	 0.0	 35.2	 -35.2	 1.0	 100.0	 1	 77.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.2;
	66577	 38.6	 0.0	 35.2	 -35.2	 1.0	 100.0	 1	 77.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.2;
	66579	 61.52	 0.0	 30.4	 -30.4	 1.0	 100.0	 1	 61.52	 61.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.9;
	66581	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66581	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66581	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66581	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66582	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66582	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66582	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66582	 72.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 75.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	66583	 44.75	 5.65	 36.1	 -24.8	 1.0	 100.0	 1	 74.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5;
	66583	 44.75	 5.65	 36.1	 -24.8	 1.0	 100.0	 1	 74.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5;
	66583	 44.75	 5.65	 36.1	 -24.8	 1.0	 100.0	 1	 74.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5;
	66584	 37.55	 24.4	 24.4	 24.4	 1.0	 100.0	 1	 74.1	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.1;
	66585	 43.5	 44.6	 44.6	 44.6	 1.0	 100.0	 1	 72.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	66585	 43.0	 44.6	 44.6	 44.6	 1.0	 100.0	 1	 72.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	66586	 38.5	 5.45	 34.9	 -24.0	 1.0	 100.0	 1	 72.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	66587	 37.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	66587	 37.0	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	66587	 47.25	 6.65	 37.1	 -23.8	 1.0	 100.0	 1	 71.5	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.5;
	66588	 35.7	 5.4	 34.6	 -23.8	 1.0	 100.0	 1	 71.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.4;
	66588	 35.7	 5.4	 34.6	 -23.8	 1.0	 100.0	 1	 71.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.4;
	66589	 45.6	 34.5	 34.5	 34.5	 1.0	 100.0	 1	 71.2	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2;
	66589	 45.6	 34.5	 34.5	 34.5	 1.0	 100.0	 1	 71.2	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2;
	66590	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	66590	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	66592	 33.75	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	66592	 33.75	 5.1	 32.7	 -22.5	 1.0	 100.0	 1	 67.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	66593	 9.175	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 16.65	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.65;
	66593	 9.175	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 16.65	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.65;
	66593	 9.175	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 16.65	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.65;
	66593	 9.175	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 16.65	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.65;
	66594	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 66.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.2;
	66594	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 66.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.2;
	66594	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 66.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.2;
	66595	 16.0	 3.34	 12.0	 -5.32	 1.0	 100.0	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	66595	 16.0	 3.34	 12.0	 -5.32	 1.0	 100.0	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	66595	 16.0	 3.34	 12.0	 -5.32	 1.0	 100.0	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	66595	 16.0	 3.34	 12.0	 -5.32	 1.0	 100.0	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	66596	 31.5	 4.75	 30.5	 -21.0	 1.0	 100.0	 1	 63.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	66596	 31.5	 4.75	 30.5	 -21.0	 1.0	 100.0	 1	 63.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	66597	 55.0	 30.5	 30.5	 30.5	 1.0	 100.0	 1	 63.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	66597	 55.0	 30.5	 30.5	 30.5	 1.0	 100.0	 1	 63.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	66597	 55.0	 30.5	 30.5	 30.5	 1.0	 100.0	 1	 63.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	66597	 55.0	 30.5	 30.5	 30.5	 1.0	 100.0	 1	 63.0	 47.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	66598	 15.95	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 30.4	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	66598	 43.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 62.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.6;
	66598	 43.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 62.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.6;
	66599	 41.0	 46.5	 46.5	 46.5	 1.0	 100.0	 1	 62.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0;
	66600	 45.385	 6.85	 34.2	 -20.5	 1.0	 100.0	 1	 61.5	 29.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	66600	 32.0	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	66601	 49.2	 0.0	 24.3	 -24.3	 1.0	 100.0	 1	 49.2	 49.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	66602	 36.7	 3.8	 24.4	 -16.8	 1.0	 100.0	 1	 50.4	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	66602	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66602	 19.85	 5.4	 23.4	 -12.6	 1.0	 100.0	 1	 37.7	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.7;
	66604	 40.75	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66605	 40.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 60.5	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66606	 40.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66607	 48.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66609	 53.25	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66609	 53.25	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 46.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66613	 37.4	 19.7	 19.7	 19.7	 1.0	 100.0	 1	 59.8	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.8;
	66613	 37.4	 19.7	 19.7	 19.7	 1.0	 100.0	 1	 59.8	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.8;
	66613	 46.65	 25.7	 25.7	 25.7	 1.0	 100.0	 1	 78.3	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.3;
	66613	 46.65	 25.7	 25.7	 25.7	 1.0	 100.0	 1	 78.3	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.3;
	66615	 29.5	 4.45	 28.6	 -19.7	 1.0	 100.0	 1	 59.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	66616	 29.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	66616	 29.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	66618	 46.75	 43.9	 43.9	 43.9	 1.0	 100.0	 1	 58.5	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5;
	66620	 56.0	 28.1	 28.1	 28.1	 1.0	 100.0	 1	 58.0	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0;
	66621	 28.8	 4.35	 27.9	 -19.2	 1.0	 100.0	 1	 57.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.6;
	66621	 30.15	 4.55	 29.2	 -20.1	 1.0	 100.0	 1	 60.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.3;
	66622	 33.7	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	66623	 29.0	 11.65	 42.0	 -18.7	 1.0	 100.0	 1	 56.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0;
	66623	 140.5	 0.0	 98.4	 -98.4	 1.0	 100.0	 1	 271.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	66623	 140.5	 0.0	 98.4	 -98.4	 1.0	 100.0	 1	 271.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	66623	 140.5	 0.0	 98.4	 -98.4	 1.0	 100.0	 1	 271.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	66623	 140.5	 0.0	 98.4	 -98.4	 1.0	 100.0	 1	 271.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	66623	 140.5	 0.0	 98.4	 -98.4	 1.0	 100.0	 1	 271.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	66623	 140.5	 0.0	 98.4	 -98.4	 1.0	 100.0	 1	 271.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	66624	 34.4	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 55.8	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.8;
	66624	 27.65	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 45.3	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.3;
	66626	 28.15	 4.2	 26.8	 -18.4	 1.0	 100.0	 1	 55.3	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.3;
	66628	 37.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 55.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66628	 70.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 118.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.0;
	66628	 70.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 118.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.0;
	66628	 80.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 138.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 138.0;
	66628	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66628	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66628	 37.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 55.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66628	 37.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 55.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66628	 37.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 55.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66628	 66.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 110.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0;
	66628	 66.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 110.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0;
	66628	 67.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 113.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.0;
	66628	 70.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 118.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.0;
	66628	 70.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 118.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.0;
	66629	 30.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 55.0	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66629	 30.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 55.0	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66630	 28.4	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 1.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66631	 32.5	 7.15	 32.6	 -18.3	 1.0	 100.0	 1	 55.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66631	 32.5	 7.15	 32.6	 -18.3	 1.0	 100.0	 1	 55.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66632	 32.5	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66632	 32.5	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66633	 30.0	 0.0	 18.1	 -18.1	 1.0	 100.0	 1	 55.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66633	 30.0	 0.0	 18.1	 -18.1	 1.0	 100.0	 1	 55.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66633	 30.0	 0.0	 18.1	 -18.1	 1.0	 100.0	 1	 55.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	66634	 15.15	 11.33	 11.33	 11.33	 1.0	 100.0	 1	 18.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	66634	 15.15	 11.33	 11.33	 11.33	 1.0	 100.0	 1	 18.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	66634	 15.15	 11.33	 11.33	 11.33	 1.0	 100.0	 1	 18.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	66635	 10.15	 0.0	 6.0	 -6.0	 1.0	 100.0	 1	 18.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	66635	 10.15	 0.0	 6.0	 -6.0	 1.0	 100.0	 1	 18.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	66635	 10.15	 0.0	 6.0	 -6.0	 1.0	 100.0	 1	 18.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	66636	 27.45	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 54.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.9;
	66636	 30.6	 4.6	 29.6	 -20.4	 1.0	 100.0	 1	 61.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.2;
	66638	 27.95	 4.05	 26.1	 -18.0	 1.0	 100.0	 1	 53.9	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.9;
	66639	 26.55	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66640	 26.5	 0.0	 17.4	 -17.4	 1.0	 100.0	 1	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	66642	 37.05	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 42.1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.1;
	66642	 42.9	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 52.8	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.8;
	66643	 26.1	 3.95	 25.3	 -17.4	 1.0	 100.0	 1	 52.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2;
	66643	 28.8	 4.35	 27.9	 -19.2	 1.0	 100.0	 1	 57.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.6;
	66644	 25.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	66644	 25.85	 3.9	 25.0	 -17.2	 1.0	 100.0	 1	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	66645	 38.1	 3.15	 20.0	 -13.7	 1.0	 100.0	 1	 41.2	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.2;
	66645	 46.2	 4.6	 26.3	 -17.1	 1.0	 100.0	 1	 51.4	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4;
	66646	 27.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66646	 27.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66647	 25.0	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66647	 25.0	 3.75	 24.2	 -16.7	 1.0	 100.0	 1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66649	 45.0	 16.4	 16.4	 16.4	 1.0	 100.0	 1	 50.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66650	 31.5	 24.2	 24.2	 24.2	 1.0	 100.0	 1	 50.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66651	 50.0	 24.2	 24.2	 24.2	 1.0	 100.0	 1	 50.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66651	 50.0	 24.2	 24.2	 24.2	 1.0	 100.0	 1	 50.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66651	 53.5	 26.2	 26.2	 26.2	 1.0	 100.0	 1	 54.0	 53.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	66652	 35.0	 31.0	 31.0	 31.0	 1.0	 100.0	 1	 50.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66652	 35.0	 31.0	 31.0	 31.0	 1.0	 100.0	 1	 50.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66653	 40.0	 19.8	 19.8	 19.8	 1.0	 100.0	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66654	 44.25	 16.4	 16.4	 16.4	 1.0	 100.0	 1	 49.9	 38.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	66654	 44.0	 16.4	 16.4	 16.4	 1.0	 100.0	 1	 49.9	 38.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	66654	 43.65	 16.4	 16.4	 16.4	 1.0	 100.0	 1	 49.9	 37.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	66656	 42.45	 3.8	 24.2	 -16.6	 1.0	 100.0	 1	 49.9	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	66657	 40.95	 37.4	 37.4	 37.4	 1.0	 100.0	 1	 49.9	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	66658	 32.0	 3.3	 21.3	 -14.7	 1.0	 100.0	 1	 44.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	66658	 42.4	 3.75	 24.1	 -16.6	 1.0	 100.0	 1	 49.8	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	66658	 42.4	 3.75	 24.1	 -16.6	 1.0	 100.0	 1	 49.8	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	66658	 27.15	 3.75	 24.1	 -16.6	 1.0	 100.0	 1	 49.8	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	66660	 47.85	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 49.8	 45.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66663	 2.6	 2.33	 2.33	 2.33	 1.0	 100.0	 1	 3.1	 2.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1;
	66665	 45.75	 4.45	 25.4	 -16.5	 1.0	 100.0	 1	 49.5	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.5;
	66666	 39.75	 7.1	 30.7	 -16.5	 1.0	 100.0	 1	 49.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.5;
	66667	 39.75	 7.1	 30.7	 -16.5	 1.0	 100.0	 1	 49.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.5;
	66668	 30.25	 5.65	 24.5	 -13.2	 1.0	 100.0	 1	 39.5	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.5;
	66668	 37.65	 7.1	 30.6	 -16.4	 1.0	 100.0	 1	 49.3	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.3;
	66669	 6.15	 5.95	 5.95	 5.95	 1.0	 100.0	 1	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	66669	 6.15	 5.95	 5.95	 5.95	 1.0	 100.0	 1	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	66669	 6.15	 5.95	 5.95	 5.95	 1.0	 100.0	 1	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	66669	 6.15	 5.95	 5.95	 5.95	 1.0	 100.0	 1	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	66670	 28.0	 25.4	 25.4	 25.4	 1.0	 100.0	 1	 41.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0;
	66670	 34.5	 31.4	 31.4	 31.4	 1.0	 100.0	 1	 49.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	66672	 45.5	 3.7	 23.7	 -16.3	 1.0	 100.0	 1	 49.0	 42.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	66673	 35.5	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	66673	 35.5	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	66674	 32.35	 30.2	 30.2	 30.2	 1.0	 100.0	 1	 48.7	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.7;
	66675	 24.3	 3.65	 23.5	 -16.2	 1.0	 100.0	 1	 48.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.6;
	66675	 24.3	 3.65	 23.5	 -16.2	 1.0	 100.0	 1	 48.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.6;
	66678	 43.6	 29.9	 29.9	 29.9	 1.0	 100.0	 1	 48.2	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.2;
	66679	 24.75	 6.8	 29.4	 -15.8	 1.0	 100.0	 1	 47.5	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	66682	 29.5	 29.1	 29.1	 29.1	 1.0	 100.0	 1	 47.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	66683	 33.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	66684	 33.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	66685	 33.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	66686	 33.5	 3.55	 22.8	 -15.7	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	66687	 33.5	 29.1	 29.1	 29.1	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	66688	 33.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	66689	 25.85	 3.5	 22.6	 -15.6	 1.0	 100.0	 1	 46.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.7;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66691	 2.05	 2.17	 2.17	 2.17	 1.0	 100.0	 1	 2.9	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.9;
	66692	 34.05	 28.6	 28.6	 28.6	 1.0	 100.0	 1	 46.1	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.1;
	66692	 34.05	 28.6	 28.6	 28.6	 1.0	 100.0	 1	 46.1	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.1;
	66693	 39.0	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	66694	 39.0	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	66695	 39.0	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	66696	 43.0	 28.5	 28.5	 28.5	 1.0	 100.0	 1	 46.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	66697	 33.5	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	66699	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 45.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	66699	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 45.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	66699	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 45.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	66700	 36.0	 0.0	 17.8	 -17.8	 1.0	 100.0	 1	 36.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	66701	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	66701	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	66701	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	66701	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	66703	 24.5	 6.3	 6.3	 6.3	 1.0	 100.0	 1	 44.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	66704	 31.46	 24.6	 24.6	 24.6	 1.0	 100.0	 1	 44.0	 18.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	66705	 38.5	 21.3	 21.3	 21.3	 1.0	 100.0	 1	 44.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	66706	 34.72	 0.0	 17.2	 -17.2	 1.0	 100.0	 1	 34.72	 34.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	66707	 27.0	 9.0	 32.3	 -14.3	 1.0	 100.0	 1	 43.0	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0;
	66708	 39.1	 8.8	 31.7	 -14.1	 1.0	 100.0	 1	 42.2	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.2;
	66709	 7.05	 2.315	 9.3	 -4.67	 1.0	 100.0	 1	 14.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	66709	 7.05	 2.315	 9.3	 -4.67	 1.0	 100.0	 1	 14.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	66709	 7.05	 2.315	 9.3	 -4.67	 1.0	 100.0	 1	 14.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	66710	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 42.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0;
	66710	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 42.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0;
	66710	 51.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 80.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	66711	 20.95	 3.15	 20.3	 -14.0	 1.0	 100.0	 1	 41.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9;
	66712	 32.8	 16.2	 16.2	 16.2	 1.0	 100.0	 1	 32.8	 32.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0;
	66713	 33.7	 14.6	 14.6	 14.6	 1.0	 100.0	 1	 40.3	 27.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.3;
	66714	 9.0	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66714	 9.0	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66714	 9.0	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66714	 9.0	 2.085	 7.5	 -3.33	 1.0	 100.0	 1	 10.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66715	 20.0	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66717	 34.5	 24.8	 24.8	 24.8	 1.0	 100.0	 1	 40.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66717	 34.5	 24.8	 24.8	 24.8	 1.0	 100.0	 1	 40.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66717	 19.25	 25.1	 25.1	 25.1	 1.0	 100.0	 1	 33.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.5;
	66718	 12.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	66718	 22.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66718	 22.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66719	 31.76	 15.7	 15.7	 15.7	 1.0	 100.0	 1	 31.76	 31.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.7;
	66720	 19.8	 3.0	 19.2	 -13.2	 1.0	 100.0	 1	 39.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6;
	66720	 19.8	 3.0	 19.2	 -13.2	 1.0	 100.0	 1	 39.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6;
	66721	 37.55	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 39.1	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.1;
	66722	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0;
	66722	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0;
	66722	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0;
	66723	 34.45	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 38.9	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.9;
	66724	 27.74	 4.4	 21.7	 -12.9	 1.0	 100.0	 1	 38.8	 16.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.8;
	66726	 19.8	 0.0	 12.7	 -12.7	 1.0	 100.0	 1	 38.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.6;
	66727	 27.7	 2.9	 18.6	 -12.8	 1.0	 100.0	 1	 38.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4;
	66728	 37.2	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 38.4	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4;
	66729	 28.1	 23.7	 23.7	 23.7	 1.0	 100.0	 1	 38.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	66730	 34.1	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 38.2	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	66731	 14.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 19.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	66731	 14.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 19.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	66732	 30.4	 0.0	 15.0	 -15.0	 1.0	 100.0	 1	 30.4	 30.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	66733	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	66734	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	66735	 19.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 37.5	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	66736	 21.05	 0.0	 12.2	 -12.2	 1.0	 100.0	 1	 37.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.1;
	66736	 21.05	 0.0	 12.2	 -12.2	 1.0	 100.0	 1	 37.1	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.1;
	66737	 18.45	 17.9	 17.9	 17.9	 1.0	 100.0	 1	 36.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.9;
	66737	 18.45	 17.9	 17.9	 17.9	 1.0	 100.0	 1	 36.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.9;
	66738	 29.44	 0.0	 14.5	 -14.5	 1.0	 100.0	 1	 29.44	 29.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.8;
	66739	 19.75	 0.0	 13.0	 -13.0	 1.0	 100.0	 1	 39.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.5;
	66739	 19.75	 0.0	 13.0	 -13.0	 1.0	 100.0	 1	 39.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.5;
	66739	 18.25	 2.75	 17.7	 -12.2	 1.0	 100.0	 1	 36.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.5;
	66740	 20.55	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 23.1	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	66740	 29.1	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 36.2	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2;
	66741	 26.1	 2.7	 17.5	 -12.1	 1.0	 100.0	 1	 36.2	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2;
	66742	 18.9	 5.15	 22.2	 -11.9	 1.0	 100.0	 1	 35.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	66743	 18.9	 5.15	 22.2	 -11.9	 1.0	 100.0	 1	 35.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	66745	 18.83	 17.0	 17.0	 17.0	 1.0	 100.0	 1	 35.0	 2.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	66746	 18.83	 2.65	 17.0	 -11.7	 1.0	 100.0	 1	 35.0	 2.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	66747	 17.3	 2.65	 16.8	 -11.5	 1.0	 100.0	 1	 34.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.6;
	66747	 17.3	 2.65	 16.8	 -11.5	 1.0	 100.0	 1	 34.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.6;
	66748	 19.05	 0.0	 9.4	 -9.4	 1.0	 100.0	 1	 22.1	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.1;
	66748	 25.5	 0.0	 14.7	 -14.7	 1.0	 100.0	 1	 34.5	 16.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.5;
	66749	 27.6	 0.0	 13.6	 -13.6	 1.0	 100.0	 1	 27.6	 27.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.5;
	66750	 27.75	 0.0	 15.0	 -15.0	 1.0	 100.0	 1	 45.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	66750	 27.75	 0.0	 15.0	 -15.0	 1.0	 100.0	 1	 45.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	66750	 27.75	 0.0	 15.0	 -15.0	 1.0	 100.0	 1	 45.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	66750	 21.15	 2.6	 16.6	 -11.4	 1.0	 100.0	 1	 34.3	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.3;
	66751	 18.4	 2.6	 16.6	 -11.4	 1.0	 100.0	 1	 34.2	 2.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2;
	66752	 18.4	 2.6	 16.6	 -11.4	 1.0	 100.0	 1	 34.2	 2.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2;
	66753	 18.4	 2.6	 16.6	 -11.4	 1.0	 100.0	 1	 34.2	 2.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2;
	66754	 18.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 34.0	 3.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	66754	 18.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 34.0	 3.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	66754	 18.7	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 34.0	 3.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	66754	 19.8	 2.7	 17.4	 -12.0	 1.0	 100.0	 1	 36.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	66754	 20.05	 2.75	 17.7	 -12.2	 1.0	 100.0	 1	 36.5	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.5;
	66755	 17.5	 21.1	 21.1	 21.1	 1.0	 100.0	 1	 34.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	66756	 5.9	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.3	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3;
	66756	 5.9	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.3	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3;
	66756	 5.9	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.3	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3;
	66759	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	66759	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	66760	 6.45	 3.57	 3.57	 3.57	 1.0	 100.0	 1	 10.9	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	66760	 6.45	 3.57	 3.57	 3.57	 1.0	 100.0	 1	 10.9	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	66760	 6.45	 3.57	 3.57	 3.57	 1.0	 100.0	 1	 10.9	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	66761	 31.3	 0.0	 10.7	 -10.7	 1.0	 100.0	 1	 32.6	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.6;
	66761	 27.25	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	66761	 27.25	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	66761	 27.25	 2.05	 13.3	 -9.2	 1.0	 100.0	 1	 27.5	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	66762	 5.915	 0.0	 1.53	 -1.53	 1.0	 100.0	 1	 10.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.83;
	66762	 5.915	 0.0	 1.53	 -1.53	 1.0	 100.0	 1	 10.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.83;
	66762	 5.915	 0.0	 1.53	 -1.53	 1.0	 100.0	 1	 10.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.83;
	66763	 16.15	 15.6	 15.6	 15.6	 1.0	 100.0	 1	 32.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.3;
	66763	 17.55	 17.0	 17.0	 17.0	 1.0	 100.0	 1	 35.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1;
	66763	 17.55	 17.0	 17.0	 17.0	 1.0	 100.0	 1	 35.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.1;
	66764	 31.15	 24.2	 24.2	 24.2	 1.0	 100.0	 1	 32.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.3;
	66764	 31.15	 24.2	 24.2	 24.2	 1.0	 100.0	 1	 32.3	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.3;
	66765	 24.4	 11.8	 11.8	 11.8	 1.0	 100.0	 1	 24.4	 24.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.4;
	66765	 31.85	 17.6	 17.6	 17.6	 1.0	 100.0	 1	 32.0	 31.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	66766	 19.1	 4.45	 21.6	 -12.7	 1.0	 100.0	 1	 38.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	66766	 19.1	 4.45	 21.6	 -12.7	 1.0	 100.0	 1	 38.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	66766	 16.0	 6.65	 24.0	 -10.7	 1.0	 100.0	 1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	66766	 16.6	 6.9	 24.9	 -11.1	 1.0	 100.0	 1	 33.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.2;
	66767	 15.95	 6.65	 23.9	 -10.6	 1.0	 100.0	 1	 31.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.9;
	66768	 20.7	 2.35	 15.2	 -10.5	 1.0	 100.0	 1	 31.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4;
	66768	 20.7	 2.35	 15.2	 -10.5	 1.0	 100.0	 1	 31.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4;
	66768	 20.7	 2.35	 15.2	 -10.5	 1.0	 100.0	 1	 31.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4;
	66770	 21.5	 12.1	 12.1	 12.1	 1.0	 100.0	 1	 25.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	66770	 26.5	 15.0	 15.0	 15.0	 1.0	 100.0	 1	 31.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	66771	 15.5	 0.0	 11.3	 -11.3	 1.0	 100.0	 1	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	66772	 16.0	 2.35	 15.0	 -10.3	 1.0	 100.0	 1	 31.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	66773	 24.8	 0.0	 12.3	 -12.3	 1.0	 100.0	 1	 24.8	 24.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	66774	 19.25	 17.6	 17.6	 17.6	 1.0	 100.0	 1	 23.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.5;
	66774	 23.9	 23.1	 23.1	 23.1	 1.0	 100.0	 1	 30.8	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	66776	 5.515	 0.835	 5.07	 -3.4	 1.0	 100.0	 1	 10.2	 0.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	66776	 5.515	 0.835	 5.07	 -3.4	 1.0	 100.0	 1	 10.2	 0.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	66776	 5.515	 0.835	 5.07	 -3.4	 1.0	 100.0	 1	 10.2	 0.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	66778	 4.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 6.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0;
	66778	 4.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 6.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0;
	66778	 4.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 6.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0;
	66778	 4.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 6.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0;
	66778	 4.8	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 6.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0;
	66778	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66778	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66778	 32.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 40.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	66780	 9.05	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	66780	 9.05	 3.125	 11.25	 -5.0	 1.0	 100.0	 1	 15.0	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	66781	 16.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 30.0	 2.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66781	 24.75	 21.8	 21.8	 21.8	 1.0	 100.0	 1	 45.0	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	66782	 15.0	 2.5	 7.0	 -2.0	 1.0	 100.0	 1	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66782	 15.0	 2.5	 7.0	 -2.0	 1.0	 100.0	 1	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66782	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66782	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66784	 16.5	 14.5	 14.5	 14.5	 1.0	 100.0	 1	 30.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66784	 16.5	 14.5	 14.5	 14.5	 1.0	 100.0	 1	 30.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66784	 17.6	 15.6	 15.6	 15.6	 1.0	 100.0	 1	 32.2	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.2;
	66785	 16.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 30.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66785	 16.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 30.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66785	 16.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 30.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66786	 25.0	 4.3	 18.6	 -10.0	 1.0	 100.0	 1	 30.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66786	 25.0	 4.3	 18.6	 -10.0	 1.0	 100.0	 1	 30.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66786	 14.5	 4.8	 17.3	 -7.7	 1.0	 100.0	 1	 23.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	66787	 24.0	 0.0	 11.9	 -11.9	 1.0	 100.0	 1	 24.0	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	66788	 15.45	 10.0	 10.0	 10.0	 1.0	 100.0	 1	 29.9	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.9;
	66789	 23.92	 0.0	 11.8	 -11.8	 1.0	 100.0	 1	 23.92	 23.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.9;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66790	 2.65	 0.25	 1.6	 -1.1	 1.0	 100.0	 1	 3.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.3;
	66791	 14.85	 2.25	 14.4	 -9.9	 1.0	 100.0	 1	 29.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7;
	66792	 18.56	 0.0	 11.5	 -11.5	 1.0	 100.0	 1	 18.56	 18.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0;
	66792	 31.13	 0.0	 18.5	 -18.5	 1.0	 100.0	 1	 31.13	 31.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8;
	66793	 20.5	 6.05	 21.8	 -9.7	 1.0	 100.0	 1	 29.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0;
	66794	 22.4	 17.8	 17.8	 17.8	 1.0	 100.0	 1	 28.8	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8;
	66794	 22.4	 17.8	 17.8	 17.8	 1.0	 100.0	 1	 28.8	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8;
	66794	 37.95	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 15.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66794	 37.95	 37.5	 37.5	 37.5	 1.0	 100.0	 1	 60.5	 15.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	66795	 21.8	 2.2	 13.9	 -9.5	 1.0	 100.0	 1	 28.6	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.6;
	66796	 23.75	 4.1	 17.7	 -9.5	 1.0	 100.0	 1	 28.5	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.5;
	66796	 20.5	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	66797	 24.65	 0.0	 12.1	 -12.1	 1.0	 100.0	 1	 28.3	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3;
	66799	 20.1	 17.4	 17.4	 17.4	 1.0	 100.0	 1	 28.0	 12.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	66800	 16.0	 4.05	 17.4	 -9.3	 1.0	 100.0	 1	 28.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	66801	 20.0	 4.05	 17.4	 -9.3	 1.0	 100.0	 1	 28.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	66802	 20.05	 4.0	 17.3	 -9.3	 1.0	 100.0	 1	 27.9	 12.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.9;
	66803	 19.85	 2.1	 13.4	 -9.2	 1.0	 100.0	 1	 27.7	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.7;
	66804	 4.715	 1.15	 4.14	 -1.84	 1.0	 100.0	 1	 5.52	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.52;
	66804	 4.715	 1.15	 4.14	 -1.84	 1.0	 100.0	 1	 5.52	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.52;
	66804	 4.715	 1.15	 4.14	 -1.84	 1.0	 100.0	 1	 5.52	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.52;
	66804	 4.715	 1.15	 4.14	 -1.84	 1.0	 100.0	 1	 5.52	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.52;
	66804	 4.715	 1.15	 4.14	 -1.84	 1.0	 100.0	 1	 5.52	 3.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.52;
	66805	 24.6	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 27.4	 21.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	66805	 24.6	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 27.4	 21.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	66806	 25.35	 9.0	 9.0	 9.0	 1.0	 100.0	 1	 27.4	 23.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	66807	 21.2	 2.1	 13.3	 -9.1	 1.0	 100.0	 1	 27.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	66807	 21.2	 2.1	 13.3	 -9.1	 1.0	 100.0	 1	 27.4	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	66808	 16.15	 0.0	 3.9	 -3.9	 1.0	 100.0	 1	 27.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.3;
	66809	 14.65	 3.9	 16.9	 -9.1	 1.0	 100.0	 1	 27.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.3;
	66810	 21.68	 10.7	 10.7	 10.7	 1.0	 100.0	 1	 21.68	 21.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.1;
	66811	 6.75	 1.025	 6.55	 -4.5	 1.0	 100.0	 1	 13.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	66811	 6.75	 1.025	 6.55	 -4.5	 1.0	 100.0	 1	 13.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	66814	 13.35	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	66814	 13.35	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	66814	 13.35	 2.0	 12.9	 -8.9	 1.0	 100.0	 1	 26.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	66815	 9.575	 8.05	 8.05	 8.05	 1.0	 100.0	 1	 13.3	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3;
	66815	 9.575	 8.05	 8.05	 8.05	 1.0	 100.0	 1	 13.3	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3;
	66816	 3.3	 3.2	 3.2	 3.2	 1.0	 100.0	 1	 6.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	66816	 3.3	 3.2	 3.2	 3.2	 1.0	 100.0	 1	 6.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	66816	 3.3	 3.2	 3.2	 3.2	 1.0	 100.0	 1	 6.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	66816	 3.3	 3.2	 3.2	 3.2	 1.0	 100.0	 1	 6.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	66817	 19.0	 14.3	 14.3	 14.3	 1.0	 100.0	 1	 23.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	66817	 20.55	 15.9	 15.9	 15.9	 1.0	 100.0	 1	 25.6	 15.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.6;
	66818	 12.75	 3.65	 15.8	 -8.5	 1.0	 100.0	 1	 25.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5;
	66818	 13.35	 3.8	 16.5	 -8.9	 1.0	 100.0	 1	 26.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	66819	 13.25	 0.0	 8.4	 -8.4	 1.0	 100.0	 1	 25.5	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5;
	66820	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2;
	66820	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2;
	66820	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2;
	66820	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2;
	66820	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2;
	66820	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2;
	66822	 10.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	66822	 10.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 12.5	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	66823	 12.55	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 25.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	66823	 12.55	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 25.0	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	66824	 20.0	 15.5	 15.5	 15.5	 1.0	 100.0	 1	 25.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	66825	 13.7	 8.9	 8.9	 8.9	 1.0	 100.0	 1	 13.7	 13.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	66825	 12.94	 9.3	 9.3	 9.3	 1.0	 100.0	 1	 12.94	 12.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.5;
	66825	 20.0	 9.9	 9.9	 9.9	 1.0	 100.0	 1	 20.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	66825	 22.96	 11.3	 11.3	 11.3	 1.0	 100.0	 1	 22.96	 22.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.7;
	66826	 17.95	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 24.9	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66826	 17.95	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 24.9	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66828	 22.95	 3.55	 15.4	 -8.3	 1.0	 100.0	 1	 24.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66828	 22.95	 3.55	 15.4	 -8.3	 1.0	 100.0	 1	 24.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66829	 22.95	 3.55	 15.4	 -8.3	 1.0	 100.0	 1	 24.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66829	 22.95	 3.55	 15.4	 -8.3	 1.0	 100.0	 1	 24.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66830	 22.95	 3.55	 15.4	 -8.3	 1.0	 100.0	 1	 24.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66830	 22.95	 3.55	 15.4	 -8.3	 1.0	 100.0	 1	 24.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	66831	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 12.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2;
	66831	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 12.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2;
	66832	 18.2	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.4	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.4;
	66832	 18.2	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.4	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.4;
	66833	 11.0	 9.0	 9.0	 9.0	 1.0	 100.0	 1	 12.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	66833	 11.0	 9.0	 9.0	 9.0	 1.0	 100.0	 1	 12.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	66834	 19.2	 0.0	 9.5	 -9.5	 1.0	 100.0	 1	 19.2	 19.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	66834	 50.4	 0.0	 24.9	 -24.9	 1.0	 100.0	 1	 50.4	 50.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	66835	 19.2	 0.0	 9.5	 -9.5	 1.0	 100.0	 1	 19.2	 19.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	66836	 13.5	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	66837	 18.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	66838	 13.2	 7.9	 7.9	 7.9	 1.0	 100.0	 1	 23.9	 2.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9;
	66839	 11.9	 1.8	 11.5	 -7.9	 1.0	 100.0	 1	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8;
	66839	 12.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	66839	 12.5	 1.9	 12.1	 -8.3	 1.0	 100.0	 1	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	66840	 6.435	 4.77	 4.77	 4.77	 1.0	 100.0	 1	 7.87	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.87;
	66840	 6.435	 4.77	 4.77	 4.77	 1.0	 100.0	 1	 7.87	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.87;
	66840	 6.435	 4.77	 4.77	 4.77	 1.0	 100.0	 1	 7.87	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.87;
	66841	 18.65	 14.4	 14.4	 14.4	 1.0	 100.0	 1	 23.3	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.3;
	66841	 18.65	 14.4	 14.4	 14.4	 1.0	 100.0	 1	 23.3	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.3;
	66844	 41.2	 8.25	 35.6	 -19.1	 1.0	 100.0	 1	 57.4	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	66844	 15.0	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	66844	 32.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66844	 32.5	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	66844	 20.7	 1.9	 12.3	 -8.5	 1.0	 100.0	 1	 25.4	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.4;
	66844	 44.55	 4.15	 26.7	 -18.4	 1.0	 100.0	 1	 55.1	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.1;
	66844	 10.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	66844	 10.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	66845	 14.0	 3.3	 14.3	 -7.7	 1.0	 100.0	 1	 23.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	66846	 17.92	 0.0	 8.9	 -8.9	 1.0	 100.0	 1	 17.92	 17.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.4;
	66847	 17.76	 8.8	 8.8	 8.8	 1.0	 100.0	 1	 17.76	 17.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2;
	66847	 35.52	 17.5	 17.5	 17.5	 1.0	 100.0	 1	 35.52	 35.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.4;
	66848	 11.0	 4.6	 16.5	 -7.3	 1.0	 100.0	 1	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	66849	 12.0	 1.7	 10.7	 -7.3	 1.0	 100.0	 1	 22.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	66850	 10.88	 0.0	 8.7	 -8.7	 1.0	 100.0	 1	 10.88	 10.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	66851	 4.62	 0.0	 4.35	 -4.35	 1.0	 100.0	 1	 4.62	 4.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.95;
	66851	 7.01	 0.0	 4.35	 -4.35	 1.0	 100.0	 1	 7.01	 7.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.95;
	66852	 8.76	 4.35	 4.35	 4.35	 1.0	 100.0	 1	 8.76	 8.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.95;
	66852	 8.76	 4.35	 4.35	 4.35	 1.0	 100.0	 1	 8.76	 8.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.95;
	66853	 17.36	 0.0	 8.6	 -8.6	 1.0	 100.0	 1	 17.36	 17.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.7;
	66854	 17.55	 1.65	 10.5	 -7.2	 1.0	 100.0	 1	 21.6	 13.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	66855	 9.28	 0.0	 8.4	 -8.4	 1.0	 100.0	 1	 9.28	 9.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2;
	66856	 4.22	 0.0	 4.15	 -4.15	 1.0	 100.0	 1	 4.22	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.55;
	66856	 4.22	 0.0	 4.15	 -4.15	 1.0	 100.0	 1	 4.22	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.55;
	66858	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	66860	 10.65	 9.9	 9.9	 9.9	 1.0	 100.0	 1	 20.5	 0.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.5;
	66861	 13.05	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 20.1	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.1;
	66862	 6.5	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66862	 6.5	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66863	 5.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66863	 5.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	66864	 4.17	 0.0	 2.9	 -2.9	 1.0	 100.0	 1	 6.67	 1.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.67;
	66864	 4.17	 0.0	 2.9	 -2.9	 1.0	 100.0	 1	 6.67	 1.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.67;
	66864	 4.17	 0.0	 2.9	 -2.9	 1.0	 100.0	 1	 6.67	 1.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.67;
	66865	 17.5	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	66866	 10.5	 15.0	 15.0	 15.0	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	66867	 10.5	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	66868	 16.0	 7.9	 7.9	 7.9	 1.0	 100.0	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	75434	 121.4	 24.75	 107.1	 -57.6	 1.0	 100.0	 1	 172.8	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	75440	 85.2	 0.0	 47.0	 -47.0	 1.0	 100.0	 1	 85.2	 85.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.5;
	75452	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	75452	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	75452	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	75452	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	75452	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	75452	 4.7	 1.75	 6.3	 -2.8	 1.0	 100.0	 1	 8.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	75455	 8.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 16.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	75455	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 16.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	75455	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 16.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	75461	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75461	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75461	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75461	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75462	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75462	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75462	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75462	 6.25	 1.56	 5.62	 -2.5	 1.0	 100.0	 1	 7.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	75464	 15.15	 1.75	 11.3	 -7.8	 1.0	 100.0	 1	 23.3	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.3;
	75482	 69.92	 13.2	 84.7	 -58.3	 1.0	 100.0	 1	 69.92	 69.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.8;
	75482	 50.16	 0.0	 55.3	 -55.3	 1.0	 100.0	 1	 50.16	 50.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.4;
	75482	 59.8	 0.0	 65.9	 -65.9	 1.0	 100.0	 1	 59.8	 59.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.5;
	75483	 55.12	 54.1	 54.1	 54.1	 1.0	 100.0	 1	 55.12	 55.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.8;
	75490	 30.6	 0.0	 30.2	 -30.2	 1.0	 100.0	 1	 30.6	 30.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.5;
	75490	 88.4	 16.65	 107.0	 -73.7	 1.0	 100.0	 1	 88.4	 88.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0;
	75498	 5.04	 1.405	 5.68	 -2.87	 1.0	 100.0	 1	 8.58	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	75498	 5.04	 1.405	 5.68	 -2.87	 1.0	 100.0	 1	 8.58	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	75498	 5.04	 1.405	 5.68	 -2.87	 1.0	 100.0	 1	 8.58	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	75498	 5.04	 1.405	 5.68	 -2.87	 1.0	 100.0	 1	 8.58	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	75498	 5.04	 1.405	 5.68	 -2.87	 1.0	 100.0	 1	 8.58	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	75498	 5.04	 1.405	 5.68	 -2.87	 1.0	 100.0	 1	 8.58	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	75500	 23.75	 3.6	 23.0	 -15.8	 1.0	 100.0	 1	 47.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	75500	 23.75	 3.6	 23.0	 -15.8	 1.0	 100.0	 1	 47.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	75500	 23.75	 3.6	 23.0	 -15.8	 1.0	 100.0	 1	 47.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	75500	 23.75	 3.6	 23.0	 -15.8	 1.0	 100.0	 1	 47.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	75516	 209.76	 19.8	 127.0	 -87.4	 1.0	 100.0	 1	 209.76	 209.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 262.2;
	75518	 226.5	 35.5	 153.7	 -82.7	 1.0	 100.0	 1	 248.0	 205.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 248.0;
	75525	 76.76	 13.35	 85.7	 -59.0	 1.0	 100.0	 1	 76.76	 76.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.9;
	75529	 120.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	75529	 84.65	 16.35	 70.8	 -38.1	 1.0	 100.0	 1	 114.3	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.3;
	75534	 59.76	 0.0	 65.9	 -65.9	 1.0	 100.0	 1	 59.76	 59.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.4;
	75545	 38.36	 0.0	 42.3	 -42.3	 1.0	 100.0	 1	 38.36	 38.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.9;
	75552	 45.0	 0.0	 32.7	 -32.7	 1.0	 100.0	 1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	75552	 45.0	 0.0	 32.7	 -32.7	 1.0	 100.0	 1	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	75559	 28.08	 0.0	 32.0	 -32.0	 1.0	 100.0	 1	 28.08	 28.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.2;
	75559	 56.16	 0.0	 64.0	 -64.0	 1.0	 100.0	 1	 56.16	 56.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.4;
	75561	 10.25	 1.325	 8.47	 -5.82	 1.0	 100.0	 1	 17.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	75561	 10.25	 1.325	 8.47	 -5.82	 1.0	 100.0	 1	 17.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	75561	 10.25	 1.325	 8.47	 -5.82	 1.0	 100.0	 1	 17.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	75561	 10.25	 1.325	 8.47	 -5.82	 1.0	 100.0	 1	 17.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	75566	 26.25	 23.0	 23.0	 23.0	 1.0	 100.0	 1	 47.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	75566	 26.25	 23.0	 23.0	 23.0	 1.0	 100.0	 1	 47.5	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	75572	 18.4	 0.0	 9.2	 -9.2	 1.0	 100.0	 1	 36.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.8;
	75572	 18.4	 0.0	 9.2	 -9.2	 1.0	 100.0	 1	 36.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.8;
	75572	 18.4	 0.0	 9.2	 -9.2	 1.0	 100.0	 1	 36.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.8;
	75572	 48.45	 0.0	 31.8	 -31.8	 1.0	 100.0	 1	 96.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.9;
	75577	 5.0	 0.6	 3.88	 -2.68	 1.0	 100.0	 1	 8.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	75577	 5.0	 0.6	 3.88	 -2.68	 1.0	 100.0	 1	 8.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	75577	 5.0	 0.6	 3.88	 -2.68	 1.0	 100.0	 1	 8.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	75577	 5.0	 0.6	 3.88	 -2.68	 1.0	 100.0	 1	 8.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	75580	 7.6	 0.0	 4.95	 -4.95	 1.0	 100.0	 1	 15.0	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	75580	 7.6	 0.0	 4.95	 -4.95	 1.0	 100.0	 1	 15.0	 0.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	75583	 4.3	 2.45	 2.45	 2.45	 1.0	 100.0	 1	 6.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	75583	 4.3	 2.45	 2.45	 2.45	 1.0	 100.0	 1	 6.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	75583	 4.3	 2.45	 2.45	 2.45	 1.0	 100.0	 1	 6.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	75583	 4.3	 2.45	 2.45	 2.45	 1.0	 100.0	 1	 6.6	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	75585	 14.65	 1.85	 11.8	 -8.1	 1.0	 100.0	 1	 24.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.3;
	75588	 12.0	 12.4	 12.4	 12.4	 1.0	 100.0	 1	 20.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	75588	 14.5	 15.5	 15.5	 15.5	 1.0	 100.0	 1	 25.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	75593	 218.65	 30.35	 194.8	 -134.1	 1.0	 100.0	 1	 402.3	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.3;
	75595	 115.2	 0.0	 63.5	 -63.5	 1.0	 100.0	 1	 115.2	 115.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0;
	75600	 32.35	 3.05	 19.4	 -13.3	 1.0	 100.0	 1	 40.0	 24.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	75600	 71.0	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	75604	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	75604	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	75606	 7.75	 1.65	 7.13	 -3.83	 1.0	 100.0	 1	 11.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5;
	75606	 7.75	 1.65	 7.13	 -3.83	 1.0	 100.0	 1	 11.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5;
	75606	 7.75	 1.65	 7.13	 -3.83	 1.0	 100.0	 1	 11.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5;
	75608	 8.5	 2.15	 9.3	 -5.0	 1.0	 100.0	 1	 15.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	75608	 8.5	 2.15	 9.3	 -5.0	 1.0	 100.0	 1	 15.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	75610	 146.4	 13.05	 83.7	 -57.6	 1.0	 100.0	 1	 172.8	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	75619	 66.6	 17.35	 62.4	 -27.7	 1.0	 100.0	 1	 83.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.2;
	75619	 66.6	 17.35	 62.4	 -27.7	 1.0	 100.0	 1	 83.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.2;
	75623	 42.95	 3.45	 22.2	 -15.3	 1.0	 100.0	 1	 45.9	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.9;
	75623	 42.95	 3.45	 22.2	 -15.3	 1.0	 100.0	 1	 45.9	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.9;
	75623	 149.55	 13.5	 86.7	 -59.7	 1.0	 100.0	 1	 179.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 179.1;
	75624	 22.05	 0.0	 14.5	 -14.5	 1.0	 100.0	 1	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	75624	 22.05	 0.0	 14.5	 -14.5	 1.0	 100.0	 1	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	75624	 22.05	 0.0	 14.5	 -14.5	 1.0	 100.0	 1	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	75624	 22.05	 0.0	 14.5	 -14.5	 1.0	 100.0	 1	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	75625	 5.5	 0.83	 5.33	 -3.67	 1.0	 100.0	 1	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	75625	 5.5	 0.83	 5.33	 -3.67	 1.0	 100.0	 1	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	75625	 5.5	 0.83	 5.33	 -3.67	 1.0	 100.0	 1	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	75626	 15.4	 2.3	 14.9	 -10.3	 1.0	 100.0	 1	 30.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	75626	 15.4	 2.3	 14.9	 -10.3	 1.0	 100.0	 1	 30.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	75626	 15.4	 2.3	 14.9	 -10.3	 1.0	 100.0	 1	 30.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	75632	 34.5	 0.0	 21.4	 -21.4	 1.0	 100.0	 1	 65.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0;
	75632	 16.4	 4.1	 17.8	 -9.6	 1.0	 100.0	 1	 28.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8;
	75632	 6.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	75632	 6.0	 2.075	 7.5	 -3.35	 1.0	 100.0	 1	 10.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	76719	 29.5	 11.25	 40.5	 -18.0	 1.0	 100.0	 1	 54.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	76719	 17.125	 4.75	 18.5	 -9.0	 1.0	 100.0	 1	 27.0	 7.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	76719	 17.125	 4.75	 18.5	 -9.0	 1.0	 100.0	 1	 27.0	 7.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	76719	 17.125	 4.75	 18.5	 -9.0	 1.0	 100.0	 1	 27.0	 7.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	76719	 17.125	 4.75	 18.5	 -9.0	 1.0	 100.0	 1	 27.0	 7.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	76725	 38.05	 3.35	 21.4	 -14.7	 1.0	 100.0	 1	 44.1	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	76725	 49.8	 4.7	 30.3	 -20.9	 1.0	 100.0	 1	 62.6	 37.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.6;
	76728	 35.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	76728	 35.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	76733	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 48.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0;
	76733	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	76733	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	76733	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	76733	 0.0	 0.0	 0.0	 0.0	 1.0	 100.0	 0	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	76738	 15.1	 3.9	 16.9	 -9.1	 1.0	 100.0	 1	 27.2	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.2;
	76739	 16.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	76739	 16.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	76739	 16.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	76739	 18.4	 5.6	 20.1	 -8.9	 1.0	 100.0	 1	 26.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.8;
	76761	 107.0	 22.05	 95.4	 -51.3	 1.0	 100.0	 1	 154.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.0;
	76761	 107.0	 22.05	 95.4	 -51.3	 1.0	 100.0	 1	 154.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.0;
	76761	 139.0	 33.35	 144.4	 -77.7	 1.0	 100.0	 1	 233.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	76763	 112.5	 11.3	 72.6	 -50.0	 1.0	 100.0	 1	 150.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	76763	 112.5	 11.3	 72.6	 -50.0	 1.0	 100.0	 1	 150.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	76781	 14.05	 0.0	 9.1	 -9.1	 1.0	 100.0	 1	 27.6	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	76783	 16.875	 15.2	 15.2	 15.2	 1.0	 100.0	 1	 25.0	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	76783	 33.75	 30.3	 30.3	 30.3	 1.0	 100.0	 1	 50.0	 17.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	76804	 80.0	 0.0	 44.1	 -44.1	 1.0	 100.0	 1	 80.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	76827	 72.0	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	76827	 72.0	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	76827	 72.0	 16.35	 70.7	 -38.0	 1.0	 100.0	 1	 114.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	76827	 172.4	 22.25	 142.8	 -98.3	 1.0	 100.0	 1	 294.8	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 294.8;
	76833	 56.0	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0;
	76833	 56.0	 4.65	 30.0	 -20.7	 1.0	 100.0	 1	 62.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0;
	76833	 57.0	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0;
	76833	 57.0	 4.85	 31.0	 -21.3	 1.0	 100.0	 1	 64.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0;
	76837	 5.95	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	76837	 5.95	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	76837	 5.95	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	76837	 5.95	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.8	 0.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76839	 1.485	 0.475	 1.82	 -0.87	 1.0	 100.0	 1	 2.61	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.61;
	76841	 20.6	 1.7	 10.8	 -7.4	 1.0	 100.0	 1	 22.2	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2;
	76841	 20.6	 1.7	 10.8	 -7.4	 1.0	 100.0	 1	 22.2	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2;
	76841	 20.6	 1.7	 10.8	 -7.4	 1.0	 100.0	 1	 22.2	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.2;
	76841	 17.35	 2.25	 14.4	 -9.9	 1.0	 100.0	 1	 29.7	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7;
	76850	 123.5	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0;
	76850	 123.5	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0;
	76850	 217.5	 23.0	 147.7	 -101.7	 1.0	 100.0	 1	 305.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 305.0;
	76856	 31.7	 3.25	 21.0	 -14.5	 1.0	 100.0	 1	 43.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	76856	 31.7	 3.25	 21.0	 -14.5	 1.0	 100.0	 1	 43.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	76856	 31.7	 3.25	 21.0	 -14.5	 1.0	 100.0	 1	 43.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	76856	 31.7	 3.25	 21.0	 -14.5	 1.0	 100.0	 1	 43.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	76856	 31.7	 3.25	 21.0	 -14.5	 1.0	 100.0	 1	 43.4	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	76859	 36.0	 19.4	 19.4	 19.4	 1.0	 100.0	 1	 40.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	76859	 36.0	 24.8	 24.8	 24.8	 1.0	 100.0	 1	 40.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	76861	 17.35	 4.4	 19.0	 -10.2	 1.0	 100.0	 1	 30.7	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.7;
	78242	 35.2	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	78242	 76.4	 13.0	 56.3	 -30.3	 1.0	 100.0	 1	 90.8	 62.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.8;
	78258	 66.0	 11.0	 47.7	 -25.7	 1.0	 100.0	 1	 77.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.0;
	78260	 46.5	 10.75	 46.5	 -25.0	 1.0	 100.0	 1	 75.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	78268	 46.9	 10.0	 43.3	 -23.3	 1.0	 100.0	 1	 69.9	 23.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9;
	78268	 46.9	 10.0	 43.3	 -23.3	 1.0	 100.0	 1	 69.9	 23.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9;
	78273	 37.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	78274	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	78274	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	78277	 37.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	78277	 37.75	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	78278	 18.15	 1.7	 10.8	 -7.4	 1.0	 100.0	 1	 22.3	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.3;
	78278	 31.65	 7.9	 35.9	 -20.1	 1.0	 100.0	 1	 60.3	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.3;
	78278	 25.9	 7.1	 31.0	 -16.8	 1.0	 100.0	 1	 50.3	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.3;
	78279	 41.5	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	78279	 17.5	 4.3	 18.6	 -10.0	 1.0	 100.0	 1	 30.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	78281	 47.68	 0.0	 23.6	 -23.6	 1.0	 100.0	 1	 47.68	 47.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.6;
	78282	 39.95	 8.45	 36.5	 -19.6	 1.0	 100.0	 1	 58.9	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9;
	78283	 30.15	 4.4	 28.2	 -19.4	 1.0	 100.0	 1	 58.3	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.3;
	78287	 42.75	 26.9	 26.9	 26.9	 1.0	 100.0	 1	 55.5	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.5;
	78289	 31.7	 18.6	 18.6	 18.6	 1.0	 100.0	 1	 38.4	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4;
	78289	 20.55	 14.2	 14.2	 14.2	 1.0	 100.0	 1	 27.6	 13.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	78289	 20.55	 14.2	 14.2	 14.2	 1.0	 100.0	 1	 27.6	 13.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	78300	 38.0	 33.5	 33.5	 33.5	 1.0	 100.0	 1	 54.0	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	78303	 49.0	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	78303	 49.0	 7.55	 32.8	 -17.7	 1.0	 100.0	 1	 53.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	78305	 32.85	 8.55	 37.0	 -19.9	 1.0	 100.0	 1	 59.7	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.7;
	78305	 27.5	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	78307	 43.35	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 49.9	 36.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	78307	 43.2	 0.0	 16.4	 -16.4	 1.0	 100.0	 1	 49.9	 36.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	78309	 47.85	 7.15	 30.9	 -16.6	 1.0	 100.0	 1	 49.8	 45.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	78310	 48.35	 30.9	 30.9	 30.9	 1.0	 100.0	 1	 49.8	 46.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	78311	 48.35	 7.15	 30.9	 -16.6	 1.0	 100.0	 1	 49.8	 46.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	78313	 32.75	 3.75	 24.0	 -16.5	 1.0	 100.0	 1	 49.5	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.5;
	78316	 33.5	 7.05	 30.4	 -16.3	 1.0	 100.0	 1	 49.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	78318	 24.3	 3.65	 23.5	 -16.2	 1.0	 100.0	 1	 48.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.6;
	78320	 41.25	 6.95	 30.1	 -16.2	 1.0	 100.0	 1	 48.5	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.5;
	78322	 33.65	 6.75	 29.3	 -15.8	 1.0	 100.0	 1	 47.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.3;
	78323	 33.65	 3.55	 22.9	 -15.8	 1.0	 100.0	 1	 47.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.3;
	78328	 35.75	 3.5	 22.5	 -15.5	 1.0	 100.0	 1	 46.5	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	78333	 34.0	 27.9	 27.9	 27.9	 1.0	 100.0	 1	 45.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	78333	 34.0	 27.9	 27.9	 27.9	 1.0	 100.0	 1	 45.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	78333	 34.0	 27.9	 27.9	 27.9	 1.0	 100.0	 1	 45.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	78333	 34.0	 27.9	 27.9	 27.9	 1.0	 100.0	 1	 45.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	78335	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	78335	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	78335	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	78335	 8.6	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 11.2	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	78341	 21.95	 13.5	 13.5	 13.5	 1.0	 100.0	 1	 27.9	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.9;
	78341	 21.95	 13.5	 13.5	 13.5	 1.0	 100.0	 1	 27.9	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.9;
	78341	 15.9	 16.6	 16.6	 16.6	 1.0	 100.0	 1	 26.8	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.8;
	78341	 22.5	 30.0	 30.0	 30.0	 1.0	 100.0	 1	 40.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	78347	 31.85	 5.55	 24.0	 -12.9	 1.0	 100.0	 1	 38.7	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.7;
	78354	 18.9	 5.15	 22.2	 -11.9	 1.0	 100.0	 1	 35.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	78359	 8.6	 3.45	 12.4	 -5.5	 1.0	 100.0	 1	 16.5	 0.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	78359	 8.6	 3.45	 12.4	 -5.5	 1.0	 100.0	 1	 16.5	 0.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	78360	 24.75	 15.0	 15.0	 15.0	 1.0	 100.0	 1	 33.0	 16.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	78367	 22.5	 1.8	 11.4	 -7.8	 1.0	 100.0	 1	 23.5	 21.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.5;
	78367	 29.55	 3.4	 17.2	 -10.4	 1.0	 100.0	 1	 31.1	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.1;
	78368	 17.5	 14.3	 14.3	 14.3	 1.0	 100.0	 1	 23.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	78368	 23.2	 19.0	 19.0	 19.0	 1.0	 100.0	 1	 30.7	 15.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.7;
	78369	 16.05	 18.7	 18.7	 18.7	 1.0	 100.0	 1	 30.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.1;
	78371	 4.3	 1.04	 3.75	 -1.67	 1.0	 100.0	 1	 5.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0;
	78371	 4.3	 1.04	 3.75	 -1.67	 1.0	 100.0	 1	 5.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0;
	78371	 4.3	 1.04	 3.75	 -1.67	 1.0	 100.0	 1	 5.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0;
	78371	 4.3	 1.04	 3.75	 -1.67	 1.0	 100.0	 1	 5.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0;
	78371	 4.3	 1.04	 3.75	 -1.67	 1.0	 100.0	 1	 5.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0;
	78371	 4.3	 1.04	 3.75	 -1.67	 1.0	 100.0	 1	 5.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0;
	78373	 16.14	 2.25	 14.5	 -10.0	 1.0	 100.0	 1	 30.0	 2.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	78376	 8.165	 7.0	 7.0	 7.0	 1.0	 100.0	 1	 9.33	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.33;
	78376	 8.165	 7.0	 7.0	 7.0	 1.0	 100.0	 1	 9.33	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.33;
	78376	 8.165	 7.0	 7.0	 7.0	 1.0	 100.0	 1	 9.33	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.33;
	78377	 21.75	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 24.0	 19.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	78377	 24.25	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 27.0	 21.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	78378	 16.5	 16.9	 16.9	 16.9	 1.0	 100.0	 1	 22.5	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	78378	 7.075	 10.05	 10.05	 10.05	 1.0	 100.0	 1	 13.4	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.4;
	78378	 7.075	 10.05	 10.05	 10.05	 1.0	 100.0	 1	 13.4	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.4;
	78381	 21.6	 15.6	 15.6	 15.6	 1.0	 100.0	 1	 25.2	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.2;
	78381	 26.9	 19.7	 19.7	 19.7	 1.0	 100.0	 1	 31.8	 22.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.8;
	78384	 13.2	 15.4	 15.4	 15.4	 1.0	 100.0	 1	 24.9	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	78384	 13.2	 15.4	 15.4	 15.4	 1.0	 100.0	 1	 24.9	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	78388	 13.05	 1.75	 11.2	 -7.7	 1.0	 100.0	 1	 23.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	78388	 13.05	 1.75	 11.2	 -7.7	 1.0	 100.0	 1	 23.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	78388	 13.05	 1.75	 11.2	 -7.7	 1.0	 100.0	 1	 23.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	78388	 13.05	 1.75	 11.2	 -7.7	 1.0	 100.0	 1	 23.1	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	78389	 18.48	 0.0	 9.1	 -9.1	 1.0	 100.0	 1	 18.48	 18.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	78391	 13.55	 15.8	 15.8	 15.8	 1.0	 100.0	 1	 21.0	 6.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	78392	 10.5	 1.6	 10.2	 -7.0	 1.0	 100.0	 1	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.012000	  14.770000	 212.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.032000	  22.486000	 192.910000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.029000	  15.974000	 105.390000;
	2	 0.0	 0.0	 3	   0.033000	  16.010000	  94.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.002000	  14.879000	 1662.890000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.002000	  13.166000	 993.460000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  34.327000	 273.310000;
	2	 0.0	 0.0	 3	   0.053000	  34.327000	 273.310000;
	2	 0.0	 0.0	 3	   0.053000	  34.327000	 273.310000;
	2	 0.0	 0.0	 3	   0.053000	  34.327000	 273.310000;
	2	 0.0	 0.0	 3	   0.074000	  34.608000	 218.480000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.064000	  34.523000	 227.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.074000	  34.605000	 225.650000;
	2	 0.0	 0.0	 3	   0.074000	  34.605000	 225.650000;
	2	 0.0	 0.0	 3	   0.074000	  34.605000	 225.650000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.080000	  34.622000	 218.340000;
	2	 0.0	 0.0	 3	   0.080000	  34.622000	 218.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.083000	  34.672000	 214.560000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.133000	  34.913000	 114.680000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.005000	  14.879000	 573.640000;
	2	 0.0	 0.0	 3	   0.005000	  14.879000	 573.640000;
	2	 0.0	 0.0	 3	   0.005000	  14.879000	 573.640000;
	2	 0.0	 0.0	 3	   0.003000	  14.879000	 898.410000;
	2	 0.0	 0.0	 3	   0.003000	  14.879000	 898.410000;
	2	 0.0	 0.0	 3	   0.003000	  14.879000	 898.410000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	  14.879000	 7248.630000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.002000	  12.823000	 1158.630000;
	2	 0.0	 0.0	 3	   0.002000	  12.823000	 1158.630000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.054000	  34.387000	 271.580000;
	2	 0.0	 0.0	 3	   0.056000	  34.402000	 265.720000;
	2	 0.0	 0.0	 3	   0.057000	  34.433000	 259.140000;
	2	 0.0	 0.0	 3	   0.057000	  34.433000	 259.140000;
	2	 0.0	 0.0	 3	   0.057000	  34.433000	 259.140000;
	2	 0.0	 0.0	 3	   0.057000	  34.433000	 259.140000;
	2	 0.0	 0.0	 3	   0.101000	  34.704000	 198.260000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.062000	  34.496000	 240.710000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.073000	  34.526000	 226.220000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.108000	  34.775000	 181.330000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.002000	  13.326000	 923.600000;
	2	 0.0	 0.0	 3	   0.002000	  13.326000	 923.600000;
	2	 0.0	 0.0	 3	   0.002000	  13.326000	 923.600000;
	2	 0.0	 0.0	 3	   0.002000	  13.270000	 943.800000;
	2	 0.0	 0.0	 3	   0.002000	  13.312000	 864.780000;
	2	 0.0	 0.0	 3	   0.002000	  13.312000	 864.780000;
	2	 0.0	 0.0	 3	   0.002000	  13.312000	 864.780000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.010000	  14.537000	 247.640000;
	2	 0.0	 0.0	 3	   0.010000	  14.537000	 247.640000;
	2	 0.0	 0.0	 3	   0.006000	  13.669000	 418.350000;
	2	 0.0	 0.0	 3	   0.003000	  13.122000	 605.410000;
	2	 0.0	 0.0	 3	   0.012000	  14.750000	 215.780000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.015000	  15.035000	 180.210000;
	2	 0.0	 0.0	 3	   0.016000	  15.139000	 173.130000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.036000	  16.010000	  87.320000;
	2	 0.0	 0.0	 3	   0.036000	  16.010000	  87.320000;
	2	 0.0	 0.0	 3	   0.036000	  16.010000	  87.320000;
	2	 0.0	 0.0	 3	   0.036000	  16.010000	  87.320000;
	2	 0.0	 0.0	 3	   0.036000	  16.010000	  87.320000;
	2	 0.0	 0.0	 3	   0.036000	  16.010000	  87.320000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.073000	  16.010000	  42.310000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1299.000000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1299.000000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1299.000000;
	2	 0.0	 0.0	 3	   0.003000	  13.158000	 649.560000;
	2	 0.0	 0.0	 3	   0.003000	  13.184000	 687.280000;
	2	 0.0	 0.0	 3	   0.003000	  13.184000	 687.280000;
	2	 0.0	 0.0	 3	   0.003000	  13.158000	 649.560000;
	2	 0.0	 0.0	 3	   0.003000	  13.132000	 630.660000;
	2	 0.0	 0.0	 3	   0.003000	  13.132000	 630.660000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.007000	  13.850000	 372.190000;
	2	 0.0	 0.0	 3	   0.007000	  13.850000	 372.190000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.031000	  24.524000	 247.780000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.021000	  23.644000	 324.710000;
	2	 0.0	 0.0	 3	   0.021000	  23.644000	 324.710000;
	2	 0.0	 0.0	 3	   0.020000	  23.548000	 338.950000;
	2	 0.0	 0.0	 3	   0.008000	  14.084000	 316.540000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.082000	  25.287000	 137.650000;
	2	 0.0	 0.0	 3	   0.033000	  24.719000	 230.420000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.013000	  14.784000	 210.690000;
	2	 0.0	 0.0	 3	   0.004000	  13.430000	 500.630000;
	2	 0.0	 0.0	 3	   0.005000	  13.519000	 469.370000;
	2	 0.0	 0.0	 3	   0.003000	  13.139000	 635.090000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.020000	  23.543000	 339.200000;
	2	 0.0	 0.0	 3	   0.020000	  23.543000	 339.200000;
	2	 0.0	 0.0	 3	   0.013000	  22.680000	 469.160000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.020000	  23.551000	 338.880000;
	2	 0.0	 0.0	 3	   0.020000	  23.551000	 338.880000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.018000	  23.341000	 370.530000;
	2	 0.0	 0.0	 3	   0.018000	  23.341000	 370.530000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.027000	  24.223000	 271.680000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.452000	  23.294000	 1440.750000;
	2	 0.0	 0.0	 3	   0.002000	  13.291000	 835.830000;
	2	 0.0	 0.0	 3	   0.003000	  13.174000	 674.340000;
	2	 0.0	 0.0	 3	   0.003000	  13.174000	 674.340000;
	2	 0.0	 0.0	 3	   0.002000	  13.269000	 810.520000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1380.200000;
	2	 0.0	 0.0	 3	   0.004000	  13.126000	 595.540000;
	2	 0.0	 0.0	 3	   0.004000	  13.183000	 579.460000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  13.494000	 479.530000;
	2	 0.0	 0.0	 3	   0.006000	  13.836000	 376.070000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.007000	  13.928000	 358.400000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  13.987000	 352.310000;
	2	 0.0	 0.0	 3	   0.005000	  13.564000	 453.990000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.008000	  14.123000	 310.360000;
	2	 0.0	 0.0	 3	   0.011000	  14.648000	 231.470000;
	2	 0.0	 0.0	 3	   0.011000	  14.648000	 231.470000;
	2	 0.0	 0.0	 3	   0.004000	  13.189000	 579.210000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.012000	  14.753000	 215.030000;
	2	 0.0	 0.0	 3	   0.012000	  14.753000	 215.030000;
	2	 0.0	 0.0	 3	   0.012000	  14.753000	 215.030000;
	2	 0.0	 0.0	 3	   0.012000	  14.753000	 215.030000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.042000	  25.041000	 199.620000;
	2	 0.0	 0.0	 3	   0.042000	  25.041000	 199.620000;
	2	 0.0	 0.0	 3	   0.042000	  25.041000	 199.620000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.011000	  14.580000	 242.690000;
	2	 0.0	 0.0	 3	   0.031000	  16.004000	 101.130000;
	2	 0.0	 0.0	 3	   0.020000	  15.465000	 146.320000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.032000	  24.644000	 238.760000;
	2	 0.0	 0.0	 3	   0.070000	  25.226000	 148.530000;
	2	 0.0	 0.0	 3	   0.039000	  16.010000	  80.800000;
	2	 0.0	 0.0	 3	   0.013000	  14.814000	 205.820000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  16.010000	  50.500000;
	2	 0.0	 0.0	 3	   0.062000	  16.010000	  50.830000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.116000	  25.492000	  78.470000;
	2	 0.0	 0.0	 3	   0.116000	  25.492000	  78.470000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.124000	  25.535000	  68.040000;
	2	 0.0	 0.0	 3	   0.004000	  13.221000	 570.960000;
	2	 0.0	 0.0	 3	   0.004000	  13.221000	 570.960000;
	2	 0.0	 0.0	 3	   0.002000	  13.294000	 837.010000;
	2	 0.0	 0.0	 3	   0.002000	  13.294000	 837.010000;
	2	 0.0	 0.0	 3	   0.005000	  13.664000	 419.910000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.007000	  13.986000	 352.400000;
	2	 0.0	 0.0	 3	   0.007000	  13.986000	 352.400000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1327.880000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1327.880000;
	2	 0.0	 0.0	 3	   0.006000	  13.674000	 417.030000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.020000	  23.526000	 342.160000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.013000	  22.616000	 482.810000;
	2	 0.0	 0.0	 3	   0.059000	  25.134000	 173.590000;
	2	 0.0	 0.0	 3	   0.059000	  25.134000	 173.590000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.067000	  25.203000	 157.040000;
	2	 0.0	 0.0	 3	   0.067000	  25.203000	 157.040000;
	2	 0.0	 0.0	 3	   0.067000	  25.203000	 157.040000;
	2	 0.0	 0.0	 3	   0.069000	  25.214000	 150.920000;
	2	 0.0	 0.0	 3	   0.069000	  25.214000	 150.920000;
	2	 0.0	 0.0	 3	   0.038000	  25.009000	 210.520000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.098000	  25.370000	 118.690000;
	2	 0.0	 0.0	 3	   0.098000	  25.370000	 118.690000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1327.580000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1327.580000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.005000	  13.561000	 458.090000;
	2	 0.0	 0.0	 3	   0.005000	  13.508000	 471.020000;
	2	 0.0	 0.0	 3	   0.006000	  13.696000	 415.410000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.020000	  23.509000	 345.990000;
	2	 0.0	 0.0	 3	   0.020000	  23.509000	 345.990000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.030000	  24.472000	 251.650000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.019000	  23.422000	 356.340000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.060000	  25.138000	 173.520000;
	2	 0.0	 0.0	 3	   0.031000	  24.609000	 241.730000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1336.400000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1336.400000;
	2	 0.0	 0.0	 3	   0.002000	  13.266000	 798.280000;
	2	 0.0	 0.0	 3	   0.002000	  13.262000	 793.370000;
	2	 0.0	 0.0	 3	   0.002000	  13.262000	 793.370000;
	2	 0.0	 0.0	 3	   0.002000	  13.234000	 754.130000;
	2	 0.0	 0.0	 3	   0.002000	  13.279000	 817.310000;
	2	 0.0	 0.0	 3	   0.002000	  13.234000	 754.130000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.012000	  14.757000	 214.460000;
	2	 0.0	 0.0	 3	   0.019000	  15.409000	 151.120000;
	2	 0.0	 0.0	 3	   0.017000	  23.183000	 392.460000;
	2	 0.0	 0.0	 3	   0.034000	  24.820000	 227.120000;
	2	 0.0	 0.0	 3	   0.031000	  24.581000	 242.540000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.018000	  15.320000	 161.050000;
	2	 0.0	 0.0	 3	   0.060000	  16.010000	  52.050000;
	2	 0.0	 0.0	 3	   0.060000	  16.010000	  52.050000;
	2	 0.0	 0.0	 3	   0.029000	  15.960000	 107.030000;
	2	 0.0	 0.0	 3	   0.047000	  15.555000	 105.830000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  19.790000	 2076.300000;
	2	 0.0	 0.0	 3	   0.003000	  19.790000	 2076.300000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.006000	  21.017000	 906.200000;
	2	 0.0	 0.0	 3	   0.006000	  21.017000	 906.200000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.006000	  21.199000	 851.470000;
	2	 0.0	 0.0	 3	   0.006000	  21.199000	 851.470000;
	2	 0.0	 0.0	 3	   0.007000	  21.254000	 835.260000;
	2	 0.0	 0.0	 3	   0.007000	  21.254000	 835.260000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  20.147000	 1902.600000;
	2	 0.0	 0.0	 3	   0.007000	  21.290000	 821.730000;
	2	 0.0	 0.0	 3	   0.007000	  21.290000	 821.730000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.003000	  20.505000	 1748.200000;
	2	 0.0	 0.0	 3	   0.003000	  20.505000	 1748.200000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  21.873000	 614.130000;
	2	 0.0	 0.0	 3	   0.009000	  21.855000	 622.710000;
	2	 0.0	 0.0	 3	   0.010000	  21.909000	 600.510000;
	2	 0.0	 0.0	 3	   0.010000	  21.909000	 600.510000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  21.853000	 632.870000;
	2	 0.0	 0.0	 3	   0.009000	  21.853000	 632.870000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.006000	  21.181000	 856.800000;
	2	 0.0	 0.0	 3	   0.006000	  21.181000	 856.800000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.400000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.013000	  22.677000	 469.550000;
	2	 0.0	 0.0	 3	   0.013000	  22.677000	 469.550000;
	2	 0.0	 0.0	 3	   0.004000	  21.031000	 1187.190000;
	2	 0.0	 0.0	 3	   0.004000	  21.031000	 1187.190000;
	2	 0.0	 0.0	 3	   0.013000	  22.673000	 470.580000;
	2	 0.0	 0.0	 3	   0.013000	  22.673000	 470.580000;
	2	 0.0	 0.0	 3	   0.004000	  21.040000	 1207.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.014000	  22.842000	 445.990000;
	2	 0.0	 0.0	 3	   0.014000	  22.842000	 445.990000;
	2	 0.0	 0.0	 3	   0.004000	  21.025000	 1184.100000;
	2	 0.0	 0.0	 3	   0.004000	  21.025000	 1184.100000;
	2	 0.0	 0.0	 3	   0.007000	  21.363000	 796.700000;
	2	 0.0	 0.0	 3	   0.007000	  21.363000	 796.700000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.054000	  25.107000	 186.760000;
	2	 0.0	 0.0	 3	   0.054000	  25.107000	 186.760000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.010000	  21.891000	 603.600000;
	2	 0.0	 0.0	 3	   0.010000	  21.891000	 603.600000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  23.617000	 330.300000;
	2	 0.0	 0.0	 3	   0.021000	  23.617000	 330.300000;
	2	 0.0	 0.0	 3	   0.021000	  23.617000	 330.300000;
	2	 0.0	 0.0	 3	   0.007000	  21.384000	 796.540000;
	2	 0.0	 0.0	 3	   0.006000	  21.156000	 859.480000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.063000	  25.170000	 165.040000;
	2	 0.0	 0.0	 3	   0.031000	  24.504000	 248.250000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.770000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.040000	  25.024000	 207.350000;
	2	 0.0	 0.0	 3	   0.029000	  24.443000	 255.680000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.452000	  23.294000	 1440.750000;
	2	 0.0	 0.0	 3	   0.452000	  23.294000	 1440.750000;
	2	 0.0	 0.0	 3	   0.452000	  23.294000	 1440.750000;
	2	 0.0	 0.0	 3	   0.021000	  14.880000	 131.690000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.055000	  34.393000	 267.890000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.452000	  23.294000	 1440.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.060000	  34.481000	 248.230000;
	2	 0.0	 0.0	 3	   0.060000	  34.481000	 248.230000;
	2	 0.0	 0.0	 3	   0.060000	  34.481000	 248.230000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.116000	  58.907000	 379.000000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.040000	  16.010000	  80.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.082000	  34.640000	 215.940000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.086000	  34.694000	 205.870000;
	2	 0.0	 0.0	 3	   0.086000	  34.694000	 205.870000;
	2	 0.0	 0.0	 3	   0.086000	  34.694000	 205.870000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.047000	  15.553000	 110.850000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.106000	  34.752000	 196.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.049000	  16.010000	  65.650000;
	2	 0.0	 0.0	 3	   0.049000	  16.010000	  65.650000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.880000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.880000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.005000	  17.118000	 367.100000;
	2	 0.0	 0.0	 3	   0.103000	  25.545000	  79.840000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.880000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.116000	  34.988000	 127.930000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.116000	  34.815000	 154.340000;
	2	 0.0	 0.0	 3	   0.110000	  34.798000	 154.560000;
	2	 0.0	 0.0	 3	   0.109000	  34.782000	 163.500000;
	2	 0.0	 0.0	 3	   0.117000	  34.841000	 139.620000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.082000	  23.025000	  78.440000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.130000	  34.871000	 118.440000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.253000	  58.907000	 173.530000;
	2	 0.0	 0.0	 3	   0.063000	  25.170000	 164.810000;
	2	 0.0	 0.0	 3	   0.063000	  25.170000	 164.810000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.132000	  34.884000	 116.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.136000	  34.922000	 113.710000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.144000	  34.972000	 104.040000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.140000	  34.937000	 111.510000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.008000	  14.103000	 311.320000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  34.494000	 242.060000;
	2	 0.0	 0.0	 3	   0.062000	  34.494000	 242.060000;
	2	 0.0	 0.0	 3	   0.062000	  34.494000	 242.060000;
	2	 0.0	 0.0	 3	   0.062000	  34.494000	 242.060000;
	2	 0.0	 0.0	 3	   0.062000	  34.494000	 242.060000;
	2	 0.0	 0.0	 3	   0.062000	  34.494000	 242.060000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.138000	  34.926000	 111.760000;
	2	 0.0	 0.0	 3	   0.127000	  34.866000	 128.740000;
	2	 0.0	 0.0	 3	   0.003000	  13.125000	 606.130000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.016000	  15.139000	 173.130000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.044000	  16.010000	  71.440000;
	2	 0.0	 0.0	 3	   0.044000	  16.010000	  71.440000;
	2	 0.0	 0.0	 3	   0.044000	  16.010000	  71.440000;
	2	 0.0	 0.0	 3	   0.051000	  16.010000	  64.530000;
	2	 0.0	 0.0	 3	   0.051000	  16.010000	  64.530000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.054000	  34.353000	 272.840000;
	2	 0.0	 0.0	 3	   0.106000	  34.766000	 194.920000;
	2	 0.0	 0.0	 3	   0.119000	  25.502000	  75.370000;
	2	 0.0	 0.0	 3	   0.119000	  25.500000	  75.370000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.117000	  34.849000	 138.660000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.021000	  14.879000	 131.690000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  16.010000	  50.730000;
	2	 0.0	 0.0	 3	   0.031000	  16.010000	 101.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.012000	  14.750000	 215.780000;
	2	 0.0	 0.0	 3	   0.012000	  14.750000	 215.780000;
	2	 0.0	 0.0	 3	   0.012000	  14.750000	 215.780000;
	2	 0.0	 0.0	 3	   0.005000	  13.483000	 480.900000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.032000	  24.664000	 236.160000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.540000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.057000	  34.459000	 256.810000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.061000	  34.488000	 244.510000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.042000	  25.041000	 199.620000;
	2	 0.0	 0.0	 3	   0.057000	  25.128000	 185.550000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.059000	  15.604000	 102.710000;
	2	 0.0	 0.0	 3	   0.059000	  15.604000	 102.710000;
	2	 0.0	 0.0	 3	   0.126000	  34.866000	 133.780000;
	2	 0.0	 0.0	 3	   0.098000	  34.695000	 199.070000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.380000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	58575	 59351	 8.6e-05	 0.000979	 0.07365	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58575	 75433	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58575	 75433	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58576	 59160	 0.000721	 0.008664	 0.65174	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58576	 59251	 0.000886	 0.014964	 1.56707	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58576	 59251	 0.000886	 0.014964	 1.56707	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 0	 -30.0	 30.0;
	58576	 59338	 0.000171	 0.002143	 0.14147	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58576	 75436	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58576	 75436	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58577	 59107	 0.011521	 0.0675	 0.0184	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 58577	 0.067893	 0.164079	 0.04648	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58577	 75437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58577	 75437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58578	 59133	 0.002057	 0.03805	 3.89314	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58578	 59203	 0.000779	 0.013136	 1.37236	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58578	 75438	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58578	 75438	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58579	 59203	 0.000836	 0.01	 0.75314	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58579	 59332	 0.00035	 0.005593	 0.64897	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58579	 59332	 0.00035	 0.005593	 0.64897	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58579	 75440	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58579	 75440	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58580	 59162	 0.000864	 0.013886	 1.62607	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58580	 59162	 0.000864	 0.013886	 1.62607	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58580	 61455	 0.001764	 0.024521	 1.89814	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58580	 75442	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58580	 75442	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58581	 59204	 0.05575	 0.129671	 0.03959	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75440	 58581	 0.003343	 0.015336	 0.00393	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58581	 75444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58581	 75444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58582	 58597	 0.000636	 0.001679	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58582	 59303	 0.057943	 0.158086	 0.03491	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58582	 75445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58582	 75445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58582	 75460	 0.00055	 0.001543	 0.0004	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58583	 59079	 0.039771	 0.105214	 0.02466	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58583	 59252	 0.044621	 0.211964	 0.05123	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58583	 75446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58583	 75446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58584	 59272	 0.001107	 0.018507	 1.64736	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58584	 75447	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58584	 75447	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75448	 58584	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75448	 58584	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58585	 59350	 0.003364	 0.010214	 0.00224	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 58585	 0.005743	 0.015736	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58585	 75852	 0.00095	 0.002543	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58586	 59108	 0.000557	 0.006693	 0.5029	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58586	 61660	 0.0007	 0.009107	 0.58275	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58586	 75449	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58586	 75449	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58587	 59321	 0.003864	 0.009721	 0.00251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58587	 59323	 0.011264	 0.030679	 0.00676	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58588	 59133	 0.000157	 0.00225	 0.17963	 2385.0	 2504.25	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58588	 59140	 0.000207	 0.005257	 0.42931	 2893.0	 3037.65	 3182.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58588	 75451	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58588	 75451	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75452	 58588	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75452	 58588	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58589	 59222	 0.012021	 0.032279	 0.00731	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58589	 59223	 0.007421	 0.027007	 0.00827	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58589	 59273	 0.033014	 0.177914	 0.04393	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58589	 75453	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58589	 75453	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58590	 59302	 0.007321	 0.019943	 0.00439	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58590	 75454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58590	 75454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58591	 59216	 0.000629	 0.007829	 0.5375	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58591	 59251	 0.000793	 0.00945	 0.71129	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58591	 75455	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58591	 75455	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58592	 59107	 0.0487	 0.173671	 0.03874	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58592	 59149	 0.0595	 0.194764	 0.05194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58592	 75456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58592	 75456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58593	 59160	 0.002886	 0.038643	 2.59279	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58593	 59247	 0.000757	 0.009486	 0.65191	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58593	 75457	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58593	 75457	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58594	 59139	 0.021321	 0.085407	 0.02154	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58594	 59240	 0.026514	 0.10625	 0.0268	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58594	 75459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58594	 75459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58595	 75764	 0.004336	 0.016936	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58596	 59306	 0.000629	 0.007514	 0.56481	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58596	 75460	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58596	 75460	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58597	 59314	 0.070464	 0.18975	 0.04316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58597	 75462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58597	 75462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58598	 75777	 0.068793	 0.157357	 0.00384	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58599	 59122	 0.000229	 0.002514	 0.00082	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58599	 59123	 0.000514	 0.003236	 0.00088	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58599	 59124	 0.001571	 0.005136	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58600	 59247	 0.00165	 0.021564	 1.39686	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58600	 59289	 0.000729	 0.0094	 0.60156	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58600	 75463	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58600	 75463	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58601	 58602	 0.000293	 0.008043	 0.78529	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58601	 75465	 8.1e-05	 0.00647	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58601	 75465	 8.1e-05	 0.00647	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58602	 58610	 0.000457	 0.011886	 1.27257	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58602	 59923	 0.000307	 0.008336	 0.81414	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58602	 59959	 0.000236	 0.0059	 0.70368	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58602	 60302	 0.000171	 0.004321	 0.29579	 2783.0	 2922.15	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58602	 75466	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58602	 75466	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58602	 75466	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58603	 59850	 0.000521	 0.006779	 0.43314	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58603	 75469	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58603	 75469	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58604	 60408	 0.004636	 0.025086	 0.00609	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58604	 60411	 0.006757	 0.045286	 0.01388	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58604	 75470	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58604	 75470	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58604	 75496	 0.000214	 0.002707	 0.00084	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58604	 75496	 0.000214	 0.002707	 0.00084	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58605	 60055	 0.0008	 0.005486	 0.00969	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58605	 75471	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58605	 75471	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58605	 75494	 0.001407	 0.010529	 0.04074	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58605	 75984	 0.0073	 0.048771	 0.09212	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58606	 59849	 0.004157	 0.027743	 0.05233	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58606	 75472	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58606	 75472	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75473	 58606	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75473	 58606	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58606	 75494	 0.001386	 0.011571	 0.0361	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58607	 58608	 0.0	 1e-05	 0.0	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58607	 75474	 0.001136	 0.049987	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58607	 75474	 0.001136	 0.049987	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58608	 60242	 0.000914	 0.0106	 0.09166	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58608	 75475	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58608	 75475	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58609	 59589	 0.000929	 0.01345	 1.08143	 2385.0	 2504.25	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58609	 59651	 5e-05	 0.000621	 0.04281	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58609	 75476	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58609	 75476	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75477	 58609	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75477	 58609	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58610	 60034	 0.000429	 0.005521	 0.35259	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58610	 61623	 0.001221	 0.017114	 1.10221	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58610	 75478	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58610	 75478	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58610	 75478	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75479	 58610	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75479	 58610	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58611	 75480	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58611	 75480	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58611	 75657	 0.003336	 0.027636	 0.08729	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58611	 75707	 0.006671	 0.046821	 0.07985	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58612	 60239	 0.001607	 0.020279	 1.40893	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58612	 75481	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58612	 75481	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75482	 58612	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	75482	 58612	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 0	 -30.0	 30.0;
	58613	 60044	 0.001107	 0.020236	 0.20099	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58613	 60242	 0.0019	 0.021521	 0.19634	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58613	 75483	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58613	 75483	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75484	 58613	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75484	 58613	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58613	 75525	 0.000229	 0.002857	 0.04991	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58614	 58644	 0.001921	 0.024157	 0.00749	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58614	 59531	 0.0138	 0.180171	 0.05231	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58614	 59531	 0.0138	 0.180171	 0.05231	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58614	 59615	 0.01385	 0.055471	 0.01398	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58614	 59619	 0.002757	 0.030379	 0.01555	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58614	 75485	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58614	 75485	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58615	 59565	 0.0004	 0.005186	 0.33141	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58615	 60034	 0.000193	 0.002493	 0.15924	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58615	 75486	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58615	 75486	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58616	 58620	 0.002464	 0.013071	 0.00436	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58616	 75489	 0.001779	 0.016136	 0.00526	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58616	 75522	 0.009857	 0.040121	 0.00978	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58616	 75983	 0.035279	 0.09845	 0.02068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58617	 59376	 0.000243	 0.002907	 0.21813	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58617	 60058	 0.000779	 0.0093	 0.7001	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58617	 75487	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58617	 75487	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58618	 59565	 0.000379	 0.004893	 0.31268	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58618	 75489	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58618	 75489	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58619	 76067	 0.007029	 0.069671	 0.02135	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58619	 76068	 0.001514	 0.006171	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58621	 59511	 0.030371	 0.40465	 0.11795	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58621	 59511	 0.030371	 0.40465	 0.11795	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58621	 75491	 0.002529	 0.020957	 0.00551	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58621	 75904	 0.01415	 0.067464	 0.01601	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75489	 58622	 0.004836	 0.022886	 0.0055	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58622	 75491	 0.011264	 0.045114	 0.01137	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75481	 58623	 0.000407	 0.00465	 0.04234	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58623	 75490	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58623	 75490	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75491	 58623	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75491	 58623	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58624	 58654	 0.000514	 0.003464	 0.00638	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75482	 58624	 0.001293	 0.008379	 0.01669	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58624	 75492	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58624	 75492	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58624	 76078	 0.005964	 0.040721	 0.07342	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58625	 75983	 0.014186	 0.053936	 0.0151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58626	 59376	 0.000614	 0.018607	 2.30521	 4708.0	 4943.4	 5178.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58626	 59850	 0.000836	 0.009979	 0.75107	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58626	 75493	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58626	 75493	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75495	 58626	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75495	 58626	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58661	 58627	 0.001652	 0.019802	 1.4964	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58627	 60038	 0.000393	 0.010193	 1.089	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58627	 75496	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58627	 75496	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58628	 59691	 0.000336	 0.001821	 0.00045	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58628	 59692	 0.001093	 0.004871	 0.00132	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58628	 59778	 0.006814	 0.084086	 0.02719	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58628	 75497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58628	 75497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58629	 59520	 0.017279	 0.206207	 0.07235	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58629	 59520	 0.017279	 0.206207	 0.07235	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58629	 59620	 0.01595	 0.1203	 0.03344	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58629	 59659	 0.015229	 0.057914	 0.01622	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58629	 59774	 0.00565	 0.0566	 0.01885	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58630	 59562	 0.003321	 0.043186	 0.01249	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58630	 59562	 0.003321	 0.043186	 0.01249	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58630	 75498	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58630	 75498	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58630	 75901	 0.001186	 0.015457	 0.00446	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58630	 75901	 0.001186	 0.015457	 0.00446	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58631	 59773	 0.000214	 0.002643	 0.18135	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58631	 75499	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58631	 75499	 0.001965	 0.086478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58632	 59601	 0.026243	 0.129586	 0.03511	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58632	 59645	 0.014064	 0.056314	 0.01419	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58633	 58997	 0.000879	 0.010971	 0.75471	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58633	 60068	 0.000679	 0.010079	 0.65006	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58633	 75500	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58633	 75500	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75501	 58633	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75501	 58633	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58634	 59832	 0.025643	 0.078657	 0.00213	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58634	 60184	 0.009729	 0.022593	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58634	 76116	 0.001229	 0.004293	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58635	 59564	 0.014507	 0.17285	 0.06051	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58635	 59564	 0.014507	 0.17285	 0.06051	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58635	 75502	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58635	 75502	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58636	 76068	 0.002421	 0.015957	 0.004	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58637	 59594	 0.0002	 0.003021	 0.00176	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58637	 59611	 0.003486	 0.043821	 0.01358	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58637	 59611	 0.003486	 0.043821	 0.01358	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58637	 75503	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58637	 75503	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58638	 59774	 0.004914	 0.05105	 0.01579	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58638	 59776	 0.007464	 0.031071	 0.00969	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58638	 59845	 0.012357	 0.10405	 0.03086	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58638	 75504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58638	 75504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58639	 59681	 0.005671	 0.071371	 0.02213	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58639	 59681	 0.005671	 0.071371	 0.02213	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58639	 59685	 0.006421	 0.026693	 0.00623	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58639	 59686	 0.003743	 0.044493	 0.0155	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58639	 59686	 0.003743	 0.044493	 0.0155	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75502	 58640	 0.011343	 0.050557	 0.00086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75502	 58640	 0.011343	 0.050557	 0.00086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58640	 75927	 0.154557	 0.605329	 0.01347	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58640	 75927	 0.154557	 0.605329	 0.01347	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58641	 59761	 0.062514	 0.116257	 0.00272	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58641	 75948	 0.011629	 0.0239	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58642	 59463	 0.003771	 0.012579	 0.00319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58642	 59467	 0.007186	 0.056029	 0.01676	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58642	 59470	 0.002186	 0.01615	 0.00466	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58643	 59479	 0.054171	 0.185086	 0.00403	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58643	 61546	 0.04855	 0.1287	 0.00326	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58644	 59615	 0.005257	 0.050479	 0.01469	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58644	 60076	 0.0119	 0.152757	 0.04576	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58644	 60076	 0.0119	 0.152757	 0.04576	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58644	 75505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58644	 75505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58645	 59595	 0.13605	 0.532486	 0.01184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58645	 59595	 0.13605	 0.532486	 0.01184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58645	 59609	 0.027479	 0.078814	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58645	 59610	 0.037386	 0.200857	 0.00477	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58646	 59553	 0.142543	 0.636679	 0.01085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58646	 59553	 0.142543	 0.636679	 0.01085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58646	 59683	 0.096029	 0.336593	 0.00934	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58646	 59683	 0.096029	 0.336593	 0.00934	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58646	 59684	 0.07735	 0.096029	 0.00209	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75476	 58647	 1.4e-05	 0.000236	 0.00079	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58647	 75506	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58647	 75506	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75507	 58647	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75507	 58647	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58647	 79712	 0.005636	 0.114793	 0.43796	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58648	 59659	 0.003329	 0.012657	 0.00354	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58648	 59685	 0.023864	 0.092914	 0.02484	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58649	 59553	 0.0398	 0.155471	 0.00345	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58649	 59553	 0.0398	 0.155471	 0.00345	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75502	 58649	 0.009264	 0.032436	 0.0009	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75502	 58649	 0.009264	 0.032436	 0.0009	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58649	 75927	 0.156336	 0.612329	 0.01363	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58649	 75927	 0.156336	 0.612329	 0.01363	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75468	 58650	 0.179193	 0.528043	 0.01085	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58650	 75881	 0.055264	 0.193564	 0.00536	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58650	 75886	 0.0097	 0.058736	 0.00184	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58651	 76069	 0.040979	 0.0762	 0.00179	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58652	 75905	 0.020436	 0.090571	 0.00272	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58653	 59596	 0.07245	 0.283114	 0.00629	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58653	 59596	 0.07245	 0.283114	 0.00629	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58653	 59609	 0.049736	 0.131843	 0.00334	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58653	 59610	 0.03155	 0.140614	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58653	 59610	 0.03155	 0.140614	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75490	 58654	 0.000657	 0.00445	 0.0082	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58654	 75508	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58654	 75508	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75468	 58655	 0.053857	 0.16525	 0.00448	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58655	 75883	 0.053143	 0.207614	 0.00461	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58655	 75883	 0.053143	 0.207614	 0.00461	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58655	 76058	 0.022	 0.040914	 0.00096	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58656	 59463	 0.003886	 0.017714	 0.00562	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58656	 59470	 0.002264	 0.010793	 0.00313	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58656	 59475	 0.012236	 0.071714	 0.01955	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58657	 59841	 0.078529	 0.161414	 0.00308	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58657	 75956	 0.06645	 0.136579	 0.00261	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58657	 75981	 0.035407	 0.120964	 0.00263	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58658	 59775	 0.019657	 0.067157	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58658	 75957	 0.00915	 0.045414	 0.00109	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58659	 60613	 0.002293	 0.040314	 4.86121	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58659	 60613	 0.002293	 0.040314	 4.86121	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58659	 60907	 0.002436	 0.044593	 5.20757	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58659	 60981	 0.000157	 0.004371	 0.42574	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58659	 75509	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58659	 75509	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75510	 58659	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75510	 58659	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58660	 60202	 0.001571	 0.018186	 0.15966	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58660	 60423	 0.000764	 0.012907	 0.13362	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58660	 75511	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58660	 75511	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58660	 76606	 0.002407	 0.026314	 0.25922	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58661	 61150	 0.000564	 0.007036	 0.48269	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58661	 75514	 0.000106	 0.008461	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58661	 75514	 0.000106	 0.008461	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75515	 58661	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75515	 58661	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58662	 75516	 0.000212	 0.016922	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58662	 75516	 0.000212	 0.016922	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58663	 59958	 0.000164	 0.002521	 0.01314	 1083.0	 1137.15	 1191.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58663	 60333	 0.000557	 0.004764	 0.00906	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58663	 75518	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58663	 75518	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75519	 58663	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75519	 58663	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58664	 60965	 0.000236	 0.002914	 0.04674	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58664	 60971	 0.000264	 0.00325	 0.0521	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58664	 75520	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58664	 75520	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58665	 60069	 0.002486	 0.02835	 0.25692	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58665	 60242	 0.002636	 0.030479	 0.26822	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75478	 58665	 0.0011	 0.012086	 0.11748	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58665	 75522	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58665	 75522	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58666	 60956	 0.01375	 0.055064	 0.01388	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58666	 61633	 0.020971	 0.081636	 0.02182	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75522	 58666	 0.002229	 0.020214	 0.00659	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58667	 60976	 0.006464	 0.043143	 0.08145	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58667	 61154	 0.000329	 0.002121	 0.00423	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58667	 75523	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58667	 75523	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58668	 60388	 0.000564	 0.004986	 0.00884	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58668	 75524	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58668	 75524	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58669	 60239	 0.000164	 0.001929	 0.14492	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58669	 75525	 0.000163	 0.012221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58669	 75525	 0.000163	 0.012221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75526	 58669	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75526	 58669	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58670	 60455	 0.000307	 0.003679	 0.27601	 244.0	 244.0	 244.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58670	 61007	 0.000343	 0.004386	 0.28954	 244.0	 244.0	 244.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58670	 75527	 1e-06	 1e-05	 0.0	 900.0	 1125.0	 1350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58670	 75527	 1e-06	 1e-05	 0.0	 900.0	 1125.0	 1350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58671	 60957	 0.000293	 0.00345	 0.25909	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58671	 75529	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58671	 75529	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58672	 61014	 0.0005	 0.007907	 0.12991	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58672	 75530	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58672	 75530	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75531	 58672	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75531	 58672	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58673	 60976	 0.002557	 0.017464	 0.03145	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58673	 75532	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58673	 75532	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75533	 58673	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75533	 58673	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58673	 76146	 0.006336	 0.07355	 0.14166	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58674	 58697	 0.000171	 0.002664	 0.02775	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58674	 75534	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58674	 75534	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75529	 58675	 0.0011	 0.007693	 0.0131	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58675	 75535	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58675	 75535	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58676	 75536	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58676	 75536	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58676	 75730	 0.001457	 0.024693	 0.45012	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58677	 60200	 0.000493	 0.005843	 0.43908	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58677	 60239	 0.000729	 0.00875	 0.65817	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58677	 75537	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58677	 75537	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75538	 58677	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75538	 58677	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58678	 61593	 0.000507	 0.008379	 0.09059	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58678	 75539	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58678	 75539	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58679	 61019	 0.000743	 0.019571	 2.123	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58679	 75540	 8.1e-05	 0.00647	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58679	 75540	 8.1e-05	 0.00647	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58680	 58688	 2.1e-05	 0.000657	 0.06404	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58680	 58696	 0.000579	 0.015871	 1.56329	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58681	 60893	 0.033714	 0.187757	 0.05737	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58681	 60948	 0.011214	 0.085986	 0.02306	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58681	 60950	 0.0165	 0.066079	 0.01666	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58681	 60954	 0.014936	 0.049843	 0.01264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58681	 75543	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58681	 75543	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58681	 76140	 0.0189	 0.095036	 0.02476	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58681	 76612	 0.021771	 0.125286	 0.03556	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58682	 60956	 0.019793	 0.052321	 0.01225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75522	 58682	 0.000321	 0.001293	 0.00033	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58683	 60956	 0.012636	 0.038621	 0.00835	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75479	 58683	 0.006914	 0.037957	 0.01004	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58684	 60239	 9.3e-05	 0.0012	 0.07677	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58684	 75544	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58684	 75544	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75545	 58684	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75545	 58684	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58685	 61214	 0.006064	 0.042543	 0.07253	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58685	 61585	 0.000479	 0.003107	 0.00619	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58685	 75546	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58685	 75546	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58686	 60412	 0.001071	 0.020007	 1.64636	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58686	 61623	 9.3e-05	 0.002436	 0.23701	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58686	 75547	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58686	 75547	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58687	 60423	 0.000529	 0.005821	 0.05657	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58687	 61554	 0.001121	 0.018821	 0.19504	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58687	 75550	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58687	 75550	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75551	 58687	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75551	 58687	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58688	 61560	 0.000757	 0.012129	 1.41636	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58688	 75552	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58688	 75552	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58689	 58710	 0.003593	 0.0235	 0.00598	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58689	 60950	 0.022986	 0.059107	 0.01464	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58689	 75553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58689	 75553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58689	 76595	 0.011107	 0.096307	 0.03462	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58690	 61091	 0.000586	 0.002571	 0.00089	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58690	 61092	 0.000779	 0.004979	 0.00168	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58691	 58696	 0.000136	 0.002471	 0.20044	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58691	 60412	 0.000271	 0.003238	 0.24291	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58691	 61455	 0.0021	 0.027629	 1.80721	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58691	 75554	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58691	 75554	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58692	 61578	 0.003743	 0.014971	 0.00377	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58692	 61581	 0.008986	 0.029307	 0.00778	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58693	 61191	 0.016736	 0.052314	 0.01516	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58693	 61592	 0.006021	 0.016886	 0.00434	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75546	 58693	 2.9e-05	 0.000107	 3e-05	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58693	 76578	 0.004607	 0.027864	 0.00711	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58693	 76583	 0.002171	 0.009021	 0.00211	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58694	 61205	 0.005971	 0.043636	 0.01122	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58694	 61210	 0.01205	 0.092386	 0.02477	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58694	 75573	 0.014671	 0.101907	 0.02913	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58695	 58709	 0.01235	 0.068543	 0.02085	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58695	 58715	 0.001436	 0.011029	 0.00296	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58695	 60958	 0.029729	 0.152164	 0.03838	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58695	 75555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58695	 75555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58696	 75556	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58696	 75556	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58697	 61558	 0.002043	 0.02105	 0.23376	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58697	 75559	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58697	 75559	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58698	 58717	 0.000621	 0.005343	 0.01174	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58698	 75561	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58698	 75561	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58699	 61163	 0.01325	 0.043221	 0.01148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58699	 75562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58699	 75562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58699	 76396	 0.013707	 0.048786	 0.01085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58700	 61023	 0.001857	 0.00655	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58700	 61037	 0.001014	 0.00395	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58700	 76411	 0.000886	 0.005514	 0.00134	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58701	 60371	 0.000921	 0.002871	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58701	 76053	 0.004643	 0.016186	 0.00375	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58701	 76185	 0.001421	 0.003579	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58702	 59488	 0.004143	 0.014214	 0.00341	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58702	 60392	 0.001436	 0.004679	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58702	 75563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58702	 75563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58703	 61214	 0.00035	 0.002429	 0.00428	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58703	 61220	 0.001743	 0.011407	 0.02239	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58703	 75564	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58703	 75564	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58704	 61486	 0.027771	 0.075643	 0.01667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58704	 61489	 0.016886	 0.043771	 0.01324	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58704	 75565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58704	 75565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75517	 58705	 0.007271	 0.041321	 0.00075	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58706	 61328	 0.000179	 0.001957	 0.01903	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58706	 75566	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58706	 75566	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58707	 60438	 0.011886	 0.053979	 0.01874	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58707	 75568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58707	 75568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58707	 76213	 0.008071	 0.040814	 0.01136	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58708	 60435	 0.014007	 0.037114	 0.00094	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58708	 76209	 0.019307	 0.075121	 0.00126	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58709	 60287	 0.004093	 0.029171	 0.00904	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58709	 60291	 0.013029	 0.050686	 0.01354	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58709	 60403	 0.003321	 0.025014	 0.00694	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58709	 75569	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58709	 75569	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58709	 76148	 0.01065	 0.0556	 0.01339	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58709	 76199	 0.015114	 0.050943	 0.01266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58710	 60950	 0.006679	 0.035971	 0.00989	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58710	 60951	 0.009293	 0.057157	 0.01649	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58711	 61236	 0.001914	 0.003936	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58711	 61237	 0.009807	 0.022764	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58712	 60970	 0.001357	 0.010921	 0.02053	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58712	 60976	 0.0041	 0.027843	 0.05073	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58712	 75570	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58712	 75570	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75571	 58712	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75571	 58712	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58713	 61561	 0.003743	 0.0102	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58713	 61565	 0.000536	 0.00145	 0.00033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58713	 61573	 0.000707	 0.002821	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58713	 61574	 0.001964	 0.009007	 0.00231	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58713	 61575	 0.00205	 0.006907	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75552	 58714	 0.000221	 0.002271	 0.02519	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58714	 75572	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58714	 75572	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58715	 60283	 0.010979	 0.044671	 0.01089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58715	 60403	 0.010643	 0.041829	 0.01094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58715	 75575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58715	 75575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58716	 60977	 0.004521	 0.017186	 0.00481	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58716	 75576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58716	 75576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58717	 60980	 0.0008	 0.013264	 0.04898	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58717	 61496	 0.000671	 0.01065	 0.02234	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58717	 75577	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58717	 75577	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75578	 58717	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75578	 58717	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58718	 60830	 0.000864	 0.009779	 0.08905	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58718	 60889	 0.000521	 0.006221	 0.0571	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58718	 75579	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58718	 75579	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75557	 58719	 0.003229	 0.023264	 0.01943	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58719	 76136	 0.005064	 0.0521	 0.01478	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58719	 76137	 0.00385	 0.03305	 0.00941	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58720	 61215	 0.002243	 0.010671	 0.00309	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75564	 58720	 0.000343	 0.002121	 0.0006	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58721	 60978	 0.038314	 0.078414	 0.00193	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58722	 60983	 0.002986	 0.010564	 0.00238	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58722	 60987	 0.023593	 0.059329	 0.01538	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58722	 75582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58722	 75582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58723	 61196	 0.003307	 0.012029	 0.00369	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58723	 61199	 0.005386	 0.013536	 0.00351	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58723	 61201	 0.004193	 0.016786	 0.00423	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58723	 61202	 0.010764	 0.025943	 0.00733	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58724	 60438	 0.023471	 0.097629	 0.02281	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58724	 76213	 0.005464	 0.019871	 0.00609	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58725	 61436	 0.000171	 0.001907	 0.0185	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58725	 75583	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58725	 75583	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58726	 61474	 0.010057	 0.028843	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58727	 61057	 0.182293	 0.373571	 0.00921	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58727	 61153	 0.0737	 0.145936	 0.00214	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58727	 61171	 0.079507	 0.15745	 0.00231	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58727	 61538	 0.105093	 0.07445	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58727	 76397	 0.07875	 0.138514	 0.0026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58728	 61469	 0.006771	 0.033586	 0.0008	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58728	 76549	 0.064821	 0.0706	 0.00096	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58729	 60889	 0.000107	 0.00125	 0.01136	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58729	 60891	 0.000129	 0.001479	 0.0138	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58729	 75585	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58729	 75585	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58730	 60890	 0.007071	 0.024264	 0.00581	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58730	 60892	 0.003907	 0.019771	 0.0055	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58731	 61074	 0.009279	 0.026021	 0.0067	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58731	 61163	 0.003779	 0.009993	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58732	 61015	 0.038357	 0.133879	 0.0311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58732	 61486	 0.02655	 0.091129	 0.02185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58732	 75586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58732	 75586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58732	 76408	 0.007179	 0.029643	 0.00701	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58733	 60258	 0.0005	 0.005664	 0.05117	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58733	 75587	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58733	 75587	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58734	 60405	 0.000493	 0.005414	 0.05259	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58734	 60971	 0.001129	 0.019236	 0.19543	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58734	 75588	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58734	 75588	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58735	 61668	 0.000879	 0.016264	 1.33107	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58735	 61685	 0.001393	 0.018514	 1.80179	 2385.0	 2504.25	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58735	 61756	 0.000357	 0.009264	 0.98929	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58735	 75589	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58735	 75589	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75590	 58735	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75590	 58735	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58736	 61692	 0.000629	 0.007507	 0.56446	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58736	 75591	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58736	 75591	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58737	 61752	 0.0013	 0.016307	 1.12729	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58737	 75593	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58737	 75593	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75594	 58737	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75594	 58737	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58738	 61675	 0.003257	 0.021164	 0.04218	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58738	 75597	 0.001064	 0.0093	 0.01696	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58739	 61756	 0.000657	 0.011121	 1.08821	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58739	 61773	 0.0001	 0.00255	 0.27091	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58739	 75595	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58739	 75595	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58740	 61660	 0.002557	 0.044986	 6.00036	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58740	 61673	 0.000457	 0.005686	 0.3898	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58740	 61685	 0.00205	 0.037957	 3.88157	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58740	 61685	 0.00205	 0.037957	 3.88157	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58740	 75596	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58740	 75596	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75597	 58740	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75597	 58740	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58741	 58746	 3.6e-05	 0.0001	 3e-05	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 58741	 7.1e-05	 0.000464	 0.00016	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58741	 76631	 0.068843	 0.185364	 0.04216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58742	 61672	 0.006679	 0.075579	 0.02913	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58742	 61672	 0.006679	 0.075579	 0.02913	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58742	 61739	 0.071614	 0.28885	 0.0735	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58743	 58756	 0.001686	 0.010693	 0.0029	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58744	 61648	 0.000607	 0.007264	 0.54596	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58744	 75598	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58744	 75598	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58745	 61734	 0.02255	 0.078971	 0.02619	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58745	 61735	 0.0351	 0.096243	 0.02095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58745	 76630	 0.019386	 0.0544	 0.01401	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58746	 61667	 0.031671	 0.108757	 0.02609	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 58746	 0.000107	 0.000436	 0.00015	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58747	 61661	 0.029629	 0.112771	 0.03162	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 58747	 0.000336	 0.001214	 0.00037	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58747	 75600	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58747	 75600	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58747	 75601	 7e-06	 5e-05	 1e-05	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58748	 61778	 0.006164	 0.076129	 0.14254	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75593	 58748	 7.1e-05	 0.000493	 0.00084	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58748	 75601	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58748	 75601	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75602	 58748	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75602	 58748	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58749	 61772	 0.018521	 0.046571	 0.01206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75595	 58749	 0.002771	 0.006964	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58750	 61772	 0.0129	 0.032436	 0.00841	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75595	 58750	 0.006243	 0.016207	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58751	 58759	 0.001057	 0.007793	 0.00197	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58751	 61669	 0.034907	 0.121807	 0.02829	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58751	 61739	 0.034271	 0.190893	 0.05834	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58751	 76625	 0.064493	 0.166214	 0.04128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58752	 58766	 0.003271	 0.02035	 0.00574	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75598	 58752	 0.003607	 0.023571	 0.00599	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58753	 61707	 0.0017	 0.021279	 0.01446	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58753	 64462	 0.003614	 0.045243	 0.03077	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58753	 75603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58753	 75603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58754	 58766	 0.00175	 0.010014	 0.00333	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58754	 61672	 0.016643	 0.102436	 0.02959	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58755	 75608	 0.012593	 0.0561	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58756	 61736	 0.009493	 0.082271	 0.02956	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58756	 76629	 0.021686	 0.076671	 0.01729	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58756	 76630	 0.008907	 0.049107	 0.01148	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58757	 61662	 0.01595	 0.036179	 0.00072	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75600	 58757	 0.001721	 0.003536	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75602	 58757	 0.001386	 0.003971	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58758	 61673	 0.000529	 0.006807	 0.51128	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58758	 61746	 9.3e-05	 0.001143	 0.08554	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58758	 75604	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58758	 75604	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58759	 61672	 0.011743	 0.100829	 0.02874	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58760	 61720	 0.000486	 0.006171	 0.40801	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58760	 75605	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58760	 75605	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58761	 75606	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58761	 75606	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58761	 76687	 0.001521	 0.012093	 0.04134	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58762	 61681	 0.115193	 0.318286	 0.06991	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58762	 61739	 0.036764	 0.126293	 0.03031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58763	 61764	 0.001671	 0.019007	 0.17194	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58763	 66065	 0.005721	 0.084986	 0.79479	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58763	 75607	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58763	 75607	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58763	 76671	 0.000607	 0.006593	 0.06549	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75599	 58764	 0.020686	 0.059336	 0.00091	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75603	 58765	 0.009836	 0.022307	 0.00044	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58767	 76622	 0.024479	 0.062929	 0.00097	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58768	 76624	 0.242429	 0.48065	 0.00706	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58768	 76637	 0.334064	 0.534836	 0.01235	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58769	 61661	 0.025029	 0.066179	 0.01549	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58769	 61663	 0.051157	 0.1673	 0.04456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58769	 61695	 0.0735	 0.202079	 0.04412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58769	 61735	 0.046143	 0.192386	 0.04509	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 58769	 0.053421	 0.167471	 0.04869	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58769	 76629	 0.027436	 0.187636	 0.06428	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75600	 58770	 0.001807	 0.003364	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75602	 58770	 0.001407	 0.003214	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58771	 76660	 0.086986	 0.340014	 0.00755	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58772	 61671	 0.049286	 0.187979	 0.05286	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58772	 61672	 0.006371	 0.02185	 0.00524	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58773	 59013	 0.000886	 0.006043	 0.01089	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58773	 59016	 0.000986	 0.006593	 0.01243	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58773	 75609	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58773	 75609	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58774	 58830	 0.000486	 0.008564	 0.75407	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58774	 59075	 0.00225	 0.038357	 4.889	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58774	 59075	 0.00225	 0.038357	 4.889	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58774	 75610	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58774	 75610	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75611	 58774	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75611	 58774	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58775	 58779	 0.002221	 0.013	 0.00354	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58775	 58917	 0.008686	 0.022543	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58775	 75612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58775	 75612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58776	 59786	 0.002314	 0.0286	 0.46112	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75500	 58776	 0.000593	 0.006721	 0.06068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58776	 75613	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58776	 75613	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58777	 59059	 0.000621	 0.00745	 0.55986	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58777	 59255	 0.001064	 0.020536	 2.46943	 3450.0	 3622.5	 3795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58777	 75616	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58777	 75616	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58778	 59013	 0.0013	 0.008671	 0.01635	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58778	 75619	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58778	 75619	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75620	 58778	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75620	 58778	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58778	 75673	 0.008871	 0.059986	 0.11081	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58779	 58892	 0.010357	 0.060693	 0.01654	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58780	 58799	 0.008914	 0.02355	 0.00551	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58780	 58992	 0.009514	 0.036164	 0.01013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58780	 75621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58780	 75621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58781	 59078	 0.063714	 0.173893	 0.03842	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58781	 59242	 0.015764	 0.13545	 0.03864	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58781	 59312	 0.017843	 0.106379	 0.02803	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58781	 75622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58781	 75622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58781	 75671	 0.011907	 0.037229	 0.01079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58782	 59052	 0.091521	 0.235336	 0.00364	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58782	 59093	 0.0413	 0.137779	 0.00219	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58782	 75693	 0.032221	 0.163036	 0.00284	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75610	 58783	 0.000657	 0.006279	 0.01116	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58783	 75623	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58783	 75623	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58784	 59002	 0.033071	 0.164136	 0.00391	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58784	 59088	 0.026664	 0.054793	 0.00104	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58785	 61771	 0.00045	 0.005414	 0.40647	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58785	 75624	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58785	 75624	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58786	 58907	 0.033629	 0.08645	 0.00134	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58786	 58909	 0.046457	 0.095071	 0.00234	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58786	 76409	 0.075964	 0.10365	 0.00185	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58787	 75682	 0.051907	 0.222007	 0.00502	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58788	 58887	 0.00155	 0.015329	 0.26283	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58788	 58887	 0.00155	 0.015329	 0.26283	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58788	 58967	 0.001493	 0.017957	 0.17791	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58788	 75625	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58788	 75625	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58789	 59075	 0.0003	 0.003557	 0.26709	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58789	 59076	 0.000193	 0.002414	 0.16529	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58789	 75626	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58789	 75626	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58790	 58983	 0.002286	 0.01655	 0.00891	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58790	 75627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58790	 75627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58790	 75667	 0.0054	 0.051579	 0.01894	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58791	 59056	 0.0002	 0.002436	 0.17624	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58791	 59076	 0.0005	 0.006236	 0.42763	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58791	 75628	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58791	 75628	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58792	 58981	 0.021964	 0.0602	 0.01309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58792	 59070	 0.033814	 0.110414	 0.02936	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58792	 75629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58792	 75629	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58793	 58859	 0.043314	 0.109714	 0.00217	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58794	 58799	 0.008393	 0.027364	 0.00726	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58794	 75630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58794	 75630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58795	 58891	 0.001507	 0.012129	 0.00341	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58795	 58931	 0.001214	 0.00885	 0.00227	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58796	 75631	 0.013729	 0.0353	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58797	 58798	 0.000579	 0.007293	 0.00226	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58797	 58980	 0.001886	 0.024693	 0.00703	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58798	 58991	 0.009679	 0.104957	 0.04427	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58799	 58800	 0.004021	 0.015793	 0.00414	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58799	 75631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58799	 75631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58800	 59082	 0.014321	 0.05965	 0.01861	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58801	 59060	 0.004186	 0.010529	 0.00273	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58801	 59062	 0.002807	 0.007643	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58801	 75632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58801	 75632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58801	 75731	 0.0052	 0.013964	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58802	 58978	 0.006436	 0.033586	 0.00809	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58802	 58979	 0.019157	 0.057693	 0.01806	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58802	 58980	 0.031343	 0.078829	 0.02044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58803	 58811	 0.001043	 0.004064	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58803	 58814	 0.00465	 0.011207	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58803	 75633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58803	 75633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75633	 58804	 0.033314	 0.02985	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58805	 75635	 0.0566	 0.040093	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58806	 75638	 0.029779	 0.021093	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58807	 58808	 0.000207	 0.0014	 0.00252	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58807	 58820	 0.000136	 0.001321	 0.00467	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58807	 58846	 0.000193	 0.002236	 0.00901	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58808	 75634	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58808	 75634	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58809	 58810	 0.000693	 0.002829	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58809	 75637	 0.001164	 0.004829	 0.00113	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58810	 58811	 0.001171	 0.00485	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58810	 75635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58810	 75635	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58812	 58816	 0.024657	 0.019514	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75633	 58812	 0.017307	 0.021486	 0.00047	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58813	 58816	 0.041207	 0.029193	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58814	 75636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58814	 75636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58814	 75643	 0.003343	 0.010907	 0.00289	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58815	 58817	 0.013021	 0.009221	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75636	 58815	 0.017414	 0.020414	 0.00036	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75633	 58816	 0.038943	 0.03205	 0.00065	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75636	 58816	 0.017421	 0.0176	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58818	 58819	 0.030379	 0.025007	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58818	 58824	 0.021457	 0.0152	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75636	 58818	 0.033457	 0.0237	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75633	 58819	 0.020586	 0.020793	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58819	 75639	 0.007157	 0.016236	 0.00032	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58820	 75637	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75638	 58820	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58820	 75642	 0.000671	 0.00945	 0.01813	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58821	 58822	 0.00555	 0.01405	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75638	 58821	 0.002964	 0.009793	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58822	 58835	 0.021514	 0.017707	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58822	 75641	 0.009057	 0.01635	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58823	 58827	 0.001914	 0.004807	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58823	 75639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58823	 75639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58824	 58826	 0.018564	 0.012021	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58825	 58826	 0.022279	 0.014421	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75636	 58825	 0.024343	 0.019264	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58826	 75640	 0.005814	 0.010814	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58827	 58829	 0.001843	 0.008786	 0.00209	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58827	 75640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58827	 75640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58827	 75643	 0.002293	 0.008714	 0.00244	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58827	 75655	 0.013107	 0.072764	 0.02214	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58828	 75641	 0.024579	 0.01945	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75637	 58829	 0.001971	 0.009329	 0.00224	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58829	 75641	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58829	 75641	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58830	 58989	 0.000393	 0.007107	 0.48636	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58830	 75642	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58830	 75642	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58831	 58834	 0.006686	 0.019671	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58831	 58858	 0.016071	 0.036929	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58832	 58858	 0.031257	 0.022143	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58833	 58834	 0.004514	 0.019993	 0.00046	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58833	 75653	 0.006693	 0.038057	 0.00069	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58834	 58838	 0.0057	 0.025386	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75641	 58834	 0.008007	 0.028029	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75641	 58835	 0.026564	 0.021864	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58835	 75647	 0.009307	 0.039793	 0.0009	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58836	 58837	 0.001829	 0.005386	 0.00125	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58836	 58854	 0.000879	 0.009679	 0.0029	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75643	 58836	 0.003079	 0.0256	 0.00775	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58836	 75645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58836	 75645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58837	 58840	 0.001229	 0.004229	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75645	 58838	 0.002807	 0.017257	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75638	 58839	 0.012043	 0.027321	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58839	 75646	 0.005936	 0.009479	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58839	 75652	 0.020821	 0.052743	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58840	 58841	 0.001829	 0.007429	 0.00181	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58840	 58842	 0.001786	 0.004629	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58840	 75646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58840	 75646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58841	 58842	 0.001514	 0.0052	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58841	 75649	 0.001457	 0.006021	 0.00142	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58841	 75651	 0.001243	 0.006914	 0.0021	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58842	 75647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58842	 75647	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58843	 58902	 0.512743	 0.565393	 0.00756	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75633	 58843	 0.023721	 0.054243	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58844	 58848	 0.000207	 0.003893	 0.03739	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58844	 75648	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58844	 75648	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58844	 75700	 0.000393	 0.006264	 0.10287	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58845	 58852	 0.0011	 0.010529	 0.00386	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75648	 58845	 0.001536	 0.015764	 0.00447	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58846	 75649	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58846	 75649	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58846	 75650	 0.000143	 0.002279	 0.00757	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58847	 75652	 0.038479	 0.027257	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58848	 75650	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58849	 58857	 0.015814	 0.061757	 0.00137	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58849	 75654	 0.008721	 0.030543	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58849	 75684	 0.024186	 0.107771	 0.00183	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58850	 58852	 0.003393	 0.013586	 0.00342	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58850	 58854	 0.002736	 0.006886	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58850	 75653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58850	 75653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58851	 58853	 0.003336	 0.008821	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58851	 58951	 0.01035	 0.043021	 0.01004	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58851	 75654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58851	 75654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58852	 58853	 0.001936	 0.007743	 0.00195	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58853	 58854	 0.000543	 0.005393	 0.00146	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58853	 58956	 0.015643	 0.062664	 0.01579	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75654	 58855	 0.045979	 0.032571	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75654	 58856	 0.0275	 0.056286	 0.00139	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58856	 75686	 0.014393	 0.081821	 0.00148	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58857	 58859	 0.115193	 0.183936	 0.00424	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75644	 58858	 0.03175	 0.065243	 0.00124	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58859	 75656	 0.10275	 0.16405	 0.00378	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75610	 58860	 0.002114	 0.033436	 0.0702	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75642	 58860	 0.001614	 0.018771	 0.06676	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58860	 75655	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75656	 58860	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75644	 58861	 0.051221	 0.077686	 0.00111	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75500	 58862	 0.001386	 0.017643	 0.15536	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58862	 75657	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75501	 58863	 0.014886	 0.074821	 0.01949	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75614	 58863	 0.023407	 0.078121	 0.01983	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75658	 58863	 0.025564	 0.061629	 0.01741	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58863	 75751	 0.034643	 0.197693	 0.05754	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58864	 58868	 0.000486	 0.0059	 0.0191	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58864	 58966	 0.002643	 0.025186	 0.09211	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58865	 58873	 0.019307	 0.035907	 0.00084	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58865	 75665	 0.009271	 0.031671	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58866	 58867	 0.007986	 0.0245	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58866	 75665	 0.010286	 0.023529	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58867	 58897	 0.053379	 0.207707	 0.00347	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58868	 58869	 0.000229	 0.0028	 0.00906	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58868	 75660	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58868	 75660	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58869	 58878	 0.000386	 0.004393	 0.0164	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58869	 75661	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58869	 75661	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58870	 58881	 0.000736	 0.003364	 0.00086	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75661	 58870	 0.000536	 0.002443	 0.00063	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58871	 58876	 0.000193	 0.002207	 0.00124	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75661	 58871	 0.000307	 0.00335	 0.00171	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75660	 58872	 0.018543	 0.072421	 0.00161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75660	 58872	 0.018543	 0.072421	 0.00161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58872	 75662	 0.002843	 0.011086	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58872	 75662	 0.002843	 0.011086	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58873	 58874	 0.010043	 0.018679	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58873	 58884	 0.019057	 0.108329	 0.00196	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58873	 75663	 0.023207	 0.037229	 0.00069	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58874	 75662	 0.010229	 0.023743	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58875	 75662	 0.006764	 0.023686	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58875	 75662	 0.006764	 0.023686	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58875	 75663	 0.010936	 0.01675	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58875	 75665	 0.003664	 0.026543	 0.00066	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58876	 58877	 0.0002	 0.002086	 0.00159	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58876	 58879	 0.000457	 0.004393	 0.00145	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58876	 75662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58876	 75662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58877	 75663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58877	 75663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58877	 75664	 0.0003	 0.003293	 0.00293	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58878	 75664	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75665	 58878	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58878	 75740	 0.001279	 0.025264	 0.0972	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58879	 58880	 0.000364	 0.003314	 0.00121	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58880	 58881	 0.0005	 0.006521	 0.00189	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75626	 58880	 0.003764	 0.048729	 0.03877	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58881	 58882	 0.000936	 0.008593	 0.00344	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58882	 58885	 0.002164	 0.0197	 0.00716	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58883	 58885	 0.00735	 0.081193	 0.02221	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75625	 58883	 0.006021	 0.064957	 0.01861	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58883	 75690	 0.019093	 0.076471	 0.01928	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58884	 58890	 0.027307	 0.138979	 0.00315	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58885	 75666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58885	 75666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58886	 75667	 0.0082	 0.059893	 0.0154	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58886	 76651	 0.0245	 0.161643	 0.04066	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58887	 66478	 0.005243	 0.055286	 0.88036	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58887	 66478	 0.005243	 0.055286	 0.88036	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58887	 75667	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58887	 75667	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58888	 59031	 0.012957	 0.050929	 0.01333	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58888	 59078	 0.061543	 0.155079	 0.04029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75539	 58888	 0.060493	 0.182779	 0.05746	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58888	 75668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58888	 75668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75668	 58889	 0.112136	 0.208593	 0.00489	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58890	 75669	 0.018421	 0.088443	 0.00264	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58891	 58892	 0.018936	 0.0737	 0.0197	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58891	 58894	 0.013557	 0.049329	 0.01511	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58892	 58912	 0.036936	 0.1013	 0.02205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58892	 75692	 0.014164	 0.136221	 0.03973	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58893	 58896	 0.008964	 0.067543	 0.01875	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58893	 58898	 0.0323	 0.212021	 0.05421	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58893	 75710	 0.02885	 0.147207	 0.05357	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58894	 58896	 0.005864	 0.024386	 0.00569	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58894	 75669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58894	 75669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58895	 58897	 0.031421	 0.120414	 0.00341	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75669	 58895	 0.022314	 0.06845	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58895	 75670	 0.024907	 0.051193	 0.00098	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58896	 75670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58896	 75670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58896	 75692	 0.038443	 0.196536	 0.07174	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75665	 58897	 0.080593	 0.268957	 0.00426	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75670	 58897	 0.0582	 0.194186	 0.00308	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58898	 58899	 0.0123	 0.139464	 0.05389	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58898	 58899	 0.0123	 0.139464	 0.05389	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58899	 58901	 0.008843	 0.038757	 0.01334	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58899	 58935	 0.066871	 0.200914	 0.04545	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58899	 58991	 0.085807	 0.216707	 0.05644	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58900	 58901	 0.014293	 0.070493	 0.01907	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58900	 58936	 0.024321	 0.100507	 0.02381	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58900	 75695	 0.024079	 0.122757	 0.04462	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75447	 58903	 0.002179	 0.029736	 0.10224	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58903	 75671	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58903	 75671	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58903	 75675	 0.001021	 0.0133	 0.05006	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58904	 75672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58904	 75672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58904	 75674	 0.020529	 0.054271	 0.01271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58904	 75683	 0.024757	 0.097386	 0.02551	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58905	 58906	 0.000357	 0.004107	 0.04366	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58905	 58911	 0.000314	 0.00395	 0.03521	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58906	 61014	 0.001536	 0.027043	 0.25756	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58906	 61436	 0.003457	 0.038471	 0.36878	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58906	 75673	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75674	 58906	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58908	 58934	 0.004779	 0.031279	 0.06142	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75673	 58908	 0.002214	 0.017521	 0.06085	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58908	 76407	 0.003407	 0.027336	 0.09213	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58910	 59008	 0.021936	 0.05515	 0.01429	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75671	 58910	 0.026957	 0.092543	 0.02219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58910	 75676	 0.019786	 0.047693	 0.01347	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58911	 75675	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75676	 58911	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58911	 75821	 0.004521	 0.079507	 0.81043	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58912	 61770	 0.047643	 0.126086	 0.02956	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75624	 58912	 0.014629	 0.050179	 0.01203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58913	 58915	 0.037386	 0.06575	 0.00124	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75612	 58913	 0.109236	 0.148936	 0.00331	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58913	 75711	 0.060964	 0.113371	 0.00266	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58913	 75712	 0.043536	 0.0695	 0.0016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58914	 58920	 0.0585	 0.046293	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58914	 75681	 0.040514	 0.029286	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58914	 75712	 0.134636	 0.157864	 0.00274	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58915	 75677	 0.050729	 0.04015	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58915	 75678	 0.082829	 0.058671	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58916	 58917	 0.003364	 0.008657	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58916	 58922	 0.004657	 0.012307	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58916	 58999	 0.013957	 0.05765	 0.01364	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58916	 75677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58916	 75677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58917	 58918	 0.002236	 0.006086	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58917	 75678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58917	 75678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58918	 58922	 0.002407	 0.006364	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75678	 58919	 0.070807	 0.045843	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58919	 75679	 0.053714	 0.03805	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58920	 75681	 0.030543	 0.024171	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58921	 75679	 0.008707	 0.017243	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58921	 75681	 0.012829	 0.032979	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58922	 75679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58922	 75679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58923	 58974	 0.004993	 0.07495	 0.17646	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58923	 75680	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75681	 58923	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58923	 75709	 0.001514	 0.025536	 0.13469	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58924	 58925	 0.006014	 0.0123	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58924	 58927	 0.005857	 0.013607	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58925	 58926	 0.008136	 0.0186	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75679	 58925	 0.005614	 0.0161	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75669	 58926	 0.074357	 0.2605	 0.00721	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75681	 58926	 0.009657	 0.033807	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75681	 58927	 0.011043	 0.020536	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58928	 58930	 0.049579	 0.036479	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75681	 58928	 0.009564	 0.017779	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58929	 58932	 0.270079	 0.174957	 0.00333	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75681	 58929	 0.024329	 0.038836	 0.00089	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75680	 58931	 0.002429	 0.02085	 0.00594	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58933	 59246	 0.009157	 0.091579	 0.02457	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58933	 75682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58933	 75682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58933	 75683	 0.008107	 0.061693	 0.01939	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75530	 58934	 0.005421	 0.059321	 0.11541	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58934	 75683	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58934	 75683	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58935	 75694	 0.0895	 0.244871	 0.05427	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58935	 75695	 0.026457	 0.336843	 0.1062	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58935	 75695	 0.026457	 0.336843	 0.1062	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58935	 75742	 0.024671	 0.313586	 0.09863	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58935	 75742	 0.024671	 0.313586	 0.09863	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58936	 58978	 0.026329	 0.107243	 0.02616	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58937	 58938	 0.002621	 0.00695	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58937	 58939	 0.009586	 0.007586	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58937	 58941	 0.0095	 0.013843	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58937	 58946	 0.004343	 0.013321	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58937	 58949	 0.0144	 0.04805	 0.00076	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58937	 75684	 0.0038	 0.017707	 0.00041	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58938	 75684	 0.002793	 0.011936	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75642	 58940	 0.0018	 0.0184	 0.05846	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58940	 75684	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58940	 75684	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58940	 75701	 0.001357	 0.020457	 0.07351	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58941	 58944	 0.013729	 0.0113	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58942	 58944	 0.023386	 0.018507	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58943	 58944	 0.023364	 0.015121	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75684	 58944	 0.01755	 0.036064	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58945	 58946	 0.002493	 0.012379	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58945	 75685	 0.005343	 0.028679	 0.00068	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75684	 58947	 0.058393	 0.037807	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58948	 58965	 0.078271	 0.055443	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75684	 58948	 0.02285	 0.051829	 0.00104	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58949	 58964	 0.124164	 0.112036	 0.00187	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58950	 58957	 0.017093	 0.027286	 0.00063	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58951	 58952	 0.003207	 0.011657	 0.00357	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58951	 58956	 0.005036	 0.021914	 0.00624	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58951	 75685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58951	 75685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58952	 75686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58952	 75686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58952	 75702	 0.007379	 0.057836	 0.01481	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58953	 58954	 0.010971	 0.010779	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58954	 58955	 0.005693	 0.010007	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75686	 58954	 0.1262	 0.099886	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58954	 75687	 0.00825	 0.023657	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58955	 75687	 0.006057	 0.01245	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58956	 58958	 0.002836	 0.010307	 0.00316	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58956	 75687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58956	 75687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58956	 75702	 0.00635	 0.0492	 0.01724	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75687	 58957	 0.005907	 0.023071	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58957	 75688	 0.019464	 0.057229	 0.00117	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58958	 58963	 0.003936	 0.028721	 0.00739	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58958	 75688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58958	 75688	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58959	 58960	 0.06115	 0.055171	 0.00092	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58960	 58961	 0.151086	 0.1392	 0.00223	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58960	 75703	 0.033736	 0.089429	 0.00227	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58961	 75964	 0.1562	 0.274864	 0.00516	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58962	 58963	 0.003871	 0.031114	 0.00875	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58962	 75689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58962	 75689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58962	 75739	 0.004279	 0.036	 0.01066	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58966	 75690	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58966	 75690	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58966	 75691	 0.003057	 0.03655	 0.07228	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58998	 58967	 0.002243	 0.04235	 0.89336	 1959.0	 2056.95	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58967	 75691	 8.1e-05	 0.006451	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75692	 58967	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58967	 76671	 0.005486	 0.059093	 0.90736	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75628	 58968	 0.621193	 0.403536	 0.00768	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58969	 58970	 0.0465	 0.1178	 0.00234	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75628	 58969	 0.055514	 0.185214	 0.00294	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58969	 75729	 0.062071	 0.060979	 0.00103	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58970	 75693	 0.020164	 0.053443	 0.00136	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58971	 75693	 0.084979	 0.0602	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58971	 75727	 0.028129	 0.025207	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58972	 59053	 0.006529	 0.017764	 0.00391	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58972	 59089	 0.019343	 0.126621	 0.03226	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75626	 58972	 0.052971	 0.186114	 0.06201	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58972	 75693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58972	 75693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58973	 75749	 0.156229	 0.414757	 0.01054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58974	 59101	 0.003357	 0.070271	 0.24341	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58974	 75694	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58974	 75694	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75618	 58975	 0.018036	 0.040907	 0.00081	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58976	 59037	 0.071907	 0.193664	 0.04406	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58976	 59252	 0.072293	 0.198729	 0.04338	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58977	 58998	 0.006564	 0.068071	 1.16521	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58977	 58998	 0.006564	 0.068071	 1.16521	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58977	 59095	 0.004571	 0.048	 0.75979	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58977	 59095	 0.004571	 0.048	 0.75979	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58977	 75695	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58977	 75695	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75611	 58979	 0.016414	 0.066829	 0.01629	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75655	 58979	 0.0096	 0.059671	 0.01685	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75611	 58980	 0.003021	 0.024529	 0.00781	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75623	 58980	 0.007221	 0.042321	 0.01153	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75611	 58981	 0.009029	 0.035486	 0.00929	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75623	 58981	 0.009893	 0.029179	 0.00679	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58981	 75696	 0.004107	 0.018293	 0.00497	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75642	 58982	 0.003493	 0.054964	 0.11702	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	58982	 75696	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75697	 58982	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58983	 59067	 0.008979	 0.127179	 0.04223	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58984	 65924	 0.0493	 0.1926	 0.00427	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58984	 65924	 0.0493	 0.1926	 0.00427	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75627	 58984	 0.069757	 0.244386	 0.00677	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75627	 58984	 0.069757	 0.244386	 0.00677	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58985	 75698	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58985	 75698	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58986	 75699	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58986	 75699	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58987	 75726	 0.080486	 0.128493	 0.00296	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	58988	 58990	 0.025143	 0.066471	 0.01556	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58988	 75752	 0.0282	 0.0968	 0.02321	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59376	 58989	 0.000564	 0.018043	 1.98707	 4708.0	 4943.4	 5178.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58989	 75700	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58989	 75700	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58989	 75700	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75702	 58990	 0.012279	 0.030871	 0.008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58991	 58992	 0.012707	 0.077421	 0.01949	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	58991	 75704	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58991	 75704	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58992	 59005	 0.012457	 0.050693	 0.01236	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58992	 75705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58992	 75705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58993	 58994	 0.078186	 0.18915	 0.05364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	58993	 58996	 0.028221	 0.100486	 0.02237	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75617	 58993	 0.027314	 0.099471	 0.03049	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	58993	 75706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58993	 75706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58995	 58996	 0.006693	 0.066364	 0.02034	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	58995	 75708	 0.01515	 0.118229	 0.03542	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58996	 59063	 0.008393	 0.082036	 0.02304	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58997	 59249	 0.002643	 0.046593	 3.28971	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	58997	 75707	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75708	 58997	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58998	 75709	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75710	 58998	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58998	 75792	 0.007021	 0.0953	 0.88693	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	58999	 59000	 0.002707	 0.016843	 0.00475	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75710	 58999	 0.005007	 0.072279	 0.02296	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	58999	 75711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58999	 75711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59000	 59001	 0.0106	 0.027521	 0.00668	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75680	 59000	 0.011786	 0.044793	 0.01254	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59000	 75712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59000	 75712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59001	 75713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59001	 75713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59002	 59052	 0.063586	 0.247471	 0.00414	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75621	 59003	 0.1151	 0.291736	 0.00579	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59003	 75714	 0.036486	 0.084714	 0.00126	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59004	 75714	 0.039479	 0.025557	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59005	 59006	 0.005557	 0.020229	 0.00619	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59005	 75714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59005	 75714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59006	 75715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59006	 75715	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75620	 59007	 0.056707	 0.145793	 0.00226	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75619	 59008	 0.008086	 0.040214	 0.01299	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59009	 61423	 0.008736	 0.034	 0.00908	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75609	 59009	 0.004621	 0.012221	 0.00286	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75609	 59010	 0.005707	 0.015536	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75619	 59010	 0.005479	 0.014471	 0.00339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59011	 59015	 0.00475	 0.016793	 0.00379	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59011	 59030	 0.005621	 0.025043	 0.00681	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59011	 75716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59011	 75716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59011	 76538	 0.008443	 0.042407	 0.01104	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75716	 59012	 0.042793	 0.053121	 0.00116	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59012	 75718	 0.007343	 0.028686	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59013	 61446	 0.003057	 0.021079	 0.03723	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59013	 75717	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75718	 59013	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59014	 59015	 0.00355	 0.009379	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59014	 59017	 0.002336	 0.007786	 0.00197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75619	 59014	 0.010093	 0.024314	 0.00686	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75717	 59015	 0.001636	 0.0068	 0.00159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59016	 75719	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75720	 59016	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59017	 75721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59017	 75721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59018	 59022	 0.02395	 0.021607	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59018	 59023	 0.0048	 0.018664	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75720	 59018	 0.011093	 0.063064	 0.00114	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75721	 59018	 0.004664	 0.023729	 0.00054	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59019	 59020	 0.001593	 0.005471	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75719	 59019	 0.002307	 0.009529	 0.00226	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59019	 75722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59019	 75722	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59020	 59028	 0.005807	 0.019371	 0.00491	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75722	 59021	 0.043514	 0.030821	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59023	 59024	 0.021764	 0.021386	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59023	 59025	 0.022564	 0.014607	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59023	 59027	 0.097164	 0.068829	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59024	 59026	 0.026721	 0.021143	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59028	 59029	 0.0088	 0.045807	 0.01349	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75619	 59028	 0.011457	 0.040507	 0.00913	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59029	 59078	 0.018529	 0.085043	 0.02181	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59030	 59031	 0.012314	 0.051207	 0.01196	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59032	 59033	 0.029571	 0.054986	 0.00129	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59032	 76590	 0.015164	 0.059229	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59033	 59034	 0.050629	 0.081214	 0.0015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59034	 75723	 0.038843	 0.062	 0.00143	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59035	 59038	 0.002593	 0.020036	 0.04079	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59035	 75723	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59035	 75723	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59035	 76586	 0.001114	 0.012921	 0.02477	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59036	 75724	 0.073914	 0.246664	 0.00391	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59036	 76588	 0.068321	 0.318821	 0.00734	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59037	 75724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59037	 75724	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59038	 59058	 0.001679	 0.010614	 0.02224	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59039	 75725	 0.727214	 0.473	 0.00899	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59040	 59297	 0.048179	 0.230843	 0.06736	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59040	 75725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59040	 75725	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59040	 75754	 0.035843	 0.156386	 0.0447	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75695	 59041	 0.074621	 0.1979	 0.04651	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59041	 75754	 0.066121	 0.180493	 0.03989	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59042	 59043	 0.238257	 0.234193	 0.00396	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75706	 59042	 0.053107	 0.09875	 0.00231	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59043	 75736	 0.069221	 0.289164	 0.00835	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59044	 75736	 0.270293	 0.191571	 0.00303	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75705	 59045	 0.581536	 0.573379	 0.00969	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75680	 59046	 0.031571	 0.108407	 0.02601	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59046	 75726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59046	 75726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59047	 59049	 0.015586	 0.023371	 0.00042	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75726	 59047	 0.076657	 0.049629	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59048	 59049	 0.022921	 0.018136	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59048	 59051	 0.038943	 0.068486	 0.00129	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59049	 59051	 0.047979	 0.063057	 0.00086	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75712	 59049	 0.078186	 0.160036	 0.00394	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75726	 59049	 0.042421	 0.061814	 0.0014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75699	 59050	 0.0759	 0.296614	 0.00659	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75713	 59050	 0.046786	 0.228379	 0.00394	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75713	 59051	 0.038429	 0.087893	 0.00214	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59052	 59055	 0.032571	 0.125307	 0.00214	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59053	 59089	 0.020186	 0.130229	 0.03421	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59053	 75727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59053	 75727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59053	 75728	 0.004479	 0.030729	 0.00896	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75628	 59054	 0.436586	 0.283121	 0.00539	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59055	 75729	 0.014443	 0.038286	 0.00097	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59056	 75728	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59057	 75732	 0.154743	 0.232093	 0.00421	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75616	 59058	 0.003164	 0.020557	 0.04096	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59059	 61455	 0.00165	 0.019857	 1.51164	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59059	 75730	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59059	 75730	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59060	 59061	 0.001543	 0.003871	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59060	 60208	 0.001379	 0.004607	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59060	 75733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59060	 75733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59061	 59062	 0.001971	 0.005214	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59061	 75734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59061	 75734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59062	 75735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59062	 75735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59063	 60204	 0.013164	 0.06825	 0.01667	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75731	 59063	 0.013507	 0.099407	 0.02522	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59063	 75736	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59063	 75736	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59064	 59065	 0.019379	 0.015336	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59064	 59065	 0.019379	 0.015336	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75735	 59064	 0.033671	 0.035957	 0.00076	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59065	 59066	 0.022329	 0.02015	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59065	 59066	 0.022329	 0.02015	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75632	 59066	 0.029486	 0.047064	 0.00109	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59067	 65913	 0.020664	 0.266557	 0.08041	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59067	 65913	 0.020664	 0.266557	 0.08041	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59067	 75741	 0.011871	 0.134586	 0.05199	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59067	 75741	 0.011871	 0.134586	 0.05199	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75688	 59068	 0.26825	 0.173771	 0.00331	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75689	 59068	 0.109157	 0.174286	 0.00401	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75688	 59069	 0.23285	 0.165007	 0.00261	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75696	 59070	 0.0583	 0.156843	 0.03564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59071	 59095	 0.004471	 0.051986	 0.46111	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59071	 59786	 0.000814	 0.008614	 0.08991	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75700	 59071	 0.000657	 0.00775	 0.13547	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59071	 75737	 7.4e-05	 0.005882	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75738	 59071	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59071	 76073	 0.004543	 0.080179	 0.81064	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75738	 59072	 0.018564	 0.050557	 0.01114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59072	 75960	 0.004279	 0.011486	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75701	 59073	 0.003279	 0.0229	 0.03933	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75737	 59073	 0.003514	 0.023721	 0.0437	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59073	 75739	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59073	 75739	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59073	 75962	 0.00115	 0.010771	 0.01986	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75702	 59074	 0.012021	 0.0419	 0.00971	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75739	 59074	 0.008286	 0.022707	 0.00494	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59074	 75960	 0.013786	 0.049057	 0.01091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59075	 75740	 9.6e-05	 0.007684	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75741	 59075	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59076	 75742	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59076	 75742	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59077	 75743	 0.248979	 0.161279	 0.00307	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59078	 59079	 0.009543	 0.042964	 0.01144	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59079	 75743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59079	 75743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59080	 75744	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59081	 59087	 0.025986	 0.028586	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59081	 59088	 0.008736	 0.017957	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59081	 59090	 0.023614	 0.027686	 0.00048	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59082	 59083	 0.002636	 0.010029	 0.00281	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59082	 75746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59082	 75746	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59083	 59084	 0.00785	 0.032414	 0.00767	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59084	 59089	 0.006543	 0.039557	 0.0101	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59084	 75747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59084	 75747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59085	 75749	 0.016129	 0.036593	 0.00073	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75747	 59086	 0.01535	 0.07615	 0.00181	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59086	 75749	 0.023314	 0.059057	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59087	 75749	 0.018693	 0.0434	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59089	 59091	 0.000807	 0.009107	 0.00264	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59089	 75748	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59089	 75748	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75748	 59090	 0.007707	 0.022664	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59090	 75749	 0.003571	 0.020293	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75696	 59091	 0.031143	 0.386	 0.13081	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75696	 59091	 0.031143	 0.386	 0.13081	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59091	 75749	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59091	 75749	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59092	 59093	 0.0353	 0.108314	 0.00294	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75748	 59092	 0.017607	 0.078786	 0.00162	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75746	 59094	 0.459629	 0.298114	 0.00567	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59095	 75750	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75751	 59095	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75659	 59096	 0.490836	 0.348336	 0.00551	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75658	 59097	 0.015179	 0.099307	 0.02529	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75751	 59097	 0.015421	 0.090407	 0.02465	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75614	 59098	 0.025814	 0.103443	 0.02609	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59098	 75752	 0.019529	 0.081207	 0.01897	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75613	 59099	 0.005636	 0.0635	 0.11661	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75737	 59099	 0.001729	 0.016593	 0.03725	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59099	 75752	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75753	 59099	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75753	 59100	 0.43875	 0.31125	 0.00492	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59101	 75754	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59101	 75754	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59101	 75811	 0.00725	 0.077607	 0.15876	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59102	 59103	 0.00475	 0.019621	 0.00464	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75754	 59102	 0.01865	 0.065936	 0.01486	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59103	 75812	 0.028214	 0.133543	 0.04285	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59104	 59307	 0.09685	 0.257471	 0.06069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 59104	 0.072914	 0.199157	 0.04405	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59104	 75755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59104	 75755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75433	 59105	 0.018186	 0.128743	 0.22225	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59105	 75756	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59105	 75756	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59106	 59119	 0.0549	 0.138257	 0.03589	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75449	 59106	 0.009079	 0.026771	 0.00623	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59106	 75757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59106	 75757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75434	 59107	 0.091943	 0.23235	 0.06056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75756	 59107	 0.03385	 0.102	 0.03196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59107	 75759	 0.019171	 0.101729	 0.03401	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59108	 61752	 0.001007	 0.012043	 0.90829	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59108	 75758	 0.000229	 0.017175	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75759	 59108	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59109	 75760	 0.914571	 0.652107	 0.0103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59110	 59111	 0.010657	 0.138964	 0.04026	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59110	 59111	 0.010657	 0.138964	 0.04026	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59110	 59211	 0.025964	 0.098793	 0.02769	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59110	 75760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59110	 75760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59110	 75799	 0.023286	 0.123643	 0.04136	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59111	 75761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59111	 75761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59111	 75828	 0.014571	 0.183936	 0.05727	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59111	 75828	 0.014571	 0.183936	 0.05727	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75761	 59112	 0.435021	 0.3086	 0.00488	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59113	 59181	 0.161593	 0.475993	 0.00978	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59113	 75762	 0.0029	 0.014393	 0.00034	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59113	 75802	 0.118421	 0.363757	 0.00987	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59113	 75807	 0.160857	 0.368343	 0.00901	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59114	 59184	 0.000507	 0.007486	 0.48236	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59114	 59216	 0.000514	 0.007657	 0.49331	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59114	 75762	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59114	 75762	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59115	 59369	 0.089293	 0.2043	 0.00499	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59115	 75841	 0.070993	 0.217893	 0.00591	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59116	 59117	 0.022057	 0.055464	 0.01437	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59116	 59119	 0.012629	 0.065743	 0.01937	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 59116	 0.064829	 0.163379	 0.04246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59116	 75840	 0.01235	 0.099314	 0.02795	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 59117	 0.085536	 0.216	 0.05626	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59117	 75763	 0.013771	 0.037507	 0.00826	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59118	 59325	 0.002614	 0.0308	 0.05689	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59118	 61741	 0.009857	 0.069014	 0.11894	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59118	 75763	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59118	 75763	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59118	 76620	 0.013564	 0.092486	 0.16966	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 59119	 0.068786	 0.182321	 0.04282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59119	 76621	 0.038079	 0.134779	 0.03043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59119	 76661	 0.047693	 0.130029	 0.02869	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59120	 76631	 0.095271	 0.230929	 0.06563	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59121	 59122	 0.000529	 0.005714	 0.00164	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59121	 59129	 0.001529	 0.005821	 0.00163	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75452	 59121	 0.0032	 0.020493	 0.00689	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59121	 75764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59121	 75764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59122	 75765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59122	 75765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59123	 59124	 0.000979	 0.002457	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59123	 59135	 0.001921	 0.01545	 0.00434	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59123	 75766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59123	 75766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59123	 75771	 0.0005	 0.006607	 0.00404	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59124	 75767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59124	 75767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59125	 59131	 0.000793	 0.004807	 0.00123	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59125	 59136	 0.002779	 0.009721	 0.00322	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59125	 75768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59125	 75768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75768	 59126	 0.017043	 0.011036	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75766	 59127	 0.02085	 0.0135	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75765	 59128	 0.022079	 0.017471	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59129	 75769	 0.002236	 0.009093	 0.00221	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75451	 59130	 0.001171	 0.007664	 0.01504	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59130	 75769	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59130	 75769	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59131	 75770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59131	 75770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59131	 75771	 0.000807	 0.005729	 0.00157	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75770	 59132	 0.043221	 0.034207	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59133	 75771	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75772	 59134	 0.023479	 0.021036	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75769	 59135	 0.00165	 0.011436	 0.00326	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59135	 75773	 0.004793	 0.048314	 0.02966	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59136	 59137	 0.003757	 0.014293	 0.004	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59137	 59139	 0.023336	 0.093493	 0.02358	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75772	 59138	 0.016843	 0.090464	 0.00215	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59140	 59251	 0.000593	 0.009279	 0.90529	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59140	 75773	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59140	 75773	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59141	 59329	 0.019136	 0.072771	 0.02039	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75771	 59141	 0.020014	 0.081493	 0.01987	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75767	 59142	 0.002257	 0.007907	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75768	 59142	 0.003864	 0.010236	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59143	 59284	 0.024771	 0.157264	 0.04282	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75452	 59143	 0.0162	 0.102707	 0.02791	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75452	 59144	 0.074236	 0.172936	 0.05289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75463	 59145	 0.015679	 0.061629	 0.01613	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59145	 75776	 0.056186	 0.197514	 0.06585	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59146	 59147	 0.032514	 0.025729	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59147	 59150	 0.012314	 0.0229	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75464	 59147	 0.003671	 0.012529	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59148	 59150	 0.003986	 0.00925	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59148	 75774	 0.008071	 0.015007	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75463	 59149	 0.002271	 0.009364	 0.00221	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59149	 75774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59149	 75774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59151	 75836	 0.764143	 0.543757	 0.00859	 50.0	 50.2	 50.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59152	 59153	 0.014286	 0.054329	 0.01521	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59152	 59301	 0.012779	 0.152186	 0.05322	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59152	 59301	 0.012779	 0.152186	 0.05322	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59152	 75831	 0.044207	 0.15195	 0.03649	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59153	 75775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59153	 75775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59153	 75776	 0.066857	 0.20995	 0.06116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59154	 59339	 0.516593	 0.409557	 0.00516	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75775	 59154	 0.036871	 0.073007	 0.00107	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59155	 59156	 0.023571	 0.070936	 0.00139	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59155	 59317	 0.060243	 0.235371	 0.00522	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59155	 75830	 0.112764	 0.376471	 0.00597	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59156	 59157	 0.132407	 0.104793	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59156	 59208	 0.104429	 0.366114	 0.01015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59158	 61677	 0.005957	 0.113029	 0.50096	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59158	 75776	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75777	 59158	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59159	 59283	 0.020207	 0.140893	 0.25307	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59159	 75778	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59159	 75778	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59159	 75855	 0.023271	 0.160464	 0.29906	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59160	 75779	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59160	 75779	 0.001109	 0.057656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59161	 59206	 0.670993	 0.476964	 0.00754	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75439	 59161	 0.065171	 0.119379	 0.00206	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59162	 75780	 0.000124	 0.009885	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75439	 59163	 0.02875	 0.128129	 0.00218	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75439	 59163	 0.02875	 0.128129	 0.00218	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75781	 59163	 0.027143	 0.106014	 0.00235	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75781	 59163	 0.027143	 0.106014	 0.00235	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59164	 59166	 0.091529	 0.064836	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59165	 59166	 0.173486	 0.122921	 0.00194	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59166	 59167	 0.077729	 0.061514	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59166	 59168	 0.034157	 0.086529	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75781	 59166	 0.017157	 0.117771	 0.00215	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59168	 75783	 0.01665	 0.065043	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59169	 59170	 0.001457	 0.019871	 0.0071	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75438	 59169	 0.002071	 0.030943	 0.00916	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59169	 75782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59169	 75782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59170	 59171	 0.002007	 0.019943	 0.00542	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59170	 59175	 0.006043	 0.014557	 0.00411	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75780	 59170	 0.004836	 0.053507	 0.01606	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59170	 75783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59170	 75783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59171	 59173	 0.002636	 0.007086	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59171	 59179	 0.003971	 0.054086	 0.01934	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59171	 75784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59171	 75784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75783	 59172	 0.013779	 0.053614	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75784	 59172	 0.005686	 0.022564	 0.00064	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59173	 59174	 0.000557	 0.001507	 0.00034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59174	 75785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59174	 75785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59175	 75786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59175	 75786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59176	 59177	 0.040879	 0.076014	 0.00178	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59176	 59178	 0.0376	 0.115357	 0.00313	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75782	 59177	 0.067871	 0.126221	 0.00296	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59178	 59220	 0.027971	 0.134964	 0.00239	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75786	 59178	 0.0304	 0.118743	 0.00264	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59178	 75787	 0.049571	 0.238064	 0.00712	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59179	 59242	 0.011443	 0.082864	 0.04466	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59179	 75787	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59179	 75787	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59180	 59181	 0.248629	 0.2444	 0.00413	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59180	 75788	 0.009186	 0.04895	 0.00086	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59180	 75795	 0.136493	 0.088379	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59181	 75796	 0.21355	 0.320443	 0.00582	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59182	 75788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59182	 75788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59182	 75790	 0.001264	 0.008279	 0.00306	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59182	 75791	 0.006271	 0.059071	 0.0179	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59183	 59185	 0.000121	 0.001907	 0.14686	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59183	 59190	 0.00015	 0.002121	 0.14642	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59183	 75789	 0.000115	 0.009166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75790	 59183	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59184	 59185	 0.000171	 0.002614	 0.20098	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59184	 75791	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59184	 75791	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59186	 59187	 0.085929	 0.060871	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59187	 59191	 0.031271	 0.045571	 0.00103	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59188	 59190	 5e-05	 0.000621	 0.03957	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59188	 75792	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59189	 75796	 0.041636	 0.04535	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59190	 59279	 0.000307	 0.005236	 0.40775	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59190	 75796	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59190	 75796	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59191	 59193	 0.010643	 0.007693	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59191	 59194	 0.013336	 0.018193	 0.00033	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59191	 59196	 0.031093	 0.025593	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75796	 59191	 0.002479	 0.010929	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75794	 59192	 0.001807	 0.005321	 0.00124	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59192	 75797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59192	 75797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59192	 75812	 0.034036	 0.189557	 0.05792	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59193	 59194	 0.008393	 0.014764	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59194	 59197	 0.013071	 0.011793	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75797	 59194	 0.003593	 0.014021	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59195	 59197	 0.036493	 0.023629	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75797	 59198	 0.049086	 0.031779	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75797	 59199	 0.257186	 0.182271	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59200	 59248	 0.012321	 0.161907	 0.04626	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59200	 59248	 0.012321	 0.161907	 0.04626	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59200	 61743	 0.031129	 0.375979	 0.13426	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59200	 61743	 0.031129	 0.375979	 0.13426	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75694	 59200	 0.108443	 0.27465	 0.07177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59201	 75810	 0.489136	 0.317336	 0.00604	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59202	 59307	 0.073071	 0.184307	 0.04794	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75457	 59202	 0.093429	 0.2415	 0.06019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59202	 75809	 0.099321	 0.25945	 0.06344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59203	 75798	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59203	 75798	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75798	 59204	 0.016007	 0.048621	 0.01065	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59205	 59331	 0.569757	 0.404607	 0.00639	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75444	 59205	 0.094064	 0.238364	 0.00472	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59207	 59275	 0.172957	 0.438721	 0.00871	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75436	 59207	 0.124621	 0.426293	 0.00929	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59208	 75834	 0.08235	 0.352386	 0.00797	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59209	 59214	 0.245364	 0.457164	 0.01072	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59209	 59241	 0.164721	 0.473029	 0.00729	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59210	 75799	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59210	 75799	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59210	 75843	 0.004471	 0.084136	 0.36816	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75799	 59211	 0.010086	 0.038343	 0.01074	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59211	 75800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59211	 75800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59212	 59214	 0.1184	 0.243429	 0.00464	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75800	 59212	 0.028236	 0.052507	 0.00123	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75800	 59213	 0.054521	 0.038621	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59215	 75807	 0.120836	 0.0856	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59216	 59249	 0.000893	 0.010664	 0.80329	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59216	 59255	 0.001571	 0.02705	 2.95157	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59216	 59255	 0.001571	 0.02705	 2.95157	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59216	 75801	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75791	 59217	 0.030093	 0.122607	 0.02992	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75801	 59217	 0.022879	 0.091657	 0.02311	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75773	 59218	 0.018007	 0.147479	 0.04013	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75778	 59218	 0.062479	 0.221714	 0.05021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75779	 59218	 0.039093	 0.153979	 0.0404	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59219	 59221	 0.232557	 0.150629	 0.00286	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75453	 59220	 0.1283	 0.238693	 0.00559	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59220	 75803	 0.134536	 0.214843	 0.00495	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75453	 59221	 0.064264	 0.147007	 0.00359	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59222	 75803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59222	 75803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59223	 59224	 0.008507	 0.029657	 0.00688	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59224	 59225	 0.011421	 0.038486	 0.00956	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59225	 59226	 0.012821	 0.041836	 0.01111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59225	 75822	 0.036493	 0.099436	 0.02193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59226	 59273	 0.01145	 0.072579	 0.01971	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59226	 75818	 0.0335	 0.088586	 0.02075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59226	 75822	 0.019143	 0.076671	 0.01933	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59227	 59273	 0.041921	 0.200393	 0.04775	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59227	 59329	 0.033014	 0.137414	 0.03214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59228	 59231	 0.011786	 0.059236	 0.01542	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59228	 59287	 0.01875	 0.13715	 0.03533	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59228	 75804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59228	 75804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75459	 59229	 0.271379	 0.214871	 0.00271	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59230	 59231	 0.003643	 0.014171	 0.00379	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59230	 59239	 0.006614	 0.02515	 0.00704	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59230	 75805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59230	 75805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59231	 75806	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59231	 75806	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59232	 59236	 0.02445	 0.041193	 0.00059	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75806	 59232	 0.027621	 0.051357	 0.0012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59233	 59234	 0.014771	 0.065443	 0.00149	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75804	 59233	 0.123979	 0.287979	 0.00429	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59233	 75830	 0.089486	 0.396843	 0.00906	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59234	 59235	 0.014343	 0.029471	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59234	 59236	 0.0491	 0.075221	 0.00106	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59235	 59237	 0.030807	 0.0276	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59236	 75807	 0.0291	 0.039707	 0.00071	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59237	 75807	 0.064707	 0.058379	 0.00098	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59238	 59239	 0.005079	 0.020964	 0.00496	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75801	 59238	 0.022671	 0.093671	 0.02219	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59238	 75807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59238	 75807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59239	 59240	 0.004943	 0.016129	 0.00429	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75455	 59239	 0.012164	 0.028243	 0.00861	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75455	 59240	 0.004964	 0.016564	 0.0042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59240	 75808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59240	 75808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59240	 75814	 0.063479	 0.194579	 0.04222	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59241	 75844	 0.118657	 0.364486	 0.00989	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75442	 59242	 0.005557	 0.055657	 0.01854	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59243	 59246	 0.027879	 0.087214	 0.02529	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75442	 59243	 0.008186	 0.046357	 0.01149	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75671	 59243	 0.034486	 0.125657	 0.03856	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59244	 59246	 0.026443	 0.090771	 0.02176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75442	 59244	 0.011443	 0.037314	 0.00991	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75443	 59245	 0.168879	 0.386764	 0.00946	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59247	 75809	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59247	 75809	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59248	 75810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59248	 75810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59248	 75812	 0.01065	 0.115064	 0.06171	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59249	 75811	 0.00013	 0.010428	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75810	 59250	 0.123786	 0.328421	 0.00834	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75813	 59250	 0.123957	 0.380807	 0.01034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59251	 75814	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59251	 75814	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59252	 59291	 0.041664	 0.167207	 0.04226	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75446	 59253	 0.183721	 0.36405	 0.00535	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59254	 75816	 0.0143	 0.022821	 0.00053	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59255	 59256	 6.4e-05	 0.000807	 0.05546	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59255	 59272	 0.000279	 0.004986	 0.43761	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59255	 75815	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59256	 75817	 0.000115	 0.009166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75818	 59256	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59257	 59258	 0.068229	 0.048329	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59257	 59260	 0.017207	 0.012186	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59257	 59265	 0.017693	 0.01585	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75816	 59257	 0.008457	 0.022414	 0.00057	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59259	 59266	 0.017343	 0.019071	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59261	 59264	 0.00995	 0.023107	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75816	 59261	 0.00845	 0.019329	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59262	 59269	 0.002671	 0.012714	 0.00301	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59262	 59271	 0.012171	 0.041743	 0.01	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75815	 59262	 0.00235	 0.014221	 0.00363	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75818	 59262	 0.002014	 0.0153	 0.00481	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59262	 75819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59262	 75819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75819	 59263	 0.1581	 0.215621	 0.00479	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59263	 75823	 0.138221	 0.284221	 0.00542	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59264	 59266	 0.010971	 0.01645	 0.0003	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59264	 59268	 0.007686	 0.017443	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75819	 59264	 0.014807	 0.027536	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59265	 59266	 0.008086	 0.016014	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59266	 59267	 0.07615	 0.060264	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59266	 59268	 0.030636	 0.0217	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75816	 59266	 0.022214	 0.051579	 0.00076	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59268	 75820	 0.095136	 0.13865	 0.00314	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59269	 59270	 0.007836	 0.0435	 0.01323	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59269	 59271	 0.012214	 0.033471	 0.00728	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59270	 59273	 0.041457	 0.113729	 0.02476	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59270	 59288	 0.023693	 0.206243	 0.07459	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75815	 59270	 0.004993	 0.037614	 0.01044	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59271	 75820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59271	 75820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59272	 75821	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59272	 75821	 8.9e-05	 0.007096	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59273	 59287	 0.020064	 0.142171	 0.03911	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59274	 59275	 0.188764	 0.13375	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59275	 59361	 0.318671	 0.510043	 0.01177	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59276	 75825	 0.438429	 0.311021	 0.00491	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59277	 59280	 0.532686	 0.345729	 0.00658	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59277	 75825	 0.281129	 0.253843	 0.00425	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59277	 75827	 0.179164	 0.235571	 0.00323	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59278	 59279	 5.7e-05	 0.000757	 0.05183	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59278	 75824	 8.6e-05	 0.006874	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59279	 59327	 0.000607	 0.007764	 0.58364	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59279	 75826	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59280	 59281	 0.227486	 0.147343	 0.00281	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75778	 59282	 0.074693	 0.204043	 0.04514	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59283	 75828	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59283	 75828	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75440	 59284	 0.014436	 0.112407	 0.02924	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59284	 75829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59284	 75829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59285	 59330	 0.678436	 0.482293	 0.00762	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75444	 59285	 0.217579	 0.347729	 0.00801	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59286	 59310	 0.071407	 0.195029	 0.04313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59286	 61667	 0.082743	 0.219607	 0.05166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59288	 59321	 0.021007	 0.116714	 0.03555	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59288	 75830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59288	 75830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59289	 75831	 0.000419	 0.031452	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75820	 59290	 0.016621	 0.08895	 0.0027	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59290	 75833	 0.021936	 0.117836	 0.0028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59291	 59295	 0.0129	 0.073093	 0.01813	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59291	 75833	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59291	 75833	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75833	 59292	 0.033857	 0.14135	 0.00408	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59292	 75834	 0.094086	 0.175	 0.0041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59293	 59294	 0.029164	 0.089471	 0.00242	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75833	 59293	 0.02075	 0.091964	 0.00276	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59294	 59296	 0.051729	 0.148386	 0.00229	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59295	 59297	 0.0052	 0.063371	 0.02096	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59295	 59297	 0.0052	 0.063371	 0.02096	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75815	 59295	 0.03115	 0.148779	 0.04323	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59295	 75834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59295	 75834	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59296	 59298	 0.274657	 0.177929	 0.00339	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75834	 59296	 0.1412	 0.290364	 0.00554	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59298	 59299	 0.412793	 0.292793	 0.00463	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59300	 59301	 0.034857	 0.090557	 0.022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75460	 59300	 0.023507	 0.079243	 0.01971	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59301	 59302	 0.0266	 0.066886	 0.01734	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59302	 59303	 0.009207	 0.024329	 0.00569	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59303	 75835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59303	 75835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59304	 59315	 0.657914	 0.467607	 0.00739	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75445	 59304	 0.020107	 0.041143	 0.00101	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59306	 75837	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59306	 75837	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75456	 59308	 0.044036	 0.171329	 0.00286	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59308	 75838	 0.0818	 0.251093	 0.00681	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75456	 59309	 0.136643	 0.088479	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75756	 59310	 0.036721	 0.095414	 0.02318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59310	 75838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59310	 75838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59310	 76667	 0.086929	 0.239307	 0.05234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59311	 59313	 0.1198	 0.317814	 0.00807	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75446	 59311	 0.0566	 0.242086	 0.00547	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75448	 59312	 0.008829	 0.040493	 0.01038	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75453	 59313	 0.355629	 0.327971	 0.00526	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75823	 59313	 0.428364	 0.471986	 0.00631	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59316	 59317	 0.005486	 0.0183	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59316	 59318	 0.01335	 0.021414	 0.00039	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59316	 59320	 0.06015	 0.042607	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75802	 59316	 0.236957	 0.3788	 0.00874	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59318	 59319	 0.023507	 0.01665	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59318	 75839	 0.007421	 0.025979	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59319	 59320	 0.0212	 0.013729	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59319	 59322	 0.0469	 0.033221	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75802	 59319	 0.362257	 0.476879	 0.00654	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59320	 59322	 0.009821	 0.017264	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59321	 59323	 0.012343	 0.031021	 0.00804	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59321	 75839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59321	 75839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75839	 59322	 0.006771	 0.0237	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75812	 59323	 0.051079	 0.140179	 0.03054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59324	 59326	 0.0004	 0.005079	 0.33545	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59324	 61660	 0.001186	 0.019207	 2.27221	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59324	 61660	 0.001186	 0.019207	 2.27221	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59324	 75840	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75826	 59325	 0.005614	 0.065121	 0.12529	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59326	 59327	 0.000679	 0.008686	 0.65306	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59338	 59326	 0.001965	 0.025581	 1.6498	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59326	 59358	 0.000429	 0.005536	 0.35353	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59327	 75842	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59327	 75842	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75829	 59328	 0.461157	 0.3272	 0.00517	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59332	 75843	 0.000365	 0.029198	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75441	 59333	 0.230971	 0.163679	 0.00259	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75456	 59334	 0.787357	 0.571836	 0.00866	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75755	 59334	 0.664321	 0.527293	 0.00664	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75457	 59335	 0.059286	 0.154257	 0.03754	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75828	 59335	 0.048986	 0.165457	 0.04125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75458	 59336	 0.197964	 0.303443	 0.00426	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75458	 59337	 0.285964	 0.390679	 0.00699	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75836	 59337	 0.693407	 0.550521	 0.00693	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59338	 75845	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59338	 75845	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59340	 59343	 0.001771	 0.004271	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59340	 59348	 0.002764	 0.007536	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 59340	 0.001493	 0.006093	 0.00149	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59340	 75846	 0.001736	 0.004757	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59340	 75852	 0.006386	 0.01605	 0.00416	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59341	 59363	 0.001271	 0.00875	 0.01544	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75433	 59341	 0.000136	 0.000843	 0.00176	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59341	 75846	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59341	 75846	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59342	 59344	 0.027021	 0.017493	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59342	 75847	 0.008807	 0.010329	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59343	 59354	 0.00265	 0.007014	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59343	 75847	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59343	 75847	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59344	 75848	 0.014386	 0.009314	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59345	 59348	 0.001764	 0.004429	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59345	 75848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59345	 75848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59346	 59360	 0.202614	 0.131221	 0.0025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59346	 59361	 0.727786	 0.517636	 0.00818	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59346	 75850	 0.010914	 0.021386	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59347	 75850	 0.058	 0.041929	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59347	 75853	 0.021557	 0.023021	 0.00049	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59348	 75849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59348	 75849	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59349	 59350	 0.001707	 0.004121	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59349	 75850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59349	 75850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59351	 59358	 0.00035	 0.004536	 0.28974	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59351	 75851	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59352	 59353	 0.002414	 0.006579	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59352	 59362	 0.00295	 0.008093	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 59353	 0.001579	 0.006329	 0.00159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75846	 59353	 0.002157	 0.005914	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59354	 59362	 0.001636	 0.004829	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59354	 75854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59354	 75854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59355	 59356	 0.018271	 0.012943	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59355	 59366	 0.043829	 0.043057	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75854	 59355	 0.006107	 0.01135	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75848	 59357	 0.030943	 0.0337	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59357	 75859	 0.006564	 0.0174	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59358	 75855	 0.000114	 0.009124	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59359	 59360	 0.360979	 0.285921	 0.0036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75856	 59359	 0.0972	 0.2224	 0.00544	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75437	 59360	 0.898286	 0.640314	 0.01011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75755	 59361	 0.659336	 0.4285	 0.00815	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59362	 75857	 0.001321	 0.007921	 0.0024	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75855	 59363	 0.001	 0.011336	 0.02489	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59363	 75857	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59363	 75857	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75857	 59364	 0.001521	 0.004486	 0.00104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59364	 75858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59364	 75858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59365	 59366	 0.054543	 0.035314	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59366	 75859	 0.003779	 0.011586	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59367	 59368	 0.000614	 0.002064	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59367	 75859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59367	 75859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75857	 59368	 0.000886	 0.003371	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59369	 59370	 0.014193	 0.026386	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75856	 59370	 0.030714	 0.078964	 0.00122	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75450	 59371	 0.552221	 0.499743	 0.00836	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75858	 59371	 0.040879	 0.174793	 0.00395	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59372	 75860	 0.399043	 0.283014	 0.00447	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59373	 59375	 0.002657	 0.012179	 0.00312	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59373	 75860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59373	 75860	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59373	 75861	 0.006093	 0.038579	 0.01047	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59374	 59375	 0.008757	 0.076479	 0.02102	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75614	 59374	 0.019479	 0.132971	 0.04542	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75487	 59375	 0.025071	 0.088671	 0.01999	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59376	 75861	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59376	 75861	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75615	 59377	 0.30925	 0.279279	 0.00467	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59378	 75863	 0.021807	 0.034814	 0.0008	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59379	 75863	 0.046464	 0.032914	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59380	 59383	 0.041621	 0.032936	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59380	 59384	 0.00205	 0.015521	 0.00051	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59380	 75862	 0.016571	 0.064707	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59380	 75862	 0.016571	 0.064707	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59381	 75862	 0.065257	 0.04225	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59382	 59778	 0.006114	 0.06705	 0.01861	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59382	 75862	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59382	 75862	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59382	 75954	 0.002171	 0.021971	 0.00646	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59384	 59385	 0.001271	 0.009164	 0.0003	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59385	 59387	 0.001343	 0.009721	 0.00024	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59386	 75863	 0.021821	 0.015457	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59387	 59392	 0.001236	 0.007464	 0.00024	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59388	 75952	 0.071929	 0.070664	 0.00119	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59388	 75982	 0.186436	 0.120736	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59389	 75863	 0.055807	 0.1266	 0.00253	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59390	 59394	 0.316457	 0.20505	 0.0039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59391	 75958	 0.219921	 0.155843	 0.00246	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59392	 75863	 0.002843	 0.015221	 0.00046	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59393	 59756	 0.0529	 0.136214	 0.0338	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59393	 75863	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59393	 75863	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59393	 75954	 0.007464	 0.04095	 0.01083	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75863	 59394	 0.026771	 0.049779	 0.00116	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75863	 59395	 0.081629	 0.05285	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59396	 59942	 0.004793	 0.0205	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59396	 75864	 0.0038	 0.014843	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59397	 59398	 0.001164	 0.008521	 0.00219	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59397	 59410	 0.002221	 0.013236	 0.00348	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59397	 75864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59397	 75864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59398	 60090	 0.000836	 0.004343	 0.00114	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59398	 75865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59398	 75865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75864	 59399	 0.019243	 0.02055	 0.00044	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59399	 75866	 0.01225	 0.013086	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59400	 59944	 0.001171	 0.006643	 0.00164	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59400	 59945	 0.0009	 0.00315	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59400	 60086	 0.001186	 0.003571	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59400	 75866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59400	 75866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59401	 76104	 0.019057	 0.017193	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59402	 59403	 0.028029	 0.022179	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59403	 59405	 0.021357	 0.021571	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75864	 59403	 0.017571	 0.01245	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59404	 59406	 0.007521	 0.017207	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59404	 59446	 0.018957	 0.095907	 0.00167	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59404	 75867	 0.013621	 0.035007	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59405	 59415	 0.012171	 0.019436	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59406	 59420	 0.00895	 0.026314	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59407	 59420	 0.020371	 0.014429	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59408	 59443	 0.004479	 0.018493	 0.00438	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59408	 75867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59408	 75867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59408	 75874	 0.001479	 0.006107	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75867	 59409	 0.045807	 0.029657	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59410	 59417	 0.002921	 0.010029	 0.0024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59410	 59854	 0.001036	 0.006779	 0.00172	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59410	 75868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59410	 75868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59411	 59413	 0.008807	 0.016371	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59411	 75988	 0.005086	 0.013486	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59412	 59418	 0.001036	 0.004264	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59412	 59976	 0.001307	 0.005329	 0.0013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59413	 59975	 0.016164	 0.037536	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59413	 75869	 0.004521	 0.015457	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59414	 59416	 0.011143	 0.016236	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75868	 59414	 0.014493	 0.019771	 0.00035	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59415	 59416	 0.010929	 0.017529	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59416	 75869	 0.008036	 0.01865	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59417	 59418	 0.002407	 0.00825	 0.00198	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59417	 59430	 0.001207	 0.007086	 0.00193	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59417	 59852	 0.002564	 0.015521	 0.00396	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59417	 75869	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59417	 75869	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59417	 75874	 0.00175	 0.01855	 0.00551	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59419	 75873	 0.018921	 0.014971	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59420	 59422	 0.0055	 0.010229	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75869	 59420	 0.00725	 0.032121	 0.00096	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59421	 59422	 0.005486	 0.011271	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59421	 59425	 0.010043	 0.019879	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59422	 59424	 0.024307	 0.020007	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59423	 59424	 0.002329	 0.011357	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75867	 59423	 0.005993	 0.020986	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59424	 75872	 0.006707	 0.0257	 0.00073	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59425	 75872	 0.010743	 0.022071	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59426	 75870	 0.0339	 0.024014	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59427	 59457	 0.001207	 0.010707	 0.00588	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59427	 59974	 0.002886	 0.018879	 0.0048	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59427	 75870	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59427	 75870	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59427	 75871	 0.000236	 0.003029	 0.00153	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59428	 59431	 0.00735	 0.013671	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59428	 59440	 0.053279	 0.1095	 0.00209	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75870	 59428	 0.006486	 0.016429	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59428	 75872	 0.012507	 0.02325	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59428	 75873	 0.004664	 0.023593	 0.00041	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59429	 59437	 0.000121	 0.001864	 0.03335	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59429	 75871	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59429	 76029	 0.000393	 0.005921	 0.10768	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59430	 59432	 0.001464	 0.004443	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59430	 59979	 0.001121	 0.006443	 0.00182	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59430	 75873	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59430	 75873	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75873	 59431	 0.008729	 0.017864	 0.00044	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59432	 59979	 0.001457	 0.004393	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75870	 59433	 0.037886	 0.026836	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59434	 59978	 0.039457	 0.02795	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59435	 59436	 0.051036	 0.036157	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75870	 59435	 0.017057	 0.035057	 0.00067	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75872	 59435	 0.012057	 0.01925	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59435	 75881	 0.129714	 0.241321	 0.00565	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59437	 75874	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59437	 75874	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59437	 75949	 0.001671	 0.026586	 0.43899	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59438	 59441	 0.002743	 0.007043	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75874	 59438	 0.000929	 0.003707	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59438	 75875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59438	 75875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59439	 59442	 0.03215	 0.025443	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75875	 59439	 0.06115	 0.043314	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59440	 59453	 0.016157	 0.030043	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59440	 59454	 0.066693	 0.043179	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59440	 75876	 0.00445	 0.0152	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59441	 75876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59441	 75876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75876	 59442	 0.027679	 0.019607	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59443	 75877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59443	 75877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59444	 60146	 0.003136	 0.01115	 0.00248	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59444	 60149	 0.002043	 0.00715	 0.00237	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59444	 75878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59444	 75878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75878	 59445	 0.056643	 0.036671	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75878	 59446	 0.021229	 0.049286	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59446	 75885	 0.007964	 0.016371	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59446	 75977	 0.054629	 0.182271	 0.00289	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59447	 59449	 0.058779	 0.03805	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59448	 59452	 0.037879	 0.024521	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59449	 59450	 0.0304	 0.024057	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59449	 59451	 0.007593	 0.0156	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59451	 59452	 0.015464	 0.017014	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75877	 59451	 0.015864	 0.070314	 0.00211	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59451	 75880	 0.068414	 0.127229	 0.00298	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59453	 59455	 0.031321	 0.064364	 0.00123	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59455	 59462	 0.040879	 0.092736	 0.00185	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59456	 59457	 0.001443	 0.01	 0.00286	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59456	 60003	 0.001464	 0.010764	 0.00273	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59457	 59458	 0.001536	 0.01625	 0.00482	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59458	 59461	 0.001879	 0.021143	 0.00611	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59459	 75879	 0.034407	 0.0338	 0.00057	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59459	 76048	 0.061429	 0.098543	 0.00182	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59460	 59461	 0.001936	 0.007521	 0.00201	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59460	 75882	 0.008643	 0.035179	 0.00857	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59461	 60019	 0.006807	 0.048136	 0.01321	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59461	 75879	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59461	 75879	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75879	 59462	 0.019693	 0.060414	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59463	 59469	 0.005157	 0.026821	 0.0079	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59464	 59466	 0.02845	 0.0816	 0.00126	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75876	 59464	 0.028693	 0.088036	 0.00239	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59465	 59467	 0.003514	 0.021821	 0.00616	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59465	 59840	 0.004714	 0.029871	 0.00811	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59466	 75880	 0.007479	 0.0171	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59467	 59469	 0.007171	 0.038129	 0.00885	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59467	 75880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59467	 75880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59468	 75881	 0.236036	 0.186864	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59469	 75881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59469	 75881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59470	 75882	 0.002779	 0.0286	 0.00811	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59471	 59472	 0.000386	 0.004257	 0.04052	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59471	 75882	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59472	 59473	 0.000207	 0.002564	 0.02237	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59472	 60006	 0.001529	 0.016771	 0.16314	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59473	 75884	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59473	 75884	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59474	 59828	 0.011086	 0.079121	 0.02454	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59474	 59834	 0.00615	 0.033057	 0.00814	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75874	 59474	 0.002571	 0.023307	 0.01219	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59474	 75885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59474	 75885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59475	 59844	 0.017657	 0.081064	 0.02078	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59475	 75886	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59475	 75886	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59476	 59477	 0.017836	 0.01155	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59477	 59478	 0.018507	 0.026964	 0.00061	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59478	 59479	 0.040493	 0.119093	 0.00244	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59478	 59480	 0.052129	 0.096936	 0.00227	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59480	 59486	 0.033193	 0.094193	 0.00148	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59480	 61010	 0.038186	 0.163286	 0.00369	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75470	 59480	 0.091764	 0.441343	 0.01323	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59481	 59482	 0.102679	 0.066479	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59482	 59483	 0.054379	 0.049064	 0.00082	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59482	 59484	 0.096071	 0.19025	 0.00279	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59482	 59486	 0.033107	 0.068043	 0.0013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59483	 59484	 0.056293	 0.115207	 0.00284	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59483	 75887	 0.113486	 0.259707	 0.00634	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59484	 60036	 0.068793	 0.2688	 0.00596	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59485	 59496	 0.025779	 0.069236	 0.0157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75496	 59485	 0.021993	 0.085629	 0.02289	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59485	 75887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59485	 75887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59487	 59496	 0.00655	 0.049364	 0.0137	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75496	 59487	 0.003693	 0.030836	 0.008	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59488	 59489	 0.008186	 0.028086	 0.00673	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59489	 75888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59489	 75888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59489	 76199	 0.011393	 0.026443	 0.00806	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59490	 59492	 0.125907	 0.127186	 0.00169	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59490	 59493	 0.050664	 0.0928	 0.0016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75888	 59490	 0.018757	 0.090036	 0.00269	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59491	 59493	 0.023171	 0.059564	 0.00092	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59491	 59494	 0.042743	 0.068564	 0.00126	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59491	 59495	 0.039271	 0.091186	 0.00136	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59492	 59493	 0.006021	 0.01595	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59492	 76149	 0.0361	 0.067129	 0.00157	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59492	 76197	 0.014957	 0.066279	 0.00199	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59494	 60168	 0.173264	 0.190621	 0.00254	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59494	 76149	 0.031043	 0.078629	 0.00156	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59495	 60178	 0.074471	 0.172929	 0.00257	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59496	 60179	 0.004957	 0.047329	 0.01919	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59497	 59500	 0.0482	 0.1883	 0.00418	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59497	 59500	 0.0482	 0.1883	 0.00418	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59497	 59543	 0.100679	 0.449136	 0.00764	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59497	 59543	 0.100679	 0.449136	 0.00764	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59497	 75889	 0.071579	 0.250771	 0.00695	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59497	 75889	 0.071579	 0.250771	 0.00695	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59498	 59506	 0.026	 0.155807	 0.00375	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59498	 59544	 0.085807	 0.300707	 0.00834	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59498	 59544	 0.085807	 0.300707	 0.00834	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59498	 75889	 0.030964	 0.185571	 0.00446	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59498	 75902	 0.05095	 0.475014	 0.00921	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59499	 59500	 0.022343	 0.014464	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59500	 59502	 0.033057	 0.026164	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59500	 75889	 0.027507	 0.122586	 0.00208	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59500	 75889	 0.027507	 0.122586	 0.00208	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59501	 75889	 0.061914	 0.108893	 0.00204	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59503	 59504	 0.036307	 0.028729	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59503	 75889	 0.040307	 0.054993	 0.00099	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59505	 75889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59505	 75889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59505	 75901	 0.0339	 0.162	 0.0471	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75889	 59506	 0.006757	 0.033514	 0.0008	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75889	 59507	 0.046286	 0.1621	 0.00449	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75889	 59507	 0.046286	 0.1621	 0.00449	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59507	 75890	 0.062007	 0.242257	 0.00538	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59507	 75890	 0.062007	 0.242257	 0.00538	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59508	 59517	 0.027807	 0.305121	 0.13096	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59508	 59517	 0.027807	 0.305121	 0.13096	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59508	 75890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59508	 75890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59508	 75901	 0.019179	 0.253	 0.07268	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59508	 75901	 0.019179	 0.253	 0.07268	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59509	 59514	 0.104271	 0.365564	 0.01014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59509	 59514	 0.104271	 0.365564	 0.01014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59509	 59560	 0.096936	 0.378986	 0.00841	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59509	 59560	 0.096936	 0.378986	 0.00841	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59509	 59621	 0.157764	 0.705057	 0.01202	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59509	 59621	 0.157764	 0.705057	 0.01202	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 59509	 0.145593	 0.511071	 0.01419	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 59509	 0.145593	 0.511071	 0.01419	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75890	 59509	 0.035093	 0.254264	 0.00639	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59510	 59511	 0.010514	 0.068786	 0.0175	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59510	 60181	 0.017293	 0.134721	 0.03508	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59511	 59512	 0.003879	 0.050264	 0.01989	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59511	 75891	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59511	 75891	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59512	 59528	 0.003164	 0.023929	 0.01175	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59513	 60181	 0.019414	 0.245743	 0.07684	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59513	 60181	 0.019414	 0.245743	 0.07684	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59513	 75892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59513	 75892	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59514	 59515	 0.035014	 0.212071	 0.00664	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59514	 59516	 0.05585	 0.379707	 0.00941	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59515	 59516	 0.044107	 0.211807	 0.00634	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59516	 75893	 0.089657	 0.350479	 0.00778	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59516	 75893	 0.089657	 0.350479	 0.00778	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59517	 59626	 0.021793	 0.206021	 0.0628	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59517	 67513	 0.009057	 0.1189	 0.03391	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59517	 67513	 0.009057	 0.1189	 0.03391	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59517	 75893	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59517	 75893	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59518	 59635	 0.075014	 0.379793	 0.00661	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75893	 59518	 0.048907	 0.171279	 0.00474	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59519	 59539	 0.12995	 0.508521	 0.01131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59519	 59539	 0.12995	 0.508521	 0.01131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75892	 59519	 0.174471	 0.683857	 0.01524	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75892	 59519	 0.174471	 0.683857	 0.01524	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59521	 0.005457	 0.068686	 0.02129	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59521	 0.005457	 0.068686	 0.02129	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59523	 0.007171	 0.090314	 0.02801	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59523	 0.007171	 0.090314	 0.02801	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59637	 0.012693	 0.15115	 0.05285	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59637	 0.012693	 0.15115	 0.05285	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59638	 0.028721	 0.379136	 0.11188	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59520	 59638	 0.028721	 0.379136	 0.11188	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59521	 59523	 0.001821	 0.026343	 0.00836	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59521	 59542	 0.007236	 0.081871	 0.03156	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59521	 59542	 0.007236	 0.081871	 0.03156	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59522	 59523	 0.002457	 0.031457	 0.00939	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59522	 59523	 0.002457	 0.031457	 0.00939	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59522	 59541	 0.002564	 0.031636	 0.01022	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59522	 59541	 0.002564	 0.031636	 0.01022	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59524	 59533	 0.109479	 0.225079	 0.00429	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59524	 75934	 0.156943	 0.398014	 0.00789	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59525	 75895	 0.019707	 0.119343	 0.00374	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59525	 75924	 0.029721	 0.276814	 0.00536	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59526	 59527	 0.001764	 0.013529	 0.00362	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59526	 59528	 0.00405	 0.024486	 0.00625	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59526	 59619	 0.00215	 0.031779	 0.01094	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59527	 59528	 0.0015	 0.010607	 0.00291	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59528	 59529	 0.000514	 0.00625	 0.00206	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59528	 59529	 0.000514	 0.00625	 0.00206	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59529	 59530	 0.001764	 0.020964	 0.0073	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59529	 59530	 0.001764	 0.020964	 0.0073	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59529	 75894	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59529	 75894	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59530	 59537	 0.003393	 0.043436	 0.01297	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59530	 59537	 0.003393	 0.043436	 0.01297	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59531	 59535	 0.001121	 0.012479	 0.00831	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59531	 75895	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59531	 75895	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59532	 59539	 0.032043	 0.1428	 0.00243	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59532	 59539	 0.032043	 0.1428	 0.00243	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75894	 59532	 0.050571	 0.225407	 0.00383	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75894	 59532	 0.050571	 0.225407	 0.00383	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59533	 75897	 0.016829	 0.031293	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59534	 59535	 0.000886	 0.010936	 0.00353	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59534	 59535	 0.000886	 0.010936	 0.00353	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59534	 59542	 0.000793	 0.010186	 0.00304	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59534	 59542	 0.000793	 0.010186	 0.00304	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59535	 59536	 0.000386	 0.004036	 0.00226	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59535	 59538	 0.000564	 0.003929	 0.0023	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59535	 59541	 0.000957	 0.0125	 0.00361	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59535	 59541	 0.000957	 0.0125	 0.00361	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59535	 75896	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59535	 75896	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59536	 59537	 0.0006	 0.007521	 0.00233	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59536	 59537	 0.0006	 0.007521	 0.00233	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59536	 59538	 0.000371	 0.005229	 0.00173	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59536	 75897	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59536	 75897	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59539	 59540	 0.0106	 0.047236	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59539	 59540	 0.0106	 0.047236	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75896	 59540	 0.0135	 0.047279	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75896	 59540	 0.0135	 0.047279	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59543	 59667	 0.083264	 0.371321	 0.00631	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59543	 59667	 0.083264	 0.371321	 0.00631	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59543	 75936	 0.187214	 0.658286	 0.01833	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59543	 75936	 0.187214	 0.658286	 0.01833	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59544	 59545	 0.073821	 0.258629	 0.00716	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59544	 59545	 0.073821	 0.258629	 0.00716	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59545	 59671	 0.072471	 0.323129	 0.00549	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59545	 59671	 0.072471	 0.323129	 0.00549	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59545	 59680	 0.035843	 0.259721	 0.00653	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59546	 75898	 0.221729	 0.157121	 0.00249	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59547	 59548	 0.004429	 0.055757	 0.01728	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59547	 59548	 0.004429	 0.055757	 0.01728	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59547	 59682	 0.00865	 0.108979	 0.03382	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59547	 59682	 0.00865	 0.108979	 0.03382	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59547	 75898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59547	 75898	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59548	 59552	 0.001636	 0.01525	 0.00472	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59548	 75899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59548	 75899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59548	 75901	 0.007229	 0.085943	 0.02997	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59548	 75901	 0.007229	 0.085943	 0.02997	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59549	 59551	 0.051843	 0.231071	 0.00393	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59549	 59551	 0.051843	 0.231071	 0.00393	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75899	 59549	 0.033007	 0.128929	 0.00286	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75899	 59549	 0.033007	 0.128929	 0.00286	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59550	 59551	 0.274121	 0.194286	 0.00307	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59551	 75902	 0.015686	 0.101207	 0.00322	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59552	 75900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59552	 75900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75502	 59553	 0.030664	 0.11975	 0.00266	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75502	 59553	 0.030664	 0.11975	 0.00266	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59554	 59556	 0.027929	 0.097786	 0.00271	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59554	 59556	 0.027929	 0.097786	 0.00271	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59554	 59561	 0.040507	 0.141843	 0.00393	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59554	 59561	 0.040507	 0.141843	 0.00393	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59555	 59556	 0.015964	 0.055886	 0.00155	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59555	 59556	 0.015964	 0.055886	 0.00155	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75900	 59555	 0.025357	 0.112986	 0.00192	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75900	 59555	 0.025357	 0.112986	 0.00192	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59555	 75902	 0.03595	 0.160229	 0.00272	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59556	 59557	 0.014371	 0.064029	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59556	 59557	 0.014371	 0.064029	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59556	 75902	 0.0351	 0.137107	 0.00304	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59556	 75902	 0.0351	 0.137107	 0.00304	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 59557	 0.037379	 0.166593	 0.00283	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 59557	 0.037379	 0.166593	 0.00283	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59557	 75902	 0.02505	 0.0877	 0.00243	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59557	 75902	 0.02505	 0.0877	 0.00243	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59558	 75902	 0.031407	 0.038993	 0.00085	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59559	 75901	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59559	 75949	 0.007064	 0.072193	 1.29443	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59559	 75949	 0.007064	 0.072193	 1.29443	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 59560	 0.050621	 0.1773	 0.00491	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75498	 59560	 0.050621	 0.1773	 0.00491	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75902	 59560	 0.054879	 0.1922	 0.00532	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75902	 59560	 0.054879	 0.1922	 0.00532	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59561	 75903	 0.066421	 0.259521	 0.00576	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59561	 75903	 0.066421	 0.259521	 0.00576	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59562	 59612	 0.011836	 0.134179	 0.05183	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59562	 59612	 0.011836	 0.134179	 0.05183	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75902	 59563	 0.094314	 0.214007	 0.00427	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59564	 59611	 0.012236	 0.159643	 0.0463	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59564	 59611	 0.012236	 0.159643	 0.0463	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59564	 75903	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59564	 75903	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59565	 75904	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59566	 75906	 0.004675	 0.0944	 0.0	 175.0	 175.0	 175.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75907	 59566	 0.099969	 0.269449	 0.06766	 128.0	 128.0	 128.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75906	 59567	 0.155171	 0.544864	 0.01514	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59567	 75908	 0.185543	 0.727643	 0.01622	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59567	 75908	 0.185543	 0.727643	 0.01622	 88.0	 92.4	 96.8	 0.0	 0.0	 0	 -30.0	 30.0;
	59657	 59569	 0.14887	 0.33467	 0.0892	 81.0	 85.0	 94.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59657	 59569	 0.14887	 0.33467	 0.0892	 81.0	 85.0	 94.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75907	 59569	 0.094214	 0.228329	 0.06488	 128.0	 128.0	 128.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59570	 59573	 0.0007	 0.007729	 0.07362	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59570	 75909	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59570	 75909	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59571	 59573	 0.000186	 0.002786	 0.04996	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75466	 59571	 0.000343	 0.00865	 0.14245	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59571	 75910	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75911	 59571	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59572	 60074	 0.000793	 0.0099	 0.04032	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75910	 59572	 0.000286	 0.004229	 0.01568	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59572	 75912	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59572	 75912	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59573	 76082	 0.000271	 0.006621	 0.11901	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59574	 59578	 0.001936	 0.007536	 0.00201	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59574	 59598	 0.0032	 0.011636	 0.00356	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59574	 75913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59574	 75913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59575	 59576	 0.003307	 0.005821	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59575	 59577	 0.018721	 0.013257	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59575	 59584	 0.006557	 0.0256	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59575	 59584	 0.006557	 0.0256	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59575	 59588	 0.017607	 0.030964	 0.00058	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75913	 59575	 0.000943	 0.007336	 0.00014	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59576	 59588	 0.016779	 0.026921	 0.0005	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59578	 75914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59578	 75914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59578	 75916	 0.000679	 0.009707	 0.00324	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59579	 59580	 0.024179	 0.01565	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59580	 59582	 0.005686	 0.017443	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59580	 59595	 0.013014	 0.045564	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59581	 59582	 0.012079	 0.008557	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59582	 59584	 0.005579	 0.021779	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59582	 59584	 0.005579	 0.021779	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59582	 59593	 0.011393	 0.023414	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75914	 59582	 0.00695	 0.030964	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75914	 59582	 0.00695	 0.030964	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75913	 59583	 0.01685	 0.011936	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75913	 59585	 0.030364	 0.050643	 0.00074	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59585	 75915	 0.011386	 0.020029	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59586	 59598	 0.001986	 0.004793	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59586	 75915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59586	 75915	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59587	 59599	 0.053964	 0.039014	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75914	 59587	 0.0214	 0.061371	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59588	 75917	 0.011186	 0.043686	 0.00097	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59588	 75919	 0.008771	 0.055921	 0.00136	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59589	 66540	 0.001071	 0.027307	 2.07907	 2811.0	 2951.55	 3092.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59589	 75916	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59589	 75916	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75917	 59590	 0.031807	 0.03125	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75917	 59591	 0.038907	 0.025193	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59592	 59611	 0.002629	 0.03125	 0.01089	 380.0	 380.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59592	 59611	 0.002629	 0.03125	 0.01089	 390.0	 390.35	 390.35	 0.0	 0.0	 1	 -30.0	 30.0;
	75916	 59592	 0.001614	 0.020986	 0.00606	 360.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75916	 59592	 0.001614	 0.020986	 0.00606	 360.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59593	 59595	 0.010379	 0.049814	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75917	 59593	 0.008071	 0.067129	 0.00127	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59594	 75918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59594	 75918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75503	 59596	 0.008193	 0.052214	 0.00127	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75918	 59596	 0.024429	 0.0954	 0.00211	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75918	 59596	 0.024429	 0.0954	 0.00211	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75916	 59597	 0.005121	 0.021143	 0.005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59597	 75919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59597	 75919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59598	 59600	 0.004521	 0.017779	 0.00465	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59600	 59607	 0.0042	 0.015286	 0.00468	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59601	 59603	 0.000786	 0.003236	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59601	 75920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59601	 75920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75920	 59602	 0.017679	 0.012521	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59603	 59607	 0.001893	 0.006879	 0.00211	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75920	 59604	 0.052143	 0.041264	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59604	 75921	 0.058743	 0.038029	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59605	 59606	 0.177121	 0.1147	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75920	 59605	 0.043636	 0.02825	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59607	 75921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59607	 75921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75915	 59608	 0.1242	 0.23105	 0.00541	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75920	 59608	 0.232179	 0.150386	 0.00286	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75921	 59608	 0.247529	 0.195964	 0.00246	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59608	 75932	 0.113036	 0.449357	 0.01286	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75903	 59610	 0.098814	 0.440807	 0.0075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75903	 59610	 0.098814	 0.440807	 0.0075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59611	 59612	 0.003914	 0.050164	 0.01498	 370.0	 370.0	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59611	 59612	 0.003914	 0.050164	 0.01498	 370.0	 370.0	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59612	 59623	 0.004421	 0.057543	 0.01664	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59612	 59623	 0.004421	 0.057543	 0.01664	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59612	 75922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59612	 75922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59613	 59634	 0.062443	 0.243979	 0.00541	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59613	 59634	 0.062443	 0.243979	 0.00541	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75917	 59613	 0.039907	 0.155879	 0.00346	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75917	 59613	 0.039907	 0.155879	 0.00346	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75919	 59613	 0.025236	 0.112457	 0.00191	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75919	 59613	 0.025236	 0.112457	 0.00191	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75919	 59614	 0.270157	 0.175014	 0.00333	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59615	 59620	 0.004757	 0.053264	 0.01694	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75882	 59615	 0.024629	 0.205121	 0.05425	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59615	 75923	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59615	 75923	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59616	 59618	 0.100236	 0.206057	 0.00393	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75891	 59616	 0.061607	 0.215643	 0.00447	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59617	 59618	 0.018807	 0.043671	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75485	 59617	 0.016457	 0.0884	 0.0021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75505	 59617	 0.010314	 0.077979	 0.00259	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59619	 59620	 0.0104	 0.0485	 0.01201	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59620	 75924	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59620	 75924	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59621	 75925	 0.0818	 0.364779	 0.0062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59621	 75925	 0.0818	 0.364779	 0.0062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59622	 59628	 0.01695	 0.072457	 0.00164	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59622	 75925	 0.019529	 0.096914	 0.00231	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59623	 59625	 0.001107	 0.015721	 0.00827	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59623	 75925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59623	 75925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59624	 75926	 0.013921	 0.025114	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59625	 59626	 0.000314	 0.004886	 0.00272	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75901	 59626	 0.01955	 0.247479	 0.07739	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75901	 59626	 0.01955	 0.247479	 0.07739	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59626	 75926	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59626	 75926	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75926	 59627	 0.015357	 0.010879	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59628	 59631	 0.022614	 0.064857	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 59628	 0.03735	 0.076757	 0.00146	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59629	 59635	 0.232829	 0.164993	 0.00261	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59630	 59631	 0.006121	 0.032864	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59630	 59635	 0.034764	 0.166914	 0.00499	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 59631	 0.008371	 0.037086	 0.00084	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 59632	 0.035793	 0.02535	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59633	 59634	 0.043307	 0.151664	 0.0042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59633	 59634	 0.043307	 0.151664	 0.0042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 59633	 0.025536	 0.099736	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 59633	 0.025536	 0.099736	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75926	 59636	 0.289829	 0.444557	 0.00625	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59637	 59638	 0.017121	 0.21645	 0.06754	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59637	 59638	 0.017121	 0.21645	 0.06754	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59637	 75927	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59637	 75927	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59638	 59656	 0.01315	 0.171629	 0.04981	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59638	 59656	 0.01315	 0.171629	 0.04981	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59657	 59638	 0.09113	 0.246614	 0.00619	 135.0	 135.0	 135.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59638	 59658	 0.087814	 0.237772	 0.05974	 161.0	 161.0	 161.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59639	 75929	 0.379179	 0.245793	 0.00468	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59640	 59646	 0.215557	 0.152743	 0.00241	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59641	 59647	 0.735929	 0.584514	 0.00736	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59642	 59643	 0.058436	 0.204671	 0.00567	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59642	 59643	 0.058436	 0.204671	 0.00567	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59642	 74246	 0.096593	 0.338564	 0.00939	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59642	 74246	 0.096593	 0.338564	 0.00939	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59643	 75928	 0.034171	 0.152286	 0.00259	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59643	 75928	 0.034171	 0.152286	 0.00259	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75477	 59644	 0.003007	 0.012021	 0.00406	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59644	 75928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59644	 75928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75506	 59645	 0.005343	 0.021386	 0.00539	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59645	 75929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59645	 75929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59646	 75933	 0.0554	 0.043843	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59647	 75932	 0.036671	 0.058829	 0.00109	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59648	 59652	 0.027407	 0.017743	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59649	 59650	 0.022907	 0.014829	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59649	 75931	 0.043357	 0.042593	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59651	 75930	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75931	 59652	 0.010686	 0.041743	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75931	 59652	 0.010686	 0.041743	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59652	 75932	 0.006621	 0.025864	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59652	 75932	 0.006621	 0.025864	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59653	 75932	 0.028014	 0.022171	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59654	 59656	 0.0011	 0.014057	 0.00419	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59654	 59656	 0.0011	 0.014057	 0.00419	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75477	 59654	 0.000943	 0.009486	 0.00581	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75506	 59654	 0.000914	 0.0099	 0.00607	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59654	 75932	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59654	 75932	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75932	 59655	 0.005243	 0.023357	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75932	 59655	 0.005243	 0.023357	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59655	 75933	 0.007907	 0.035243	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59655	 75933	 0.007907	 0.035243	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59656	 75933	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59656	 75933	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59657	 59658	 0.069942	 0.190112	 0.04783	 96.0	 96.0	 96.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59658	 70531	 0.020014	 0.264179	 0.07596	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59658	 70531	 0.020014	 0.264179	 0.07596	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75930	 59658	 0.013586	 0.1579	 0.09856	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59659	 75934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59659	 75934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59660	 59689	 0.005707	 0.03425	 0.01037	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59660	 59776	 0.008193	 0.056279	 0.01642	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59661	 75946	 0.040757	 0.108036	 0.00274	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59662	 59675	 0.0424	 0.112386	 0.00285	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59662	 75935	 0.02635	 0.102529	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59663	 59706	 0.004521	 0.047936	 0.01424	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59663	 59778	 0.002964	 0.038629	 0.01116	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59663	 75935	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59663	 75935	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59664	 59675	 0.024393	 0.095257	 0.00211	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59664	 59702	 0.032114	 0.125421	 0.00278	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59664	 59702	 0.032114	 0.125421	 0.00278	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75935	 59664	 0.007221	 0.0523	 0.00131	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59664	 75958	 0.01835	 0.148486	 0.00383	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59665	 59672	 0.309757	 0.219579	 0.00347	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59666	 59667	 0.136829	 0.098929	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59667	 59669	 0.004686	 0.016407	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59667	 59669	 0.004686	 0.016407	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59668	 59669	 0.019729	 0.086921	 0.00151	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59668	 59669	 0.019729	 0.086921	 0.00151	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59668	 59760	 0.11325	 0.442964	 0.00984	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59668	 59760	 0.11325	 0.442964	 0.00984	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59670	 59760	 0.31225	 0.22135	 0.0035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59671	 59674	 0.03775	 0.132179	 0.00366	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59671	 59674	 0.03775	 0.132179	 0.00366	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59672	 59675	 0.101457	 0.200921	 0.00295	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59673	 59674	 0.0164	 0.057429	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59673	 59674	 0.0164	 0.057429	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59673	 75942	 0.028864	 0.11275	 0.0025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59673	 75942	 0.028864	 0.11275	 0.0025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59675	 59704	 0.006143	 0.036814	 0.00089	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59676	 75936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59676	 75936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59676	 75945	 0.005607	 0.023157	 0.00548	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59677	 59678	 0.024836	 0.110686	 0.00188	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59677	 59678	 0.024836	 0.110686	 0.00188	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59677	 75947	 0.033543	 0.117464	 0.00325	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59677	 75947	 0.033543	 0.117464	 0.00325	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59678	 59679	 0.020721	 0.080914	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59678	 59679	 0.020721	 0.080914	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59678	 75937	 0.039243	 0.153271	 0.0034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59678	 75937	 0.039243	 0.153271	 0.0034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59679	 59680	 0.022357	 0.078271	 0.00216	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59679	 59680	 0.022357	 0.078271	 0.00216	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59680	 75938	 0.029114	 0.116521	 0.00246	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59680	 75938	 0.029114	 0.116521	 0.00246	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59680	 75939	 0.0715	 0.279407	 0.0062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59680	 75939	 0.0715	 0.279407	 0.0062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59681	 59682	 0.001629	 0.0205	 0.00635	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59681	 59682	 0.001629	 0.0205	 0.00635	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59681	 75937	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59681	 75937	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59682	 75938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59682	 75938	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75937	 59683	 0.066586	 0.260171	 0.00577	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75937	 59683	 0.066586	 0.260171	 0.00577	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75938	 59683	 0.022614	 0.210607	 0.00408	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59686	 59692	 0.002643	 0.031429	 0.01095	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59686	 59692	 0.002643	 0.031429	 0.01095	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59686	 75939	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59686	 75939	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59687	 59689	 0.001743	 0.006986	 0.00176	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59687	 59692	 0.004293	 0.011693	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59687	 75940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59687	 75940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75497	 59688	 0.017429	 0.022907	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59688	 75941	 0.026136	 0.018514	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59689	 59692	 0.003286	 0.0125	 0.0035	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59690	 59720	 0.006293	 0.012871	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59690	 75941	 0.006114	 0.017971	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59691	 59692	 0.000593	 0.00325	 0.00086	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59691	 75941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59691	 75941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59692	 59721	 0.000621	 0.00625	 0.00208	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59693	 59720	 0.036764	 0.0238	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59694	 59696	 0.006507	 0.022221	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59694	 59718	 0.003971	 0.011671	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59695	 59714	 0.034836	 0.024679	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59696	 59698	 0.00735	 0.031414	 0.00071	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59696	 75947	 0.034521	 0.064193	 0.0015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59697	 59698	 0.00405	 0.021757	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59697	 59699	 0.004243	 0.014857	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59697	 59712	 0.014364	 0.029529	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59699	 59703	 0.00355	 0.013857	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59700	 59703	 0.0348	 0.02465	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59701	 59702	 0.024807	 0.017571	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59702	 59703	 0.003621	 0.013864	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59702	 75946	 0.024136	 0.049607	 0.00094	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59703	 59708	 0.009457	 0.018721	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59704	 59705	 0.00595	 0.018264	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59704	 75946	 0.015743	 0.0463	 0.00095	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59705	 75942	 0.007207	 0.020457	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59706	 59728	 0.003293	 0.011529	 0.00382	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59706	 75942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59706	 75942	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59706	 75945	 0.001907	 0.007864	 0.00186	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59707	 59708	 0.007143	 0.013286	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59707	 75946	 0.005471	 0.026707	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59708	 59709	 0.021207	 0.013729	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59709	 59727	 0.024664	 0.019521	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59710	 59713	 0.022721	 0.016093	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59711	 59712	 0.016579	 0.010736	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59712	 75944	 0.00865	 0.021907	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59713	 59714	 0.035036	 0.024814	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59713	 75944	 0.01275	 0.026093	 0.00064	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59715	 59716	 0.005043	 0.017236	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59715	 59725	 0.005057	 0.020079	 0.00057	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59716	 59717	 0.002357	 0.009171	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59717	 59719	 0.00535	 0.015721	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59718	 59719	 0.003029	 0.008036	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59719	 59720	 0.001836	 0.011843	 0.00038	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75941	 59720	 0.012814	 0.032457	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59720	 75943	 0.003821	 0.020436	 0.00062	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59720	 75946	 0.012593	 0.101893	 0.00263	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59721	 59731	 0.0019	 0.027464	 0.00872	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59721	 75943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59721	 75943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59722	 59740	 0.008957	 0.034993	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59722	 59740	 0.008957	 0.034993	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 59722	 0.036871	 0.129107	 0.00358	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 59722	 0.036871	 0.129107	 0.00358	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59723	 59725	 0.017157	 0.022543	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59723	 59739	 0.021979	 0.014229	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59724	 59725	 0.006557	 0.011043	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59724	 59738	 0.019857	 0.014064	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59725	 59726	 0.003621	 0.012671	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59725	 59726	 0.003621	 0.012671	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59725	 75947	 0.00765	 0.026793	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59725	 75947	 0.00765	 0.026793	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59726	 75944	 0.005857	 0.023929	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59726	 75944	 0.005857	 0.023929	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59727	 75944	 0.014557	 0.011986	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59728	 75944	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59728	 75944	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59728	 75945	 0.00085	 0.005479	 0.00144	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59729	 75945	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59729	 75949	 0.002907	 0.031186	 0.46117	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59729	 75949	 0.002907	 0.031186	 0.46117	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59730	 59732	 0.002336	 0.013286	 0.00041	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59730	 59733	 0.006643	 0.017607	 0.00045	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75946	 59730	 0.006143	 0.023993	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75946	 59730	 0.006143	 0.023993	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75945	 59731	 0.000714	 0.00895	 0.00277	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75945	 59731	 0.000714	 0.00895	 0.00277	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59731	 75947	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59731	 75947	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59732	 59733	 0.005014	 0.0127	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59732	 59743	 0.005621	 0.022971	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59732	 59743	 0.005621	 0.022971	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59734	 59735	 0.011093	 0.007857	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59734	 59736	 0.013807	 0.008936	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75947	 59735	 0.014929	 0.012286	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59737	 59741	 0.001657	 0.014121	 0.00037	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59737	 59743	 0.005243	 0.023379	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59737	 59743	 0.005243	 0.023379	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59740	 59741	 0.005171	 0.022786	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59740	 59741	 0.005171	 0.022786	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59741	 59744	 0.031407	 0.02225	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75947	 59741	 0.007079	 0.040221	 0.00073	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59742	 59743	 0.016486	 0.011679	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59745	 59748	 0.18335	 0.118736	 0.00226	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59746	 59747	 0.01295	 0.034329	 0.00087	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59746	 60042	 0.046479	 0.1232	 0.00313	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59747	 59748	 0.014271	 0.036157	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59748	 59749	 0.165421	 0.129686	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59748	 59750	 0.026914	 0.133543	 0.00319	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59748	 76117	 0.167764	 0.389821	 0.0058	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59750	 59751	 0.046607	 0.086657	 0.00203	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59750	 75948	 0.124929	 0.2289	 0.00395	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59751	 59752	 0.033757	 0.069379	 0.00132	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59752	 59753	 0.04495	 0.031843	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59752	 59754	 0.027193	 0.0176	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59752	 75948	 0.099129	 0.070221	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59753	 59754	 0.033364	 0.023636	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59754	 75948	 0.091014	 0.058929	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59755	 59758	 0.019286	 0.118586	 0.00214	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59755	 75948	 0.010793	 0.064664	 0.00156	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59756	 60190	 0.041507	 0.151364	 0.04649	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59756	 75948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59756	 75948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75948	 59757	 0.099186	 0.070264	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59758	 59759	 0.016429	 0.081529	 0.00194	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59759	 59760	 0.031493	 0.110279	 0.00305	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59759	 59760	 0.031493	 0.110279	 0.00305	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59759	 59762	 0.167929	 0.108743	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75948	 59759	 0.023579	 0.169721	 0.00556	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59763	 59773	 0.000571	 0.0074	 0.47294	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59763	 59923	 0.000871	 0.015657	 1.12057	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59763	 60038	 0.000764	 0.014143	 1.1545	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59763	 75949	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59763	 75949	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59763	 75949	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59764	 59769	 0.015493	 0.02725	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59764	 59779	 0.017521	 0.036	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59764	 75955	 0.021486	 0.044157	 0.00084	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59765	 59767	 0.00935	 0.036507	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75862	 59765	 0.007486	 0.053857	 0.00176	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59765	 75955	 0.00315	 0.01315	 0.00038	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59766	 59770	 0.000136	 0.001829	 0.00112	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75951	 59766	 0.000507	 0.006621	 0.00419	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75952	 59767	 0.004464	 0.036707	 0.00071	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59767	 75953	 0.008443	 0.015693	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59767	 75959	 0.023643	 0.104736	 0.00239	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59768	 59769	 0.028964	 0.01875	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59769	 75955	 0.003929	 0.019157	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59770	 75953	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59770	 75953	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59770	 75954	 0.00015	 0.001971	 0.00125	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75950	 59771	 0.000543	 0.004536	 0.01414	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59771	 75954	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75955	 59771	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59772	 75959	 0.050107	 0.116329	 0.00173	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59772	 75981	 0.091929	 0.188186	 0.00464	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59773	 75956	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59773	 75956	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59775	 59781	 0.024993	 0.106864	 0.00241	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59776	 75957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59776	 75957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59777	 59781	 0.205493	 0.185479	 0.00311	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75954	 59778	 0.00425	 0.046779	 0.02781	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59778	 75958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59778	 75958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75955	 59779	 0.024971	 0.073429	 0.00151	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75951	 59780	 0.008879	 0.03665	 0.00867	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59780	 75959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59780	 75959	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59781	 59782	 0.005	 0.02675	 0.00081	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59781	 59783	 0.008271	 0.021914	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59782	 59783	 0.001736	 0.012479	 0.00041	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75959	 59782	 0.018979	 0.084557	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75959	 59782	 0.018979	 0.084557	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75504	 59783	 0.060986	 0.238264	 0.00529	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59784	 59785	 0.051307	 0.046293	 0.00077	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59785	 75961	 0.020179	 0.046843	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59785	 75964	 0.092121	 0.090507	 0.00153	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59786	 59787	 0.000457	 0.005021	 0.04929	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59786	 75960	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59787	 75962	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75964	 59788	 0.176207	 0.206636	 0.00359	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75689	 59789	 0.178914	 0.115864	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75963	 59790	 0.096564	 0.2497	 0.06226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59791	 59793	 0.002407	 0.009457	 0.00247	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59791	 60027	 0.0166	 0.05695	 0.01365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59791	 75965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59791	 75965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59792	 59793	 0.001014	 0.005257	 0.00129	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59792	 59796	 0.000829	 0.003864	 0.00096	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59793	 59807	 0.00065	 0.00295	 0.00094	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59793	 59828	 0.00315	 0.022657	 0.006	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59793	 75966	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59793	 75966	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59794	 59795	 0.007936	 0.014171	 0.00021	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75966	 59794	 0.007086	 0.01795	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59794	 75967	 0.003471	 0.016943	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75966	 59795	 0.006343	 0.011793	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59796	 59812	 0.00155	 0.006086	 0.00159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59796	 75967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59796	 75967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59797	 59799	 0.001986	 0.009114	 0.00234	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59797	 59812	 0.0006	 0.002829	 0.00091	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59797	 75968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59797	 75968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59798	 59801	 0.006907	 0.019807	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75965	 59798	 0.007414	 0.015243	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75967	 59798	 0.007229	 0.016786	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59799	 59830	 0.005079	 0.019757	 0.00528	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59799	 75969	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59799	 75969	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59800	 59819	 0.010764	 0.009643	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75969	 59800	 0.013507	 0.02275	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75969	 59801	 0.012814	 0.029429	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59802	 59821	 0.00515	 0.01365	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59802	 60022	 0.007064	 0.020779	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59802	 60023	 0.020257	 0.021636	 0.00046	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59803	 59804	 0.009593	 0.019707	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59803	 60198	 0.075021	 0.1542	 0.00294	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59803	 75973	 0.039507	 0.032521	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59804	 75970	 0.014536	 0.015993	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59805	 59806	 0.000593	 0.003371	 0.00084	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59805	 59827	 0.000743	 0.003764	 0.00136	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59806	 59807	 0.000721	 0.003807	 0.00096	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59807	 75970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59807	 75970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59808	 75971	 0.007007	 0.014393	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59808	 75973	 0.016736	 0.042393	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59809	 59810	 0.001607	 0.006429	 0.00162	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59809	 59811	 0.001071	 0.004064	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59809	 75971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59809	 75971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59810	 59829	 0.003586	 0.014893	 0.00348	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59811	 59813	 0.001079	 0.004329	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59812	 59813	 0.000971	 0.002779	 0.00069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59813	 75972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59813	 75972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59814	 59816	 0.012664	 0.026021	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75972	 59814	 0.008143	 0.015143	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59815	 59816	 0.016429	 0.020393	 0.00044	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59815	 59817	 0.017886	 0.036764	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75968	 59815	 0.006179	 0.02405	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75969	 59815	 0.013114	 0.02695	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75972	 59816	 0.016721	 0.034371	 0.00066	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59816	 75975	 0.009093	 0.040279	 0.00121	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75969	 59817	 0.020057	 0.036743	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59817	 75980	 0.074264	 0.138107	 0.00324	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59818	 59824	 0.032436	 0.021	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59819	 59821	 0.013214	 0.011921	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59820	 59822	 0.007786	 0.014471	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59820	 59824	 0.006357	 0.011821	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59821	 59822	 0.005371	 0.016486	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59822	 59826	 0.052914	 0.034257	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59823	 59824	 0.032871	 0.021279	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59824	 59825	 0.022014	 0.01425	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75969	 59824	 0.013871	 0.036764	 0.00094	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59825	 59831	 0.065664	 0.042507	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59827	 59828	 0.001429	 0.010093	 0.00277	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59827	 75973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59827	 75973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59828	 59835	 0.004164	 0.023879	 0.00794	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59828	 75974	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59828	 75974	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59829	 59843	 0.004971	 0.019529	 0.00511	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59830	 59845	 0.007743	 0.029421	 0.00824	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59830	 75975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59830	 75975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75974	 59832	 0.049764	 0.149807	 0.00293	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59833	 59834	 0.003293	 0.013607	 0.00322	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59833	 60182	 0.005886	 0.024471	 0.00571	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59834	 59837	 0.003643	 0.014586	 0.00493	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59834	 59839	 0.004286	 0.018636	 0.00531	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59835	 59838	 0.000986	 0.006121	 0.00173	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59835	 75976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59835	 75976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59836	 59837	 0.0024	 0.009893	 0.00234	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59836	 59838	 0.001064	 0.004264	 0.00107	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59837	 75977	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59837	 75977	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59838	 59839	 0.001186	 0.004814	 0.00117	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59840	 59843	 0.00805	 0.031307	 0.00836	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59840	 75978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59840	 75978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75880	 59841	 0.03825	 0.205507	 0.00488	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59841	 75981	 0.039271	 0.134171	 0.00292	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75978	 59842	 0.010836	 0.064943	 0.00156	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59842	 75979	 0.008486	 0.0421	 0.00101	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59843	 75979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59843	 75979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75499	 59844	 0.007157	 0.03285	 0.00841	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59845	 59846	 0.003057	 0.011886	 0.00317	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59845	 59847	 0.010836	 0.027243	 0.00706	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59845	 75980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59845	 75980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59846	 75981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59846	 75981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59847	 59848	 0.009	 0.022621	 0.00586	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59848	 75982	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59848	 75982	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75469	 59849	 0.000964	 0.008329	 0.01549	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75474	 59849	 0.001571	 0.011036	 0.01879	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75482	 59849	 0.009371	 0.064071	 0.11578	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59849	 75983	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59849	 75983	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59850	 75984	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75985	 59850	 0.000243	 0.018209	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 0	 -30.0	 30.0;
	59851	 59937	 0.003236	 0.012643	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59851	 75986	 0.002307	 0.008836	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59852	 59853	 0.0008	 0.003679	 0.00094	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59852	 59868	 0.001886	 0.010007	 0.00334	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59852	 75986	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59852	 75986	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59853	 59866	 0.000686	 0.002743	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59853	 75987	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59853	 75987	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59854	 59855	 0.001129	 0.004693	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59854	 59977	 0.00195	 0.005007	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59854	 75988	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59854	 75988	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59854	 75996	 0.004979	 0.0181	 0.00554	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59855	 59864	 0.0004	 0.0027	 0.00083	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59855	 59976	 0.000643	 0.003571	 0.00109	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59856	 59857	 0.003379	 0.006943	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59856	 59862	 0.003107	 0.01375	 0.00031	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75988	 59856	 0.006971	 0.020507	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59857	 75989	 0.005036	 0.006864	 0.00015	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59858	 59971	 0.001379	 0.004736	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59858	 75989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59858	 75989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59859	 76038	 0.0227	 0.014693	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59860	 59975	 0.007043	 0.012714	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75989	 59860	 0.002571	 0.011986	 0.00028	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59860	 76040	 0.004336	 0.012429	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59861	 59862	 0.00255	 0.006757	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59861	 75992	 0.002779	 0.012386	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59862	 76037	 0.004393	 0.011643	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59863	 59864	 0.000271	 0.001943	 0.0006	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59863	 59874	 0.000479	 0.003043	 0.00083	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59865	 59866	 0.000436	 0.002079	 0.0005	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59865	 59873	 0.000464	 0.002064	 0.00056	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59865	 59874	 0.001193	 0.004014	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59867	 59871	 0.005936	 0.011036	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75986	 59867	 0.012093	 0.025414	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75987	 59867	 0.014921	 0.018521	 0.00041	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59867	 75990	 0.003657	 0.014514	 0.00041	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59868	 59870	 0.00095	 0.003686	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59868	 60020	 0.001329	 0.003621	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59868	 75990	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59868	 75990	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59868	 75996	 0.001529	 0.006129	 0.00154	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75990	 59869	 0.004157	 0.005671	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59870	 59872	 0.001036	 0.002736	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59870	 59883	 0.000536	 0.002771	 0.00073	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59870	 75991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59870	 75991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75991	 59871	 0.00365	 0.006793	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59872	 59873	 0.000443	 0.002029	 0.00052	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59872	 59880	 0.000921	 0.00525	 0.00152	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59874	 59875	 0.000536	 0.00215	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59874	 59876	 0.001171	 0.004679	 0.00158	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59875	 59881	 0.000629	 0.002386	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59876	 59878	 0.000914	 0.004207	 0.00108	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59876	 59974	 0.001979	 0.011236	 0.00325	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59876	 75992	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59876	 75992	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59876	 76031	 0.004636	 0.019279	 0.0045	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59877	 59879	 0.006929	 0.012886	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59877	 59969	 0.004864	 0.011286	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59877	 76037	 0.00735	 0.017064	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59878	 59897	 0.000764	 0.003657	 0.00106	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59878	 75993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59878	 75993	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75993	 59879	 0.005821	 0.009293	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59880	 59881	 0.000464	 0.001893	 0.00046	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59880	 59895	 0.000457	 0.002007	 0.00057	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59880	 75994	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59880	 75994	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59882	 59893	 0.005021	 0.011536	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75994	 59882	 0.021629	 0.015321	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59882	 75995	 0.00335	 0.009843	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59883	 59890	 0.000493	 0.002657	 0.00073	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59883	 75995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59883	 75995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75990	 59884	 0.003771	 0.011093	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75995	 59884	 0.004321	 0.01425	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59884	 75997	 0.004536	 0.015121	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59885	 59905	 0.00045	 0.002114	 0.00052	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59885	 75996	 0.000686	 0.002743	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59886	 59931	 8.6e-05	 0.000907	 0.00174	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59886	 75996	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75997	 59886	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59886	 76030	 0.000443	 0.006971	 0.01461	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59886	 76059	 0.000507	 0.003564	 0.00606	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59887	 59888	 0.008979	 0.011807	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59887	 75998	 0.015357	 0.009943	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75997	 59888	 0.01355	 0.013686	 0.00018	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59888	 75998	 0.006579	 0.013514	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59889	 59890	 0.000371	 0.00205	 0.00074	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59889	 59961	 0.001514	 0.006814	 0.00181	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59889	 75998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59889	 75998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59891	 59892	 0.005243	 0.008829	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59891	 59899	 0.008086	 0.012914	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75998	 59891	 0.003064	 0.008129	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59892	 75999	 0.00485	 0.008529	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59893	 76000	 0.01215	 0.007864	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59893	 76001	 0.008971	 0.02035	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59894	 59895	 0.000593	 0.002721	 0.00069	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59894	 59896	 0.000714	 0.003457	 0.00079	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59894	 75999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59894	 75999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59895	 76000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59895	 76000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59896	 59962	 0.000521	 0.002486	 0.00072	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59897	 59898	 0.000679	 0.003343	 0.00098	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59897	 76001	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59897	 76001	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59897	 76031	 0.002614	 0.010179	 0.00272	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59898	 59964	 0.000443	 0.002686	 0.00068	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59899	 59900	 0.005607	 0.009193	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59899	 76033	 0.002364	 0.00905	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59900	 59901	 0.006407	 0.006836	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59901	 59902	 0.012979	 0.009193	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59901	 59903	 0.005871	 0.008807	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59902	 76002	 0.019279	 0.015257	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59903	 76002	 0.014336	 0.009279	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59904	 59905	 0.000443	 0.001921	 0.00055	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59904	 59912	 0.000543	 0.001979	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59904	 76003	 0.001071	 0.004164	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59905	 76002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59905	 76002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59906	 59907	 0.00235	 0.0072	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59906	 59915	 0.003471	 0.006457	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59906	 76005	 0.005671	 0.014371	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76002	 59907	 0.005036	 0.011693	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59907	 76061	 0.010329	 0.015486	 0.00028	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59907	 76061	 0.010329	 0.015486	 0.00028	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59908	 59911	 4.3e-05	 0.000464	 0.00443	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59908	 76003	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59908	 76003	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59909	 59910	 0.000257	 0.0028	 0.00088	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76003	 59909	 0.000264	 0.002786	 0.00083	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59910	 59960	 0.000293	 0.003207	 0.001	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59911	 59914	 4.3e-05	 0.000529	 0.00476	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76003	 59912	 0.000693	 0.002857	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59913	 76004	 0.000121	 0.000771	 0.00154	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59913	 76006	 0.000221	 0.001457	 0.0029	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59914	 59916	 7.1e-05	 0.000843	 0.00765	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59914	 60021	 9.3e-05	 0.000993	 0.00939	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59914	 76004	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76005	 59915	 0.002914	 0.007379	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59916	 59918	 5.7e-05	 0.000629	 0.00572	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59916	 76006	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59916	 76006	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59917	 59919	 0.033871	 0.023993	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76005	 59917	 0.018321	 0.012979	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59918	 76007	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59918	 76009	 6.4e-05	 0.000714	 0.00629	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76008	 59919	 0.010164	 0.010857	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59920	 76011	 0.001486	 0.00405	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59920	 76028	 0.000264	 0.002579	 0.00081	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59921	 59922	 2.1e-05	 0.000221	 0.01527	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59921	 59923	 2.9e-05	 0.000386	 0.02454	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59921	 76009	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59921	 76009	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59922	 76010	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76011	 59922	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59923	 59959	 0.000107	 0.00195	 0.17084	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59923	 76012	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59923	 76012	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76014	 59923	 0.00012	 0.00961	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59924	 60021	 6.4e-05	 0.000807	 0.00822	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59924	 76015	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76016	 59924	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59925	 59926	 0.005536	 0.010286	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59925	 59928	 0.0079	 0.013893	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59925	 76017	 0.008879	 0.0121	 0.00027	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59926	 76026	 0.0109	 0.025307	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59927	 59954	 0.001293	 0.008507	 0.00214	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76016	 59927	 0.000264	 0.002064	 0.00053	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59927	 76017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59927	 76017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59928	 59929	 0.003843	 0.003886	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59928	 76018	 0.003029	 0.006221	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59928	 76027	 0.015879	 0.029529	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76017	 59929	 0.007564	 0.008321	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59929	 76018	 0.0022	 0.005064	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76016	 59930	 0.000907	 0.003629	 0.00091	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59930	 76018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59930	 76018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59930	 76019	 0.0004	 0.002057	 0.0005	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 59931	 0.0003	 0.00195	 0.00389	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59931	 76019	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59931	 76019	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59932	 59933	 0.004621	 0.0063	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76018	 59932	 0.003929	 0.011264	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59933	 76020	 0.002643	 0.006136	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59933	 76026	 0.015036	 0.027957	 0.00066	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59934	 59936	 0.000329	 0.002914	 0.0016	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59934	 60020	 0.000171	 0.002193	 0.00068	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76016	 59934	 0.001757	 0.00805	 0.00206	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59934	 76020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59934	 76020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75990	 59935	 0.005836	 0.013557	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76020	 59935	 0.0108	 0.009743	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59936	 59940	 0.00075	 0.004107	 0.00109	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59936	 59950	 0.000986	 0.008629	 0.00237	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59936	 76021	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59936	 76021	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59937	 59939	 0.0093	 0.01355	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76021	 59937	 0.008679	 0.021986	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76021	 59938	 0.008043	 0.011714	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59938	 76023	 0.011814	 0.027421	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59939	 59941	 0.009707	 0.010371	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59940	 59951	 0.00045	 0.002886	 0.00076	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59941	 76022	 0.009	 0.016736	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75868	 59942	 0.02565	 0.023143	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75986	 59942	 0.006336	 0.026457	 0.00076	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59943	 76022	 0.034114	 0.024657	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59944	 59945	 0.00065	 0.002886	 0.00079	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59944	 59947	 0.000929	 0.004421	 0.00105	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59946	 76022	 0.024464	 0.017329	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59947	 59949	 0.000571	 0.002829	 0.00076	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59947	 76022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59947	 76022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59948	 76024	 0.004864	 0.009993	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59948	 76025	 0.0081	 0.01665	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59948	 76088	 0.011379	 0.034907	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59949	 59951	 0.000514	 0.002536	 0.00074	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59949	 76023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59949	 76023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59950	 59952	 0.0004	 0.002936	 0.00086	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59950	 60082	 0.000314	 0.00355	 0.00136	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59950	 76024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59950	 76024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59951	 76025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59951	 76025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59952	 59953	 0.000514	 0.003371	 0.00086	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59953	 59954	 0.000814	 0.005164	 0.0014	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59953	 76026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59953	 76026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59954	 76027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59954	 76027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59955	 60105	 0.0006	 0.006321	 0.00171	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76014	 59955	 0.000521	 0.006	 0.00168	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59956	 60168	 0.1582	 0.124029	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75519	 59956	 0.08735	 0.1024	 0.00178	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59957	 60379	 0.000943	 0.005429	 0.00154	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76007	 59957	 0.002029	 0.01075	 0.00273	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76006	 59958	 0.00065	 0.004479	 0.00791	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76013	 59958	 0.000571	 0.004014	 0.00684	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	59958	 76028	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59958	 76028	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59959	 60302	 0.000179	 0.003	 0.29206	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59959	 76029	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59959	 76029	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59960	 59961	 0.000636	 0.00265	 0.00062	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 59960	 0.0004	 0.0034	 0.00204	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59961	 76033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59961	 76033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59962	 59965	 0.00285	 0.008393	 0.00195	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 59962	 0.0007	 0.005107	 0.00131	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59962	 76034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59962	 76034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76034	 59963	 0.005864	 0.0109	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59963	 76035	 0.008586	 0.015964	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59964	 59965	 0.000486	 0.002686	 0.00081	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59965	 59989	 0.000393	 0.003921	 0.00105	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59965	 76035	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59965	 76035	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59966	 59967	 0.00975	 0.0088	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76035	 59966	 0.022086	 0.015643	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59967	 59986	 0.009221	 0.01715	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59968	 59970	 0.000364	 0.003664	 0.00108	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59968	 59983	 0.000736	 0.005779	 0.00169	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 59968	 0.003971	 0.01615	 0.00394	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59969	 76036	 0.003714	 0.008493	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59970	 59972	 0.001186	 0.0056	 0.00135	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59970	 59973	 0.000843	 0.004821	 0.00136	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59970	 76036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59970	 76036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59971	 59972	 0.001193	 0.0031	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59971	 76037	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59971	 76037	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59972	 59973	 0.0007	 0.002879	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59972	 59979	 0.001379	 0.007843	 0.00227	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59972	 76038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59972	 76038	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59973	 59980	 0.000807	 0.002857	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59974	 59980	 0.001071	 0.004421	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59974	 76039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59974	 76039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59976	 59977	 0.0008	 0.002071	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59978	 76041	 0.014757	 0.02595	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59979	 76040	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59979	 76040	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59980	 76041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59980	 76041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59981	 59982	 0.001543	 0.012807	 0.00024	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59981	 59998	 0.005714	 0.011693	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59981	 76046	 0.002579	 0.011007	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76041	 59982	 0.002521	 0.014329	 0.00044	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	59983	 59984	 0.000314	 0.0024	 0.00076	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59984	 59994	 0.000271	 0.002393	 0.00064	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59985	 59993	 0.00265	 0.011314	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76036	 59985	 0.003993	 0.028936	 0.00073	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59985	 76045	 0.002186	 0.013114	 0.00031	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59985	 76046	 0.004907	 0.016379	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59986	 76042	 0.005757	 0.011829	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	59987	 59988	 0.000279	 0.002836	 0.00084	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59987	 76042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59987	 76042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59987	 76044	 0.000586	 0.005136	 0.00204	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59988	 59989	 0.000379	 0.003557	 0.00108	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59990	 59991	 2.9e-05	 0.000364	 0.00321	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	59990	 60006	 4.3e-05	 0.000507	 0.00581	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	59991	 76043	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59991	 76043	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76043	 59992	 7.1e-05	 0.000771	 0.00334	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59992	 76044	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76045	 59992	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76045	 59993	 0.002179	 0.0108	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	59994	 59995	 0.000336	 0.002936	 0.00105	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59994	 76046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59994	 76046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59995	 59996	 0.000671	 0.00395	 0.00108	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76044	 59995	 0.000621	 0.006193	 0.00169	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59996	 76047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59996	 76047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59996	 76051	 0.001257	 0.0056	 0.00152	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	59997	 59998	 0.00475	 0.010864	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59997	 59999	 0.0222	 0.026571	 0.00044	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76047	 59997	 0.006614	 0.018979	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	59999	 60002	 0.01575	 0.025143	 0.00058	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60000	 60001	 0.014529	 0.010293	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60000	 60005	 0.017557	 0.011364	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60002	 76056	 0.011264	 0.020943	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60003	 60015	 0.000657	 0.004393	 0.00135	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60003	 76048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60003	 76048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60004	 60013	 0.000821	 0.003107	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60004	 60018	 0.00135	 0.005579	 0.00132	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60004	 76049	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60004	 76049	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76047	 60005	 0.004864	 0.011121	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76049	 60005	 0.004021	 0.012329	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60006	 60370	 0.000257	 0.00295	 0.02584	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60006	 76050	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76044	 60007	 0.002171	 0.007586	 0.00251	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76051	 60007	 0.003621	 0.0093	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60007	 76152	 0.004	 0.0332	 0.00874	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60008	 60009	 0.0001	 0.001093	 0.00213	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60008	 76053	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76054	 60008	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60008	 76151	 0.000536	 0.007214	 0.02548	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76050	 60009	 0.000164	 0.001636	 0.00329	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60010	 60011	 0.004221	 0.00785	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76054	 60010	 0.007879	 0.018021	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60011	 60017	 0.009036	 0.018571	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60012	 60014	 0.002529	 0.011379	 0.00303	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60012	 76152	 0.005214	 0.025707	 0.00695	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76053	 60013	 0.001179	 0.005479	 0.00136	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60013	 76055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60013	 76055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60014	 60015	 0.001221	 0.005321	 0.00151	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60014	 60018	 0.001107	 0.003207	 0.00077	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60015	 60018	 0.000879	 0.003829	 0.00109	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60015	 76056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60015	 76056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76056	 60016	 0.026293	 0.020807	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76055	 60017	 0.007643	 0.012257	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60017	 76057	 0.006207	 0.014414	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60018	 76057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60018	 76057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60019	 61227	 0.011179	 0.06205	 0.01887	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75467	 60019	 0.004779	 0.041	 0.01167	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60019	 76058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60019	 76058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60019	 76152	 0.007121	 0.037743	 0.0126	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76019	 60020	 0.000207	 0.002564	 0.00083	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76029	 60021	 0.000114	 0.002814	 0.04871	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60021	 76059	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75965	 60022	 0.003971	 0.013907	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60023	 60025	 0.030986	 0.063686	 0.00121	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75965	 60024	 0.030943	 0.025464	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75974	 60025	 0.036421	 0.111736	 0.00303	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60026	 60030	 0.011593	 0.061779	 0.00109	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60026	 76062	 0.005807	 0.027871	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60027	 60033	 0.006364	 0.022271	 0.00739	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60027	 76062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60027	 76062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60028	 60032	 0.1857	 0.1529	 0.0031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76062	 60028	 0.00905	 0.031686	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60029	 60031	 0.024343	 0.055664	 0.00136	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75952	 60029	 0.072271	 0.165321	 0.00404	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60030	 60031	 0.005214	 0.027779	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60032	 76117	 0.128514	 0.239086	 0.0056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60033	 60189	 0.02025	 0.050914	 0.01319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60033	 60197	 0.016186	 0.064836	 0.01634	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60034	 76063	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60034	 76063	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60035	 60037	 0.058264	 0.10835	 0.00254	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60035	 76113	 0.110286	 0.252371	 0.00616	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60036	 60039	 0.065214	 0.121279	 0.00284	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60036	 60042	 0.186986	 0.428371	 0.01048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60037	 76065	 0.068007	 0.126464	 0.00296	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60038	 76064	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60039	 60040	 0.092964	 0.065857	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76065	 60039	 0.094364	 0.175507	 0.00411	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76065	 60041	 0.326079	 0.231171	 0.00366	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60042	 76117	 0.080393	 0.182407	 0.00364	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60043	 76070	 0.263229	 0.170514	 0.00324	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60044	 61558	 0.000486	 0.008093	 0.07586	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60044	 76066	 6.6e-05	 0.005263	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76067	 60044	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60044	 76073	 0.001443	 0.014879	 0.23414	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60044	 76073	 0.001443	 0.014879	 0.23414	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60045	 60046	 0.000507	 0.008829	 0.02964	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76066	 60045	 0.000743	 0.0104	 0.04315	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60045	 76575	 0.002279	 0.015521	 0.02795	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75483	 60046	 0.000864	 0.014829	 0.06206	 1083.0	 1137.15	 1191.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60046	 76068	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76069	 60046	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60047	 60050	 0.005993	 0.041779	 0.01571	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75526	 60047	 0.006264	 0.054257	 0.01949	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75471	 60048	 0.02495	 0.057936	 0.01766	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75985	 60048	 0.044979	 0.119021	 0.0279	 118.0	 123.9	 129.8	 1.0	 0.0	 0	 -30.0	 30.0;
	60049	 60050	 0.00205	 0.015721	 0.00421	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60049	 60057	 0.006843	 0.065314	 0.02649	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75484	 60049	 0.024186	 0.111071	 0.02849	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60049	 76070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60049	 76070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75495	 60051	 0.004736	 0.018621	 0.00487	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60051	 76071	 0.004586	 0.017421	 0.00488	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75472	 60052	 0.0044	 0.024136	 0.00638	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75495	 60052	 0.003979	 0.017729	 0.00481	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75473	 60053	 0.014121	 0.040507	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75471	 60054	 0.001779	 0.009279	 0.00224	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75472	 60054	 0.000664	 0.00295	 0.0008	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60055	 76071	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76072	 60055	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76072	 60056	 0.089086	 0.079836	 0.00164	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60057	 60063	 0.007386	 0.074707	 0.02199	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60058	 60068	 0.000557	 0.007979	 0.55814	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60058	 76073	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60058	 76073	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75488	 60059	 0.107529	 0.118279	 0.00158	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60060	 76076	 0.202543	 0.143514	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60061	 60062	 0.00535	 0.018729	 0.00621	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76074	 60061	 0.01765	 0.064236	 0.01968	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60062	 60064	 0.006721	 0.026907	 0.00678	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60063	 60064	 0.005886	 0.054836	 0.01699	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60064	 60065	 0.003679	 0.016864	 0.00432	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75487	 60065	 0.0218	 0.074829	 0.01794	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60065	 76076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60065	 76076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60066	 76077	 0.464421	 0.301236	 0.00573	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76075	 60067	 0.434564	 0.308271	 0.00487	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60068	 76077	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60068	 76077	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75465	 60069	 4.3e-05	 0.000707	 0.01157	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75481	 60069	 0.001586	 0.017379	 0.16902	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60069	 76078	 8.1e-05	 0.006451	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76079	 60069	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60070	 60071	 0.000457	 0.003421	 0.00095	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76079	 60070	 0.000814	 0.006279	 0.0022	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60071	 76080	 0.000636	 0.005179	 0.00165	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60072	 60074	 0.000579	 0.007271	 0.02959	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76078	 60072	 0.000321	 0.003171	 0.01552	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60072	 76080	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76081	 60072	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60072	 76083	 0.000207	 0.0021	 0.00423	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60073	 60957	 0.000207	 0.002929	 0.20233	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60073	 76082	 7.2e-05	 0.005789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76083	 60073	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75468	 60075	 0.133771	 0.41105	 0.01116	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76081	 60075	 0.024614	 0.086186	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76063	 60076	 0.012421	 0.162086	 0.04701	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76063	 60076	 0.012421	 0.162086	 0.04701	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75950	 60077	 0.005386	 0.087586	 0.17579	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 60077	 0.000379	 0.004921	 0.01114	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60077	 76084	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60077	 76084	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60078	 60105	 0.000986	 0.004607	 0.00114	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76084	 60078	 0.00095	 0.00395	 0.00123	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60079	 60098	 0.000379	 0.003457	 0.00126	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76084	 60079	 0.000343	 0.003614	 0.00099	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76027	 60080	 0.036486	 0.023621	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60081	 60083	 0.001886	 0.004843	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60081	 76085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60081	 76085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60081	 76092	 0.004286	 0.011329	 0.00265	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60082	 60084	 0.000443	 0.0033	 0.00169	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60083	 60084	 0.001436	 0.004007	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60083	 60094	 0.001929	 0.005243	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60084	 60085	 0.000457	 0.003271	 0.00101	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60085	 60086	 0.001257	 0.005186	 0.00123	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60085	 60091	 0.000707	 0.003671	 0.00108	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60085	 76086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60085	 76086	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60086	 76087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60086	 76087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60087	 60088	 0.00285	 0.010929	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60087	 76088	 0.004371	 0.023493	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60088	 60089	 0.002064	 0.008064	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60089	 60140	 0.004186	 0.012836	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60090	 60129	 0.00495	 0.016143	 0.00429	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60090	 60143	 0.000771	 0.005279	 0.00154	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60091	 76088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60091	 76088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60092	 60097	 0.001114	 0.004586	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60092	 76089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60092	 76089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76089	 60093	 0.003286	 0.016314	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60093	 76102	 0.002579	 0.013836	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60094	 60098	 0.001686	 0.007	 0.00164	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60094	 76090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60094	 76090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76088	 60095	 0.006336	 0.016786	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76090	 60095	 0.003243	 0.012436	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76090	 60096	 0.007479	 0.013436	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60096	 76091	 0.019007	 0.0123	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60097	 76091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60097	 76091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60097	 76092	 0.001207	 0.00475	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60098	 76092	 0.001714	 0.006729	 0.00176	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76013	 60099	 0.000793	 0.009286	 0.01729	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60099	 76092	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76093	 60099	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76093	 60100	 0.00945	 0.019864	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60100	 76096	 0.013036	 0.018993	 0.00043	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76093	 60101	 0.023307	 0.015086	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60102	 60120	 0.002186	 0.01085	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60102	 76094	 0.002886	 0.015486	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60103	 60104	 0.000729	 0.003343	 0.00086	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60103	 60108	 0.00095	 0.003729	 0.00098	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60103	 60114	 0.000914	 0.004357	 0.00104	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60104	 60105	 0.000757	 0.003593	 0.00104	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76084	 60104	 0.003871	 0.011757	 0.00257	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60106	 60110	 0.046407	 0.030043	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60107	 60108	 0.000729	 0.00285	 0.00074	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60107	 60119	 0.001107	 0.004686	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60107	 76094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60107	 76094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60108	 60109	 0.000914	 0.005686	 0.00161	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76014	 60109	 0.001443	 0.011964	 0.00315	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60109	 76095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60109	 76095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76094	 60110	 0.007407	 0.013771	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76095	 60110	 0.003929	 0.015336	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60111	 60117	 0.02205	 0.015621	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60111	 60118	 0.006271	 0.014557	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60111	 76097	 0.008671	 0.020143	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60112	 60119	 0.000886	 0.003557	 0.0009	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60112	 60153	 0.002686	 0.009214	 0.00221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76092	 60112	 0.005593	 0.014057	 0.00364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60113	 76096	 0.014907	 0.013357	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60114	 60116	 0.001157	 0.006043	 0.00159	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60114	 76096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60114	 76096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60115	 60117	 0.011157	 0.022921	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76096	 60115	 0.00605	 0.016036	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60115	 76097	 0.009614	 0.010264	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76092	 60116	 0.001214	 0.004629	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60116	 76097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60116	 76097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60117	 60118	 0.003779	 0.00865	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60117	 76108	 0.006007	 0.020507	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60118	 76098	 0.003636	 0.012729	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60120	 76110	 0.004593	 0.017936	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60121	 60151	 0.002643	 0.0137	 0.00334	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76092	 60121	 0.002093	 0.01125	 0.00276	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60121	 76098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60121	 76098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76098	 60122	 0.020336	 0.014407	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60123	 60124	 0.020236	 0.014336	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76097	 60123	 0.029671	 0.023479	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60124	 60127	 0.003436	 0.01055	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76089	 60124	 0.0139	 0.032279	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76093	 60124	 0.002964	 0.018221	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76097	 60124	 0.007657	 0.017779	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60125	 60126	 0.003121	 0.018707	 0.00045	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60125	 76107	 0.004921	 0.030271	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60126	 60131	 0.005843	 0.010864	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76097	 60126	 0.010343	 0.031736	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60127	 60128	 0.01025	 0.01035	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60127	 60131	 0.008236	 0.016929	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76089	 60128	 0.02045	 0.013236	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60129	 60130	 0.001236	 0.003271	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60129	 60138	 0.001686	 0.004543	 0.00127	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60129	 76099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60129	 76099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60130	 60132	 0.001414	 0.004429	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60131	 76100	 0.003221	 0.008536	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60132	 76100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60132	 76100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60133	 76101	 0.023414	 0.018529	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60133	 76102	 0.025679	 0.020321	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60134	 60135	 0.003643	 0.020714	 0.00037	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60134	 60140	 0.003914	 0.017336	 0.00039	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60135	 60136	 0.002793	 0.013007	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76099	 60136	 0.002286	 0.011357	 0.00027	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60137	 60138	 0.001436	 0.0036	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60137	 76101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60137	 76101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60138	 76102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60138	 76102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76088	 60139	 0.00225	 0.011157	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76101	 60139	 0.004557	 0.018086	 0.00051	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60140	 76103	 0.002357	 0.011314	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60141	 60143	 0.001364	 0.00675	 0.00197	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60141	 60146	 0.001157	 0.005636	 0.00156	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60141	 60149	 0.002536	 0.010157	 0.00256	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60141	 60185	 0.009321	 0.037307	 0.01261	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76060	 60141	 0.004036	 0.035743	 0.01964	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60141	 76103	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60141	 76103	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60142	 60147	 0.005171	 0.012	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60142	 76104	 0.008493	 0.019714	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60143	 76104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60143	 76104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60144	 60145	 0.001643	 0.0067	 0.00163	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60144	 60182	 0.004307	 0.015071	 0.00499	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60144	 76105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60144	 76105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60145	 60146	 0.001143	 0.005436	 0.00129	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60146	 76106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60146	 76106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60147	 60148	 0.009836	 0.020214	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75877	 60147	 0.015879	 0.0467	 0.00096	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76103	 60147	 0.009179	 0.02325	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76106	 60148	 0.009229	 0.012129	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60150	 60151	 0.003564	 0.019179	 0.00527	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60150	 60187	 0.004743	 0.024757	 0.00596	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60151	 76107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60151	 76107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60152	 60155	 0.010214	 0.023721	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60152	 60156	 0.007307	 0.015014	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60153	 76108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60153	 76108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60154	 60155	 0.002093	 0.009271	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76108	 60154	 0.001864	 0.009264	 0.00022	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60155	 76110	 0.003943	 0.01955	 0.00046	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60155	 76111	 0.006586	 0.022486	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60156	 60157	 0.0158	 0.011193	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60156	 60163	 0.010493	 0.011207	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60158	 60165	 0.004936	 0.013529	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60158	 76109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60158	 76109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60159	 60160	 0.005193	 0.013343	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76109	 60159	 0.008836	 0.020507	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76108	 60160	 0.012979	 0.037221	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60161	 76111	 0.044586	 0.031586	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60162	 60163	 0.016814	 0.019707	 0.00034	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60162	 60167	 0.031493	 0.024921	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76109	 60162	 0.017357	 0.01705	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60163	 60167	 0.016286	 0.010543	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76109	 60163	 0.014886	 0.029471	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60163	 76111	 0.005764	 0.019686	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60164	 60165	 0.001471	 0.005736	 0.00154	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76014	 60164	 0.005243	 0.027264	 0.00803	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60164	 76110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60164	 76110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60165	 76111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60165	 76111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60166	 60167	 0.010186	 0.007214	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60169	 60170	 0.016986	 0.038843	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60169	 76112	 0.030029	 0.068679	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60170	 60171	 0.0128	 0.0263	 0.0005	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60171	 60172	 0.019786	 0.052436	 0.00133	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60171	 60174	 0.03935	 0.046129	 0.0008	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76109	 60171	 0.006336	 0.034007	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60172	 60183	 0.07075	 0.145414	 0.00277	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60173	 60174	 0.012271	 0.020671	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60173	 60176	 0.011364	 0.02335	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60175	 60176	 0.009893	 0.020336	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76109	 60175	 0.024607	 0.082086	 0.0013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60176	 76112	 0.009457	 0.046929	 0.00112	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60177	 60179	 0.010114	 0.04115	 0.01003	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60177	 60180	 0.009629	 0.033557	 0.00778	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60177	 76112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60177	 76112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60178	 76113	 0.063021	 0.124793	 0.00183	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60179	 60180	 0.009071	 0.04325	 0.01253	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60179	 76113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60179	 76113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76064	 60180	 0.009279	 0.060664	 0.01544	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60180	 76114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60180	 76114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75904	 60181	 0.018607	 0.243564	 0.07099	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75904	 60181	 0.018607	 0.243564	 0.07099	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60182	 76115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60182	 76115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60183	 60184	 0.00415	 0.012736	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76115	 60183	 0.021386	 0.054986	 0.00085	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60184	 76116	 0.01045	 0.015664	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60185	 60186	 0.004464	 0.017543	 0.00459	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60185	 76116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60185	 76116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60186	 60187	 0.006786	 0.022629	 0.00574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60186	 60197	 0.007779	 0.028307	 0.00866	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60187	 60195	 0.0122	 0.049657	 0.0121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60188	 60192	 0.027793	 0.106507	 0.00301	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76114	 60188	 0.028771	 0.154536	 0.00367	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60189	 60190	 0.014757	 0.052186	 0.01176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60189	 60194	 0.008229	 0.0335	 0.00816	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76064	 60190	 0.008507	 0.093943	 0.0257	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60190	 76117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60190	 76117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60191	 60198	 0.030614	 0.087807	 0.00135	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76103	 60191	 0.0809	 0.316179	 0.00702	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60191	 76119	 0.004836	 0.012807	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60192	 60193	 0.005736	 0.0196	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76117	 60192	 0.141329	 0.290629	 0.00554	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60193	 76118	 0.005979	 0.017586	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60193	 76119	 0.00835	 0.02455	 0.0005	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60194	 60196	 0.001114	 0.004057	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60195	 60196	 0.001529	 0.006229	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60195	 76118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60195	 76118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60196	 76119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60196	 76119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60199	 61436	 0.002214	 0.034629	 0.42259	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60199	 76120	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60199	 76120	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60199	 76121	 0.0008	 0.010929	 0.11144	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60200	 76121	 0.000173	 0.01294	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60200	 76121	 0.000173	 0.01294	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60201	 76123	 0.025307	 0.0345	 0.00076	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60202	 60433	 0.001907	 0.020971	 0.2041	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60202	 76122	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76123	 60203	 0.035957	 0.023279	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60204	 76212	 0.019771	 0.093471	 0.02996	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60205	 60209	 0.010243	 0.041014	 0.01034	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60205	 76212	 0.010329	 0.05765	 0.01473	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75733	 60206	 0.022807	 0.020436	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60207	 76124	 0.022029	 0.0156	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60208	 60209	 0.001207	 0.004214	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75731	 60208	 0.009829	 0.0247	 0.0064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60208	 76124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60208	 76124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60210	 60212	 0.000471	 0.002514	 0.00064	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60210	 60215	 0.002121	 0.008836	 0.00276	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60211	 60212	 0.001814	 0.010429	 0.00296	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60211	 60218	 0.006364	 0.016821	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75512	 60211	 0.003443	 0.037721	 0.01046	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60211	 76125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60211	 76125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60213	 76126	 0.030264	 0.019593	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60214	 76126	 0.013993	 0.009907	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60215	 60216	 0.000871	 0.007243	 0.00191	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60215	 60432	 0.003357	 0.010943	 0.00291	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75512	 60215	 0.004479	 0.049514	 0.01486	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60215	 76126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60215	 76126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60216	 60223	 0.001171	 0.005714	 0.00158	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60216	 76127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60216	 76127	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60217	 60220	 0.075579	 0.053536	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60218	 60245	 0.012793	 0.034357	 0.00779	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60219	 60220	 0.013086	 0.023014	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76126	 60219	 0.065879	 0.04265	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60220	 60221	 0.004486	 0.017529	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60220	 60224	 0.122943	 0.0796	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76125	 60221	 0.008007	 0.035479	 0.00106	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60222	 60227	 0.043593	 0.030879	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76127	 60222	 0.014429	 0.02965	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60223	 60225	 0.002	 0.007071	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60225	 60230	 0.001814	 0.005907	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60225	 76128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60225	 76128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76128	 60226	 0.032464	 0.025693	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60227	 60229	 0.0909	 0.05885	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60228	 76129	 0.036336	 0.0357	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60230	 60236	 0.007293	 0.018336	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60230	 76129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60230	 76129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60231	 60232	 0.036721	 0.026014	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76129	 60231	 0.029157	 0.02065	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60232	 60233	 0.006479	 0.016407	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60232	 76209	 0.013021	 0.026757	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60233	 60234	 0.018029	 0.01615	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60234	 60235	 0.016507	 0.016679	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60235	 76130	 0.004886	 0.01295	 0.00033	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60236	 60237	 0.001071	 0.0036	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60236	 76130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60236	 76130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60236	 76207	 0.001886	 0.013771	 0.00406	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60237	 60238	 0.001179	 0.004029	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60238	 60241	 0.0031	 0.009136	 0.00212	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60239	 76131	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60239	 76131	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75483	 60240	 0.003843	 0.026979	 0.04596	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60240	 76132	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60240	 76132	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60240	 76133	 0.00405	 0.027657	 0.04983	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75526	 60241	 0.017093	 0.042964	 0.01114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76131	 60241	 0.004693	 0.012786	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76132	 60241	 0.004329	 0.010879	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75478	 60242	 0.003707	 0.040914	 0.40059	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75525	 60242	 0.001614	 0.018336	 0.16716	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60242	 76133	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60242	 76133	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60243	 60244	 0.010921	 0.028364	 0.00689	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60243	 61626	 0.011514	 0.029593	 0.00733	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60243	 76134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60243	 76134	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60244	 60245	 0.011	 0.02855	 0.00693	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60244	 61626	 0.01395	 0.037993	 0.00837	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60244	 76135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60244	 76135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75511	 60246	 0.002207	 0.013393	 0.03051	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75547	 60246	 0.004514	 0.031693	 0.054	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60247	 61006	 0.544614	 0.353507	 0.00673	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60248	 60249	 0.002236	 0.030064	 0.10629	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60248	 61374	 0.0024	 0.029793	 0.10769	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60249	 60250	 0.000714	 0.008971	 0.03138	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60249	 76136	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60249	 76136	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75541	 60250	 0.004021	 0.033579	 0.10491	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75556	 60250	 0.001021	 0.013321	 0.04313	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60250	 76137	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60250	 76137	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60251	 60252	 0.00225	 0.023814	 0.00707	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60251	 60948	 0.010107	 0.078357	 0.02748	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60252	 76138	 0.002579	 0.028514	 0.00855	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75542	 60253	 0.016357	 0.041429	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60254	 76139	 0.055507	 0.043507	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75541	 60255	 0.00145	 0.009893	 0.01781	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60255	 76138	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76139	 60255	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60256	 60257	 0.038229	 0.027079	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60256	 60416	 0.011029	 0.019821	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76139	 60256	 0.014829	 0.023664	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60257	 60416	 0.034343	 0.022236	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60257	 76205	 0.01755	 0.025571	 0.00058	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60257	 76206	 0.010143	 0.025686	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60257	 76389	 0.673186	 0.437571	 0.00832	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75540	 60258	 0.000893	 0.009971	 0.09404	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60258	 76140	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60258	 76140	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60259	 60260	 0.038107	 0.030157	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76139	 60260	 0.061793	 0.055371	 0.00114	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60261	 60263	 0.29425	 0.190643	 0.00363	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60262	 60265	 0.067714	 0.170693	 0.04437	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60262	 60464	 0.108964	 0.290129	 0.06851	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60262	 76141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60262	 76141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60263	 60264	 0.5489	 0.389729	 0.00616	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76141	 60263	 0.116829	 0.075643	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60264	 60496	 0.126193	 0.258421	 0.00636	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60264	 76142	 0.408571	 0.289786	 0.00458	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60265	 76142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60265	 76142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60265	 76377	 0.046114	 0.175807	 0.04941	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60266	 60267	 0.008743	 0.014736	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76142	 60266	 0.007671	 0.022	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60267	 60268	 0.010736	 0.011464	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60267	 60269	 0.061443	 0.039779	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60268	 60270	 0.010121	 0.020036	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60270	 60271	 0.02025	 0.027607	 0.00061	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60270	 60273	 0.1475	 0.144929	 0.00245	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60271	 60272	 0.018429	 0.046671	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76142	 60271	 0.133343	 0.094464	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60272	 60274	 0.029329	 0.077736	 0.00197	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60273	 60276	 0.0907	 0.179607	 0.00264	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60274	 60275	 0.012379	 0.042293	 0.00092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60275	 60282	 0.0659	 0.042664	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60275	 76143	 0.013243	 0.056621	 0.00128	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60276	 60280	 0.05515	 0.128043	 0.00191	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60277	 76143	 0.051386	 0.0364	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60278	 60279	 0.002521	 0.00585	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60278	 60493	 0.009929	 0.034071	 0.00816	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60279	 60493	 0.011821	 0.040564	 0.00972	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60279	 76143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60279	 76143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60280	 76232	 0.040157	 0.101714	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76141	 60281	 0.677857	 0.440636	 0.00838	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60283	 76144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60283	 76144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60284	 60299	 0.01415	 0.071586	 0.00124	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76144	 60284	 0.017129	 0.075893	 0.00228	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60285	 60286	 0.0307	 0.062821	 0.00154	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60285	 76149	 0.059714	 0.105029	 0.00197	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60285	 76197	 0.095407	 0.061771	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75569	 60286	 0.013279	 0.046486	 0.00129	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60286	 76145	 0.030971	 0.06365	 0.00121	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60287	 60290	 0.003621	 0.018914	 0.00456	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60287	 76145	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60287	 76145	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60288	 60404	 0.000379	 0.004164	 0.04085	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60288	 76146	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60288	 76146	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60289	 60331	 0.000357	 0.004114	 0.03554	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60289	 60405	 0.000714	 0.009807	 0.1	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60289	 76147	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60290	 60295	 0.00335	 0.015621	 0.00387	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60291	 60317	 0.002371	 0.014443	 0.00364	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60291	 76150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60291	 76150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60292	 60296	 0.036743	 0.026029	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60292	 60316	 0.014493	 0.036707	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76150	 60292	 0.009814	 0.0301	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60293	 60295	 0.001714	 0.005893	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60293	 60321	 0.002421	 0.008086	 0.00205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60294	 60295	 0.001486	 0.005193	 0.00172	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60294	 60320	 0.001307	 0.005221	 0.00131	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60295	 76163	 0.001307	 0.004564	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76145	 60297	 0.010914	 0.041807	 0.00118	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76150	 60297	 0.020671	 0.038436	 0.0009	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60297	 76164	 0.045579	 0.093671	 0.00179	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60298	 60299	 0.006457	 0.019807	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76150	 60298	 0.01175	 0.020657	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76150	 60299	 0.016879	 0.031386	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60300	 60308	 0.067657	 0.139057	 0.00265	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76144	 60300	 0.036371	 0.162107	 0.00275	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60300	 76153	 0.028407	 0.097043	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76150	 60301	 0.020864	 0.048436	 0.00072	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60301	 76155	 0.031021	 0.054557	 0.00103	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60302	 76151	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60302	 76151	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76152	 60302	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60303	 60304	 0.000707	 0.006079	 0.00173	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76152	 60303	 0.000814	 0.007643	 0.00231	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60304	 60371	 0.000807	 0.006279	 0.00163	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60305	 60306	 0.005586	 0.018636	 0.00473	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76152	 60305	 0.002657	 0.011979	 0.00319	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60306	 60307	 0.005707	 0.019564	 0.00469	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60307	 60363	 0.005021	 0.016386	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60307	 76153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60307	 76153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60308	 60310	 0.073107	 0.051786	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76153	 60308	 0.022086	 0.03525	 0.00081	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60308	 76177	 0.028407	 0.023379	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60309	 76186	 0.059757	 0.038693	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60310	 76154	 0.007171	 0.022	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60310	 76180	 0.0122	 0.025079	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60311	 60364	 6.4e-05	 0.000807	 0.0129	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60311	 60370	 4.3e-05	 0.0006	 0.00914	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60311	 76154	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60311	 76154	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60312	 76186	 0.027814	 0.018007	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60313	 60322	 0.0219	 0.022114	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60313	 76156	 0.005457	 0.016036	 0.00033	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60313	 76170	 0.036686	 0.02375	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60314	 60315	 0.003	 0.006857	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60314	 76170	 0.006757	 0.010786	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60315	 76156	 0.004129	 0.00945	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60316	 60322	 0.009914	 0.026279	 0.00066	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60316	 76155	 0.016529	 0.033964	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60317	 60318	 0.002629	 0.010529	 0.00265	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60317	 76155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60317	 76155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60318	 76156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60318	 76156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76156	 60319	 0.029557	 0.020943	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60320	 60324	 0.000643	 0.003043	 0.00073	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60320	 76157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60320	 76157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60321	 60323	 0.0022	 0.006886	 0.00199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60322	 76158	 0.01065	 0.017	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60322	 76168	 0.010964	 0.0217	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60323	 60324	 0.002307	 0.005936	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60323	 60341	 0.002221	 0.005714	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60323	 76158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60323	 76158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60324	 60325	 0.000543	 0.002207	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60325	 60337	 0.000786	 0.002986	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60325	 60343	 0.003393	 0.009464	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60326	 60336	 0.001193	 0.004764	 0.0012	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60326	 76159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60326	 76159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60326	 76160	 0.001029	 0.004257	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76149	 60327	 0.029307	 0.060229	 0.00115	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60327	 76164	 0.015436	 0.031721	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60328	 60330	 0.000443	 0.003014	 0.00542	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60328	 60333	 0.000214	 0.002364	 0.00506	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76147	 60328	 0.000586	 0.008707	 0.02037	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76159	 60329	 0.020757	 0.018729	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60329	 76161	 0.014157	 0.019314	 0.00034	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60330	 76160	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76161	 60330	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60330	 76162	 0.000143	 0.001536	 0.00389	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60331	 60365	 0.000729	 0.007986	 0.0776	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60331	 76162	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60332	 60334	 0.000364	 0.003107	 0.00089	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60332	 60376	 0.000421	 0.003079	 0.00079	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75518	 60332	 0.002414	 0.00965	 0.00243	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60334	 60336	 0.000407	 0.003579	 0.00095	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60335	 76165	 0.0236	 0.015279	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76163	 60336	 0.003364	 0.013686	 0.00334	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60336	 76165	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60336	 76165	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75518	 60337	 0.00485	 0.01635	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60337	 76166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60337	 76166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60338	 60374	 0.001464	 0.003757	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60338	 76167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60338	 76167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60339	 60341	 0.001386	 0.003336	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60339	 60353	 0.0018	 0.004664	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76158	 60340	 0.0046	 0.0157	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60340	 76189	 0.036836	 0.055221	 0.001	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60341	 76168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60341	 76168	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60342	 60347	 0.001043	 0.003257	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60342	 60372	 0.003129	 0.008521	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60343	 60372	 0.001857	 0.004479	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60343	 76169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60343	 76169	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60344	 60348	 0.001693	 0.005514	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60344	 60372	 0.001114	 0.003057	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76168	 60345	 0.009686	 0.018014	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76169	 60345	 0.02075	 0.016421	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60345	 76187	 0.015357	 0.019064	 0.00041	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60346	 60349	 0.002143	 0.005557	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60346	 60386	 0.001164	 0.004664	 0.00117	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 60346	 0.002621	 0.009529	 0.00291	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60346	 76173	 0.000664	 0.004579	 0.00134	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60347	 60367	 0.001793	 0.006379	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60348	 60349	 0.001121	 0.003371	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60349	 60354	 0.000986	 0.003507	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60350	 76174	 0.017343	 0.011229	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60351	 76176	 0.019264	 0.013929	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60352	 60353	 0.001771	 0.004114	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60352	 60369	 0.002143	 0.005386	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60352	 76170	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60352	 76170	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60353	 60367	 0.001036	 0.002807	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60354	 60355	 0.000829	 0.003421	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 60356	 0.001186	 0.004064	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 76171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60355	 76171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60355	 76173	 0.001629	 0.004429	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 76175	 0.002007	 0.006764	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60356	 60368	 0.000971	 0.003429	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60356	 76172	 0.000707	 0.005143	 0.00178	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60357	 76176	 0.0169	 0.010943	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60358	 76172	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60358	 76172	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60358	 76178	 0.000457	 0.003093	 0.00569	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60358	 76181	 0.000243	 0.001557	 0.00311	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60359	 60360	 0.000221	 0.001914	 0.00365	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76030	 60359	 0.000771	 0.005414	 0.00921	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60359	 76173	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76174	 60359	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60360	 76175	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76176	 60360	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60360	 76181	 0.000114	 0.001779	 0.00383	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60361	 76180	 0.01695	 0.010971	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60362	 60366	 0.012207	 0.019486	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76155	 60362	 0.023271	 0.05895	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60362	 76183	 0.017729	 0.011479	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60363	 60367	 0.002107	 0.011943	 0.00296	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76172	 60363	 0.002286	 0.006229	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60363	 76177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60363	 76177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60364	 60365	 6.4e-05	 0.000729	 0.00688	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60364	 76178	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76029	 60365	 0.000214	 0.0036	 0.03396	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60365	 76181	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60365	 76181	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76171	 60366	 0.025679	 0.021136	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60366	 76182	 0.00615	 0.010086	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 60367	 0.008386	 0.019464	 0.00593	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60367	 76182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60367	 76182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60368	 60369	 0.000771	 0.00205	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60369	 76183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60369	 76183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75466	 60370	 0.00085	 0.015421	 0.15435	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60370	 76184	 8.1e-05	 0.006451	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76185	 60371	 0.001986	 0.0067	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60372	 76187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60372	 76187	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76167	 60373	 0.0172	 0.020157	 0.00035	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60373	 76190	 0.011	 0.00905	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60374	 60375	 0.000921	 0.002793	 0.00061	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60374	 60382	 0.00205	 0.005493	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60375	 60376	 0.000857	 0.002307	 0.00065	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60376	 60377	 0.00035	 0.002071	 0.00056	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60377	 60378	 0.000443	 0.002507	 0.00073	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60378	 60379	 0.000479	 0.002129	 0.00058	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60379	 60381	 0.001786	 0.00635	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60379	 76188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60379	 76188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76188	 60380	 0.00635	 0.008657	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60380	 76189	 0.010007	 0.015971	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60381	 60382	 0.001214	 0.004307	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 60381	 0.005293	 0.01815	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60381	 76189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60381	 76189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60382	 60383	 0.00095	 0.003093	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60382	 76190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60382	 76190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60383	 60384	 0.001029	 0.003343	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60384	 60385	 0.000621	 0.0022	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60385	 60386	 0.000936	 0.003264	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75560	 60387	 0.052686	 0.119514	 0.00239	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60388	 60400	 0.000321	 0.002629	 0.00483	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75588	 60388	 0.000179	 0.001164	 0.00231	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60388	 76198	 0.0018	 0.013857	 0.02471	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60389	 60393	 0.000964	 0.002714	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60389	 60411	 0.001464	 0.003393	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60389	 76191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60389	 76191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60390	 60391	 0.01035	 0.007329	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76191	 60390	 0.0184	 0.011914	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60390	 76202	 0.030771	 0.019921	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75563	 60391	 0.008064	 0.00945	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75888	 60391	 0.086329	 0.151843	 0.00286	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60391	 76192	 0.007714	 0.01435	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60392	 60393	 0.001021	 0.003007	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75524	 60392	 0.00065	 0.003514	 0.00096	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60392	 76192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60392	 76192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76192	 60394	 0.017864	 0.01755	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60394	 76200	 0.074921	 0.119607	 0.00276	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60395	 76193	 0.0224	 0.014507	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60396	 60408	 0.007221	 0.028093	 0.00751	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75524	 60396	 0.002179	 0.009	 0.00213	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60396	 76193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60396	 76193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60397	 60398	 0.027321	 0.024486	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76191	 60397	 0.021414	 0.037664	 0.00071	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76193	 60397	 0.016321	 0.028707	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60398	 60402	 0.043057	 0.034079	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60399	 76202	 0.022843	 0.018071	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60400	 60970	 0.003936	 0.029493	 0.1143	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60400	 76194	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76195	 60400	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60401	 60406	 0.141514	 0.100257	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76195	 60401	 0.02385	 0.021371	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60403	 60407	 0.018586	 0.058107	 0.01684	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60404	 76196	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60405	 76198	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76199	 60405	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60407	 60975	 0.018014	 0.054236	 0.01697	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60408	 76200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60408	 76200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60409	 60974	 0.024736	 0.094786	 0.00268	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76200	 60409	 0.017414	 0.077164	 0.00231	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60409	 76201	 0.107879	 0.147214	 0.00263	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76194	 60410	 0.009407	 0.055121	 0.01502	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60410	 76201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60410	 76201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60410	 76394	 0.00545	 0.049657	 0.01805	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76194	 60411	 0.00055	 0.00445	 0.00141	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60411	 76202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60411	 76202	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60412	 76203	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60412	 76203	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76204	 60413	 0.562864	 0.407864	 0.00619	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60414	 60419	 0.005679	 0.021571	 0.00604	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75587	 60414	 0.001279	 0.013293	 0.00411	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60415	 60417	 0.030321	 0.029786	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75542	 60415	 0.04305	 0.088486	 0.00169	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76139	 60415	 0.034707	 0.028564	 0.00058	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60416	 76205	 0.0093	 0.01485	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60416	 76206	 0.015721	 0.027643	 0.00052	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60417	 76205	 0.017014	 0.016714	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60418	 60419	 0.001171	 0.003957	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76138	 60418	 0.005886	 0.01555	 0.00364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60418	 76205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60418	 76205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60419	 76206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60419	 76206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60420	 61493	 0.009543	 0.076707	 0.02158	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75510	 60420	 0.006057	 0.070079	 0.04348	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60421	 60422	 0.069771	 0.232829	 0.00369	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75565	 60421	 0.088471	 0.2603	 0.00534	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75565	 60422	 0.147679	 0.338107	 0.00826	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60422	 76404	 0.0672	 0.40315	 0.00971	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75525	 60423	 0.000886	 0.010021	 0.09129	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75544	 60423	 0.000636	 0.007029	 0.06694	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60423	 76207	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60423	 76207	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60423	 76606	 0.003443	 0.039179	 0.35914	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60424	 60426	 0.001679	 0.004214	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76207	 60424	 0.002471	 0.007279	 0.00169	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60424	 76208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60424	 76208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60425	 60435	 0.008914	 0.016571	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76208	 60425	 0.014986	 0.017571	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60426	 60428	 0.00315	 0.008586	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60427	 60428	 0.004	 0.01005	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60427	 60430	 0.001336	 0.003521	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60428	 76209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60428	 76209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75512	 60429	 0.010164	 0.036979	 0.01132	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60429	 76210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60429	 76210	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60430	 60432	 0.001986	 0.005864	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76209	 60431	 0.037914	 0.030007	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75537	 60433	 0.000479	 0.005493	 0.04816	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76121	 60433	 0.001779	 0.020186	 0.18409	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60433	 76211	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60433	 76211	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76210	 60434	 0.085286	 0.244679	 0.00376	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60436	 61595	 0.005136	 0.0347	 0.06395	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75534	 60436	 0.003086	 0.021643	 0.03686	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75559	 60436	 0.002636	 0.017993	 0.0324	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60436	 76212	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60436	 76212	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75509	 60437	 0.001736	 0.026557	 0.09285	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76203	 60437	 0.002693	 0.037614	 0.07285	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60437	 76213	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60437	 76213	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60437	 76400	 0.0021	 0.034186	 0.06756	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60438	 60444	 0.0038	 0.03715	 0.01043	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60439	 60440	 0.099757	 0.070671	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60440	 60449	 0.180171	 0.142614	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75568	 60440	 0.041464	 0.199129	 0.00596	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60440	 76215	 0.143893	 0.295907	 0.00564	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76206	 60441	 0.432529	 0.306829	 0.00485	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60441	 76214	 0.08965	 0.063507	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60441	 76215	 0.487279	 0.386236	 0.00486	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60442	 60443	 0.027379	 0.0711	 0.01726	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60442	 60446	 0.042236	 0.1135	 0.02576	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75587	 60442	 0.016443	 0.056421	 0.01352	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60442	 76214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60442	 76214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75587	 60443	 0.037043	 0.123729	 0.03144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76122	 60443	 0.020057	 0.107921	 0.02659	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60443	 76215	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60443	 76215	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60444	 60446	 0.004171	 0.015179	 0.00464	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60444	 60447	 0.002786	 0.026214	 0.00794	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75557	 60444	 0.045807	 0.2098	 0.06701	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60444	 76216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60444	 76216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76216	 60445	 0.0202	 0.041521	 0.00079	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60445	 76218	 0.031171	 0.064064	 0.00122	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60446	 60448	 0.002864	 0.009543	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60447	 60450	 0.005121	 0.045371	 0.01208	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60447	 76217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60447	 76217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60448	 76218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60448	 76218	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76122	 60450	 0.005343	 0.042929	 0.01207	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76123	 60451	 0.065557	 0.173814	 0.00441	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76215	 60451	 0.046257	 0.203857	 0.00354	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75549	 60452	 0.085957	 0.2178	 0.00431	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76215	 60452	 0.109471	 0.248436	 0.00496	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60453	 60465	 0.217836	 0.2397	 0.0032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60454	 60468	 0.417821	 0.296364	 0.00469	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60454	 76219	 0.29575	 0.191614	 0.00365	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60455	 76219	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60455	 76219	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60456	 60459	 0.017171	 0.058921	 0.01412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60456	 60983	 0.038857	 0.104414	 0.02369	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 60456	 0.005257	 0.021407	 0.00521	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 60456	 0.005257	 0.021407	 0.00521	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 60456	 0.005257	 0.021407	 0.00521	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60456	 76220	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60456	 76220	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60456	 76377	 0.092371	 0.249307	 0.05686	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60457	 60996	 0.164586	 0.116607	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60457	 61525	 0.071164	 0.132336	 0.0031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76220	 60457	 0.022286	 0.10875	 0.00188	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60458	 60959	 0.408457	 0.264821	 0.00504	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75528	 60458	 0.029514	 0.0868	 0.00178	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76220	 60458	 0.245293	 0.173829	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60459	 60464	 0.004843	 0.0293	 0.00748	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 60459	 0.010893	 0.039643	 0.01214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 60459	 0.010893	 0.039643	 0.01214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60459	 76221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60459	 76221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60460	 60461	 0.018714	 0.038457	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76221	 60460	 0.024886	 0.056921	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60461	 60463	 0.020471	 0.030686	 0.00056	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60462	 60463	 0.02315	 0.020886	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60462	 76222	 0.05335	 0.034536	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60463	 76222	 0.07805	 0.050536	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60463	 76406	 0.132507	 0.246529	 0.00577	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 60464	 0.006571	 0.06765	 0.0192	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60464	 76222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60464	 76222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76222	 60465	 0.016143	 0.040886	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76222	 60466	 0.07145	 0.083764	 0.00146	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76222	 60467	 0.059743	 0.158371	 0.00402	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60469	 60470	 0.001514	 0.011736	 0.00411	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60469	 60472	 0.003579	 0.020979	 0.00571	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60469	 61196	 0.002443	 0.018693	 0.00501	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60469	 61201	 0.003507	 0.018607	 0.00621	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60470	 60472	 0.000907	 0.007636	 0.00226	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75564	 60470	 0.0068	 0.051207	 0.01421	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60470	 76377	 0.068293	 0.181007	 0.04251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60471	 60478	 0.002257	 0.010171	 0.00271	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60471	 61215	 0.006814	 0.034821	 0.00876	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60472	 60473	 0.001914	 0.011664	 0.00294	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60472	 60475	 0.000764	 0.005129	 0.00157	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60472	 76223	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60472	 76223	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60473	 60475	 0.002279	 0.007421	 0.00197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60473	 60494	 0.009929	 0.04555	 0.01167	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60473	 76224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60473	 76224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60474	 60477	 0.01345	 0.016693	 0.00036	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76223	 60474	 0.013286	 0.011986	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60475	 60494	 0.008714	 0.052707	 0.01346	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60475	 76225	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60475	 76225	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76225	 60476	 0.014479	 0.010257	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60477	 76226	 0.033414	 0.065486	 0.00098	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60478	 60482	 0.006343	 0.019836	 0.00574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60478	 76226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60478	 76226	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60479	 60480	 0.037193	 0.095614	 0.00148	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76224	 60479	 0.01885	 0.049964	 0.00126	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60480	 60481	 0.11205	 0.147286	 0.00202	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60481	 76229	 0.2247	 0.177879	 0.00224	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60481	 76231	 0.160957	 0.114036	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60482	 60484	 0.003886	 0.013586	 0.0045	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60482	 76227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60482	 76227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76227	 60483	 0.025043	 0.049586	 0.00073	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60483	 76519	 0.021171	 0.056114	 0.00142	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60484	 60485	 0.006071	 0.02115	 0.00491	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60485	 60487	 0.006386	 0.022579	 0.00509	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60486	 76228	 0.086614	 0.056079	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60487	 60488	 0.0057	 0.019007	 0.00482	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60487	 76228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60487	 76228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60488	 61242	 0.010357	 0.028193	 0.00621	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60488	 76229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60488	 76229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60489	 61266	 0.043214	 0.069329	 0.00128	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76229	 60489	 0.024064	 0.044743	 0.00105	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60490	 76230	 0.177871	 0.140793	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60491	 60492	 0.016043	 0.037243	 0.01135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60491	 60910	 0.014836	 0.039214	 0.00918	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60491	 76230	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60491	 76230	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60492	 60494	 0.0087	 0.023679	 0.00521	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60492	 76231	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60492	 76231	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60493	 60494	 0.008793	 0.0352	 0.00887	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60493	 76232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60493	 76232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60493	 76377	 0.023493	 0.089364	 0.02504	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60494	 76233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60494	 76233	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76233	 60495	 0.029779	 0.019279	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76219	 60496	 0.152821	 0.523143	 0.01141	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60497	 60505	 0.010257	 0.01495	 0.00034	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60497	 60640	 0.027007	 0.027279	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60497	 60641	 0.022014	 0.015593	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60497	 60657	 0.049479	 0.035771	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60497	 76249	 0.022543	 0.057107	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60498	 60504	 0.001036	 0.00325	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60498	 60634	 0.002521	 0.008229	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60498	 76234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60498	 76234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60499	 60500	 0.001486	 0.003729	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60499	 60503	 0.000893	 0.003471	 0.00093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60499	 60631	 0.003421	 0.011736	 0.00281	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60499	 76235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60499	 76235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60500	 60501	 0.000857	 0.003529	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60500	 60511	 0.001286	 0.006957	 0.00169	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60500	 60636	 0.001943	 0.008014	 0.0019	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60500	 76236	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60500	 76236	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60501	 60511	 0.000821	 0.003821	 0.00094	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60501	 76237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60501	 76237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76237	 60502	 0.018664	 0.014629	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60503	 60509	 0.0014	 0.00325	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60503	 60525	 0.001614	 0.008221	 0.00298	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60503	 61278	 0.005664	 0.022264	 0.00582	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60503	 76238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60503	 76238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60503	 76252	 0.002143	 0.016443	 0.00441	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60504	 60508	 0.000829	 0.002921	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60504	 76239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60504	 76239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60505	 60506	 0.009543	 0.006179	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60505	 60520	 0.009107	 0.021143	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60507	 76240	 0.011686	 0.007564	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60508	 60509	 0.0012	 0.003164	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60508	 60519	 0.001071	 0.003793	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60508	 76240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60508	 76240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60509	 60517	 0.000921	 0.003	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60509	 76241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60509	 76241	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76237	 60510	 0.026029	 0.018443	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76241	 60510	 0.022457	 0.017771	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60510	 76248	 0.016893	 0.026957	 0.00062	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60511	 60515	 0.000536	 0.002557	 0.00074	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60511	 60527	 0.001021	 0.006186	 0.00158	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60512	 60513	 0.00595	 0.009493	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60512	 60528	 0.004993	 0.009286	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60513	 76242	 0.018264	 0.011821	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60514	 76242	 0.0103	 0.00815	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60515	 60527	 0.000807	 0.003836	 0.00092	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60515	 76242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60515	 76242	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60516	 76246	 0.01655	 0.011721	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60517	 60524	 0.000721	 0.003	 0.0007	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60517	 76243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60517	 76243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76243	 60518	 0.015693	 0.010164	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60518	 76245	 0.010193	 0.013907	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60519	 60522	 0.001	 0.003271	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60520	 60521	 0.003521	 0.01	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60520	 60661	 0.013221	 0.0441	 0.0007	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60520	 76249	 0.008021	 0.023579	 0.00049	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60521	 76244	 0.002864	 0.011136	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60522	 60523	 0.000736	 0.001993	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60522	 60539	 0.000886	 0.003693	 0.00115	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60522	 76244	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60522	 76244	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60523	 60541	 0.00105	 0.003614	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60523	 76245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60523	 76245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60524	 60525	 0.0009	 0.003679	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 60533	 0.000914	 0.003043	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 76246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60524	 76246	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60525	 60526	 0.000386	 0.002007	 0.00053	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60525	 60527	 0.001379	 0.00415	 0.0013	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60526	 60527	 0.001	 0.002571	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60526	 60530	 0.000657	 0.00335	 0.00121	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60527	 60530	 0.000293	 0.002529	 0.00069	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60527	 76252	 0.0009	 0.004579	 0.00166	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60528	 76247	 0.004586	 0.01215	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60529	 60530	 0.001536	 0.003857	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60529	 60947	 0.008514	 0.038343	 0.01021	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60529	 76247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60529	 76247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60529	 76252	 0.001079	 0.004321	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60530	 76252	 0.000271	 0.002064	 0.00101	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60531	 60532	 0.010793	 0.007643	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60532	 76253	 0.015314	 0.016843	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60533	 60550	 0.001229	 0.005071	 0.0012	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60533	 76248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60533	 76248	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60534	 60535	 0.007107	 0.008829	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76244	 60534	 0.003871	 0.006814	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60535	 76249	 0.0106	 0.010414	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60536	 76249	 0.03225	 0.020879	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60537	 76249	 0.013514	 0.012193	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60538	 60540	 0.000657	 0.0035	 0.00116	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60538	 60644	 0.008393	 0.02985	 0.00664	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60538	 60663	 0.002671	 0.014179	 0.00473	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60538	 76249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60538	 76249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60538	 76256	 0.000771	 0.005064	 0.00127	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60539	 76250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60539	 76250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60539	 76256	 0.000586	 0.003429	 0.00094	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60540	 60541	 0.000671	 0.002343	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60540	 76256	 0.000571	 0.002279	 0.00057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60541	 60546	 0.002514	 0.008893	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60541	 76251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60541	 76251	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60542	 76255	 0.015629	 0.010121	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76248	 60543	 0.015614	 0.010107	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60544	 60555	 1.4e-05	 0.000221	 0.01399	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60544	 76252	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60544	 76252	 0.000271	 0.020351	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60545	 60546	 0.000243	 0.001993	 0.00054	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60545	 60552	 0.001486	 0.005	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76252	 60545	 0.000236	 0.002671	 0.00103	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60545	 76253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60545	 76253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60546	 60552	 0.001136	 0.00285	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60546	 60557	 0.001593	 0.003843	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60546	 76254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60546	 76254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60547	 60548	 0.004157	 0.007307	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76254	 60547	 0.002536	 0.00745	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60548	 60549	 0.010164	 0.008043	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60549	 76255	 0.005021	 0.007529	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60550	 60552	 0.002264	 0.005257	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60550	 76255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60550	 76255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60550	 76256	 0.000421	 0.002336	 0.00071	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60551	 76256	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60551	 76270	 0.000343	 0.003557	 0.03939	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60551	 76380	 0.000386	 0.006621	 0.06539	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76256	 60552	 0.002193	 0.00765	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60552	 76258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60552	 76258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60553	 76260	 0.029743	 0.021071	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60554	 76259	 0.009607	 0.015329	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60555	 60593	 0.000121	 0.001436	 0.10748	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60555	 60918	 0.000121	 0.001471	 0.11041	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60555	 76259	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60555	 76259	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60556	 60557	 0.000979	 0.003429	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60556	 60569	 0.0015	 0.005714	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60556	 76260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60556	 76260	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76252	 60557	 0.00065	 0.004629	 0.00144	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76258	 60558	 0.005764	 0.011843	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60558	 76261	 0.007921	 0.010414	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76257	 60559	 0.022893	 0.023121	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60560	 60561	 0.005893	 0.012107	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60560	 60562	 0.008	 0.012257	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76257	 60561	 0.012829	 0.02385	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60562	 60575	 0.004643	 0.00745	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60563	 60564	 0.006343	 0.004493	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60564	 76263	 0.004479	 0.011879	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60565	 76262	 0.00645	 0.013257	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60566	 60568	 0.000864	 0.002357	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60566	 76261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60566	 76261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76261	 60567	 0.011757	 0.007607	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60568	 60569	 0.000579	 0.001779	 0.00039	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60569	 60570	 0.001007	 0.002921	 0.00071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60569	 60579	 0.000521	 0.002079	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60570	 60571	 0.000721	 0.001936	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60570	 76262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60570	 76262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60570	 76265	 0.000593	 0.003386	 0.00112	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76256	 60571	 0.004736	 0.012286	 0.00299	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60571	 76263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60571	 76263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60571	 76265	 0.000971	 0.004	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60572	 60573	 0.006736	 0.004357	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60573	 60584	 0.0066	 0.005436	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60574	 60575	 0.003607	 0.008379	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60574	 60578	 0.002093	 0.007143	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76263	 60574	 0.010693	 0.012536	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60576	 60577	 0.0142	 0.009193	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60577	 60589	 0.0202	 0.0181	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60578	 76267	 0.001571	 0.0078	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60579	 76264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60579	 76264	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60579	 76265	 0.000864	 0.003443	 0.00116	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76264	 60580	 0.003086	 0.005743	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60580	 76266	 0.001779	 0.006814	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60581	 76265	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76266	 60581	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60581	 76271	 0.0004	 0.003214	 0.00604	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60581	 76373	 0.002021	 0.016836	 0.05253	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60582	 60583	 0.004886	 0.003864	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76266	 60582	 0.003093	 0.004936	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60584	 60585	 0.004221	 0.008671	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60585	 60586	 0.009557	 0.006764	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76266	 60585	 0.0018	 0.007686	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60585	 76269	 0.001557	 0.005979	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60587	 60590	 0.000771	 0.002236	 0.00054	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60587	 76267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60587	 76267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76267	 60588	 0.0113	 0.008	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60589	 76268	 0.005093	 0.009471	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60590	 60591	 0.000857	 0.002593	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60590	 60594	 0.000557	 0.00255	 0.00081	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60590	 76268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60590	 76268	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76265	 60591	 0.001436	 0.003907	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60591	 76269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60591	 76269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76266	 60592	 0.011264	 0.008914	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60593	 60613	 2.9e-05	 0.000521	 0.04576	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60593	 76270	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60593	 76270	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76272	 60594	 0.001279	 0.004664	 0.00143	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60594	 76274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60594	 76274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60594	 76281	 0.002579	 0.01175	 0.00373	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76274	 60595	 0.00935	 0.01275	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60596	 60599	 0.0242	 0.017143	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60597	 60599	 0.026	 0.018414	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60598	 60599	 0.014079	 0.009114	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60599	 76275	 0.003486	 0.013571	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76272	 60600	 0.001207	 0.007071	 0.00193	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60600	 76275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60600	 76275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60601	 60602	 0.014736	 0.009536	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76273	 60601	 0.011136	 0.017779	 0.00041	 62.0	 62.0	 62.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60603	 60692	 0.005257	 0.020664	 0.00541	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60603	 76276	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60603	 76276	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60603	 76281	 0.00145	 0.007971	 0.00288	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60603	 76286	 0.005107	 0.0123	 0.00347	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60604	 60605	 0.003357	 0.013121	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60604	 60699	 0.0108	 0.03175	 0.00065	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60605	 76277	 0.001636	 0.008129	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60605	 76283	 0.00885	 0.018179	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60606	 60607	 0.000986	 0.002957	 0.00066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60606	 76277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60606	 76277	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76272	 60607	 0.001814	 0.007271	 0.00184	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60607	 76281	 0.000914	 0.003471	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60608	 60609	 0.017093	 0.013521	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76275	 60608	 0.006621	 0.016779	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60610	 60611	 0.0099	 0.006407	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60610	 76278	 0.015943	 0.010321	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60612	 76278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60612	 76278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60612	 76281	 0.002043	 0.006157	 0.00193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60613	 60730	 0.000129	 0.001564	 0.11743	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60613	 76279	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76281	 60613	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60614	 76283	 0.01425	 0.0101	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60615	 60624	 9.3e-05	 0.00105	 0.01018	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76270	 60615	 0.000171	 0.001943	 0.01756	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60615	 76282	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60616	 60617	 0.002393	 0.007993	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76283	 60616	 0.00355	 0.015821	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60617	 60701	 0.016986	 0.027114	 0.00062	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60618	 60736	 0.000371	 0.002614	 0.00446	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76271	 60618	 0.000743	 0.00495	 0.00933	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76282	 60618	 0.000343	 0.00235	 0.00423	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60618	 76284	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60618	 76284	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76284	 60619	 0.001057	 0.003629	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60619	 76285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60619	 76285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60620	 60622	 0.014757	 0.011679	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76285	 60620	 0.013586	 0.012171	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60621	 60623	 0.028607	 0.018521	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60621	 60627	 0.021529	 0.01525	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60621	 60734	 0.012721	 0.008236	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76285	 60621	 0.004257	 0.016557	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60624	 60626	 9.3e-05	 0.001021	 0.00931	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60624	 60732	 9.3e-05	 0.001021	 0.00996	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60624	 76286	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60625	 60715	 0.004029	 0.013443	 0.00341	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76286	 60625	 0.000957	 0.003129	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60626	 76288	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60626	 76288	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60627	 60628	 0.010264	 0.007271	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60629	 60637	 0.026536	 0.018793	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60630	 61279	 0.021064	 0.016671	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60630	 76292	 0.01145	 0.018279	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60631	 60632	 0.001571	 0.004271	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60631	 60636	 0.001671	 0.004407	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60631	 61281	 0.001314	 0.004421	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60631	 76289	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60631	 76289	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60632	 60634	 0.001671	 0.0042	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60632	 61283	 0.001321	 0.004543	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60632	 76290	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60632	 76290	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60633	 76291	 0.028129	 0.019921	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60634	 76291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60634	 76291	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76235	 60635	 0.011321	 0.025679	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60635	 76292	 0.008193	 0.011179	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60636	 61281	 0.003379	 0.008929	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60636	 76292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60636	 76292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60637	 60638	 0.008043	 0.018671	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76292	 60637	 0.0183	 0.015064	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76236	 60638	 0.005314	 0.015621	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60639	 60640	 0.007321	 0.015036	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76235	 60639	 0.003714	 0.012379	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60640	 60642	 0.01135	 0.019957	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60642	 60643	 0.026707	 0.021136	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60643	 76293	 0.019543	 0.013843	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60644	 61295	 0.005471	 0.012707	 0.00387	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60644	 76293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60644	 76293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60645	 60647	 0.005586	 0.012779	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76293	 60645	 0.004443	 0.015171	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60646	 60648	 0.010707	 0.019314	 0.00028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60646	 76363	 0.004529	 0.015857	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60647	 60648	 0.006143	 0.012621	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60649	 60652	 0.030371	 0.0274	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60649	 60655	 0.011657	 0.013664	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60649	 76295	 0.013379	 0.033879	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60650	 60651	 0.022879	 0.024436	 0.00051	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60650	 60654	 0.012479	 0.02565	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60650	 60866	 0.029371	 0.068186	 0.00101	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60650	 76296	 0.015964	 0.032807	 0.00063	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60651	 60653	 0.019279	 0.015114	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60652	 76363	 0.0054	 0.021086	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60654	 60660	 0.00405	 0.010743	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60655	 60656	 0.003607	 0.007379	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60656	 76294	 0.0042	 0.012879	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60658	 60660	 0.037279	 0.026407	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60659	 60662	 0.02185	 0.015479	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60660	 60661	 0.010193	 0.013893	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60660	 76294	 0.015971	 0.037086	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60661	 60662	 0.022357	 0.0184	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60663	 60664	 0.001264	 0.003336	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60663	 76294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60663	 76294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60664	 60874	 0.008786	 0.023929	 0.00527	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76256	 60664	 0.005764	 0.02265	 0.00592	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60664	 76295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60664	 76295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60665	 76296	 0.019607	 0.012693	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60666	 60668	 0.007707	 0.014321	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76295	 60666	 0.0163	 0.013414	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60667	 60867	 0.00135	 0.004207	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60667	 76296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60667	 76296	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60668	 60671	 0.017529	 0.020543	 0.00036	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60668	 60673	 0.0132	 0.014093	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60668	 76358	 0.0087	 0.024957	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60669	 60670	 0.0048	 0.007657	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60669	 76304	 0.007007	 0.020607	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60670	 60671	 0.015464	 0.012729	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60672	 60673	 0.012693	 0.020264	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60672	 76302	 0.004321	 0.01655	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60674	 60675	 0.01835	 0.013	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60674	 60676	 0.009543	 0.019621	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60674	 76297	 0.005593	 0.0239	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60674	 76302	 0.018621	 0.029729	 0.00069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60676	 76361	 0.010121	 0.022957	 0.00046	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60677	 60683	 0.004964	 0.013114	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60677	 76297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60677	 76297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60677	 76352	 0.001707	 0.0105	 0.00303	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60677	 76359	 0.003407	 0.01365	 0.00344	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60678	 60680	 0.02035	 0.014414	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60679	 60680	 0.002407	 0.007936	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60679	 60687	 0.014579	 0.009443	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60679	 76302	 0.017071	 0.033807	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76297	 60680	 0.003293	 0.012864	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60681	 76298	 0.029564	 0.019136	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60682	 60683	 0.001243	 0.005186	 0.00161	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60682	 60688	 0.000957	 0.003979	 0.00093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60682	 60703	 0.006543	 0.017293	 0.00405	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60682	 60704	 0.001429	 0.003314	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60682	 76298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60682	 76298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60683	 60684	 0.001921	 0.007807	 0.0019	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60684	 60840	 0.005821	 0.022657	 0.00605	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60684	 60862	 0.002464	 0.014007	 0.00406	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60684	 76299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60684	 76299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60684	 76353	 0.00205	 0.007793	 0.00218	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60685	 60690	 0.018621	 0.012057	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60686	 60688	 0.001821	 0.004814	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60686	 76300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60686	 76300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60688	 60689	 0.003593	 0.010907	 0.00239	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60688	 60705	 0.004014	 0.010607	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60688	 76301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60688	 76301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60689	 60694	 0.002264	 0.005686	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60689	 60880	 0.007871	 0.021436	 0.00472	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76272	 60689	 0.010136	 0.033821	 0.00858	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60689	 76302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60689	 76302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60690	 60693	 0.018621	 0.012057	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76301	 60690	 0.0224	 0.029443	 0.0004	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60691	 76303	 0.009679	 0.006264	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60692	 60694	 0.001271	 0.004357	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60692	 76303	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60692	 76303	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60693	 60697	 0.012293	 0.025164	 0.00062	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60694	 60695	 0.001407	 0.003614	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60695	 76304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60695	 76304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76304	 60696	 0.02225	 0.015764	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60697	 60698	 0.012079	 0.016479	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76276	 60697	 0.006229	 0.038314	 0.00069	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60698	 60699	 0.006407	 0.013171	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60699	 60702	 0.043086	 0.027893	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60699	 76305	 0.023814	 0.0196	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60700	 60703	 0.003136	 0.008136	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60700	 76305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60700	 76305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76305	 60701	 0.016221	 0.014536	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60702	 76306	 0.025621	 0.016586	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60703	 60708	 0.001364	 0.003543	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60703	 60715	 0.003471	 0.008364	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60704	 60705	 0.001293	 0.003421	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60705	 60707	 0.001843	 0.004436	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60705	 60708	 0.002964	 0.007629	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60705	 76306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60705	 76306	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60706	 76307	 0.024864	 0.017614	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60707	 60708	 0.002564	 0.006443	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60707	 76307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60707	 76307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60708	 60715	 0.004386	 0.011779	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76299	 60709	 0.00385	 0.015029	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76307	 60709	 0.004293	 0.019036	 0.00057	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60710	 60711	 0.052729	 0.041729	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60710	 60712	 0.020793	 0.024371	 0.00042	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60712	 60713	 0.005043	 0.013357	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60712	 60714	 0.017736	 0.018943	 0.0004	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60713	 60717	 0.0475	 0.033643	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60713	 76348	 0.004771	 0.021143	 0.00064	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60714	 76308	 0.007057	 0.016386	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60715	 76308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60715	 76308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60715	 76311	 0.002436	 0.012893	 0.0043	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60715	 76353	 0.00855	 0.0325	 0.0091	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60716	 60728	 0.00455	 0.008171	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76308	 60716	 0.00985	 0.022864	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60717	 60718	 0.015771	 0.012357	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60717	 60719	 0.021457	 0.013893	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76308	 60717	 0.009493	 0.018793	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60717	 76348	 0.03085	 0.054257	 0.00102	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60719	 60720	 0.014629	 0.018164	 0.00039	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60720	 76348	 0.011571	 0.026257	 0.00052	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60721	 60725	 0.027464	 0.019457	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60722	 60724	 0.015464	 0.010014	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60723	 60724	 0.012371	 0.008757	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60723	 60725	 0.008129	 0.012186	 0.00022	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60725	 60726	 0.00365	 0.009671	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60726	 76330	 0.004129	 0.017664	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60727	 60728	 0.003671	 0.014293	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60727	 76309	 0.002836	 0.014336	 0.00025	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76288	 60729	 0.000271	 0.001879	 0.0032	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60729	 76309	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60729	 76309	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60729	 76310	 0.000457	 0.0032	 0.00545	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60730	 60770	 6.4e-05	 0.000807	 0.0554	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60730	 76310	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76311	 60730	 0.000329	 0.024712	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76287	 60731	 0.002586	 0.012607	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60731	 76312	 0.006686	 0.015286	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60732	 60739	 7.9e-05	 0.000907	 0.00828	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76279	 60732	 0.000136	 0.001407	 0.01559	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60732	 76312	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60732	 76312	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60733	 76314	 0.011293	 0.008	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60735	 76314	 0.024564	 0.0174	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60736	 76313	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76314	 60736	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60737	 60743	 0.001793	 0.004321	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76313	 60737	 0.001064	 0.002807	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60737	 76315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60737	 76315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60738	 60742	 0.023486	 0.018407	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76315	 60738	 0.016136	 0.015857	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60739	 76316	 0.001136	 0.049987	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60739	 76316	 0.001136	 0.049987	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76288	 60740	 0.000371	 0.002414	 0.00481	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76310	 60740	 0.000571	 0.003957	 0.00698	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76316	 60740	 0.000207	 0.001471	 0.00251	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60740	 76317	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60740	 76317	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60741	 60750	 0.001221	 0.003143	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76317	 60741	 0.001664	 0.004529	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60742	 76318	 0.009543	 0.013021	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60743	 60748	 0.001993	 0.005271	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60743	 60749	 0.002107	 0.005743	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76313	 60743	 0.00285	 0.007164	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60743	 76318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60743	 76318	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76318	 60744	 0.02035	 0.013179	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60745	 60748	 0.009664	 0.024293	 0.00629	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60745	 60940	 0.005257	 0.018571	 0.00419	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60745	 76319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60745	 76319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60746	 76338	 0.116657	 0.075536	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60747	 76320	 0.024036	 0.017021	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60748	 76320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60748	 76320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60748	 76322	 0.0037	 0.008586	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60749	 76322	 0.002407	 0.006193	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60750	 60751	 0.001686	 0.004593	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60750	 76322	 0.001321	 0.005471	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76311	 60751	 0.002593	 0.006671	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60752	 60754	 0.0002	 0.001307	 0.00261	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76310	 60752	 0.000536	 0.003593	 0.00676	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60752	 76321	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60752	 76321	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60752	 76327	 0.00035	 0.002593	 0.00494	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60753	 60754	 0.000257	 0.001664	 0.00332	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60753	 76322	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76323	 60753	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60755	 60756	 0.023821	 0.016879	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76323	 60755	 0.006507	 0.014879	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60757	 60758	 0.021007	 0.014879	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76321	 60758	 0.012486	 0.028329	 0.00056	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76321	 60759	 0.016993	 0.013993	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60760	 60761	 0.018307	 0.01185	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60761	 60765	 0.0074	 0.01375	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60762	 60763	 0.015007	 0.009721	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60763	 76324	 0.004743	 0.007993	 0.00011	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60764	 60766	 0.000736	 0.002593	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60764	 60791	 0.0006	 0.005493	 0.00199	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60764	 76324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60764	 76324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60764	 76328	 0.001529	 0.012414	 0.00395	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60765	 76326	 0.004857	 0.012871	 0.00033	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60766	 60769	 0.0014	 0.004564	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60767	 76325	 0.013107	 0.017879	 0.00032	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60768	 60782	 0.001743	 0.007236	 0.00169	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60768	 76325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60768	 76325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60768	 76328	 0.000986	 0.006464	 0.00164	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60769	 60787	 0.0025	 0.006036	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60769	 76326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60769	 76326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60769	 76328	 0.000943	 0.00735	 0.0022	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60770	 61019	 0.000221	 0.003043	 0.23034	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60770	 76327	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60770	 76327	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76311	 60771	 0.002614	 0.010457	 0.00264	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76328	 60771	 0.003143	 0.010793	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60771	 76330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60771	 76330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76330	 60772	 0.034257	 0.022179	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60773	 60774	 0.024714	 0.017507	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76329	 60773	 0.040871	 0.029543	 0.00045	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60775	 60777	 0.028807	 0.020407	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60775	 60845	 0.029864	 0.021157	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76325	 60776	 0.02635	 0.017064	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76325	 60777	 0.012971	 0.03335	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60778	 60779	 0.027986	 0.019821	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60779	 60780	 0.011079	 0.00785	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76325	 60779	 0.005679	 0.013179	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60781	 60835	 0.029014	 0.018786	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60781	 76331	 0.008771	 0.019886	 0.0004	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60782	 60786	 0.001514	 0.00535	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60782	 76331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60782	 76331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76331	 60783	 0.012343	 0.007993	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60784	 60785	 0.006364	 0.016857	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60784	 76332	 0.006829	 0.026679	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60785	 60824	 0.008186	 0.013121	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76328	 60786	 0.003064	 0.0146	 0.00346	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60786	 76332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60786	 76332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60786	 76343	 0.001743	 0.010221	 0.00279	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60787	 76333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60787	 76333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60788	 60790	 0.006486	 0.022707	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76333	 60788	 0.004171	 0.019464	 0.00045	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60789	 60790	 0.024179	 0.019136	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60789	 60793	 0.029057	 0.018814	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60790	 76344	 0.011093	 0.0195	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60791	 60795	 0.002043	 0.009536	 0.00236	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60791	 76334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60791	 76334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60792	 60793	 0.004607	 0.013557	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76334	 60792	 0.002379	 0.010529	 0.00024	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60793	 76335	 0.016057	 0.017664	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60794	 60797	 0.001429	 0.003436	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60794	 76335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60794	 76335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60795	 60796	 0.0013	 0.003021	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60795	 60799	 0.0032	 0.008036	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60795	 60803	 0.004886	 0.012686	 0.00308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60795	 76336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60795	 76336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60796	 60797	 0.0017	 0.004364	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60796	 60801	 0.001629	 0.004221	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60797	 76337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60797	 76337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60798	 76342	 0.005907	 0.0197	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60798	 76462	 0.005736	 0.026743	 0.00061	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60799	 60800	 0.0014	 0.0036	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60800	 61187	 0.001736	 0.004171	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60800	 76338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60800	 76338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60800	 76461	 0.003643	 0.009457	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60801	 60804	 0.001257	 0.003314	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60801	 76339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60801	 76339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76339	 60802	 0.017714	 0.012543	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60802	 76340	 0.022757	 0.016121	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60803	 60806	 0.002907	 0.007686	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60803	 76340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60803	 76340	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60803	 76461	 0.002086	 0.005364	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60804	 61187	 0.002507	 0.005821	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60805	 76462	 0.023071	 0.016343	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60806	 76341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60806	 76341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60806	 76343	 0.006543	 0.017821	 0.00393	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76339	 60807	 0.015386	 0.020993	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76341	 60807	 0.016579	 0.013121	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76341	 60808	 0.013243	 0.021143	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60808	 76344	 0.037286	 0.046279	 0.00101	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60809	 60810	 0.002164	 0.005721	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60809	 61076	 0.001957	 0.005036	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60809	 76342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60809	 76342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60810	 60818	 0.002564	 0.006879	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60811	 61181	 0.001836	 0.01225	 0.02309	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76327	 60811	 0.00055	 0.00635	 0.02293	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60811	 76343	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76344	 60811	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60812	 60824	 0.018057	 0.028829	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76344	 60812	 0.006871	 0.018207	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76344	 60813	 0.028164	 0.01995	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60814	 60815	 0.001514	 0.003993	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60814	 60821	 0.00145	 0.005521	 0.00154	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76343	 60814	 0.001593	 0.008007	 0.00209	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60814	 76345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60814	 76345	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60815	 60816	 0.001493	 0.004071	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60815	 76346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60815	 76346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60816	 60818	 0.001557	 0.004114	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60816	 60819	 0.001907	 0.006643	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76343	 60816	 0.0025	 0.011136	 0.00303	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76346	 60817	 0.019921	 0.014107	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60819	 61072	 0.0023	 0.008186	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60819	 61177	 0.0086	 0.022336	 0.00542	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76343	 60819	 0.003814	 0.016614	 0.00474	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60820	 61071	 0.01395	 0.032386	 0.00061	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60820	 76347	 0.006536	 0.02005	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60821	 61172	 0.007864	 0.021414	 0.00472	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60821	 76347	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60821	 76347	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60822	 60826	 0.034429	 0.058	 0.00083	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76347	 60822	 0.039807	 0.081464	 0.00201	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60823	 60824	 0.02215	 0.051429	 0.00076	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60823	 60831	 0.023421	 0.034129	 0.00077	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76345	 60825	 0.027429	 0.021707	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60826	 60827	 0.034957	 0.037336	 0.00079	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60827	 60828	 0.01715	 0.027507	 0.00051	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60827	 61060	 0.093943	 0.06655	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60828	 61062	 0.066643	 0.0733	 0.00098	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76347	 60828	 0.080443	 0.16535	 0.00316	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75581	 60829	 0.192993	 0.124986	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60830	 61637	 0.002521	 0.027729	 0.27032	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60831	 60834	 0.016064	 0.0369	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60832	 60848	 0.130457	 0.10325	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60833	 60834	 0.01535	 0.028536	 0.00067	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60833	 60853	 0.008171	 0.018543	 0.00037	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60835	 60839	 0.048521	 0.043779	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60836	 60838	 0.035379	 0.022907	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60837	 60838	 0.027107	 0.01755	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60838	 60848	 0.007736	 0.0258	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76331	 60838	 0.017071	 0.058307	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60839	 60842	 0.033164	 0.04525	 0.00081	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60840	 60841	 0.004093	 0.010814	 0.00253	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60840	 76348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60840	 76348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60841	 60847	 0.003564	 0.029593	 0.00779	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60841	 76349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60841	 76349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60842	 60843	 0.022621	 0.029443	 0.00041	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76349	 60842	 0.010621	 0.035443	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60843	 60844	 0.007493	 0.011229	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76330	 60843	 0.017207	 0.057393	 0.00091	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60844	 60845	 0.010593	 0.009493	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76349	 60846	 0.062286	 0.044121	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60847	 60852	 0.006071	 0.022093	 0.00676	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 60847	 0.002436	 0.018043	 0.00924	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60848	 60849	 0.03295	 0.023343	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60848	 60850	 0.042321	 0.0274	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60848	 76350	 0.007879	 0.034907	 0.00105	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60851	 60853	 0.01835	 0.011879	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60852	 76350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60852	 76350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76350	 60853	 0.003436	 0.013371	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60854	 60856	 0.096593	 0.062543	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60855	 76354	 0.011571	 0.023771	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76349	 60856	 0.024771	 0.039536	 0.00091	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60857	 60859	 0.000171	 0.001907	 0.01798	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76270	 60857	 0.000764	 0.008636	 0.07863	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60857	 76351	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76352	 60857	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60858	 76354	 0.037714	 0.026714	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60859	 60860	 0.000229	 0.002529	 0.02404	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60859	 76353	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60860	 60889	 0.000243	 0.002743	 0.02714	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60860	 76355	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60860	 76355	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60861	 60862	 0.001571	 0.004157	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60861	 76356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60861	 76356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76355	 60862	 0.000929	 0.008029	 0.00289	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60862	 76357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60862	 76357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76357	 60863	 0.034986	 0.024786	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60864	 60865	 0.008557	 0.025157	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76356	 60864	 0.004636	 0.024714	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60865	 60870	 0.025664	 0.047721	 0.00111	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60866	 60868	 0.009814	 0.034329	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60867	 60874	 0.006321	 0.021693	 0.0052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60867	 60880	 0.001379	 0.0056	 0.00136	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76256	 60867	 0.009893	 0.029779	 0.00931	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60867	 76358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60867	 76358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60867	 76359	 0.002414	 0.009671	 0.00244	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60868	 76503	 0.007793	 0.034543	 0.00104	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60869	 60871	 0.000486	 0.003429	 0.00584	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60869	 76359	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76360	 60869	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60870	 60884	 0.031186	 0.042507	 0.00094	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60871	 60872	 0.000314	 0.002164	 0.00382	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60871	 76361	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60871	 76361	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76351	 60872	 0.000386	 0.0027	 0.00572	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60872	 76362	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60872	 76362	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76362	 60873	 0.0211	 0.01495	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60874	 61307	 0.005086	 0.012257	 0.00346	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60874	 61319	 0.0066	 0.021521	 0.00571	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60874	 61326	 0.011707	 0.039436	 0.0098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60874	 76363	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60874	 76363	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76363	 60875	 0.026393	 0.018693	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60876	 60878	 0.035007	 0.0248	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60877	 60881	 0.026707	 0.021136	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60878	 60881	 0.020764	 0.031807	 0.00045	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60878	 76364	 0.0044	 0.011657	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76358	 60879	 0.01505	 0.009743	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60880	 61320	 0.013	 0.031329	 0.00885	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76359	 60880	 0.001207	 0.005021	 0.00156	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60880	 76364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60880	 76364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60881	 60882	 0.044557	 0.02885	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76361	 60883	 0.0458	 0.032443	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76360	 60884	 0.021143	 0.039314	 0.00092	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60885	 60887	 0.004814	 0.024621	 0.00671	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60885	 61321	 0.004257	 0.017721	 0.00552	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60885	 76365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60885	 76365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76365	 60886	 0.068514	 0.048536	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60887	 60893	 0.011693	 0.066486	 0.01926	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75585	 60888	 0.002286	 0.012771	 0.00326	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76355	 60888	 0.004343	 0.022514	 0.0055	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60890	 60948	 0.01035	 0.101243	 0.02845	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 60890	 0.012629	 0.044921	 0.00999	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75540	 60891	 0.002671	 0.047221	 0.45289	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60891	 76366	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76367	 60891	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76367	 60892	 0.002893	 0.011579	 0.00291	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60893	 60948	 0.018036	 0.10355	 0.03448	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60893	 76507	 0.023064	 0.103936	 0.02769	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60894	 76369	 0.013993	 0.009057	 0.00017	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60895	 60907	 4.3e-05	 0.000579	 0.03949	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60895	 60931	 2.9e-05	 0.000329	 0.02441	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60895	 76368	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60896	 60930	 0.022893	 0.016214	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76369	 60896	 0.009486	 0.010129	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60897	 60898	 0.016671	 0.011807	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60897	 60899	 0.016793	 0.01515	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60899	 76375	 0.006364	 0.013371	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60900	 60905	 5.7e-05	 0.000643	 0.00586	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76368	 60900	 7.9e-05	 0.0009	 0.00826	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60900	 76372	 7.1e-05	 0.000779	 0.00755	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60901	 60902	 0.024571	 0.017407	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60901	 76371	 0.022257	 0.021864	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60902	 60926	 0.041886	 0.029671	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60903	 76370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60903	 76370	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60903	 76374	 0.004386	 0.0116	 0.00271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60904	 76375	 0.023057	 0.020664	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60905	 76371	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60905	 76371	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60905	 76372	 5e-05	 0.000564	 0.00487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60906	 76375	 0.01065	 0.007543	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60907	 76372	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60907	 76372	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60908	 60909	 0.070029	 0.049607	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60909	 76388	 0.049486	 0.092021	 0.00216	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60910	 76376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60910	 76376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60910	 76377	 0.006736	 0.020464	 0.00448	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76376	 60911	 0.065593	 0.042464	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76373	 60912	 0.00105	 0.015729	 0.03681	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60912	 76377	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76378	 60912	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76378	 60913	 0.041964	 0.029721	 0.00047	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60914	 76388	 0.080179	 0.06345	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60915	 76388	 0.048021	 0.038007	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60916	 76379	 0.047243	 0.030586	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60917	 76379	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60917	 76379	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60917	 76380	 0.000129	 0.001807	 0.01726	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60917	 76383	 0.000157	 0.002264	 0.02161	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60918	 60929	 5.7e-05	 0.000957	 0.08819	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60918	 76380	 7.9e-05	 0.006285	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76381	 60919	 0.04635	 0.032829	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60920	 60922	 0.032229	 0.022829	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76378	 60920	 0.016371	 0.057314	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60921	 60923	 0.034057	 0.02205	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60921	 60925	 0.023386	 0.024979	 0.00053	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76370	 60921	 0.023857	 0.081507	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60924	 60925	 0.082907	 0.053679	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60927	 76382	 0.023786	 0.0154	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60928	 60929	 2.1e-05	 0.0003	 0.02194	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60928	 60931	 2.9e-05	 0.000407	 0.02581	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60928	 76382	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60928	 76382	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60929	 61560	 0.001571	 0.020529	 1.32793	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60929	 76383	 0.000173	 0.01294	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60929	 76383	 0.000173	 0.01294	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60932	 76384	 0.054314	 0.1261	 0.00188	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60933	 60944	 0.004893	 0.016321	 0.00414	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60933	 60987	 0.014043	 0.036464	 0.00885	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76374	 60933	 0.005993	 0.024007	 0.00605	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60933	 76384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60933	 76384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60934	 60935	 0.000443	 0.004314	 0.00121	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76374	 60934	 0.000893	 0.009157	 0.00259	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60935	 60941	 0.00135	 0.008571	 0.00233	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60935	 76385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60935	 76385	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60936	 60937	 0.000714	 0.006971	 0.00219	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60936	 60939	 0.000971	 0.007857	 0.0025	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60936	 76386	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60936	 76386	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76374	 60937	 0.000857	 0.008964	 0.00301	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76375	 60938	 0.035257	 0.062007	 0.00116	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60939	 60940	 0.002579	 0.00885	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60939	 60941	 0.003614	 0.008707	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60939	 76387	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60939	 76387	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60941	 60945	 0.002421	 0.015043	 0.00424	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60942	 60943	 0.006243	 0.026071	 0.00075	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76387	 60942	 0.0092	 0.045657	 0.00109	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60943	 76444	 0.009964	 0.034886	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60944	 61142	 0.006379	 0.0191	 0.0043	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60945	 61139	 0.002614	 0.016743	 0.00564	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60945	 61142	 0.010321	 0.027714	 0.00628	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60946	 76388	 0.087586	 0.069321	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76377	 60947	 0.006214	 0.024429	 0.00639	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60947	 76388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60947	 76388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75543	 60949	 0.124664	 0.181721	 0.00411	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76140	 60950	 0.021857	 0.056757	 0.01378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60951	 60952	 0.003121	 0.008564	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60951	 60954	 0.00285	 0.009507	 0.00241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60951	 76389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60951	 76389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60952	 60954	 0.002671	 0.00705	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76389	 60953	 0.072593	 0.047	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75553	 60955	 0.066314	 0.119657	 0.00173	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75535	 60956	 0.011886	 0.041586	 0.01379	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75535	 60958	 0.012764	 0.110686	 0.03981	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75912	 60958	 0.019	 0.053	 0.01113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60959	 60960	 0.223071	 0.144479	 0.00275	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60960	 60967	 0.024971	 0.036393	 0.00082	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60960	 76390	 0.033271	 0.065879	 0.00096	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60960	 76571	 0.194136	 0.125729	 0.00239	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60961	 60962	 0.002214	 0.011286	 0.00409	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60961	 60963	 0.0028	 0.008557	 0.00185	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60961	 61544	 0.008493	 0.02245	 0.00526	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75520	 60961	 0.009429	 0.0343	 0.0105	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60961	 76390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60961	 76390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75515	 60962	 0.002229	 0.014121	 0.00384	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60963	 60964	 0.001157	 0.002907	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60964	 76391	 0.002971	 0.008	 0.00224	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75514	 60965	 0.000186	 0.002164	 0.04514	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60965	 76391	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60965	 76391	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60965	 76447	 0.002	 0.02265	 0.20669	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60966	 60968	 0.002121	 0.0085	 0.00214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76391	 60966	 0.001771	 0.010393	 0.00283	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60967	 76392	 0.011593	 0.023821	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75520	 60968	 0.001821	 0.007914	 0.00226	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60968	 76392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60968	 76392	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75521	 60969	 0.137436	 0.124014	 0.00208	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75562	 60969	 0.560993	 0.4449	 0.0056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60970	 76393	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60970	 76393	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60971	 76394	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60972	 60973	 0.071914	 0.164514	 0.00401	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75521	 60972	 0.009371	 0.032	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76392	 60972	 0.014764	 0.02745	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60973	 61009	 0.159964	 0.2977	 0.00697	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76395	 60974	 0.02595	 0.114943	 0.00262	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75532	 60975	 0.011679	 0.030871	 0.00723	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75570	 60975	 0.006064	 0.017871	 0.00416	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60976	 76396	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76397	 60976	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75532	 60977	 0.019636	 0.053821	 0.01171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60977	 76398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60977	 76398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75576	 60978	 0.086836	 0.266564	 0.00723	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76398	 60978	 0.074243	 0.31765	 0.00719	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60979	 76399	 0.099129	 0.078457	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60980	 76399	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60980	 76399	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60980	 76400	 0.001721	 0.030014	 0.10092	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60981	 76400	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60981	 76400	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76120	 60982	 0.001379	 0.018557	 0.06553	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76400	 60982	 0.00215	 0.026	 0.11392	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60983	 61142	 0.030993	 0.084421	 0.01861	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60983	 76401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60983	 76401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75582	 60984	 0.238343	 0.154379	 0.00294	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60985	 60989	 0.094779	 0.101229	 0.00214	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76219	 60985	 0.131864	 0.210579	 0.00485	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76401	 60985	 0.066186	 0.131057	 0.00192	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60986	 76402	 0.15835	 0.112193	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60987	 76402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60987	 76402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60988	 60995	 0.021214	 0.062379	 0.00128	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75582	 60988	 0.025464	 0.087	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76401	 60989	 0.023114	 0.080929	 0.00224	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60989	 76403	 0.012829	 0.037714	 0.00077	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60990	 76403	 0.037593	 0.026629	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 60991	 0.031679	 0.108779	 0.02609	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60991	 76403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60991	 76403	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76403	 60992	 0.0519	 0.0336	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60993	 60994	 0.147136	 0.104243	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60993	 61527	 0.06715	 0.138021	 0.00264	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76403	 60993	 0.021514	 0.054486	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60994	 60995	 0.040336	 0.070943	 0.00134	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60997	 61002	 0.019279	 0.110907	 0.03146	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75510	 60997	 0.004507	 0.068436	 0.02524	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76213	 60997	 0.069564	 0.187314	 0.0426	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60997	 76404	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60997	 76404	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60998	 61002	 0.021979	 0.058107	 0.01361	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75557	 60998	 0.045814	 0.123143	 0.02795	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60999	 61000	 0.269279	 0.19085	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60999	 76405	 0.196929	 0.405214	 0.00774	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61001	 76405	 0.248521	 0.179743	 0.00273	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61002	 76405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61002	 76405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61003	 61004	 0.120543	 0.212064	 0.00399	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76405	 61003	 0.056329	 0.130786	 0.00194	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61004	 61006	 0.159064	 0.197536	 0.00431	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75558	 61004	 0.071707	 0.220079	 0.00596	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61005	 61006	 0.775429	 0.616121	 0.00776	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61007	 76406	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61007	 76406	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61008	 61013	 0.035507	 0.124329	 0.00344	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76406	 61008	 0.03955	 0.156964	 0.00449	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61009	 61546	 0.124307	 0.288729	 0.00429	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61010	 61011	 0.039571	 0.025621	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61010	 61012	 0.02735	 0.093443	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61012	 61013	 0.029993	 0.105014	 0.00291	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61014	 76407	 0.000192	 0.015383	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76408	 61014	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61015	 61016	 0.018243	 0.049671	 0.01094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75674	 61015	 0.029557	 0.104557	 0.02359	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61016	 61017	 0.014271	 0.036993	 0.01119	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61016	 76409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61016	 76409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61017	 61428	 0.014557	 0.051471	 0.0116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76409	 61018	 0.159629	 0.1131	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61019	 61150	 0.000186	 0.003043	 0.21348	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61019	 76410	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61019	 76410	 0.000174	 0.013904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76411	 61019	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61020	 61028	 0.059757	 0.047293	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61021	 61022	 0.001286	 0.004336	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61021	 61027	 0.000914	 0.003143	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61022	 61023	 0.001179	 0.003693	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61024	 61025	 0.001421	 0.003871	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61024	 61032	 0.002093	 0.005629	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61024	 61036	 0.001093	 0.0056	 0.00141	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61024	 61047	 0.002771	 0.011286	 0.00275	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61025	 61027	 0.001971	 0.005214	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61025	 76412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61025	 76412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61026	 61027	 0.000986	 0.002557	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61026	 61133	 0.004264	 0.0116	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61026	 76413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61026	 76413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61028	 61031	 0.026957	 0.021329	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76413	 61028	 0.004514	 0.013857	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76412	 61029	 0.015229	 0.01205	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61030	 61031	 0.023236	 0.016457	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61031	 76414	 0.007907	 0.022679	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61032	 61033	 0.001157	 0.004029	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61032	 76414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61032	 76414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61033	 61034	 0.0009	 0.003129	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61034	 61035	 0.000514	 0.001864	 0.00057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61035	 61037	 0.000479	 0.00195	 0.00048	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61035	 76415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61035	 76415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76411	 61036	 0.001507	 0.008829	 0.00241	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61038	 61041	 0.0009	 0.003736	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76411	 61038	 0.002207	 0.008043	 0.00246	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61038	 76416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61038	 76416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76416	 61039	 0.015657	 0.015379	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61040	 76417	 0.00605	 0.012436	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61040	 76418	 0.00795	 0.01275	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61041	 61045	 0.00125	 0.00475	 0.00133	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61041	 61097	 0.008057	 0.02765	 0.00662	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61041	 61104	 0.005736	 0.019321	 0.0048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76411	 61041	 0.0018	 0.010971	 0.00276	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61041	 76417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61041	 76417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76417	 61042	 0.006407	 0.011271	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61042	 76464	 0.005736	 0.010664	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61043	 61044	 0.013186	 0.011814	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61043	 76463	 0.00535	 0.00995	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61044	 76418	 0.006307	 0.011721	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61045	 61049	 0.001636	 0.00595	 0.00182	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61045	 76418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61045	 76418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61046	 61049	 0.002164	 0.005929	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76411	 61046	 0.00455	 0.018786	 0.00444	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61046	 76419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61046	 76419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61047	 61108	 0.004457	 0.01035	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61047	 61123	 0.001221	 0.004193	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61047	 76420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61047	 76420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61047	 76438	 0.006186	 0.016843	 0.00371	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61048	 76421	 0.008279	 0.0164	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61048	 76437	 0.01955	 0.015471	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61049	 76421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61049	 76421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61049	 76438	 0.003743	 0.009893	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61050	 61051	 0.013671	 0.013807	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76421	 61050	 0.005371	 0.008614	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61051	 61052	 0.021614	 0.013993	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61051	 61055	 0.020521	 0.014536	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61052	 76422	 0.008029	 0.018636	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61053	 61185	 0.001457	 0.004993	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61053	 76422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61053	 76422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61054	 61056	 0.024743	 0.017529	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61054	 61101	 0.00735	 0.015107	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61054	 61102	 0.018293	 0.027743	 0.0004	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61055	 76436	 0.039736	 0.025721	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61056	 76436	 0.009236	 0.018286	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61058	 61066	 0.042829	 0.047107	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61058	 61075	 0.037057	 0.0305	 0.00062	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61058	 61155	 0.080771	 0.063929	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61059	 61067	 0.0293	 0.02075	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61060	 61061	 0.033171	 0.059857	 0.00086	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61061	 76424	 0.036343	 0.092057	 0.00182	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61063	 61065	 0.04465	 0.0451	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61063	 61071	 0.024936	 0.04385	 0.00082	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61064	 61068	 0.031721	 0.022471	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61064	 61069	 0.043143	 0.034143	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61065	 61066	 0.028643	 0.028936	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61065	 61067	 0.027493	 0.030236	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61065	 61069	 0.0567	 0.051157	 0.00086	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61066	 61068	 0.040329	 0.026107	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61068	 61083	 0.016243	 0.033379	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61069	 76457	 0.017243	 0.036236	 0.00066	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61070	 76423	 0.030607	 0.019814	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61072	 61172	 0.002029	 0.006836	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61072	 76423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61072	 76423	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61073	 61083	 0.024829	 0.016071	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61074	 76424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61074	 76424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61075	 61167	 0.021107	 0.019043	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76424	 61075	 0.018907	 0.030179	 0.00069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61076	 61079	 0.0074	 0.023136	 0.0067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61076	 76425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61076	 76425	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61076	 76459	 0.001421	 0.009293	 0.00236	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61077	 76429	 0.03425	 0.024264	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61078	 61183	 0.017671	 0.034986	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61078	 76426	 0.032057	 0.026386	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61079	 61085	 0.004586	 0.012129	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61079	 61089	 0.003614	 0.009707	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61079	 76426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61079	 76426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61080	 61081	 0.001786	 0.004793	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61080	 61166	 0.005664	 0.014707	 0.00357	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61080	 61172	 0.008507	 0.020507	 0.00579	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61080	 76427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61080	 76427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61081	 61156	 0.002336	 0.006164	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61081	 76428	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61081	 76428	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61082	 61083	 0.010607	 0.014457	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76427	 61082	 0.005236	 0.010714	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61083	 61173	 0.033936	 0.030614	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61083	 76458	 0.022657	 0.0526	 0.00079	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76428	 61084	 0.028671	 0.018564	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61084	 76431	 0.010693	 0.027479	 0.00043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61085	 61086	 0.002686	 0.0077	 0.00189	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61085	 76429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61085	 76429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75523	 61086	 0.002764	 0.010057	 0.00308	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61086	 76430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61086	 76430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76426	 61087	 0.020157	 0.020364	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61087	 76431	 0.0159	 0.016986	 0.00036	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61088	 61089	 0.001336	 0.004171	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61088	 76452	 0.002107	 0.006221	 0.00145	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75523	 61089	 0.002943	 0.012257	 0.00382	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61089	 76431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61089	 76431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61090	 76433	 0.016036	 0.025714	 0.00047	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61090	 76435	 0.014093	 0.0225	 0.00052	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61091	 61095	 0.003036	 0.008321	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75523	 61091	 0.000743	 0.003079	 0.00072	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61092	 61159	 0.002571	 0.006457	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75523	 61092	 0.002629	 0.007743	 0.0018	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61092	 76432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61092	 76432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61093	 61099	 0.015179	 0.022121	 0.0005	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61093	 76433	 0.004707	 0.009886	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61094	 61095	 0.001671	 0.004021	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61094	 76433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61094	 76433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61095	 76434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61095	 76434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76434	 61096	 0.025621	 0.01815	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61097	 76435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61097	 76435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61097	 76448	 0.007329	 0.019371	 0.00454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61098	 61107	 0.011557	 0.010429	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76435	 61098	 0.012257	 0.014371	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61099	 61100	 0.020371	 0.018379	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61099	 61102	 0.018629	 0.027143	 0.00061	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76435	 61099	 0.011557	 0.022886	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76430	 61100	 0.016929	 0.019843	 0.00034	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76422	 61101	 0.007721	 0.017657	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61102	 76439	 0.032121	 0.056486	 0.00106	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61103	 76436	 0.012286	 0.0087	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61104	 76436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61104	 76436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61104	 76438	 0.002207	 0.005729	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61105	 61107	 0.007557	 0.009386	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76436	 61105	 0.008	 0.014879	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76436	 61106	 0.011843	 0.007671	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61108	 76437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61108	 76437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61108	 76438	 0.002036	 0.005386	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61109	 61110	 0.00965	 0.016971	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61109	 76439	 0.004664	 0.010836	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61110	 61146	 0.023621	 0.021314	 0.00036	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76270	 61111	 0.001757	 0.019264	 0.18746	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61111	 76438	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61111	 76447	 0.000286	 0.003286	 0.02968	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76439	 61112	 0.026921	 0.017429	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76439	 61113	 0.020586	 0.018443	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61114	 61119	 0.010221	 0.0164	 0.0003	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76439	 61114	 0.010314	 0.0344	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61115	 61146	 0.04205	 0.041307	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61115	 76449	 0.010721	 0.017114	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61116	 61117	 0.025829	 0.016721	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61117	 61125	 0.012186	 0.02265	 0.00053	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76437	 61117	 0.003307	 0.016807	 0.00038	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61118	 61122	 0.022864	 0.0162	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61119	 61122	 0.015014	 0.020486	 0.00036	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61119	 76449	 0.017686	 0.050729	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61120	 61121	 0.015943	 0.011293	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61120	 76449	 0.051229	 0.082179	 0.00152	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61121	 61122	 0.017364	 0.011243	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61123	 76440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61123	 76440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61124	 61125	 0.009814	 0.017529	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61124	 61127	 0.0073	 0.015007	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61126	 61127	 0.015529	 0.01005	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61127	 61128	 0.003364	 0.008521	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76440	 61128	 0.002979	 0.011571	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61129	 61130	 0.0154	 0.009964	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76420	 61130	 0.010543	 0.018543	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61131	 76441	 0.048671	 0.034479	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61132	 61138	 0.003071	 0.010714	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61132	 61144	 0.008936	 0.03115	 0.00722	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61132	 76441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61132	 76441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61133	 61138	 0.006929	 0.018321	 0.00429	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61133	 61141	 0.003679	 0.008871	 0.00251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61133	 76442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61133	 76442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61134	 61135	 0.014729	 0.023507	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76440	 61134	 0.066507	 0.077964	 0.00136	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76441	 61134	 0.068286	 0.048371	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76442	 61134	 0.008043	 0.018243	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61135	 61136	 0.021671	 0.038107	 0.00071	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61136	 76446	 0.085414	 0.060507	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61137	 76443	 0.07385	 0.052314	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61138	 61139	 0.001743	 0.009236	 0.00309	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61138	 76443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61138	 76443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61139	 61140	 0.002129	 0.00695	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61139	 76444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61139	 76444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61140	 61141	 0.003464	 0.011307	 0.003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61142	 76445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61142	 76445	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76445	 61143	 0.014221	 0.071929	 0.00125	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61143	 76446	 0.031993	 0.109307	 0.00238	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61144	 61531	 0.010957	 0.038736	 0.00873	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61144	 76446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61144	 76446	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61144	 76448	 0.01595	 0.043714	 0.00951	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61145	 61148	 0.003157	 0.010836	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61145	 61514	 0.008071	 0.028543	 0.00643	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61145	 61534	 0.006593	 0.023314	 0.00526	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61145	 76448	 0.004957	 0.02275	 0.00583	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61147	 76449	 0.079721	 0.057636	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61148	 76448	 0.004071	 0.014179	 0.00329	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61149	 76449	 0.102536	 0.072636	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61150	 76447	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61150	 76447	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61151	 61152	 0.008171	 0.021593	 0.00506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61151	 61536	 0.008221	 0.020671	 0.00536	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61151	 76450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61151	 76450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61152	 61161	 0.005521	 0.014186	 0.00351	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61152	 76451	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61152	 76451	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61153	 61539	 0.228786	 0.162129	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76450	 61153	 0.150036	 0.11875	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76451	 61153	 0.127429	 0.082507	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61154	 61181	 0.0024	 0.014586	 0.03323	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61154	 76452	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76453	 61154	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61155	 76456	 0.016171	 0.033236	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61156	 61166	 0.001579	 0.004243	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76452	 61156	 0.003979	 0.012443	 0.00361	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61156	 76454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61156	 76454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61157	 61162	 0.003857	 0.010357	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61157	 61163	 0.01155	 0.029029	 0.00752	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61157	 61166	 0.003921	 0.010357	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76432	 61158	 0.0489	 0.031657	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61158	 76455	 0.027579	 0.01785	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61159	 61160	 0.002736	 0.006593	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61159	 76455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61159	 76455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61160	 61161	 0.007021	 0.016293	 0.00496	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61160	 61162	 0.005286	 0.013971	 0.00327	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61164	 76456	 0.03755	 0.0266	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61165	 61170	 0.0211	 0.013664	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 61165	 0.007979	 0.02345	 0.00048	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76454	 61165	 0.038843	 0.02515	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61166	 76456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61166	 76456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76453	 61167	 0.021664	 0.063707	 0.00131	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61168	 61169	 0.027579	 0.017857	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76453	 61169	 0.012314	 0.024379	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61172	 76457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61172	 76457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61172	 76459	 0.004436	 0.02365	 0.00664	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61173	 61176	 0.036264	 0.023479	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76457	 61173	 0.019164	 0.033707	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76426	 61174	 0.011379	 0.023379	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61174	 76458	 0.012593	 0.021214	 0.0003	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61175	 61176	 0.022793	 0.014757	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76427	 61175	 0.025107	 0.02265	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61176	 76458	 0.007229	 0.024686	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61177	 61189	 0.00095	 0.003193	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61177	 76458	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61177	 76458	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61178	 76466	 0.023036	 0.016321	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61179	 61188	 0.024914	 0.032743	 0.00045	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61180	 61190	 0.016743	 0.011864	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76338	 61180	 0.015321	 0.009921	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76410	 61181	 0.000207	 0.002457	 0.00644	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61181	 76459	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76460	 61181	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61182	 61183	 0.015443	 0.035843	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76460	 61182	 0.006414	 0.019671	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76422	 61183	 0.014536	 0.023207	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76410	 61184	 0.000314	 0.002993	 0.00531	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61184	 76461	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76462	 61184	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61185	 61186	 0.001186	 0.004621	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61185	 76463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61185	 76463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76411	 61186	 0.001943	 0.008021	 0.0019	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61186	 76464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61186	 76464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76411	 61187	 0.00245	 0.009529	 0.00254	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61187	 76465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61187	 76465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76425	 61188	 0.006657	 0.01765	 0.00045	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61188	 76466	 0.015293	 0.022279	 0.0005	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76459	 61189	 0.003493	 0.016293	 0.00404	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61189	 76466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61189	 76466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76465	 61190	 0.027014	 0.021379	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61191	 61202	 0.016843	 0.044529	 0.01043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61191	 76467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61191	 76467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61192	 61193	 0.088143	 0.057064	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76467	 61192	 0.242543	 0.238414	 0.00402	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61194	 61195	 0.210693	 0.149293	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61195	 61197	 0.029436	 0.026557	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61195	 76468	 0.048571	 0.0603	 0.00131	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61196	 61198	 0.00455	 0.013629	 0.00307	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61196	 76468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61196	 76468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61197	 61200	 0.01045	 0.023707	 0.00047	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61198	 61199	 0.001193	 0.003886	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61199	 61202	 0.005407	 0.0143	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61199	 61574	 0.013329	 0.055514	 0.01732	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61199	 76469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61199	 76469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76469	 61200	 0.005121	 0.011714	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61201	 61215	 0.004886	 0.017014	 0.00394	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61202	 61590	 0.010207	 0.04155	 0.01013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61202	 76470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61202	 76470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61203	 61211	 0.009321	 0.022471	 0.00634	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61203	 61570	 0.014986	 0.040814	 0.00899	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61204	 61205	 0.007114	 0.039471	 0.012	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61204	 61210	 0.004686	 0.018771	 0.00473	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61204	 61570	 0.017486	 0.043957	 0.01139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61206	 61366	 0.004229	 0.051121	 0.09913	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75572	 61206	 0.001929	 0.021857	 0.04801	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61207	 61373	 0.024693	 0.116993	 0.02818	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61207	 76477	 0.016107	 0.065571	 0.01599	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61208	 76471	 0.068893	 0.054521	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61209	 61210	 0.002371	 0.007986	 0.00199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61209	 61218	 0.007064	 0.017014	 0.00481	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61209	 76471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61209	 76471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61210	 61211	 0.00505	 0.013557	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61210	 61213	 0.007121	 0.023993	 0.00596	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61211	 76472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61211	 76472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61212	 76473	 0.025164	 0.017829	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61213	 61216	 0.0021	 0.007971	 0.00223	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61213	 76473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61213	 76473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61213	 76474	 0.006243	 0.016207	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61214	 76474	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61214	 76474	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61216	 76475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61216	 76475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61216	 76479	 0.007086	 0.025786	 0.00789	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61217	 61218	 0.001043	 0.002707	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61217	 76477	 0.003464	 0.009293	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61218	 76476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61218	 76476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61219	 61221	 0.003043	 0.008943	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61219	 76478	 0.005464	 0.024207	 0.00073	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61220	 61223	 0.000929	 0.0071	 0.01291	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75572	 61220	 0.00475	 0.069436	 0.1725	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61220	 76477	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76478	 61220	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61221	 61222	 0.007271	 0.012786	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76475	 61221	 0.02605	 0.021443	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76475	 61222	 0.052964	 0.034286	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61223	 76479	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61223	 76479	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61224	 61576	 0.049064	 0.124286	 0.00246	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76470	 61224	 0.028871	 0.073136	 0.00145	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75555	 61225	 0.324629	 0.210364	 0.00401	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75468	 61226	 0.051629	 0.11065	 0.00194	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75575	 61226	 0.3891	 0.416457	 0.00881	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76058	 61226	 0.070136	 0.130429	 0.00305	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61227	 61229	 0.001729	 0.012836	 0.00489	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75467	 61227	 0.010193	 0.029529	 0.00712	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61228	 61229	 0.005214	 0.037879	 0.01309	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75911	 61228	 0.007536	 0.030679	 0.00747	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75912	 61228	 0.005321	 0.031186	 0.0085	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61230	 61243	 0.007871	 0.020807	 0.00487	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61230	 61369	 0.015971	 0.045821	 0.01128	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61230	 61377	 0.006064	 0.021143	 0.0049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61230	 76480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61230	 76480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61230	 76490	 0.012821	 0.029757	 0.00906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76480	 61231	 0.021207	 0.013729	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76480	 61232	 0.021321	 0.0151	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61233	 61234	 0.00145	 0.004893	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61233	 61235	 0.001543	 0.004086	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61233	 61243	 0.005843	 0.013571	 0.00414	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61233	 61353	 0.005921	 0.01975	 0.00501	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61233	 76481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61233	 76481	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61234	 61235	 0.001286	 0.004407	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61234	 61316	 0.00075	 0.003271	 0.00093	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61234	 76482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61234	 76482	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61235	 61238	 0.001507	 0.005243	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61235	 76483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61235	 76483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76483	 61236	 0.006536	 0.013429	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61237	 61240	 0.008143	 0.015143	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61238	 76484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61238	 76484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61239	 61245	 0.003686	 0.0123	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76484	 61239	 0.006429	 0.018443	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61239	 76485	 0.011229	 0.017921	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61240	 76485	 0.004186	 0.0088	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61241	 61245	 0.022129	 0.018214	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61241	 61255	 0.016857	 0.016557	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61242	 61244	 0.002129	 0.005621	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61243	 61244	 0.001814	 0.004207	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61243	 61261	 0.00745	 0.020007	 0.00454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61243	 76485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61243	 76485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61244	 76486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61244	 76486	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61244	 76490	 0.003114	 0.010386	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61245	 61246	 0.018443	 0.013064	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61247	 61255	 0.032007	 0.022671	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61248	 61249	 0.001257	 0.0042	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61248	 61333	 0.004493	 0.020607	 0.00528	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61248	 76487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61248	 76487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61249	 76488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61249	 76488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76487	 61250	 0.024343	 0.015757	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61251	 61323	 0.0208	 0.018636	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76487	 61251	 0.037214	 0.02945	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61252	 61256	 0.025443	 0.018021	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61252	 61257	 0.006629	 0.010579	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76488	 61252	 0.009614	 0.014414	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61253	 61254	 0.020057	 0.015871	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61254	 61256	 0.032471	 0.038064	 0.00066	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61254	 61312	 0.009229	 0.016236	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61255	 61264	 0.006786	 0.010836	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76487	 61255	 0.016479	 0.024707	 0.00045	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61255	 76491	 0.013471	 0.035707	 0.00091	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61255	 76504	 0.124957	 0.088521	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61256	 61263	 0.011686	 0.027129	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61257	 61258	 0.006629	 0.011964	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61258	 61259	 0.0031	 0.006371	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61259	 61265	 0.008193	 0.015236	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61260	 76489	 0.015271	 0.009886	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61261	 61295	 0.005014	 0.017193	 0.00412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61261	 76489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61261	 76489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61261	 76490	 0.001964	 0.00715	 0.00219	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61262	 61328	 0.000707	 0.011793	 0.12461	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76270	 61262	 0.001364	 0.015821	 0.13694	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61262	 76490	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61263	 61264	 0.007793	 0.012436	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76491	 61263	 0.003386	 0.01625	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76491	 61265	 0.004121	 0.014086	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61266	 76493	 0.019143	 0.017157	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61267	 61269	 0.00125	 0.004293	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61267	 61271	 0.001236	 0.003464	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61268	 76492	 0.030986	 0.020057	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61269	 61270	 0.000857	 0.003479	 0.00085	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61269	 76492	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61269	 76492	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76490	 61270	 0.001086	 0.004357	 0.0011	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61270	 76493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61270	 76493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61271	 76494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61271	 76494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61272	 61293	 0.015557	 0.010071	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61273	 61274	 0.015536	 0.021171	 0.00047	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76494	 61273	 0.007571	 0.017307	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61274	 61275	 0.006386	 0.013129	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61275	 76495	 0.005214	 0.010714	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61276	 61277	 0.001986	 0.00525	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61276	 61278	 0.003143	 0.007293	 0.00222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61276	 61286	 0.003379	 0.008936	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61276	 76495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61276	 76495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61277	 61278	 0.001979	 0.005321	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76495	 61280	 0.018814	 0.012179	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61281	 61282	 0.000971	 0.003329	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61282	 61284	 0.001379	 0.00365	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61282	 61286	 0.002614	 0.0069	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61283	 61284	 0.001179	 0.003836	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61284	 61286	 0.001721	 0.004693	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61284	 76496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61284	 76496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61285	 61297	 0.027843	 0.019721	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76293	 61285	 0.054064	 0.035	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76496	 61285	 0.008943	 0.0122	 0.00022	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61286	 61295	 0.002671	 0.006714	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76490	 61286	 0.007657	 0.027071	 0.0061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61286	 76497	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61286	 76497	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76497	 61287	 0.007693	 0.015807	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61288	 61289	 0.007786	 0.012486	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76494	 61288	 0.007357	 0.015457	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61289	 61290	 0.005664	 0.011643	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61290	 61291	 0.014836	 0.009607	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76497	 61290	 0.004871	 0.014943	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61292	 61293	 0.019929	 0.017857	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61292	 76498	 0.011893	 0.022107	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61293	 61294	 0.019236	 0.013621	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76489	 61293	 0.006007	 0.023371	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61295	 76498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61295	 76498	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61296	 61308	 0.006814	 0.027043	 0.00077	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61296	 76502	 0.005964	 0.026421	 0.00079	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76293	 61298	 0.031493	 0.022314	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61299	 61304	 0.025014	 0.016193	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61300	 61301	 0.013821	 0.018843	 0.00042	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61300	 61304	 0.018864	 0.012214	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76293	 61301	 0.00825	 0.016886	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61302	 76499	 0.031443	 0.024886	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61303	 61304	 0.016514	 0.010693	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61303	 61306	 0.026507	 0.017164	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61303	 61309	 0.021486	 0.01925	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61304	 76499	 0.011157	 0.028257	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61305	 61306	 0.020271	 0.018286	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61305	 61311	 0.018964	 0.030264	 0.0007	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61305	 61315	 0.008857	 0.010379	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61305	 76499	 0.0159	 0.036357	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61307	 61324	 0.009057	 0.022779	 0.0059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76256	 61307	 0.013307	 0.045657	 0.01094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61307	 76499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61307	 76499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61308	 61318	 0.049714	 0.039343	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76363	 61308	 0.05735	 0.040621	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76499	 61308	 0.031614	 0.022393	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61309	 61310	 0.006957	 0.010136	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76489	 61310	 0.024664	 0.036986	 0.00067	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61311	 61322	 0.004614	 0.015757	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61312	 61313	 0.00565	 0.011564	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76488	 61312	 0.003107	 0.012971	 0.00037	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61313	 61314	 0.011207	 0.012329	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61314	 61315	 0.016436	 0.010643	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61316	 61336	 0.001536	 0.008807	 0.00249	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61316	 76500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61316	 76500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61317	 61319	 0.0054	 0.0147	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61317	 61324	 0.002136	 0.008679	 0.00211	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61317	 61326	 0.003571	 0.013579	 0.0038	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61317	 61333	 0.004029	 0.014043	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61319	 61320	 0.003643	 0.010543	 0.00254	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61319	 76501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61319	 76501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61320	 61321	 0.002964	 0.009893	 0.00251	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61320	 61332	 0.009643	 0.032486	 0.00807	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61320	 61342	 0.016743	 0.050857	 0.01114	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61320	 76502	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61320	 76502	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61321	 76503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61321	 76503	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61322	 76504	 0.00535	 0.0209	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61323	 76504	 0.007379	 0.018771	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61324	 76504	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61324	 76504	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61325	 61326	 0.000664	 0.0071	 0.00227	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61325	 76507	 0.001479	 0.019229	 0.00556	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61326	 76505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61326	 76505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61327	 61332	 0.003457	 0.017043	 0.00461	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61327	 76507	 0.0022	 0.012207	 0.00371	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75552	 61328	 0.002479	 0.043714	 0.41864	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61328	 76506	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76507	 61328	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76505	 61329	 0.040329	 0.028564	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76505	 61330	 0.018264	 0.032121	 0.0006	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76506	 61331	 0.001043	 0.010821	 0.02331	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61331	 76508	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61331	 76508	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61332	 61333	 0.002414	 0.010993	 0.00349	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61333	 61336	 0.005236	 0.0185	 0.00417	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61333	 76509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61333	 76509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76509	 61334	 0.020043	 0.0142	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76509	 61335	 0.03105	 0.021993	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61336	 61342	 0.0011	 0.009	 0.00244	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61336	 76510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61336	 76510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61336	 76521	 0.011936	 0.065529	 0.01733	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76510	 61337	 0.033779	 0.021871	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61338	 76511	 0.027786	 0.019686	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76510	 61339	 0.024721	 0.016007	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61340	 61341	 0.001536	 0.005	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61340	 61342	 0.005814	 0.015371	 0.0036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61340	 61344	 0.004557	 0.010586	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61340	 76511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61340	 76511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61341	 61344	 0.006564	 0.017871	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76508	 61341	 0.002329	 0.013636	 0.00371	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76508	 61342	 0.0009	 0.009379	 0.00316	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61343	 61350	 0.0029	 0.009064	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61343	 61367	 0.003443	 0.011986	 0.00278	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61344	 61347	 0.001429	 0.00555	 0.00149	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61344	 61348	 0.001971	 0.010086	 0.00254	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61344	 76512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61344	 76512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61345	 61346	 0.012036	 0.019307	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76510	 61345	 0.036286	 0.0257	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76512	 61346	 0.013093	 0.026793	 0.00066	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61347	 61354	 0.001257	 0.005043	 0.00127	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61348	 61365	 0.003593	 0.014629	 0.00356	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61349	 76523	 0.007286	 0.025521	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61350	 61351	 0.002329	 0.006343	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61350	 76513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61350	 76513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61351	 61355	 0.00205	 0.005579	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61351	 76514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61351	 76514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76514	 61352	 0.025593	 0.0185	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61353	 61354	 0.000971	 0.003686	 0.00103	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61353	 61355	 0.001693	 0.004071	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61353	 76515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61353	 76515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61355	 61377	 0.003779	 0.009814	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61355	 76516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61355	 76516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76516	 61356	 0.021457	 0.016979	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61357	 61362	 0.0185	 0.08105	 0.00174	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61357	 76517	 0.021193	 0.037279	 0.0007	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61357	 76522	 0.053764	 0.059136	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61358	 61360	 0.004364	 0.015279	 0.00506	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61358	 61377	 0.004364	 0.0166	 0.00464	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61358	 76517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61358	 76517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61359	 61360	 0.002736	 0.013479	 0.00364	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61359	 61361	 0.003829	 0.016757	 0.00576	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61360	 76518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61360	 76518	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61361	 61368	 0.008136	 0.042464	 0.01023	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76479	 61361	 0.002479	 0.01555	 0.0112	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61361	 76519	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61361	 76519	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76519	 61362	 0.010093	 0.044729	 0.00134	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61363	 76522	 0.052279	 0.078379	 0.00142	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61364	 61367	 0.000443	 0.005093	 0.00141	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61364	 76521	 0.002314	 0.025593	 0.00768	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61365	 76520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61365	 76520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61365	 76521	 0.003936	 0.022564	 0.0075	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75566	 61366	 0.004821	 0.032164	 0.06067	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61366	 76521	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61366	 76521	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61367	 61368	 0.003707	 0.009629	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61367	 61369	 0.001293	 0.006114	 0.00147	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61368	 61369	 0.001714	 0.006879	 0.00174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61368	 76522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61368	 76522	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61369	 76523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61369	 76523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75567	 61370	 0.212914	 0.168543	 0.00212	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76511	 61371	 0.068657	 0.054336	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76511	 61372	 0.070736	 0.082921	 0.00144	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76520	 61372	 0.019307	 0.056764	 0.00116	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76136	 61373	 0.044221	 0.219014	 0.05959	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61374	 61376	 0.000943	 0.0115	 0.04291	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75567	 61375	 0.052914	 0.047743	 0.0008	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75566	 61376	 0.000743	 0.00725	 0.02524	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76366	 61376	 0.0063	 0.042057	 0.0794	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76506	 61376	 0.001371	 0.01435	 0.027	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61377	 76524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61377	 76524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76518	 61378	 0.010271	 0.047886	 0.0011	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76524	 61378	 0.017579	 0.046593	 0.00118	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76486	 61379	 0.118271	 0.083786	 0.00132	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61380	 76554	 0.027929	 0.019786	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61381	 76525	 0.017621	 0.012486	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61382	 61383	 0.000479	 0.002714	 0.00079	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61382	 61394	 0.001471	 0.006721	 0.00213	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61382	 61443	 0.004007	 0.010586	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61382	 76525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61382	 76525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61383	 61384	 0.000393	 0.002086	 0.0007	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61384	 76526	 0.000407	 0.002593	 0.0007	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61385	 61386	 0.0001	 0.001564	 0.00354	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61385	 61450	 0.000886	 0.013243	 0.03098	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61385	 76526	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61385	 76526	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75583	 61386	 0.000679	 0.005529	 0.01811	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61386	 76527	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61386	 76527	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61386	 76534	 0.000279	 0.0029	 0.00606	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61387	 61392	 0.011957	 0.041857	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76527	 61387	 0.003079	 0.012214	 0.00035	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61388	 76528	 0.022679	 0.017771	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61389	 61397	 0.00095	 0.004543	 0.00131	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76526	 61389	 0.000543	 0.004079	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61389	 76528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61389	 76528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61390	 61391	 0.002943	 0.0078	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76528	 61390	 0.00235	 0.009171	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61391	 61392	 0.004264	 0.0108	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61392	 76531	 0.003321	 0.020407	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61393	 76529	 0.013786	 0.012443	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61394	 61483	 0.0009	 0.003286	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61394	 76529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61394	 76529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61395	 61402	 0.013629	 0.009657	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61396	 76531	 0.025921	 0.016779	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61397	 61400	 0.000757	 0.003379	 0.00092	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61397	 76530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61397	 76530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76530	 61398	 0.011243	 0.007964	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61399	 76532	 0.017929	 0.014193	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61400	 61401	 0.000671	 0.004264	 0.00116	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61400	 61408	 0.00205	 0.008507	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61401	 61484	 0.000886	 0.004893	 0.00176	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61401	 76531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61401	 76531	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61402	 76555	 0.013086	 0.013214	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61403	 61404	 0.020386	 0.0132	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61404	 76555	 0.01835	 0.013	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61405	 61416	 0.019257	 0.015236	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61405	 61417	 0.025307	 0.020029	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61405	 76555	 0.010221	 0.021007	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61406	 61407	 0.004714	 0.008757	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61406	 61412	 0.0103	 0.00815	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61406	 61413	 0.024964	 0.017686	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61407	 61411	 0.017514	 0.0158	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76531	 61407	 0.004914	 0.021907	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61408	 61475	 0.002643	 0.010393	 0.00272	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61408	 76532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61408	 76532	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76532	 61409	 0.028114	 0.019914	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61410	 61414	 0.013764	 0.00975	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61411	 61474	 0.03205	 0.056364	 0.00106	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61414	 61415	 0.022821	 0.017893	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61415	 61421	 0.01095	 0.017564	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61417	 61418	 0.019021	 0.013471	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61419	 61421	 0.030279	 0.019607	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61420	 61472	 0.034879	 0.024707	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61421	 61422	 0.032229	 0.020864	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61421	 76555	 0.012429	 0.060643	 0.00105	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61423	 61424	 0.008436	 0.035064	 0.00819	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61424	 61428	 0.008107	 0.033493	 0.00793	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61425	 61444	 0.144814	 0.114614	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61426	 61427	 0.005079	 0.020964	 0.00496	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61426	 61428	 0.003521	 0.01385	 0.00362	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61427	 61429	 0.005064	 0.019693	 0.00526	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61428	 61495	 0.006279	 0.039786	 0.0108	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61428	 76559	 0.018843	 0.073336	 0.0196	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61429	 61432	 0.007629	 0.029007	 0.00812	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61430	 61475	 0.002029	 0.014829	 0.00381	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61430	 61476	 0.002064	 0.012071	 0.00329	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61430	 61477	 0.009129	 0.029764	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61431	 61476	 0.002729	 0.030686	 0.00887	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75561	 61431	 0.003329	 0.033186	 0.01233	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61432	 61439	 0.003036	 0.008321	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61432	 76533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61432	 76533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75584	 61433	 0.083707	 0.0593	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76533	 61434	 0.083307	 0.053936	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61435	 76536	 0.026771	 0.017329	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61436	 76534	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61437	 61439	 0.001086	 0.005129	 0.00164	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76526	 61437	 0.002043	 0.0091	 0.00247	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76535	 61437	 0.00065	 0.006857	 0.00186	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61438	 61442	 0.019379	 0.015186	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61439	 61443	 0.001286	 0.007379	 0.00245	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61440	 61441	 0.022343	 0.014464	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61441	 61442	 0.026636	 0.021079	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76525	 61441	 0.007257	 0.014914	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61442	 76537	 0.01015	 0.01785	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61443	 76537	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61443	 76537	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61443	 76546	 0.005436	 0.021379	 0.00559	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76537	 61444	 0.015043	 0.030914	 0.00059	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61445	 76540	 0.0309	 0.02445	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61446	 61450	 0.000279	 0.002543	 0.00479	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75530	 61446	 0.019643	 0.132479	 0.2538	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61446	 76538	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76539	 61446	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61447	 76540	 0.019329	 0.01515	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76538	 61448	 0.00345	 0.014036	 0.00342	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61448	 76540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61448	 76540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61448	 76541	 0.003236	 0.00855	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61448	 76546	 0.001193	 0.008207	 0.00239	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76540	 61449	 0.006443	 0.009664	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61450	 76541	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76542	 61450	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61451	 61452	 0.0012	 0.004114	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61451	 61466	 0.002321	 0.008193	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61451	 76543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61451	 76543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61452	 61454	 0.002407	 0.008514	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76541	 61452	 0.001821	 0.004907	 0.00138	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61452	 76544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61452	 76544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61453	 61459	 0.0038	 0.0133	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61453	 76545	 0.003129	 0.013379	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61454	 76545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61454	 76545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61454	 76546	 0.001186	 0.005207	 0.00179	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61455	 76546	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61455	 76546	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61456	 61457	 0.022193	 0.039036	 0.00074	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61456	 61472	 0.0568	 0.040236	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76547	 61456	 0.0049	 0.02285	 0.00053	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61457	 61464	 0.008843	 0.01555	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61458	 61463	 0.027829	 0.046879	 0.00066	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61458	 61471	 0.023143	 0.0525	 0.00105	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76547	 61458	 0.0408	 0.103357	 0.00205	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61459	 61460	 0.020964	 0.013571	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61459	 61464	 0.012893	 0.017593	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61460	 61461	 0.02355	 0.015243	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61460	 61463	 0.010486	 0.020764	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76544	 61460	 0.0181	 0.017779	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61462	 61463	 0.012579	 0.010357	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61462	 76548	 0.021379	 0.013843	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61463	 61464	 0.011021	 0.015043	 0.00027	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76543	 61465	 0.022743	 0.016107	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61466	 61467	 0.001707	 0.0057	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61466	 76548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61466	 76548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61467	 76549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61467	 76549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61468	 61470	 0.018471	 0.046786	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76539	 61468	 0.025521	 0.0732	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76549	 61468	 0.00605	 0.023621	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75716	 61469	 0.046529	 0.081829	 0.00154	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61471	 76553	 0.21095	 0.232121	 0.0031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61473	 76555	 0.133243	 0.130914	 0.00221	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61475	 61476	 0.005921	 0.027164	 0.00696	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76546	 61475	 0.009479	 0.03795	 0.00956	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61476	 76550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61476	 76550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61477	 61480	 0.004921	 0.020464	 0.00478	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61477	 76551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61477	 76551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61478	 61479	 0.008343	 0.021129	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61478	 61481	 0.146679	 0.132357	 0.00221	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76550	 61479	 0.07305	 0.128486	 0.00241	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76551	 61479	 0.037136	 0.06905	 0.00161	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75577	 61480	 0.0198	 0.090914	 0.02331	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61480	 76552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61480	 76552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61481	 61601	 0.063893	 0.244929	 0.00693	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76552	 61481	 0.05675	 0.166907	 0.00342	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61482	 61599	 0.037164	 0.112964	 0.02477	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76546	 61482	 0.025443	 0.087329	 0.02094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61482	 76553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61482	 76553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76546	 61483	 0.002193	 0.008929	 0.00218	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61483	 76554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61483	 76554	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76546	 61484	 0.00255	 0.010593	 0.00247	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61484	 76555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61484	 76555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75578	 61485	 0.217193	 0.153907	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75531	 61486	 0.027643	 0.107664	 0.0288	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61486	 76556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61486	 76556	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61487	 61488	 0.015364	 0.016407	 0.00035	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61487	 61492	 0.137671	 0.2831	 0.0054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75565	 61487	 0.089521	 0.142914	 0.00329	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76556	 61487	 0.41225	 0.326614	 0.00411	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61488	 76557	 0.011021	 0.017586	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61489	 76557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61489	 76557	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75586	 61490	 0.4508	 0.357243	 0.0045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76557	 61490	 0.087693	 0.154243	 0.0029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61491	 61492	 0.060714	 0.039307	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61492	 76558	 0.065664	 0.25555	 0.00427	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61493	 61494	 0.00655	 0.047586	 0.01645	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61494	 61495	 0.007471	 0.04815	 0.01262	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61494	 76558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61494	 76558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75583	 61496	 0.001193	 0.019329	 0.03851	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61496	 76559	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61496	 76559	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61497	 61499	 0.002093	 0.005536	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61497	 61511	 0.004021	 0.014214	 0.0032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61497	 76560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61497	 76560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61498	 61527	 0.071364	 0.064386	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61498	 76561	 0.028271	 0.0183	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61499	 61510	 0.0033	 0.011679	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61499	 76561	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61499	 76561	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76561	 61500	 0.033214	 0.0215	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61501	 61502	 0.028443	 0.02015	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61502	 61526	 0.068779	 0.056614	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76560	 61502	 0.004957	 0.014571	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61503	 61509	 0.010893	 0.014843	 0.00033	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76560	 61503	 0.009057	 0.022936	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76561	 61504	 0.0287	 0.022714	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61504	 76564	 0.005943	 0.015743	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61505	 61510	 0.0092	 0.025657	 0.00539	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61505	 61521	 0.001886	 0.0094	 0.00304	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61505	 76562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61505	 76562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61506	 61507	 0.013464	 0.023679	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61506	 61508	 0.019864	 0.036929	 0.00086	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76560	 61506	 0.019243	 0.030871	 0.00057	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76562	 61507	 0.014721	 0.025893	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61508	 61524	 0.039414	 0.069321	 0.0013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61509	 61526	 0.027271	 0.0246	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61510	 61511	 0.002514	 0.006643	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61510	 61514	 0.002279	 0.007814	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61510	 61531	 0.007321	 0.020421	 0.00429	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75515	 61510	 0.008993	 0.077186	 0.02198	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61510	 76563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61510	 76563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61511	 61513	 0.002079	 0.007	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61511	 76564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61511	 76564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61512	 61515	 0.023014	 0.03025	 0.00041	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76563	 61512	 0.007271	 0.01495	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61513	 61514	 0.004493	 0.012307	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61513	 61517	 0.001393	 0.004914	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61514	 61534	 0.001564	 0.005214	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61514	 76565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61514	 76565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61515	 61532	 0.01675	 0.025664	 0.00036	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76565	 61515	 0.011557	 0.033143	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61516	 61518	 0.006536	 0.016557	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61516	 61520	 0.02305	 0.02065	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76564	 61516	 0.033836	 0.024457	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61517	 61519	 0.00145	 0.0059	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61517	 76566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61517	 76566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76566	 61518	 0.003621	 0.016029	 0.00036	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61519	 61537	 0.003014	 0.013121	 0.00374	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76563	 61520	 0.0815	 0.052764	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61521	 61523	 0.002357	 0.014143	 0.00428	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61522	 61524	 0.133493	 0.094571	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61523	 61541	 0.002071	 0.014643	 0.00401	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61524	 61545	 0.022271	 0.08535	 0.00241	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61525	 61526	 0.051571	 0.082729	 0.00153	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61527	 61528	 0.0496	 0.03925	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61528	 61529	 0.061136	 0.043307	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61528	 61530	 0.052321	 0.041407	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76563	 61529	 0.008721	 0.019786	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61530	 76567	 0.025557	 0.0408	 0.00094	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61531	 76567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61531	 76567	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61532	 61533	 0.054671	 0.043264	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61535	 61536	 0.003093	 0.008036	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61535	 61540	 0.008929	 0.023593	 0.00552	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75515	 61535	 0.012579	 0.060157	 0.02108	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61535	 76568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61535	 76568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61537	 61540	 0.002871	 0.015236	 0.00509	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61537	 76569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61537	 76569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75562	 61538	 0.103893	 0.082221	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61539	 76570	 0.17345	 0.112321	 0.00214	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61540	 61542	 0.00415	 0.029357	 0.00806	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61540	 76570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61540	 76570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75515	 61541	 0.005071	 0.032464	 0.01092	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75515	 61542	 0.002529	 0.018179	 0.00481	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76390	 61543	 0.095479	 0.061814	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75527	 61544	 0.032321	 0.095364	 0.02221	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61544	 76571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61544	 76571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76571	 61545	 0.011693	 0.062807	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75470	 61546	 0.08445	 0.193193	 0.00472	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61547	 61548	 0.001357	 0.016386	 0.07174	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75483	 61547	 0.005586	 0.037271	 0.07034	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75550	 61547	 0.003493	 0.024514	 0.04175	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76211	 61547	 0.001507	 0.014793	 0.05074	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61548	 61552	 0.000393	 0.005136	 0.01661	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75559	 61548	 0.00735	 0.048479	 0.09401	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61549	 76573	 0.025679	 0.040986	 0.00094	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61550	 76574	 0.025914	 0.023386	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61551	 76573	 0.02525	 0.01635	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61552	 76572	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76573	 61552	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61552	 76575	 0.000114	 0.001829	 0.00365	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76572	 61553	 0.000564	 0.005407	 0.00157	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61553	 76574	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61553	 76574	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61553	 76576	 0.001636	 0.012071	 0.00349	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61554	 61555	 2.1e-05	 0.000357	 0.00363	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61554	 76575	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61554	 76575	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61555	 61558	 7.9e-05	 0.001321	 0.01287	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76573	 61556	 0.037536	 0.033871	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76573	 61557	 0.024593	 0.019464	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61558	 76576	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61558	 76576	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61559	 61570	 0.010471	 0.028121	 0.00637	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61559	 61589	 0.007086	 0.017821	 0.00461	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61559	 76577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61559	 76577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61560	 76578	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61561	 61562	 0.0017	 0.004629	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61561	 61565	 0.003529	 0.009329	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76578	 61561	 0.000629	 0.008671	 0.00313	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61561	 76580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61561	 76580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61562	 61564	 0.000914	 0.00325	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61562	 61565	 0.001921	 0.005514	 0.00136	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76578	 61562	 0.002386	 0.014786	 0.00358	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61563	 61571	 0.019757	 0.0177	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61563	 76581	 0.003679	 0.009743	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61564	 61565	 0.000936	 0.002407	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61565	 61573	 0.001086	 0.003786	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61565	 76581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61565	 76581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61566	 61567	 0.0053	 0.013486	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76580	 61566	 0.007186	 0.031836	 0.00096	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61567	 61568	 0.012907	 0.024	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76577	 61568	 0.015557	 0.036114	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61569	 61570	 0.0046	 0.011079	 0.00313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61569	 61572	 0.003686	 0.009571	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61570	 61573	 0.010729	 0.028357	 0.00664	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61572	 61575	 0.002193	 0.007143	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61572	 76582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61572	 76582	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61573	 61575	 0.001286	 0.004293	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61574	 61575	 0.001021	 0.004079	 0.00103	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75564	 61574	 0.029236	 0.073536	 0.01906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76582	 61576	 0.012079	 0.03705	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75574	 61577	 0.100186	 0.257643	 0.00399	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61578	 61589	 0.010257	 0.024729	 0.00698	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61579	 76585	 0.052214	 0.083343	 0.00192	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61580	 61581	 0.0032	 0.007714	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61580	 61588	 0.007771	 0.019536	 0.00506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61582	 76584	 0.057043	 0.117243	 0.00224	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61583	 61584	 0.129221	 0.091543	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61583	 61591	 0.305743	 0.242107	 0.00305	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61584	 76584	 0.015614	 0.060743	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61585	 76583	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76584	 61585	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76584	 61586	 0.055514	 0.072971	 0.001	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61586	 76585	 0.008514	 0.037721	 0.00086	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61587	 61588	 0.007029	 0.017671	 0.00458	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76578	 61587	 0.004529	 0.015836	 0.00525	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61587	 76585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61587	 76585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61590	 61592	 0.005257	 0.024114	 0.00618	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76578	 61592	 0.004993	 0.019986	 0.00504	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75730	 61593	 0.00125	 0.013679	 0.13441	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61593	 76586	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61594	 61600	 0.011421	 0.047479	 0.01109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76587	 61594	 0.006064	 0.01895	 0.00549	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61595	 61597	 0.001264	 0.008514	 0.01567	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61595	 76589	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61595	 76589	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75731	 61596	 0.019857	 0.066271	 0.01681	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76587	 61596	 0.004786	 0.016743	 0.00555	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76586	 61597	 0.000193	 0.001329	 0.00235	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61598	 61599	 0.027364	 0.071071	 0.01726	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76587	 61598	 0.006729	 0.018071	 0.00409	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76589	 61598	 0.009457	 0.035943	 0.01006	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61598	 76590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61598	 76590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75539	 61600	 0.016193	 0.063014	 0.01684	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61600	 76591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61600	 76591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76591	 61601	 0.150179	 0.264264	 0.00497	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61601	 76592	 0.204836	 0.469436	 0.01149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75534	 61602	 0.001236	 0.01805	 0.06921	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75536	 61602	 0.000457	 0.005771	 0.01379	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75538	 61602	 0.003643	 0.028364	 0.10181	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61602	 76592	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61602	 76592	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75579	 61603	 0.015164	 0.127836	 0.22514	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61603	 76593	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61603	 76593	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61603	 76594	 0.00025	 0.001629	 0.00325	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61603	 76602	 0.000129	 0.001	 0.00341	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61604	 61605	 0.000107	 0.00125	 0.01139	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61604	 61619	 0.0001	 0.001114	 0.00976	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61604	 76594	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61605	 61611	 0.000186	 0.002157	 0.01891	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61605	 76597	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61605	 76597	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61606	 61610	 0.0491	 0.034786	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61606	 76599	 0.027821	 0.019707	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61607	 61610	 0.006057	 0.01065	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76597	 61607	 0.011386	 0.012157	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61608	 61610	 0.011414	 0.023986	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76596	 61608	 0.003536	 0.015129	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61608	 76613	 0.029579	 0.040321	 0.00089	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61609	 61615	 0.007379	 0.015171	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76593	 61609	 0.002086	 0.010357	 0.00025	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61609	 76600	 0.044071	 0.036271	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61610	 61613	 0.011707	 0.008293	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61610	 76599	 0.050314	 0.035643	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61611	 61636	 0.000621	 0.006793	 0.06599	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61611	 76598	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76599	 61612	 0.023921	 0.015486	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61614	 61615	 0.01035	 0.019243	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76596	 61614	 0.034936	 0.061436	 0.00116	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61615	 61616	 0.018393	 0.014557	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61616	 76601	 0.012629	 0.029314	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61617	 61618	 0.001936	 0.0053	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61617	 61620	 0.0024	 0.008493	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76598	 61617	 0.008	 0.020579	 0.00509	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61617	 76600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61617	 76600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61618	 76601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61618	 76601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61618	 76604	 0.003371	 0.014264	 0.00321	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61619	 61622	 0.000114	 0.00125	 0.01216	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61619	 76602	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76603	 61619	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76603	 61620	 0.000821	 0.003121	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61621	 76605	 0.026607	 0.036307	 0.00065	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61622	 76604	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61622	 76606	 0.000579	 0.009643	 0.08908	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61623	 76606	 0.00011	 0.008799	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61623	 76606	 0.00011	 0.008799	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76607	 61623	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61624	 61645	 0.041871	 0.077864	 0.00182	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76600	 61624	 0.034314	 0.070521	 0.00134	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76601	 61624	 0.0279	 0.057336	 0.00109	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61624	 76610	 0.139543	 0.149064	 0.00315	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61625	 61626	 0.005479	 0.021536	 0.00564	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61625	 61628	 0.005443	 0.014914	 0.00324	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61625	 61630	 0.012364	 0.033657	 0.00741	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75548	 61625	 0.00835	 0.060457	 0.03256	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61625	 76608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61625	 76608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61626	 61627	 0.00215	 0.005886	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61627	 61633	 0.016821	 0.0423	 0.01096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61628	 76609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61628	 76609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61629	 61631	 0.1127	 0.072971	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76608	 61629	 0.033921	 0.059657	 0.00112	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76609	 61629	 0.008329	 0.017107	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61630	 61632	 0.015843	 0.041879	 0.00981	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76609	 61631	 0.116	 0.090936	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61631	 76610	 0.182693	 0.164886	 0.00276	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61632	 61647	 0.006614	 0.023057	 0.00534	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76607	 61632	 0.007693	 0.050336	 0.0128	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61632	 76610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61632	 76610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61634	 61635	 0.102936	 0.072921	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76599	 61635	 0.018329	 0.032236	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61636	 61637	 0.00095	 0.010557	 0.10058	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61636	 76611	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61636	 76611	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61637	 76612	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61637	 76612	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61638	 61640	 0.008221	 0.027436	 0.00696	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76611	 61638	 0.007136	 0.025229	 0.00569	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61639	 76613	 0.10585	 0.083771	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76595	 61640	 0.002893	 0.011264	 0.00301	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61640	 76613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61640	 76613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76613	 61641	 0.036829	 0.026086	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76600	 61642	 0.074779	 0.1537	 0.00293	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61642	 76614	 0.024771	 0.109771	 0.00329	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61642	 76615	 0.162171	 0.259029	 0.00597	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61643	 61646	 0.004686	 0.012393	 0.0029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76607	 61643	 0.02065	 0.078536	 0.022	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61643	 76614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61643	 76614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75535	 61644	 0.040907	 0.108221	 0.02536	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76612	 61644	 0.058729	 0.155529	 0.03649	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61644	 76615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61644	 76615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76614	 61645	 0.051736	 0.102429	 0.0015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61646	 61647	 0.001079	 0.00375	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61648	 63749	 0.0011	 0.02045	 1.68443	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61648	 76616	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61648	 76616	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61649	 61650	 0.000564	 0.005007	 0.00134	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61649	 61651	 0.001864	 0.009357	 0.00244	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76616	 61649	 0.001114	 0.010707	 0.00311	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61650	 61651	 0.000543	 0.004679	 0.00133	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61651	 61652	 0.000457	 0.005971	 0.0017	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61651	 76618	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61651	 76618	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61652	 61656	 0.000593	 0.008193	 0.00367	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61652	 76619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61652	 76619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61653	 61655	 0.003693	 0.012921	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61653	 61655	 0.003693	 0.012921	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76618	 61653	 0.006929	 0.02425	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76618	 61653	 0.006929	 0.02425	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61654	 61655	 0.003536	 0.015743	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61654	 61655	 0.003536	 0.015743	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76619	 61654	 0.004936	 0.019264	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76619	 61654	 0.004936	 0.019264	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61656	 76647	 0.005336	 0.080964	 0.02987	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75599	 61657	 0.026121	 0.189214	 0.00475	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76618	 61657	 0.051371	 0.375829	 0.00694	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61658	 61659	 0.010364	 0.090493	 0.02488	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61658	 61777	 0.009271	 0.113164	 0.03749	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61658	 61777	 0.009271	 0.113164	 0.03749	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61658	 76669	 0.022021	 0.1531	 0.04384	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61659	 76621	 0.007821	 0.075164	 0.02188	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61660	 76620	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61660	 76620	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76621	 61660	 0.00016	 0.012814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75594	 61661	 0.035957	 0.12725	 0.02872	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61661	 76622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61661	 76622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75594	 61663	 0.003686	 0.012429	 0.00309	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75601	 61663	 0.003507	 0.011443	 0.00304	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61663	 76623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61663	 76623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76623	 61664	 0.063779	 0.041293	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61665	 61666	 0.043079	 0.050493	 0.00088	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76622	 61665	 0.234921	 0.413714	 0.00779	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76623	 61666	 0.019543	 0.076043	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 61667	 0.031807	 0.099521	 0.02886	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61667	 76624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61667	 76624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61668	 61821	 0.001664	 0.020036	 1.52557	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61668	 76625	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61668	 76625	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76625	 61669	 0.012486	 0.051557	 0.0122	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61669	 76626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61669	 76626	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76626	 61670	 0.035407	 0.046536	 0.00064	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76616	 61671	 0.0385	 0.219914	 0.06409	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76625	 61671	 0.019943	 0.155779	 0.04674	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75598	 61672	 0.01035	 0.103214	 0.0384	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61673	 76627	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76628	 61673	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75596	 61674	 0.001136	 0.012621	 0.11914	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76627	 61674	 0.000329	 0.003793	 0.03324	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61675	 61778	 0.016814	 0.107357	 0.2275	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76628	 61675	 0.002821	 0.021764	 0.05145	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61675	 76629	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61675	 76629	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61676	 61751	 0.0083	 0.095714	 0.935	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75596	 61676	 0.00025	 0.00275	 0.02671	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61676	 76630	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61676	 76630	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61677	 76631	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61677	 76631	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75594	 61678	 0.064436	 0.215864	 0.05505	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75606	 61678	 0.016607	 0.118664	 0.03686	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76631	 61678	 0.023343	 0.084993	 0.02605	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61679	 61680	 0.004864	 0.012621	 0.00306	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61679	 76632	 0.028457	 0.078021	 0.01698	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61680	 61755	 0.071236	 0.191843	 0.04364	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61681	 61739	 0.101943	 0.263779	 0.06582	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61681	 76632	 0.010493	 0.090057	 0.02566	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61682	 61683	 0.0325	 0.146629	 0.03912	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61682	 61743	 0.041064	 0.229093	 0.07018	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61682	 61769	 0.063	 0.216986	 0.05226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61682	 76632	 0.048664	 0.272107	 0.08362	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61682	 76681	 0.06795	 0.237921	 0.05551	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61683	 61755	 0.039843	 0.159864	 0.04039	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61683	 76632	 0.045021	 0.1358	 0.0426	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61684	 61694	 0.1664	 0.422057	 0.00837	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61684	 76634	 0.132071	 0.271564	 0.00518	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61685	 76632	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61685	 76632	 0.000206	 0.016475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61686	 61688	 0.019314	 0.039686	 0.00076	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76633	 61686	 0.024707	 0.086464	 0.00179	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76632	 61687	 0.003529	 0.011771	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61687	 76634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61687	 76634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76634	 61688	 0.013343	 0.027414	 0.00052	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61689	 61690	 0.469257	 0.371914	 0.00469	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75592	 61689	 0.595707	 0.492264	 0.00998	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61690	 61691	 0.147343	 0.104386	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61690	 76636	 0.137157	 0.282036	 0.00538	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61691	 76636	 0.116214	 0.29455	 0.00584	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61692	 61746	 0.00095	 0.012307	 0.78921	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61692	 76635	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61693	 61694	 0.07085	 0.179514	 0.00356	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61693	 61776	 0.14065	 0.373271	 0.00949	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61695	 61696	 0.036471	 0.093836	 0.02326	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 61695	 0.089007	 0.240893	 0.06805	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61696	 61748	 0.037686	 0.129464	 0.03107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 61696	 0.105336	 0.266671	 0.06965	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61696	 76637	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61696	 76637	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61697	 61715	 0.001136	 0.012907	 0.11758	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61697	 61824	 0.00065	 0.010021	 0.22784	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75591	 61697	 0.001586	 0.034486	 0.56161	 1737.0	 1823.85	 1910.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61697	 76638	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61698	 61699	 0.026036	 0.032314	 0.00071	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76640	 61698	 0.005	 0.019157	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61700	 61702	 0.001893	 0.007371	 0.00197	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76639	 61700	 0.002093	 0.007057	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61701	 61713	 0.02235	 0.015836	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61701	 76641	 0.010464	 0.023743	 0.00047	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61702	 61710	 0.000907	 0.005471	 0.00139	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76639	 61702	 0.002771	 0.007586	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61702	 76641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61702	 76641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61703	 61715	 0.001079	 0.011879	 0.11544	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61703	 76642	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61704	 61717	 0.017307	 0.012257	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76644	 61704	 0.014014	 0.02465	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61705	 76645	 0.025236	 0.017879	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76639	 61706	 0.001657	 0.006436	 0.00172	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76643	 61706	 0.000686	 0.00275	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61706	 76645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61706	 76645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61706	 76647	 0.02125	 0.075136	 0.01694	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76639	 61707	 0.000736	 0.008607	 0.00516	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61707	 76646	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61707	 76646	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61708	 61709	 0.028336	 0.018343	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61709	 61711	 0.033579	 0.021736	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76645	 61709	 0.013157	 0.04035	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61710	 61712	 0.001193	 0.008286	 0.00236	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61712	 61716	 0.012	 0.084921	 0.02332	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76636	 61714	 0.156407	 0.522557	 0.0083	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61714	 76648	 0.160007	 0.297771	 0.00698	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75591	 61715	 0.001421	 0.02365	 0.54086	 1877.0	 1970.85	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61715	 76647	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61715	 76647	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76635	 61716	 0.026164	 0.171507	 0.04377	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61716	 76648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61716	 76648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75691	 61718	 0.0069	 0.044843	 0.08949	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61718	 76649	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76650	 61718	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76650	 61719	 0.070807	 0.131679	 0.00309	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61720	 61756	 0.000914	 0.011879	 0.76136	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61720	 76651	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61720	 76651	 0.000329	 0.023064	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61721	 61774	 0.032157	 0.153629	 0.04464	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61721	 65943	 0.034086	 0.250714	 0.07464	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75595	 61721	 0.037329	 0.154436	 0.03664	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76651	 61721	 0.002421	 0.030421	 0.00942	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61721	 76672	 0.053486	 0.1896	 0.04289	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61722	 61723	 0.000864	 0.003579	 0.00085	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61722	 61729	 0.002693	 0.009079	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61722	 76652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61722	 76652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61723	 61736	 0.001879	 0.009257	 0.0025	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61723	 76653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61723	 76653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61724	 61726	 0.017257	 0.011171	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76653	 61724	 0.006871	 0.014064	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61724	 76658	 0.008264	 0.018743	 0.00037	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61725	 61727	 0.001507	 0.006021	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61725	 61736	 0.001029	 0.005914	 0.00167	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61726	 76658	 0.0069	 0.008564	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61727	 61731	 0.001871	 0.006614	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76653	 61728	 0.02885	 0.022836	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61729	 61730	 0.002007	 0.005393	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61729	 61734	 0.002829	 0.006821	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61730	 61731	 0.001521	 0.004257	 0.00109	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61730	 76655	 0.002693	 0.007936	 0.00184	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61731	 76654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61731	 76654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61732	 61738	 0.000543	 0.003286	 0.00749	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75597	 61732	 0.003664	 0.046736	 0.08854	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61732	 76655	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76656	 61732	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76656	 61733	 0.007829	 0.016079	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61733	 76657	 0.005714	 0.017536	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61733	 76660	 0.01605	 0.0364	 0.00073	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76655	 61734	 0.003964	 0.009971	 0.00259	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61734	 76657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61734	 76657	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61734	 76659	 0.001986	 0.012579	 0.00341	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76630	 61736	 0.006429	 0.049236	 0.03634	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61736	 76658	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61736	 76658	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76654	 61737	 0.05395	 0.042693	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76656	 61737	 0.063807	 0.0452	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61738	 76659	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76660	 61738	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76659	 61739	 0.005671	 0.091393	 0.02989	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75604	 61740	 0.057907	 0.199314	 0.04796	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61740	 76686	 0.066229	 0.20795	 0.06058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61740	 76688	 0.090021	 0.210064	 0.06437	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61741	 76661	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76662	 61741	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76662	 61742	 0.010657	 0.021907	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76621	 61743	 0.115129	 0.291879	 0.07636	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76661	 61743	 0.057364	 0.197421	 0.0475	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61743	 76663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61743	 76663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61744	 61745	 0.024686	 0.032121	 0.00045	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76662	 61744	 0.092714	 0.245871	 0.00624	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76663	 61745	 0.228207	 0.425086	 0.00996	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61746	 76664	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61746	 76664	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75592	 61747	 0.042679	 0.163564	 0.00462	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61748	 76665	 0.003507	 0.014264	 0.00348	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61749	 61750	 0.019164	 0.013857	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61750	 76666	 0.007593	 0.013357	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61751	 61753	 0.001307	 0.013886	 0.14499	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61751	 76665	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61752	 76667	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61752	 76667	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75842	 61753	 0.007864	 0.100964	 0.98307	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61753	 76668	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76669	 61753	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75589	 61754	 0.020736	 0.144671	 0.26011	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61754	 76670	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61754	 76670	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76670	 61755	 0.0303	 0.118043	 0.03159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61756	 76671	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61756	 76671	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76672	 61756	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76672	 61756	 0.000188	 0.015042	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61757	 61758	 0.00025	 0.002743	 0.02588	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61757	 76673	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61757	 76673	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61758	 76674	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61758	 76674	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75608	 61759	 0.087729	 0.269314	 0.0073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61759	 76683	 0.20655	 0.425071	 0.00811	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61760	 61761	 0.056243	 0.084321	 0.00153	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61760	 61762	 0.0413	 0.095886	 0.00143	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61760	 76680	 0.025679	 0.078771	 0.00214	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61762	 61763	 0.049893	 0.039486	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61762	 76677	 0.016486	 0.056307	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61764	 61766	 0.000357	 0.003686	 0.04081	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61764	 76675	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76676	 61764	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75590	 61765	 0.021286	 0.094936	 0.02583	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61765	 76677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61765	 76677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61765	 76679	 0.002436	 0.010064	 0.00238	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61766	 76678	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75590	 61767	 0.002664	 0.027693	 0.00856	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76625	 61767	 0.051764	 0.237436	 0.07599	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76672	 61767	 0.0549	 0.209586	 0.05901	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76679	 61767	 0.033307	 0.117871	 0.0266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61768	 76682	 0.261529	 0.538657	 0.01029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75624	 61769	 0.027814	 0.114964	 0.02724	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61769	 76681	 0.005486	 0.019107	 0.00443	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61770	 76681	 0.010443	 0.02685	 0.00665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61771	 76681	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75595	 61772	 0.019136	 0.049679	 0.01206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76676	 61772	 0.042493	 0.243486	 0.05994	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61772	 76683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61772	 76683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61773	 66006	 0.0008	 0.014214	 1.258	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61773	 76684	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61773	 76684	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75595	 61774	 0.006057	 0.090586	 0.02684	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76684	 61774	 0.0046	 0.030807	 0.01938	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61774	 78146	 0.02535	 0.212693	 0.05548	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61775	 76685	 0.101307	 0.229886	 0.00459	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61776	 76685	 0.0039	 0.013321	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76632	 61777	 0.064714	 0.310821	 0.07455	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61777	 76685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61777	 76685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61778	 76686	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61778	 76686	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61778	 76687	 0.002779	 0.023529	 0.04586	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75591	 61779	 0.007207	 0.080836	 0.81107	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61779	 76687	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76688	 61779	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61780	 62107	 0.000157	 0.003543	 0.35449	 3339.0	 3505.95	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61780	 62451	 0.000271	 0.007571	 0.871	 4451.0	 4673.55	 4896.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61780	 76689	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61780	 76689	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61781	 65791	 0.002443	 0.046707	 5.00407	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61781	 76693	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61781	 76693	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76695	 61781	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76695	 61781	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61781	 79865	 0.000921	 0.031421	 3.27493	 2000.0	 2000.0	 2000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61782	 62623	 0.002436	 0.046621	 4.99264	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61782	 62623	 0.002436	 0.046621	 4.99264	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61782	 65519	 0.002221	 0.039886	 4.52864	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61782	 65519	 0.002221	 0.039886	 4.52864	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61782	 65791	 0.002457	 0.042764	 5.609	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61782	 65791	 0.002457	 0.042764	 5.609	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61782	 76696	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61782	 76696	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76697	 61782	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76697	 61782	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76696	 61783	 0.000679	 0.011964	 0.1281	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61783	 76698	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61783	 76698	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61784	 62103	 0.001286	 0.014571	 0.1328	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61784	 63483	 0.001186	 0.023929	 0.44654	 1737.0	 1823.85	 1910.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61784	 76699	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61784	 76699	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76700	 61784	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76700	 61784	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61784	 76911	 0.002	 0.022721	 0.20733	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61785	 63005	 0.001679	 0.015579	 0.06023	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61785	 76701	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61785	 76701	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76702	 61785	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76702	 61785	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61786	 61979	 0.02315	 0.12075	 0.03173	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61786	 61983	 0.013	 0.101229	 0.02633	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61786	 61984	 0.009343	 0.06765	 0.03644	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61786	 61994	 0.041257	 0.172314	 0.05396	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61786	 62059	 0.01345	 0.185536	 0.06731	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61786	 65669	 0.099843	 0.305471	 0.06753	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61786	 76703	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61786	 76703	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61787	 61789	 5.7e-05	 0.000964	 0.00976	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61787	 76704	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61787	 76704	 0.000529	 0.028567	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61788	 62983	 0.0057	 0.038036	 0.07178	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61788	 63088	 0.009421	 0.106586	 0.19704	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61788	 76706	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61788	 76706	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61789	 61790	 0.0	 1e-05	 3e-05	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76689	 61789	 0.000121	 0.001557	 0.02376	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61790	 61791	 4.3e-05	 0.000771	 0.01285	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76689	 61790	 0.000121	 0.001486	 0.02498	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61791	 62103	 0.000293	 0.003043	 0.04731	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61791	 62103	 0.000293	 0.003043	 0.04731	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61791	 76707	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61791	 76707	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61792	 61808	 0.000114	 0.001271	 0.01238	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61792	 63030	 0.00095	 0.010779	 0.09819	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61792	 76708	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61792	 76708	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61793	 62134	 0.001357	 0.017936	 0.28803	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61793	 76709	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61793	 76709	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61793	 76710	 0.0	 1e-05	 2e-05	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61794	 62107	 0.000421	 0.006636	 0.64582	 2588.0	 2717.4	 2846.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61794	 63297	 0.002129	 0.03015	 1.9815	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61794	 76710	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61794	 76710	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61795	 63088	 0.000329	 0.003436	 0.00646	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61795	 76713	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61795	 76713	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76714	 61795	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76714	 61795	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61795	 77237	 0.000214	 0.001343	 0.00281	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62520	 0.002771	 0.009807	 0.00221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62627	 0.001314	 0.00475	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62630	 0.001293	 0.003629	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62633	 0.000179	 0.000464	 0.00014	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62634	 0.001429	 0.0085	 0.00224	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62905	 0.002007	 0.008179	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62908	 0.003164	 0.013157	 0.00307	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 62916	 0.003279	 0.018843	 0.00534	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61796	 76715	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61796	 76715	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61797	 62030	 7.9e-05	 0.001043	 0.02239	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61797	 66016	 0.002236	 0.037986	 0.69769	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61797	 76716	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61797	 76716	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61798	 62640	 0.004443	 0.031693	 0.00983	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62737	 0.001471	 0.012593	 0.00359	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62738	 0.001121	 0.009764	 0.00268	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62750	 0.000729	 0.004329	 0.00114	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62754	 0.000607	 0.006893	 0.00266	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62775	 0.002543	 0.02255	 0.006	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62928	 0.003743	 0.023714	 0.00644	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62949	 0.000293	 0.003236	 0.00097	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62958	 0.003107	 0.011814	 0.00331	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62959	 0.002436	 0.008857	 0.00271	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 62980	 0.003121	 0.027214	 0.00747	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61798	 76717	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61798	 76717	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61799	 63050	 0.000379	 0.004493	 0.07849	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61799	 76718	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 0.98	 0.0	 1	 -30.0	 30.0;
	61799	 76718	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 0.98	 0.0	 1	 -30.0	 30.0;
	61800	 63386	 0.000114	 0.001236	 0.0118	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61800	 76719	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61800	 76719	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61800	 77240	 0.003057	 0.034771	 0.31828	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61801	 62545	 0.000107	 0.001871	 0.02004	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61801	 76721	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61801	 76721	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61801	 77040	 6.4e-05	 0.0007	 0.00682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61802	 63078	 0.000764	 0.002543	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61802	 63237	 0.002121	 0.005693	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61802	 63239	 0.005814	 0.017664	 0.00387	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61802	 76722	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61802	 76722	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61803	 62163	 0.0038	 0.02025	 0.00569	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61803	 62189	 0.000607	 0.0051	 0.00151	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61803	 62225	 0.000321	 0.004	 0.00129	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61803	 62237	 0.002557	 0.010564	 0.0025	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61803	 62255	 0.000114	 0.001414	 0.00044	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61803	 76723	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61803	 76723	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61804	 63058	 0.022321	 0.0538	 0.01519	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61804	 76724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61804	 76724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61805	 63055	 0.008571	 0.0262	 0.00566	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61806	 63436	 0.00125	 0.00455	 0.00139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61806	 63441	 0.001021	 0.004693	 0.0012	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61806	 76725	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61806	 76725	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61807	 62052	 0.024736	 0.1814	 0.05376	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61807	 63342	 0.003357	 0.018029	 0.00444	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61807	 63343	 0.000757	 0.00765	 0.00225	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61807	 63346	 0.005257	 0.029886	 0.00865	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61807	 63378	 0.009564	 0.043421	 0.01507	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61807	 76726	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61807	 76726	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61808	 76727	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61808	 76727	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76728	 61808	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76728	 61808	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61809	 63321	 0.0134	 0.0447	 0.01134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61810	 62694	 0.00055	 0.003586	 0.00704	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61810	 76729	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61810	 76729	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76730	 61810	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76730	 61810	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61811	 63236	 0.001571	 0.017329	 0.03293	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61811	 76731	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61811	 76731	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76732	 61811	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76732	 61811	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61812	 63003	 0.000364	 0.004957	 0.05051	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61812	 65153	 0.001929	 0.021186	 0.20622	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61812	 76733	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61812	 76733	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61813	 62089	 0.0054	 0.021229	 0.00556	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61813	 62799	 0.00985	 0.034836	 0.00785	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61813	 63397	 0.052214	 0.1907	 0.05869	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61813	 76736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61813	 76736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61814	 62046	 0.014371	 0.050807	 0.01145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61814	 62049	 0.026636	 0.101336	 0.02841	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61814	 62984	 0.023221	 0.113464	 0.03139	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61815	 62046	 0.019736	 0.085964	 0.02451	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61815	 62047	 0.037129	 0.09975	 0.02263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61815	 62640	 0.01705	 0.088457	 0.02161	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61815	 76737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61815	 76737	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61816	 63055	 0.0081	 0.027021	 0.00686	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61816	 63059	 0.0192	 0.065879	 0.01579	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61816	 76738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61816	 76738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61817	 63270	 0.001643	 0.005979	 0.00183	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61817	 76739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61817	 76739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61818	 61992	 0.005671	 0.01165	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61818	 76870	 0.121807	 0.2266	 0.00531	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61819	 63462	 0.000557	 0.005064	 0.00999	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61819	 76740	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61819	 76740	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76741	 61819	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76741	 61819	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61820	 63494	 0.002686	 0.04395	 0.43231	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61820	 76742	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61820	 76742	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61821	 61831	 0.000357	 0.006257	 0.59479	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61821	 61831	 0.000357	 0.006257	 0.59479	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61821	 76745	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61821	 76745	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61822	 76747	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61822	 76747	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61822	 76761	 0.002079	 0.021479	 0.33863	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61822	 76761	 0.002079	 0.021479	 0.33863	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61823	 64689	 0.0047	 0.064129	 0.13102	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76638	 61823	 0.006286	 0.066929	 0.12281	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61823	 76749	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61823	 76749	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61824	 64398	 0.000586	 0.009593	 0.14979	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61824	 76750	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61824	 76750	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61825	 64142	 0.001086	 0.017736	 0.00558	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61825	 76762	 0.000107	 0.001193	 0.0005	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61826	 61827	 0.008593	 0.038679	 0.01029	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61826	 64476	 0.013164	 0.031721	 0.00896	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61826	 64478	 0.021164	 0.088036	 0.02057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61826	 76784	 0.032314	 0.199421	 0.05783	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61827	 64664	 0.045679	 0.291586	 0.08004	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61827	 64728	 0.045829	 0.167229	 0.0514	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61828	 63646	 0.000586	 0.007086	 0.0137	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61828	 76751	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61828	 76751	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61828	 77438	 0.002179	 0.014129	 0.02814	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61829	 63514	 0.001386	 0.012329	 0.02166	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61829	 64689	 0.004279	 0.043386	 0.08749	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61829	 76752	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61829	 76752	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76753	 61829	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76753	 61829	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61830	 61849	 7.1e-05	 0.000329	 0.00011	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61830	 63769	 0.001679	 0.007657	 0.00243	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61830	 63822	 0.00425	 0.031229	 0.00791	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61830	 77373	 0.001493	 0.009014	 0.0023	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61831	 63749	 0.001786	 0.024836	 1.92336	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61831	 64384	 0.001536	 0.022357	 1.8205	 2385.0	 2504.25	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61831	 76754	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61831	 76754	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61832	 64713	 0.000457	 0.005143	 0.04686	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61832	 76756	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61832	 76756	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61833	 63990	 0.000971	 0.012493	 0.21259	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61833	 76759	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61833	 76759	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61834	 64561	 0.0278	 0.111414	 0.02811	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61834	 76760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61834	 76760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61835	 64137	 0.000179	 0.0026	 0.16739	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61835	 76761	 0.000154	 0.011578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61835	 76761	 0.000154	 0.011578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76762	 61835	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76762	 61835	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61836	 64243	 0.000471	 0.006129	 0.39166	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61836	 64384	 0.00055	 0.009443	 0.93786	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61836	 76763	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61836	 76763	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61837	 64536	 0.006664	 0.026686	 0.00672	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61837	 64538	 0.002736	 0.033314	 0.01101	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76743	 61837	 0.000143	 0.00155	 0.00044	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61838	 63578	 6.4e-05	 0.000736	 0.00637	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61838	 63907	 6.4e-05	 0.000893	 0.01439	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61838	 76766	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61838	 76766	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61839	 61840	 3.6e-05	 0.000286	 9e-05	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61839	 64257	 0.0013	 0.006136	 0.00196	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61839	 64376	 0.002607	 0.011871	 0.00376	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61840	 64257	 0.000914	 0.005864	 0.00197	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61840	 77520	 0.002536	 0.02105	 0.00554	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61841	 64489	 0.057779	 0.225843	 0.06071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61841	 64524	 0.030943	 0.109486	 0.0247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61841	 64638	 0.018979	 0.067529	 0.01502	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61841	 76767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61841	 76767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61842	 63829	 0.013507	 0.081107	 0.02459	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61842	 64222	 0.080593	 0.213864	 0.05029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61842	 64383	 0.01025	 0.042336	 0.01001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61842	 76768	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61842	 76768	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61843	 61867	 0.006321	 0.025729	 0.00627	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61843	 64526	 0.019093	 0.072614	 0.02034	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61843	 76769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61843	 76769	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61844	 64225	 0.014643	 0.057579	 0.01507	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61844	 64227	 0.012536	 0.030207	 0.00853	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61844	 76770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61844	 76770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61845	 64128	 0.034586	 0.138693	 0.03502	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61845	 64474	 0.017943	 0.0466	 0.01131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61845	 76771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61845	 76771	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61846	 63502	 0.00225	 0.00935	 0.00218	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61846	 63989	 0.005871	 0.020536	 0.00681	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61846	 76772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61846	 76772	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61847	 63741	 0.009221	 0.121064	 0.03454	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61847	 63741	 0.009221	 0.121064	 0.03454	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61847	 76773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61847	 76773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61848	 61861	 4.3e-05	 0.000286	 9e-05	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61848	 63614	 0.000279	 0.002643	 0.00077	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61849	 63766	 0.001179	 0.004893	 0.00153	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61850	 64381	 0.029993	 0.0779	 0.01892	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61850	 64730	 0.072814	 0.187793	 0.04668	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61850	 76774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61850	 76774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61851	 76786	 0.01455	 0.0566	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61851	 77581	 0.04265	 0.125436	 0.00257	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61852	 64078	 0.006579	 0.011571	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61852	 64080	 0.017379	 0.019114	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61852	 64087	 0.018171	 0.014957	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61852	 77468	 0.007543	 0.010286	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61853	 63508	 0.006886	 0.055921	 0.01781	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61853	 64693	 0.001071	 0.015471	 0.00491	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61853	 64694	 0.000807	 0.00515	 0.00173	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61853	 64696	 0.001357	 0.014407	 0.00428	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61854	 64380	 0.010414	 0.027043	 0.00656	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61854	 64381	 0.02035	 0.052329	 0.01296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61855	 64694	 0.000264	 0.001314	 0.00034	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61855	 76775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61855	 76775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61856	 64101	 0.000429	 0.001729	 0.00044	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61856	 64102	 0.001529	 0.0063	 0.00149	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61856	 64108	 0.00075	 0.003507	 0.00087	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61856	 76776	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61856	 76776	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61857	 64451	 0.087536	 0.147486	 0.0021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61857	 64465	 0.005971	 0.012214	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61857	 64466	 0.017243	 0.058907	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61858	 64234	 0.023579	 0.08585	 0.02631	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61858	 64528	 0.029186	 0.070364	 0.01988	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61858	 76777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61858	 76777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61859	 63800	 0.012914	 0.044307	 0.01061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61859	 64455	 0.0062	 0.016636	 0.00377	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61859	 76778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61859	 76778	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61860	 63860	 0.0003	 0.001021	 0.00024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61860	 63878	 0.00065	 0.002121	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61861	 63870	 0.001686	 0.006871	 0.00167	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61861	 63872	 0.000371	 0.003386	 0.00111	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61861	 77328	 0.000364	 0.00325	 0.00085	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61862	 64447	 0.032993	 0.101214	 0.00274	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61862	 64451	 0.032379	 0.064114	 0.00094	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61863	 64144	 0.001343	 0.011707	 0.00464	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61863	 64594	 0.011464	 0.082529	 0.02189	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61863	 64609	 0.008193	 0.040393	 0.01092	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76762	 61863	 0.001714	 0.01895	 0.00569	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61863	 76779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61863	 76779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61864	 64661	 0.002586	 0.0124	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61865	 63751	 0.000843	 0.002129	 4e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61865	 63752	 0.002357	 0.005979	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61866	 77581	 0.020864	 0.052843	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61867	 63844	 0.022129	 0.092057	 0.02151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61867	 76780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61867	 76780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61868	 64116	 0.001064	 0.007486	 0.01274	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61868	 76781	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61868	 76781	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61868	 77466	 0.0016	 0.01065	 0.02007	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61869	 63835	 0.036986	 0.099579	 0.02796	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61869	 64238	 0.100414	 0.275093	 0.06106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61869	 64621	 0.026807	 0.069629	 0.01691	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61869	 76782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61869	 76782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61870	 64498	 0.090221	 0.063914	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61870	 64501	 0.008621	 0.024729	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61871	 77578	 0.129629	 0.266536	 0.00509	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61872	 64062	 0.314421	 0.259079	 0.00525	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61872	 64230	 0.060543	 0.206864	 0.0045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61872	 77618	 0.125807	 0.1475	 0.00256	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61873	 64209	 0.024186	 0.017136	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61873	 64210	 0.003607	 0.009143	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61873	 64215	 0.009593	 0.0068	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61874	 64505	 0.006914	 0.031729	 0.00813	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61874	 64506	 0.006829	 0.027786	 0.00677	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61874	 64619	 0.050371	 0.230957	 0.07388	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61874	 76783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61874	 76783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61875	 64562	 0.030164	 0.086521	 0.00133	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61875	 64563	 0.192907	 0.308214	 0.00711	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61875	 64564	 0.060957	 0.141536	 0.00211	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76742	 61876	 0.000421	 0.00415	 0.00884	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61876	 76784	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61876	 76784	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76785	 61876	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76785	 61876	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61877	 64570	 0.005407	 0.013686	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61877	 64580	 0.023393	 0.015143	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61877	 77611	 0.003321	 0.004836	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61878	 64478	 0.048679	 0.117479	 0.03323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61878	 64554	 0.071443	 0.192393	 0.04376	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61878	 64731	 0.071186	 0.260907	 0.08066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61878	 76786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61878	 76786	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61879	 77534	 0.009686	 0.019171	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61880	 65792	 2.1e-05	 0.00025	 0.00244	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61880	 65793	 0.000157	 0.003436	 0.05547	 1737.0	 1823.85	 1910.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61880	 76787	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61880	 76787	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61880	 77559	 0.011171	 0.130186	 2.41507	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61880	 77559	 0.011171	 0.130186	 2.41507	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61881	 65707	 0.018993	 0.087193	 0.02236	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61881	 65719	 0.000543	 0.00545	 0.00334	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61881	 76789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61881	 76789	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61882	 65601	 0.023229	 0.125014	 0.03081	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61882	 65603	 0.042486	 0.214329	 0.0561	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61882	 65605	 0.025571	 0.11745	 0.03014	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61883	 65656	 0.003986	 0.037979	 0.72464	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61883	 65656	 0.003986	 0.037979	 0.72464	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61883	 76790	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61883	 76790	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61884	 65791	 0.000107	 0.002971	 0.22248	 3031.0	 3182.55	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61884	 76792	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61884	 76792	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61885	 65654	 0.00885	 0.099121	 1.60686	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61885	 65654	 0.00885	 0.099121	 1.60686	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61885	 76796	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61885	 76796	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61886	 65609	 0.006057	 0.078579	 0.17926	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61886	 76798	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61886	 76798	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76799	 61886	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76799	 61886	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61887	 65879	 0.026086	 0.15695	 0.04769	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61887	 65905	 0.002764	 0.01365	 0.00369	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61887	 65907	 0.001493	 0.007757	 0.00189	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61887	 76800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61887	 76800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61888	 65465	 0.001171	 0.0091	 0.00236	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61888	 65523	 0.002043	 0.008421	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61888	 77853	 0.001329	 0.01	 0.00277	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61889	 61894	 0.002421	 0.010607	 0.00365	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61889	 65655	 0.034671	 0.193107	 0.05902	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61889	 65685	 0.006964	 0.06215	 0.01632	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61889	 76801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61889	 76801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61890	 65572	 0.067771	 0.222093	 0.05932	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61890	 65753	 0.019764	 0.076943	 0.02056	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61890	 76802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61890	 76802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61891	 65564	 0.027679	 0.1078	 0.02884	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61891	 76803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61891	 76803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61892	 65579	 0.022757	 0.162057	 0.28213	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61892	 76804	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61892	 76804	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61893	 65667	 0.015857	 0.051729	 0.01374	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61893	 65818	 0.076971	 0.221757	 0.05486	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61893	 65820	 0.065421	 0.152279	 0.04654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61894	 65684	 0.016807	 0.131243	 0.03934	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76790	 61894	 0.0006	 0.003843	 0.00129	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61895	 65664	 0.004957	 0.0624	 0.01934	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61895	 65664	 0.004957	 0.0624	 0.01934	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61895	 65702	 0.052879	 0.1442	 0.03184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61895	 76805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61895	 76805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61896	 65640	 0.002879	 0.012943	 0.00344	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61896	 65642	 0.009443	 0.078407	 0.02064	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61896	 76806	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61896	 76806	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61897	 65635	 0.064736	 0.365471	 0.09493	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61897	 65666	 0.015221	 0.054179	 0.01205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61897	 65670	 0.01185	 0.043121	 0.01321	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61897	 76807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61897	 76807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61898	 65662	 0.042936	 0.113814	 0.00289	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61898	 77902	 0.19305	 0.3594	 0.00842	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61899	 65755	 0.009579	 0.081529	 0.00213	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61899	 65775	 0.010829	 0.100843	 0.00195	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61899	 65780	 0.016914	 0.059221	 0.00164	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61899	 65780	 0.016914	 0.059221	 0.00164	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61900	 65488	 0.002136	 0.006971	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61900	 65510	 0.001364	 0.005464	 0.00138	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61900	 77849	 0.000386	 0.001679	 0.00058	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61901	 65782	 0.000657	 0.006136	 0.0019	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61901	 65790	 0.000229	 0.002579	 0.00145	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61901	 65813	 0.005479	 0.084507	 0.04714	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61902	 65892	 0.092664	 0.274964	 0.06448	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61902	 76808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61902	 76808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61902	 77876	 0.033171	 0.117386	 0.02649	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61903	 65801	 0.007586	 0.036807	 0.00841	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61903	 65802	 0.001771	 0.006729	 0.00189	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61904	 65748	 0.025407	 0.092507	 0.02836	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61904	 65801	 0.016529	 0.051679	 0.01497	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61904	 76809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61904	 76809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61905	 65872	 0.017064	 0.043221	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61905	 65874	 0.167579	 0.294914	 0.00554	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61906	 65782	 0.000186	 0.00225	 0.00061	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61906	 65790	 0.00065	 0.006807	 0.00187	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61907	 65816	 0.011507	 0.018364	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61907	 65817	 0.021571	 0.02835	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61907	 65821	 0.038886	 0.030779	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61908	 65740	 0.012214	 0.057829	 0.01391	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61909	 65149	 0.001	 0.017407	 1.64693	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61909	 72313	 0.00182	 0.05144	 4.892	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61909	 76810	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61909	 76810	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61909	 79866	 0.00087	 0.02107	 1.447	 2144.0	 2566.0	 2598.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61910	 64760	 0.001136	 0.007721	 0.01406	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61910	 65019	 0.000229	 0.001543	 0.00284	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61910	 76814	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61910	 76814	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76815	 61910	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76815	 61910	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61911	 65258	 0.0043	 0.045871	 0.48372	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61911	 76816	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61911	 76816	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61912	 65250	 0.018871	 0.162271	 0.04634	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61912	 65259	 0.023936	 0.188079	 0.04839	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61912	 76817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61912	 76817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61913	 61921	 0.000307	 0.005364	 0.47656	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61913	 65149	 0.000321	 0.003843	 0.28866	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61913	 76818	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61913	 76818	 0.000196	 0.013749	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76819	 61913	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	76819	 61913	 0.000432	 0.034597	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	61913	 79862	 0.002057	 0.039557	 2.75893	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76818	 61914	 0.00015	 0.001721	 0.01831	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61914	 76820	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61914	 76820	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61914	 77737	 0.001129	 0.012364	 0.12016	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61915	 65153	 0.001007	 0.017179	 0.17446	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61915	 65181	 0.001321	 0.017921	 0.1871	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61915	 76822	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61915	 76822	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61916	 65149	 0.000371	 0.004657	 0.31931	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61916	 76823	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61916	 79863	 0.002007	 0.035521	 2.91157	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61917	 61929	 7.1e-05	 0.000779	 0.00148	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61917	 64889	 0.00405	 0.0334	 0.06891	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61917	 76824	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61917	 76824	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61918	 65091	 0.000414	 0.00765	 0.14107	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61918	 76825	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61918	 76825	 0.000125	 0.009999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76826	 61918	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76826	 61918	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61918	 77737	 0.001121	 0.015907	 0.15058	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61919	 65266	 0.005543	 0.054943	 0.01684	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61919	 76834	 0.000164	 0.001157	 0.00068	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61920	 65269	 0.011264	 0.043829	 0.01171	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61920	 65272	 0.015607	 0.073893	 0.01778	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61920	 65274	 0.00735	 0.020136	 0.00438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61920	 77659	 0.017093	 0.071193	 0.02221	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61920	 77820	 0.027821	 0.1115	 0.02813	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61921	 65263	 0.001636	 0.028336	 3.06314	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61921	 76827	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61921	 76827	 0.000137	 0.010999	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76828	 61921	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76828	 61921	 0.000324	 0.024331	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61922	 65091	 0.000164	 0.001936	 0.01676	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61922	 65218	 0.000286	 0.003543	 0.05675	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61922	 76829	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61922	 76829	 0.000157	 0.011764	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76830	 61922	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76830	 61922	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61923	 61926	 2.9e-05	 0.0002	 0.00037	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61923	 65075	 4.3e-05	 0.000307	 0.00062	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61924	 65207	 0.012486	 0.071636	 0.02383	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61924	 65225	 0.010864	 0.043493	 0.0147	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76819	 61924	 0.003493	 0.014414	 0.00341	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61924	 77738	 0.023243	 0.065221	 0.01679	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61925	 61929	 0.000321	 0.002143	 0.00404	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61925	 65152	 0.004471	 0.067136	 0.15786	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61925	 65156	 0.001286	 0.010736	 0.02148	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61925	 76831	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61925	 76831	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61926	 76832	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61926	 76832	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61927	 61937	 7e-06	 0.000136	 0.00867	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61927	 76833	 0.000212	 0.016922	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61927	 76833	 0.000212	 0.016922	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76834	 61927	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	76834	 61927	 0.000618	 0.043246	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	61928	 65287	 0.069993	 0.185543	 0.04359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61928	 76835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61928	 76835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61929	 76836	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61929	 76836	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61930	 64732	 0.016479	 0.091493	 0.02784	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61930	 64734	 0.01185	 0.053371	 0.01421	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61930	 76837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61930	 76837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61931	 65096	 0.002357	 0.006229	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61931	 65125	 0.0011	 0.004271	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61931	 65128	 0.003514	 0.008471	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61931	 76838	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61931	 76838	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61932	 64737	 0.001979	 0.010314	 0.00271	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61932	 65287	 0.048164	 0.201407	 0.06318	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61933	 61934	 0.001657	 0.005521	 9e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61933	 65300	 0.012371	 0.01895	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61933	 65301	 0.050557	 0.032729	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61933	 65303	 0.016857	 0.057586	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61934	 65332	 0.045786	 0.044979	 0.00076	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61934	 65374	 0.091607	 0.082093	 0.00168	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61935	 64734	 0.007821	 0.02725	 0.00632	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61935	 64735	 0.010343	 0.04895	 0.01177	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61935	 65265	 0.0266	 0.080821	 0.01771	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61935	 76839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61935	 76839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61935	 77780	 0.015579	 0.06945	 0.01889	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61936	 64737	 0.007629	 0.023393	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61936	 64737	 0.007629	 0.023393	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61937	 65288	 0.000136	 0.001886	 0.14267	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61937	 76840	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61937	 76840	 0.000915	 0.04942	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61938	 64733	 0.079814	 0.2452	 0.0046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61939	 77778	 0.140679	 0.414221	 0.00851	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61940	 65225	 0.005029	 0.019571	 0.00523	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61940	 76841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61940	 76841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61941	 65021	 0.006686	 0.034771	 0.01024	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76819	 61941	 0.002864	 0.010021	 0.00332	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61942	 65259	 0.043136	 0.164393	 0.04618	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61942	 65260	 0.022221	 0.0809	 0.02479	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61942	 65287	 0.035586	 0.148507	 0.04646	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61942	 65381	 0.080086	 0.323643	 0.08257	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61943	 65300	 0.050357	 0.03985	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61943	 65374	 0.106236	 0.075257	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61943	 65375	 0.008579	 0.019629	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61944	 61950	 0.0007	 0.011829	 1.233	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61944	 61950	 0.0007	 0.011829	 1.233	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61944	 66278	 0.000814	 0.013736	 1.34807	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61944	 76842	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61944	 76842	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76843	 61944	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76843	 61944	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61950	 61945	 0.002436	 0.031832	 2.0652	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61945	 76844	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61945	 76844	 0.000209	 0.014665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76845	 61945	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76845	 61945	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61946	 64490	 0.030293	 0.287579	 0.08819	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61946	 64620	 0.018814	 0.115807	 0.03346	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61946	 66012	 0.031157	 0.179329	 0.05991	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61946	 66289	 0.010057	 0.068564	 0.02337	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61946	 66290	 0.028114	 0.106979	 0.02999	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61947	 66362	 0.002614	 0.041914	 0.42738	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76844	 61947	 0.000864	 0.009493	 0.09224	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61947	 76846	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61947	 76846	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61948	 66033	 0.077564	 0.20575	 0.04837	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61948	 66034	 0.012179	 0.117114	 0.03414	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76843	 61948	 0.028057	 0.357743	 0.11305	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76843	 61948	 0.028057	 0.357743	 0.11305	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61948	 76861	 0.002293	 0.025907	 0.00998	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61948	 76861	 0.002293	 0.025907	 0.00998	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61949	 66174	 0.00125	 0.013664	 0.13424	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	61949	 66358	 0.000457	 0.005564	 0.05396	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61949	 76848	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61949	 76848	 0.000296	 0.02222	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76849	 61949	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76849	 61949	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61950	 66006	 0.001379	 0.016579	 1.25629	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61950	 76850	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61950	 76850	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76852	 61950	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76852	 61950	 0.000309	 0.021623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61951	 65953	 0.014429	 0.038743	 0.00878	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61951	 65954	 0.040664	 0.105679	 0.02568	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61951	 66010	 0.069493	 0.189764	 0.04196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61951	 66423	 0.043807	 0.182571	 0.04277	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61951	 76853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61951	 76853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61952	 66045	 2.9e-05	 0.000307	 0.00524	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61952	 66065	 6.4e-05	 0.001086	 0.01074	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61952	 76854	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61952	 76854	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61953	 65955	 0.004957	 0.019836	 0.005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61953	 66266	 0.092836	 0.357464	 0.10179	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75590	 61953	 0.079736	 0.275321	 0.06652	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61954	 65964	 0.035871	 0.139807	 0.03744	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61954	 66288	 0.010371	 0.049571	 0.01736	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61955	 66217	 5e-05	 0.000864	 0.00844	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61955	 66244	 0.000221	 0.003407	 0.03821	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61955	 76856	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61955	 76856	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61956	 66112	 0.001486	 0.006693	 0.00178	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61956	 66118	 0.002314	 0.005379	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61956	 66121	 0.000679	 0.002279	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61956	 66123	 0.000993	 0.003507	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61956	 76858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61956	 76858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61956	 78041	 0.0069	 0.0251	 0.00769	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61957	 66439	 8.6e-05	 0.000886	 0.00169	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	61957	 76859	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61957	 76859	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76860	 61957	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76860	 61957	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61958	 66237	 0.0029	 0.011964	 0.00283	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61958	 66238	 0.006179	 0.025671	 0.00599	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61958	 78061	 0.002636	 0.01725	 0.00439	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61959	 66021	 0.002643	 0.027386	 0.43276	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61959	 66021	 0.002643	 0.027386	 0.43276	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66259	 61959	 0.002243	 0.04035	 0.93929	 1959.0	 2056.95	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61959	 76861	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61959	 76861	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61960	 65914	 0.0183	 0.125629	 0.00229	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61960	 65924	 0.068979	 0.269521	 0.00598	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61960	 65924	 0.068979	 0.269521	 0.00598	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61960	 65925	 0.188757	 0.133743	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61960	 77975	 0.03085	 0.120493	 0.00267	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61960	 77975	 0.03085	 0.120493	 0.00267	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61961	 78108	 0.013557	 0.023843	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61961	 78110	 0.013293	 0.012	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61961	 78111	 0.015221	 0.012529	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61962	 66048	 0.003486	 0.021121	 0.00066	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61962	 78009	 0.001829	 0.00485	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61962	 78010	 0.0049	 0.029364	 0.00071	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61962	 78011	 0.019221	 0.018879	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61963	 61964	 0.039093	 0.11885	 0.02606	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61963	 63046	 0.031314	 0.0879	 0.02264	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61964	 61966	 0.011443	 0.101514	 0.02706	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61964	 65808	 0.015271	 0.151821	 0.04141	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61964	 76862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61964	 76862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61965	 61968	 0.014943	 0.092936	 0.02626	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61965	 61971	 0.042321	 0.172657	 0.04221	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61965	 65709	 0.017007	 0.068121	 0.01717	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61965	 76863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61965	 76863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61966	 61968	 0.014486	 0.074029	 0.01864	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61966	 76864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61966	 76864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61967	 61968	 0.011393	 0.044793	 0.01172	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61967	 61969	 0.012579	 0.051207	 0.01248	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61969	 63040	 0.065486	 0.250479	 0.0707	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61969	 63046	 0.025436	 0.167857	 0.04224	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61969	 76865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61969	 76865	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61970	 61972	 0.108486	 0.201793	 0.00472	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61970	 76866	 0.144364	 0.268614	 0.00629	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 61971	 0.055914	 0.218493	 0.05871	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61971	 76866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61971	 76866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76863	 61972	 0.05355	 0.2373	 0.00541	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61972	 77919	 0.0636	 0.195186	 0.00529	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61973	 65711	 0.0188	 0.0753	 0.01898	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 61973	 0.028564	 0.364436	 0.11526	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 61973	 0.028564	 0.364436	 0.11526	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61973	 76867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61973	 76867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61974	 61975	 0.029471	 0.118136	 0.02981	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61974	 65704	 0.026479	 0.109421	 0.02592	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61975	 63048	 0.010764	 0.115529	 0.03701	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76698	 61975	 0.004071	 0.050529	 0.0219	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76697	 61976	 0.002414	 0.0209	 0.0075	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76698	 61976	 0.006736	 0.061436	 0.02234	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76696	 61977	 0.000857	 0.0106	 0.09826	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61977	 76868	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61977	 76868	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61978	 62053	 0.032121	 0.194886	 0.04996	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61978	 62064	 0.034764	 0.1649	 0.03977	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61978	 63062	 0.021921	 0.103836	 0.025	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76868	 61978	 0.00375	 0.052136	 0.02867	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61979	 65670	 0.051443	 0.176943	 0.04254	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61980	 61981	 0.214314	 0.138807	 0.00264	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61981	 62061	 0.379729	 0.4726	 0.01031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61981	 62062	 0.398871	 0.545643	 0.00977	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76703	 61981	 0.023371	 0.169307	 0.00425	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76703	 61982	 0.040186	 0.072514	 0.00105	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61983	 61984	 0.004914	 0.0203	 0.00481	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61983	 61985	 0.016979	 0.064564	 0.01809	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61983	 61996	 0.018057	 0.074579	 0.01766	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	61983	 63181	 0.028371	 0.130343	 0.03346	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61984	 63181	 0.031721	 0.148229	 0.03681	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	61984	 76869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61984	 76869	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61985	 63169	 0.021714	 0.074521	 0.01786	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61986	 61993	 0.06415	 0.2247	 0.00622	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76703	 61986	 0.0569	 0.265464	 0.00611	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76869	 61986	 0.089979	 0.258157	 0.00397	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61987	 61988	 0.108757	 0.246814	 0.00493	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76703	 61987	 0.187671	 0.62745	 0.00997	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61988	 61989	 0.066579	 0.073229	 0.00098	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61989	 61990	 0.028179	 0.02525	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61990	 61991	 0.034779	 0.052136	 0.00095	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61991	 61992	 0.0072	 0.015136	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	61993	 76870	 0.303179	 0.196436	 0.00374	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	61993	 76871	 0.040043	 0.11775	 0.00241	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61994	 62004	 0.030707	 0.108636	 0.02451	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	61994	 76870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61994	 76870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61995	 62002	 0.024736	 0.062214	 0.01612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61995	 62004	 0.019836	 0.04605	 0.01403	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61995	 76871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61995	 76871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61996	 61997	 0.010914	 0.029907	 0.0065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61996	 63381	 0.034079	 0.079164	 0.02414	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61996	 76872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61996	 76872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	61997	 62000	 0.005286	 0.012736	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	61998	 76876	 0.046886	 0.092836	 0.00136	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61999	 76873	 0.011129	 0.017757	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61999	 76876	 0.039914	 0.028279	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62000	 62001	 0.001593	 0.004129	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62001	 62002	 0.001529	 0.004186	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62001	 62004	 0.00885	 0.021329	 0.00602	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62001	 76873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62001	 76873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62002	 62006	 0.002936	 0.006807	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62002	 76874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62002	 76874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62003	 62005	 0.020086	 0.02355	 0.00041	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76874	 62003	 0.0238	 0.024043	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62003	 76876	 0.015329	 0.024471	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62004	 76875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62004	 76875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62005	 62009	 0.111886	 0.079257	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76875	 62005	 0.031664	 0.050543	 0.00116	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62006	 76876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62006	 76876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62007	 62008	 0.034729	 0.028586	 0.00058	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62007	 62010	 0.095386	 0.085479	 0.00175	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76876	 62007	 0.02105	 0.04815	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76871	 62009	 0.196129	 0.15525	 0.00196	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76872	 62009	 0.411114	 0.291593	 0.00461	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62011	 62012	 0.0018	 0.007471	 0.00174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62011	 62022	 0.004343	 0.011893	 0.00259	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62011	 62031	 0.021014	 0.087564	 0.02734	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62011	 76877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62011	 76877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62012	 62018	 0.002293	 0.009321	 0.00227	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62013	 62014	 0.016357	 0.014657	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76877	 62013	 0.026	 0.045729	 0.00086	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62013	 76879	 0.007143	 0.016336	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62015	 62018	 0.001179	 0.0145	 0.00469	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62015	 62025	 0.003057	 0.046736	 0.01506	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62015	 76878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62015	 76878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76878	 62016	 0.005314	 0.034264	 0.00109	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62016	 76879	 0.006843	 0.053343	 0.001	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62017	 76879	 0.014543	 0.009414	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62018	 62019	 0.003079	 0.013414	 0.00382	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62018	 62020	 0.002093	 0.008707	 0.00271	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62018	 62022	 0.002679	 0.014429	 0.00396	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62018	 62025	 0.004007	 0.059314	 0.02043	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62018	 62027	 0.019157	 0.08345	 0.02379	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62018	 76879	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62018	 76879	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62018	 77186	 0.042671	 0.282857	 0.07163	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62019	 62020	 0.0024	 0.0084	 0.00279	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62019	 63426	 0.0161	 0.092579	 0.02626	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62020	 62022	 0.001907	 0.006657	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62021	 76880	 0.003136	 0.019271	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62021	 76881	 0.042129	 0.22555	 0.00684	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62022	 62028	 0.022371	 0.11065	 0.03237	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62022	 76880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62022	 76880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76877	 62023	 0.010029	 0.023286	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76880	 62023	 0.023886	 0.02155	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76878	 62024	 0.077564	 0.054943	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62025	 62037	 0.007471	 0.094614	 0.04897	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 62025	 0.0519	 0.262386	 0.06887	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62026	 62040	 0.02385	 0.124414	 0.03269	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62026	 63051	 0.034179	 0.134543	 0.03527	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62026	 77186	 0.036486	 0.159193	 0.04551	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62027	 63425	 0.004386	 0.024321	 0.00739	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62027	 76881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62027	 76881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62028	 63432	 0.029229	 0.171671	 0.04694	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62029	 66031	 0.0164	 0.1863	 0.07219	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62029	 66031	 0.0164	 0.1863	 0.07219	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62029	 76882	 0.017393	 0.227471	 0.06622	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62029	 76882	 0.017393	 0.227471	 0.06622	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76693	 62030	 0.000143	 0.001721	 0.04296	 1646.0	 1728.3	 1810.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62030	 76882	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62030	 76882	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62031	 62032	 0.019421	 0.245814	 0.07686	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62031	 62032	 0.019421	 0.245814	 0.07686	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62031	 77186	 0.047886	 0.348293	 0.09377	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62032	 62991	 0.023393	 0.302414	 0.09151	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62032	 62991	 0.023393	 0.302414	 0.09151	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76693	 62033	 0.001229	 0.011129	 0.22748	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62033	 76883	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62033	 76883	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76694	 62034	 0.00305	 0.035936	 0.06639	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62034	 76884	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62034	 76884	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62035	 62037	 0.005036	 0.071564	 0.03769	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62035	 62038	 0.001093	 0.015179	 0.01046	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62035	 76885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62035	 76885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76885	 62036	 0.261479	 0.324979	 0.00709	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76883	 62038	 0.005321	 0.073857	 0.05101	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62039	 76886	 0.296714	 0.192243	 0.00366	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62040	 62043	 0.005007	 0.023879	 0.00691	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62041	 62043	 0.005107	 0.026493	 0.00647	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62041	 62076	 0.03715	 0.149014	 0.03764	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62041	 76886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62041	 76886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76886	 62042	 0.046557	 0.136936	 0.00281	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62042	 76899	 0.143643	 0.422971	 0.00869	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76886	 62044	 0.040757	 0.10325	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62044	 76887	 0.053879	 0.1841	 0.00401	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62045	 62046	 0.015514	 0.077971	 0.02031	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62045	 63059	 0.020729	 0.124621	 0.03782	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62045	 76887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62045	 76887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62047	 62050	 0.017271	 0.048457	 0.01247	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62048	 63332	 0.078929	 0.209286	 0.00531	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62048	 76888	 0.070064	 0.239443	 0.00521	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62048	 76889	 0.036986	 0.06505	 0.00122	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62048	 76890	 0.064943	 0.088529	 0.00196	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62049	 62050	 0.0118	 0.0576	 0.01591	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62049	 62053	 0.009586	 0.096107	 0.03204	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62049	 76888	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62049	 76888	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62050	 62052	 0.026579	 0.078407	 0.01825	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62050	 76889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62050	 76889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62051	 62052	 0.019657	 0.052779	 0.01196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62051	 76890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62051	 76890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62053	 63053	 0.026571	 0.119786	 0.03193	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62053	 76891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62053	 76891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62054	 62055	 0.277043	 0.48815	 0.00919	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76888	 62054	 0.107521	 0.246029	 0.00601	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76891	 62054	 0.094257	 0.420443	 0.00715	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62055	 62056	 0.405343	 0.409993	 0.00543	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62056	 62062	 0.119243	 0.316343	 0.00804	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62056	 76892	 0.079843	 0.18265	 0.00446	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62057	 76892	 0.050279	 0.049393	 0.00084	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62058	 62060	 0.103729	 0.067157	 0.00128	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62059	 62063	 0.011907	 0.045257	 0.01267	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62059	 76892	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62059	 76892	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76892	 62060	 0.009836	 0.019471	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62061	 62066	 0.136064	 0.278657	 0.00686	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62062	 63377	 0.167014	 0.382479	 0.00935	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62063	 62065	 0.012557	 0.052193	 0.01219	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62064	 62065	 0.025821	 0.122364	 0.02947	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62065	 76893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62065	 76893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62066	 65660	 0.185379	 0.430843	 0.00641	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76893	 62066	 0.095836	 0.254157	 0.00645	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62067	 62069	 0.017557	 0.124371	 0.0342	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62067	 62071	 0.008686	 0.125586	 0.03997	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62067	 62074	 0.0171	 0.164607	 0.04806	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62067	 66782	 0.021514	 0.16525	 0.04442	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76700	 62067	 0.016457	 0.21175	 0.06363	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76700	 62067	 0.016457	 0.21175	 0.06363	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62067	 76894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62067	 76894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62067	 76900	 0.015064	 0.190186	 0.05924	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62068	 76895	 0.0265	 0.131514	 0.00314	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62068	 76898	 0.019864	 0.092629	 0.00213	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62069	 63026	 0.012721	 0.062857	 0.01836	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62069	 76895	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62069	 76895	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76894	 62070	 0.057886	 0.311129	 0.00739	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62070	 76896	 0.044093	 0.250729	 0.00454	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62071	 62072	 0.037736	 0.156107	 0.03704	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62071	 62074	 0.011714	 0.055864	 0.01619	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62071	 71761	 0.007829	 0.09335	 0.02621	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62071	 76896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62071	 76896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62072	 71761	 0.011343	 0.0705	 0.01991	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62072	 76897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62072	 76897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62072	 77292	 0.019893	 0.237821	 0.08364	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62072	 77292	 0.019893	 0.237821	 0.08364	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62072	 78277	 0.020536	 0.260193	 0.08144	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62072	 78277	 0.020536	 0.260193	 0.08144	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62073	 62074	 0.008136	 0.067743	 0.02053	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62073	 63017	 0.016443	 0.098029	 0.02582	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62073	 66782	 0.011664	 0.053543	 0.01372	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62073	 76898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62073	 76898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62074	 71772	 0.019171	 0.212986	 0.06431	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62075	 62076	 0.010693	 0.04065	 0.01138	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62075	 62572	 0.006243	 0.025786	 0.0061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62076	 76899	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62076	 76899	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62077	 62078	 0.074907	 0.053064	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62077	 62829	 0.026957	 0.047407	 0.00089	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62078	 62806	 0.113886	 0.073736	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62079	 62085	 0.003007	 0.027814	 0.05237	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62079	 76900	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62079	 76900	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62079	 76937	 0.007686	 0.053764	 0.09251	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62080	 62084	 0.014107	 0.017507	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62080	 62113	 0.010636	 0.024329	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 62080	 0.173457	 0.511071	 0.0105	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62080	 76901	 0.029793	 0.021107	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62081	 62101	 0.001307	 0.003457	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62081	 76901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62081	 76901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62082	 62092	 0.000957	 0.003957	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62082	 62094	 0.00235	 0.006221	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62082	 76902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62082	 76902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76692	 62083	 0.170121	 0.501207	 0.0103	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76901	 62083	 0.018821	 0.022064	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76902	 62083	 0.023886	 0.021407	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62083	 76906	 0.005979	 0.020414	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 62084	 0.176557	 0.520236	 0.01069	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62084	 76906	 0.005064	 0.015543	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76699	 62085	 0.002643	 0.0371	 0.07123	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62086	 62104	 0.061064	 0.173321	 0.00272	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 62086	 0.090964	 0.310957	 0.00677	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 62087	 0.1495	 0.396821	 0.01009	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62087	 76903	 0.026843	 0.143036	 0.00251	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62087	 76907	 0.058214	 0.115264	 0.00169	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62087	 76939	 0.38495	 0.249543	 0.00475	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62088	 62089	 0.010021	 0.038107	 0.01067	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76900	 62088	 0.013179	 0.054879	 0.01712	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62088	 76903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62088	 76903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62089	 62093	 0.0098	 0.040471	 0.00958	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62089	 76904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62089	 76904	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62090	 62091	 0.023871	 0.05415	 0.00108	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76904	 62090	 0.059514	 0.089236	 0.00162	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62091	 76906	 0.005786	 0.032871	 0.00059	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62091	 77143	 0.0396	 0.063529	 0.00117	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62092	 62093	 0.001821	 0.006621	 0.00203	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62092	 76905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62092	 76905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62093	 76906	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62093	 76906	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62094	 62095	 0.001979	 0.005414	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62094	 76907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62094	 76907	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62095	 62097	 0.001614	 0.004064	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62096	 62135	 0.010179	 0.015264	 0.00028	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62096	 76908	 0.041979	 0.03455	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62097	 62136	 0.001629	 0.004807	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62098	 62101	 0.003436	 0.008279	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62098	 62136	 0.0027	 0.007129	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62098	 76908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62098	 76908	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76902	 62099	 0.022157	 0.015693	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76907	 62099	 0.028164	 0.025407	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76908	 62099	 0.011357	 0.0174	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76908	 62100	 0.02335	 0.021064	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62100	 76930	 0.0225	 0.0178	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62101	 62138	 0.00175	 0.004543	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76699	 62102	 0.00155	 0.017386	 0.03182	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76704	 62102	 0.0014	 0.011607	 0.03661	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62103	 62106	 0.000179	 0.004036	 0.0773	 1921.0	 2017.05	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62104	 76931	 0.075114	 0.190314	 0.00377	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62105	 76914	 0.020114	 0.067114	 0.00106	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62105	 76923	 0.021193	 0.054486	 0.00084	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62106	 76909	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62106	 76909	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62106	 76910	 0.000107	 0.002279	 0.03866	 1737.0	 1823.85	 1910.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62107	 62108	 2.9e-05	 0.000593	 0.04263	 2354.0	 2471.7	 2589.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62107	 66610	 0.00274	 0.05584	 4.268	 2015.0	 2015.0	 2015.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62107	 66610	 0.00274	 0.05584	 4.268	 2015.0	 2015.0	 2015.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62107	 66610	 0.002414	 0.044121	 5.13657	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 0	 -30.0	 30.0;
	62107	 76910	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	62107	 76910	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	62107	 76910	 8.3e-05	 0.006666	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	62108	 62451	 0.000314	 0.004943	 0.36689	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62108	 76911	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76912	 62108	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62109	 62133	 0.000179	 0.002814	 0.02931	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76910	 62109	 0.000171	 0.002086	 0.0334	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62109	 76913	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62110	 62112	 0.002179	 0.015114	 0.00431	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76912	 62110	 0.005914	 0.020907	 0.00471	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76913	 62110	 0.003729	 0.014921	 0.00376	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62110	 76915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62110	 76915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76915	 62111	 0.0185	 0.049029	 0.00124	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62111	 76916	 0.005757	 0.014579	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76909	 62112	 0.001129	 0.0106	 0.00321	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62112	 76916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62112	 76916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62113	 76917	 0.008864	 0.018221	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62114	 62115	 0.000779	 0.004279	 0.00154	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62114	 62116	 0.000929	 0.003529	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62114	 62163	 0.001893	 0.008679	 0.00222	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62114	 62165	 0.000586	 0.003207	 0.00116	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62114	 76917	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62114	 76917	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62115	 62145	 0.000493	 0.0035	 0.00096	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62116	 62151	 0.000757	 0.003043	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62117	 62151	 0.000629	 0.002214	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62117	 62176	 0.001721	 0.004943	 0.00121	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62117	 76918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62117	 76918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76917	 62118	 0.00825	 0.016886	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76918	 62118	 0.004679	 0.008221	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62118	 76949	 0.025007	 0.024564	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62119	 62128	 0.000336	 0.002279	 0.00411	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62119	 62206	 0.001164	 0.008179	 0.01393	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62119	 76919	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62119	 76919	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62119	 76924	 0.000436	 0.002979	 0.00686	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62120	 62130	 0.001121	 0.004629	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62120	 62157	 0.001229	 0.005064	 0.0012	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62121	 62153	 0.002736	 0.01075	 0.00281	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62121	 62156	 0.001371	 0.004993	 0.00153	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62122	 62125	 0.001371	 0.006757	 0.00183	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62122	 76920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62122	 76920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62122	 76927	 0.002629	 0.013914	 0.00464	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62123	 62124	 0.000814	 0.004107	 0.00107	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62123	 62195	 0.001286	 0.005886	 0.00151	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62124	 62131	 0.001029	 0.004114	 0.00139	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62124	 76921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62124	 76921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62125	 62131	 0.0014	 0.005621	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62125	 62202	 0.0007	 0.003336	 0.00096	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62125	 76922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62125	 76922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62126	 62127	 7.1e-05	 0.001129	 0.01094	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62126	 62155	 0.000114	 0.001564	 0.01529	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62126	 76923	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62126	 76923	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76911	 62127	 0.000221	 0.003007	 0.04582	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62127	 76924	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62127	 76924	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62128	 76925	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62128	 76925	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62128	 76937	 0.001243	 0.008407	 0.01549	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62129	 62162	 0.000914	 0.004364	 0.00104	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62129	 62214	 0.002064	 0.008279	 0.00209	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62129	 76927	 0.000886	 0.009221	 0.00254	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62130	 62131	 0.00115	 0.004371	 0.00122	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76925	 62130	 0.0012	 0.007621	 0.00207	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62130	 76926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62130	 76926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76919	 62132	 0.006129	 0.018793	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62132	 76928	 0.005243	 0.0201	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62133	 62134	 5e-05	 0.000779	 0.00875	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62134	 62159	 0.000157	 0.002507	 0.02444	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62134	 76927	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62135	 76931	 0.005429	 0.012407	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62136	 62140	 0.001614	 0.006657	 0.00157	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62136	 76929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62136	 76929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62137	 62142	 0.02355	 0.01525	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76908	 62137	 0.034464	 0.022314	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76929	 62137	 0.022029	 0.0156	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62138	 62144	 0.001829	 0.004829	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62138	 76930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62138	 76930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76930	 62139	 0.026879	 0.02425	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62139	 76933	 0.023914	 0.015486	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62140	 62141	 0.001421	 0.005879	 0.00139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62140	 76931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62140	 76931	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62141	 76934	 0.002929	 0.0115	 0.00301	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62141	 76938	 0.002129	 0.011114	 0.00268	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62142	 76932	 0.0083	 0.0146	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62143	 62144	 0.000729	 0.003993	 0.00106	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62143	 62147	 0.000671	 0.003936	 0.00107	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62143	 76932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62143	 76932	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62144	 62145	 0.000764	 0.003621	 0.00116	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62145	 62149	 0.001936	 0.00605	 0.00175	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62145	 76933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62145	 76933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62146	 76935	 0.022393	 0.014493	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62147	 76934	 0.000629	 0.003757	 0.00114	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62148	 76934	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76935	 62148	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62148	 76937	 0.000286	 0.002279	 0.00766	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62149	 62150	 0.000693	 0.004707	 0.0016	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62149	 62153	 0.003921	 0.010521	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76934	 62149	 0.000371	 0.005121	 0.00206	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62150	 62151	 0.000257	 0.001929	 0.00054	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62152	 76947	 0.018964	 0.013707	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62153	 62177	 0.00145	 0.005993	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62153	 76936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62153	 76936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62154	 62155	 0.000129	 0.001836	 0.01661	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62154	 76937	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76938	 62154	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62156	 62157	 0.001029	 0.004236	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76938	 62156	 0.004329	 0.017321	 0.00436	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62156	 76939	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62156	 76939	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62156	 76962	 0.012179	 0.029357	 0.00829	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76923	 62158	 0.01535	 0.053743	 0.00149	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76935	 62158	 0.026457	 0.049193	 0.00115	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76939	 62158	 0.008157	 0.01865	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62159	 62390	 0.000693	 0.008371	 0.07404	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62159	 76940	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62160	 62161	 0.023329	 0.016521	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76941	 62160	 0.021314	 0.020936	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62161	 76942	 0.012343	 0.008743	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62162	 62217	 0.001421	 0.005586	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62162	 76942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62162	 76942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62163	 62165	 0.001514	 0.0055	 0.00169	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62163	 62874	 0.002729	 0.012286	 0.00327	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62163	 76943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62163	 76943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76943	 62164	 0.02945	 0.019071	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62165	 62872	 0.001686	 0.00685	 0.00167	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62166	 76945	 0.014914	 0.015929	 0.00034	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62166	 76946	 0.009586	 0.01685	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62167	 62172	 0.001329	 0.00455	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62167	 62857	 0.003964	 0.013814	 0.0032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62167	 76944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62167	 76944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62168	 62171	 0.024279	 0.0172	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62168	 76950	 0.011571	 0.016136	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62169	 76985	 0.021229	 0.013743	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62170	 62175	 0.01075	 0.01465	 0.00033	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62170	 76950	 0.019107	 0.025114	 0.00034	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62172	 62173	 0.001021	 0.003964	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62172	 76945	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62172	 76945	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62173	 62187	 0.001929	 0.007964	 0.00189	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62173	 76946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62173	 76946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62174	 62175	 0.007243	 0.011564	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76943	 62174	 0.008214	 0.016886	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76946	 62174	 0.005786	 0.017021	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62175	 76952	 0.004764	 0.010893	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62176	 62178	 0.000871	 0.002929	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62176	 76947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62176	 76947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62177	 62178	 0.001071	 0.004286	 0.00108	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62177	 76948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62177	 76948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62178	 62180	 0.001171	 0.004464	 0.00125	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62178	 76949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62178	 76949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76947	 62179	 0.015629	 0.023436	 0.00043	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76949	 62179	 0.009707	 0.017514	 0.00025	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62179	 76951	 0.007214	 0.021207	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62180	 62183	 0.001021	 0.00415	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62181	 62255	 0.002129	 0.008279	 0.00221	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62181	 62307	 0.001007	 0.004157	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62181	 76950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62181	 76950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62182	 62185	 0.023129	 0.016386	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62182	 62232	 0.0089	 0.017629	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62183	 62186	 0.00095	 0.003607	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62183	 62255	 0.0032	 0.010007	 0.0029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62183	 76951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62183	 76951	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62184	 62185	 0.005836	 0.013336	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62184	 76952	 0.005607	 0.014214	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62185	 62188	 0.005486	 0.011271	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76951	 62185	 0.01705	 0.029979	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62185	 76974	 0.002771	 0.013286	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62186	 62187	 0.000757	 0.002957	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62187	 76952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62187	 76952	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62188	 76953	 0.00365	 0.008479	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62189	 62219	 0.000586	 0.002671	 0.00085	 200.0	 200.0	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62189	 76953	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62189	 76953	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62190	 62195	 0.000829	 0.0045	 0.00109	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62190	 62196	 0.001143	 0.004579	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62190	 62241	 0.001021	 0.004229	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62191	 62192	 0.000507	 0.001986	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62191	 62193	 0.001029	 0.004243	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62192	 62394	 0.0005	 0.001979	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62193	 62196	 0.001093	 0.003871	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62193	 62197	 0.0013	 0.005193	 0.00131	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62193	 76954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62193	 76954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76954	 62194	 0.00365	 0.0075	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62194	 77019	 0.005064	 0.007386	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62195	 76955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62195	 76955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62197	 62204	 0.000564	 0.003857	 0.00113	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62197	 62208	 0.001043	 0.004257	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62198	 62208	 0.000614	 0.002079	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62198	 62399	 0.001329	 0.004143	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62198	 76956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62198	 76956	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62199	 62200	 0.0044	 0.007021	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76921	 62199	 0.011071	 0.025429	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76955	 62199	 0.0043	 0.012214	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62200	 76957	 0.004543	 0.013357	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62201	 76958	 0.026214	 0.018571	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62202	 62203	 0.000493	 0.004207	 0.0012	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62202	 62205	 0.001471	 0.005207	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62202	 76959	 0.001993	 0.006643	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62203	 62204	 0.000621	 0.00405	 0.00103	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62203	 76957	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62203	 76957	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62204	 76958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62204	 76958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76940	 62205	 0.000721	 0.004143	 0.00117	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62205	 76959	 0.001107	 0.002779	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62206	 62207	 0.000314	 0.001921	 0.00437	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62206	 76959	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62206	 76959	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62207	 62218	 0.000414	 0.002779	 0.00523	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62208	 62448	 0.001621	 0.004779	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62209	 62210	 0.001893	 0.005579	 0.0013	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62209	 62211	 0.002093	 0.00795	 0.00223	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62209	 62216	 0.000843	 0.004236	 0.0011	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62210	 62212	 0.001093	 0.00425	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62210	 62213	 0.001807	 0.006864	 0.00192	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62211	 62449	 0.001636	 0.006786	 0.00159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62212	 62450	 0.001507	 0.006043	 0.00152	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62212	 76960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62212	 76960	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62213	 62214	 0.002307	 0.008971	 0.0024	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76957	 62215	 0.022957	 0.040371	 0.00076	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62215	 76961	 0.004136	 0.007693	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62216	 62217	 0.001314	 0.005279	 0.00133	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76940	 62216	 0.003579	 0.012271	 0.00294	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62216	 76961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62216	 76961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76959	 62217	 0.001271	 0.004529	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62218	 76962	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76963	 62218	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62218	 77041	 0.001114	 0.007321	 0.01417	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62219	 62220	 0.000864	 0.003957	 0.00101	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62219	 76964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62219	 76964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62220	 62222	 0.001021	 0.003964	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62220	 62306	 0.001021	 0.004243	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62220	 76965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62220	 76965	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62221	 62223	 0.001021	 0.003971	 0.00106	 175.0	 175.95	 175.95	 0.0	 0.0	 1	 -30.0	 30.0;
	62221	 62223	 0.001021	 0.003971	 0.00106	 175.0	 175.95	 175.95	 0.0	 0.0	 1	 -30.0	 30.0;
	62221	 62224	 0.000421	 0.002493	 0.00066	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62221	 62225	 0.000971	 0.004607	 0.00111	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62221	 76966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62221	 76966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62222	 62312	 0.00085	 0.003464	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62222	 76967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62222	 76967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62223	 62339	 0.000764	 0.002679	 0.00089	 170.0	 170.0	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62223	 62339	 0.000764	 0.002679	 0.00089	 170.0	 170.0	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62223	 76968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62223	 76968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62224	 62225	 0.000386	 0.001907	 0.00051	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62224	 76969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62224	 76969	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62226	 62227	 0.011586	 0.008207	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76966	 62226	 0.0172	 0.018364	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62227	 62249	 0.004914	 0.011243	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76968	 62227	 0.017121	 0.015343	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62228	 62248	 0.005814	 0.0133	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76966	 62228	 0.007307	 0.016957	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76967	 62228	 0.012914	 0.032721	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62229	 62246	 0.003686	 0.009764	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62229	 62248	 0.013607	 0.019829	 0.00045	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76969	 62229	 0.017629	 0.019386	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62230	 62239	 0.017536	 0.012421	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76723	 62230	 0.002471	 0.010571	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76969	 62230	 0.0098	 0.024829	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62231	 62242	 0.002664	 0.008686	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62231	 62255	 0.004057	 0.011314	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62231	 76970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62231	 76970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62232	 62243	 0.023271	 0.016486	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76970	 62232	 0.009007	 0.015843	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62233	 62235	 0.008736	 0.0173	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62233	 62243	 0.016329	 0.014636	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62234	 62235	 0.023293	 0.015079	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76723	 62234	 0.008029	 0.018436	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62235	 77017	 0.0117	 0.02675	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62236	 77017	 0.024164	 0.015643	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62237	 62238	 0.000614	 0.002136	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62237	 62396	 0.002386	 0.005536	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62237	 76971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62237	 76971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62238	 62397	 0.000643	 0.002207	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62239	 62240	 0.00205	 0.007	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62239	 62246	 0.005707	 0.014464	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76971	 62240	 0.001764	 0.00785	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62241	 62242	 0.001029	 0.00375	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62242	 76972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62242	 76972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62244	 62245	 0.0085	 0.01495	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76948	 62244	 0.007843	 0.014586	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76972	 62244	 0.022186	 0.040029	 0.00058	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76970	 62245	 0.01045	 0.014243	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62246	 62247	 0.004393	 0.007729	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62247	 62254	 0.005807	 0.014707	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62248	 62249	 0.017707	 0.014579	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62248	 62341	 0.052136	 0.041264	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62248	 76973	 0.005371	 0.015793	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62249	 62250	 0.002814	 0.006443	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62250	 62251	 0.002836	 0.008343	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62251	 77003	 0.003221	 0.011293	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62252	 76973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62252	 76973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62252	 77014	 0.002007	 0.007636	 0.00214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62253	 62254	 0.008279	 0.008136	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76971	 62253	 0.008629	 0.015171	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62254	 62392	 0.007171	 0.020564	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62255	 76974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62255	 76974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62256	 62257	 0.009814	 0.014293	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62256	 76975	 0.007536	 0.014007	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62257	 62258	 0.010536	 0.0158	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62258	 62269	 0.00525	 0.0133	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62258	 77082	 0.006643	 0.020379	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62259	 62261	 0.001057	 0.0041	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62259	 62324	 0.001021	 0.003893	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62260	 62328	 0.01605	 0.029843	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62260	 77083	 0.013564	 0.023857	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62261	 62868	 0.007521	 0.019336	 0.00479	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62261	 76975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62261	 76975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62262	 62270	 0.023914	 0.015486	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76975	 62262	 0.022093	 0.015971	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62263	 62266	 0.0058	 0.014686	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76975	 62263	 0.00575	 0.01765	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62264	 62267	 0.023429	 0.0166	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62264	 62269	 0.008571	 0.016964	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62265	 62266	 0.024064	 0.017043	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62265	 62896	 0.017521	 0.013736	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62266	 62267	 0.018079	 0.016307	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62266	 62897	 0.012693	 0.01355	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62268	 62269	 0.02285	 0.016186	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62270	 62275	 0.0117	 0.014521	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62270	 76976	 0.003264	 0.014557	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62271	 62272	 0.002114	 0.0084	 0.00024	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62271	 62893	 0.032943	 0.021329	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62271	 62896	 0.0112	 0.017879	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62272	 62274	 0.001393	 0.008543	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62273	 62274	 0.008086	 0.007243	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62273	 62892	 0.022257	 0.014407	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62274	 62280	 0.007364	 0.01175	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62274	 76976	 0.001914	 0.0095	 0.00023	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76975	 62275	 0.023043	 0.016321	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62276	 62277	 0.001029	 0.004279	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62276	 76976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62276	 76976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62277	 62288	 0.001271	 0.004629	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62277	 76977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62277	 76977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62278	 62282	 0.001943	 0.00505	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62278	 62887	 0.001407	 0.004736	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62278	 76978	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62278	 76978	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62278	 77014	 0.009936	 0.037786	 0.01058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62279	 62284	 0.006614	 0.020286	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62279	 62285	 0.006221	 0.012736	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62279	 62286	 0.004871	 0.013979	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62279	 76989	 0.006107	 0.032814	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62280	 62284	 0.002957	 0.014657	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62280	 62892	 0.004636	 0.010521	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62281	 62284	 0.00605	 0.015329	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76977	 62281	 0.021907	 0.018029	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62281	 76980	 0.005171	 0.013679	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62282	 62291	 0.00275	 0.009436	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62282	 62862	 0.003579	 0.0098	 0.00213	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62282	 76979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62282	 76979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62283	 62290	 0.008757	 0.0154	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62283	 76981	 0.033	 0.023371	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62284	 62889	 0.022879	 0.018829	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76978	 62285	 0.008464	 0.010507	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62286	 62287	 0.005307	 0.015229	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62287	 62318	 0.003814	 0.016807	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62288	 62289	 0.000979	 0.003979	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62288	 76980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62288	 76980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62289	 62320	 0.00125	 0.004757	 0.00133	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62290	 76989	 0.005807	 0.014707	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62291	 62296	 0.001986	 0.00825	 0.00193	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62291	 76981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62291	 76981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76981	 62292	 0.013629	 0.014557	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62293	 62299	 0.004079	 0.013921	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62293	 62311	 0.005736	 0.013121	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62294	 62295	 0.001057	 0.00375	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62294	 62296	 0.001736	 0.005114	 0.00119	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62295	 62312	 0.000486	 0.0019	 0.0005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62295	 76982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62295	 76982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62296	 62315	 0.002229	 0.006764	 0.00148	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62296	 76983	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62296	 76983	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62296	 77014	 0.005264	 0.021071	 0.00531	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76967	 62297	 0.004493	 0.011914	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62297	 76997	 0.019757	 0.0177	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62297	 76998	 0.0053	 0.013436	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62298	 62883	 0.017707	 0.012543	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76979	 62298	 0.008593	 0.017014	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62299	 62305	 0.006407	 0.014536	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62299	 62313	 0.029836	 0.021136	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76983	 62299	 0.018114	 0.03185	 0.0006	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62299	 76988	 0.005821	 0.031007	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62300	 62301	 0.001	 0.004136	 0.00098	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62300	 62878	 0.001036	 0.004279	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62300	 76984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62300	 76984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62301	 62308	 0.002	 0.008021	 0.00202	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62301	 76985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62301	 76985	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62302	 76987	 0.017936	 0.018114	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76984	 62303	 0.005636	 0.012886	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62303	 76988	 0.004893	 0.014386	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62304	 62305	 0.005771	 0.013193	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62304	 62310	 0.0057	 0.013029	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76982	 62305	 0.00355	 0.012129	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62306	 62309	 0.001021	 0.004079	 0.00103	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62307	 62308	 0.001021	 0.00415	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62307	 76986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62307	 76986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62308	 76987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62308	 76987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62309	 76988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62309	 76988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76984	 62310	 0.008736	 0.015357	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62310	 77146	 0.004979	 0.016614	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62311	 77147	 0.004921	 0.010079	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62313	 62314	 0.010814	 0.008557	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76981	 62314	 0.005043	 0.013364	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76983	 62314	 0.006121	 0.015514	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62314	 76989	 0.006336	 0.01255	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62315	 62317	 0.001943	 0.006779	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62315	 76989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62315	 76989	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76983	 62316	 0.0286	 0.018514	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62316	 76990	 0.009786	 0.0157	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62317	 62319	 0.001079	 0.00445	 0.00105	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62317	 62332	 0.002014	 0.004857	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62317	 62335	 0.000779	 0.003464	 0.00094	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62317	 76990	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62317	 76990	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76990	 62318	 0.001236	 0.006786	 0.00015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62318	 76991	 0.009686	 0.014114	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62319	 62320	 0.001129	 0.003371	 0.00076	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62319	 62321	 0.001186	 0.004514	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62319	 76991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62319	 76991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62320	 62332	 0.001421	 0.0057	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62320	 76992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62320	 76992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62321	 62322	 0.0012	 0.004814	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62321	 76993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62321	 76993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62322	 62323	 0.000957	 0.00395	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62323	 62324	 0.001171	 0.004564	 0.00122	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62323	 76994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62323	 76994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62325	 62327	 0.001579	 0.006307	 0.00159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62325	 62371	 0.001421	 0.005886	 0.00139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62325	 76995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62325	 76995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62326	 62327	 0.001543	 0.005407	 0.00179	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62326	 62551	 0.004893	 0.014729	 0.00461	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62326	 62559	 0.00145	 0.005807	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76994	 62328	 0.013971	 0.028707	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62329	 62330	 0.018929	 0.0258	 0.00057	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76993	 62329	 0.013043	 0.034579	 0.00088	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62329	 77000	 0.01105	 0.031693	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76995	 62330	 0.030243	 0.041264	 0.00074	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62331	 62348	 0.006479	 0.0164	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76991	 62331	 0.016464	 0.022443	 0.0005	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76994	 62331	 0.012321	 0.03265	 0.00083	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62332	 62346	 0.001443	 0.005779	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62333	 62347	 0.033257	 0.023557	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76990	 62333	 0.003693	 0.01085	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62333	 76996	 0.004543	 0.013021	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62333	 76999	 0.005821	 0.013314	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62334	 62336	 0.000686	 0.002229	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62334	 62336	 0.000686	 0.002229	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62334	 62338	 0.001221	 0.004343	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62334	 62338	 0.001221	 0.004343	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62335	 62336	 0.000443	 0.002021	 0.00051	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62336	 62344	 0.000529	 0.002107	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62336	 76996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62336	 76996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62337	 76997	 0.011621	 0.008236	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62338	 62340	 0.000514	 0.001943	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62338	 62340	 0.000514	 0.001943	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62338	 76997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62338	 76997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62339	 62340	 0.000514	 0.00205	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62339	 62340	 0.000514	 0.00205	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62340	 76998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62340	 76998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62341	 62359	 0.00585	 0.014807	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76997	 62341	 0.00725	 0.016586	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62342	 62343	 0.005579	 0.010929	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62342	 62358	 0.005821	 0.014743	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62343	 62345	 0.00585	 0.009857	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62344	 62356	 0.001379	 0.005621	 0.00137	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76996	 62345	 0.00495	 0.016521	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62345	 77002	 0.00435	 0.011014	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62346	 62353	 0.000807	 0.003164	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62346	 76999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62346	 76999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62347	 62348	 0.004964	 0.0146	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62347	 62352	 0.005807	 0.013286	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62348	 77000	 0.005886	 0.022907	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62349	 62368	 0.001807	 0.005079	 0.00131	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62349	 77000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62349	 77000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62350	 62352	 0.013571	 0.01225	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77000	 62350	 0.029543	 0.023379	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62351	 77009	 0.023464	 0.016621	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76999	 62352	 0.02565	 0.021114	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62352	 77008	 0.005814	 0.014721	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62353	 62357	 0.000671	 0.002686	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62353	 77001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62353	 77001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77001	 62354	 0.011571	 0.007493	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77001	 62355	 0.003271	 0.007479	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62355	 77007	 0.004357	 0.011043	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62355	 77008	 0.02265	 0.020436	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62356	 62357	 0.000607	 0.002157	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62356	 62363	 0.001014	 0.003536	 0.00117	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62357	 62364	 0.001043	 0.00395	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62357	 77002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62357	 77002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62358	 77005	 0.004364	 0.012514	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62358	 77006	 0.02325	 0.020836	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62359	 62360	 0.003043	 0.009336	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62359	 77004	 0.0374	 0.024214	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62360	 77003	 0.001464	 0.006814	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62360	 77015	 0.006193	 0.016421	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62361	 77003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62361	 77003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62361	 77014	 0.000779	 0.003114	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62362	 62363	 0.000407	 0.001921	 0.00056	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62362	 77004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62362	 77004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62362	 77014	 0.000964	 0.005114	 0.00129	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62363	 77005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62363	 77005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62364	 62365	 0.001221	 0.004193	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62364	 77006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62364	 77006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62364	 77014	 0.001793	 0.008836	 0.00239	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62365	 62366	 0.001021	 0.004029	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62365	 77007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62365	 77007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62365	 77076	 0.003743	 0.014979	 0.00377	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62366	 77008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62366	 77008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77008	 62367	 0.004379	 0.011343	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62367	 77009	 0.003671	 0.006821	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62368	 62379	 0.001736	 0.005214	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62368	 77009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62368	 77009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62369	 62370	 0.018429	 0.015171	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77009	 62369	 0.01245	 0.013693	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62370	 62375	 0.01285	 0.017514	 0.00039	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62370	 77012	 0.009286	 0.021071	 0.00042	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62371	 62373	 0.000907	 0.003743	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62371	 77010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62371	 77010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62372	 62420	 0.004729	 0.011979	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77010	 62372	 0.006164	 0.018136	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62373	 62376	 0.001407	 0.005643	 0.00142	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62373	 62600	 0.005557	 0.014421	 0.0035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62373	 77011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62373	 77011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62374	 62375	 0.009629	 0.015371	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77011	 62374	 0.012514	 0.008864	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77011	 62375	 0.016036	 0.024564	 0.00034	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62375	 77025	 0.004529	 0.0211	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62376	 62377	 0.001657	 0.004536	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62376	 62418	 0.001164	 0.003343	 0.00082	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62377	 62379	 0.000921	 0.003064	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62378	 77012	 0.002457	 0.007229	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62378	 77013	 0.0067	 0.009757	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62378	 77024	 0.0049	 0.014407	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62379	 62381	 0.001214	 0.004607	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62379	 77012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62379	 77012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62380	 77013	 0.011393	 0.008071	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62381	 62410	 0.0018	 0.006557	 0.00201	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62381	 77013	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62381	 77013	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62382	 62384	 0.007557	 0.014057	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62382	 62543	 0.002914	 0.006664	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77013	 62382	 0.005364	 0.015779	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62383	 62384	 0.001586	 0.006079	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62383	 77021	 0.001936	 0.008586	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62384	 62386	 0.006114	 0.014193	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77007	 62384	 0.003257	 0.011114	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62385	 62386	 0.003207	 0.008121	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62385	 62389	 0.003329	 0.010014	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62386	 62387	 0.004393	 0.0087	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62387	 62542	 0.004336	 0.009907	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62388	 62389	 0.002457	 0.008114	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77004	 62388	 0.002914	 0.007386	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62389	 77078	 0.002214	 0.00925	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62390	 77014	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62390	 77040	 0.000193	 0.002757	 0.02631	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62391	 62392	 0.0073	 0.013579	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62391	 62407	 0.004229	 0.012121	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76973	 62391	 0.004879	 0.016679	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77015	 62391	 0.006407	 0.016479	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62392	 62393	 0.008693	 0.015286	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62392	 62405	 0.003536	 0.012364	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62393	 77018	 0.009121	 0.021171	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62394	 62396	 0.000507	 0.001957	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62395	 62396	 0.001093	 0.002886	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62395	 62397	 0.000771	 0.0021	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62395	 62400	 0.001214	 0.003593	 0.00084	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62395	 77016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62395	 77016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62396	 77017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62396	 77017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62397	 62398	 0.001529	 0.0054	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62398	 62400	 0.0008	 0.002014	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62398	 62445	 0.001871	 0.008579	 0.0022	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62398	 77018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62398	 77018	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62399	 62402	 0.000871	 0.002264	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62399	 77019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62399	 77019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62400	 62402	 0.00085	 0.002136	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77017	 62401	 0.006443	 0.011329	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77018	 62401	 0.023621	 0.017079	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77019	 62401	 0.004921	 0.008657	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62403	 62404	 0.01135	 0.008036	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77018	 62403	 0.011329	 0.008336	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62404	 62444	 0.006957	 0.012236	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62405	 62440	 0.005486	 0.011279	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62405	 77043	 0.015757	 0.036029	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62406	 62407	 0.002893	 0.007321	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62406	 77035	 0.002129	 0.008279	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62408	 62436	 0.001421	 0.003829	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62408	 62439	 0.001271	 0.005107	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62408	 77020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62408	 77020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62409	 62410	 0.000771	 0.003179	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62409	 77021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62409	 77021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62409	 77076	 0.001843	 0.0067	 0.00205	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62410	 62412	 0.00205	 0.005414	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62410	 62432	 0.002614	 0.007121	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62410	 77022	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62410	 77022	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62410	 77076	 0.00235	 0.009564	 0.00233	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77022	 62411	 0.005479	 0.008214	 0.00015	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62411	 77023	 0.017614	 0.013936	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62412	 62413	 0.000757	 0.003071	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62412	 62433	 0.001457	 0.005664	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62412	 77023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62412	 77023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62413	 62414	 0.000493	 0.002036	 0.00049	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62413	 62431	 0.001343	 0.003236	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62414	 62416	 0.00095	 0.0038	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62414	 77024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62414	 77024	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62415	 62416	 0.000514	 0.002071	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62415	 62417	 0.000807	 0.003229	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62415	 77025	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62415	 77025	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62416	 77026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62416	 77026	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62417	 62418	 0.000621	 0.002014	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62418	 77027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62418	 77027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77027	 62419	 0.007886	 0.01075	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62420	 62421	 0.00315	 0.014029	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62420	 62424	 0.010764	 0.030871	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62420	 62593	 0.008593	 0.015107	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62421	 77028	 0.002543	 0.012614	 0.0003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62422	 62470	 0.0018	 0.006364	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62422	 62639	 0.003471	 0.008721	 0.00226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62422	 77028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62422	 77028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62423	 62469	 0.006864	 0.01095	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77028	 62423	 0.011586	 0.008207	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62424	 77106	 0.008243	 0.020871	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62425	 62427	 0.006571	 0.010493	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77027	 62425	 0.007343	 0.018607	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77028	 62425	 0.006607	 0.016729	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62426	 62427	 0.008271	 0.008121	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77026	 62426	 0.017586	 0.017279	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62427	 62467	 0.004229	 0.011214	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62428	 62430	 0.000993	 0.002621	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62428	 62431	 0.001743	 0.004386	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62428	 77029	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62428	 77029	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77025	 62429	 0.006714	 0.017007	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77029	 62429	 0.002021	 0.006207	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62430	 62431	 0.000807	 0.002136	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62431	 62432	 0.000771	 0.003093	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62431	 77030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62431	 77030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62432	 62433	 0.001036	 0.004079	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62432	 77031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62432	 77031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62433	 62434	 0.001029	 0.004043	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62433	 62457	 0.00145	 0.005979	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62434	 77076	 0.001136	 0.00455	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62435	 62436	 0.000807	 0.003236	 0.00081	 180.0	 180.95	 180.95	 0.0	 0.0	 1	 -30.0	 30.0;
	62435	 62541	 0.001243	 0.003736	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62435	 77032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62435	 77032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62436	 62455	 0.001229	 0.004471	 0.00137	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62436	 77033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62436	 77033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77033	 62437	 0.004257	 0.008429	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62437	 77034	 0.004414	 0.010093	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62438	 62439	 0.000514	 0.002057	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62438	 62446	 0.000607	 0.0022	 0.00067	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62438	 77034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62438	 77034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62439	 77035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62439	 77035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62440	 62441	 0.002914	 0.00835	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62440	 62442	 0.015193	 0.017807	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62441	 77037	 0.003793	 0.008671	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62442	 62444	 0.002907	 0.008336	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62442	 77036	 0.002307	 0.011664	 0.0002	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77016	 62443	 0.010579	 0.0268	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77018	 62443	 0.006	 0.0152	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62443	 77038	 0.024086	 0.015593	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62443	 77039	 0.014593	 0.041857	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62443	 77043	 0.015829	 0.036193	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62445	 62447	 0.0016	 0.003721	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76721	 62445	 0.002129	 0.009779	 0.00251	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62445	 77036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62445	 77036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62446	 77037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62446	 77037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62446	 77042	 0.001014	 0.004821	 0.00114	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62447	 62448	 0.001721	 0.004614	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62448	 77038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62448	 77038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62449	 77039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62449	 77039	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62449	 77042	 0.003407	 0.01025	 0.00321	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62450	 62452	 0.00225	 0.008179	 0.0025	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62451	 62623	 0.000221	 0.003093	 0.1972	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62451	 77040	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62451	 77040	 9.8e-05	 0.007857	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62452	 62504	 0.003636	 0.01185	 0.00314	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77042	 62452	 0.00225	 0.007843	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76721	 62453	 0.001379	 0.008414	 0.00211	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62453	 77044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62453	 77044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62454	 77045	 0.011736	 0.009286	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76721	 62455	 0.001093	 0.005657	 0.00138	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62455	 77045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62455	 77045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77032	 62456	 0.005821	 0.01475	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77045	 62456	 0.005779	 0.014636	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62456	 77056	 0.01665	 0.014921	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62457	 62458	 0.001057	 0.004486	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62457	 62476	 0.000771	 0.003207	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62457	 77076	 0.000986	 0.004657	 0.00112	 195.0	 195.0	 195.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62458	 62462	 0.001236	 0.004407	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62458	 62474	 0.001607	 0.004036	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62459	 62461	 0.010357	 0.012143	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62459	 62542	 0.021443	 0.039864	 0.00094	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62459	 77053	 0.002914	 0.007371	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62460	 62462	 0.000679	 0.002214	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62460	 62463	 0.000807	 0.003336	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62460	 62473	 0.001293	 0.003514	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62460	 77046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62460	 77046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77046	 62461	 0.008336	 0.007471	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62461	 77047	 0.013043	 0.009243	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62462	 77047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62462	 77047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62463	 62464	 0.000814	 0.0031	 0.00086	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62463	 77048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62463	 77048	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62464	 62466	 0.0008	 0.002114	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62464	 62468	 0.001729	 0.004007	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77029	 62465	 0.003664	 0.006814	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62465	 77049	 0.004907	 0.007829	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62466	 62468	 0.000929	 0.002386	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62466	 77049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62466	 77049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62467	 77050	 0.002786	 0.007057	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62468	 62470	 0.000964	 0.003864	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62468	 77050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62468	 77050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62469	 77051	 0.004993	 0.01265	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62470	 62607	 0.002757	 0.011229	 0.00274	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62470	 77051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62470	 77051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62470	 77097	 0.002714	 0.010314	 0.00289	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62471	 62485	 0.013614	 0.020414	 0.00037	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77049	 62471	 0.008514	 0.022571	 0.00057	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62471	 77098	 0.008086	 0.031571	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77046	 62472	 0.006886	 0.014086	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62472	 77052	 0.005857	 0.014836	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62472	 77079	 0.0143	 0.01775	 0.00039	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62473	 62474	 0.001271	 0.0045	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62473	 77052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62473	 77052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62474	 62484	 0.002079	 0.005393	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62474	 77053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62474	 77053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62474	 77076	 0.002414	 0.009179	 0.00257	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77052	 62475	 0.00595	 0.015071	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77053	 62475	 0.011721	 0.009279	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62475	 77054	 0.00585	 0.014814	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62475	 77055	 0.019857	 0.034921	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62475	 77058	 0.01855	 0.012007	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62476	 62477	 0.000514	 0.001807	 0.0006	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62477	 62479	 0.0008	 0.003107	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 0	 -30.0	 30.0;
	62477	 77054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62477	 77054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62478	 62479	 0.000514	 0.002057	 0.00051	 200.0	 200.95	 200.95	 0.0	 0.0	 1	 -30.0	 30.0;
	62478	 62480	 0.000593	 0.003014	 0.00082	 250.0	 250.55	 250.55	 0.0	 0.0	 1	 -30.0	 30.0;
	62478	 77055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62478	 77055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62480	 62481	 0.000664	 0.003886	 0.00106	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62480	 77056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62480	 77056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76721	 62481	 0.000493	 0.003314	 0.00101	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77055	 62482	 0.009093	 0.018686	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62482	 77081	 0.004807	 0.012736	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62483	 62484	 0.001771	 0.004686	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62483	 62487	 0.001679	 0.005093	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62483	 77057	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62483	 77057	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62483	 77080	 0.001386	 0.00565	 0.00138	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62484	 62486	 0.002679	 0.008129	 0.00178	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62484	 77058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62484	 77058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62484	 77080	 0.002479	 0.009929	 0.0025	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62485	 77066	 0.010536	 0.02165	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62485	 77098	 0.006707	 0.0299	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62486	 62494	 0.001693	 0.004257	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62486	 77059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62486	 77059	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62487	 62491	 0.00165	 0.0045	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62487	 77060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62487	 77060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62488	 62508	 0.005779	 0.014643	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77044	 62488	 0.0116	 0.023836	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62489	 62490	 0.001593	 0.0041	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62489	 62492	 0.002793	 0.007393	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62489	 77061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62489	 77061	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62489	 77080	 0.000886	 0.00545	 0.00157	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62490	 62492	 0.0012	 0.003293	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62490	 77062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62490	 77062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62491	 62493	 0.000921	 0.003336	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62491	 77063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62491	 77063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62492	 62520	 0.010721	 0.024886	 0.00758	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62492	 77064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62492	 77064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62492	 77080	 0.002579	 0.010321	 0.0026	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62493	 62494	 0.00145	 0.003907	 0.00109	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62494	 62495	 0.001607	 0.004379	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62494	 62497	 0.00285	 0.007643	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62494	 77065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62494	 77065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62495	 62497	 0.001514	 0.004	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62495	 62544	 0.003843	 0.009264	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62495	 77066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62495	 77066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62496	 62498	 0.000807	 0.003071	 0.00086	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62496	 62499	 0.000514	 0.002121	 0.00049	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62496	 77067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62496	 77067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62497	 62498	 0.001329	 0.006329	 0.0015	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62497	 62633	 0.007729	 0.019879	 0.00492	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62497	 77068	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62497	 77068	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62498	 77097	 0.00115	 0.005479	 0.00159	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62499	 62520	 0.001943	 0.007621	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62499	 77069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62499	 77069	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62500	 62501	 0.011514	 0.017457	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62500	 62516	 0.014279	 0.025114	 0.00047	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77065	 62500	 0.023479	 0.016629	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77068	 62500	 0.014729	 0.0259	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77063	 62501	 0.029214	 0.023121	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77064	 62501	 0.014043	 0.0278	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62502	 62515	 0.016307	 0.017414	 0.00037	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77061	 62502	 0.006507	 0.030329	 0.0007	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62503	 62515	 0.007493	 0.01985	 0.0005	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77062	 62503	 0.002929	 0.012229	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62504	 77070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62504	 77070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62505	 62506	 0.006371	 0.014457	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77070	 62505	 0.006214	 0.027693	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62506	 62507	 0.011521	 0.0143	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62507	 62511	 0.026871	 0.021264	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62507	 62513	 0.0323	 0.020914	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77061	 62508	 0.006364	 0.014436	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62508	 77081	 0.007386	 0.021714	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62509	 62510	 0.00845	 0.019329	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77070	 62509	 0.008143	 0.020636	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62510	 62511	 0.041929	 0.030307	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62510	 62512	 0.013686	 0.02185	 0.0005	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62511	 62512	 0.042779	 0.03385	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62511	 62513	 0.035136	 0.024886	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62511	 62982	 0.096364	 0.094671	 0.0016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77044	 62511	 0.017464	 0.044243	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62512	 62537	 0.043486	 0.078464	 0.00114	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62513	 62514	 0.01415	 0.017557	 0.00039	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62514	 62538	 0.008964	 0.023043	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77061	 62514	 0.005029	 0.020986	 0.00061	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62515	 62516	 0.022114	 0.015664	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62515	 62539	 0.019129	 0.030536	 0.0007	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62515	 77075	 0.034079	 0.059936	 0.00113	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77068	 62517	 0.007743	 0.019614	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62518	 62526	 0.009471	 0.006707	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62518	 77072	 0.021279	 0.016843	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62519	 62520	 0.001186	 0.004314	 0.00132	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62519	 62528	 0.0013	 0.004071	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62519	 77071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62519	 77071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62520	 77072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62520	 77072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77071	 62521	 0.034129	 0.0221	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62522	 62527	 0.011257	 0.013979	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77071	 62522	 0.009264	 0.014786	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62523	 62524	 0.029093	 0.020607	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62523	 62529	 0.008464	 0.014886	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62523	 77161	 0.0202	 0.023679	 0.00041	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62524	 62525	 0.024057	 0.019043	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62524	 62531	 0.020514	 0.016236	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62525	 77074	 0.018336	 0.019579	 0.00041	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77066	 62526	 0.090107	 0.071314	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77071	 62526	 0.004736	 0.01255	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77072	 62526	 0.002943	 0.006736	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62527	 62904	 0.023914	 0.017286	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62527	 77073	 0.011621	 0.0092	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62528	 62908	 0.002629	 0.006607	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62528	 62987	 0.003464	 0.010221	 0.00238	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62528	 77073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62528	 77073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77073	 62529	 0.005271	 0.012057	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77073	 62530	 0.024193	 0.015664	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62531	 62535	 0.019893	 0.012879	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62532	 62534	 0.00215	 0.005864	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62532	 62987	 0.008179	 0.018979	 0.00579	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62532	 77074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62532	 77074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62533	 62537	 0.027893	 0.028179	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62533	 62539	 0.060279	 0.039021	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62533	 63379	 0.293114	 0.189907	 0.00361	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62533	 77075	 0.015507	 0.018179	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62534	 77075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62534	 77075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77074	 62535	 0.019343	 0.024014	 0.00052	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62536	 62537	 0.034107	 0.022086	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62536	 62982	 0.0623	 0.049307	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62538	 62539	 0.022243	 0.035686	 0.00066	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77075	 62539	 0.012493	 0.025679	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62540	 62545	 0.000193	 0.002136	 0.02076	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62540	 63050	 0.004657	 0.086679	 0.90079	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77040	 62540	 0.000129	 0.001979	 0.03403	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62540	 77076	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62540	 77096	 0.000314	 0.004486	 0.07163	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77014	 62541	 0.001529	 0.006229	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77042	 62541	 0.003536	 0.015379	 0.00438	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62541	 77078	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62541	 77078	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77078	 62542	 0.002664	 0.011793	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77022	 62543	 0.003414	 0.011671	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62544	 77079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62544	 77079	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62544	 77080	 0.004029	 0.014643	 0.00449	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62545	 77080	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62546	 62564	 0.008936	 0.014336	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62546	 62584	 0.006114	 0.013864	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62547	 62549	 0.009207	 0.016614	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62547	 62550	 0.003943	 0.013457	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62548	 62566	 0.007421	 0.028979	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62548	 77086	 0.007993	 0.026671	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62548	 77160	 0.033843	 0.054029	 0.00124	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62549	 62561	 0.011029	 0.01505	 0.00027	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62549	 62562	 0.037914	 0.026857	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62549	 62566	 0.017014	 0.043736	 0.00068	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62549	 77082	 0.049157	 0.048293	 0.00081	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62550	 62563	 0.002557	 0.012671	 0.0003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62550	 77083	 0.025043	 0.022443	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62551	 62559	 0.004121	 0.011293	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62551	 62579	 0.001721	 0.006779	 0.00177	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77076	 62551	 0.015693	 0.063893	 0.01557	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62551	 77082	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62551	 77082	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62552	 62554	 0.001593	 0.005793	 0.00177	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62552	 62555	 0.002386	 0.005993	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62552	 62577	 0.004757	 0.014329	 0.00449	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62553	 62990	 0.023871	 0.054586	 0.00134	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62553	 77086	 0.0229	 0.042579	 0.001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62554	 62555	 0.00345	 0.011629	 0.00289	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62554	 62984	 0.002593	 0.013236	 0.00333	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62555	 62985	 0.005429	 0.022079	 0.00538	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62556	 62558	 0.016614	 0.050971	 0.00138	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62556	 62829	 0.011229	 0.050043	 0.00085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62557	 62567	 0.018057	 0.018236	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77082	 62557	 0.013386	 0.030357	 0.00061	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62558	 77084	 0.022629	 0.0649	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62559	 77083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62559	 77083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77083	 62560	 0.006729	 0.011829	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62561	 62565	 0.011293	 0.014836	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62563	 62564	 0.00175	 0.010479	 0.00025	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62564	 62583	 0.0033	 0.014457	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62565	 62568	 0.016157	 0.015871	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62568	 62582	 0.0098	 0.014286	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62569	 62850	 0.086164	 0.061036	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62570	 62571	 0.022036	 0.015614	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62571	 62574	 0.020371	 0.035829	 0.00067	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62572	 62580	 0.002707	 0.010286	 0.00288	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62572	 77084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62572	 77084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62573	 62574	 0.030807	 0.019943	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77082	 62574	 0.013114	 0.029993	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62575	 62576	 0.001907	 0.007929	 0.00185	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62575	 62579	 0.0011	 0.004293	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62575	 77085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62575	 77085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62576	 62580	 0.00275	 0.011357	 0.00269	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62577	 77086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62577	 77086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77085	 62578	 0.024471	 0.039057	 0.0009	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77086	 62578	 0.012771	 0.03755	 0.00077	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62579	 77087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62579	 77087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77087	 62581	 0.015314	 0.012121	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77087	 62582	 0.005243	 0.011986	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62583	 62585	 0.002479	 0.0133	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62584	 62586	 0.004921	 0.014479	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62585	 62586	 0.018829	 0.019014	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62585	 62590	 0.004371	 0.010007	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76995	 62585	 0.012886	 0.026486	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62586	 62589	 0.010229	 0.0271	 0.00069	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62587	 62588	 0.011679	 0.007557	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62587	 62591	 0.013043	 0.008443	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62589	 62591	 0.004107	 0.01065	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62589	 62592	 0.0192	 0.0136	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62589	 62595	 0.002393	 0.011557	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62589	 77088	 0.00655	 0.0201	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62590	 62591	 0.002736	 0.009121	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62591	 62596	 0.004936	 0.011286	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62593	 62594	 0.009364	 0.011621	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62594	 62595	 0.007586	 0.00745	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62595	 77088	 0.005014	 0.011471	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62596	 77088	 0.004579	 0.019579	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62597	 62598	 0.023457	 0.016621	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62598	 62599	 0.023157	 0.014993	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62598	 62603	 0.022321	 0.01445	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62598	 77090	 0.015957	 0.040421	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62599	 77088	 0.00875	 0.015379	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62600	 62605	 0.001257	 0.005214	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62600	 77088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62600	 77088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62601	 62605	 0.000593	 0.001779	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62601	 77089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62601	 77089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62602	 62603	 0.00555	 0.014064	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77089	 62602	 0.002643	 0.012321	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62603	 77109	 0.085457	 0.061779	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62604	 62605	 0.003271	 0.007886	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62604	 62690	 0.0021	 0.007343	 0.00244	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62604	 62985	 0.009186	 0.037929	 0.00897	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76729	 62604	 0.000393	 0.002729	 0.00103	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62604	 77090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62604	 77090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62604	 77097	 0.002686	 0.014986	 0.00383	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62604	 77111	 0.003314	 0.0117	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62605	 62639	 0.001007	 0.003664	 0.00112	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62605	 77097	 0.003521	 0.014543	 0.00344	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62606	 62607	 0.001036	 0.004157	 0.00105	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62606	 62610	 0.001143	 0.004343	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62607	 77097	 0.001429	 0.005543	 0.00148	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62608	 62609	 0.001021	 0.003871	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62608	 77097	 0.001021	 0.004229	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62609	 62612	 0.00105	 0.004193	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62609	 77091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62609	 77091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62610	 62611	 0.00025	 0.001436	 0.00041	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62610	 62612	 0.000664	 0.002014	 0.00044	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76729	 62611	 0.000243	 0.001307	 0.00036	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62612	 62618	 0.001286	 0.004893	 0.00137	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62612	 77092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62612	 77092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62613	 62614	 0.004421	 0.007064	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77090	 62613	 0.028493	 0.018443	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62614	 62615	 0.0206	 0.014593	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76730	 62614	 0.007607	 0.015636	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62614	 77094	 0.004357	 0.011043	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62616	 77093	 0.008929	 0.017679	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62616	 77101	 0.005721	 0.0164	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62617	 62618	 0.0016	 0.004021	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62617	 62626	 0.00205	 0.008521	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62617	 77093	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62617	 77093	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62618	 62620	 0.001036	 0.004136	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62618	 62710	 0.0012	 0.0048	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62618	 77094	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62618	 77094	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62619	 62716	 0.01295	 0.010664	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77094	 62619	 0.007971	 0.015786	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62620	 62621	 0.001014	 0.003693	 0.00113	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62620	 77095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62620	 77095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62621	 77099	 0.001043	 0.00365	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77067	 62622	 0.009164	 0.014629	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62622	 77100	 0.0075	 0.017143	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62623	 77096	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77096	 62624	 6.4e-05	 0.001079	 0.01021	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62624	 77099	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62624	 77240	 0.006286	 0.071164	 0.68746	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62625	 62638	 0.002521	 0.008836	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77100	 62625	 0.0027	 0.011979	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62625	 77101	 0.024229	 0.015686	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62625	 77102	 0.010229	 0.017993	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77099	 62626	 0.001257	 0.005036	 0.00127	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62626	 77101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62626	 77101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77099	 62627	 0.002007	 0.008043	 0.00203	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62627	 77102	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62627	 77102	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62628	 62629	 0.006457	 0.013214	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77102	 62628	 0.004979	 0.0132	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62629	 62720	 0.002721	 0.0127	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77093	 62629	 0.004207	 0.0129	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62630	 62633	 0.001607	 0.004307	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62630	 77103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62630	 77103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62631	 62725	 0.004207	 0.0129	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77102	 62631	 0.012914	 0.029536	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77103	 62631	 0.005714	 0.014479	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62631	 77105	 0.007343	 0.015093	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77103	 62632	 0.005821	 0.013314	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62632	 77150	 0.005121	 0.012979	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62633	 77104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62633	 77104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62634	 77105	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62634	 77105	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62635	 62636	 0.005814	 0.013293	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62635	 62904	 0.007257	 0.016679	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76715	 62635	 0.002857	 0.0196	 0.00036	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77069	 62636	 0.015871	 0.040807	 0.00063	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77072	 62636	 0.008736	 0.015364	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77102	 62636	 0.007793	 0.022907	 0.00047	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62637	 62638	 0.003964	 0.009057	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77072	 62637	 0.008664	 0.01715	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77102	 62638	 0.021179	 0.015	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77104	 62638	 0.03255	 0.025757	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77097	 62639	 0.002179	 0.009979	 0.00256	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62639	 77106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62639	 77106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62640	 62775	 0.005107	 0.013136	 0.00325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62640	 77107	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62640	 77107	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62641	 62644	 0.008871	 0.017564	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62641	 62645	 0.054757	 0.049407	 0.00083	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77107	 62641	 0.005764	 0.013186	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62642	 62658	 0.008621	 0.019721	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77107	 62642	 0.021464	 0.049086	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62643	 62644	 0.041979	 0.029736	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62645	 62647	 0.03695	 0.036293	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62646	 62649	 0.017586	 0.026371	 0.00048	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62646	 62650	 0.018293	 0.011843	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62647	 62651	 0.0178	 0.012607	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62647	 63320	 0.0217	 0.017171	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62648	 62768	 0.012786	 0.009057	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62649	 62769	 0.009764	 0.008036	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77107	 62649	 0.005193	 0.011871	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62650	 62770	 0.01175	 0.007607	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62651	 62771	 0.011729	 0.007593	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62652	 62656	 0.023343	 0.015114	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62652	 62657	 0.005793	 0.014679	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77107	 62652	 0.008171	 0.025064	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62653	 62658	 0.008279	 0.020971	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62653	 62667	 0.011779	 0.0242	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77090	 62653	 0.036721	 0.157007	 0.00355	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62654	 62658	 0.028329	 0.018343	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62655	 62662	 0.008786	 0.014029	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62655	 62678	 0.013629	 0.014557	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62655	 62767	 0.017457	 0.034571	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62656	 62767	 0.022464	 0.022071	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62657	 62659	 0.005793	 0.016621	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62657	 62663	 0.023379	 0.015136	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62658	 62659	 0.0058	 0.014686	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62660	 62680	 0.005771	 0.013193	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62660	 62766	 0.003007	 0.007621	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62661	 62767	 0.011536	 0.008171	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62662	 62663	 0.017971	 0.016214	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62664	 62675	 0.019586	 0.013871	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62665	 62669	 0.007886	 0.012593	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62665	 62674	 0.010493	 0.0143	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62665	 77160	 0.070457	 0.0775	 0.00104	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62666	 62674	 0.023436	 0.021	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62667	 62669	 0.0067	 0.025664	 0.00073	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62668	 62671	 0.009193	 0.01475	 0.00027	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62668	 62688	 0.012479	 0.021943	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62669	 62674	 0.022021	 0.030043	 0.00054	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62669	 77160	 0.019579	 0.044779	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62670	 77108	 0.009079	 0.017979	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62671	 62672	 0.003586	 0.006671	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62672	 62675	 0.005007	 0.011364	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62672	 62684	 0.002243	 0.009593	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62673	 62683	 0.02315	 0.0164	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62673	 62700	 0.007886	 0.011821	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62674	 62678	 0.016143	 0.037486	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62674	 62683	 0.005829	 0.022436	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62675	 62683	 0.018079	 0.014879	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62676	 62677	 0.026343	 0.01705	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62676	 62679	 0.004371	 0.009986	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62676	 62700	 0.011014	 0.019371	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62678	 62680	 0.003693	 0.009793	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62679	 62681	 0.011736	 0.0076	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62679	 77119	 0.007279	 0.018857	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62680	 62752	 0.007257	 0.020821	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62682	 62752	 0.017571	 0.013907	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62683	 77113	 0.006564	 0.0306	 0.00071	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62684	 77108	 0.002107	 0.010964	 0.00024	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62685	 62697	 0.011864	 0.008407	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62686	 62687	 0.000793	 0.002064	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62686	 62689	 0.001171	 0.002814	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62686	 62695	 0.00165	 0.0045	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62687	 62689	 0.001964	 0.005379	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62687	 77108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62687	 77108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62688	 62693	 0.011371	 0.037943	 0.0006	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62689	 62691	 0.001121	 0.003786	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62689	 77109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62689	 77109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62690	 62691	 0.000857	 0.00355	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62691	 62692	 0.001921	 0.005086	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62692	 77110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62692	 77110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62692	 77111	 0.001436	 0.005593	 0.00149	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62693	 77112	 0.001436	 0.007114	 0.00017	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62694	 77111	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77112	 62694	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62695	 62714	 0.003636	 0.0096	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77111	 62695	 0.002421	 0.00985	 0.0024	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62695	 77113	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62695	 77113	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62696	 62697	 0.004407	 0.007757	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62696	 62699	 0.016543	 0.01625	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62696	 62705	 0.011721	 0.0083	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77113	 62696	 0.005957	 0.015086	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62698	 62699	 0.011729	 0.008307	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62699	 62703	 0.004414	 0.008743	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62700	 62701	 0.011736	 0.0076	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62700	 62742	 0.011014	 0.021807	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62702	 62703	 0.002914	 0.008357	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62702	 62731	 0.0044	 0.011143	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62704	 62705	 0.005243	 0.008829	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62704	 77115	 0.00525	 0.014886	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62706	 62707	 0.009029	 0.007429	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77113	 62706	 0.002407	 0.010307	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62707	 62711	 0.004864	 0.016236	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62708	 62713	 0.003529	 0.007229	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77112	 62708	 0.003536	 0.010143	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62709	 62713	 0.0036	 0.006693	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77112	 62709	 0.005843	 0.014807	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62709	 77114	 0.005614	 0.010436	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62710	 62715	 0.00135	 0.0056	 0.00131	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77111	 62710	 0.001	 0.003536	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62711	 62712	 0.011729	 0.008307	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62711	 62713	 0.003593	 0.010557	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77110	 62712	 0.005479	 0.012729	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62714	 62715	 0.001043	 0.004086	 0.00107	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62714	 62730	 0.002171	 0.006507	 0.00146	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62715	 77114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62715	 77114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62716	 62729	 0.003143	 0.016821	 0.00051	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77093	 62716	 0.002957	 0.013107	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62717	 62718	 0.005793	 0.014671	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62717	 62732	 0.020057	 0.014207	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62718	 62719	 0.002907	 0.013893	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62718	 62726	 0.017664	 0.013979	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62719	 62725	 0.006593	 0.011593	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77105	 62719	 0.005807	 0.0147	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62720	 62721	 0.017207	 0.012186	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62720	 62728	 0.003271	 0.012736	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62721	 62725	 0.01165	 0.009221	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62722	 62726	 0.011721	 0.008307	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62722	 62728	 0.007221	 0.011529	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62723	 62724	 0.004379	 0.010014	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62723	 62729	 0.00405	 0.01025	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62723	 77116	 0.0129	 0.020586	 0.00047	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62724	 62727	 0.004393	 0.007014	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62727	 62732	 0.022207	 0.017571	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62728	 62729	 0.012986	 0.0092	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77114	 62728	 0.01685	 0.01655	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62730	 77115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62730	 77115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62731	 62742	 0.007021	 0.023171	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62731	 77117	 0.006429	 0.031386	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62731	 77120	 0.005786	 0.013236	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62732	 62789	 0.011293	 0.022357	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62732	 77116	 0.008329	 0.01905	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62733	 62736	 0.006307	 0.012907	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62733	 62917	 0.023064	 0.018986	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62733	 62946	 0.017714	 0.01255	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62734	 62737	 0.0021	 0.007014	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77099	 62734	 0.007743	 0.029429	 0.00824	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62734	 77116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62734	 77116	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62735	 62747	 0.009636	 0.014036	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62735	 77117	 0.013829	 0.016207	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77116	 62736	 0.006136	 0.012607	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62736	 77117	 0.0025	 0.012007	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62737	 77117	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62737	 77117	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62738	 62743	 0.002057	 0.008	 0.00214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62738	 77118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62738	 77118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62739	 62740	 0.01765	 0.017829	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77117	 62739	 0.013643	 0.015993	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62740	 62948	 0.008757	 0.013979	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62741	 62743	 0.001743	 0.00545	 0.00158	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62741	 77119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62741	 77119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62743	 77120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62743	 77120	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62744	 62746	 0.011736	 0.023229	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77120	 62744	 0.0179	 0.014736	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62745	 62747	 0.005664	 0.01435	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62745	 77121	 0.005793	 0.013257	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62746	 62753	 0.006043	 0.013821	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62746	 77121	 0.00375	 0.0166	 0.0005	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62748	 62750	 0.001229	 0.004343	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62748	 62949	 0.0029	 0.00855	 0.00199	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62748	 77121	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62748	 77121	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62749	 62751	 0.004107	 0.012593	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62749	 62762	 0.006821	 0.018071	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62750	 62949	 0.001607	 0.003871	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76717	 62751	 0.003964	 0.013886	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76717	 62751	 0.003964	 0.013886	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62751	 77122	 0.010021	 0.020507	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77119	 62752	 0.0041	 0.012571	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62753	 62778	 0.011479	 0.015993	 0.00027	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77119	 62753	 0.006786	 0.017986	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62754	 62783	 0.003571	 0.013571	 0.0038	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62754	 77122	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62754	 77122	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62755	 62766	 0.0043	 0.009829	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62755	 62778	 0.003607	 0.014086	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62755	 62779	 0.018214	 0.011793	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62756	 62768	 0.018321	 0.011864	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62756	 77125	 0.008807	 0.015479	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62757	 62768	 0.025693	 0.0182	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62757	 62774	 0.018064	 0.014871	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62757	 62776	 0.017857	 0.0147	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62758	 62773	 0.001636	 0.004443	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62758	 63321	 0.006057	 0.0146	 0.00412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62758	 77123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62758	 77123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62759	 63325	 0.011943	 0.016279	 0.00036	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77123	 62759	 0.006507	 0.01475	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62760	 62761	 0.023007	 0.0149	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62760	 62764	 0.008857	 0.017543	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62760	 77125	 0.0173	 0.015614	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62761	 77126	 0.022893	 0.018114	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62762	 62778	 0.00575	 0.014571	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62763	 62764	 0.005729	 0.013107	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 62763	 0.009107	 0.023071	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 62765	 0.034479	 0.022321	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62767	 77125	 0.0093	 0.031779	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77107	 62768	 0.01305	 0.020821	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62769	 62774	 0.018929	 0.012257	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62770	 62772	 0.0187	 0.012107	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77123	 62771	 0.034379	 0.022257	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62772	 62774	 0.009521	 0.016036	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62772	 77124	 0.020486	 0.016214	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62773	 62784	 0.001879	 0.005121	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62773	 77124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62773	 77124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62774	 62777	 0.022707	 0.0147	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62775	 62783	 0.003457	 0.009286	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62775	 77125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62775	 77125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77125	 62776	 0.009007	 0.015843	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62777	 62782	 0.023943	 0.016957	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62778	 62780	 0.017336	 0.017029	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 62778	 0.014571	 0.0418	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62779	 62781	 0.025936	 0.020529	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77125	 62781	 0.008386	 0.019021	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62782	 77126	 0.012193	 0.019457	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62783	 62784	 0.002707	 0.009293	 0.00223	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62783	 77126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62783	 77126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62784	 77127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62784	 77127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62785	 62786	 0.023929	 0.0197	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62785	 62787	 0.037936	 0.031229	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77127	 62785	 0.0099	 0.015807	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77123	 62786	 0.04445	 0.035179	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62787	 77158	 0.025629	 0.045071	 0.00085	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62788	 77158	 0.009693	 0.0278	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62789	 62790	 0.024107	 0.015607	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62790	 62791	 0.004407	 0.008721	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62790	 62792	 0.01775	 0.012571	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62791	 62918	 0.004329	 0.0099	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62792	 62793	 0.0088	 0.014043	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62792	 62798	 0.02345	 0.018564	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62793	 62794	 0.004107	 0.014029	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62794	 62795	 0.010536	 0.014364	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62794	 62907	 0.00575	 0.014564	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77105	 62794	 0.009086	 0.031029	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62796	 62797	 0.0469	 0.033221	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62796	 62920	 0.006421	 0.01315	 0.00032	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62797	 62798	 0.013729	 0.016086	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62797	 62912	 0.005864	 0.020036	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62797	 62923	 0.0185	 0.016693	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62797	 77153	 0.008943	 0.017707	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62799	 62802	 0.008314	 0.021364	 0.00529	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62799	 63418	 0.044614	 0.107643	 0.03044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62800	 62801	 0.048071	 0.031121	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62801	 62803	 0.00735	 0.017064	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62801	 62804	 0.014993	 0.027871	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62801	 63415	 0.226964	 0.399657	 0.00752	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62801	 77128	 0.0085	 0.025586	 0.0005	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62802	 77128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62802	 77128	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62803	 62804	 0.013507	 0.019686	 0.00044	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62804	 62805	 0.019364	 0.034057	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62804	 62806	 0.0369	 0.0589	 0.00136	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62804	 77133	 0.064429	 0.103357	 0.00191	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62805	 62812	 0.01825	 0.048364	 0.00123	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62807	 62808	 0.07585	 0.062436	 0.00126	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62807	 62809	 0.041871	 0.037521	 0.00076	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76736	 62807	 0.03695	 0.075929	 0.00145	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62808	 62810	 0.019736	 0.013979	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62808	 77144	 0.025093	 0.066514	 0.00169	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62809	 62810	 0.017836	 0.019043	 0.0004	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62810	 77129	 0.053879	 0.038164	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62810	 77134	 0.024636	 0.043329	 0.00081	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62811	 62813	 0.00185	 0.006543	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62811	 62838	 0.001893	 0.006586	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62811	 77129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62811	 77129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62812	 77131	 0.012286	 0.047971	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62813	 62818	 0.004414	 0.0144	 0.00382	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62814	 62815	 0.0261	 0.021486	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62814	 62816	 0.01	 0.023207	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62815	 77130	 0.025436	 0.016471	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62815	 77131	 0.014471	 0.019021	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62816	 77138	 0.010293	 0.044014	 0.00099	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62817	 62818	 0.001736	 0.006143	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62817	 62841	 0.002286	 0.007843	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62817	 77130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62817	 77130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62818	 62821	 0.003329	 0.011607	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62818	 77131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62818	 77131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62819	 62820	 0.062136	 0.044014	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62820	 77132	 0.03485	 0.031229	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62821	 62822	 0.005257	 0.018029	 0.00432	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62821	 62847	 0.00555	 0.01395	 0.00361	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62821	 77132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62821	 77132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62822	 77133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62822	 77133	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62823	 62824	 0.015329	 0.027657	 0.0004	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62823	 62829	 0.027671	 0.027186	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62824	 62825	 0.016486	 0.011679	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77133	 62824	 0.014836	 0.033643	 0.00067	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62825	 62826	 0.022893	 0.014821	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62826	 62827	 0.017614	 0.017307	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77133	 62826	 0.021343	 0.042257	 0.00062	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62827	 62830	 0.036786	 0.029107	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62828	 62829	 0.014164	 0.010036	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62829	 62831	 0.109136	 0.077314	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62830	 62831	 0.069086	 0.044729	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62831	 62850	 0.0304	 0.048521	 0.00111	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62832	 62833	 0.001829	 0.009071	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76906	 62832	 0.008614	 0.042743	 0.00102	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62832	 77143	 0.030143	 0.035336	 0.00061	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62833	 62834	 0.002843	 0.011279	 0.00032	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62834	 62835	 0.005514	 0.016221	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62835	 62836	 0.005529	 0.014014	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62835	 77144	 0.021893	 0.029871	 0.00054	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62836	 77134	 0.005564	 0.011393	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62837	 62838	 0.001143	 0.004457	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62837	 62874	 0.002821	 0.011293	 0.00284	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62837	 77134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62837	 77134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77134	 62839	 0.009593	 0.016864	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62839	 77137	 0.010336	 0.014086	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62840	 77138	 0.036586	 0.025921	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62841	 62859	 0.001629	 0.0056	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62842	 62844	 0.0139	 0.0163	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62842	 77139	 0.011936	 0.023636	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62843	 62844	 0.009214	 0.016207	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77130	 62843	 0.0349	 0.0226	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62844	 77141	 0.006464	 0.013229	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62845	 62847	 0.002657	 0.008957	 0.00223	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62845	 62862	 0.003493	 0.011993	 0.00287	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77014	 62845	 0.013471	 0.049014	 0.01501	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62845	 77135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62845	 77135	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62846	 62864	 0.018614	 0.01205	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62846	 62865	 0.017236	 0.016936	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77135	 62846	 0.00695	 0.012929	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62847	 62868	 0.002686	 0.007093	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62847	 77136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62847	 77136	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62848	 62849	 0.008479	 0.021471	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62848	 77142	 0.00465	 0.019414	 0.00056	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62849	 62850	 0.018843	 0.033143	 0.00062	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77082	 62850	 0.027664	 0.070086	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62851	 77143	 0.019721	 0.014257	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62852	 62853	 0.001029	 0.00425	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62852	 62872	 0.001329	 0.005329	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62853	 62873	 0.001021	 0.003579	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62854	 77144	 0.016736	 0.016443	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62855	 62856	 0.001107	 0.003457	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62855	 62875	 0.001207	 0.003936	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62856	 62857	 0.001557	 0.00375	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62856	 77137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62856	 77137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62857	 62858	 0.001007	 0.004029	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62857	 77138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62857	 77138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62858	 62860	 0.00105	 0.004286	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62859	 62860	 0.000521	 0.002157	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62859	 77139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62859	 77139	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62860	 62861	 0.001643	 0.0045	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62860	 77140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62860	 77140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62861	 62862	 0.001121	 0.004364	 0.00116	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62861	 62880	 0.000943	 0.003243	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62862	 77141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62862	 77141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62863	 62864	 0.02065	 0.013371	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62863	 62884	 0.0087	 0.017221	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62864	 62885	 0.004357	 0.009964	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62865	 62888	 0.022143	 0.019979	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62865	 77148	 0.0057	 0.014436	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77136	 62866	 0.02785	 0.019729	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62867	 62891	 0.004486	 0.010257	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77136	 62867	 0.027136	 0.019221	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62867	 77142	 0.010493	 0.014307	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62868	 77142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62868	 77142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62869	 62870	 0.013786	 0.008921	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77142	 62869	 0.006707	 0.0118	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62870	 62894	 0.017879	 0.012664	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62871	 62894	 0.013957	 0.018343	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62871	 62895	 0.012636	 0.008179	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62872	 77143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62872	 77143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62873	 62874	 0.001386	 0.004514	 0.0012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62874	 62875	 0.001007	 0.004036	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62874	 77144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62874	 77144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62875	 77145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62875	 77145	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62876	 62877	 0.008407	 0.012257	 0.00028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77137	 62876	 0.0153	 0.016664	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77145	 62876	 0.012771	 0.019571	 0.00027	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76985	 62877	 0.005114	 0.011693	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77138	 62877	 0.006607	 0.015114	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62878	 62879	 0.001014	 0.004064	 0.00102	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62879	 62881	 0.001257	 0.004186	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62879	 77146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62879	 77146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62880	 62881	 0.000643	 0.002293	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62881	 77147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62881	 77147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62882	 62883	 0.007043	 0.008257	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62882	 62884	 0.018429	 0.018614	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77141	 62882	 0.006557	 0.011536	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76979	 62883	 0.007943	 0.018021	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76978	 62884	 0.008407	 0.019221	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62885	 62886	 0.0029	 0.008307	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76978	 62886	 0.003271	 0.008671	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62887	 77148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62887	 77148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62888	 62890	 0.0121	 0.009579	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77148	 62889	 0.015629	 0.011071	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62890	 62892	 0.008464	 0.015271	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77148	 62890	 0.005629	 0.014921	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62891	 62892	 0.002914	 0.006657	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62893	 62894	 0.008743	 0.01395	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76978	 62893	 0.0157	 0.053621	 0.00116	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62895	 62897	 0.031793	 0.025164	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62898	 62903	 0.072779	 0.051557	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76928	 62899	 0.055479	 0.170229	 0.00461	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76712	 62900	 0.453807	 0.294329	 0.0056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62901	 63357	 0.018721	 0.07785	 0.01819	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76709	 62901	 0.005214	 0.036136	 0.02119	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62901	 77149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62901	 77149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62902	 62903	 0.030893	 0.042143	 0.00075	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76928	 62902	 0.053757	 0.057414	 0.00121	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76915	 62903	 0.035357	 0.089571	 0.00177	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62904	 77151	 0.022457	 0.015907	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62905	 62911	 0.001971	 0.00675	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62905	 77150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62905	 77150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62906	 77152	 0.017757	 0.011493	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77105	 62907	 0.005764	 0.019686	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62908	 77151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62908	 77151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62909	 62910	 0.009343	 0.014914	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62909	 62913	 0.010464	 0.01715	 0.0003	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77151	 62909	 0.014314	 0.019529	 0.00035	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62910	 62915	 0.00985	 0.025314	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77150	 62910	 0.002586	 0.011464	 0.00034	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62910	 77152	 0.017364	 0.015664	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62911	 77152	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62911	 77152	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77152	 62912	 0.0027	 0.013407	 0.00032	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62914	 62915	 0.01605	 0.014386	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77152	 62914	 0.012329	 0.024414	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62914	 77161	 0.053143	 0.037643	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62915	 77153	 0.007314	 0.013593	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62916	 77153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62916	 77153	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62917	 62918	 0.0043	 0.009836	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62917	 62947	 0.005921	 0.016979	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62919	 62953	 0.017186	 0.0136	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62920	 62921	 0.005779	 0.016579	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62920	 62925	 0.018971	 0.015014	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62921	 62953	 0.007357	 0.016829	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77153	 62922	 0.024221	 0.015679	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62923	 62924	 0.023407	 0.015157	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62924	 62927	 0.023929	 0.015493	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62925	 77154	 0.0138	 0.020107	 0.00046	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62926	 62930	 0.016414	 0.01805	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62926	 62931	 0.041057	 0.026579	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77153	 62926	 0.018664	 0.032821	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62927	 62931	 0.018736	 0.016907	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62927	 77154	 0.010443	 0.023879	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62928	 62988	 0.006757	 0.018514	 0.00403	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62928	 77154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62928	 77154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62929	 62932	 0.011443	 0.015607	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62929	 62957	 0.013971	 0.024571	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62930	 77162	 0.009193	 0.014671	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62932	 62937	 0.023543	 0.016679	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62933	 77162	 0.024229	 0.017164	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62934	 62935	 0.020936	 0.017229	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62934	 62977	 0.035779	 0.025343	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62935	 62936	 0.013657	 0.014579	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62936	 62939	 0.026121	 0.016914	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77154	 62936	 0.010721	 0.030764	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62937	 62940	 0.014821	 0.024964	 0.00036	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77154	 62937	 0.021807	 0.034807	 0.0008	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62938	 62942	 0.020093	 0.018129	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62938	 77162	 0.017507	 0.051486	 0.00106	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62940	 62945	 0.015229	 0.01785	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62941	 62979	 0.023429	 0.015171	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62942	 62943	 0.016571	 0.018229	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62943	 62945	 0.017143	 0.027357	 0.00063	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62944	 62945	 0.022814	 0.016157	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62945	 62964	 0.013057	 0.029864	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62947	 62948	 0.005679	 0.012979	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62948	 77155	 0.004057	 0.012436	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62949	 62958	 0.004579	 0.012107	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62949	 77155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62949	 77155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62950	 62954	 0.011779	 0.017664	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62950	 62955	 0.006486	 0.014829	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76717	 62950	 0.002171	 0.012329	 0.00022	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62951	 62952	 0.008579	 0.022671	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76717	 62951	 0.00375	 0.014879	 0.00042	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62952	 62956	 0.0135	 0.017564	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62953	 62957	 0.00935	 0.021386	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77155	 62953	 0.004329	 0.021464	 0.00051	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77155	 62954	 0.013686	 0.014614	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62955	 62960	 0.0132	 0.030636	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62956	 62960	 0.009164	 0.014621	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62956	 77157	 0.014671	 0.030014	 0.00074	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62958	 63378	 0.017629	 0.059414	 0.01477	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	62958	 77156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62958	 77156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62959	 77157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62959	 77157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62960	 62961	 0.004436	 0.013614	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62961	 62962	 0.022214	 0.017579	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62961	 62965	 0.011386	 0.018264	 0.00034	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77156	 62963	 0.020143	 0.025007	 0.00054	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62964	 62968	 0.014921	 0.026236	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77156	 62964	 0.017964	 0.052836	 0.00109	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62965	 62966	 0.003693	 0.011329	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62965	 62967	 0.015936	 0.017529	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77157	 62965	 0.007243	 0.041179	 0.00074	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62966	 62970	 0.00565	 0.011564	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62967	 62971	 0.034164	 0.022114	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62968	 62969	 0.023436	 0.015171	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62970	 62972	 0.030886	 0.025421	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62971	 62974	 0.034636	 0.024536	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62972	 62975	 0.046529	 0.041979	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62973	 62975	 0.026707	 0.023929	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62973	 63307	 0.075136	 0.055286	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62974	 62976	 0.047629	 0.030836	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62975	 62976	 0.009986	 0.022843	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62975	 63309	 0.06815	 0.053936	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62975	 77246	 0.038093	 0.0611	 0.00113	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62976	 77260	 0.027707	 0.115679	 0.00334	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62977	 62978	 0.026543	 0.018807	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62977	 62979	 0.026207	 0.018564	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62977	 77162	 0.006986	 0.018507	 0.00047	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62980	 63317	 0.014521	 0.036514	 0.00946	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62980	 77158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62980	 77158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62981	 63380	 0.234464	 0.376557	 0.00696	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77149	 62981	 0.274236	 0.4003	 0.00906	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77041	 62983	 0.004314	 0.029464	 0.05309	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	62983	 77159	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62983	 77159	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62985	 77160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62985	 77160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76712	 62986	 0.554564	 0.393764	 0.00622	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77159	 62987	 0.003657	 0.014386	 0.00376	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62987	 77161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62987	 77161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77159	 62988	 0.00345	 0.014029	 0.00341	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62988	 77162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62988	 77162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77158	 62989	 0.045736	 0.029614	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76899	 62990	 0.036157	 0.160186	 0.00365	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77084	 62990	 0.04035	 0.082921	 0.00158	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	62991	 62994	 0.036164	 0.14505	 0.03664	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62991	 62995	 0.0344	 0.130964	 0.03674	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62991	 77163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62991	 77163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62992	 63012	 0.0085	 0.030914	 0.00946	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76701	 62992	 0.007264	 0.028264	 0.00755	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62992	 77164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62992	 77164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62992	 77171	 0.00795	 0.037064	 0.00918	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62993	 66446	 0.314386	 0.50315	 0.01161	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	62994	 62999	 0.015514	 0.083571	 0.02298	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76826	 62994	 0.035543	 0.168607	 0.04067	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62994	 77165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62994	 77165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76826	 62995	 0.023707	 0.113464	 0.03982	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	62995	 77166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62995	 77166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62996	 77167	 0.285393	 0.202286	 0.0032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	62997	 63032	 0.008471	 0.038157	 0.01016	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76734	 62997	 0.015593	 0.080886	 0.01976	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	62997	 77167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62997	 77167	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	62997	 77742	 0.072436	 0.192064	 0.04513	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	62998	 63000	 0.001557	 0.005921	 0.00166	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62998	 63032	 0.002257	 0.009036	 0.00228	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	62999	 77180	 0.007036	 0.035607	 0.00991	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63000	 63029	 0.004043	 0.012636	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63000	 77168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63000	 77168	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63000	 77180	 0.001279	 0.006471	 0.0018	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77168	 63001	 0.003436	 0.0153	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63001	 77181	 0.005686	 0.027764	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76735	 63002	 0.011343	 0.044129	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63002	 77170	 0.017721	 0.060536	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76810	 63003	 0.000336	 0.004314	 0.04055	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63003	 77169	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76812	 63004	 0.0023	 0.010014	 0.00286	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63004	 77171	 0.001757	 0.009307	 0.00236	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63004	 77173	 0.001986	 0.004986	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63005	 63006	 0.00045	 0.004979	 0.00946	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63005	 77171	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77172	 63005	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63006	 66524	 0.01065	 0.148693	 0.30293	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76811	 63006	 0.0002	 0.0026	 0.00979	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63006	 77173	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77174	 63006	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63007	 63008	 0.012864	 0.008329	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63008	 63009	 0.013571	 0.009614	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77174	 63008	 0.004786	 0.012121	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63010	 63011	 0.028286	 0.020036	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63010	 63014	 0.013529	 0.041514	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77172	 63010	 0.01385	 0.031679	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63012	 63015	 0.011957	 0.073529	 0.02122	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76701	 63012	 0.000543	 0.008264	 0.00305	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76728	 63012	 0.013607	 0.08625	 0.02343	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77172	 63013	 0.070179	 0.055543	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76702	 63014	 0.052071	 0.173729	 0.00276	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77164	 63014	 0.020136	 0.053379	 0.00136	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63015	 63016	 0.004129	 0.025364	 0.00731	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63016	 63018	 0.000979	 0.005736	 0.00156	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63017	 63020	 0.002743	 0.0096	 0.00318	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76701	 63017	 0.010943	 0.10515	 0.03064	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63017	 77175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63017	 77175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63018	 63020	 0.0025	 0.008421	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63018	 63024	 0.003029	 0.011507	 0.00322	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63018	 77176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63018	 77176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77176	 63019	 0.0441	 0.043321	 0.00073	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63020	 63024	 0.001571	 0.006293	 0.00159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63020	 77177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63020	 77177	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63021	 63022	 0.009107	 0.019143	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77175	 63021	 0.011086	 0.022786	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63022	 63023	 0.009107	 0.021143	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63023	 63025	 0.010314	 0.019179	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63024	 63026	 0.008	 0.037786	 0.01209	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77177	 63025	 0.008814	 0.025921	 0.00053	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63025	 78372	 0.0316	 0.1985	 0.00434	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63027	 77181	 0.029543	 0.047157	 0.00109	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76708	 63028	 0.040686	 0.124836	 0.00338	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63028	 77178	 0.017021	 0.029936	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63029	 63032	 0.002936	 0.010693	 0.00327	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63029	 77178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63029	 77178	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63030	 77179	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76727	 63031	 0.0035	 0.0363	 0.06979	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63031	 77182	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63031	 77182	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63033	 72475	 0.013357	 0.080864	 0.00253	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76702	 63033	 0.010093	 0.039421	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76702	 63033	 0.010093	 0.039421	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77164	 63033	 0.050457	 0.103264	 0.00254	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63034	 63036	 0.265757	 0.172157	 0.00328	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63035	 63036	 0.069936	 0.200621	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63035	 63038	 0.115479	 0.292693	 0.0058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63036	 63037	 0.081886	 0.363064	 0.00829	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76865	 63036	 0.035593	 0.191207	 0.00454	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76885	 63037	 0.086193	 0.382529	 0.01151	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63038	 77183	 0.16755	 0.424979	 0.00843	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63039	 63047	 0.176614	 0.328743	 0.0077	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76866	 63039	 0.1125	 0.25745	 0.00629	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 63040	 0.014243	 0.118307	 0.03118	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63040	 77183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63040	 77183	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63041	 63060	 0.244957	 0.334321	 0.00742	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63041	 63061	 0.089771	 0.227479	 0.00451	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76891	 63041	 0.080493	 0.213429	 0.00541	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63042	 63043	 0.205193	 0.132893	 0.00253	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76891	 63042	 0.391557	 0.353807	 0.00592	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63042	 77188	 0.146179	 0.334671	 0.00818	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63044	 63045	 0.005814	 0.038936	 0.01193	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76884	 63044	 0.011657	 0.091371	 0.02343	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63044	 77184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63044	 77184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63045	 63046	 0.005607	 0.039636	 0.01088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63047	 77185	 0.114636	 0.213243	 0.00499	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63048	 63055	 0.014679	 0.088807	 0.02269	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 63048	 0.011879	 0.067271	 0.01668	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63048	 77185	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63048	 77185	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63049	 77187	 0.066593	 0.117121	 0.0022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63050	 77186	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63050	 77186	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77186	 63051	 0.021407	 0.077929	 0.02388	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63051	 77187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63051	 77187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63052	 63053	 0.0042	 0.0171	 0.00416	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63052	 63054	 0.003636	 0.014543	 0.00366	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63053	 63063	 0.005821	 0.015393	 0.0036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 63053	 0.029021	 0.212779	 0.05499	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63053	 77188	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63053	 77188	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63054	 63062	 0.003136	 0.014614	 0.00362	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63054	 77189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63054	 77189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63055	 63059	 0.022229	 0.077829	 0.02581	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63055	 77190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63055	 77190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63056	 63064	 0.147943	 0.303036	 0.00746	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76724	 63056	 0.033064	 0.167271	 0.00291	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77185	 63056	 0.04745	 0.210229	 0.00479	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63057	 63060	 0.008107	 0.024871	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63057	 77191	 0.011471	 0.030414	 0.00077	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63058	 63063	 0.019186	 0.052593	 0.01144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63059	 77191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63059	 77191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76738	 63060	 0.075729	 0.155007	 0.00381	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77190	 63060	 0.105179	 0.240679	 0.00588	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63061	 77192	 0.028914	 0.085029	 0.00174	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63063	 77192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63063	 77192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77192	 63064	 0.090514	 0.088921	 0.0015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63065	 63069	 0.0145	 0.019779	 0.00035	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63065	 77194	 0.005171	 0.012007	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63066	 63075	 0.005586	 0.008914	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63066	 63223	 0.021629	 0.019514	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63066	 77194	 0.004157	 0.022157	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63067	 63068	 0.00885	 0.00945	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63067	 63077	 0.019679	 0.015571	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63068	 63072	 0.008186	 0.018729	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63069	 63071	 0.007314	 0.018521	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63069	 63080	 0.011179	 0.022136	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63070	 63086	 0.0016	 0.005586	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63070	 77193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63070	 77193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77193	 63071	 0.028614	 0.020686	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63071	 77196	 0.003257	 0.0175	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63072	 77194	 0.005507	 0.012793	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63072	 77196	 0.011371	 0.026014	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63073	 63091	 0.001079	 0.004243	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63073	 63237	 0.007121	 0.019393	 0.00427	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63073	 77194	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63073	 77194	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63074	 63093	 0.012014	 0.024693	 0.00047	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77194	 63074	 0.005143	 0.007007	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63075	 63076	 0.0181	 0.011714	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63076	 63222	 0.025457	 0.018036	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76722	 63076	 0.003714	 0.010529	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76722	 63077	 0.020114	 0.020314	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63078	 77195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63078	 77195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63079	 63080	 0.019186	 0.012421	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77195	 63079	 0.012007	 0.012129	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63080	 63081	 0.015136	 0.0098	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63081	 63082	 0.0065	 0.012864	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77193	 63082	 0.005829	 0.016721	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63083	 63102	 0.003714	 0.009414	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63083	 63106	 0.004836	 0.012243	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63084	 63085	 0.004429	 0.010129	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63084	 63106	 0.002314	 0.006136	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63084	 77201	 0.007093	 0.016221	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63085	 63116	 0.024564	 0.020221	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77193	 63085	 0.003779	 0.011593	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63086	 63087	 0.001407	 0.005721	 0.00139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63087	 63114	 0.002979	 0.011307	 0.00316	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63087	 77196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63087	 77196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63087	 77197	 0.000393	 0.003929	 0.00106	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63088	 77197	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63088	 77197	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63089	 63092	 0.001	 0.004014	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76713	 63089	 0.003036	 0.012621	 0.00294	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77197	 63089	 0.002157	 0.007393	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63089	 77198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63089	 77198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77198	 63090	 0.012129	 0.019357	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63091	 63092	 0.001236	 0.004686	 0.00131	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63092	 63131	 0.000636	 0.002479	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63092	 77199	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63092	 77199	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63093	 63094	 0.014457	 0.010236	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63093	 63218	 0.011029	 0.019393	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77199	 63093	 0.005007	 0.017114	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63095	 63096	 0.023421	 0.016593	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77199	 63095	 0.04295	 0.030421	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63096	 77200	 0.013236	 0.026214	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63097	 77200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63097	 77200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63097	 77241	 0.005829	 0.022164	 0.00621	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63098	 63100	 0.00625	 0.014293	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63098	 63101	 0.021171	 0.01675	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63098	 63102	 0.023079	 0.023314	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63098	 63103	 0.01125	 0.011364	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63098	 63242	 0.020721	 0.013414	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63099	 63100	 0.015586	 0.011043	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63100	 63240	 0.021836	 0.017979	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77195	 63100	 0.002664	 0.013207	 0.00031	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63102	 63279	 0.006943	 0.012214	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63104	 63105	 0.011057	 0.007836	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63104	 63107	 0.021586	 0.025307	 0.00044	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63105	 63106	 0.005357	 0.005721	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63107	 63109	 0.008571	 0.016964	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63107	 63110	 0.011364	 0.0155	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63107	 77201	 0.001864	 0.011186	 0.00027	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63108	 63110	 0.019821	 0.014043	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63108	 63113	 0.032121	 0.022757	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63109	 63111	 0.013793	 0.027314	 0.0004	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63109	 63293	 0.014379	 0.032886	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63111	 63112	 0.0044	 0.010071	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63111	 77202	 0.003136	 0.013093	 0.00038	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63112	 63113	 0.00715	 0.010721	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63112	 63115	 0.027821	 0.021807	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63113	 63143	 0.007314	 0.014479	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63113	 63290	 0.008564	 0.021686	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63114	 63176	 0.004371	 0.013164	 0.00412	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63114	 77201	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63114	 77201	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77201	 63115	 0.007193	 0.016443	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63116	 63119	 0.02695	 0.021329	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63116	 63120	 0.004586	 0.013479	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77201	 63116	 0.007814	 0.0097	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63117	 63136	 0.005907	 0.014957	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63117	 63137	 0.014564	 0.014307	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63117	 77212	 0.018421	 0.016621	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63118	 63122	 0.001	 0.003886	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63118	 77202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63118	 77202	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63119	 63120	 0.0089	 0.01565	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77202	 63119	 0.021557	 0.015271	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63120	 77203	 0.004493	 0.011914	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63121	 63122	 0.001336	 0.005514	 0.00131	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77197	 63121	 0.00165	 0.007807	 0.0025	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63121	 77203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63121	 77203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63122	 63176	 0.003264	 0.009457	 0.00228	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63122	 77204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63122	 77204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63123	 63124	 0.0039	 0.008836	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77204	 63123	 0.003921	 0.011243	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63123	 77239	 0.017236	 0.0575	 0.00091	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63124	 63136	 0.005343	 0.012407	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63125	 63138	 0.0029	 0.011607	 0.00292	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63125	 63176	 0.005679	 0.019793	 0.00459	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63125	 63181	 0.002971	 0.01325	 0.0036	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63125	 77205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63125	 77205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63125	 77238	 0.000943	 0.009657	 0.00306	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63126	 63132	 0.001321	 0.005021	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63126	 77206	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63126	 77206	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63126	 77241	 0.00385	 0.014007	 0.00429	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63127	 63134	 0.004307	 0.00985	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 63127	 0.004171	 0.01105	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63128	 63135	 0.006821	 0.015836	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 63128	 0.006821	 0.017279	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63129	 63130	 0.012643	 0.008186	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63129	 63185	 0.004686	 0.010721	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77198	 63129	 0.007957	 0.015764	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 63129	 0.011736	 0.018729	 0.00043	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63129	 77207	 0.012793	 0.019593	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63131	 63132	 0.000971	 0.0037	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63132	 77207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63132	 77207	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77207	 63133	 0.020986	 0.013586	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77200	 63134	 0.008064	 0.018714	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77200	 63135	 0.010764	 0.015686	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63136	 63146	 0.006493	 0.011421	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77205	 63136	 0.007643	 0.040714	 0.00071	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63138	 63139	 0.001807	 0.006043	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63138	 63154	 0.004793	 0.012657	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63138	 77208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63138	 77208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63139	 63154	 0.002621	 0.006086	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63139	 77209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63139	 77209	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63140	 63163	 0.029857	 0.023629	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63140	 63179	 0.0213	 0.053957	 0.00107	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63140	 63292	 0.031193	 0.024686	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77209	 63141	 0.023529	 0.041379	 0.00078	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63142	 63151	 0.0045	 0.010286	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63142	 63168	 0.010721	 0.024521	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77205	 63142	 0.003043	 0.013486	 0.00041	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63143	 63175	 0.008693	 0.017793	 0.00044	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63144	 63145	 0.016729	 0.013771	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63145	 63156	 0.010714	 0.014607	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63145	 77212	 0.007393	 0.021207	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63146	 63147	 0.01135	 0.008043	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63148	 63149	 0.010179	 0.008057	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63148	 63166	 0.020107	 0.013014	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63148	 63168	 0.021086	 0.023193	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77209	 63148	 0.018786	 0.015464	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63150	 63151	 0.003664	 0.006814	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77208	 63150	 0.006464	 0.011364	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63152	 63179	 0.011736	 0.008314	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63153	 63158	 0.0233	 0.015086	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63153	 63165	 0.018136	 0.02895	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63153	 77210	 0.005829	 0.014757	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63154	 77210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63154	 77210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63155	 63161	 0.0393	 0.058921	 0.00107	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63155	 63300	 0.043664	 0.034557	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77210	 63155	 0.0111	 0.025386	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63156	 63157	 0.015414	 0.010921	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63158	 63178	 0.0221	 0.019936	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63159	 63178	 0.0169	 0.010943	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77209	 63159	 0.008871	 0.017557	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63160	 63164	 0.028064	 0.018171	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63160	 63165	 0.042329	 0.027407	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63161	 63162	 0.250029	 0.177193	 0.0028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63167	 63168	 0.034243	 0.022171	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63169	 63172	 0.011314	 0.039429	 0.00914	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63170	 63182	 0.063557	 0.045021	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63170	 77211	 0.038357	 0.040964	 0.00086	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77210	 63171	 0.02565	 0.075436	 0.00154	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63171	 77211	 0.016	 0.04815	 0.00094	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63171	 77213	 0.020721	 0.047393	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63172	 63181	 0.009593	 0.025357	 0.00594	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63172	 77211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63172	 77211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63173	 63174	 0.02095	 0.014843	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63173	 77213	 0.051893	 0.036757	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63174	 63182	 0.024271	 0.019207	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63175	 77212	 0.005279	 0.013364	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63176	 77212	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63176	 77212	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63177	 63178	 0.003943	 0.008071	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63177	 63179	 0.009029	 0.017879	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77208	 63178	 0.008729	 0.019957	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63179	 63180	 0.011507	 0.00745	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77212	 63179	 0.008514	 0.019464	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63181	 77213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63181	 77213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63181	 77241	 0.0053	 0.021221	 0.00535	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63182	 77243	 0.03365	 0.041771	 0.00091	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63183	 63184	 0.089036	 0.156614	 0.00294	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63183	 63192	 0.185421	 0.131379	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76872	 63184	 0.075107	 0.293529	 0.00651	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63184	 77243	 0.443914	 0.314929	 0.00498	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63185	 63191	 0.004293	 0.010879	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63186	 63190	 0.009829	 0.008086	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76714	 63186	 0.007357	 0.013686	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63186	 77239	 0.005064	 0.008086	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63187	 63188	 0.0053	 0.018179	 0.00436	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63187	 63298	 0.003629	 0.009879	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63187	 77241	 0.003657	 0.013893	 0.00389	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63188	 63205	 0.005114	 0.015393	 0.00481	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76713	 63189	 0.002257	 0.005664	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63189	 77214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63189	 77214	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63189	 77238	 0.002621	 0.006936	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77214	 63190	 0.006279	 0.014236	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63190	 77242	 0.012043	 0.031914	 0.00081	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63190	 77243	 0.119229	 0.0862	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76714	 63191	 0.0055	 0.018793	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63192	 77215	 0.081079	 0.066743	 0.00135	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63193	 63206	 0.087821	 0.062214	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 63194	 0.010907	 0.019186	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77214	 63194	 0.005343	 0.015721	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63195	 77215	 0.010829	 0.008571	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63196	 63198	 0.039643	 0.031371	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63197	 63198	 0.009079	 0.023329	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63197	 63215	 0.0213	 0.029036	 0.00064	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77200	 63198	 0.009757	 0.024721	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63199	 63216	 0.231071	 0.149664	 0.00285	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63199	 63229	 0.079964	 0.109014	 0.00242	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63200	 63209	 0.554664	 0.360064	 0.00685	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63201	 63213	 0.001771	 0.004457	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63201	 77215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63201	 77215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63202	 63203	 0.033764	 0.026721	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63203	 63204	 0.004686	 0.011871	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63203	 63305	 0.050264	 0.041371	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63204	 63304	 0.122964	 0.079621	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77200	 63204	 0.012057	 0.03055	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63205	 63208	 0.005064	 0.013786	 0.00304	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63205	 77216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63205	 77216	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63206	 63210	 0.091307	 0.072264	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63206	 63382	 0.241971	 0.156736	 0.00299	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63207	 63210	 0.083671	 0.066214	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63208	 63213	 0.006279	 0.015786	 0.00409	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63209	 63211	 0.041057	 0.074079	 0.00107	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63209	 63385	 0.816571	 0.58145	 0.00919	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77215	 63209	 0.127136	 0.082314	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63209	 77242	 0.076429	 0.193643	 0.00384	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77215	 63210	 0.077779	 0.055093	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77216	 63211	 0.017214	 0.018929	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63211	 77242	 0.045236	 0.119907	 0.00304	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77215	 63212	 0.030564	 0.019786	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63213	 77217	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63213	 77217	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77215	 63214	 0.033186	 0.021486	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77217	 63214	 0.027036	 0.0175	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63215	 63217	 0.062557	 0.044314	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63216	 63226	 0.104393	 0.0942	 0.00158	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63216	 63305	 0.061714	 0.055307	 0.00113	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63217	 63226	 0.098043	 0.063479	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63217	 63227	 0.038664	 0.025029	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63218	 63227	 0.080771	 0.052293	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63219	 63221	 0.023379	 0.016564	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63219	 77224	 0.024836	 0.039843	 0.00074	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63220	 77224	 0.034236	 0.022164	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63221	 63222	 0.021157	 0.0137	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63224	 77226	 0.014521	 0.025543	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63225	 63235	 0.008307	 0.044443	 0.00135	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76732	 63225	 0.012086	 0.086971	 0.00285	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63225	 77218	 0.222479	 0.157657	 0.00249	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63226	 63229	 0.145314	 0.155229	 0.00329	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77200	 63226	 0.107307	 0.146307	 0.00325	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63228	 63235	 0.052286	 0.118614	 0.00236	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63228	 77221	 0.031621	 0.055614	 0.00104	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63229	 77218	 0.0594	 0.235786	 0.00674	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63230	 63374	 0.016243	 0.063221	 0.01689	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63230	 77218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63230	 77218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63230	 77222	 0.023314	 0.065421	 0.01685	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63231	 63234	 0.001757	 0.006829	 0.00182	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63231	 63277	 0.001443	 0.005614	 0.0015	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63231	 77219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63231	 77219	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63232	 63234	 0.0037	 0.009779	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63232	 63276	 0.003407	 0.014164	 0.00331	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63232	 77220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63232	 77220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63232	 77222	 0.002829	 0.015693	 0.00477	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63233	 77221	 0.122843	 0.079536	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63234	 77221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63234	 77221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63234	 77222	 0.005293	 0.021193	 0.00716	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63235	 77223	 0.0171	 0.052464	 0.00142	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63236	 77222	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77223	 63236	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63237	 63254	 0.0106	 0.02665	 0.00691	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63237	 77224	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63237	 77224	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63237	 77241	 0.012836	 0.053	 0.01254	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77224	 63238	 0.023707	 0.01535	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63239	 63245	 0.001286	 0.0039	 0.00086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63239	 63257	 0.00475	 0.013621	 0.00335	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63239	 77225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63239	 77225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63240	 63241	 0.006314	 0.014443	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63240	 63251	 0.01135	 0.019957	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63240	 63285	 0.235014	 0.237486	 0.00314	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77224	 63240	 0.004121	 0.02205	 0.00067	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63241	 63242	 0.006579	 0.007021	 0.00015	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63241	 63280	 0.073471	 0.052043	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63241	 63294	 0.009	 0.025807	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63241	 63295	 0.044686	 0.028929	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63243	 63244	 0.01615	 0.010457	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63243	 63249	 0.013757	 0.024821	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77224	 63243	 0.041036	 0.026571	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77225	 63243	 0.003071	 0.0189	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63245	 63260	 0.001479	 0.005236	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63246	 63278	 0.001271	 0.005257	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63246	 77226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63246	 77226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63247	 63249	 0.0154	 0.034929	 0.0007	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63247	 77227	 0.003793	 0.0202	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63248	 63250	 0.00285	 0.013293	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63248	 77230	 0.0047	 0.023321	 0.00056	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63249	 63251	 0.006814	 0.015457	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63250	 63294	 0.00465	 0.018086	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63252	 63255	 0.014871	 0.023743	 0.00055	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63252	 63265	 0.008107	 0.016057	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63252	 63268	 0.053879	 0.038164	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63253	 63255	 0.02245	 0.014536	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63254	 63256	 0.001543	 0.006	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63254	 77227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63254	 77227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63255	 63282	 0.005043	 0.025021	 0.0006	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77227	 63255	 0.00375	 0.018964	 0.00033	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63256	 63262	 0.003107	 0.010986	 0.00248	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63256	 63275	 0.002	 0.007057	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63256	 77228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63256	 77228	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63257	 63259	 0.001857	 0.004771	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63257	 77229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63257	 77229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77227	 63258	 0.021157	 0.017414	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63258	 77230	 0.008907	 0.010436	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63259	 63260	 0.00175	 0.0045	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63259	 77230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63259	 77230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63260	 63277	 0.002229	 0.010621	 0.00252	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63260	 77231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63260	 77231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77230	 63261	 0.014857	 0.015007	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77231	 63261	 0.013079	 0.010764	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63262	 63270	 0.002364	 0.008979	 0.00251	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63262	 63275	 0.001686	 0.005879	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63262	 77232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63262	 77232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63263	 63264	 0.003193	 0.012243	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77232	 63263	 0.007321	 0.019414	 0.00049	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63263	 77235	 0.019464	 0.034221	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63264	 63265	 0.004836	 0.020657	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63265	 63267	 0.016971	 0.018664	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77232	 63266	 0.0508	 0.040207	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63267	 63268	 0.022307	 0.017657	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63268	 63271	 0.057121	 0.051536	 0.00086	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63268	 63272	 0.023243	 0.0168	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63268	 63273	 0.031671	 0.033821	 0.00071	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63269	 63270	 0.004836	 0.019364	 0.00488	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63269	 63337	 0.020207	 0.07685	 0.02153	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63269	 77233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63269	 77233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63271	 63274	 0.0257	 0.041029	 0.00094	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76739	 63273	 0.060007	 0.137257	 0.00335	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63274	 63333	 0.052643	 0.061714	 0.00107	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63274	 63334	 0.164957	 0.130564	 0.00164	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77233	 63274	 0.027036	 0.11285	 0.00326	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63275	 63278	 0.0027	 0.007393	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63275	 77234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63275	 77234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63276	 63277	 0.001421	 0.005579	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63276	 77235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63276	 77235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63277	 63278	 0.000943	 0.003764	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63278	 77236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63278	 77236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63280	 63281	 0.0309	 0.021886	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63280	 63283	 0.017657	 0.03105	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63280	 63286	 0.051514	 0.040771	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63280	 63288	 0.098607	 0.063843	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63281	 63293	 0.03355	 0.023764	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63282	 63283	 0.005957	 0.023179	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63284	 63285	 0.039693	 0.102043	 0.00158	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63284	 63333	 0.009621	 0.024379	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63286	 63287	 0.025886	 0.020486	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63287	 63293	 0.043564	 0.0282	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63288	 63292	 0.035421	 0.029157	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63289	 63291	 0.029686	 0.019214	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63289	 63293	 0.027636	 0.017893	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63290	 63291	 0.010157	 0.020107	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63291	 63292	 0.014579	 0.015571	 0.00033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63296	 77237	 0.000357	 0.024997	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63296	 77240	 0.000207	 0.002214	 0.02308	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63297	 77240	 7.4e-05	 0.005945	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77241	 63298	 0.0054	 0.018186	 0.00452	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63298	 77243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63298	 77243	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76711	 63299	 0.087421	 0.211707	 0.0601	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63299	 77244	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63299	 77244	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63301	 63380	 0.700171	 0.455264	 0.00866	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77244	 63302	 0.745214	 0.530164	 0.00838	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77218	 63303	 0.230936	 0.473643	 0.01169	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63306	 63332	 0.265157	 0.171771	 0.00327	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76737	 63306	 0.139379	 0.250636	 0.0045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77158	 63307	 0.086071	 0.060971	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63308	 63309	 0.026193	 0.021557	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63308	 63310	 0.1583	 0.102507	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63308	 63331	 0.068479	 0.120443	 0.00226	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63308	 77260	 0.0525	 0.1611	 0.00436	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63309	 63312	 0.0149	 0.026207	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63310	 63336	 0.099543	 0.158921	 0.00366	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63311	 63315	 0.068564	 0.044393	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63312	 77246	 0.005807	 0.019836	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63313	 77245	 0.016721	 0.037921	 0.00076	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63313	 77246	 0.0267	 0.036429	 0.00065	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63314	 77245	 0.04045	 0.032014	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63315	 63336	 0.106979	 0.108064	 0.00143	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63315	 77245	 0.060164	 0.042614	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63316	 63317	 0.004536	 0.01365	 0.00427	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63316	 63342	 0.011179	 0.040679	 0.01246	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63316	 77245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63316	 77245	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63317	 77246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63317	 77246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77246	 63318	 0.064614	 0.051136	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63319	 77247	 0.04545	 0.032193	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63320	 77247	 0.008771	 0.015421	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63321	 77247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63321	 77247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63322	 63323	 0.006036	 0.0252	 0.00073	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63322	 63327	 0.007943	 0.018171	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77247	 63322	 0.0124	 0.025486	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76737	 63323	 0.034786	 0.186871	 0.00444	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63324	 63326	 0.007986	 0.012743	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77247	 63324	 0.006607	 0.016729	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63325	 63326	 0.023293	 0.0165	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63325	 63329	 0.02615	 0.020693	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63326	 63330	 0.017493	 0.025493	 0.00058	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63327	 63330	 0.005857	 0.014836	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63328	 63331	 0.046414	 0.071107	 0.001	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63330	 63331	 0.020914	 0.0428	 0.00105	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63332	 63376	 0.046021	 0.116579	 0.00231	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63333	 63334	 0.0186	 0.042543	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63334	 63375	 0.110414	 0.316857	 0.00488	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76732	 63335	 0.123293	 0.473443	 0.01342	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63336	 63340	 0.10675	 0.084486	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 63336	 0.031007	 0.166557	 0.00396	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63337	 63370	 0.021029	 0.073636	 0.02442	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63338	 63339	 0.074071	 0.124793	 0.00178	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63338	 63375	 0.07885	 0.329493	 0.00952	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63338	 63376	 0.075629	 0.216979	 0.00334	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 63338	 0.072514	 0.323329	 0.00549	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63339	 63340	 0.011629	 0.034193	 0.0007	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63340	 63341	 0.015414	 0.073979	 0.00221	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 63341	 0.016043	 0.097493	 0.0018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63341	 77248	 0.017286	 0.039529	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63342	 63343	 0.007336	 0.0228	 0.00476	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63342	 77248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63342	 77248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63343	 63370	 0.004736	 0.027743	 0.00756	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63343	 63378	 0.02295	 0.055321	 0.01563	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63344	 63347	 0.0021	 0.008164	 0.00218	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76706	 63344	 0.002086	 0.008671	 0.00202	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 63345	 0.029414	 0.077957	 0.00198	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63345	 77249	 0.011843	 0.033971	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63346	 63347	 0.001829	 0.006514	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63346	 63378	 0.016564	 0.043793	 0.01025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63346	 77249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63346	 77249	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63347	 63350	 0.00265	 0.0103	 0.00275	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63347	 77250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63347	 77250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63348	 63350	 0.001386	 0.005007	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63348	 63351	 0.002321	 0.009029	 0.00241	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76706	 63348	 0.001071	 0.010836	 0.00319	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63348	 77251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63348	 77251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77251	 63349	 0.003986	 0.017757	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63349	 77252	 0.020107	 0.032093	 0.00074	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63349	 77255	 0.016893	 0.034707	 0.00066	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63350	 63353	 0.002879	 0.011314	 0.00296	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63351	 63354	 0.003136	 0.010221	 0.00271	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63352	 63355	 0.003036	 0.010414	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63352	 77252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63352	 77252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63353	 63368	 0.005486	 0.021979	 0.00554	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63353	 77253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63353	 77253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63354	 63369	 0.004979	 0.018936	 0.0053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63354	 77254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63354	 77254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76706	 63355	 0.001779	 0.010214	 0.00289	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63355	 77255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63355	 77255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76706	 63356	 0.005786	 0.015536	 0.00352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63356	 77256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63356	 77256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63357	 63360	 0.005907	 0.023636	 0.00596	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63358	 63359	 0.020464	 0.01325	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63359	 77257	 0.017686	 0.018886	 0.0004	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77159	 63360	 0.024521	 0.064836	 0.01518	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63360	 77257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63360	 77257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63361	 63379	 0.091136	 0.071436	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77257	 63361	 0.025107	 0.040079	 0.00092	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63362	 63363	 0.016057	 0.015771	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63362	 63365	 0.047914	 0.031021	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63363	 63364	 0.0187	 0.016757	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77257	 63363	 0.005864	 0.015536	 0.00039	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63364	 63365	 0.033757	 0.021857	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63364	 63367	 0.042486	 0.049807	 0.00086	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63365	 63379	 0.09245	 0.065493	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63366	 63367	 0.047907	 0.039436	 0.0008	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77256	 63367	 0.06795	 0.172157	 0.00341	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63368	 63372	 0.002214	 0.007757	 0.00257	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63368	 77258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63368	 77258	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63369	 63370	 0.003986	 0.015493	 0.00414	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63370	 63371	 0.004064	 0.015807	 0.00422	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76731	 63371	 0.012129	 0.081429	 0.01967	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63371	 77259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63371	 77259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63372	 63374	 0.012971	 0.047214	 0.01446	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77259	 63373	 0.125364	 0.081171	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63375	 63377	 0.099264	 0.251557	 0.00499	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63378	 77260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63378	 77260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77255	 63380	 0.066764	 0.204893	 0.00555	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63381	 63384	 0.0227	 0.061829	 0.01363	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63382	 63383	 0.180021	 0.245557	 0.00545	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63383	 77261	 0.023793	 0.047107	 0.00069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76719	 63384	 0.0132	 0.030643	 0.00934	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63385	 77261	 0.078371	 0.201514	 0.00312	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63386	 77261	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63386	 77261	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76720	 63387	 0.049343	 0.031943	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76720	 63388	 0.022993	 0.016286	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63389	 63390	 0.007414	 0.011893	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76720	 63389	 0.0065	 0.019121	 0.00039	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63391	 63393	 0.024614	 0.065079	 0.01524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63391	 63427	 0.016693	 0.059021	 0.01331	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63391	 77262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63391	 77262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63392	 63394	 0.111207	 0.100343	 0.00168	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63392	 77263	 0.282314	 0.277564	 0.00469	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63393	 77263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63393	 77263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77262	 63394	 0.168186	 0.208879	 0.00455	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63394	 77264	 0.014629	 0.057143	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63395	 63396	 0.018757	 0.013286	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63395	 77264	 0.028864	 0.046064	 0.00106	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63396	 77266	 0.03255	 0.030521	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63397	 63400	 0.005679	 0.017236	 0.00377	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63397	 63408	 0.006379	 0.0195	 0.00421	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63397	 63411	 0.008286	 0.030143	 0.00923	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63397	 63412	 0.014407	 0.033436	 0.01019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63397	 63427	 0.0216	 0.076371	 0.01722	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63397	 77264	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63397	 77264	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63398	 63399	 0.02495	 0.017671	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63398	 63402	 0.031364	 0.025814	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63398	 63403	 0.037014	 0.023964	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63398	 77265	 0.013829	 0.014771	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63399	 77265	 0.030321	 0.024957	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63400	 63427	 0.017371	 0.054307	 0.01574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63400	 77265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63400	 77265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63401	 63404	 0.060307	 0.042721	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63401	 63405	 0.067664	 0.10145	 0.00184	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77265	 63401	 0.03465	 0.037	 0.00079	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63402	 63403	 0.019864	 0.0178	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63402	 77276	 0.058121	 0.154086	 0.00391	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77265	 63404	 0.029271	 0.043886	 0.0008	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63405	 63407	 0.068386	 0.073036	 0.00154	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63405	 63415	 0.123729	 0.283186	 0.00692	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63405	 77268	 0.190007	 0.150407	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63406	 77266	 0.045464	 0.0322	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63406	 77267	 0.077807	 0.050379	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77264	 63407	 0.067364	 0.05545	 0.00112	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63407	 77266	 0.031986	 0.034164	 0.00072	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63408	 63409	 0.002221	 0.008886	 0.00224	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63408	 63412	 0.007764	 0.02115	 0.00466	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63408	 77266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63408	 77266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63409	 63410	 0.005321	 0.019357	 0.00593	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63410	 63411	 0.004614	 0.01905	 0.00451	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63410	 63413	 0.008364	 0.063614	 0.02	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63411	 77267	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63411	 77267	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63412	 63416	 0.028743	 0.098671	 0.02366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63412	 77268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63412	 77268	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63413	 63414	 0.013586	 0.077979	 0.02594	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63413	 63432	 0.031029	 0.1244	 0.0314	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63413	 77269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63413	 77269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63414	 63417	 0.015843	 0.104429	 0.02622	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77182	 63414	 0.010464	 0.130136	 0.05656	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63415	 77270	 0.190086	 0.30515	 0.00564	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63415	 77271	 0.118179	 0.1887	 0.00435	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76900	 63416	 0.02055	 0.0748	 0.02291	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63416	 77270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63416	 77270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76900	 63417	 0.015586	 0.086557	 0.02634	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63418	 63419	 0.0376	 0.094607	 0.02454	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63418	 77271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63418	 77271	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63419	 63429	 0.006486	 0.026764	 0.00634	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63419	 77272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63419	 77272	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63420	 63421	 0.1985	 0.157136	 0.00198	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77272	 63421	 0.038279	 0.098414	 0.00152	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63422	 63425	 0.008771	 0.038193	 0.01089	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63422	 63429	 0.003914	 0.015921	 0.00388	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63422	 77273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63422	 77273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77273	 63423	 0.0165	 0.0731	 0.00219	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63423	 77274	 0.011586	 0.0556	 0.00166	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76881	 63424	 0.026529	 0.129457	 0.00224	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63424	 77274	 0.023221	 0.102307	 0.00178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63425	 77274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63425	 77274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63426	 63427	 0.0105	 0.060221	 0.02003	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63426	 77275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63426	 77275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63427	 77276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63427	 77276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63428	 63430	 0.012993	 0.032907	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63428	 63431	 0.031471	 0.055343	 0.00104	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63430	 63431	 0.018614	 0.0621	 0.00099	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77273	 63430	 0.008521	 0.062293	 0.00115	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77272	 63431	 0.095857	 0.168621	 0.00317	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77276	 63431	 0.015714	 0.084393	 0.00201	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77182	 63432	 0.02305	 0.187757	 0.0601	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63433	 63434	 0.000807	 0.003243	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63433	 63443	 0.00145	 0.005636	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63433	 77277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63433	 77277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63434	 63436	 0.000607	 0.002429	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63435	 63439	 0.006221	 0.010943	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63435	 0.0009	 0.002379	 6e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63436	 77278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63436	 77278	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63437	 63438	 0.000443	 0.003579	 0.00101	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63437	 66757	 0.0006	 0.006657	 0.00444	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76740	 63437	 0.000971	 0.007586	 0.00227	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63437	 77279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63437	 77279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63438	 63441	 0.000536	 0.003186	 0.00084	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63438	 77280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63438	 77280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76725	 63439	 0.007121	 0.0141	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77280	 63439	 0.00345	 0.007893	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63439	 77281	 0.015814	 0.010236	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63440	 63445	 0.019464	 0.013786	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63440	 0.043471	 0.028143	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63440	 77281	 0.017157	 0.01215	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63441	 77281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63441	 77281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76725	 63442	 0.0488	 0.034571	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77278	 63442	 0.021429	 0.013871	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63442	 77282	 0.020579	 0.013321	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63443	 63455	 0.001193	 0.004971	 0.00155	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63444	 63453	 0.001457	 0.003843	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63444	 77282	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63444	 77282	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63445	 63446	 0.007593	 0.009886	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63445	 0.0624	 0.0404	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77282	 63445	 0.008679	 0.010771	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63445	 77283	 0.025079	 0.017764	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63446	 63448	 0.00725	 0.016829	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63446	 0.060843	 0.039393	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63447	 0.018607	 0.029707	 0.00069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77279	 63447	 0.0077	 0.01355	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77280	 63447	 0.018029	 0.012771	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63448	 0.038336	 0.044936	 0.00078	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76741	 63448	 0.017821	 0.045136	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63448	 77285	 0.011321	 0.034729	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63449	 63453	 0.001107	 0.00525	 0.00126	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76740	 63449	 0.003329	 0.0159	 0.00557	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63449	 77283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63449	 77283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63449	 77284	 0.005686	 0.015021	 0.00351	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63450	 0.127414	 0.090264	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77283	 63450	 0.045107	 0.03195	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63451	 63452	 0.001386	 0.004336	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63451	 63479	 0.012179	 0.032193	 0.00754	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63451	 63486	 0.001307	 0.006786	 0.00166	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63452	 63453	 0.000371	 0.001614	 0.00056	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63452	 63454	 0.000986	 0.00345	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63454	 63455	 0.001414	 0.004843	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63455	 63465	 0.00105	 0.010114	 0.00294	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63456	 63457	 0.022007	 0.023507	 0.0005	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63456	 63466	 0.027743	 0.024864	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63456	 63481	 0.021886	 0.014171	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63456	 0.194579	 0.174429	 0.00357	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63457	 63458	 0.015479	 0.0392	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63457	 0.24095	 0.217514	 0.00364	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63458	 0.149143	 0.217436	 0.00491	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63458	 77288	 0.243979	 0.191321	 0.00246	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63458	 77289	 0.0145	 0.135014	 0.00261	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63459	 63461	 0.063536	 0.130586	 0.00249	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63459	 0.085036	 0.123929	 0.0028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63459	 77286	 0.016729	 0.047464	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63459	 77287	 0.020579	 0.032843	 0.00076	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63460	 0.126693	 0.082029	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77277	 63460	 0.042021	 0.049264	 0.00086	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63460	 77288	 0.019471	 0.049321	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63461	 0.274586	 0.217414	 0.00274	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76897	 63461	 0.217207	 0.497914	 0.01219	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63462	 77284	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77285	 63462	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63463	 63464	 0.002464	 0.010171	 0.00241	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63463	 63465	 0.005864	 0.020729	 0.00467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63463	 63472	 0.005179	 0.057157	 0.01562	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63463	 77286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63463	 77286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63464	 63465	 0.003807	 0.009571	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63464	 77287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63464	 77287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63465	 63486	 0.001707	 0.009986	 0.00272	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63465	 77288	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63465	 77288	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63465	 77292	 0.012779	 0.196986	 0.05541	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63466	 63468	 0.037264	 0.024121	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63466	 0.171607	 0.183336	 0.00388	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77286	 63466	 0.009171	 0.026014	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63467	 63469	 0.041321	 0.029271	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63467	 63471	 0.010843	 0.058236	 0.00139	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 63467	 0.099714	 0.185464	 0.00434	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77286	 63467	 0.013507	 0.039714	 0.00081	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63469	 63470	 0.030021	 0.019436	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63471	 77289	 0.018514	 0.099086	 0.00301	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63472	 63473	 0.004321	 0.04685	 0.02874	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63472	 77289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63472	 77289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63473	 77290	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63473	 77290	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63473	 77292	 0.0054	 0.065279	 0.03706	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63474	 63475	 0.017336	 0.011221	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63474	 63480	 0.015929	 0.0326	 0.0008	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63476	 63480	 0.030886	 0.038343	 0.00084	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63477	 63478	 0.039993	 0.025893	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63477	 77291	 0.022593	 0.020386	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77285	 63478	 0.076536	 0.075193	 0.00127	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63478	 77291	 0.046107	 0.032664	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77284	 63479	 0.010464	 0.026314	 0.00682	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63479	 77291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63479	 77291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77285	 63480	 0.036714	 0.143407	 0.00318	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63482	 63485	 0.131529	 0.093179	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77291	 63482	 0.032843	 0.094207	 0.00145	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63483	 77292	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63483	 77292	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77290	 63484	 0.242921	 0.217829	 0.00446	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63487	 63651	 0.01705	 0.013493	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63487	 63935	 0.006107	 0.013964	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63487	 77293	 0.001221	 0.006543	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63488	 63490	 0.008421	 0.008271	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63488	 77294	 0.005736	 0.022407	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63488	 77349	 0.003114	 0.007886	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63489	 63653	 0.000879	 0.0032	 0.00098	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63489	 63933	 0.002414	 0.009486	 0.00248	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63489	 77293	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63489	 77293	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63489	 77430	 0.001321	 0.007314	 0.00222	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63491	 63652	 0.003536	 0.008086	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63491	 77294	 0.00455	 0.012064	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63492	 63493	 0.0011	 0.004479	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63492	 77294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63492	 77294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63492	 77430	 0.002164	 0.008679	 0.00219	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63493	 63679	 0.000671	 0.005557	 0.00217	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63493	 77295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63493	 77295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63493	 77296	 0.000507	 0.005379	 0.00159	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63493	 77439	 0.00195	 0.009914	 0.00359	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63494	 64713	 0.001586	 0.019079	 0.18903	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63494	 77296	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63495	 63978	 0.00325	 0.013507	 0.00315	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76751	 63495	 0.003379	 0.008686	 0.00215	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76772	 63496	 0.090257	 0.1441	 0.00332	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63497	 63644	 0.097014	 0.220143	 0.00439	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63497	 77596	 0.111114	 0.327007	 0.00671	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63498	 77302	 0.010993	 0.021771	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63499	 63557	 0.007914	 0.013329	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63499	 63581	 0.009021	 0.020629	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63499	 77302	 0.022457	 0.030636	 0.00055	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63500	 77298	 0.016429	 0.016136	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63501	 63505	 0.00185	 0.00545	 0.00127	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63501	 63506	 0.000871	 0.003493	 0.00118	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63501	 63507	 0.00215	 0.005857	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63501	 63520	 0.000943	 0.004657	 0.00136	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63501	 77298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63501	 77298	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63502	 63509	 0.005571	 0.018164	 0.00482	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63502	 64696	 0.008236	 0.031293	 0.00876	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63503	 63519	 0.001293	 0.005336	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63503	 77299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63503	 77299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63503	 77305	 0.00285	 0.014307	 0.00372	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63504	 63505	 0.002029	 0.006836	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63504	 63580	 0.001436	 0.005236	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63504	 77300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63504	 77300	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63505	 77301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63505	 77301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63506	 63507	 0.001171	 0.004686	 0.00118	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63506	 63542	 0.001593	 0.005636	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63506	 63543	 0.000964	 0.003221	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63506	 77302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63506	 77302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63507	 63523	 0.001071	 0.004293	 0.00108	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63507	 63538	 0.001564	 0.00545	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63508	 63538	 0.002586	 0.009829	 0.00275	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63508	 77303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63508	 77303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63509	 77304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63509	 77304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63510	 63512	 0.041779	 0.033064	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77303	 63510	 0.014343	 0.032957	 0.0005	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77304	 63510	 0.012443	 0.041507	 0.00066	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63511	 63512	 0.013329	 0.027271	 0.00067	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77304	 63511	 0.006357	 0.024821	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63512	 63583	 0.039921	 0.049557	 0.00108	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63513	 63521	 0.001571	 0.006521	 0.00152	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63513	 77305	 0.002714	 0.010657	 0.00279	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63514	 63534	 0.001721	 0.017814	 0.03421	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76756	 63514	 0.002664	 0.027879	 0.05249	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63514	 77305	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77306	 63514	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63514	 77438	 0.002979	 0.020507	 0.03621	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63515	 63516	 0.0238	 0.025421	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63516	 63526	 0.007207	 0.020679	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63517	 63579	 0.009814	 0.02245	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77299	 63517	 0.009736	 0.017121	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77299	 63518	 0.007829	 0.016014	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77300	 63518	 0.031357	 0.0203	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63519	 63520	 0.000386	 0.002064	 0.00051	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63519	 77307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63519	 77307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63521	 63522	 0.000507	 0.002064	 0.0005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63521	 77308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63521	 77308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63522	 63523	 0.000964	 0.004007	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63522	 77309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63522	 77309	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63523	 77310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63523	 77310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77303	 63524	 0.014771	 0.024886	 0.00036	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77309	 63524	 0.00855	 0.015036	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63525	 63526	 0.013479	 0.014821	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63525	 63528	 0.009993	 0.016029	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63526	 63528	 0.011679	 0.021714	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63526	 77635	 0.009029	 0.048479	 0.00115	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63527	 63528	 0.019743	 0.021714	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63528	 64697	 0.028279	 0.083171	 0.00171	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77306	 63528	 0.018257	 0.037364	 0.00092	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63529	 63530	 0.012964	 0.011614	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63529	 63530	 0.012964	 0.011614	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63529	 77313	 0.00785	 0.022507	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63530	 63532	 0.023086	 0.020686	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63530	 63532	 0.023086	 0.020686	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63531	 63533	 0.0061	 0.016129	 0.00377	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77296	 63531	 0.009014	 0.030914	 0.00741	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63531	 77312	 0.002607	 0.006893	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63531	 77326	 0.003671	 0.011486	 0.00333	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63532	 77311	 0.004221	 0.011186	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63533	 63538	 0.001664	 0.006671	 0.00168	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63533	 77311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63533	 77311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63534	 63926	 0.001021	 0.006964	 0.01254	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63534	 64047	 0.006964	 0.047557	 0.0858	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76766	 63534	 0.000179	 0.001686	 0.00303	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63534	 77312	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77313	 63534	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63535	 63536	 0.001043	 0.002514	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63535	 63537	 0.001521	 0.003821	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63535	 77314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63535	 77314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63536	 63537	 0.002414	 0.006371	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63536	 77315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63536	 77315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63536	 77326	 0.001521	 0.005536	 0.00169	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63537	 63544	 0.001386	 0.003221	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63537	 77316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63537	 77316	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63538	 77317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63538	 77317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77311	 63539	 0.027364	 0.026879	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77316	 63539	 0.022486	 0.01625	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77317	 63539	 0.010371	 0.020536	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77314	 63540	 0.01885	 0.0122	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77316	 63540	 0.016029	 0.012686	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63541	 63542	 0.001321	 0.003421	 0.00104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63541	 77318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63541	 77318	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63543	 63544	 0.000814	 0.002364	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63545	 63551	 0.020929	 0.014821	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63545	 63556	 0.009529	 0.016057	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77318	 63545	 0.005793	 0.010193	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63546	 63547	 0.004864	 0.00855	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63546	 63550	 0.014814	 0.010493	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77315	 63547	 0.005293	 0.012107	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63548	 63549	 0.033743	 0.023907	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77315	 63548	 0.009371	 0.019179	 0.00047	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63549	 63550	 0.009114	 0.008221	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63549	 63568	 0.018779	 0.0133	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63551	 63554	 0.022614	 0.017721	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63552	 63553	 0.019521	 0.01545	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77314	 63552	 0.022314	 0.026157	 0.00046	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63553	 63554	 0.011629	 0.008236	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63554	 77319	 0.004579	 0.017879	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63555	 63556	 0.002121	 0.00825	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63555	 63559	 0.016457	 0.01475	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63555	 63567	 0.002471	 0.007257	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63557	 63560	 0.019336	 0.012521	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63558	 63581	 0.01575	 0.014114	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63559	 63560	 0.0066	 0.013071	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63559	 63565	 0.005721	 0.014493	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63561	 77319	 0.007079	 0.014007	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63561	 77324	 0.027721	 0.01795	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63562	 63563	 0.000486	 0.001914	 0.0005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63562	 63566	 0.000814	 0.003364	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63563	 63571	 0.001621	 0.005293	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63563	 77319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63563	 77319	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63564	 63565	 0.004093	 0.013986	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63564	 77394	 0.002779	 0.013786	 0.00033	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63566	 64375	 0.001164	 0.004236	 0.0013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63566	 77320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63566	 77320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77320	 63567	 0.003107	 0.010607	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63568	 77321	 0.011236	 0.015314	 0.00034	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63569	 63571	 0.003007	 0.010629	 0.00239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63569	 63573	 0.001221	 0.003171	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63569	 64282	 0.003471	 0.01005	 0.00242	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63569	 77321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63569	 77321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63569	 77326	 0.003343	 0.011829	 0.00266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63570	 63848	 0.001221	 0.006779	 0.00206	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63570	 77322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63570	 77322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63570	 77326	 0.000679	 0.006993	 0.00199	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63571	 63572	 0.001007	 0.003586	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63571	 64252	 0.000836	 0.003336	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63571	 77323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63571	 77323	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63572	 63573	 0.00145	 0.004829	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63572	 77324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63572	 77324	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63573	 77325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63573	 77325	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63574	 63575	 0.013179	 0.010329	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77325	 63574	 0.014693	 0.011629	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63574	 77525	 0.013557	 0.031014	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63575	 77535	 0.014314	 0.009271	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77321	 63576	 0.010079	 0.023043	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63576	 77436	 0.0072	 0.012993	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63577	 77406	 0.016529	 0.013079	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63578	 77326	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63578	 77372	 0.001057	 0.013607	 0.12804	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63579	 63582	 0.00865	 0.028543	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63580	 63820	 0.001179	 0.0048	 0.00117	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63581	 63817	 0.002979	 0.013186	 0.0003	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63582	 64700	 0.015493	 0.060286	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63583	 77440	 0.045421	 0.053243	 0.00093	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63584	 63586	 0.171157	 0.200707	 0.00349	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63584	 63836	 0.41565	 0.42045	 0.00557	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63585	 63586	 0.032164	 0.074679	 0.00111	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63585	 77614	 0.079736	 0.180914	 0.00361	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 63586	 0.005036	 0.026957	 0.00081	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63586	 77615	 0.235971	 0.415571	 0.00782	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63587	 63836	 0.241079	 0.424586	 0.00799	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63587	 63837	 0.131007	 0.402536	 0.01092	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76782	 63587	 0.001571	 0.007814	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63588	 63984	 0.0027	 0.006179	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63588	 63986	 0.003771	 0.006629	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63589	 63984	 0.002943	 0.00745	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63589	 77427	 0.003371	 0.019179	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63590	 63599	 0.000314	 0.0036	 0.03277	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63590	 63907	 0.000529	 0.006129	 0.05376	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63590	 77328	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63590	 77519	 0.001021	 0.013443	 0.12005	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63591	 63592	 0.005893	 0.014929	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63591	 63953	 0.024871	 0.017614	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77329	 63591	 0.005407	 0.018029	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63592	 63954	 0.006343	 0.013029	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63593	 63595	 0.00125	 0.004871	 0.0013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63593	 63626	 0.001571	 0.005386	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63593	 63627	 0.001629	 0.005586	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63593	 77330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63593	 77330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63594	 63613	 0.015221	 0.0243	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63594	 63621	 0.026007	 0.016836	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63594	 77343	 0.006893	 0.020279	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63595	 63612	 0.001171	 0.003829	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63596	 63954	 0.007107	 0.0165	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63596	 77340	 0.0067	 0.022364	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63597	 77340	 0.013864	 0.008979	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63598	 64361	 0.00135	 0.003564	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63598	 77331	 0.001343	 0.003557	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76763	 63599	 0.001686	 0.023371	 0.2339	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63599	 77331	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63600	 63626	 0.001143	 0.005393	 0.0013	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63600	 64028	 0.004264	 0.010714	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 63600	 0.00095	 0.004493	 0.00108	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63601	 63610	 0.016007	 0.011571	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63602	 63603	 0.006536	 0.0115	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63602	 77334	 0.023321	 0.0151	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63602	 77342	 0.006621	 0.015021	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63603	 63604	 0.006464	 0.015014	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77330	 63603	 0.018607	 0.016793	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63604	 77333	 0.010521	 0.017721	 0.00025	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63605	 63632	 0.008164	 0.020671	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77330	 63605	 0.008543	 0.029914	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63606	 63630	 0.009086	 0.023357	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63606	 77333	 0.003079	 0.012207	 0.00035	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63607	 63609	 0.001607	 0.006621	 0.00156	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63607	 77333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63607	 77333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63608	 77334	 0.017414	 0.013779	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63609	 63611	 0.002007	 0.008036	 0.00202	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63609	 63626	 0.002971	 0.007164	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63609	 77334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63609	 77334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63610	 77335	 0.0098	 0.012164	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63611	 64028	 0.002364	 0.00635	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 63611	 0.0017	 0.006671	 0.00174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63611	 77335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63611	 77335	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63612	 63634	 0.001257	 0.004379	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63612	 77336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63612	 77336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63613	 63628	 0.014793	 0.020157	 0.00045	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77336	 63613	 0.019571	 0.019771	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63614	 63616	 0.00095	 0.00395	 0.00092	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63615	 77337	 0.012993	 0.009393	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63616	 77337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63616	 77337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63617	 63917	 0.002164	 0.0096	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77337	 63617	 0.002229	 0.011043	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63618	 63622	 0.001614	 0.005436	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77328	 63618	 0.001136	 0.005393	 0.00129	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63618	 77338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63618	 77338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63619	 63628	 0.014064	 0.035629	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63619	 63629	 0.0206	 0.014593	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77338	 63619	 0.003871	 0.013214	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63620	 63621	 0.0071	 0.016814	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77338	 63620	 0.003993	 0.010121	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63620	 77339	 0.0086	 0.0113	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63622	 63625	 0.000879	 0.00275	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63622	 77339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63622	 77339	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63623	 63627	 0.001029	 0.004264	 0.00133	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77328	 63623	 0.003071	 0.013379	 0.00381	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 63623	 0.001729	 0.0082	 0.00197	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63623	 77340	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63623	 77340	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77340	 63624	 0.010786	 0.007643	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63625	 63627	 0.000771	 0.003171	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63625	 77341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63625	 77341	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63626	 77342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63626	 77342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63627	 77343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63627	 77343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63628	 63919	 0.008329	 0.017121	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63630	 63631	 0.003979	 0.015529	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63630	 77344	 0.005814	 0.013293	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63631	 63633	 0.016507	 0.016214	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63631	 63636	 0.016414	 0.013507	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63631	 63638	 0.009943	 0.017486	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63632	 64035	 0.013664	 0.012243	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63633	 64016	 0.024043	 0.017379	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63634	 77344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63634	 77344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63635	 63643	 0.005207	 0.011907	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77344	 63635	 0.002007	 0.012357	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63636	 63643	 0.017064	 0.018764	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63637	 63639	 0.008071	 0.023736	 0.00049	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63637	 63640	 0.011564	 0.018464	 0.00043	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63638	 77345	 0.019536	 0.031186	 0.00072	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63639	 63958	 0.020186	 0.0222	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63639	 77352	 0.004971	 0.026686	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63640	 77345	 0.029929	 0.027007	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63641	 63724	 0.004	 0.010579	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63641	 64000	 0.002507	 0.006821	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63641	 77345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63641	 77345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63642	 63643	 0.010321	 0.006679	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63643	 63957	 0.057529	 0.04075	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63644	 77580	 0.237814	 0.500736	 0.00914	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63645	 63648	 0.148357	 0.105107	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63645	 77347	 0.043643	 0.099821	 0.00244	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63646	 77346	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63646	 77346	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76751	 63647	 0.003443	 0.013793	 0.00348	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77346	 63647	 0.003429	 0.01415	 0.00335	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63647	 77347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63647	 77347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63648	 64068	 0.15305	 0.108436	 0.00171	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63649	 63728	 0.026936	 0.019079	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63649	 77364	 0.02295	 0.040364	 0.00076	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63650	 63653	 0.001193	 0.00465	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63650	 63937	 0.001064	 0.004407	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63650	 77348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63650	 77348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63652	 63655	 0.002307	 0.005836	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63653	 63656	 0.001586	 0.007271	 0.00186	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63653	 77349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63653	 77349	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63654	 63655	 0.005143	 0.013029	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77349	 63654	 0.016164	 0.010464	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63655	 77350	 0.005979	 0.006386	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63656	 63657	 0.000793	 0.002879	 0.00088	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63656	 63679	 0.000686	 0.003457	 0.00096	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63656	 77350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63656	 77350	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63657	 63682	 0.003536	 0.008521	 0.00241	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63657	 77351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63657	 77351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63658	 63659	 0.003379	 0.006286	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77348	 63658	 0.003629	 0.008293	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63659	 63661	 0.005929	 0.008079	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63660	 63952	 0.020357	 0.016107	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63661	 63662	 0.002464	 0.00725	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63661	 63966	 0.004714	 0.011943	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77351	 63661	 0.003257	 0.017479	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63662	 63663	 0.00665	 0.013171	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63663	 63668	 0.004029	 0.013764	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63663	 63731	 0.003093	 0.012043	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63664	 63732	 0.007057	 0.011264	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63664	 63733	 0.031957	 0.031964	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63664	 63961	 0.004507	 0.013264	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63664	 77352	 0.004793	 0.013743	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63665	 63684	 0.003421	 0.012093	 0.00273	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77296	 63665	 0.007343	 0.0279	 0.00781	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63665	 77352	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63665	 77352	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63666	 63676	 0.019586	 0.014157	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77352	 63666	 0.0085	 0.011586	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63667	 63668	 0.006557	 0.012986	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63668	 63669	 0.004043	 0.00925	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63668	 63671	 0.012971	 0.029664	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63668	 63673	 0.0072	 0.010493	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63669	 63670	 0.002507	 0.008371	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77351	 63670	 0.00285	 0.011114	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63671	 77354	 0.0046	 0.012186	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63672	 77355	 0.008771	 0.017186	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63673	 63674	 0.003586	 0.007371	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63674	 77356	 0.004464	 0.012664	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63675	 63677	 0.021593	 0.021807	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63675	 77356	 0.008586	 0.02175	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63678	 63698	 0.02025	 0.014343	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63678	 77363	 0.006071	 0.009693	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63679	 63681	 0.0015	 0.006193	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63679	 77353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63679	 77353	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77353	 63680	 0.007964	 0.012714	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63681	 63682	 0.001021	 0.003979	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63681	 63683	 0.001793	 0.0074	 0.00175	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77296	 63681	 0.001136	 0.0113	 0.00307	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63681	 77354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63681	 77354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63682	 77355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63682	 77355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63683	 63684	 0.000707	 0.002936	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63683	 77356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63683	 77356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63684	 77357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63684	 77357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63685	 63686	 0.0211	 0.013657	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63685	 63696	 0.004593	 0.0135	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77357	 63685	 0.001536	 0.007614	 0.00018	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77355	 63687	 0.009021	 0.014393	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63688	 63689	 0.012043	 0.007793	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63689	 63690	 0.008414	 0.013429	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77356	 63689	 0.006736	 0.019329	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63690	 63692	 0.016486	 0.014779	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63691	 63695	 0.001607	 0.006264	 0.00167	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77346	 63691	 0.001536	 0.006493	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63691	 77358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63691	 77358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63692	 63696	 0.009721	 0.014171	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77358	 63692	 0.015364	 0.027721	 0.0004	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63693	 63720	 0.00115	 0.004007	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63693	 63721	 0.00205	 0.007171	 0.00238	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77346	 63693	 0.002179	 0.011721	 0.00289	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63693	 77359	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63693	 77359	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63694	 63696	 0.003793	 0.01115	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63694	 63706	 0.002879	 0.006579	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63695	 63704	 0.000829	 0.003386	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63695	 77360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63695	 77360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63697	 63700	 0.0038	 0.009629	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77352	 63697	 0.005007	 0.017536	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63699	 63700	 0.002943	 0.007457	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63699	 63708	 0.005136	 0.009029	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63701	 63708	 0.011664	 0.00755	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63702	 63706	 0.004779	 0.007629	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63702	 77361	 0.00715	 0.008386	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63703	 63704	 0.000879	 0.003071	 0.00102	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63703	 63707	 0.001707	 0.005579	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63703	 77361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63703	 77361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63704	 77362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63704	 77362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77362	 63705	 0.012021	 0.009514	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63707	 63710	 0.001907	 0.005714	 0.00129	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63707	 77363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63707	 77363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77363	 63708	 0.005686	 0.01195	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63709	 77365	 0.013236	 0.009371	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63710	 63711	 0.001386	 0.003479	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63711	 63724	 0.001864	 0.004921	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63712	 63716	 0.001543	 0.004136	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63712	 63724	 0.002014	 0.004671	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63713	 63717	 0.024	 0.015536	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63714	 63721	 0.001657	 0.005593	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63714	 63727	 0.002436	 0.005864	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63714	 77364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63714	 77364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63715	 63716	 0.001429	 0.004014	 0.00104	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63715	 63721	 0.003471	 0.008057	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63715	 77365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63715	 77365	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77365	 63717	 0.009971	 0.009	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77363	 63718	 0.014186	 0.018643	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77361	 63719	 0.015214	 0.00985	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63720	 63723	 0.001279	 0.004307	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63721	 77366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63721	 77366	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77366	 63722	 0.017421	 0.011279	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63723	 77367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63723	 77367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63724	 77368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63724	 77368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77368	 63725	 0.033143	 0.026229	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77364	 63726	 0.028014	 0.030814	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77368	 63726	 0.055629	 0.044029	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63727	 63992	 0.003643	 0.009164	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63729	 63968	 0.001071	 0.003621	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63729	 77369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63729	 77369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63730	 63732	 0.010929	 0.009793	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 63730	 0.005986	 0.009557	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63731	 63732	 0.004479	 0.010243	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63733	 63734	 0.006814	 0.010214	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63733	 63965	 0.004779	 0.007629	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77369	 63733	 0.002957	 0.012629	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63735	 63737	 0.012793	 0.045521	 0.01012	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63735	 64385	 0.025043	 0.087329	 0.02026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63736	 63737	 0.005743	 0.020307	 0.00458	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63736	 63738	 0.022471	 0.074993	 0.01903	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63736	 77370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63736	 77370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63738	 63835	 0.037243	 0.121643	 0.03235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63739	 63740	 0.205321	 0.361464	 0.0068	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76760	 63740	 0.065736	 0.256843	 0.0057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76773	 63740	 0.069007	 0.2952	 0.00667	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63741	 64547	 0.031407	 0.107843	 0.02587	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63741	 64561	 0.03835	 0.113186	 0.02636	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63741	 77371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63741	 77371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63742	 63745	 0.035857	 0.028379	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63742	 63750	 0.016507	 0.018157	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63743	 63750	 0.008443	 0.01485	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63744	 63746	 0.00435	 0.009871	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63744	 77374	 0.010414	 0.029864	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63745	 63746	 0.015036	 0.0119	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63747	 63750	 0.03275	 0.0212	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63748	 63750	 0.006757	 0.011886	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63748	 63751	 0.006236	 0.011207	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63748	 77374	 0.003157	 0.015143	 0.00045	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63749	 64243	 0.000214	 0.003629	 0.2371	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63749	 77372	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63749	 77372	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77374	 63750	 0.00815	 0.025007	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63751	 63762	 0.006457	 0.011357	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63752	 63754	 0.025064	 0.025314	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63753	 63760	 0.001386	 0.005443	 0.00142	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63753	 63769	 0.001571	 0.0055	 0.00182	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63753	 77375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63753	 77375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63755	 63759	 0.010371	 0.008536	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63756	 63757	 0.02135	 0.015121	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63757	 63758	 0.062943	 0.049814	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63757	 63759	 0.007936	 0.01815	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63759	 63762	 0.008107	 0.01425	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77374	 63759	 0.005743	 0.0285	 0.00068	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77375	 63759	 0.01445	 0.016936	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77373	 63760	 0.001386	 0.005536	 0.00139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63760	 77376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63760	 77376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63761	 63763	 0.0153	 0.009907	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63762	 63763	 0.014443	 0.011429	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77376	 63763	 0.005421	 0.010736	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63764	 77377	 0.013114	 0.037607	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63765	 63767	 0.001071	 0.00375	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77373	 63765	 0.002214	 0.011929	 0.00328	 202.0	 202.0	 202.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63765	 77377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63765	 77377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63766	 63775	 0.002179	 0.011314	 0.00276	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77373	 63766	 0.003343	 0.013807	 0.00326	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63766	 77378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63766	 77378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63767	 63786	 0.008057	 0.028664	 0.00637	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63767	 63787	 0.006907	 0.024407	 0.0055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63767	 77379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63767	 77379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77379	 63768	 0.045879	 0.036307	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63769	 63777	 0.001971	 0.01045	 0.00349	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77378	 63770	 0.012679	 0.0562	 0.00169	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63770	 77384	 0.033686	 0.062643	 0.00146	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63770	 77637	 0.015136	 0.043407	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63771	 63772	 0.001	 0.003993	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63771	 63775	 0.002021	 0.008357	 0.00198	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63772	 63773	 0.0016	 0.004229	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63772	 63807	 0.001393	 0.005564	 0.0014	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63772	 77380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63772	 77380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63773	 63774	 0.00205	 0.005143	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63774	 64701	 0.003964	 0.010871	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63775	 63777	 0.00195	 0.006893	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63775	 77381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63775	 77381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77381	 63776	 0.031271	 0.022607	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63777	 63778	 0.000536	 0.002721	 0.00099	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63777	 77382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63777	 77382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63778	 63805	 0.000729	 0.004193	 0.00119	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63779	 63796	 0.003229	 0.011414	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63779	 64439	 0.018486	 0.046471	 0.01204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63779	 64718	 0.006271	 0.021514	 0.00516	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63780	 77386	 0.074843	 0.053021	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77379	 63781	 0.016514	 0.042807	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63781	 77384	 0.0628	 0.056657	 0.00095	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63782	 63789	 0.056207	 0.044486	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63782	 77386	 0.040893	 0.055793	 0.001	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63783	 63791	 0.016586	 0.016293	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63783	 77385	 0.011343	 0.028743	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63784	 63786	 0.002143	 0.005379	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63784	 63787	 0.004236	 0.011371	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63784	 63793	 0.002664	 0.006693	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63784	 63800	 0.01415	 0.036743	 0.00892	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 63784	 0.012779	 0.060493	 0.01455	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63784	 77383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63784	 77383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63785	 64704	 0.00625	 0.016064	 0.00398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63785	 77384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63785	 77384	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63786	 63787	 0.0023	 0.005964	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63786	 77385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63786	 77385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63787	 77386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63787	 77386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63788	 63792	 0.019171	 0.017293	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77383	 63788	 0.003907	 0.016693	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63789	 63790	 0.017636	 0.011421	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63790	 63792	 0.008843	 0.01555	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63790	 77387	 0.001821	 0.0085	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63791	 63792	 0.017614	 0.011407	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63793	 63794	 0.0019	 0.005107	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63793	 63796	 0.003693	 0.00975	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63794	 64704	 0.004457	 0.015293	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63795	 63798	 0.017414	 0.012336	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63795	 63799	 0.017836	 0.024314	 0.00054	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77383	 63795	 0.014614	 0.033421	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63795	 77387	 0.005014	 0.013293	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63796	 77387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63796	 77387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77387	 63797	 0.0174	 0.012321	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63801	 63802	 0.072436	 0.115643	 0.00266	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63801	 64466	 0.068586	 0.12755	 0.00299	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63802	 63803	 0.158779	 0.112493	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77374	 63802	 0.0966	 0.169921	 0.00319	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63803	 77516	 0.198021	 0.128243	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63804	 63809	 0.00265	 0.010936	 0.00259	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77373	 63804	 0.005564	 0.026329	 0.00633	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63804	 77388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63804	 77388	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63805	 63822	 0.001614	 0.008243	 0.00224	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63805	 77389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63805	 77389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63806	 63807	 0.001436	 0.005943	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63806	 63823	 0.002793	 0.011536	 0.00273	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63806	 77390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63806	 77390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63808	 77391	 0.021857	 0.01415	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63809	 63821	 0.001586	 0.006357	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63809	 77391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63809	 77391	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63810	 63812	 0.000607	 0.002757	 0.00087	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63810	 63822	 0.000979	 0.007671	 0.00196	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63810	 77392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63810	 77392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77392	 63811	 0.01215	 0.009614	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63812	 64247	 0.002807	 0.008443	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63812	 64374	 0.000814	 0.003371	 0.0008	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77392	 63813	 0.003229	 0.012379	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63813	 77394	 0.00565	 0.0162	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63814	 63815	 0.006486	 0.016807	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63814	 63819	 0.002836	 0.008686	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63815	 77393	 0.009779	 0.015607	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63816	 63818	 0.001443	 0.005957	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63816	 63820	 0.000971	 0.003821	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63816	 77393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63816	 77393	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63817	 77394	 0.002764	 0.013729	 0.00033	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63818	 64374	 0.002286	 0.00575	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63818	 77394	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63818	 77394	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63819	 77396	 0.007457	 0.029114	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63820	 63823	 0.001207	 0.006179	 0.00169	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63821	 64245	 0.002121	 0.008486	 0.00214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63821	 77395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63821	 77395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63822	 77396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63822	 77396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63823	 64702	 0.0026	 0.009893	 0.00277	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63824	 64699	 0.00345	 0.012071	 0.004	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63824	 64702	 0.001329	 0.00465	 0.00154	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63825	 77397	 0.0502	 0.065979	 0.00091	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63826	 63827	 0.009786	 0.040414	 0.00956	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63826	 64211	 0.037343	 0.104229	 0.0219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63826	 64621	 0.100393	 0.271221	 0.06193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63826	 77397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63826	 77397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63827	 63828	 0.027014	 0.091079	 0.02266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63827	 63829	 0.023643	 0.084171	 0.01873	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63828	 64233	 0.041893	 0.097357	 0.0297	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63828	 64551	 0.046979	 0.122136	 0.02969	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63828	 77398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63828	 77398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63829	 64553	 0.030321	 0.102264	 0.02544	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63829	 77399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63829	 77399	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63830	 64380	 0.061721	 0.168436	 0.03721	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63830	 64381	 0.052729	 0.139586	 0.03274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63830	 64561	 0.080536	 0.209936	 0.05119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63830	 77400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63830	 77400	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63831	 64267	 0.006907	 0.035793	 0.00874	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76764	 63831	 0.008264	 0.037907	 0.00971	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63831	 77401	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63831	 77401	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63832	 64229	 0.011114	 0.028857	 0.00701	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76764	 63832	 0.014507	 0.049779	 0.01193	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63832	 77402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63832	 77402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76765	 63833	 0.033093	 0.0582	 0.00109	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63834	 77403	 0.487543	 0.38645	 0.00486	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63835	 64623	 0.041357	 0.109407	 0.02564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63835	 77403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63835	 77403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63836	 63837	 0.117764	 0.298486	 0.00591	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63836	 64239	 0.2139	 0.398343	 0.00934	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63837	 65884	 0.056893	 0.304707	 0.00925	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63838	 77612	 0.386479	 0.413636	 0.00875	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63839	 77509	 0.400657	 0.527621	 0.00724	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63840	 77405	 0.118179	 0.212479	 0.00381	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63841	 63845	 0.32485	 0.257264	 0.00324	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63841	 63846	 0.213571	 0.151336	 0.00239	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63842	 63844	 0.042307	 0.1137	 0.0258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63842	 64524	 0.0201	 0.070079	 0.01626	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63842	 77404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63842	 77404	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63843	 63845	 0.052329	 0.097314	 0.00228	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63844	 64556	 0.068679	 0.182036	 0.04276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63844	 77405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63844	 77405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77404	 63845	 0.0654	 0.121629	 0.00285	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63845	 77592	 0.102979	 0.235636	 0.00576	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63846	 64509	 0.312171	 0.257221	 0.00521	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77405	 63846	 0.126879	 0.223214	 0.00419	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63847	 63848	 0.0025	 0.006714	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63847	 63850	 0.000443	 0.002021	 0.00052	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63847	 63985	 0.000486	 0.002243	 0.00057	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63848	 63873	 0.00145	 0.0058	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63848	 77406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63848	 77406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63849	 63853	 0.003421	 0.007821	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63849	 63866	 0.010364	 0.009286	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77406	 63849	 0.001393	 0.0079	 0.00014	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63850	 63851	 0.00075	 0.003093	 0.00073	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63850	 63852	 0.000743	 0.002979	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63850	 77407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63850	 77407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63851	 64298	 0.002329	 0.006036	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63851	 64299	 0.00115	 0.002979	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63851	 77408	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63851	 77408	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63852	 77409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63852	 77409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63853	 63854	 0.00715	 0.009743	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63854	 63867	 0.005657	 0.0112	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77409	 63854	 0.005664	 0.013007	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63855	 63859	 0.003271	 0.015971	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77408	 63855	 0.002621	 0.012229	 0.00028	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63856	 63857	 0.003993	 0.009121	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63856	 63858	 0.010271	 0.018057	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77409	 63856	 0.002121	 0.010543	 0.00025	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63857	 63879	 0.0064	 0.012671	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63858	 63863	 0.001914	 0.008479	 0.00019	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63858	 64307	 0.002764	 0.010807	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63858	 64309	 0.020136	 0.019786	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63859	 77410	 0.003907	 0.0099	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63860	 63878	 0.000993	 0.002786	 0.00071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63860	 64298	 0.002936	 0.013471	 0.00345	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63860	 77410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63860	 77410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63861	 63863	 0.004771	 0.010914	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63861	 63939	 0.004314	 0.009864	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63862	 63864	 0.004836	 0.011057	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63862	 63868	 0.022364	 0.018407	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63862	 63940	 0.006543	 0.0115	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77410	 63864	 0.003993	 0.010107	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63865	 63868	 0.006671	 0.012407	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63865	 77415	 0.00475	 0.016229	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63867	 63875	 0.003671	 0.009729	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63867	 77413	 0.009021	 0.022843	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63868	 77411	 0.00505	 0.014493	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63869	 63893	 0.014186	 0.01515	 0.00032	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63869	 77411	 0.003114	 0.010636	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63870	 63881	 0.0027	 0.007143	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63870	 77411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63870	 77411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77411	 63871	 0.012414	 0.008793	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63872	 77412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63872	 77412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63873	 63874	 0.002079	 0.005486	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63873	 77413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63873	 77413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63873	 77423	 0.001586	 0.006464	 0.00158	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63874	 77414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63874	 77414	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63874	 77423	 0.001807	 0.007514	 0.00234	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63875	 63879	 0.003893	 0.011171	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63876	 63885	 0.001493	 0.007936	 0.00014	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63876	 77415	 0.0122	 0.02055	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63877	 63880	 0.006479	 0.006364	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63877	 77415	 0.004036	 0.010221	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63878	 63881	 0.002257	 0.006193	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77328	 63878	 0.006	 0.020221	 0.00502	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63878	 77415	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63878	 77415	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77415	 63879	 0.004286	 0.011364	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63880	 63887	 0.009443	 0.006114	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63880	 63889	 0.00455	 0.011529	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77328	 63881	 0.00385	 0.016007	 0.00374	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63881	 77416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63881	 77416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63882	 63883	 0.0008	 0.002693	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63882	 63908	 0.000764	 0.002786	 0.00085	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63882	 63910	 0.001064	 0.003786	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63882	 77417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63882	 77417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63883	 63886	 0.000564	 0.001914	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63883	 77418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63883	 77418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77414	 63884	 0.003793	 0.008679	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77418	 63884	 0.002007	 0.005307	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63885	 77419	 0.000879	 0.0042	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63886	 63900	 0.000821	 0.002507	 0.00054	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63886	 77419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63886	 77419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63887	 63888	 0.004193	 0.007379	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63888	 63890	 0.003593	 0.007114	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63888	 77421	 0.002014	 0.008414	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63889	 77421	 0.001464	 0.005114	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77416	 63890	 0.013093	 0.018243	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63891	 63892	 0.004307	 0.00725	 0.0001	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77416	 63891	 0.004257	 0.008707	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63892	 63894	 0.00695	 0.014293	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63892	 63903	 0.004386	 0.010029	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63892	 63905	 0.013971	 0.009043	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63893	 63894	 0.003007	 0.005593	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63894	 63906	 0.003764	 0.009543	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63895	 63897	 0.00385	 0.011814	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77412	 63895	 0.001986	 0.008807	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63896	 63898	 0.003914	 0.011514	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77412	 63896	 0.001957	 0.011707	 0.00028	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63897	 63920	 0.0052	 0.011893	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63898	 63916	 0.014357	 0.02525	 0.00047	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63898	 63917	 0.003407	 0.017236	 0.0003	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63898	 63921	 0.005036	 0.014436	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77417	 63899	 0.001543	 0.007186	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63899	 77420	 0.001829	 0.006107	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63900	 63901	 0.000629	 0.0024	 0.00067	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63900	 63908	 0.001686	 0.006964	 0.00165	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63900	 77420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63900	 77420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63901	 63904	 0.001657	 0.004536	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63901	 77421	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63901	 77421	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77421	 63902	 0.00815	 0.005271	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77421	 63903	 0.005	 0.012664	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63904	 63913	 0.000586	 0.002436	 0.00057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63904	 63914	 0.000693	 0.002821	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63904	 77422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63904	 77422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63906	 63915	 0.016479	 0.018121	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77412	 63906	 0.013129	 0.026971	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63907	 77423	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63907	 77423	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77423	 63908	 0.0006	 0.003929	 0.00146	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63909	 63910	 0.000507	 0.002807	 0.00086	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63909	 63922	 0.001807	 0.004779	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77423	 63909	 0.000893	 0.0045	 0.00117	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63910	 63911	 0.000771	 0.003136	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63910	 77424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63910	 77424	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63911	 63913	 0.000729	 0.003021	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63911	 77425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63911	 77425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77420	 63912	 0.004621	 0.010564	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77422	 63912	 0.004786	 0.009479	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63913	 77426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63913	 77426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63914	 77427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63914	 77427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77427	 63915	 0.005771	 0.014621	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63916	 63986	 0.018207	 0.013157	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63918	 63952	 0.016564	 0.018221	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63919	 63960	 0.010136	 0.018286	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63920	 63950	 0.007171	 0.01145	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63921	 63952	 0.017486	 0.013836	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63922	 63923	 0.001057	 0.00415	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77423	 63922	 0.001479	 0.005907	 0.00149	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63922	 77428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63922	 77428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63923	 77429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63923	 77429	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63923	 77430	 0.001514	 0.008693	 0.00246	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63924	 63925	 0.023107	 0.014957	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77424	 63924	 0.008764	 0.013993	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63925	 63929	 0.017636	 0.012493	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63926	 77430	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77431	 63926	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63926	 77438	 0.000143	 0.00145	 0.00285	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77431	 63927	 0.003343	 0.014821	 0.00044	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63928	 63930	 0.005807	 0.013179	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63929	 63936	 0.007586	 0.0195	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77429	 63929	 0.006686	 0.026107	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63930	 63931	 0.00425	 0.006786	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77426	 63930	 0.009136	 0.01005	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77428	 63930	 0.009529	 0.0365	 0.00103	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63931	 77432	 0.008307	 0.011329	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77427	 63932	 0.015629	 0.01535	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63933	 77432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63933	 77432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77432	 63934	 0.011457	 0.014221	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63935	 63936	 0.003164	 0.007236	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63936	 77433	 0.004857	 0.018693	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63937	 63968	 0.001079	 0.004314	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63937	 77433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63937	 77433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63938	 63939	 0.006843	 0.008021	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63938	 63940	 0.011829	 0.01555	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63938	 63942	 0.005579	 0.012814	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63941	 63943	 0.017564	 0.011371	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63942	 63943	 0.005443	 0.012636	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63943	 77437	 0.00465	 0.020593	 0.00047	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63944	 77437	 0.008193	 0.01255	 0.00018	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63945	 63979	 0.011643	 0.020471	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63945	 64337	 0.02515	 0.017814	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63945	 77437	 0.008886	 0.020321	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63946	 63979	 0.004207	 0.009629	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63946	 63988	 0.0042	 0.010643	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63947	 63948	 0.003914	 0.00805	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63947	 63984	 0.006836	 0.008979	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63948	 63951	 0.006043	 0.015314	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63948	 63967	 0.003907	 0.013036	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77432	 63948	 0.011393	 0.038	 0.0006	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63949	 63950	 0.005236	 0.007136	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63949	 63951	 0.004843	 0.00995	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63949	 63952	 0.004329	 0.014786	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63950	 63986	 0.013871	 0.008979	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63951	 63963	 0.007071	 0.012429	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63951	 63965	 0.021821	 0.015457	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77337	 63952	 0.00705	 0.034979	 0.00084	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63953	 63981	 0.024829	 0.016079	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63955	 63956	 0.018021	 0.012764	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63956	 63957	 0.012629	 0.017229	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63957	 63958	 0.005471	 0.014057	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77338	 63957	 0.025071	 0.073729	 0.00151	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63958	 63960	 0.035393	 0.025071	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63958	 63962	 0.005286	 0.014	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63959	 63960	 0.020093	 0.013007	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63959	 63962	 0.007914	 0.014229	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63960	 63963	 0.010071	 0.013729	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63961	 63962	 0.011571	 0.011371	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63962	 63964	 0.004114	 0.012107	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77412	 63963	 0.024364	 0.061707	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77352	 63964	 0.003507	 0.013686	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63966	 77434	 0.00415	 0.009421	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63967	 77434	 0.002393	 0.008171	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63968	 77434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63968	 77434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63969	 77435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63969	 77435	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63969	 77439	 0.001157	 0.0039	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63970	 63973	 0.006614	 0.0131	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77435	 63970	 0.003971	 0.011379	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63971	 63972	 0.003621	 0.010643	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77435	 63971	 0.001707	 0.007971	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	63972	 63974	 0.017093	 0.011064	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77295	 63972	 0.011107	 0.022829	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63973	 63974	 0.014429	 0.011421	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77297	 63975	 0.01285	 0.02915	 0.00058	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63976	 63977	 0.001336	 0.004457	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63976	 63989	 0.007129	 0.024457	 0.00586	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63977	 63978	 0.001007	 0.004257	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77296	 63977	 0.00205	 0.007986	 0.00213	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63979	 63980	 0.013421	 0.014621	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63979	 64327	 0.0138	 0.020107	 0.00046	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63979	 64336	 0.022171	 0.01435	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63982	 63983	 0.007	 0.017729	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63982	 64362	 0.001814	 0.00635	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63983	 64353	 0.013579	 0.015921	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63983	 64366	 0.007236	 0.0168	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	63983	 64373	 0.006571	 0.018843	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77332	 63983	 0.0247	 0.062564	 0.00124	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63985	 64292	 0.001086	 0.004736	 0.00135	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	63985	 77436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63985	 77436	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77328	 63987	 0.000593	 0.002407	 0.00059	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	63987	 77437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63987	 77437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77437	 63988	 0.005436	 0.012436	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	63990	 77438	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63991	 77589	 0.351779	 0.413043	 0.00719	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	63991	 77617	 0.311893	 0.306707	 0.00518	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63992	 63993	 0.004714	 0.012836	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63993	 63994	 0.001593	 0.005371	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63993	 77441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63993	 77441	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63994	 63995	 0.001836	 0.005986	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	63994	 77442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63994	 77442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63995	 63996	 0.004136	 0.010393	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63995	 64002	 0.003429	 0.00905	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63995	 77443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63995	 77443	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63996	 63997	 0.005779	 0.015279	 0.00358	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63996	 77444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63996	 77444	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63997	 64070	 0.006543	 0.015764	 0.00445	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	63997	 77445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	63997	 77445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77442	 63998	 0.020421	 0.022457	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77444	 63999	 0.048321	 0.05315	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64000	 64004	 0.002893	 0.009921	 0.00238	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64000	 77446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64000	 77446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77446	 64001	 0.02855	 0.025757	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64001	 77448	 0.01035	 0.020493	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64002	 64004	 0.002193	 0.007379	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64002	 64008	 0.003843	 0.015379	 0.00387	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64002	 77447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64002	 77447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77446	 64003	 0.014736	 0.018293	 0.0004	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64004	 77448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64004	 77448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77442	 64005	 0.011443	 0.020129	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77447	 64005	 0.005636	 0.011543	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77441	 64006	 0.010021	 0.018079	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64007	 64022	 0.047429	 0.037536	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77448	 64007	 0.015129	 0.038321	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64007	 77449	 0.016507	 0.048536	 0.00099	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64008	 64019	 0.005736	 0.014743	 0.00365	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64008	 64046	 0.004571	 0.017379	 0.00486	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64008	 77449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64008	 77449	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64008	 77457	 0.0054	 0.024071	 0.00654	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64009	 64051	 0.017264	 0.039486	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77449	 64009	 0.026	 0.045721	 0.00086	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64010	 64011	 0.016879	 0.013357	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77334	 64010	 0.01725	 0.015564	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64011	 64012	 0.023814	 0.015414	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64011	 64030	 0.010121	 0.017057	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64013	 64036	 0.005171	 0.011829	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77333	 64013	 0.00315	 0.014679	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64014	 64015	 0.014471	 0.011457	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64014	 64033	 0.003921	 0.01675	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64014	 64035	 0.002993	 0.011457	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64014	 64036	 0.014571	 0.016021	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64015	 64017	 0.016921	 0.013393	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64016	 64035	 0.010164	 0.017879	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64017	 64037	 0.018657	 0.016836	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64018	 64035	 0.01905	 0.033493	 0.00063	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64019	 64024	 0.002593	 0.008886	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64019	 64045	 0.005193	 0.017493	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64019	 77450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64019	 77450	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64020	 64044	 0.016057	 0.024071	 0.00044	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77450	 64020	 0.049057	 0.031764	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64021	 64040	 0.061957	 0.044793	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64021	 77451	 0.008186	 0.013071	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64022	 77454	 0.047457	 0.033614	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64023	 64025	 0.016057	 0.010393	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64024	 64031	 0.005279	 0.01395	 0.00326	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64024	 64034	 0.003629	 0.00875	 0.00247	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64025	 64026	 0.006121	 0.012114	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64025	 77451	 0.005779	 0.014979	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64026	 64030	 0.011343	 0.014907	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64027	 64028	 0.000971	 0.00245	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64027	 64038	 0.014357	 0.037271	 0.00905	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 64027	 0.004014	 0.013779	 0.0033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64027	 77451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64027	 77451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64028	 64032	 0.009643	 0.026429	 0.00575	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 64028	 0.003279	 0.011586	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64029	 64030	 0.01085	 0.017321	 0.0004	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64029	 77452	 0.026121	 0.016907	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77451	 64030	 0.0138	 0.031564	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64031	 64034	 0.002421	 0.006593	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64031	 77452	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64031	 77452	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64032	 64045	 0.009307	 0.026693	 0.00657	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64032	 77453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64032	 77453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64033	 64037	 0.014764	 0.029236	 0.00043	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77334	 64033	 0.031136	 0.054757	 0.00103	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77452	 64033	 0.008914	 0.020386	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64033	 77454	 0.009957	 0.028257	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64034	 77454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64034	 77454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64038	 64039	 0.007264	 0.019507	 0.00442	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64038	 64041	 0.016179	 0.054514	 0.01355	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64038	 64045	 0.008736	 0.023793	 0.00524	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64039	 64349	 0.007929	 0.021293	 0.00483	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64041	 64647	 0.015186	 0.05775	 0.01617	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64041	 77455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64041	 77455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64042	 64043	 0.085293	 0.083793	 0.00141	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64042	 64049	 0.116729	 0.082693	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64042	 77458	 0.079779	 0.127986	 0.00236	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77455	 64043	 0.070964	 0.140521	 0.00206	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77453	 64044	 0.131679	 0.093286	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64044	 77456	 0.004021	 0.016793	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64045	 77456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64045	 77456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64045	 77457	 0.004407	 0.018193	 0.00431	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64046	 77457	 0.001764	 0.006171	 0.00204	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64047	 64116	 0.00535	 0.034729	 0.06926	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76742	 64047	 0.011993	 0.128657	 0.23871	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64047	 77457	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77458	 64047	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77458	 64048	 0.013207	 0.026143	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64049	 77459	 0.108479	 0.097879	 0.00164	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64050	 64072	 0.012886	 0.034057	 0.00797	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64050	 64196	 0.013179	 0.042979	 0.01141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64050	 77459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64050	 77459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64051	 64052	 0.081229	 0.057543	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77458	 64051	 0.006014	 0.029857	 0.00071	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64053	 64059	 0.085329	 0.2162	 0.00429	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64053	 64631	 0.12605	 0.2885	 0.00705	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64054	 64056	 0.013243	 0.033286	 0.00862	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64054	 64383	 0.059614	 0.150193	 0.03901	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64054	 77460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64054	 77460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64055	 64056	 0.012807	 0.03385	 0.00792	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64055	 64556	 0.017771	 0.042829	 0.01209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64055	 77461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64055	 77461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64056	 64222	 0.012907	 0.032457	 0.00841	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64057	 64059	 0.073443	 0.168	 0.0041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64057	 64062	 0.091986	 0.090371	 0.00153	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64058	 64059	 0.046571	 0.106521	 0.0026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64058	 64060	 0.094321	 0.066821	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64058	 64061	 0.078371	 0.106936	 0.00191	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77460	 64059	 0.052193	 0.149721	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64059	 77561	 0.224121	 0.571079	 0.00905	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64061	 64063	 0.228036	 0.161593	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64061	 64064	 0.046529	 0.067807	 0.00154	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64063	 77619	 0.103114	 0.181393	 0.00341	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64064	 64065	 0.046671	 0.070793	 0.00101	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64065	 64066	 0.073786	 0.058393	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64065	 77618	 0.10605	 0.186557	 0.00351	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64067	 64069	 0.090736	 0.353229	 0.0059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76771	 64067	 0.048807	 0.190671	 0.00423	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64068	 77462	 0.140057	 0.137614	 0.00232	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64069	 77463	 0.044371	 0.151593	 0.0033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64070	 64071	 0.007757	 0.020864	 0.00585	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64070	 77462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64070	 77462	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64071	 64072	 0.012093	 0.031964	 0.00748	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64071	 77463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64071	 77463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64072	 77464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64072	 77464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77459	 64073	 0.219579	 0.173829	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64074	 64076	 0.001186	 0.004507	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64074	 64083	 0.002507	 0.006743	 0.00189	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64074	 77467	 0.002864	 0.010886	 0.00304	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64075	 77471	 0.002671	 0.011843	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64075	 77502	 0.004357	 0.016686	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64076	 64153	 0.001043	 0.003979	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64076	 77465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64076	 77465	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64077	 64078	 0.014921	 0.010571	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64077	 64201	 0.020286	 0.014371	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64077	 77468	 0.006036	 0.015286	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76761	 64079	 0.000957	 0.010229	 0.15031	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64079	 77466	 0.000148	 0.01111	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64079	 77488	 0.000543	 0.005936	 0.05766	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64080	 64081	 0.012571	 0.008136	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64081	 64085	 0.015614	 0.012243	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64082	 77469	 0.01525	 0.010807	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64083	 64096	 0.0008	 0.00275	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64083	 77469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64083	 77469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64084	 64085	 0.006164	 0.009836	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77469	 64084	 0.014593	 0.01605	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64085	 64086	 0.015143	 0.011986	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64085	 64094	 0.006529	 0.011964	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64086	 64087	 0.017871	 0.014143	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64086	 64093	 0.01055	 0.017764	 0.00025	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64088	 64090	 0.019907	 0.012886	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64089	 64102	 0.00135	 0.004621	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76781	 64089	 0.014279	 0.038879	 0.00856	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64089	 77470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64089	 77470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77470	 64090	 0.004257	 0.011036	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64091	 64092	 0.006007	 0.010843	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76776	 64091	 0.006679	 0.017707	 0.00045	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64092	 64093	 0.015736	 0.01245	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64093	 64094	 0.0135	 0.010686	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64093	 77474	 0.00595	 0.015779	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64094	 64095	 0.005579	 0.008907	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64095	 77476	 0.007971	 0.014021	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64096	 64097	 0.001629	 0.004193	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64096	 64098	 0.000879	 0.003629	 0.00086	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64097	 64099	 0.001893	 0.004571	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64097	 77471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64097	 77471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64098	 64165	 0.001229	 0.004793	 0.00128	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64098	 77472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64098	 77472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64099	 64176	 0.001993	 0.006493	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64099	 77473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64099	 77473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64099	 77489	 0.004493	 0.018664	 0.00436	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76776	 64100	 0.004071	 0.01425	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64100	 77476	 0.011443	 0.009421	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64101	 64105	 0.002179	 0.00575	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64101	 77474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64101	 77474	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64102	 77475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64102	 77475	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64103	 64104	 0.0366	 0.023693	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64104	 77478	 0.005686	 0.012893	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64105	 64106	 0.001557	 0.005536	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64105	 64165	 0.002729	 0.007436	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64105	 77476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64105	 77476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64106	 64167	 0.001914	 0.005143	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64106	 77477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64106	 77477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64106	 77489	 0.003521	 0.014093	 0.00355	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77477	 64107	 0.006657	 0.017107	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64107	 77478	 0.017279	 0.02025	 0.00035	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64108	 77478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64108	 77478	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64109	 64111	 0.036729	 0.026014	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77478	 64109	 0.027236	 0.029086	 0.00061	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64110	 64134	 0.004829	 0.012414	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64110	 77479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64110	 77479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64110	 77489	 0.001771	 0.007371	 0.00172	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77479	 64111	 0.010443	 0.04655	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64112	 64134	 0.008957	 0.021579	 0.00609	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64112	 64135	 0.011529	 0.030943	 0.00701	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64112	 64650	 0.014357	 0.03795	 0.00889	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64113	 64114	 0.013479	 0.013486	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77479	 64113	 0.005293	 0.012014	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64115	 64185	 0.090807	 0.064329	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64115	 64648	 0.237493	 0.1683	 0.00266	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64116	 77480	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64116	 77480	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64117	 64118	 0.020543	 0.0161	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64118	 77482	 0.012379	 0.0283	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64119	 77482	 0.023114	 0.014964	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64120	 77482	 0.01125	 0.028493	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64121	 64202	 0.040521	 0.026236	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64121	 77482	 0.009607	 0.015329	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77466	 64122	 0.000236	 0.002714	 0.00531	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64122	 77481	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77482	 64122	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76781	 64123	 0.002957	 0.007121	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77481	 64123	 0.005829	 0.019	 0.00504	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64123	 77483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64123	 77483	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77483	 64124	 0.007136	 0.024979	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64124	 77505	 0.01945	 0.044486	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64125	 64128	 0.02145	 0.064257	 0.01448	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64125	 64198	 0.009971	 0.027143	 0.00598	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64125	 77484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64125	 77484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64126	 64127	 0.001043	 0.004057	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64126	 64200	 0.001507	 0.006021	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64126	 77485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64126	 77485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64127	 64193	 0.004207	 0.016829	 0.00424	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64127	 77486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64127	 77486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64128	 64145	 0.021993	 0.059057	 0.01339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64128	 77487	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64128	 77487	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64129	 64156	 0.003786	 0.013764	 0.00421	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64129	 77489	 0.0034	 0.016593	 0.00459	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64130	 64183	 0.002543	 0.012629	 0.0003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64130	 77490	 0.003193	 0.015343	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64131	 77490	 0.023814	 0.016864	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64132	 77491	 0.011443	 0.019279	 0.00027	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64133	 64138	 0.0016	 0.005329	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64133	 64139	 0.002579	 0.0098	 0.00274	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64133	 64140	 0.000521	 0.004357	 0.00114	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64133	 77489	 0.001536	 0.012057	 0.00309	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64134	 64135	 0.0027	 0.006936	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64135	 77489	 0.002307	 0.008157	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76779	 64136	 0.078264	 0.106693	 0.00236	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64137	 64243	 0.001536	 0.019986	 1.29143	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64137	 77488	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64138	 77491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64138	 77491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64139	 64142	 0.001721	 0.011843	 0.00345	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64139	 64147	 0.008636	 0.032814	 0.00919	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64140	 64142	 0.000921	 0.0072	 0.00215	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64140	 77492	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64140	 77492	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77492	 64141	 0.01915	 0.0124	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64142	 77493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64142	 77493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77493	 64143	 0.026064	 0.035529	 0.00079	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76762	 64144	 0.000921	 0.00915	 0.00249	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64145	 64147	 0.01495	 0.038814	 0.00942	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64146	 77494	 0.315443	 0.204393	 0.00389	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64147	 64543	 0.081079	 0.280007	 0.06767	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64147	 77494	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64147	 77494	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64148	 64186	 0.031593	 0.020457	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64148	 77507	 0.009764	 0.019336	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64149	 64150	 0.011414	 0.007386	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64150	 77495	 0.008964	 0.013064	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64151	 64152	 0.000807	 0.003229	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64151	 64155	 0.001164	 0.004843	 0.00113	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64152	 64188	 0.001229	 0.004214	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64153	 64154	 0.001257	 0.004307	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64153	 64200	 0.002721	 0.00655	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64153	 77495	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64153	 77495	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64154	 64155	 0.000921	 0.0035	 0.00098	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64154	 64170	 0.001543	 0.004193	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64154	 77496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64154	 77496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64155	 77497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64155	 77497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64156	 64175	 0.001414	 0.004936	 0.00164	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64156	 77498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64156	 77498	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77498	 64157	 0.018871	 0.080671	 0.00182	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64157	 77506	 0.1023	 0.092307	 0.00154	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64158	 64160	 0.027414	 0.022564	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64158	 64162	 0.016529	 0.016693	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64158	 64169	 0.009293	 0.016343	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64159	 64160	 0.022557	 0.015979	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77496	 64159	 0.019193	 0.048621	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64161	 64162	 0.009507	 0.015171	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77498	 64162	 0.012007	 0.036821	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77498	 64163	 0.015121	 0.016629	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77498	 64164	 0.012186	 0.024129	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64165	 64167	 0.000936	 0.003671	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64165	 77499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64165	 77499	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64166	 64180	 0.0155	 0.012271	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77499	 64166	 0.009964	 0.008929	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64167	 64168	 0.000671	 0.002693	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77489	 64168	 0.002357	 0.009179	 0.00245	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64168	 77500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64168	 77500	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64169	 64171	 0.005814	 0.014721	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77497	 64169	 0.018636	 0.016814	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64170	 64173	 0.0012	 0.004129	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64170	 77501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64170	 77501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77501	 64171	 0.004743	 0.012571	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64172	 77502	 0.026893	 0.01905	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64173	 64175	 0.0017	 0.005729	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64173	 77502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64173	 77502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77502	 64174	 0.01315	 0.009314	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64175	 64176	 0.000921	 0.0035	 0.00098	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64176	 64178	 0.001143	 0.004579	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64177	 64180	 0.009186	 0.014736	 0.00027	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64178	 64179	 0.001121	 0.004079	 0.00125	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77489	 64179	 0.003714	 0.015329	 0.00363	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64179	 77503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64179	 77503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64180	 64181	 0.006293	 0.016671	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77503	 64180	 0.01845	 0.011943	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64181	 64182	 0.016557	 0.011729	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64181	 64183	 0.006021	 0.0201	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77500	 64181	 0.004271	 0.009771	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64184	 64202	 0.033757	 0.021857	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77470	 64184	 0.020593	 0.020229	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77475	 64185	 0.016064	 0.042586	 0.00108	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64187	 64189	 0.015221	 0.00985	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64187	 64192	 0.031171	 0.020179	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64188	 64198	 0.007057	 0.018143	 0.00449	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64188	 77504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64188	 77504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77504	 64189	 0.014871	 0.016357	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77486	 64190	 0.0121	 0.020379	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64191	 64192	 0.044093	 0.028543	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77504	 64191	 0.014071	 0.019179	 0.00043	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64191	 77506	 0.084471	 0.059836	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77485	 64192	 0.016071	 0.0407	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64193	 64194	 0.003	 0.010457	 0.00243	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64194	 64196	 0.005886	 0.019207	 0.0051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64194	 77505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64194	 77505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64195	 64197	 0.097629	 0.098614	 0.00131	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77505	 64195	 0.01545	 0.03175	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77484	 64197	 0.066421	 0.106029	 0.00244	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64198	 77506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64198	 77506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77506	 64199	 0.105493	 0.0683	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77467	 64200	 0.0023	 0.009486	 0.00224	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77481	 64200	 0.002414	 0.009493	 0.00249	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64200	 77507	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64200	 77507	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77468	 64202	 0.012079	 0.027621	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77468	 64203	 0.005636	 0.016164	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64204	 77508	 0.095336	 0.129979	 0.00289	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64205	 64212	 0.007879	 0.020821	 0.00487	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64205	 64217	 0.004914	 0.012993	 0.00304	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64205	 77508	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64205	 77508	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64206	 77510	 0.057336	 0.130071	 0.00259	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64207	 64209	 0.021979	 0.035079	 0.00081	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64207	 77510	 0.035943	 0.025464	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64207	 77511	 0.017436	 0.035836	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64208	 77510	 0.054893	 0.092471	 0.00131	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64211	 64213	 0.029493	 0.07585	 0.01879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64211	 64649	 0.044386	 0.120986	 0.02669	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64211	 77509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64211	 77509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64212	 64213	 0.009671	 0.0265	 0.00576	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64212	 77510	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64212	 77510	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64213	 64621	 0.114629	 0.305464	 0.07221	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77508	 64214	 0.035321	 0.080786	 0.00197	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64216	 64601	 0.040121	 0.159207	 0.00455	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77508	 64216	 0.0102	 0.043614	 0.00099	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64217	 64650	 0.032679	 0.086407	 0.02024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64217	 77511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64217	 77511	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64218	 77514	 0.167336	 0.331529	 0.00487	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64219	 64222	 0.010293	 0.042793	 0.00999	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64219	 64225	 0.01305	 0.050786	 0.01357	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64219	 77512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64219	 77512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77512	 64220	 0.003779	 0.020143	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64220	 77513	 0.1666	 0.168314	 0.00223	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77512	 64221	 0.055943	 0.065579	 0.00114	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64222	 77513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64222	 77513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77513	 64223	 0.038264	 0.067286	 0.00126	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76770	 64224	 0.093764	 0.1406	 0.00256	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64225	 64620	 0.059386	 0.282929	 0.06866	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64225	 64640	 0.084014	 0.299114	 0.06804	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64225	 77514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64225	 77514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76770	 64226	 0.092221	 0.075914	 0.00154	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64227	 77515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64227	 77515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76783	 64228	 0.181343	 0.371621	 0.00916	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64229	 77516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64229	 77516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64230	 64231	 0.597921	 0.424714	 0.00671	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64231	 64466	 0.1974	 0.332764	 0.00474	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76765	 64232	 0.126993	 0.290671	 0.0071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64233	 64234	 0.017371	 0.054314	 0.01574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64233	 77517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64233	 77517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77517	 64235	 0.290586	 0.285714	 0.00482	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76777	 64236	 0.288964	 0.204821	 0.00324	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64237	 64511	 0.148336	 0.381621	 0.00591	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64237	 77563	 0.188214	 0.488629	 0.00926	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76747	 64238	 0.016536	 0.208957	 0.06516	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76747	 64238	 0.016536	 0.208957	 0.06516	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64238	 77518	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64238	 77518	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64238	 77876	 0.028057	 0.212236	 0.05924	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64239	 64595	 0.109214	 0.321414	 0.00659	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77518	 64239	 0.0839	 0.172457	 0.00329	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64240	 64459	 0.054814	 0.141171	 0.03504	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76754	 64240	 0.056086	 0.1877	 0.0478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64241	 64242	 0.003779	 0.015757	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64241	 77533	 0.004564	 0.021929	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64242	 64320	 0.006457	 0.022614	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64243	 77519	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64243	 77519	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64244	 64283	 0.049943	 0.039529	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64245	 64249	 0.0013	 0.005214	 0.00131	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64245	 77522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64245	 77522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77522	 64246	 0.013879	 0.015271	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64247	 64248	 0.001214	 0.004786	 0.00125	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64247	 64251	 0.000893	 0.003907	 0.00134	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64247	 77523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64247	 77523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64248	 64249	 0.0008	 0.00315	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64248	 64376	 0.004721	 0.018379	 0.00491	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64248	 77524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64248	 77524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64250	 64254	 0.001629	 0.0068	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77524	 64250	 0.001936	 0.008579	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64251	 64252	 0.000829	 0.003879	 0.00096	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64251	 64375	 0.002957	 0.007814	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64252	 77525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64252	 77525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64253	 64254	 0.002314	 0.012443	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77525	 64253	 0.003693	 0.009779	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64254	 64255	 0.002764	 0.00945	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77524	 64254	 0.0037	 0.015457	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64255	 64275	 0.007014	 0.020121	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64255	 64276	 0.00265	 0.012343	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64256	 77526	 0.02885	 0.018679	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64257	 64258	 0.000921	 0.007636	 0.00201	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64258	 64259	 0.000629	 0.004286	 0.00146	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64259	 64270	 0.000643	 0.003871	 0.00099	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64259	 77526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64259	 77526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64260	 64261	 0.0031	 0.008221	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77526	 64260	 0.002507	 0.008786	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64261	 64283	 0.00355	 0.010436	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64262	 64270	 0.002793	 0.007386	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64262	 77527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64262	 77527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64262	 77532	 0.0021	 0.006407	 0.00139	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77527	 64263	 0.008786	 0.022243	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64264	 64265	 0.00575	 0.016964	 0.00394	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64264	 64268	 0.005457	 0.014429	 0.00338	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64265	 64267	 0.003357	 0.012157	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64265	 77528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64265	 77528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64266	 77529	 0.034186	 0.024214	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64267	 64341	 0.005964	 0.023871	 0.00601	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64267	 77529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64267	 77529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64268	 64274	 0.003629	 0.00995	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64268	 77530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64268	 77530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77528	 64269	 0.087793	 0.056836	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64270	 64286	 0.001407	 0.005479	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64270	 77531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64270	 77531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64270	 77532	 0.001371	 0.0048	 0.00159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76763	 64271	 0.001529	 0.016229	 0.24309	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77519	 64271	 0.000321	 0.005793	 0.05788	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64271	 77532	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64272	 64274	 0.001579	 0.006	 0.00168	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77532	 64272	 0.002314	 0.0105	 0.00364	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64272	 77534	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64272	 77534	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77534	 64273	 0.007514	 0.017193	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64274	 64301	 0.001729	 0.006714	 0.00179	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64275	 64283	 0.005429	 0.013743	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64276	 64277	 0.006371	 0.016893	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64277	 64278	 0.015057	 0.00975	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64277	 64280	 0.007721	 0.014357	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64277	 77535	 0.013021	 0.020893	 0.00039	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77323	 64278	 0.023621	 0.015293	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64279	 64280	 0.004529	 0.011464	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64279	 77536	 0.005243	 0.015043	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64280	 64285	 0.004736	 0.010836	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64281	 64282	 0.000707	 0.002836	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64281	 64284	 0.001793	 0.006979	 0.00186	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64282	 64292	 0.001257	 0.004929	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64282	 77535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64282	 77535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77531	 64283	 0.014307	 0.036779	 0.00057	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64284	 64287	 0.000593	 0.002457	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64284	 77536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64284	 77536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64285	 64291	 0.007143	 0.013286	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64286	 64287	 0.0008	 0.003136	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64288	 77537	 0.0041	 0.010386	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64289	 64290	 0.000571	 0.002929	 0.00074	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64289	 64292	 0.002343	 0.008529	 0.00261	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77532	 64289	 0.001029	 0.009871	 0.00287	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64289	 77537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64289	 77537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64290	 64293	 0.001421	 0.005707	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64290	 77538	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64290	 77538	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77537	 64291	 0.015814	 0.021579	 0.00039	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77532	 64292	 0.004286	 0.019986	 0.00495	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64292	 77539	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64292	 77539	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64293	 64298	 0.001179	 0.004471	 0.00125	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64293	 64299	 0.003029	 0.007293	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64294	 64295	 0.005029	 0.009343	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77538	 64294	 0.004779	 0.014057	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64295	 64300	 0.005207	 0.007807	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64296	 64297	 0.012057	 0.009543	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77539	 64296	 0.008507	 0.01945	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64298	 77540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64298	 77540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64299	 77541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64299	 77541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64300	 64372	 0.009229	 0.0076	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64301	 64330	 0.000786	 0.003157	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64302	 64305	 0.001964	 0.006857	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64302	 64334	 0.003586	 0.012686	 0.00286	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77532	 64302	 0.002857	 0.017257	 0.00441	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64302	 77542	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64302	 77542	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64303	 64304	 0.013843	 0.0182	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64303	 64308	 0.00635	 0.016086	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77537	 64303	 0.00895	 0.045264	 0.00079	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77542	 64304	 0.00615	 0.020507	 0.00033	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64305	 64312	 0.001607	 0.004386	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64306	 64307	 0.002571	 0.007557	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77540	 64306	 0.002957	 0.014964	 0.00026	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64307	 64308	 0.007271	 0.012786	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64309	 64311	 0.009121	 0.016957	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77542	 64309	 0.008	 0.042636	 0.00075	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64310	 64311	 0.002893	 0.007329	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64310	 77545	 0.007579	 0.0192	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64312	 64321	 0.003986	 0.010921	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64312	 64334	 0.001643	 0.004343	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64313	 64325	 0.007936	 0.015707	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64314	 77543	 0.018671	 0.016729	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64315	 64316	 0.004036	 0.010221	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64315	 77543	 0.004571	 0.023136	 0.0004	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64316	 64325	 0.005857	 0.014836	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64317	 64318	 0.005093	 0.012893	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64317	 77543	 0.004086	 0.009336	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64318	 64323	 0.017264	 0.013664	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64318	 64324	 0.0067	 0.015321	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64319	 64322	 0.0364	 0.035764	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77530	 64319	 0.015393	 0.0352	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64320	 77544	 0.004379	 0.014593	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64321	 64331	 0.000686	 0.002679	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64321	 77543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64321	 77543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64324	 64325	 0.014843	 0.026107	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64324	 64329	 0.032179	 0.029036	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64325	 64326	 0.003007	 0.007793	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77437	 64325	 0.0361	 0.057621	 0.00133	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64326	 64328	 0.005043	 0.011536	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64327	 64328	 0.0055	 0.0113	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64328	 64373	 0.0074	 0.013757	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64329	 77552	 0.017093	 0.023321	 0.00041	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64330	 64331	 0.000457	 0.001879	 0.00044	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64330	 77544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64330	 77544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64331	 64334	 0.005379	 0.013957	 0.00339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64332	 64333	 0.005771	 0.007871	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64332	 77545	 0.004179	 0.010586	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64334	 64335	 0.000693	 0.002629	 0.00074	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64335	 77545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64335	 77545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64338	 64356	 0.011793	 0.016086	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64338	 77546	 0.007571	 0.019186	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64339	 64359	 0.007229	 0.010529	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64339	 64364	 0.006207	 0.012707	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64340	 64348	 0.003357	 0.011871	 0.00267	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64340	 64363	 0.005793	 0.013957	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64340	 77546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64340	 77546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64341	 64342	 0.003286	 0.013657	 0.00319	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64341	 77547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64341	 77547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64342	 64347	 0.003271	 0.012429	 0.00348	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64343	 64344	 0.035707	 0.048679	 0.00108	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77529	 64343	 0.025321	 0.064143	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77547	 64344	 0.042657	 0.062157	 0.00141	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64344	 77551	 0.0923	 0.065386	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64345	 64346	 0.003871	 0.013779	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64345	 64350	 0.007336	 0.023914	 0.00635	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64346	 64348	 0.004943	 0.017229	 0.00399	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64346	 64349	 0.006057	 0.021107	 0.00489	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64346	 64350	 0.006936	 0.026357	 0.00738	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64347	 64351	 0.004179	 0.01145	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64347	 64355	 0.004136	 0.01125	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64347	 77548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64347	 77548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64348	 77549	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64348	 77549	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64349	 77550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64349	 77550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64350	 64549	 0.012714	 0.051736	 0.01261	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64350	 77551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64350	 77551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64351	 64355	 0.001936	 0.004671	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64351	 77552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64351	 77552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64352	 64353	 0.00555	 0.014714	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77552	 64352	 0.003014	 0.014036	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64354	 64366	 0.017393	 0.014314	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64355	 77553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64355	 77553	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64357	 64364	 0.03995	 0.032886	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77553	 64357	 0.018129	 0.027179	 0.00049	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64358	 64359	 0.014079	 0.009971	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64360	 77554	 0.023421	 0.016593	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64361	 64363	 0.001236	 0.004157	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 64361	 0.002586	 0.006643	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77532	 64361	 0.012057	 0.057086	 0.01373	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64361	 77554	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64361	 77554	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77554	 64362	 0.003443	 0.015243	 0.00046	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 64363	 0.001593	 0.004979	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64363	 77555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64363	 77555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77555	 64364	 0.005621	 0.012857	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64365	 64367	 0.011157	 0.014664	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77332	 64365	 0.009664	 0.027714	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64368	 64370	 0.017293	 0.015493	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77455	 64369	 0.235086	 0.152271	 0.0029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77551	 64369	 0.293586	 0.232471	 0.00293	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64370	 64371	 0.014136	 0.00915	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77555	 64370	 0.010307	 0.029557	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77542	 64372	 0.004921	 0.012464	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64373	 64378	 0.007679	 0.005436	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64374	 64375	 0.001371	 0.005479	 0.00138	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64375	 77556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64375	 77556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64376	 77557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64376	 77557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77542	 64377	 0.023586	 0.016707	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77400	 64379	 0.272736	 0.398093	 0.00901	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64379	 77603	 0.330043	 0.38745	 0.00674	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64380	 77558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64380	 77558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64381	 64382	 0.031236	 0.075314	 0.02128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64382	 64474	 0.055971	 0.13515	 0.03824	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64383	 64551	 0.00935	 0.052957	 0.01313	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64383	 64642	 0.016086	 0.076693	 0.02224	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64383	 77560	 0.000643	 0.007793	 0.00442	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64384	 77559	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64384	 77559	 0.000102	 0.008148	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79865	 64384	 0.000914	 0.031236	 3.25357	 2000.0	 2000.0	 2000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64385	 65803	 0.021264	 0.070964	 0.01801	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64386	 65814	 0.085257	 0.261729	 0.00709	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64386	 77950	 0.092529	 0.172093	 0.00403	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64387	 64394	 0.029893	 0.072071	 0.02036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64387	 64548	 0.086829	 0.224257	 0.05584	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64387	 77562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64387	 77562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64388	 64518	 0.09045	 0.206936	 0.00506	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64388	 77565	 0.0868	 0.156636	 0.00226	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64389	 77564	 0.061786	 0.043764	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64389	 77565	 0.084036	 0.075829	 0.00127	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64390	 64392	 0.024193	 0.060843	 0.01577	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64390	 64634	 0.028321	 0.073564	 0.01786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64390	 77563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64390	 77563	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64391	 64392	 0.0024	 0.006443	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64391	 64393	 0.0033	 0.008986	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64391	 77564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64391	 77564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64393	 64394	 0.003121	 0.008257	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64393	 77565	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64393	 77565	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64394	 65798	 0.016543	 0.093721	 0.02326	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64395	 64396	 0.01745	 0.013807	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64395	 64397	 0.019657	 0.013921	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64395	 64405	 0.01445	 0.015429	 0.00033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64395	 64407	 0.004536	 0.01765	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64395	 64428	 0.007793	 0.019736	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64395	 77567	 0.006543	 0.035136	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77372	 64398	 0.002429	 0.026529	 0.26133	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64398	 77566	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64399	 77568	 0.016457	 0.01065	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64400	 64403	 0.000721	 0.002743	 0.00077	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77566	 64400	 0.001321	 0.0053	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64400	 77568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64400	 77568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64401	 64402	 0.011657	 0.007543	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64401	 64405	 0.004379	 0.017043	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77568	 64401	 0.001757	 0.010807	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64403	 64404	 0.000514	 0.001986	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77566	 64403	 0.001557	 0.007264	 0.0018	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64404	 64417	 0.000786	 0.003057	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64405	 64422	 0.005079	 0.014571	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64406	 64407	 0.011171	 0.008079	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64407	 64408	 0.003464	 0.009936	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64408	 64410	 0.001964	 0.009421	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64408	 77572	 0.003707	 0.019893	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64409	 64411	 0.002686	 0.0119	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64409	 64422	 0.005793	 0.014679	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77567	 64409	 0.010943	 0.062221	 0.00113	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64410	 77569	 0.002693	 0.011929	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64411	 64413	 0.002636	 0.014986	 0.00027	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64411	 64418	 0.0041	 0.014	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64411	 77569	 0.003436	 0.012036	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64412	 64433	 0.001221	 0.003986	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64412	 77569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64412	 77569	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64413	 64414	 0.003979	 0.013586	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64413	 64420	 0.025029	 0.016207	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64414	 64434	 0.004579	 0.012143	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64415	 64416	 0.005707	 0.013057	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64415	 64425	 0.005257	 0.020536	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64415	 64442	 0.035743	 0.023143	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64415	 64448	 0.029279	 0.066414	 0.00133	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64416	 64436	 0.018564	 0.01315	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64416	 64438	 0.042814	 0.027721	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64417	 64419	 0.001457	 0.005293	 0.00162	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64417	 77570	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64417	 77570	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64418	 77571	 0.002821	 0.011207	 0.00032	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64419	 77571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64419	 77571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77570	 64421	 0.01045	 0.015664	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64423	 64448	 0.0124	 0.059507	 0.00178	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77570	 64423	 0.002664	 0.015171	 0.00046	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64424	 64425	 0.004793	 0.0205	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77571	 64424	 0.003114	 0.015743	 0.00027	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77567	 64426	 0.022421	 0.045893	 0.00113	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64427	 64428	 0.005479	 0.0161	 0.00033	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77567	 64427	 0.007586	 0.025914	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64429	 64431	 0.001271	 0.013779	 0.0058	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64429	 64431	 0.001271	 0.013779	 0.0058	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64429	 64432	 0.000414	 0.004079	 0.00125	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77566	 64429	 0.002364	 0.018129	 0.00486	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64429	 77572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64429	 77572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77572	 64430	 0.027029	 0.0175	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64431	 64461	 0.002379	 0.02825	 0.00984	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64431	 64461	 0.002379	 0.02825	 0.00984	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64432	 64433	 0.0021	 0.007986	 0.00224	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64432	 64460	 0.003036	 0.0118	 0.00315	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64433	 64435	 0.001307	 0.004643	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64434	 64437	 0.023443	 0.015179	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64434	 77573	 0.008814	 0.018114	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64435	 77573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64435	 77573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64439	 64456	 0.006164	 0.015507	 0.00401	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64439	 77574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64439	 77574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64439	 77575	 0.002793	 0.010871	 0.00291	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64440	 64441	 0.013843	 0.020171	 0.00046	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64440	 64444	 0.024843	 0.025093	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77574	 64440	 0.009693	 0.0225	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64441	 64446	 0.005679	 0.012993	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76756	 64443	 0.00295	 0.020329	 0.0359	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64443	 77575	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77576	 64443	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64444	 64450	 0.027214	 0.02455	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64445	 64446	 0.006957	 0.015914	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64445	 64448	 0.005071	 0.036493	 0.00119	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64445	 64450	 0.007021	 0.02065	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76778	 64445	 0.148179	 0.149693	 0.00199	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64447	 64448	 0.024129	 0.069193	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64449	 64450	 0.005164	 0.013086	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64449	 77577	 0.02205	 0.02425	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64452	 77577	 0.0219	 0.018029	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64453	 64456	 0.003543	 0.009707	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64453	 77577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64453	 77577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64454	 64464	 0.038664	 0.061714	 0.00142	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77577	 64454	 0.006379	 0.0169	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64455	 64456	 0.004371	 0.011236	 0.00279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77567	 64457	 0.072207	 0.072936	 0.00096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64458	 64459	 0.021307	 0.056329	 0.01319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64458	 64462	 0.035329	 0.096257	 0.02123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64460	 64723	 0.005029	 0.019757	 0.00517	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76750	 64461	 0.004236	 0.053264	 0.01651	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76750	 64461	 0.004236	 0.053264	 0.01651	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76750	 64462	 0.001329	 0.015014	 0.00843	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64462	 77578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64462	 77578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64463	 64464	 0.040621	 0.065164	 0.00121	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64464	 77648	 0.053321	 0.105571	 0.00155	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64465	 64467	 0.183164	 0.144986	 0.00183	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64468	 64470	 0.052979	 0.206979	 0.00459	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77518	 64468	 0.07	 0.310293	 0.00708	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64469	 77579	 0.14265	 0.092364	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64470	 77877	 0.072621	 0.283779	 0.0063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64471	 77579	 0.107686	 0.069721	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64472	 64473	 0.044393	 0.133893	 0.04199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64472	 77579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64472	 77579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64472	 77876	 0.030421	 0.095186	 0.0276	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64473	 64545	 0.035036	 0.1449	 0.03436	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64474	 64731	 0.097193	 0.263371	 0.07451	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64474	 77580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64474	 77580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76771	 64475	 0.510114	 0.362071	 0.00572	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64476	 77581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64476	 77581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64477	 77582	 0.155143	 0.109914	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64478	 77582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64478	 77582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64479	 64481	 0.119864	 0.210871	 0.00396	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76786	 64479	 0.1686	 0.382879	 0.00765	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77582	 64479	 0.02905	 0.066443	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64480	 64652	 0.114893	 0.392921	 0.00856	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77582	 64480	 0.009764	 0.0555	 0.00101	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64482	 64483	 0.009143	 0.010057	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64482	 77584	 0.010871	 0.021529	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64483	 77583	 0.02385	 0.016893	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64484	 64490	 0.003279	 0.0079	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64484	 77583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64484	 77583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64485	 64491	 0.028536	 0.028821	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64485	 64492	 0.014293	 0.025793	 0.00037	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77583	 64485	 0.006864	 0.015943	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64486	 64487	 0.003207	 0.007271	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64486	 64491	 0.008057	 0.010986	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64487	 77584	 0.0032	 0.007307	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64488	 64489	 0.001993	 0.005	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64488	 64493	 0.00325	 0.008357	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64488	 64499	 0.004486	 0.014014	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64488	 77584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64488	 77584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64489	 64505	 0.004229	 0.014936	 0.00336	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64489	 77585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64489	 77585	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64490	 64499	 0.001843	 0.007179	 0.00192	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64490	 77586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64490	 77586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77586	 64492	 0.020407	 0.035886	 0.00067	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64493	 64494	 0.001171	 0.003671	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64494	 64505	 0.001464	 0.004571	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64495	 64507	 0.008357	 0.014693	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77404	 64495	 0.149429	 0.33925	 0.00677	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64496	 64497	 0.012986	 0.029457	 0.00059	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77583	 64496	 0.076464	 0.054164	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77404	 64497	 0.157386	 0.404957	 0.00627	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77585	 64497	 0.025643	 0.030057	 0.00052	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77586	 64498	 0.066157	 0.066821	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64499	 64500	 0.00165	 0.0083	 0.00216	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64500	 64510	 0.013679	 0.059957	 0.02064	 191.0	 191.0	 191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77586	 64502	 0.033664	 0.231179	 0.00421	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77586	 64503	 0.028364	 0.075186	 0.00191	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64504	 77587	 0.025821	 0.035229	 0.00063	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64505	 64506	 0.001993	 0.005579	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64506	 77587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64506	 77587	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64507	 64508	 0.006314	 0.016743	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77587	 64507	 0.008536	 0.021621	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77585	 64508	 0.060093	 0.0389	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76770	 64509	 0.10595	 0.362279	 0.00789	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76783	 64509	 0.293879	 0.263607	 0.00539	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64510	 78003	 0.019471	 0.232714	 0.08181	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64510	 78003	 0.019471	 0.232714	 0.08181	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77370	 64511	 0.485443	 0.53515	 0.00715	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64511	 77615	 0.122321	 0.4184	 0.00911	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64512	 64514	 0.004779	 0.009471	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64513	 64514	 0.012093	 0.023936	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76746	 64514	 0.012386	 0.076143	 0.00137	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76746	 64515	 0.369036	 0.504479	 0.01121	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64516	 64522	 0.024836	 0.067643	 0.01491	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64516	 65807	 0.035121	 0.094357	 0.02141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64517	 64518	 0.318314	 0.225657	 0.00356	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64517	 77617	 0.823214	 0.53615	 0.01019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64518	 77589	 0.047214	 0.238907	 0.00416	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64519	 64522	 0.027093	 0.065314	 0.01845	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64519	 66253	 0.08425	 0.196471	 0.06016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64519	 77588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64519	 77588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64520	 64522	 0.005736	 0.015721	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64520	 64638	 0.070579	 0.1871	 0.04395	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76787	 64520	 0.029714	 0.168657	 0.04194	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64520	 77589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64520	 77589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77589	 64521	 0.052786	 0.04345	 0.00088	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64521	 77590	 0.009857	 0.012829	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64522	 77590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64522	 77590	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76767	 64523	 0.0606	 0.12	 0.00176	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64524	 64526	 0.030879	 0.08295	 0.01881	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64524	 77591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64524	 77591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76780	 64525	 0.08025	 0.120329	 0.00219	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64526	 64527	 0.003086	 0.008014	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64526	 77592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64526	 77592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64527	 64531	 0.002986	 0.0079	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64527	 77593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64527	 77593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64528	 64548	 0.02355	 0.080836	 0.01938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64528	 77594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64528	 77594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77593	 64529	 0.028671	 0.020314	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77592	 64530	 0.047371	 0.050586	 0.00107	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64531	 64548	 0.034707	 0.0837	 0.02365	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77591	 64532	 0.336986	 0.238914	 0.00378	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77592	 64532	 0.207679	 0.1644	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64533	 77595	 0.256843	 0.20335	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64534	 77596	 0.087486	 0.139679	 0.00321	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64535	 77595	 0.026807	 0.069471	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76784	 64536	 0.009	 0.032743	 0.01002	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64536	 77595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64536	 77595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77595	 64537	 0.008964	 0.009571	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64538	 64729	 0.015029	 0.109986	 0.0325	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64538	 77596	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64538	 77596	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76744	 64539	 0.005243	 0.037714	 0.00124	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76785	 64539	 0.003429	 0.013393	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76785	 64539	 0.003429	 0.013393	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76785	 64540	 0.145536	 0.103107	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64541	 64542	 0.096436	 0.2767	 0.00426	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64541	 64616	 0.10535	 0.266986	 0.00529	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64542	 64546	 0.178307	 0.159836	 0.00327	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64542	 77597	 0.031721	 0.065193	 0.00124	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64543	 64545	 0.012829	 0.053336	 0.01245	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64543	 64547	 0.017407	 0.041964	 0.01185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64543	 77597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64543	 77597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77597	 64544	 0.093079	 0.127007	 0.00227	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64544	 77598	 0.018057	 0.041293	 0.00101	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77371	 64546	 0.153771	 0.441521	 0.0068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64546	 77598	 0.168564	 0.1703	 0.00226	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64547	 77598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64547	 77598	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64548	 64635	 0.027307	 0.068671	 0.0178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64548	 77599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64548	 77599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64549	 64641	 0.019786	 0.082271	 0.01922	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76764	 64549	 0.012421	 0.050564	 0.01232	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64549	 77600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64549	 77600	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77600	 64550	 0.228029	 0.1788	 0.00229	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64551	 64552	 0.013186	 0.0574	 0.01636	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64551	 77601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64551	 77601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64552	 64647	 0.030907	 0.123921	 0.04196	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64553	 64649	 0.026579	 0.086757	 0.02305	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64554	 77602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64554	 77602	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77602	 64555	 0.14065	 0.247479	 0.00465	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64557	 64558	 0.195171	 0.126393	 0.00241	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64557	 64559	 0.055079	 0.099386	 0.00144	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77517	 64558	 0.510393	 0.458786	 0.00939	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76768	 64559	 0.117693	 0.269343	 0.00658	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64560	 77603	 0.053471	 0.094043	 0.00176	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64561	 77603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64561	 77603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77371	 64562	 0.429221	 0.472936	 0.00631	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77603	 64562	 0.01155	 0.023736	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76760	 64564	 0.049721	 0.231929	 0.00534	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64565	 64569	 0.007164	 0.018979	 0.00048	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64565	 64605	 0.029779	 0.075443	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64566	 64567	 0.012057	 0.0078	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64566	 64599	 0.026836	 0.021236	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64567	 64568	 0.002936	 0.006721	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64567	 64570	 0.004414	 0.011186	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64568	 64569	 0.006557	 0.011536	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64569	 64574	 0.021864	 0.017307	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64569	 77611	 0.007986	 0.024493	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64571	 64577	 0.008186	 0.016814	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64571	 77611	 0.010714	 0.017193	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64572	 64573	 0.006586	 0.016686	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64572	 64576	 0.013564	 0.014921	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64572	 77609	 0.012593	 0.044086	 0.00122	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64573	 64611	 0.004471	 0.011329	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64574	 64575	 0.012529	 0.008871	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64574	 64611	 0.010307	 0.023379	 0.00046	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64576	 64577	 0.004307	 0.007571	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64577	 64578	 0.004014	 0.009179	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64578	 77610	 0.007593	 0.020129	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64579	 64584	 0.010807	 0.008893	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64579	 77611	 0.018314	 0.011857	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64580	 64583	 0.012871	 0.008336	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64581	 64583	 0.016236	 0.013364	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64581	 77607	 0.030414	 0.021543	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64582	 64591	 0.001036	 0.003764	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64582	 64594	 0.0012	 0.00495	 0.00117	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64582	 77604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64582	 77604	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64583	 64584	 0.019393	 0.013736	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77604	 64583	 0.013107	 0.017221	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64584	 64590	 0.004457	 0.010107	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64585	 64586	 0.00395	 0.010157	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64585	 77611	 0.027757	 0.017971	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64586	 77605	 0.004443	 0.010157	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64587	 64594	 0.003657	 0.013314	 0.00408	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64587	 64612	 0.001571	 0.008186	 0.00241	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64587	 77605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64587	 77605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64588	 64589	 0.017586	 0.011386	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77605	 64588	 0.006414	 0.011279	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64589	 64590	 0.009336	 0.009171	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64589	 77606	 0.007707	 0.010129	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77605	 64590	 0.010779	 0.017207	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76747	 64591	 0.002021	 0.01625	 0.00457	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64591	 77606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64591	 77606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64592	 64593	 0.0033	 0.009693	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64592	 64597	 0.021707	 0.019586	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77606	 64592	 0.00255	 0.0123	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64593	 64598	 0.006693	 0.016943	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64594	 77607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64594	 77607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64595	 64596	 0.097164	 0.204279	 0.00372	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64595	 64598	 0.101029	 0.256036	 0.00507	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76748	 64596	 0.043979	 0.250071	 0.00453	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77510	 64596	 0.121707	 0.322893	 0.0082	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77607	 64599	 0.024386	 0.033271	 0.00059	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64600	 77611	 0.027836	 0.081864	 0.00168	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64601	 64604	 0.014807	 0.065607	 0.00197	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64602	 64606	 0.048529	 0.038407	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64603	 64605	 0.017507	 0.013721	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64604	 64605	 0.0061	 0.026086	 0.00059	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64604	 64606	 0.005907	 0.0197	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64605	 64607	 0.007029	 0.011221	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64606	 64607	 0.007893	 0.018057	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64607	 64608	 0.005179	 0.023071	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77607	 64608	 0.009414	 0.050171	 0.00088	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64609	 64617	 0.005871	 0.044686	 0.01404	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64609	 77608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64609	 77608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64610	 64612	 0.005729	 0.015136	 0.00354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76747	 64610	 0.003864	 0.017557	 0.00609	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64610	 77609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64610	 77609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76747	 64612	 0.000557	 0.00545	 0.00474	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64612	 77610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64612	 77610	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77610	 64613	 0.008014	 0.02805	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77610	 64613	 0.008014	 0.02805	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64613	 77612	 0.079614	 0.27895	 0.00773	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64613	 77612	 0.079614	 0.27895	 0.00773	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76748	 64614	 0.025929	 0.065686	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77609	 64614	 0.013357	 0.021321	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76748	 64615	 0.002407	 0.004236	 8e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76748	 64616	 0.093793	 0.328736	 0.00911	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76748	 64616	 0.093793	 0.328736	 0.00911	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77518	 64616	 0.2044	 0.518786	 0.0103	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76747	 64617	 0.001571	 0.017179	 0.00476	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64617	 77611	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64617	 77611	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76747	 64618	 0.005479	 0.065114	 0.02269	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64618	 77612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64618	 77612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64619	 64620	 0.0637	 0.165614	 0.05029	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76745	 64619	 0.010793	 0.13605	 0.04226	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64619	 77613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64619	 77613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64620	 66289	 0.0704	 0.192243	 0.04251	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64620	 66290	 0.074071	 0.196414	 0.04616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64621	 64623	 0.015643	 0.052193	 0.01324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64621	 77614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64621	 77614	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77403	 64622	 0.7395	 0.481064	 0.00914	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64622	 77615	 0.150914	 0.106921	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64623	 65803	 0.075864	 0.35195	 0.09156	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64623	 77615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64623	 77615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76755	 64624	 0.456171	 0.361507	 0.00455	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76755	 64625	 0.066179	 0.059714	 0.001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64626	 64631	 0.141	 0.357486	 0.00709	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76755	 64626	 0.04615	 0.135729	 0.00279	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64627	 64628	 0.109221	 0.077371	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64627	 64630	 0.0632	 0.144557	 0.00353	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76755	 64627	 0.058057	 0.203207	 0.00421	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64629	 64630	 0.088643	 0.096557	 0.00131	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77397	 64632	 0.284086	 0.50825	 0.00751	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77615	 64632	 0.870643	 0.567457	 0.01079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77615	 64633	 0.312721	 0.257671	 0.00522	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64634	 64635	 0.018807	 0.050507	 0.01145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64635	 77616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64635	 77616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77616	 64636	 0.091229	 0.059064	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77599	 64637	 0.409543	 0.265529	 0.00505	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77616	 64637	 0.263279	 0.20845	 0.00262	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64638	 77617	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64638	 77617	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76786	 64639	 0.4867	 0.479343	 0.00809	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64640	 64641	 0.019864	 0.080879	 0.01972	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77373	 64640	 0.087529	 0.232436	 0.05471	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77560	 64640	 0.040814	 0.163779	 0.04139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64640	 77618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64640	 77618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64641	 64644	 0.006814	 0.031064	 0.00986	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76764	 64641	 0.012471	 0.051493	 0.01219	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64642	 64643	 0.005579	 0.025586	 0.00656	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64642	 77619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64642	 77619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64643	 64644	 0.004679	 0.025164	 0.00619	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64643	 77620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64643	 77620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64645	 64647	 0.012157	 0.032143	 0.00752	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64645	 64649	 0.0312	 0.082507	 0.01933	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76781	 64645	 0.014229	 0.038743	 0.00854	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77480	 64645	 0.009779	 0.023557	 0.00665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64645	 77621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64645	 77621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64646	 64648	 0.196657	 0.139343	 0.0022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77621	 64646	 0.072107	 0.057064	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76781	 64647	 0.026343	 0.072221	 0.01571	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64648	 77622	 0.091164	 0.136693	 0.00249	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64649	 64650	 0.016321	 0.043143	 0.0101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64649	 77622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64649	 77622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64651	 64652	 0.1873	 0.29925	 0.0069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76785	 64652	 0.227121	 0.282193	 0.00615	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64653	 64654	 0.020336	 0.014407	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64653	 64661	 0.004243	 0.007464	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64653	 64665	 0.021914	 0.025693	 0.00045	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64653	 77625	 0.013957	 0.022271	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64655	 64656	 0.0037	 0.006879	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64655	 64665	 0.004229	 0.0096	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64656	 64666	 0.004886	 0.014021	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64656	 77623	 0.003893	 0.009871	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64657	 64659	 0.0006	 0.002407	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64657	 64662	 0.001743	 0.0099	 0.00286	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64657	 77623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64657	 77623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64658	 77624	 0.010729	 0.0076	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64659	 64660	 0.001179	 0.004479	 0.00125	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64659	 77624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64659	 77624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64660	 64674	 0.000564	 0.004836	 0.00138	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64660	 77625	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64660	 77625	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64660	 77632	 0.001143	 0.012886	 0.00496	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64662	 64664	 0.003236	 0.008136	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64662	 64728	 0.020229	 0.121586	 0.0369	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64662	 77626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64662	 77626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77626	 64663	 0.023486	 0.015207	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64664	 64729	 0.026129	 0.085286	 0.02266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64664	 77627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64664	 77627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64665	 64668	 0.01165	 0.020493	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77626	 64665	 0.003621	 0.01945	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64666	 64667	 0.003207	 0.007343	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64667	 64670	 0.004436	 0.011236	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64669	 64670	 0.005807	 0.014929	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64669	 64677	 0.019857	 0.045414	 0.00111	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77627	 64669	 0.031679	 0.080243	 0.00159	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64671	 64680	 0.002671	 0.012814	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77623	 64671	 0.003436	 0.025114	 0.00046	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64672	 64673	 0.013307	 0.010429	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64672	 64680	 0.009879	 0.022593	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64672	 64681	 0.019807	 0.018243	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64672	 77628	 0.006143	 0.016286	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64674	 64688	 0.000593	 0.003864	 0.00099	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64674	 77628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64674	 77628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64675	 64677	 0.038214	 0.024743	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64676	 64677	 0.029836	 0.021136	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64677	 64678	 0.025029	 0.016207	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64677	 64679	 0.006479	 0.016414	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64677	 77647	 0.010907	 0.052336	 0.00156	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64679	 64680	 0.006907	 0.0175	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64680	 64682	 0.008457	 0.021414	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64681	 64684	 0.014086	 0.012714	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64682	 64683	 0.008714	 0.022079	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64682	 64685	 0.004479	 0.01025	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64683	 77647	 0.025721	 0.075636	 0.00155	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64684	 77631	 0.008214	 0.010793	 0.00015	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64685	 77629	 0.004186	 0.010607	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64686	 64687	 0.001114	 0.004243	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64686	 64688	 0.0006	 0.00365	 0.00093	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64686	 77629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64686	 77629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64687	 64725	 0.004114	 0.016171	 0.00423	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64687	 77630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64687	 77630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64688	 77631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64688	 77631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64689	 77632	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77633	 64689	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77627	 64690	 0.041936	 0.061114	 0.00138	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64691	 64692	 0.040457	 0.092529	 0.00226	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77627	 64691	 0.0302	 0.117943	 0.00261	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64692	 64695	 0.015779	 0.075736	 0.00226	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76758	 64692	 0.034914	 0.09255	 0.00235	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76759	 64693	 0.001257	 0.019264	 0.00621	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76752	 64694	 0.003871	 0.017657	 0.0056	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64694	 77634	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64694	 77634	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76775	 64695	 0.005271	 0.035793	 0.00089	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64696	 77635	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64696	 77635	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77634	 64697	 0.009229	 0.052471	 0.00095	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64698	 64699	 0.002786	 0.010121	 0.0031	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64698	 64708	 0.001164	 0.004236	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64698	 77636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64698	 77636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77636	 64700	 0.011593	 0.045264	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64701	 64703	 0.002814	 0.00995	 0.00224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64701	 77637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64701	 77637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64702	 77638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64702	 77638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64703	 64705	 0.003686	 0.01265	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64703	 77639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64703	 77639	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64704	 77640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64704	 77640	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64704	 77645	 0.003964	 0.016136	 0.00393	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64705	 64706	 0.001979	 0.006993	 0.00158	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64706	 64707	 0.001643	 0.004271	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64706	 77641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64706	 77641	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64706	 77645	 0.00555	 0.0152	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64707	 64715	 0.005307	 0.014886	 0.00384	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64707	 77642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64707	 77642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64708	 64710	 0.001829	 0.0064	 0.00212	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64708	 77643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64708	 77643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76753	 64709	 0.002379	 0.011107	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77643	 64709	 0.004564	 0.021293	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64710	 64715	 0.00385	 0.010186	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76752	 64710	 0.001929	 0.008393	 0.00239	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64710	 77644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64710	 77644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77640	 64711	 0.0152	 0.024271	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77641	 64711	 0.010993	 0.01755	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77643	 64712	 0.073421	 0.05755	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64712	 77646	 0.038543	 0.027307	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64713	 77645	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64714	 64715	 0.002307	 0.00555	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77645	 64714	 0.002343	 0.005643	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 64715	 0.006007	 0.027543	 0.00706	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64716	 64725	 0.006207	 0.023586	 0.0066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 64716	 0.005014	 0.028493	 0.00825	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77575	 64716	 0.01075	 0.037471	 0.00869	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64716	 77647	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64716	 77647	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77647	 64717	 0.023964	 0.0548	 0.00134	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76757	 64718	 0.00245	 0.023043	 0.00698	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64718	 77648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64718	 77648	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64719	 64720	 0.002093	 0.005264	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64719	 64721	 0.001493	 0.004007	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64719	 77649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64719	 77649	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64720	 64721	 0.001464	 0.003764	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64720	 64725	 0.003571	 0.010536	 0.00245	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64720	 77650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64720	 77650	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64721	 64722	 0.001336	 0.005557	 0.0013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64722	 64723	 0.002021	 0.008079	 0.00204	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64724	 77651	 0.138579	 0.098179	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64725	 77651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64725	 77651	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77650	 64726	 0.052193	 0.036971	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77633	 64727	 0.043493	 0.112729	 0.00213	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64728	 77652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64728	 77652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76759	 64729	 0.010336	 0.041379	 0.01398	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64730	 77653	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64730	 77653	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64731	 77654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64731	 77654	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64732	 65262	 0.049621	 0.237836	 0.06944	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64732	 77655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64732	 77655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64733	 77656	 0.005293	 0.015571	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64733	 77657	 0.014507	 0.067629	 0.00156	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64734	 64735	 0.005036	 0.023107	 0.00592	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64734	 77656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64734	 77656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64735	 77657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64735	 77657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64735	 77659	 0.011536	 0.046936	 0.01144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76837	 64736	 0.019221	 0.095364	 0.00227	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76839	 64736	 0.021586	 0.132721	 0.00239	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76840	 64737	 0.02225	 0.118107	 0.0395	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64737	 77780	 0.014564	 0.0593	 0.01445	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64738	 65279	 0.010864	 0.131229	 1.29171	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64738	 77659	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64738	 77659	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64739	 64776	 0.002114	 0.008029	 0.00225	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64739	 65035	 0.003586	 0.01645	 0.00421	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64739	 77660	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64739	 77660	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64740	 64863	 0.003136	 0.010714	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64740	 64911	 0.011879	 0.007693	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64740	 64916	 0.006557	 0.014864	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64741	 64747	 0.008821	 0.023371	 0.00059	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64741	 64995	 0.009086	 0.030314	 0.00048	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64741	 77668	 0.009871	 0.017629	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64742	 64743	 0.011879	 0.008414	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64742	 64745	 0.007114	 0.00935	 0.00013	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64743	 77667	 0.0066	 0.011607	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64744	 64745	 0.0046	 0.008093	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64744	 64995	 0.003629	 0.0092	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 64744	 0.004786	 0.015964	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64746	 64749	 0.017607	 0.019364	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64747	 64749	 0.00555	 0.014714	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64747	 64772	 0.012664	 0.022271	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64748	 64774	 0.010429	 0.016643	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64748	 64779	 0.004914	 0.008836	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64748	 77668	 0.010079	 0.025536	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64749	 64750	 0.008014	 0.012857	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64749	 64772	 0.008057	 0.010986	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64749	 77661	 0.004243	 0.0189	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64750	 65002	 0.012943	 0.014236	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64751	 77661	 0.010871	 0.008521	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64752	 65048	 0.003143	 0.012971	 0.00307	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64752	 77661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64752	 77661	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64752	 77665	 0.002486	 0.009029	 0.00276	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64753	 64771	 0.003371	 0.007714	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64753	 64772	 0.004593	 0.009443	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64754	 64766	 0.004836	 0.008507	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77661	 64754	 0.00475	 0.007579	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64755	 64757	 0.000821	 0.002064	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64755	 65052	 0.000821	 0.002171	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64755	 77662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64755	 77662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64756	 77663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64756	 77663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64756	 77665	 0.001636	 0.004557	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64757	 64759	 0.000821	 0.0021	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64758	 77666	 0.006929	 0.008121	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64759	 65071	 0.001593	 0.004771	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64759	 77664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64759	 77664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64760	 64889	 0.0011	 0.012029	 0.02333	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64760	 65075	 0.000764	 0.005257	 0.00929	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76829	 64760	 0.000921	 0.008793	 0.01563	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64760	 77665	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77666	 64760	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77664	 64761	 0.008407	 0.009243	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64761	 77670	 0.005364	 0.011021	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64761	 77714	 0.016343	 0.014643	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64762	 64763	 0.003	 0.006864	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64762	 64764	 0.003114	 0.008921	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64763	 64771	 0.001321	 0.00655	 0.00016	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64763	 64782	 0.002343	 0.009121	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64764	 64765	 0.002121	 0.006514	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64764	 64766	 0.002657	 0.007614	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64765	 64784	 0.0027	 0.008293	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64766	 64767	 0.00375	 0.006979	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64767	 65041	 0.003264	 0.007464	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64768	 64769	 0.002443	 0.008343	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64768	 65041	 0.003329	 0.008429	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64769	 64770	 0.006764	 0.006643	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77663	 64769	 0.002236	 0.005929	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77662	 64770	 0.006871	 0.013607	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64771	 64773	 0.003129	 0.007929	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64772	 64773	 0.006336	 0.007864	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64772	 64817	 0.068871	 0.054507	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64773	 64774	 0.003714	 0.0076	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64774	 64780	 0.02035	 0.013179	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64775	 64776	 0.001057	 0.004029	 0.00113	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64775	 64881	 0.002786	 0.012786	 0.00328	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64775	 77667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64775	 77667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64776	 64812	 0.001486	 0.006121	 0.00145	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64776	 64813	 0.00095	 0.003357	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64776	 77668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64776	 77668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64777	 64778	 0.015307	 0.020114	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 64777	 0.018543	 0.018221	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64778	 77673	 0.005943	 0.017043	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64779	 64780	 0.003757	 0.007686	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64779	 64817	 0.033036	 0.02615	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64780	 64811	 0.005271	 0.015129	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64781	 64809	 0.014164	 0.013914	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64782	 64783	 0.004843	 0.007729	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64782	 64784	 0.002393	 0.009493	 0.00027	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64783	 64808	 0.002629	 0.008771	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64783	 64809	 0.004107	 0.010893	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64784	 64785	 0.002043	 0.0091	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77666	 64784	 0.002321	 0.014286	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64785	 64788	 0.001707	 0.006543	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76830	 64786	 0.00215	 0.0114	 0.00289	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64786	 77669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64786	 77669	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64786	 77716	 0.002221	 0.008886	 0.00224	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64787	 64791	 0.004721	 0.01355	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64787	 64806	 0.003314	 0.008386	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64788	 64789	 0.001943	 0.007564	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77666	 64788	 0.002793	 0.010907	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64789	 64791	 0.006707	 0.0107	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64789	 77670	 0.002114	 0.007221	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64790	 65063	 0.001129	 0.003686	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77665	 64790	 0.002414	 0.006064	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64790	 77670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64790	 77670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64791	 64792	 0.002936	 0.006714	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64791	 64806	 0.007864	 0.022564	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64791	 77717	 0.0116	 0.029379	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64792	 65076	 0.004379	 0.017021	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64793	 64794	 0.001821	 0.007607	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64793	 64795	 0.008693	 0.011421	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64793	 64797	 0.007364	 0.022171	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64794	 64795	 0.003686	 0.009764	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64794	 64807	 0.001793	 0.006271	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64794	 77675	 0.002879	 0.012743	 0.00029	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64795	 64796	 0.002807	 0.009593	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64796	 64797	 0.002064	 0.00705	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64797	 64801	 0.00465	 0.012321	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77669	 64797	 0.001286	 0.006379	 0.00015	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64798	 64799	 0.000536	 0.002157	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64798	 64825	 0.000471	 0.001879	 0.00047	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64798	 77671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64798	 77671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64799	 64839	 0.0006	 0.002171	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64800	 64801	 0.004479	 0.007143	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64800	 64804	 0.01215	 0.007864	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64801	 64802	 0.001807	 0.008814	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64802	 64803	 0.011364	 0.008993	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64802	 77672	 0.0019	 0.007414	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64802	 77677	 0.003779	 0.009707	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64805	 65080	 0.000714	 0.002486	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64805	 77672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64805	 77672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64806	 64808	 0.005079	 0.014579	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64807	 64808	 0.002471	 0.00655	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64809	 64810	 0.0029	 0.006629	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64809	 64811	 0.005107	 0.015029	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64810	 77675	 0.002729	 0.010657	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64811	 77765	 0.00525	 0.025207	 0.00075	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64812	 77673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64812	 77673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64812	 77764	 0.001329	 0.006886	 0.00168	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64813	 64815	 0.001	 0.003129	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64814	 77674	 0.009336	 0.008364	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64815	 64909	 0.000879	 0.003571	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64815	 77674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64815	 77674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77674	 64816	 0.010307	 0.008157	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64817	 64818	 0.015007	 0.010629	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64817	 64819	 0.002714	 0.012036	 0.00027	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77673	 64817	 0.01345	 0.017679	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64817	 77689	 0.024636	 0.033586	 0.00074	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64819	 64820	 0.002029	 0.006229	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64819	 64821	 0.002493	 0.007329	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64820	 77675	 0.002814	 0.010979	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64821	 64822	 0.006593	 0.007729	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64821	 64829	 0.002707	 0.008314	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64822	 64827	 0.006414	 0.011279	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64823	 64825	 0.000993	 0.003514	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64823	 77675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64823	 77675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64824	 64826	 0.003593	 0.007357	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64824	 64830	 0.002636	 0.005414	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64824	 77676	 0.003086	 0.007064	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64825	 77676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64825	 77676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64826	 64827	 0.005014	 0.011529	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77675	 64827	 0.009807	 0.020157	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64827	 77765	 0.010907	 0.025329	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64828	 64829	 0.004571	 0.006664	 0.00015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64828	 65219	 0.012114	 0.0213	 0.0004	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64829	 77765	 0.002036	 0.008086	 0.00023	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64830	 64831	 0.014886	 0.009636	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64830	 64832	 0.01315	 0.009314	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64830	 65219	 0.011171	 0.025343	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77671	 64830	 0.003543	 0.012093	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64833	 65088	 0.02245	 0.014536	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64833	 65220	 0.026486	 0.020957	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64834	 64844	 0.006543	 0.011514	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64834	 64847	 0.011543	 0.017679	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64834	 64908	 0.007893	 0.01805	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64835	 65102	 0.02225	 0.015764	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64836	 64860	 0.010286	 0.010986	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64837	 64843	 0.010093	 0.012529	 0.00027	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64837	 65220	 0.007436	 0.017014	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64837	 77720	 0.005314	 0.020436	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64838	 64842	 0.000793	 0.00375	 0.0009	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76830	 64838	 0.000843	 0.0048	 0.00139	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64838	 77677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64838	 77677	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64839	 64841	 0.000764	 0.003007	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64839	 77678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64839	 77678	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77678	 64840	 0.010764	 0.006971	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64841	 64842	 0.000471	 0.002229	 0.00054	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77677	 64843	 0.0082	 0.00805	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64844	 64848	 0.007264	 0.014929	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64844	 64853	 0.02645	 0.020936	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64845	 77679	 0.014329	 0.01015	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64846	 64854	 0.001443	 0.005093	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64846	 77679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64846	 77679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64847	 64848	 0.003664	 0.010771	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64847	 65184	 0.022507	 0.015943	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77679	 64848	 0.005171	 0.0216	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64848	 77682	 0.007307	 0.024379	 0.00039	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64848	 77754	 0.075529	 0.0489	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64849	 64850	 0.0045	 0.007914	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77679	 64849	 0.008693	 0.014643	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64850	 64851	 0.012914	 0.010221	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64850	 64852	 0.012757	 0.009036	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64850	 64860	 0.008857	 0.018207	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64851	 77681	 0.022464	 0.020264	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64851	 77682	 0.0127	 0.009	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64853	 64861	 0.0266	 0.017221	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64853	 65219	 0.057743	 0.0409	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64854	 65097	 0.001114	 0.003643	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64854	 77680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64854	 77680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64855	 77681	 0.029343	 0.019	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64856	 65188	 0.008886	 0.0176	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64856	 77681	 0.010629	 0.030493	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64857	 64858	 0.001207	 0.003186	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64857	 65118	 0.001864	 0.005829	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64857	 77681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64857	 77681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64858	 77682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64858	 77682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64859	 64860	 0.003636	 0.006764	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64859	 65117	 0.006386	 0.014493	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77681	 64860	 0.027364	 0.0301	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64860	 77723	 0.016293	 0.075957	 0.00175	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	64861	 65219	 0.019136	 0.022429	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77679	 64861	 0.010764	 0.031643	 0.00065	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77680	 64862	 0.017207	 0.012186	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77667	 64863	 0.002479	 0.015221	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64863	 77684	 0.008914	 0.016021	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64864	 64881	 0.00105	 0.003993	 0.00112	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64864	 64960	 0.0012	 0.003264	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64864	 77683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64864	 77683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64865	 64871	 0.001264	 0.00435	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64865	 64915	 0.00095	 0.003307	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64865	 77684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64865	 77684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64866	 64871	 0.001243	 0.004343	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64866	 64873	 0.001079	 0.004229	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64866	 65198	 0.003636	 0.012471	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64866	 77685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64866	 77685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64867	 64890	 0.01475	 0.01045	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64868	 64879	 0.002921	 0.006679	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64868	 64890	 0.004557	 0.010421	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64869	 64870	 0.002271	 0.007486	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77674	 64869	 0.003321	 0.010186	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64870	 64877	 0.004664	 0.011821	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64872	 64880	 0.023943	 0.0155	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64873	 64887	 0.001114	 0.004536	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64873	 77686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64873	 77686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64874	 64878	 0.002914	 0.007386	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77686	 64874	 0.004743	 0.007564	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64875	 64880	 0.004379	 0.006986	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64875	 77747	 0.012236	 0.013329	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64876	 77688	 0.003086	 0.007936	 0.00012	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64876	 77693	 0.005507	 0.0109	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64877	 64879	 0.006071	 0.015371	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64878	 64890	 0.003236	 0.0082	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77685	 64879	 0.003129	 0.010679	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64880	 64882	 0.013207	 0.00855	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64880	 64883	 0.002993	 0.010236	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64880	 77757	 0.043707	 0.030957	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64881	 65175	 0.002007	 0.005379	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64881	 77687	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64881	 77687	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64881	 77691	 0.005571	 0.021679	 0.00579	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64883	 64886	 0.014507	 0.014657	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77686	 64883	 0.001229	 0.006586	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64884	 64892	 0.000821	 0.003293	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64884	 64910	 0.000386	 0.001579	 0.00037	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64884	 77688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64884	 77688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64885	 64909	 0.000979	 0.003707	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64885	 77689	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64885	 77689	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64885	 77691	 0.002221	 0.007907	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64886	 64897	 0.020686	 0.020321	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64887	 64893	 0.000757	 0.002979	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64887	 77690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64887	 77690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64888	 64898	 0.006457	 0.014979	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64888	 64902	 0.014857	 0.023714	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64888	 77695	 0.016029	 0.017629	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64889	 77691	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77692	 64889	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64890	 77693	 0.001271	 0.007214	 0.00013	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64891	 64892	 0.0007	 0.00245	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64891	 64893	 0.0007	 0.002286	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64892	 77693	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64892	 77693	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64893	 64894	 0.000614	 0.002057	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64893	 77694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64893	 77694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64894	 64895	 0.0007	 0.001964	 0.00051	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64894	 77695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64894	 77695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77691	 64895	 0.001086	 0.003714	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77694	 64896	 0.011186	 0.007243	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77695	 64896	 0.016843	 0.013329	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64897	 77760	 0.010586	 0.0169	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64898	 77760	 0.050236	 0.032521	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64899	 64900	 0.020879	 0.014793	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64899	 64903	 0.027714	 0.025007	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64900	 64901	 0.017221	 0.014179	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64901	 65206	 0.008693	 0.022014	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64901	 77751	 0.00655	 0.0166	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64902	 64904	 0.01225	 0.012371	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64902	 64905	 0.012829	 0.020479	 0.00047	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64903	 64905	 0.004	 0.007429	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64904	 64905	 0.007143	 0.012564	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64905	 64906	 0.017336	 0.014271	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64905	 64907	 0.003493	 0.010714	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64905	 64908	 0.01975	 0.029614	 0.00054	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64905	 77753	 0.006893	 0.030529	 0.00091	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64907	 77753	 0.004643	 0.02305	 0.00055	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64909	 64910	 0.000536	 0.002214	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64909	 77764	 0.000364	 0.004007	 0.0012	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64912	 64913	 0.000821	 0.0022	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64912	 64914	 0.001457	 0.003664	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64912	 64927	 0.001714	 0.005586	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64912	 77696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64912	 77696	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64913	 64914	 0.000636	 0.00175	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64913	 77697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64913	 77697	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64914	 64915	 0.000636	 0.002186	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64915	 77698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64915	 77698	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64916	 64917	 0.01335	 0.009457	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64916	 64918	 0.010529	 0.010636	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77696	 64918	 0.008457	 0.010493	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64919	 64920	 0.006114	 0.015486	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64919	 64963	 0.00725	 0.020793	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64920	 64950	 0.006721	 0.011821	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64921	 64944	 0.008929	 0.01425	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64921	 64962	 0.008614	 0.011736	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64922	 64923	 0.005214	 0.011929	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64922	 64924	 0.004307	 0.00985	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64922	 64949	 0.016229	 0.0115	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64923	 64956	 0.004486	 0.011357	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64924	 64953	 0.004729	 0.010807	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64925	 64953	 0.011857	 0.011971	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64925	 77699	 0.00485	 0.008529	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64926	 77699	 0.006529	 0.018714	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64926	 77700	 0.008514	 0.019479	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64927	 64928	 0.001079	 0.002857	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64927	 77699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64927	 77699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64928	 64960	 0.002386	 0.006136	 0.00152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64929	 64955	 0.001114	 0.003486	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64929	 77700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64929	 77700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64930	 64931	 0.00435	 0.009943	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 64930	 0.005864	 0.013407	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64931	 65163	 0.003536	 0.010843	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64932	 65172	 0.025107	 0.019871	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64932	 65193	 0.0048	 0.013757	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64932	 77748	 0.016207	 0.020121	 0.00044	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64933	 64974	 0.019593	 0.015507	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64934	 64935	 0.028414	 0.0184	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64935	 77702	 0.019621	 0.031314	 0.00072	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64936	 64937	 0.009657	 0.022086	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64936	 77702	 0.020664	 0.047257	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64937	 64947	 0.017729	 0.028443	 0.00053	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64938	 64939	 0.01575	 0.011157	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64939	 64940	 0.016479	 0.011671	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64939	 77702	 0.007521	 0.01705	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64941	 64963	 0.026607	 0.017221	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64942	 64943	 0.0113	 0.008007	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64943	 64944	 0.01015	 0.010836	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64943	 64945	 0.005721	 0.014707	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64944	 64946	 0.005136	 0.010514	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64945	 64981	 0.016829	 0.048264	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64946	 64949	 0.005914	 0.014971	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64947	 64948	 0.013707	 0.012371	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64948	 64949	 0.003029	 0.008686	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64948	 64950	 0.005957	 0.015079	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64950	 64951	 0.012114	 0.009586	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64950	 64988	 0.01125	 0.025729	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64951	 64952	 0.016607	 0.012007	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64952	 64953	 0.002721	 0.006893	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64952	 64988	 0.006686	 0.015293	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64954	 64962	 0.016771	 0.011879	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 64954	 0.005471	 0.011193	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64954	 77748	 0.006557	 0.015	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64955	 65174	 0.001014	 0.003414	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	64956	 64957	 0.005014	 0.008007	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77700	 64957	 0.025271	 0.0179	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64958	 64959	 0.009443	 0.009279	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64958	 64961	 0.004993	 0.008786	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64958	 77701	 0.010236	 0.012	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77697	 64959	 0.007957	 0.013993	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64960	 77701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64960	 77701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64961	 65164	 0.021364	 0.016907	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64963	 64966	 0.01295	 0.029371	 0.00059	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64963	 64967	 0.0101	 0.0162	 0.0003	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64963	 64979	 0.008664	 0.013829	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64964	 64967	 0.006886	 0.014157	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	64964	 64983	 0.006986	 0.015971	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64965	 64983	 0.00285	 0.011636	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64965	 65023	 0.004964	 0.01315	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64965	 77704	 0.005793	 0.019793	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64966	 64968	 0.0074	 0.019029	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64966	 64983	 0.02085	 0.02845	 0.00051	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64968	 65011	 0.005593	 0.018657	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64969	 64980	 0.014443	 0.014586	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64969	 65011	 0.018621	 0.029729	 0.00069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64970	 65011	 0.02215	 0.015693	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64971	 64972	 0.015171	 0.009821	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64971	 64973	 0.036714	 0.026007	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64971	 65011	 0.011093	 0.025171	 0.0005	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64973	 77702	 0.054529	 0.0353	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64974	 64976	 0.010486	 0.006793	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64974	 77702	 0.006593	 0.014957	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64975	 77702	 0.024336	 0.030207	 0.00066	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	64977	 65207	 0.040136	 0.110093	 0.02397	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76814	 64977	 0.005064	 0.03615	 0.01121	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64977	 77702	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64977	 77702	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64978	 64979	 0.006657	 0.016864	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77702	 64978	 0.003521	 0.008921	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77702	 64980	 0.032014	 0.022679	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64981	 64986	 0.009079	 0.030279	 0.00048	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64982	 64983	 0.006264	 0.015857	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64982	 64984	 0.006971	 0.015943	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 64983	 0.039957	 0.070279	 0.00132	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64984	 64988	 0.010564	 0.020914	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64985	 64986	 0.018007	 0.01275	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64986	 64987	 0.001886	 0.008364	 0.00025	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64986	 64989	 0.004257	 0.011279	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64986	 65009	 0.023871	 0.038107	 0.00088	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64987	 77704	 0.0031	 0.015379	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64988	 64989	 0.004179	 0.011986	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64988	 64990	 0.004964	 0.010164	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	64988	 64991	 0.005443	 0.013786	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 64988	 0.012493	 0.04375	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77699	 64988	 0.011336	 0.028721	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64990	 64993	 0.006957	 0.008157	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	64991	 64994	 0.008393	 0.007521	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64991	 64996	 0.005193	 0.013757	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64992	 64995	 0.011264	 0.011071	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	64992	 64997	 0.012007	 0.010764	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77696	 64993	 0.011321	 0.009314	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	64994	 64995	 0.004943	 0.016314	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77696	 64994	 0.006793	 0.019479	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64996	 64997	 0.002907	 0.007371	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	64997	 65006	 0.0063	 0.016707	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	64998	 64999	 0.015971	 0.011314	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 64999	 0.0073	 0.01165	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65000	 65001	 0.00225	 0.006907	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65000	 65002	 0.003264	 0.013943	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77660	 65001	 0.005086	 0.011629	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65002	 65010	 0.0038	 0.011164	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65003	 65008	 0.002329	 0.008864	 0.00248	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65003	 77703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65003	 77703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65004	 65005	 0.00125	 0.003907	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65004	 77704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65004	 77704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65005	 65008	 0.002686	 0.011971	 0.00325	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65005	 77705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65005	 77705	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65006	 65007	 0.004193	 0.012864	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65007	 65010	 0.009493	 0.027221	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77705	 65007	 0.004964	 0.014593	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65008	 65035	 0.001443	 0.005764	 0.00145	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65008	 65048	 0.00135	 0.005493	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76814	 65008	 0.000164	 0.001979	 0.00069	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65008	 77706	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65008	 77706	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77660	 65009	 0.00665	 0.025979	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65010	 65037	 0.004629	 0.011729	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65010	 65038	 0.003021	 0.011814	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65011	 65012	 0.003636	 0.010421	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77706	 65011	 0.027507	 0.080893	 0.00166	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65012	 65013	 0.003836	 0.012807	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65012	 65014	 0.021079	 0.016529	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65013	 65028	 0.004086	 0.017457	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65015	 65016	 0.007671	 0.019429	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65015	 65030	 0.006629	 0.013621	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77703	 65015	 0.010721	 0.028421	 0.00072	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76821	 65016	 0.036079	 0.192271	 0.00337	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65017	 65018	 0.006529	 0.015157	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65017	 65020	 0.005664	 0.01295	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65017	 65030	 0.003343	 0.0143	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65018	 77707	 0.005657	 0.01605	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76820	 65019	 0.001914	 0.020629	 0.04096	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65019	 77707	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65019	 77707	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65020	 77708	 0.013486	 0.039664	 0.00081	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65021	 65211	 0.001536	 0.005843	 0.00164	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65021	 77708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65021	 77708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65022	 65023	 0.011314	 0.017336	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77703	 65023	 0.009864	 0.026136	 0.00066	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65024	 65026	 0.023907	 0.016936	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65024	 65028	 0.017279	 0.015486	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65025	 65028	 0.012921	 0.009157	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65026	 65027	 0.002079	 0.007271	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77704	 65026	 0.005236	 0.017879	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77705	 65026	 0.010957	 0.016421	 0.0003	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77703	 65027	 0.002264	 0.010036	 0.00023	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77705	 65027	 0.014393	 0.015371	 0.00033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65028	 65029	 0.002414	 0.0064	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77703	 65028	 0.004021	 0.012343	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65029	 65031	 0.004021	 0.013421	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65030	 65031	 0.001829	 0.006414	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65031	 65032	 0.006821	 0.008964	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65032	 65034	 0.01025	 0.018029	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77705	 65033	 0.004121	 0.015779	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65033	 77709	 0.003786	 0.021521	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77706	 65034	 0.004386	 0.012907	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65034	 77709	 0.026286	 0.018621	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76814	 65035	 0.00085	 0.0047	 0.00143	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65035	 77709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65035	 77709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65036	 65037	 0.00285	 0.007229	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77709	 65036	 0.006179	 0.014121	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65038	 65039	 0.00965	 0.014057	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76815	 65038	 0.003579	 0.02975	 0.00056	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65039	 65040	 0.012964	 0.009179	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77661	 65039	 0.004379	 0.017021	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65041	 65042	 0.014386	 0.012893	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65041	 65044	 0.004436	 0.009114	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65041	 65053	 0.005786	 0.014664	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65043	 65044	 0.004229	 0.007121	 0.0001	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65043	 65045	 0.004621	 0.005414	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65045	 65046	 0.003343	 0.008464	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65045	 65047	 0.002514	 0.005743	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77661	 65046	 0.024229	 0.031843	 0.00044	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65047	 77710	 0.004114	 0.009407	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76814	 65048	 0.000679	 0.003243	 0.00077	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65048	 77710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65048	 77710	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65049	 65056	 0.006843	 0.008021	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65049	 65057	 0.024893	 0.0197	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77710	 65049	 0.003443	 0.008729	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65050	 77712	 0.006471	 0.012807	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65051	 65053	 0.005364	 0.008043	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65051	 65059	 0.006921	 0.0091	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65052	 65221	 0.001621	 0.00445	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65052	 77711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65052	 77711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77663	 65053	 0.009164	 0.014629	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77711	 65053	 0.005007	 0.013271	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65054	 65221	 0.001979	 0.004586	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65054	 77712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65054	 77712	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65055	 65056	 0.008464	 0.01155	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65055	 65059	 0.006564	 0.009843	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77712	 65055	 0.006721	 0.017029	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65057	 65058	 0.008871	 0.0104	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77712	 65058	 0.00765	 0.01515	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65060	 65069	 0.003771	 0.009986	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65060	 65072	 0.004529	 0.012007	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65061	 77713	 0.0026	 0.006579	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65061	 77715	 0.001664	 0.004421	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65062	 65073	 0.005379	 0.008629	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65062	 65077	 0.004164	 0.007329	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65063	 65074	 0.000964	 0.003307	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65063	 77713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65063	 77713	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65064	 65070	 0.011736	 0.009286	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65065	 65066	 0.009193	 0.008293	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65065	 65070	 0.0167	 0.016407	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77662	 65065	 0.023757	 0.015379	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65066	 65214	 0.0253	 0.020021	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65067	 65068	 0.011664	 0.009229	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65068	 65069	 0.002079	 0.007093	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65068	 65212	 0.006536	 0.01655	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65068	 65215	 0.008607	 0.017036	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65069	 65070	 0.00665	 0.016843	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65070	 77714	 0.00375	 0.0087	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65071	 77714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65071	 77714	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65071	 77716	 0.002157	 0.007393	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65072	 77715	 0.001593	 0.0062	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 65073	 0.003986	 0.008193	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65074	 77715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65074	 77715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65074	 77716	 0.000843	 0.0029	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65075	 77716	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77717	 65075	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65076	 65078	 0.011536	 0.008171	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65076	 65083	 0.002636	 0.013079	 0.00031	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77669	 65076	 0.005964	 0.009564	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77669	 65077	 0.006064	 0.013864	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76830	 65079	 0.000121	 0.000707	 0.00019	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65079	 77718	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65079	 77718	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65079	 77719	 0.001871	 0.0051	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76830	 65080	 0.000636	 0.002643	 0.00082	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65081	 65084	 0.003493	 0.011936	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65081	 65086	 0.008571	 0.015936	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 65081	 0.005471	 0.016479	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65082	 65084	 0.005536	 0.014021	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76832	 65082	 0.00245	 0.010914	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76832	 65082	 0.00245	 0.010914	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77717	 65082	 0.001393	 0.010079	 0.00025	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77672	 65083	 0.002579	 0.005893	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 65083	 0.00795	 0.018179	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65085	 65086	 0.011064	 0.009107	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 65085	 0.040057	 0.0317	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65086	 77722	 0.011864	 0.034893	 0.00071	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76829	 65087	 0.000221	 0.001529	 0.0027	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65087	 77719	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77720	 65087	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65088	 65089	 0.002636	 0.011736	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65088	 77725	 0.005679	 0.011621	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65089	 65092	 0.007886	 0.012086	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77720	 65089	 0.005193	 0.017736	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65090	 65092	 0.003836	 0.010171	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65090	 65093	 0.0174	 0.011264	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77718	 65090	 0.010657	 0.03555	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65091	 77721	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65092	 65093	 0.003936	 0.011571	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65092	 65100	 0.004664	 0.009236	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65092	 77725	 0.004857	 0.014286	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65093	 65094	 0.00245	 0.007507	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65093	 65101	 0.024771	 0.0196	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65094	 77723	 0.002507	 0.009593	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 65095	 0.000986	 0.004386	 0.00119	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65095	 77723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65095	 77723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65096	 65128	 0.0036	 0.009671	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76826	 65096	 0.011264	 0.056621	 0.01474	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 65096	 0.002493	 0.0103	 0.00244	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65096	 77724	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65096	 77724	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65097	 65098	 0.000536	 0.002129	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65098	 65099	 0.000743	 0.002693	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65099	 65107	 0.002093	 0.006821	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65099	 77725	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65099	 77725	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65100	 65104	 0.011936	 0.013129	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65101	 65123	 0.007786	 0.015993	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77723	 65101	 0.00325	 0.015157	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65101	 77726	 0.005843	 0.017179	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65102	 65105	 0.018507	 0.013379	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77725	 65102	 0.00685	 0.015664	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65103	 65104	 0.008264	 0.013193	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77725	 65103	 0.022621	 0.016021	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65104	 77726	 0.006193	 0.007414	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65105	 65106	 0.006729	 0.004357	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65105	 65108	 0.0164	 0.010614	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65107	 65109	 0.0005	 0.001571	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65107	 77726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65107	 77726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65108	 65120	 0.01185	 0.010693	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65109	 65112	 0.000707	 0.001857	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65109	 77727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65109	 77727	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65110	 65111	 0.023214	 0.0182	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65110	 65114	 0.007429	 0.013064	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76838	 65110	 0.049193	 0.03185	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77724	 65110	 0.019829	 0.014043	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65111	 65134	 0.018243	 0.014436	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65112	 65113	 0.000857	 0.002357	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65113	 65126	 0.001743	 0.004671	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65113	 77728	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65113	 77728	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65114	 65115	 0.004329	 0.011129	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65115	 65116	 0.004007	 0.013679	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65115	 65130	 0.005607	 0.0142	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65116	 65136	 0.006086	 0.01745	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65116	 77733	 0.002886	 0.012771	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65117	 65122	 0.003579	 0.017464	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65117	 77729	 0.039171	 0.025357	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65118	 65159	 0.00285	 0.007171	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65118	 65160	 0.003214	 0.011629	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65118	 77729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65118	 77729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77729	 65119	 0.02195	 0.01555	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65119	 77744	 0.043179	 0.031214	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65120	 65121	 0.006457	 0.010314	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65120	 65122	 0.011957	 0.015714	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77726	 65121	 0.00795	 0.022807	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65122	 77731	 0.003407	 0.01935	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77727	 65123	 0.002843	 0.012471	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65123	 77730	 0.003429	 0.016743	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65124	 65125	 0.001279	 0.004536	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65124	 77730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65124	 77730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65126	 65128	 0.002021	 0.013014	 0.00341	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65126	 65160	 0.001671	 0.007893	 0.00253	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65126	 77731	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65126	 77731	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77728	 65127	 0.006593	 0.015079	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77730	 65127	 0.008071	 0.021393	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65128	 65131	 0.003786	 0.017364	 0.00445	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65128	 77732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65128	 77732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65129	 65130	 0.019179	 0.012414	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77732	 65130	 0.061157	 0.0484	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65131	 65143	 0.005686	 0.019514	 0.00467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76826	 65131	 0.009421	 0.04735	 0.01233	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65131	 77733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65131	 77733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65132	 65139	 0.010571	 0.023986	 0.00048	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65132	 65141	 0.007714	 0.01765	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65133	 65134	 0.008243	 0.01125	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65133	 65141	 0.008471	 0.016771	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77724	 65133	 0.014	 0.017386	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65134	 65135	 0.006921	 0.015836	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65135	 65137	 0.00805	 0.015929	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77733	 65135	 0.010129	 0.026843	 0.00068	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65136	 77734	 0.023	 0.060971	 0.00154	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65137	 65138	 0.048043	 0.034036	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65139	 65140	 0.020829	 0.047636	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77722	 65139	 0.012314	 0.03265	 0.00083	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65140	 65213	 0.052564	 0.061614	 0.00107	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65141	 65142	 0.0312	 0.0202	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77724	 65141	 0.007071	 0.016171	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77722	 65142	 0.028907	 0.020479	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76826	 65143	 0.007386	 0.035179	 0.00834	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65143	 77734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65143	 77734	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65144	 65161	 0.013664	 0.0647	 0.01556	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76826	 65144	 0.004429	 0.02225	 0.00579	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65144	 77735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65144	 77735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65145	 65146	 0.014879	 0.010543	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77734	 65145	 0.0162	 0.037614	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77735	 65145	 0.007414	 0.02275	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65147	 65150	 4.3e-05	 0.0005	 0.00844	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65147	 65210	 7.9e-05	 0.001057	 0.01868	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65147	 77736	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65147	 77736	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65148	 65151	 0.001036	 0.012507	 0.20766	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65148	 77737	 0.0007	 0.00885	 0.13495	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65149	 77737	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65149	 77737	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65150	 65151	 5.7e-05	 0.000643	 0.01156	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65151	 77740	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65151	 77740	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76733	 65152	 0.000279	 0.003921	 0.01625	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76811	 65152	 2.9e-05	 0.000529	 0.00209	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65152	 77741	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65152	 77741	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65153	 77742	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65153	 77742	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77741	 65154	 0.036221	 0.028393	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76813	 65155	 0.064564	 0.0968	 0.00176	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65156	 65158	 0.000729	 0.006921	 0.01229	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65157	 65189	 0.029543	 0.034629	 0.0006	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65157	 77744	 0.016971	 0.049907	 0.00102	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65157	 77753	 0.133971	 0.135336	 0.00179	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76825	 65158	 0.00265	 0.028793	 0.06264	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65158	 77743	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65158	 77743	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65159	 65161	 0.001821	 0.006336	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77743	 65159	 0.003421	 0.00905	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65159	 77744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65159	 77744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65159	 77752	 0.012643	 0.037271	 0.00867	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65160	 65161	 0.002021	 0.00525	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77743	 65160	 0.003457	 0.010186	 0.00237	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65160	 77745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65160	 77745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77743	 65161	 0.001179	 0.004721	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65162	 65163	 0.002386	 0.009279	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65162	 77755	 0.007636	 0.020236	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65163	 65164	 0.003514	 0.010329	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65163	 65168	 0.008036	 0.018371	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77683	 65164	 0.005414	 0.015529	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65165	 65166	 0.011721	 0.009279	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65166	 65167	 0.004229	 0.007436	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65167	 65168	 0.002957	 0.007493	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77687	 65168	 0.002121	 0.009386	 0.00028	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65169	 65195	 0.000914	 0.003564	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65169	 65198	 0.000993	 0.004457	 0.00119	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65169	 77746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65169	 77746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65170	 65176	 0.001164	 0.003486	 0.00079	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65170	 65201	 0.001421	 0.004643	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65170	 77747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65170	 77747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65171	 77767	 0.048164	 0.213536	 0.00641	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65171	 77789	 0.05055	 0.193757	 0.00548	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65172	 77748	 0.0042	 0.009607	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65172	 77755	 0.008071	 0.028257	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65173	 65174	 0.00565	 0.026343	 0.00652	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65173	 65223	 0.008543	 0.0372	 0.0106	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65174	 65194	 0.002621	 0.012043	 0.00309	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65174	 77748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65174	 77748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65175	 65176	 0.000821	 0.002129	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65176	 65198	 0.001614	 0.004907	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76822	 65177	 0.016636	 0.086293	 0.02109	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65177	 77749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65177	 77749	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65177	 77752	 0.027464	 0.072621	 0.01701	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77749	 65178	 0.348329	 0.22575	 0.00429	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65178	 77750	 0.012764	 0.012536	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65178	 77753	 0.009714	 0.0298	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65179	 65180	 0.001043	 0.0041	 0.00107	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65179	 65205	 0.002207	 0.009186	 0.00214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65179	 77750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65179	 77750	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65180	 77751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65180	 77751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65180	 77752	 0.001379	 0.005693	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65181	 65218	 0.0005	 0.005643	 0.05136	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65181	 77752	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77753	 65182	 0.033436	 0.02165	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77752	 65183	 0.002386	 0.0065	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65183	 77754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65183	 77754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77754	 65184	 0.037007	 0.029286	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65185	 65186	 0.010771	 0.008521	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77754	 65185	 0.010621	 0.016957	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65187	 65188	 0.022064	 0.015629	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77754	 65187	 0.043386	 0.028093	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77749	 65190	 0.138243	 0.220779	 0.00509	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65190	 77755	 0.099593	 0.078821	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65191	 77755	 0.018386	 0.018571	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65192	 65196	 0.03465	 0.027421	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65193	 77755	 0.006593	 0.018907	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65194	 65195	 0.000671	 0.002829	 0.00064	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65194	 77755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65194	 77755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65196	 77757	 0.020657	 0.025643	 0.00056	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65197	 77756	 0.012093	 0.008564	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65198	 65200	 0.001129	 0.0047	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65198	 77756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65198	 77756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77747	 65199	 0.004543	 0.007257	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77756	 65199	 0.008271	 0.008121	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65200	 65201	 0.001621	 0.004064	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65200	 65202	 0.001321	 0.005286	 0.00133	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65201	 65203	 0.001421	 0.005779	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65201	 77757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65201	 77757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65202	 65205	 0.002236	 0.008121	 0.00249	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65202	 77758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65202	 77758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65203	 65204	 0.000829	 0.003264	 0.00085	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65203	 77759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65203	 77759	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77752	 65204	 0.004793	 0.018829	 0.00493	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65204	 77760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65204	 77760	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65205	 77761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65205	 77761	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77761	 65206	 0.0063	 0.011079	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65207	 65264	 0.079464	 0.214171	 0.04876	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65208	 77762	 0.027879	 0.01805	 0.00034	 29.0	 29.0	 29.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77736	 65209	 0.001393	 0.010071	 0.00542	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77740	 65209	 0.000807	 0.005657	 0.00321	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65210	 66443	 0.001164	 0.01595	 0.23901	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65210	 77762	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65210	 77762	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65211	 65225	 0.007629	 0.026171	 0.00627	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76814	 65211	 0.002064	 0.012814	 0.00361	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76819	 65211	 0.010793	 0.046986	 0.01339	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65211	 77763	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65211	 77763	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65212	 65215	 0.00785	 0.016136	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65212	 65222	 0.004064	 0.020557	 0.00036	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65214	 65217	 0.012207	 0.035007	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77712	 65214	 0.022	 0.019714	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65214	 77766	 0.00625	 0.011279	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65215	 65216	 0.008571	 0.007057	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65216	 65217	 0.015493	 0.017036	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65217	 77768	 0.027457	 0.0628	 0.00154	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65218	 77764	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77722	 65219	 0.023757	 0.105243	 0.0024	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77678	 65220	 0.006293	 0.0185	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65221	 77766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65221	 77766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76841	 65222	 0.01685	 0.0905	 0.00215	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65222	 77768	 0.026979	 0.068336	 0.00135	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65223	 65280	 0.0248	 0.10805	 0.03083	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65223	 77767	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65223	 77767	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77736	 65224	 0.013229	 0.10145	 0.02721	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77738	 65224	 0.01235	 0.093114	 0.02586	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65225	 77768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65225	 77768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65226	 65228	 0.038421	 0.027214	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65226	 65231	 0.011014	 0.027907	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65227	 65231	 0.019386	 0.055607	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65227	 65240	 0.037807	 0.115986	 0.00314	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65227	 78468	 0.072521	 0.32335	 0.00549	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65229	 65230	 0.021143	 0.048357	 0.00118	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65229	 65234	 0.047321	 0.0937	 0.00138	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65230	 77769	 0.030071	 0.068779	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65231	 77769	 0.019521	 0.086479	 0.00197	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65232	 65233	 0.026486	 0.060571	 0.00148	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65232	 77816	 0.03045	 0.093414	 0.00253	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65233	 65234	 0.012736	 0.03225	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65234	 65235	 0.036643	 0.083807	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65234	 77769	 0.051443	 0.171629	 0.00272	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65234	 78521	 0.018314	 0.064121	 0.00178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65234	 78521	 0.018314	 0.064121	 0.00178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65235	 65236	 0.023193	 0.068207	 0.0014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65236	 65237	 0.030714	 0.019886	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65236	 65409	 0.013557	 0.046307	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65238	 65239	 0.009743	 0.045436	 0.01126	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65238	 67519	 0.007336	 0.054221	 0.01566	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65238	 77769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65238	 77769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65238	 77820	 0.003629	 0.032943	 0.01074	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65239	 65273	 0.034043	 0.118771	 0.02758	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65239	 77820	 0.012521	 0.047621	 0.01334	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65240	 65241	 0.03565	 0.189993	 0.00334	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65241	 77784	 0.042429	 0.241271	 0.00436	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65242	 65253	 0.015486	 0.191607	 0.06225	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65242	 65253	 0.015486	 0.191607	 0.06225	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65242	 65397	 0.075743	 0.305786	 0.07791	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65242	 77770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65242	 77770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65242	 77776	 0.049529	 0.316643	 0.08709	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65243	 65246	 0.013507	 0.026743	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65244	 65250	 0.028493	 0.074	 0.01797	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65244	 65251	 0.029279	 0.079743	 0.01758	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65244	 77771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65244	 77771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65245	 65250	 0.001571	 0.0056	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65245	 65251	 0.021379	 0.057407	 0.01301	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65245	 77772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65245	 77772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65246	 65247	 0.003871	 0.007957	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77772	 65246	 0.005036	 0.030971	 0.00056	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65247	 77774	 0.1559	 0.356971	 0.00873	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65248	 65249	 0.025957	 0.0918	 0.02071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65248	 65250	 0.017029	 0.045007	 0.01054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65248	 77773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65248	 77773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65249	 77774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65249	 77774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65249	 77776	 0.043043	 0.172786	 0.04369	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65250	 65251	 0.019336	 0.051107	 0.01196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65251	 77775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65251	 77775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77770	 65252	 0.12305	 0.549271	 0.00935	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77770	 65252	 0.12305	 0.549271	 0.00935	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77773	 65252	 0.037414	 0.16	 0.00361	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77775	 65252	 0.021879	 0.117093	 0.00355	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65253	 78078	 0.033157	 0.425257	 0.13554	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65253	 78078	 0.033157	 0.425257	 0.13554	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76817	 65254	 0.132371	 0.464436	 0.01289	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76817	 65254	 0.132371	 0.464436	 0.01289	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77772	 65254	 0.055121	 0.269107	 0.00465	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77774	 65254	 0.115314	 0.305907	 0.00776	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77771	 65255	 0.304307	 0.486943	 0.01124	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65256	 65276	 0.08155	 0.297293	 0.06436	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65256	 65278	 0.059871	 0.234107	 0.06296	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65256	 67827	 0.038043	 0.171736	 0.04586	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65257	 65279	 0.0115	 0.130929	 2.70786	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65257	 65279	 0.0115	 0.130929	 2.70786	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65257	 77776	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65257	 77776	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65259	 65260	 0.021771	 0.082807	 0.0232	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76816	 65259	 0.004593	 0.052529	 0.01603	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65260	 77777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65260	 77777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77777	 65261	 0.090814	 0.0588	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76816	 65262	 0.031429	 0.254043	 0.07204	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77776	 65262	 0.041321	 0.15745	 0.04422	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65262	 77778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65262	 77778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65263	 66278	 0.002507	 0.043921	 5.81029	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65263	 77779	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65263	 77779	 0.000513	 0.038441	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65265	 65266	 0.004086	 0.016364	 0.00412	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65265	 77780	 0.001957	 0.019614	 0.00653	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65265	 77791	 0.007929	 0.068729	 0.02469	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65266	 77780	 0.001721	 0.018457	 0.0059	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65267	 77780	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65267	 77780	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79863	 65267	 0.002029	 0.037671	 2.82029	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65268	 77781	 0.127314	 0.2043	 0.00377	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65268	 77792	 0.144229	 0.196843	 0.00352	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77659	 65269	 0.010886	 0.048507	 0.01319	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65269	 77781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65269	 77781	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65270	 77782	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77783	 65270	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65270	 77790	 0.000986	 0.011443	 0.09897	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77783	 65271	 0.004307	 0.021286	 0.00621	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65271	 77791	 0.006843	 0.050007	 0.01286	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65272	 77820	 0.016721	 0.042043	 0.01089	 124.0	 124.0	 124.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65273	 77784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65273	 77784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65273	 77787	 0.022429	 0.116964	 0.03073	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65274	 77785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65274	 77785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65274	 77787	 0.037986	 0.165771	 0.0474	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65275	 77786	 9.2e-05	 0.007333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77787	 65275	 0.000256	 0.019221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77787	 65276	 0.015443	 0.052979	 0.01269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65277	 65278	 0.021693	 0.145679	 0.04476	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65277	 65398	 0.034214	 0.240136	 0.09124	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65278	 77788	 0.085964	 0.347943	 0.08895	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76810	 65279	 0.008221	 0.102836	 1.1805	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65279	 77788	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65279	 77788	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76822	 65280	 0.033264	 0.243171	 0.08487	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77788	 65280	 0.030979	 0.196886	 0.05371	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65280	 77789	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65280	 77789	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65281	 65282	 0.081971	 0.073457	 0.0015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65281	 65283	 0.030129	 0.052986	 0.00099	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77789	 65281	 0.0732	 0.244257	 0.00387	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65283	 65284	 0.070743	 0.058229	 0.00118	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65283	 65285	 0.082357	 0.131479	 0.00303	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77767	 65283	 0.056693	 0.272336	 0.00815	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77788	 65286	 0.042986	 0.143671	 0.03652	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65287	 65381	 0.063436	 0.304593	 0.07302	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65288	 67763	 0.002671	 0.032629	 2.58771	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65288	 77790	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65288	 77790	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79862	 65288	 0.002086	 0.040221	 2.81071	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65289	 65312	 0.004564	 0.015579	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65289	 77793	 0.003686	 0.016157	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65290	 65295	 0.000943	 0.003279	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65290	 65315	 0.001571	 0.004143	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65290	 65394	 0.002793	 0.011521	 0.00273	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65290	 77793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65290	 77793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65291	 65293	 0.018971	 0.013436	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65291	 65296	 0.014343	 0.010157	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65291	 65326	 0.006393	 0.013079	 0.00032	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65291	 65334	 0.0284	 0.018386	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65292	 65293	 0.015707	 0.011129	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65292	 77794	 0.007143	 0.008379	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65294	 65306	 0.019907	 0.012886	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65294	 65307	 0.048557	 0.0477	 0.00081	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65294	 65311	 0.020779	 0.01875	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65294	 77794	 0.008386	 0.022221	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65295	 65308	 0.004636	 0.011657	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65295	 65315	 0.002743	 0.007243	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65295	 65394	 0.002136	 0.008821	 0.00209	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65295	 77794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65295	 77794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65296	 65299	 0.012993	 0.008414	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65296	 65334	 0.0103	 0.010121	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65297	 65305	 0.001336	 0.004593	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65297	 65327	 0.00155	 0.005893	 0.00165	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65297	 77795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65297	 77795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65298	 65299	 0.003671	 0.005864	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77795	 65298	 0.00385	 0.009757	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65302	 77801	 0.013114	 0.020929	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65303	 65396	 0.022479	 0.078707	 0.00218	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65303	 77797	 0.036186	 0.067293	 0.00158	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65304	 77796	 0.040021	 0.031671	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65305	 65308	 0.001307	 0.003286	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65305	 77796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65305	 77796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65308	 77797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65308	 77797	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65309	 65310	 0.004571	 0.021314	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77797	 65309	 0.002264	 0.010879	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65310	 65344	 0.003079	 0.011986	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65312	 65339	 0.004236	 0.012457	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65313	 77798	 0.021736	 0.0154	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65314	 77798	 0.013107	 0.014	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65315	 77798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65315	 77798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65316	 77799	 0.014121	 0.009143	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65317	 65320	 0.001436	 0.005236	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65317	 65358	 0.001493	 0.006164	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65317	 77799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65317	 77799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77793	 65318	 0.016171	 0.010471	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65319	 77800	 0.013393	 0.0106	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65320	 65367	 0.00155	 0.006386	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65320	 77800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65320	 77800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65321	 65364	 0.01145	 0.009429	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65321	 77805	 0.005243	 0.011986	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65322	 65323	 0.006321	 0.027864	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65322	 65323	 0.006321	 0.027864	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65322	 77807	 0.0149	 0.052157	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65322	 77807	 0.0149	 0.052157	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65323	 65324	 0.001564	 0.010643	 0.00026	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65323	 77802	 0.008979	 0.0238	 0.00061	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65324	 65325	 0.016657	 0.013186	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65324	 77811	 0.003836	 0.018421	 0.00055	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77794	 65326	 0.005036	 0.010357	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65326	 77811	 0.004357	 0.018193	 0.00052	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65327	 65328	 0.002121	 0.00545	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65327	 65394	 0.002243	 0.009264	 0.00219	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77791	 65327	 0.004771	 0.047836	 0.01593	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65327	 77801	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65327	 77801	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65328	 65329	 0.002136	 0.005486	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65329	 77802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65329	 77802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65330	 65331	 0.026771	 0.018964	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65330	 65332	 0.007007	 0.013029	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65332	 65333	 0.04525	 0.035807	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77802	 65332	 0.010407	 0.027586	 0.0007	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65334	 65335	 0.009964	 0.008207	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77801	 65334	 0.004971	 0.02125	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65336	 65337	 0.015321	 0.035043	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65336	 65342	 0.013464	 0.031264	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65337	 70690	 0.078264	 0.230221	 0.00472	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77793	 65337	 0.052264	 0.1324	 0.00262	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65338	 65346	 0.023214	 0.018193	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65339	 65344	 0.006314	 0.015993	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65340	 65341	 0.017636	 0.012493	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65340	 65344	 0.00675	 0.013871	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65340	 65345	 0.041521	 0.026879	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65342	 65344	 0.010457	 0.029671	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65343	 65344	 0.023093	 0.01495	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77798	 65346	 0.012029	 0.023814	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65347	 77812	 0.040086	 0.031721	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65348	 65354	 0.025693	 0.016636	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65348	 77804	 0.006671	 0.033114	 0.00079	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65349	 65356	 0.023029	 0.028586	 0.00062	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65349	 77812	 0.012793	 0.032393	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65350	 65351	 0.063371	 0.057179	 0.00096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65350	 74245	 0.047207	 0.440021	 0.00854	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65350	 77812	 0.008779	 0.068429	 0.00128	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65352	 65353	 0.022071	 0.014293	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65352	 77804	 0.011807	 0.018843	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65355	 65357	 0.004386	 0.013129	 0.00296	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65355	 65358	 0.001886	 0.006671	 0.0015	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65355	 77803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65355	 77803	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65357	 65388	 0.008757	 0.041721	 0.0099	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65357	 77804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65357	 77804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65358	 65386	 0.004321	 0.018	 0.00561	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65359	 65362	 0.0273	 0.027571	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65359	 65363	 0.02085	 0.018679	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77803	 65360	 0.057964	 0.047714	 0.00096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65361	 65362	 0.007193	 0.01265	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65361	 65382	 0.009807	 0.032714	 0.00052	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77799	 65363	 0.008957	 0.017736	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65365	 77808	 0.02935	 0.020786	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65366	 77805	 0.012314	 0.013543	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65367	 77805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65367	 77805	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65367	 77806	 0.001514	 0.005307	 0.00176	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76833	 65368	 0.000393	 0.007086	 0.07086	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77790	 65368	 0.0007	 0.007721	 0.07501	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65368	 77806	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65369	 65371	 0.015814	 0.010236	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77806	 65370	 0.002007	 0.00505	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65370	 77808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65370	 77808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65371	 65373	 0.005021	 0.012729	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65371	 65385	 0.011	 0.021786	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65372	 65373	 0.004371	 0.011079	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65372	 65389	 0.025907	 0.045571	 0.00086	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65372	 65390	 0.007714	 0.01765	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65373	 65384	 0.039529	 0.031286	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77808	 65373	 0.006471	 0.011386	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65374	 77819	 0.195421	 0.154693	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65375	 65376	 0.043336	 0.099114	 0.00242	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65376	 65380	 0.034721	 0.055421	 0.00128	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65377	 65378	 0.027464	 0.017779	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65378	 65379	 0.029729	 0.01925	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65378	 65380	 0.030436	 0.048579	 0.00112	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65380	 77816	 0.09405	 0.114664	 0.00184	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65381	 65393	 0.034843	 0.247821	 0.06856	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65381	 70531	 0.014729	 0.221579	 0.07509	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65382	 77810	 0.006786	 0.027721	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65383	 65388	 0.002507	 0.016064	 0.00541	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65383	 65392	 0.003021	 0.016757	 0.00509	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65383	 65393	 0.014536	 0.102893	 0.02827	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65383	 71356	 0.0675	 0.280529	 0.06696	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76840	 65383	 0.013557	 0.05635	 0.01316	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65383	 77809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65383	 77809	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65385	 65387	 0.027271	 0.017657	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65386	 65388	 0.00095	 0.006221	 0.00158	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65386	 77810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65386	 77810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65388	 65392	 0.001921	 0.011621	 0.00296	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77810	 65389	 0.014243	 0.025043	 0.00047	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77792	 65390	 0.081693	 0.151936	 0.00356	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77809	 65391	 0.063614	 0.041186	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77806	 65394	 0.00075	 0.011821	 0.00355	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65394	 77811	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65394	 77811	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77806	 65395	 0.01335	 0.055121	 0.01304	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65395	 77812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65395	 77812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65396	 71275	 0.038014	 0.133107	 0.00369	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65397	 77813	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65397	 77813	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65398	 65399	 0.0073	 0.0716	 0.02244	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77779	 65399	 0.031807	 0.4073	 0.12951	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77779	 65399	 0.031807	 0.4073	 0.12951	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65399	 77814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65399	 77814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65400	 65407	 0.013579	 0.021779	 0.0004	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65400	 77815	 0.004214	 0.018771	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65401	 65406	 0.00235	 0.007836	 0.00199	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65401	 77815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65401	 77815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65401	 77817	 0.005393	 0.01355	 0.00351	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65402	 65406	 0.0055	 0.021621	 0.00566	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65402	 77816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65402	 77816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65402	 77817	 0.010893	 0.032129	 0.00747	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65403	 66545	 0.006764	 0.085593	 0.20636	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77782	 65403	 0.000564	 0.005693	 0.01146	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65403	 77817	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65403	 77817	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65404	 65405	 0.00465	 0.00865	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77815	 65404	 0.012179	 0.015121	 0.00033	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65404	 77819	 0.004071	 0.016986	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65405	 77818	 0.006057	 0.01535	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65406	 65411	 0.001286	 0.005136	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65406	 77818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65406	 77818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65406	 77820	 0.005221	 0.021729	 0.00677	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65407	 65408	 0.003414	 0.00865	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65407	 65409	 0.014414	 0.029629	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77818	 65407	 0.003721	 0.014257	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65408	 65409	 0.009414	 0.02385	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77769	 65409	 0.016329	 0.078393	 0.00234	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65409	 77821	 0.014329	 0.080529	 0.00149	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65410	 65411	 0.001514	 0.00425	 0.00109	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77783	 65410	 0.002307	 0.019636	 0.0049	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77817	 65410	 0.001507	 0.006864	 0.00218	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65410	 77819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65410	 77819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77817	 65411	 0.002986	 0.012343	 0.00292	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65411	 77820	 0.004686	 0.020393	 0.00581	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77786	 65412	 0.003993	 0.042579	 0.44828	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77790	 65412	 0.001321	 0.014514	 0.14109	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65412	 77820	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65413	 65414	 0.025257	 0.017893	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65414	 65417	 0.003657	 0.0068	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65414	 65427	 0.02275	 0.036493	 0.00067	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65414	 65498	 0.010064	 0.044607	 0.00134	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65415	 65416	 0.011664	 0.00755	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65416	 65420	 0.004414	 0.00865	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65417	 65419	 0.003664	 0.007529	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65418	 65431	 0.0222	 0.014371	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65419	 77825	 0.009429	 0.028921	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65420	 65433	 0.005843	 0.013364	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65421	 65433	 0.011757	 0.0093	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65422	 65432	 0.012143	 0.0086	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65423	 65424	 0.001436	 0.003871	 0.00109	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65423	 65496	 0.0007	 0.002064	 0.00048	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65423	 77822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65423	 77822	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65424	 65425	 0.000607	 0.00215	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65424	 77823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65424	 77823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65425	 65428	 0.00075	 0.003007	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77822	 65426	 0.011586	 0.0075	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65427	 77843	 0.025879	 0.065557	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65428	 65430	 0.000786	 0.002979	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65428	 77824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65428	 77824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65429	 65430	 0.001757	 0.004786	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65429	 65451	 0.001543	 0.004643	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65429	 65455	 0.004064	 0.009786	 0.00276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65429	 77825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65429	 77825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65430	 65447	 0.00065	 0.002129	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65430	 77826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65430	 77826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65431	 65435	 0.011479	 0.01425	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65432	 65435	 0.004471	 0.007857	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65433	 65434	 0.005271	 0.0079	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77825	 65433	 0.004164	 0.014214	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65434	 65450	 0.004714	 0.009686	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65435	 65450	 0.014836	 0.013293	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65435	 77832	 0.00225	 0.011171	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65436	 65439	 0.01155	 0.008186	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65436	 65493	 0.005664	 0.009043	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65437	 65438	 0.011643	 0.009214	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65437	 77843	 0.009129	 0.020707	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77824	 65440	 0.0058	 0.013257	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65440	 77827	 0.005836	 0.014786	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65441	 65442	 0.002314	 0.006293	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65441	 65443	 0.000986	 0.003086	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65441	 77827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65441	 77827	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65442	 65470	 0.000807	 0.002521	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65442	 65471	 0.001107	 0.003871	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65442	 65487	 0.001657	 0.006514	 0.00171	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65443	 65444	 0.0007	 0.0021	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65444	 65446	 0.000807	 0.003064	 0.00086	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65445	 77828	 0.003721	 0.009871	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65445	 77834	 0.034043	 0.026686	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65446	 77828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65446	 77828	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65446	 77836	 0.002629	 0.0107	 0.00261	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65447	 65449	 0.000843	 0.003493	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65448	 65449	 0.001221	 0.002936	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65448	 65459	 0.001036	 0.003557	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65448	 77829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65448	 77829	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65449	 65460	 0.001514	 0.006164	 0.0015	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65449	 77830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65449	 77830	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65450	 65452	 0.005714	 0.009114	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65451	 77831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65451	 77831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65451	 77836	 0.005143	 0.021243	 0.00503	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77831	 65452	 0.003857	 0.017086	 0.00039	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65453	 65517	 0.038886	 0.151307	 0.00253	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65453	 77833	 0.009036	 0.026571	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65454	 77832	 0.017257	 0.012229	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65455	 65456	 0.001864	 0.00535	 0.00131	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65455	 77832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65455	 77832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65456	 65457	 0.001171	 0.003829	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65456	 77833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65456	 77833	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65457	 65458	 0.003743	 0.014229	 0.00399	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65458	 77853	 0.006043	 0.022964	 0.00643	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65459	 65461	 0.0008	 0.003329	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65459	 77834	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65459	 77834	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65460	 65461	 0.000486	 0.00185	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65460	 65462	 0.000893	 0.003507	 0.00091	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65460	 77836	 0.00265	 0.009636	 0.00295	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65462	 77835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65462	 77835	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65462	 77836	 0.001979	 0.008036	 0.00196	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77835	 65463	 0.017671	 0.013986	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65464	 77836	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65464	 77836	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65464	 77852	 0.000236	 0.002943	 0.02623	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65465	 65466	 0.001257	 0.005229	 0.00122	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65465	 65473	 0.002336	 0.007864	 0.00196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77836	 65465	 0.000736	 0.00455	 0.00129	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65465	 77837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65465	 77837	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65466	 65467	 0.000757	 0.003029	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65466	 65473	 0.001264	 0.00335	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65466	 65520	 0.001171	 0.006107	 0.00147	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65467	 65471	 0.00095	 0.003686	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65468	 77838	 0.0118	 0.018071	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65469	 65470	 0.000864	 0.003579	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77836	 65469	 0.002029	 0.008121	 0.00205	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65469	 77838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65469	 77838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65470	 77839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65470	 77839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77839	 65472	 0.009129	 0.014571	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65473	 77840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65473	 77840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65474	 65479	 0.003086	 0.009464	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77840	 65474	 0.003	 0.013971	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65475	 65477	 0.017579	 0.022871	 0.00032	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65475	 77855	 0.008264	 0.016907	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65476	 65477	 0.014271	 0.016729	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65477	 77863	 0.007164	 0.016386	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65478	 65479	 0.0023	 0.006086	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65478	 65541	 0.0129	 0.037	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65478	 77841	 0.018593	 0.021793	 0.00038	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65480	 65481	 0.001207	 0.0047	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77836	 65480	 0.003479	 0.014371	 0.0034	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65480	 77841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65480	 77841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65481	 65487	 0.001836	 0.006186	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65481	 77842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65481	 77842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65482	 65483	 0.022586	 0.014621	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65482	 65484	 0.032543	 0.02305	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77840	 65482	 0.013029	 0.037371	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65485	 65486	 0.0071	 0.009679	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77842	 65486	 0.006221	 0.017836	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65487	 65510	 0.001421	 0.008821	 0.00249	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65487	 77843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65487	 77843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65487	 77853	 0.009264	 0.037693	 0.00919	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65488	 65510	 0.001486	 0.003729	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65488	 77844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65488	 77844	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65489	 65534	 0.010807	 0.019007	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77844	 65489	 0.006079	 0.016107	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65489	 77860	 0.008586	 0.033407	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65490	 65756	 0.00115	 0.014014	 0.00464	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65490	 65756	 0.00115	 0.014014	 0.00464	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65490	 77845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65490	 77845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65490	 77849	 0.000893	 0.011021	 0.00356	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65490	 77849	 0.000893	 0.011021	 0.00356	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65491	 65493	 0.005643	 0.012793	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77823	 65491	 0.003557	 0.010907	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65492	 65496	 0.002371	 0.009021	 0.00253	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65492	 65500	 0.001243	 0.004514	 0.00138	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65492	 77846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65492	 77846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65493	 65509	 0.00855	 0.013721	 0.00025	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77846	 65494	 0.02405	 0.017036	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65495	 65496	 0.001043	 0.002836	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65495	 77847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65495	 77847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65497	 65504	 0.009529	 0.013007	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65498	 65516	 0.007143	 0.038343	 0.00091	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65499	 65508	 0.007836	 0.01985	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65499	 77850	 0.0047	 0.02245	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65500	 77848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65500	 77848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65500	 77849	 0.001171	 0.005479	 0.00136	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65501	 65502	 0.0132	 0.014521	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77848	 65502	 0.005607	 0.0142	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65503	 65513	 0.014021	 0.009929	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65504	 65513	 0.006314	 0.010079	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77847	 65504	 0.004729	 0.015764	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65505	 65506	 0.030557	 0.021643	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77846	 65506	 0.00875	 0.017314	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65507	 65508	 0.018507	 0.02775	 0.00051	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65507	 65563	 0.029307	 0.023193	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77843	 65509	 0.010457	 0.026486	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65510	 77849	 0.001793	 0.007057	 0.00184	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65696	 65511	 0.001536	 0.026557	 0.46529	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65511	 77849	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65511	 77852	 0.000771	 0.008379	 0.08321	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65512	 65513	 0.015243	 0.010793	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65514	 65515	 0.049021	 0.06085	 0.00133	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65514	 65516	 0.016143	 0.1108	 0.00202	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65514	 65775	 0.018257	 0.110557	 0.00346	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65515	 65517	 0.0259	 0.053	 0.00131	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65515	 65853	 0.03995	 0.114586	 0.00176	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65517	 77851	 0.06355	 0.116414	 0.00201	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65518	 65889	 0.016121	 0.097571	 0.02493	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65518	 77851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65518	 77851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65518	 77853	 0.015971	 0.073314	 0.01879	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65519	 77852	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65519	 77852	 0.00012	 0.009565	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65520	 65523	 0.001079	 0.0045	 0.0014	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65520	 65550	 0.0028	 0.014814	 0.00376	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65520	 77855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65520	 77855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77855	 65521	 0.024414	 0.024657	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65522	 65544	 0.001557	 0.004179	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65522	 77856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65522	 77856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65523	 65526	 0.003071	 0.0074	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65523	 77857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65523	 77857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77857	 65524	 0.014757	 0.00955	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65525	 77859	 0.031793	 0.031236	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65526	 65527	 0.001743	 0.0072	 0.0017	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65526	 77858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65526	 77858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65527	 65565	 0.0068	 0.02125	 0.00616	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77853	 65527	 0.003921	 0.015707	 0.00396	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65527	 77859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65527	 77859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65528	 65529	 0.024421	 0.023993	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65528	 77863	 0.012757	 0.029179	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65529	 65545	 0.033371	 0.023636	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65529	 65546	 0.018536	 0.015257	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77859	 65530	 0.028171	 0.04955	 0.00093	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65531	 65562	 0.012057	 0.018071	 0.00033	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65532	 65562	 0.00275	 0.014779	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65532	 65769	 0.014657	 0.043093	 0.00089	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65532	 77865	 0.006829	 0.019579	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65533	 65554	 0.000271	 0.002907	 0.00099	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65533	 65560	 0.000379	 0.004107	 0.00129	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65535	 65536	 0.000636	 0.005086	 0.00143	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65535	 65560	 0.000536	 0.005593	 0.00189	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65535	 77860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65535	 77860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65536	 65537	 0.000286	 0.0022	 0.00059	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65537	 65539	 0.000443	 0.002207	 0.00057	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65537	 77861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65537	 77861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65538	 65539	 0.00045	 0.002157	 0.00062	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65538	 65551	 0.001357	 0.006464	 0.00187	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65540	 65541	 0.003586	 0.01255	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77861	 65540	 0.003493	 0.01365	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65542	 65548	 0.008179	 0.016807	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65542	 77862	 0.001729	 0.009214	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65543	 65544	 0.000771	 0.002029	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65543	 65550	 0.004364	 0.010979	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65543	 77862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65543	 77862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65546	 65547	 0.009243	 0.016257	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77858	 65547	 0.008329	 0.032029	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65548	 65549	 0.014164	 0.018621	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65549	 77863	 0.008157	 0.020664	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65550	 65551	 0.001886	 0.008907	 0.00285	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65550	 65553	 0.000914	 0.009186	 0.00306	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77853	 65550	 0.008771	 0.03335	 0.00934	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65550	 77863	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65550	 77863	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65551	 77864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65551	 77864	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77863	 65552	 0.020121	 0.01425	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65553	 65564	 0.003521	 0.038936	 0.01168	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65554	 65768	 0.000671	 0.004671	 0.00274	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65554	 77865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65554	 77865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65555	 65556	 0.018736	 0.016786	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65555	 65557	 0.009379	 0.014971	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65556	 77866	 0.011293	 0.015386	 0.00034	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65557	 65769	 0.015479	 0.035393	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77864	 65558	 0.015421	 0.016964	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77863	 65559	 0.018043	 0.019264	 0.00041	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65560	 77866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65560	 77866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65561	 65562	 0.006764	 0.010143	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77845	 65562	 0.007771	 0.037929	 0.00066	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65564	 65585	 0.013879	 0.079664	 0.02651	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65564	 77867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65564	 77867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65565	 65896	 0.00455	 0.018521	 0.00451	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65566	 65878	 0.022614	 0.208193	 0.08409	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76697	 65566	 0.018293	 0.2026	 0.05567	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65567	 65569	 0.010321	 0.0192	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65567	 65571	 0.003007	 0.010264	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65568	 65574	 0.0217	 0.033243	 0.00046	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65568	 65575	 0.041521	 0.029414	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65569	 65570	 0.060429	 0.039121	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65569	 65574	 0.025557	 0.059329	 0.00089	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65569	 65577	 0.011386	 0.025821	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65571	 77868	 0.006814	 0.02915	 0.00066	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65572	 65573	 0.001593	 0.006936	 0.00198	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65572	 65578	 0.005107	 0.020079	 0.00525	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65573	 65688	 0.025821	 0.3219	 0.10573	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65573	 65688	 0.025821	 0.3219	 0.10573	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65573	 65691	 0.064129	 0.161621	 0.04199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65573	 77868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65573	 77868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77868	 65574	 0.00605	 0.020664	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65574	 77871	 0.098786	 0.256129	 0.00484	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65576	 65577	 0.014107	 0.03275	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65576	 65580	 0.208979	 0.38915	 0.00912	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65578	 77869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65578	 77869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65578	 77870	 0.022329	 0.069821	 0.02024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65579	 77870	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77871	 65579	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76802	 65580	 0.072507	 0.348471	 0.01043	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65581	 65582	 0.048279	 0.215186	 0.00366	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77869	 65581	 0.042329	 0.144607	 0.00314	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65582	 77901	 0.0542	 0.231821	 0.00524	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65583	 65585	 0.009014	 0.077336	 0.02203	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65583	 65586	 0.012593	 0.109971	 0.03025	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65583	 77872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65583	 77872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65584	 65589	 0.098307	 0.194686	 0.00286	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65584	 77916	 0.160371	 0.29845	 0.00699	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65585	 77873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65585	 77873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65586	 65587	 0.000907	 0.0074	 0.00201	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65586	 77874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65586	 77874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65587	 65588	 0.001621	 0.011307	 0.00425	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65588	 65719	 0.007579	 0.07135	 0.02163	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65588	 77875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65588	 77875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76789	 65589	 0.353136	 0.5307	 0.00966	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65590	 77877	 0.62755	 0.445893	 0.00704	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65591	 77876	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77877	 65591	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65591	 77911	 0.02425	 0.1675	 0.31286	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76808	 65592	 0.043814	 0.100214	 0.00245	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77877	 65592	 0.123979	 0.413979	 0.00657	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65592	 77925	 0.121464	 0.475186	 0.01056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65593	 65594	 0.032207	 0.02085	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65593	 65595	 0.016171	 0.010471	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65593	 65596	 0.015764	 0.029314	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65593	 77878	 0.010257	 0.02345	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65596	 65598	 0.006693	 0.022336	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65597	 65598	 0.023907	 0.021571	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65597	 65599	 0.017836	 0.014114	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65597	 77880	 0.071336	 0.064364	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65598	 65599	 0.048693	 0.031529	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65598	 65602	 0.085986	 0.252979	 0.00519	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65599	 77880	 0.0335	 0.045664	 0.00101	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65600	 65603	 0.003743	 0.013221	 0.00298	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65600	 77878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65600	 77878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65601	 65604	 0.015036	 0.060207	 0.01517	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65601	 77879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65601	 77879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77879	 65602	 0.268757	 0.367114	 0.00656	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65602	 77927	 0.13995	 0.430093	 0.01168	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65603	 65604	 0.008721	 0.033143	 0.00928	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65603	 65754	 0.013807	 0.177371	 0.05319	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65603	 65754	 0.013807	 0.177371	 0.05319	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65603	 77880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65603	 77880	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65605	 65667	 0.060564	 0.181857	 0.04111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65606	 65612	 0.03	 0.02125	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65607	 65608	 0.001029	 0.00405	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65607	 77881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65607	 77881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65607	 77882	 0.003171	 0.013086	 0.00309	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65608	 65630	 0.001914	 0.007907	 0.00187	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65609	 77882	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77883	 65609	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77882	 65610	 0.003164	 0.009071	 0.00224	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65610	 77884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65610	 77884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65611	 65614	 0.003986	 0.011714	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77881	 65611	 0.010686	 0.017057	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65612	 65613	 0.011871	 0.010636	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65612	 65615	 0.006886	 0.015986	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65613	 65616	 0.021457	 0.019357	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77883	 65614	 0.00695	 0.0176	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77883	 65615	 0.008657	 0.0198	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65616	 65624	 0.0227	 0.017964	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65616	 65626	 0.039143	 0.025343	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65616	 77885	 0.007257	 0.018807	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65617	 77885	 0.0244	 0.015793	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65617	 77886	 0.019614	 0.017693	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65618	 65619	 0.0023	 0.006086	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 65618	 0.002957	 0.008114	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65618	 77885	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65618	 77885	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65619	 65622	 0.002664	 0.010986	 0.0026	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 65619	 0.005121	 0.013529	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65619	 77886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65619	 77886	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65620	 65621	 0.044279	 0.0487	 0.00065	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77883	 65620	 0.028357	 0.028643	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77886	 65621	 0.040707	 0.047721	 0.00083	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65621	 77889	 0.036664	 0.092871	 0.00184	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65622	 65634	 0.008786	 0.029593	 0.00736	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65622	 65641	 0.0052	 0.018921	 0.00579	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77883	 65623	 0.062507	 0.158357	 0.00314	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77883	 65625	 0.084443	 0.135471	 0.0025	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65625	 77892	 0.062486	 0.109893	 0.00206	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65627	 65632	 0.138371	 0.350807	 0.00696	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65627	 77888	 0.03035	 0.056436	 0.00132	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65628	 65629	 0.007793	 0.028364	 0.00869	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65628	 65630	 0.004479	 0.017921	 0.00451	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65629	 65646	 0.011307	 0.045271	 0.01141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65629	 77887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65629	 77887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65630	 77888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65630	 77888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77887	 65631	 0.184464	 0.181271	 0.00306	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65632	 65873	 0.2009	 0.5773	 0.0089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77884	 65633	 0.038686	 0.219979	 0.00398	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65633	 77890	 0.149171	 0.378264	 0.0075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76796	 65634	 0.004193	 0.016793	 0.00423	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65634	 77889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65634	 77889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65635	 65637	 0.021486	 0.081729	 0.0229	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65635	 65698	 0.035314	 0.180886	 0.04568	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76796	 65635	 0.0199	 0.062236	 0.01804	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65635	 77890	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65635	 77890	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76797	 65636	 0.061436	 0.12165	 0.00179	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77889	 65636	 0.048821	 0.111657	 0.00273	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65636	 77891	 0.024393	 0.108093	 0.00324	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65637	 65640	 0.008236	 0.037771	 0.00968	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65637	 77891	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65637	 77891	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65638	 65639	 0.002479	 0.010993	 0.00025	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76806	 65638	 0.002086	 0.014293	 0.00026	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77891	 65639	 0.036429	 0.155771	 0.00352	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65641	 65642	 0.008914	 0.033893	 0.00949	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65641	 77892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65641	 77892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65642	 77893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65642	 77893	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77893	 65643	 0.0826	 0.145286	 0.00273	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65644	 65645	 0.013593	 0.016879	 0.00036	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77891	 65644	 0.0646	 0.113621	 0.00214	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77891	 65645	 0.052543	 0.097707	 0.00229	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77893	 65645	 0.020171	 0.061886	 0.00168	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65646	 65731	 0.018093	 0.06585	 0.02017	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65647	 65649	 0.001536	 0.011057	 0.00036	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65647	 65652	 0.002114	 0.019714	 0.00038	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65648	 65649	 0.006336	 0.028229	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65648	 65649	 0.006336	 0.028229	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65648	 77899	 0.107414	 0.479264	 0.00816	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65648	 77899	 0.107414	 0.479264	 0.00816	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65649	 65651	 0.028471	 0.020171	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65649	 77896	 0.069557	 0.184407	 0.00468	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65650	 65652	 0.0777	 0.050307	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65652	 77894	 0.003914	 0.031679	 0.00081	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65653	 65655	 0.025321	 0.082643	 0.02196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65653	 65684	 0.048143	 0.200771	 0.04707	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65653	 77894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65653	 77894	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65653	 77895	 0.014586	 0.053064	 0.01625	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65657	 65654	 0.001571	 0.019986	 0.35018	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65654	 77895	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65655	 77897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65655	 77897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65657	 65656	 0.0004	 0.0046	 0.09601	 1251.0	 1313.55	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65656	 77898	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77852	 65657	 0.010971	 0.126764	 2.32543	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77852	 65657	 0.010971	 0.126764	 2.32543	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65657	 77900	 0.00025	 0.019998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77901	 65658	 0.037729	 0.044229	 0.00077	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65659	 65661	 0.383421	 0.2824	 0.00413	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65660	 65661	 0.183907	 0.37835	 0.00722	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65661	 65662	 0.0115	 0.029136	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65662	 65665	 0.01925	 0.048764	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76805	 65662	 0.029386	 0.137021	 0.00315	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65663	 65665	 0.09495	 0.067264	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65664	 65875	 0.013357	 0.175629	 0.05021	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65664	 65875	 0.013357	 0.175629	 0.05021	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65666	 65669	 0.0409	 0.123307	 0.03866	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65666	 65702	 0.029664	 0.118914	 0.03001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65666	 77902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65666	 77902	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65668	 65818	 0.078	 0.181764	 0.05561	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65668	 65892	 0.075486	 0.207564	 0.04533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65669	 77903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65669	 77903	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65671	 65672	 0.009136	 0.020729	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65671	 65673	 0.018221	 0.024857	 0.00044	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65671	 77904	 0.00565	 0.032114	 0.00058	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65673	 65674	 0.024364	 0.017257	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65675	 65677	 0.040421	 0.033271	 0.00067	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65676	 65677	 0.031714	 0.020529	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65677	 65681	 0.048964	 0.034686	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65677	 65682	 0.057386	 0.04065	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65677	 77904	 0.008343	 0.021121	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76790	 65678	 0.0088	 0.034221	 0.00914	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65678	 77904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65678	 77904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65679	 65682	 0.075614	 0.059271	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76790	 65680	 0.006207	 0.02485	 0.00839	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65680	 77905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65680	 77905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77905	 65683	 0.04045	 0.1689	 0.00488	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65685	 65687	 0.00055	 0.003914	 0.00121	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65685	 77906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65685	 77906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65686	 65687	 0.000529	 0.004129	 0.00106	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65686	 65688	 0.005879	 0.048779	 0.01284	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65686	 77907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65686	 77907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65688	 65754	 0.021621	 0.279129	 0.08429	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65688	 65754	 0.021621	 0.279129	 0.08429	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76790	 65688	 0.010621	 0.107443	 0.03164	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76804	 65689	 0.067743	 0.163729	 0.04638	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65689	 77908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65689	 77908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77908	 65690	 0.127629	 0.375707	 0.00771	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65690	 77909	 0.188957	 0.351764	 0.00824	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65691	 65692	 0.042979	 0.117143	 0.02584	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65691	 77909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65691	 77909	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65692	 65731	 0.084521	 0.254464	 0.05771	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65692	 65877	 0.063586	 0.251364	 0.06627	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77870	 65692	 0.079064	 0.209771	 0.04933	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65692	 77910	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65692	 77910	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77910	 65693	 0.07305	 0.052807	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65694	 77913	 0.138964	 0.09845	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65695	 65776	 0.121479	 0.307929	 0.00611	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65695	 77913	 0.027707	 0.0834	 0.00163	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65696	 77911	 0.000357	 0.024997	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65696	 77942	 0.004371	 0.0604	 1.09957	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65697	 65848	 0.008443	 0.036743	 0.01047	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77912	 65697	 0.003993	 0.020693	 0.00505	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76798	 65698	 0.0037	 0.023843	 0.00625	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65698	 77914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65698	 77914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76799	 65699	 0.101457	 0.065686	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65700	 65703	 0.0411	 0.026607	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77890	 65701	 0.1562	 0.460057	 0.00945	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77914	 65701	 0.074657	 0.290571	 0.00486	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76798	 65702	 0.003443	 0.016064	 0.00398	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76799	 65703	 0.013614	 0.047664	 0.00132	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76799	 65703	 0.013614	 0.047664	 0.00132	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77914	 65703	 0.004836	 0.039129	 0.00101	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65704	 65705	 0.019264	 0.050929	 0.01192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65704	 77915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65704	 77915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65705	 77916	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65705	 77916	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65706	 77924	 0.645821	 0.458957	 0.00725	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65707	 65716	 0.018486	 0.074043	 0.01866	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65707	 77917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65707	 77917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65708	 65709	 0.021836	 0.088929	 0.02169	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65708	 65714	 0.019021	 0.085707	 0.02283	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65708	 77918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65708	 77918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65710	 65718	 0.077771	 0.15985	 0.00305	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65710	 77922	 0.070443	 0.102657	 0.00232	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65711	 65713	 0.007	 0.028029	 0.00706	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65711	 77919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65711	 77919	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65712	 65719	 0.03055	 0.119007	 0.03184	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65712	 65773	 0.0245	 0.123264	 0.03214	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65712	 77920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65712	 77920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65713	 65714	 0.006871	 0.021486	 0.00622	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65713	 65715	 0.003671	 0.014693	 0.0037	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65714	 77921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65714	 77921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65715	 65716	 0.002343	 0.008914	 0.00249	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65716	 65717	 0.006621	 0.017507	 0.0041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65716	 77922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65716	 77922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65717	 77923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65717	 77923	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77915	 65718	 0.096686	 0.19875	 0.00379	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65719	 77924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65719	 77924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76789	 65720	 0.126836	 0.321521	 0.00637	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77916	 65720	 0.084271	 0.223457	 0.00567	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65721	 65819	 0.06745	 0.163014	 0.04618	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65721	 77925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65721	 77925	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65722	 65723	 0.013329	 0.009443	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65723	 65726	 0.013243	 0.008571	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65724	 65725	 0.030871	 0.019986	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65724	 65726	 0.013443	 0.010636	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65725	 65730	 0.081736	 0.067279	 0.00136	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65725	 65733	 0.061343	 0.055343	 0.00093	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65726	 65728	 0.013729	 0.021907	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65727	 65728	 0.021343	 0.015121	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65728	 65729	 0.028657	 0.045743	 0.00106	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65728	 65735	 0.20025	 0.328521	 0.00581	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65729	 77926	 0.019636	 0.0655	 0.00104	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65730	 77926	 0.042307	 0.109657	 0.00207	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65731	 65732	 0.007486	 0.095929	 0.02867	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65731	 65732	 0.007486	 0.095929	 0.02867	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65731	 65736	 0.059079	 0.184186	 0.03856	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76798	 65731	 0.027171	 0.346179	 0.10926	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65732	 77926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65732	 77926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65733	 65734	 0.1647	 0.24705	 0.00449	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65733	 65737	 0.11195	 0.329464	 0.00676	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77926	 65733	 0.114721	 0.183179	 0.00422	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65735	 65737	 0.121764	 0.25035	 0.00478	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77895	 65736	 0.107014	 0.293436	 0.0652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77910	 65737	 0.029743	 0.159193	 0.00483	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65738	 65739	 0.07305	 0.051743	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65739	 77927	 0.1144	 0.182664	 0.00421	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65740	 65818	 0.025807	 0.339714	 0.09982	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65740	 65818	 0.025807	 0.339714	 0.09982	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65740	 77927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65740	 77927	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65741	 65846	 0.204393	 0.132371	 0.00252	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65742	 65743	 0.091986	 0.146864	 0.00339	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65742	 65882	 0.088464	 0.181843	 0.00347	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65743	 65749	 0.098579	 0.099571	 0.00132	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77913	 65743	 0.14595	 0.331336	 0.00661	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65744	 65885	 0.079636	 0.382814	 0.01146	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65744	 77928	 0.04615	 0.262714	 0.00809	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65745	 65748	 0.039214	 0.134729	 0.03234	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65745	 77928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65745	 77928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65746	 65747	 0.03545	 0.091129	 0.00141	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65746	 65749	 0.070693	 0.058186	 0.00118	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65746	 65846	 0.104786	 0.184329	 0.00346	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65746	 65870	 0.051314	 0.033221	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77913	 65747	 0.045507	 0.177064	 0.00296	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65748	 65803	 0.039107	 0.136514	 0.03171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65750	 65751	 0.035693	 0.025286	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65750	 65752	 0.0044	 0.018807	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77880	 65750	 0.054371	 0.242357	 0.00411	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65752	 77930	 0.061236	 0.309943	 0.0054	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65753	 77929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65753	 77929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65754	 77930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65754	 77930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65755	 65778	 0.003786	 0.018186	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65756	 65757	 0.0004	 0.004193	 0.00115	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65756	 65765	 0.0005	 0.006829	 0.00244	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65757	 65765	 0.000421	 0.004029	 0.00148	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65758	 65778	 0.020014	 0.027307	 0.00049	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65759	 65763	 0.000629	 0.006986	 0.00209	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65759	 65765	 0.000607	 0.008857	 0.00284	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77912	 65759	 0.017964	 0.204229	 0.07925	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77912	 65759	 0.017964	 0.204229	 0.07925	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65759	 77931	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65759	 77931	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65760	 65764	 0.0045	 0.009243	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65760	 77932	 0.004479	 0.011879	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65761	 65762	 0.000407	 0.00425	 0.00239	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65761	 65768	 0.001	 0.00725	 0.0039	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65761	 77932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65761	 77932	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65762	 65771	 0.000607	 0.006357	 0.00357	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65763	 65765	 0.000421	 0.004171	 0.00155	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65763	 65768	 0.001614	 0.005879	 0.0018	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65763	 77933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65763	 77933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77933	 65764	 0.021786	 0.014107	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65764	 77934	 0.032843	 0.032264	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65765	 77934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65765	 77934	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77931	 65766	 0.034086	 0.06975	 0.00171	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77931	 65767	 0.027929	 0.0448	 0.00083	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77932	 65769	 0.003536	 0.021164	 0.00051	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77931	 65770	 0.007164	 0.048671	 0.00121	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65770	 77936	 0.010964	 0.079429	 0.00199	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65771	 65772	 0.001493	 0.0156	 0.01028	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65771	 77935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65771	 77935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65772	 65773	 0.00425	 0.063929	 0.03749	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65772	 77936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65772	 77936	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65773	 65779	 0.017414	 0.067764	 0.01811	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65773	 65781	 0.006957	 0.077714	 0.05183	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65773	 77937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65773	 77937	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65774	 65777	 0.008271	 0.032193	 0.0086	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65774	 65779	 0.01535	 0.053714	 0.01781	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65776	 77939	 0.068114	 0.172579	 0.00342	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65777	 65865	 0.015336	 0.063343	 0.01499	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65777	 77938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65777	 77938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77931	 65778	 0.014093	 0.069943	 0.00166	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65779	 77939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65779	 77939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77938	 65780	 0.0386	 0.172029	 0.00292	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77938	 65780	 0.0386	 0.172029	 0.00292	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65781	 65813	 0.008407	 0.105514	 0.07198	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65781	 77940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65781	 77940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65782	 65794	 0.003657	 0.012793	 0.00424	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65783	 65784	 0.002571	 0.008814	 0.00211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65783	 65785	 0.002164	 0.008429	 0.00225	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65783	 65800	 0.003914	 0.016286	 0.00508	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65784	 65786	 0.002814	 0.011457	 0.00279	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65785	 65786	 0.002121	 0.008057	 0.00226	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65786	 65787	 0.000371	 0.004657	 0.00144	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65786	 65790	 0.001107	 0.010629	 0.00309	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65787	 65789	 0.000643	 0.003807	 0.0031	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65787	 77941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65787	 77941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77941	 65788	 0.004014	 0.012321	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65788	 77947	 0.01815	 0.062	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65789	 77944	 0.0006	 0.008257	 0.00298	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65790	 77944	 0.000543	 0.006836	 0.00464	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65791	 77942	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65791	 77942	 0.000131	 0.010475	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77944	 65791	 0.000166	 0.013307	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65792	 77945	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65792	 77945	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76792	 65793	 0.000193	 0.004493	 0.08607	 1921.0	 2017.05	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77942	 65793	 9.3e-05	 0.002107	 0.03976	 1921.0	 2017.05	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65793	 77946	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65793	 77946	 0.000242	 0.01818	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65794	 65804	 0.006864	 0.027479	 0.00692	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65794	 77947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65794	 77947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65795	 65797	 0.007207	 0.028321	 0.00741	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77944	 65795	 0.009757	 0.046493	 0.01103	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65795	 77948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65795	 77948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77948	 65796	 0.017593	 0.053964	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65796	 77949	 0.04545	 0.049993	 0.00066	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65796	 77951	 0.025336	 0.036914	 0.00084	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65796	 77953	 0.068307	 0.265843	 0.00444	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65797	 65798	 0.012164	 0.033114	 0.0073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65797	 65799	 0.004243	 0.01415	 0.00359	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65797	 65803	 0.014457	 0.056257	 0.01503	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65797	 77949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65797	 77949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65798	 65799	 0.013064	 0.031493	 0.00889	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77944	 65798	 0.016986	 0.088536	 0.02324	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65798	 77950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65798	 77950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65799	 65800	 0.003236	 0.013479	 0.0042	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65799	 77951	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65799	 77951	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65800	 77952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65800	 77952	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65802	 65804	 0.001993	 0.006221	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77944	 65803	 0.0213	 0.124929	 0.0341	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65803	 77953	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65803	 77953	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65805	 65806	 0.01455	 0.029779	 0.00074	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77948	 65805	 0.068343	 0.061664	 0.00103	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77947	 65806	 0.020286	 0.053779	 0.00136	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65807	 65808	 0.008136	 0.024	 0.00559	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77945	 65808	 0.005064	 0.046029	 0.015	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65808	 77954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65808	 77954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77954	 65809	 0.0677	 0.043836	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65810	 65811	 0.112821	 0.395607	 0.01097	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65810	 65811	 0.112821	 0.395607	 0.01097	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65810	 65812	 0.114914	 0.449493	 0.00999	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65810	 65812	 0.114914	 0.449493	 0.00999	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76795	 65811	 0.077793	 0.272564	 0.00755	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76795	 65811	 0.077793	 0.272564	 0.00755	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77918	 65812	 0.1016	 0.397286	 0.00882	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77918	 65812	 0.1016	 0.397286	 0.00882	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76788	 65814	 0.015157	 0.114636	 0.00381	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77564	 65814	 0.1499	 0.584307	 0.00978	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65815	 65816	 0.020179	 0.035486	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65815	 65821	 0.043429	 0.034371	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65815	 77956	 0.097021	 0.2784	 0.00429	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65816	 77955	 0.494307	 0.651614	 0.00894	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65818	 77955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65818	 77955	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65819	 65828	 0.040979	 0.108414	 0.02541	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65819	 77956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65819	 77956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65820	 77957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65820	 77957	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65822	 65825	 0.028114	 0.025193	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65822	 65859	 0.071271	 0.046143	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65823	 77959	 0.038936	 0.025207	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65824	 77959	 0.018371	 0.013014	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65825	 77958	 0.00495	 0.011221	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65826	 65831	 0.034243	 0.022171	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65827	 65828	 0.000857	 0.002586	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65827	 65832	 0.002079	 0.005657	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65827	 77958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65827	 77958	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65828	 65832	 0.001364	 0.004864	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65828	 65838	 0.004007	 0.014157	 0.00319	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65828	 65867	 0.006614	 0.033464	 0.00931	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65828	 77959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65828	 77959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65829	 65830	 0.01935	 0.012529	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65830	 77960	 0.006279	 0.010014	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77958	 65831	 0.006836	 0.010907	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65831	 77960	 0.022171	 0.017543	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65832	 77960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65832	 77960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65833	 65837	 0.048779	 0.0386	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65834	 65837	 0.008079	 0.014214	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77960	 65834	 0.004479	 0.010236	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65835	 65837	 0.022779	 0.01475	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65835	 65857	 0.020143	 0.013043	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65836	 65856	 0.023664	 0.015321	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65836	 77961	 0.008536	 0.014379	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65837	 77961	 0.014793	 0.024921	 0.00036	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65838	 65849	 0.003407	 0.01365	 0.00344	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65838	 77961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65838	 77961	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77961	 65839	 0.023971	 0.016986	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65840	 65843	 0.020693	 0.014657	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65841	 65842	 0.015836	 0.011214	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65841	 65844	 0.007636	 0.015629	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65841	 77962	 0.005436	 0.018136	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65843	 65855	 0.0239	 0.017279	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65843	 65860	 0.010207	 0.050636	 0.00121	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65843	 77962	 0.00405	 0.026129	 0.00083	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65844	 65845	 0.027186	 0.019257	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65844	 65850	 0.21505	 0.152386	 0.00241	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65845	 65871	 0.064164	 0.050779	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65847	 65868	 0.196636	 0.155657	 0.00196	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65848	 65849	 0.003793	 0.036421	 0.01059	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65848	 65867	 0.003057	 0.016957	 0.00516	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65848	 65883	 0.055507	 0.22685	 0.0556	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77912	 65848	 0.012186	 0.055921	 0.01433	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65849	 65865	 0.006029	 0.022929	 0.00641	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65849	 65889	 0.020064	 0.172564	 0.04931	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77912	 65849	 0.008257	 0.073729	 0.01936	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65849	 77962	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65849	 77962	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65851	 65852	 0.061093	 0.187471	 0.00508	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65851	 65862	 0.031764	 0.108514	 0.00236	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65852	 77967	 0.041457	 0.159521	 0.00272	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65853	 77967	 0.09445	 0.2779	 0.0057	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65854	 65888	 0.104521	 0.082721	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65858	 65864	 0.127479	 0.090314	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77960	 65858	 0.035857	 0.063057	 0.00119	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65860	 65863	 0.016986	 0.075236	 0.00171	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65861	 65862	 0.016336	 0.0572	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65861	 65863	 0.011	 0.042964	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65866	 65869	 0.045007	 0.102943	 0.00251	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77913	 65866	 0.043836	 0.111036	 0.0022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65868	 65869	 0.1218	 0.0964	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65869	 65870	 0.048657	 0.085564	 0.00161	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65872	 65873	 0.036014	 0.035379	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65873	 77963	 0.106664	 0.244071	 0.00596	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65875	 65878	 0.026629	 0.350771	 0.10319	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65875	 65878	 0.026629	 0.350771	 0.10319	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65875	 77963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65875	 77963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77872	 65876	 0.229593	 0.455143	 0.00669	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65876	 77964	 0.268307	 0.526729	 0.00791	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65877	 65880	 0.023886	 0.09085	 0.02546	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65878	 65879	 0.006993	 0.074143	 0.02203	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65878	 77964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65878	 77964	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65879	 65880	 0.004186	 0.015236	 0.00466	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65879	 77965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65879	 77965	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77965	 65881	 0.105521	 0.068321	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65882	 65886	 0.13305	 0.181579	 0.00324	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65882	 65887	 0.204779	 0.132621	 0.00252	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77876	 65883	 0.053357	 0.214479	 0.05433	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77912	 65883	 0.095314	 0.260964	 0.05789	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65883	 77966	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65883	 77966	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77966	 65884	 0.054429	 0.292514	 0.00695	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77966	 65885	 0.052757	 0.324557	 0.00586	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65886	 65887	 0.1726	 0.189893	 0.00254	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77966	 65886	 0.039107	 0.133614	 0.00291	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77851	 65888	 0.080164	 0.157129	 0.00236	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65889	 65890	 0.017014	 0.06815	 0.01718	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65889	 77967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65889	 77967	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65890	 65891	 0.022093	 0.091271	 0.02161	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65890	 77968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65890	 77968	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76804	 65891	 0.012536	 0.045607	 0.01396	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65893	 65894	 0.036007	 0.063321	 0.00119	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77854	 65893	 0.084514	 0.134921	 0.00311	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65894	 65897	 0.053779	 0.0381	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65895	 65896	 0.002571	 0.010693	 0.00249	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65895	 65899	 0.00545	 0.022186	 0.00541	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65895	 77969	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65895	 77969	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65897	 65898	 0.071764	 0.078936	 0.00106	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65897	 77970	 0.075007	 0.119743	 0.00276	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65899	 65903	 0.003893	 0.009029	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65899	 65907	 0.006679	 0.026736	 0.00903	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65899	 77970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65899	 77970	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77969	 65900	 0.032271	 0.042	 0.00059	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65900	 77971	 0.014786	 0.026007	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65901	 65902	 0.003493	 0.013279	 0.00371	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77853	 65901	 0.021571	 0.0619	 0.01524	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65901	 77971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65901	 77971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65902	 65903	 0.003921	 0.013721	 0.00455	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65903	 65904	 0.004671	 0.019007	 0.00463	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65903	 77972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65903	 77972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65904	 65905	 0.002036	 0.007736	 0.00216	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65905	 65907	 0.004436	 0.0103	 0.00314	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76800	 65906	 0.067079	 0.043429	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76800	 65908	 0.208629	 0.147829	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65909	 65910	 0.072336	 0.164121	 0.00327	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77873	 65909	 0.074057	 0.39495	 0.00694	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77867	 65910	 0.076793	 0.262443	 0.00571	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77971	 65910	 0.019871	 0.08805	 0.00264	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65911	 66264	 0.020729	 0.098871	 0.02868	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76861	 65911	 0.004457	 0.06495	 0.0208	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65911	 78002	 0.010964	 0.130471	 0.04558	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65912	 78006	 0.677629	 0.481714	 0.00761	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65913	 78078	 0.046336	 0.34185	 0.08917	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65914	 77973	 0.013507	 0.052743	 0.00117	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65915	 65916	 0.014136	 0.035536	 0.00921	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65915	 65943	 0.028129	 0.074371	 0.01741	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65915	 77973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65915	 77973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65916	 65917	 0.013986	 0.04945	 0.01114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65917	 65923	 0.004979	 0.012	 0.00339	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65917	 65947	 0.022071	 0.055493	 0.01438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65917	 78146	 0.005736	 0.059943	 0.01648	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65918	 65919	 0.02585	 0.0254	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65918	 65920	 0.014814	 0.02365	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65919	 65948	 0.162621	 0.128721	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65920	 65921	 0.024371	 0.017264	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65920	 77974	 0.006521	 0.025471	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65922	 66472	 0.057979	 0.107821	 0.00252	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65922	 66476	 0.037671	 0.08615	 0.0021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65922	 77974	 0.010279	 0.058429	 0.00106	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65923	 65943	 0.028964	 0.078893	 0.01739	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65923	 77974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65923	 77974	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65926	 65927	 0.024786	 0.043586	 0.00082	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65927	 77975	 0.026514	 0.09285	 0.00257	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65928	 65932	 0.007957	 0.028121	 0.00634	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65928	 77975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65928	 77975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65928	 78146	 0.036629	 0.144229	 0.03783	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65929	 65930	 0.053307	 0.037757	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65929	 65934	 0.010307	 0.020414	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77975	 65931	 0.028914	 0.082936	 0.00128	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65931	 77977	 0.042807	 0.038621	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65932	 65933	 0.001579	 0.005407	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65932	 65941	 0.003264	 0.011	 0.00274	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65932	 77976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65932	 77976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65933	 77977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65933	 77977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65934	 65935	 0.037193	 0.029436	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65934	 65936	 0.017921	 0.012693	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77976	 65934	 0.00615	 0.018079	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77977	 65934	 0.020671	 0.022743	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65937	 65938	 0.005436	 0.010757	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77976	 65937	 0.010993	 0.016843	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65938	 65942	 0.00745	 0.015307	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65939	 65940	 0.003071	 0.0079	 0.00012	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65939	 77980	 0.03385	 0.085743	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77976	 65940	 0.0093	 0.017293	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65941	 65943	 0.002686	 0.010443	 0.00279	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65941	 77978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65941	 77978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77978	 65942	 0.008371	 0.023757	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65943	 65944	 0.002729	 0.008893	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65943	 77979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65943	 77979	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65944	 65947	 0.004164	 0.010821	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65945	 77980	 0.043179	 0.068929	 0.00159	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65946	 65948	 0.128043	 0.090714	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65946	 77980	 0.036307	 0.043464	 0.00072	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65947	 77980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65947	 77980	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77979	 65949	 0.220743	 0.156421	 0.00247	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65950	 65952	 0.033471	 0.058864	 0.00111	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65951	 65952	 0.062329	 0.04415	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65952	 66013	 0.105186	 0.266579	 0.00529	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76853	 65952	 0.071321	 0.1466	 0.00279	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65953	 65954	 0.051964	 0.13085	 0.03396	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65953	 66421	 0.035071	 0.14065	 0.03551	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76846	 65953	 0.007864	 0.078036	 0.02124	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65954	 66289	 0.05855	 0.207664	 0.04701	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65955	 66292	 0.020129	 0.08315	 0.01969	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75590	 65955	 0.070393	 0.269507	 0.07617	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65956	 77990	 0.053214	 0.0438	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65957	 65975	 0.013379	 0.038379	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65957	 77982	 0.011986	 0.03035	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65957	 78151	 0.027864	 0.022936	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65958	 65990	 0.213243	 0.138107	 0.00263	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65958	 66497	 0.055814	 0.04375	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65958	 78151	 0.0353	 0.056621	 0.00104	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65959	 66469	 0.000314	 0.003879	 0.03564	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65959	 77981	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65959	 77996	 0.001186	 0.013479	 0.12281	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	65960	 65963	 0.026829	 0.021229	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65960	 65973	 0.017486	 0.030757	 0.00058	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77982	 65960	 0.007907	 0.027679	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65961	 65964	 0.001871	 0.006543	 0.00217	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65961	 66486	 0.001686	 0.006957	 0.00165	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65961	 77983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65961	 77983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65962	 65963	 0.005407	 0.013693	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65962	 66492	 0.004879	 0.011157	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65962	 78148	 0.023636	 0.03225	 0.00058	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65963	 65969	 0.0099	 0.022979	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65965	 65967	 0.008936	 0.022636	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65966	 65967	 0.004886	 0.014371	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65966	 77985	 0.006936	 0.021279	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65967	 77984	 0.008986	 0.022764	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65968	 65969	 0.007321	 0.017007	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65968	 65970	 0.006143	 0.018057	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77983	 65968	 0.019136	 0.039321	 0.00075	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	65969	 65973	 0.024329	 0.01575	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65969	 77985	 0.039657	 0.028093	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65970	 77984	 0.00675	 0.015443	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77981	 65971	 0.003064	 0.011929	 0.00319	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65971	 77984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65971	 77984	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77981	 65972	 0.002279	 0.009114	 0.00229	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65972	 77985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65972	 77985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77985	 65973	 0.015564	 0.01395	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77985	 65974	 0.008357	 0.019107	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65974	 77989	 0.010214	 0.023357	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65975	 65982	 0.010293	 0.018564	 0.00027	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65975	 77988	 0.024557	 0.0159	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65976	 65981	 0.002229	 0.005986	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65976	 65984	 0.003314	 0.008886	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65976	 77986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65976	 77986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65977	 65978	 0.005764	 0.014607	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77986	 65977	 0.008671	 0.017164	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77985	 65978	 0.008086	 0.018493	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65979	 65980	 0.001236	 0.0031	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65979	 65981	 0.00125	 0.004071	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65979	 77987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65979	 77987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65980	 65985	 0.001471	 0.00395	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65981	 66498	 0.00405	 0.016221	 0.00548	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65981	 77988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65981	 77988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77987	 65982	 0.022821	 0.014779	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77988	 65983	 0.016093	 0.025686	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65983	 77989	 0.03135	 0.020293	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65984	 65992	 0.015536	 0.039943	 0.00989	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65984	 77989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65984	 77989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65985	 65987	 0.003321	 0.009043	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65985	 66009	 0.001971	 0.005379	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65985	 77990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65985	 77990	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77989	 65986	 0.058879	 0.042564	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77990	 65986	 0.055214	 0.03575	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65986	 77998	 0.087529	 0.173321	 0.00254	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65987	 65988	 0.00395	 0.009929	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65987	 66009	 0.00155	 0.003743	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65988	 65992	 0.005414	 0.014843	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65988	 77991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65988	 77991	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77990	 65989	 0.0833	 0.059007	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77991	 65989	 0.038364	 0.024836	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65990	 65991	 0.055336	 0.049921	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65991	 77992	 0.043357	 0.03885	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65992	 65994	 0.001371	 0.006157	 0.00164	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65992	 65994	 0.001371	 0.006157	 0.00164	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65993	 65999	 0.064679	 0.045821	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65994	 66000	 0.001264	 0.005214	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65994	 66008	 0.003586	 0.013957	 0.00373	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65994	 77992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65994	 77992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65995	 66002	 0.061779	 0.044657	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65995	 66036	 0.197157	 0.1397	 0.00221	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65996	 66040	 0.001929	 0.0058	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	65996	 77993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65996	 77993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65996	 77997	 0.002636	 0.01055	 0.00266	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77993	 65997	 0.016493	 0.014879	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	65997	 77994	 0.004407	 0.010079	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65997	 77995	 0.027593	 0.036264	 0.0005	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	65997	 78010	 0.0159	 0.032536	 0.0008	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65998	 66005	 0.001179	 0.004729	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	65998	 77994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65998	 77994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	65998	 77997	 0.001429	 0.006764	 0.00163	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	65999	 66002	 0.02905	 0.018807	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	65999	 77995	 0.010536	 0.026679	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66000	 66001	 0.000779	 0.00295	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66001	 66004	 0.000929	 0.003643	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66002	 66003	 0.009629	 0.014436	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77992	 66002	 0.04125	 0.054221	 0.00074	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77993	 66003	 0.016479	 0.030636	 0.00071	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66004	 66005	 0.000943	 0.003707	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66004	 77995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66004	 77995	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66006	 77996	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66006	 77996	 9.5e-05	 0.007586	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77997	 66006	 0.000124	 0.009885	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77997	 66007	 0.002843	 0.00995	 0.0033	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66007	 77998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66007	 77998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77997	 66008	 0.001429	 0.008857	 0.00214	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66008	 77999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66008	 77999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66010	 66012	 0.017036	 0.064771	 0.01814	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66010	 66289	 0.057664	 0.22025	 0.06205	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66010	 66423	 0.033743	 0.13955	 0.03309	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66010	 78000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66010	 78000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66010	 78105	 0.053279	 0.223021	 0.07006	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66011	 66291	 0.100721	 0.25525	 0.00506	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78000	 66011	 0.248036	 0.443586	 0.00656	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66011	 78001	 0.103943	 0.141836	 0.00254	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66012	 78001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66012	 78001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76847	 66013	 0.02825	 0.1711	 0.00536	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76847	 66014	 0.139357	 0.125757	 0.00211	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66015	 66448	 0.042671	 0.166421	 0.04461	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76845	 66015	 0.020743	 0.10805	 0.03187	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66015	 78003	 0.076764	 0.264936	 0.06397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66021	 66016	 0.0011	 0.021157	 0.4157	 1959.0	 2056.95	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66016	 78002	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66016	 78002	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66017	 66448	 0.038321	 0.156271	 0.03818	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76695	 66017	 0.041036	 0.270029	 0.06929	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78002	 66017	 0.038721	 0.254614	 0.06526	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66017	 78068	 0.115486	 0.307786	 0.07276	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76792	 66018	 0.005486	 0.085643	 1.00307	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76844	 66018	 0.004814	 0.046064	 0.88479	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66018	 78003	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78004	 66019	 0.159836	 0.366007	 0.00895	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66020	 66024	 0.00465	 0.048936	 0.02751	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78002	 66020	 0.008186	 0.104971	 0.03139	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78002	 66020	 0.008186	 0.104971	 0.03139	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66020	 78005	 0.00495	 0.063221	 0.03204	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66021	 66440	 0.004407	 0.047186	 0.71743	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66021	 66440	 0.004407	 0.047186	 0.71743	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66021	 78005	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77779	 66022	 0.020836	 0.280729	 0.07758	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77779	 66022	 0.020836	 0.280729	 0.07758	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66022	 78132	 0.013436	 0.131086	 0.08684	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66023	 66025	 0.003314	 0.028436	 0.00809	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66023	 66026	 0.001407	 0.011436	 0.00364	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66024	 66026	 0.001414	 0.015221	 0.00814	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66025	 66027	 0.005964	 0.049529	 0.01304	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78005	 66026	 0.005736	 0.073514	 0.02196	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66026	 78132	 0.011471	 0.1791	 0.05582	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66027	 66427	 0.010143	 0.084221	 0.02217	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66028	 66256	 0.015821	 0.065793	 0.01536	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76852	 66028	 0.009864	 0.033836	 0.00811	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76842	 66029	 0.0039	 0.026029	 0.04909	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66029	 78007	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66029	 78007	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66030	 66037	 0.073686	 0.259914	 0.08704	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76882	 66030	 0.035793	 0.143564	 0.03626	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66031	 66427	 0.015129	 0.197679	 0.05744	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66031	 66427	 0.015129	 0.197679	 0.05744	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66032	 66034	 0.014529	 0.139779	 0.04077	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76843	 66032	 0.011243	 0.05545	 0.015	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78007	 66032	 0.038121	 0.124514	 0.03312	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66035	 66265	 0.024321	 0.064307	 0.01506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66035	 66454	 0.03945	 0.091671	 0.02796	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66035	 78008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66035	 78008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66036	 66268	 0.621236	 0.441379	 0.00697	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66037	 66264	 0.019507	 0.074193	 0.02079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66038	 66471	 0.752143	 0.53515	 0.00846	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66039	 66044	 0.000414	 0.003171	 0.00085	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66039	 66046	 0.000679	 0.003986	 0.00109	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66039	 66240	 0.001814	 0.008979	 0.00262	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77997	 66039	 0.001543	 0.0201	 0.00581	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77997	 66039	 0.001543	 0.0201	 0.00581	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66039	 78009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66039	 78009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66040	 78010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66040	 78010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76855	 66041	 0.005379	 0.013621	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66042	 66043	 0.00845	 0.005986	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77993	 66043	 0.016629	 0.051007	 0.00138	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66043	 78011	 0.0055	 0.013929	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66044	 78011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66044	 78011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66044	 78012	 0.000421	 0.002407	 0.0008	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77996	 66045	 0.00015	 0.002364	 0.03841	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66045	 78012	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66045	 78012	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66046	 66047	 0.000393	 0.0023	 0.00063	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66047	 66061	 0.000921	 0.003079	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66047	 66240	 0.000964	 0.004479	 0.00111	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66047	 78013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66047	 78013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66048	 66049	 0.01235	 0.007993	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66048	 66050	 0.001764	 0.009471	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66048	 66051	 0.017943	 0.0142	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66050	 66059	 0.001236	 0.007407	 0.00018	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78013	 66050	 0.002079	 0.006371	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66052	 66080	 0.010457	 0.03075	 0.00063	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66052	 78063	 0.009764	 0.043286	 0.0013	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66053	 66054	 0.009086	 0.009707	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66054	 66056	 0.002793	 0.006379	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66055	 66057	 0.007429	 0.006657	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66056	 66057	 0.002614	 0.010007	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66056	 66058	 0.002607	 0.0066	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66056	 66073	 0.003421	 0.013364	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66056	 66073	 0.003421	 0.013364	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66056	 78063	 0.005193	 0.019886	 0.00056	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66057	 66059	 0.000936	 0.004486	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66058	 66060	 0.002543	 0.006443	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66060	 66068	 0.002364	 0.009243	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66060	 78063	 0.001857	 0.009964	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66061	 66062	 0.000843	 0.003436	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66061	 78014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66061	 78014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66062	 66063	 0.000843	 0.003493	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76854	 66062	 0.000336	 0.002757	 0.00088	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66063	 66064	 0.000364	 0.002771	 0.00087	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66063	 78015	 0.000186	 0.00255	 0.00091	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76854	 66064	 0.000129	 0.00125	 0.00034	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66065	 66244	 0.000143	 0.001586	 0.03051	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66065	 78015	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66065	 78015	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66066	 66191	 0.000593	 0.006521	 0.00196	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78015	 66066	 0.00025	 0.003279	 0.00095	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66067	 66111	 0.000457	 0.006807	 0.00201	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78015	 66067	 0.000379	 0.003671	 0.00241	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66067	 78016	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66067	 78016	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78016	 66068	 0.003657	 0.016107	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66069	 66070	 0.004907	 0.008629	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66069	 66072	 0.002243	 0.012057	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66069	 78063	 0.004171	 0.0224	 0.00053	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78016	 66070	 0.0077	 0.014314	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66071	 66072	 0.002293	 0.007836	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66071	 66085	 0.004214	 0.016393	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66072	 66073	 0.001986	 0.00775	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66072	 66075	 0.002029	 0.008979	 0.00027	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66073	 66074	 0.002329	 0.011786	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66074	 66079	 0.002036	 0.008721	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66075	 66076	 0.001693	 0.007493	 0.00017	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66076	 66241	 0.001657	 0.007093	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66077	 66078	 0.012664	 0.009929	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66078	 66079	 0.002164	 0.007586	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66078	 66080	 0.007679	 0.016143	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66078	 66081	 0.0063	 0.018071	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66078	 78017	 0.012636	 0.036243	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66080	 66087	 0.098529	 0.081107	 0.00164	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66081	 66082	 0.003279	 0.008307	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66082	 66089	 0.005829	 0.014764	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66083	 66241	 0.001636	 0.006379	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66083	 78017	 0.001993	 0.007743	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66084	 66092	 0.0019	 0.005936	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66084	 66115	 0.001971	 0.004957	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66084	 78017	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66084	 78017	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66085	 66110	 0.002214	 0.006793	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66086	 66088	 0.121007	 0.095771	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66086	 66424	 0.073636	 0.195236	 0.00496	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66086	 78074	 0.294686	 0.208886	 0.0033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66086	 78091	 0.160293	 0.256029	 0.0059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66087	 78074	 0.139143	 0.109079	 0.0014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66089	 66093	 0.005486	 0.01245	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66090	 66091	 0.022436	 0.015893	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78017	 66090	 0.008864	 0.015993	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66091	 78024	 0.0198	 0.015521	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66092	 66096	 0.001071	 0.003571	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66092	 66270	 0.021314	 0.05635	 0.01319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66093	 66094	 0.004957	 0.011343	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78017	 66093	 0.021557	 0.037907	 0.00071	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66094	 78018	 0.027321	 0.021414	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66094	 78019	 0.005971	 0.012214	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66095	 66117	 0.010129	 0.011871	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66095	 78018	 0.018079	 0.011707	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66096	 66097	 0.001129	 0.003686	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66096	 78018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66096	 78018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66097	 66099	 0.002321	 0.00625	 0.00175	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66098	 66099	 0.002407	 0.006557	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66098	 78019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66098	 78019	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66099	 66100	 0.002107	 0.005664	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66099	 66103	 0.002107	 0.005079	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66100	 66106	 0.001721	 0.004721	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66100	 66108	 0.001407	 0.003536	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66100	 78020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66100	 78020	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66101	 66126	 0.020021	 0.018064	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78019	 66102	 0.041986	 0.027186	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66102	 78021	 0.007729	 0.015807	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66102	 78025	 0.00515	 0.017586	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66103	 66104	 0.001329	 0.003336	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66103	 66127	 0.002786	 0.006457	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66103	 78021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66103	 78021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66104	 66146	 0.00215	 0.0059	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66105	 66132	 0.025321	 0.020036	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78021	 66105	 0.015207	 0.020729	 0.00046	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66105	 78033	 0.0169	 0.010936	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66106	 66107	 0.002143	 0.005664	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66107	 66137	 0.001929	 0.0051	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66108	 66109	 0.001157	 0.002979	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66109	 66142	 0.001064	 0.002464	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66110	 78022	 0.007536	 0.017229	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66110	 78024	 0.005886	 0.025164	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66111	 66112	 0.000586	 0.005779	 0.00157	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66111	 78022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66111	 78022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66111	 78065	 0.004664	 0.018664	 0.0047	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66112	 66209	 0.001857	 0.00555	 0.00125	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66112	 78023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66112	 78023	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66113	 66114	 0.0129	 0.010207	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66113	 66120	 0.009193	 0.014079	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78023	 66113	 0.006321	 0.016007	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66113	 78024	 0.024407	 0.017286	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66114	 78024	 0.015957	 0.012629	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66115	 66118	 0.002329	 0.00675	 0.00163	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66115	 78024	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66115	 78024	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78017	 66116	 0.015871	 0.010279	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78024	 66117	 0.005679	 0.0146	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66118	 78025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66118	 78025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78025	 66119	 0.017936	 0.0127	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66119	 78026	 0.012343	 0.007986	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76858	 66120	 0.016786	 0.013814	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66121	 78026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66121	 78026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66122	 66126	 0.003486	 0.007964	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78026	 66122	 0.005414	 0.012379	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66123	 66125	 0.001993	 0.007043	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66123	 78027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66123	 78027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66124	 66212	 0.012129	 0.024014	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66124	 78028	 0.014271	 0.012786	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66125	 66127	 0.001271	 0.00415	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66125	 78028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66125	 78028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78028	 66126	 0.017379	 0.01755	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66127	 66131	 0.000771	 0.0031	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66128	 78029	 0.0114	 0.017464	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66128	 78031	 0.01945	 0.013779	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66128	 78034	 0.026693	 0.018907	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66129	 66130	 0.001221	 0.004086	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66129	 66133	 0.002607	 0.006886	 0.00161	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66129	 66172	 0.002243	 0.006807	 0.00149	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66129	 66242	 0.000829	 0.003514	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66129	 78029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66129	 78029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66130	 66131	 0.001536	 0.003943	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66130	 66133	 0.001414	 0.003807	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66131	 66133	 0.001171	 0.0031	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66132	 78031	 0.032936	 0.026064	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66133	 66138	 0.001293	 0.003329	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66134	 66135	 0.042593	 0.027579	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66134	 66136	 0.031764	 0.0225	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66134	 66152	 0.008064	 0.015964	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66135	 78034	 0.009714	 0.017086	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66135	 78042	 0.03375	 0.054136	 0.001	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66136	 66147	 0.006686	 0.010664	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66137	 66142	 0.001807	 0.004643	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66137	 66144	 0.000886	 0.003043	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66137	 66149	 0.005257	 0.014307	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66137	 78030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66137	 78030	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66138	 66146	 0.003071	 0.008421	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66138	 66148	 0.001593	 0.003836	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66138	 78031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66138	 78031	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78031	 66139	 0.023786	 0.0154	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66139	 78033	 0.022779	 0.014743	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66140	 66141	 0.001829	 0.006164	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66140	 66148	 0.001414	 0.004057	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66141	 66154	 0.002379	 0.008414	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66142	 78032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66142	 78032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78030	 66143	 0.015914	 0.011271	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78032	 66143	 0.012821	 0.009086	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66144	 66145	 0.000807	 0.002764	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66145	 66154	 0.001114	 0.003629	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66146	 78033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66146	 78033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78032	 66147	 0.0097	 0.017064	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78033	 66147	 0.018336	 0.012993	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66148	 78034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66148	 78034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66149	 66150	 0.001757	 0.004557	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66149	 78035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66149	 78035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66150	 66156	 0.0034	 0.008979	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66150	 66159	 0.002871	 0.007593	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66150	 78036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66150	 78036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66151	 78039	 0.011179	 0.043664	 0.00097	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66151	 78044	 0.026021	 0.051	 0.00076	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78035	 66152	 0.008636	 0.015193	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66152	 78038	 0.056336	 0.061964	 0.00083	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78035	 66153	 0.024771	 0.016036	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78036	 66153	 0.031043	 0.021993	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66154	 66155	 0.000993	 0.007586	 0.00204	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66155	 66391	 0.007021	 0.024093	 0.00577	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66155	 66394	 0.004093	 0.015921	 0.00425	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66156	 66159	 0.001279	 0.003429	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66156	 66160	 0.003071	 0.008407	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66156	 78037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66156	 78037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66157	 66163	 0.0078	 0.017836	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66157	 66178	 0.021479	 0.034286	 0.00079	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66157	 66245	 0.025771	 0.02325	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66157	 78121	 0.033071	 0.101471	 0.00275	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66158	 66245	 0.010614	 0.028129	 0.00071	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66158	 78039	 0.005107	 0.019579	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66159	 66399	 0.008014	 0.025057	 0.00726	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66159	 78038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66159	 78038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66160	 66399	 0.005293	 0.018164	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66160	 78039	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66160	 78039	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66161	 66400	 0.017486	 0.0443	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78037	 66161	 0.0183	 0.024964	 0.00044	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78035	 66162	 0.02305	 0.018236	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78036	 66163	 0.005793	 0.013243	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66164	 66167	 0.0015	 0.004414	 0.00103	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66164	 66216	 0.001236	 0.004236	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66164	 78040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66164	 78040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78040	 66165	 0.009586	 0.01615	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66165	 78057	 0.014914	 0.020329	 0.00045	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66166	 66168	 0.001107	 0.003871	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66166	 66169	 0.000614	 0.002107	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66167	 66170	 0.001543	 0.004236	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66168	 66170	 0.0021	 0.00555	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66168	 78041	 0.00315	 0.007914	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66169	 66222	 0.001593	 0.005357	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66170	 66186	 0.00155	 0.0047	 0.00103	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66170	 78041	 0.001743	 0.005129	 0.00119	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66171	 78042	 0.026814	 0.017357	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66172	 66242	 0.001186	 0.00285	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66172	 78041	 0.001507	 0.006221	 0.00147	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66173	 78042	 0.020036	 0.012971	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66174	 66284	 0.001036	 0.011343	 0.11023	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66174	 78041	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66175	 66249	 0.002164	 0.008814	 0.00215	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78041	 66175	 0.002671	 0.009429	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66175	 78043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66175	 78043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78042	 66176	 0.007929	 0.017979	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78043	 66176	 0.021957	 0.02415	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66177	 66179	 0.012957	 0.020679	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78042	 66177	 0.008564	 0.021686	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66178	 66179	 0.023643	 0.021336	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66178	 66184	 0.018936	 0.0222	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66180	 66182	 0.002014	 0.005064	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66180	 66185	 0.002893	 0.00765	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66181	 66245	 0.031529	 0.020407	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66182	 66189	 0.003764	 0.009779	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66182	 78044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66182	 78044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66183	 66245	 0.007621	 0.017279	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78044	 66183	 0.023579	 0.023164	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66185	 66249	 0.003557	 0.009686	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66185	 78045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66185	 78045	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66186	 66190	 0.001743	 0.004679	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78041	 66186	 0.002893	 0.007264	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66186	 78046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66186	 78046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78042	 66187	 0.010857	 0.0215	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78043	 66187	 0.009529	 0.01675	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78046	 66187	 0.021836	 0.017286	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66188	 66249	 0.005164	 0.020093	 0.00536	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66188	 66285	 0.009107	 0.0358	 0.00936	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66189	 66248	 0.006379	 0.016564	 0.00402	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66189	 78047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66189	 78047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66190	 66243	 0.00175	 0.004693	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66191	 66193	 0.000536	 0.005093	 0.00168	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66192	 66206	 0.004493	 0.010271	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66192	 78049	 0.004464	 0.015636	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66192	 78053	 0.003143	 0.015907	 0.00028	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66193	 66194	 0.001057	 0.004307	 0.00105	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66193	 66197	 0.001157	 0.006421	 0.00195	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66193	 78048	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66193	 78048	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66193	 78065	 0.001121	 0.007507	 0.0023	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66194	 66195	 0.001064	 0.003779	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66194	 78049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66194	 78049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66195	 66202	 0.000671	 0.0028	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66195	 78050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66195	 78050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78049	 66196	 0.00775	 0.010564	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78050	 66196	 0.013907	 0.009007	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66197	 66201	 0.000536	 0.003064	 0.00087	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66198	 66235	 0.029021	 0.031921	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76857	 66198	 0.027536	 0.048421	 0.00091	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66199	 66200	 0.001607	 0.003736	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66199	 66237	 0.001821	 0.004893	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66200	 66204	 0.001607	 0.003879	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66200	 78051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66200	 78051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66201	 66202	 0.000764	 0.002986	 0.0008	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66201	 66204	 0.001021	 0.004021	 0.00105	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66201	 66205	 0.001043	 0.004093	 0.00107	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78051	 66203	 0.029243	 0.018929	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66203	 78052	 0.017579	 0.01245	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66204	 66227	 0.000786	 0.002986	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66204	 78052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66204	 78052	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66205	 66225	 0.000664	 0.00295	 0.0008	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66205	 66228	 0.000879	 0.0042	 0.00121	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78023	 66206	 0.013986	 0.022429	 0.00041	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66207	 66208	 0.000807	 0.00285	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66207	 66213	 0.000764	 0.003007	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66207	 78053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66207	 78053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66208	 66209	 0.000864	 0.003021	 0.0007	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66209	 78054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66209	 78054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66210	 66212	 0.007829	 0.0155	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66210	 66214	 0.02775	 0.027257	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78053	 66210	 0.005079	 0.01735	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66210	 78056	 0.007071	 0.012443	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66211	 66212	 0.00955	 0.013914	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78027	 66211	 0.008579	 0.016993	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78054	 66211	 0.004179	 0.010593	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66213	 66222	 0.002557	 0.01025	 0.00259	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66213	 66226	 0.000571	 0.002557	 0.00068	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66213	 78055	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66213	 78055	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66214	 78056	 0.012214	 0.013043	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66214	 78057	 0.004086	 0.012543	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66214	 78059	 0.0044	 0.021843	 0.00052	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66215	 66221	 0.001243	 0.003879	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66215	 78056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66215	 78056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66216	 66221	 0.000929	 0.003029	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66216	 78057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66216	 78057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66217	 66284	 0.000671	 0.009157	 0.09334	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66217	 78058	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66217	 78058	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76857	 66218	 0.037421	 0.024221	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66219	 66234	 0.017786	 0.011514	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66220	 66234	 0.029693	 0.023271	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66221	 66222	 0.001857	 0.004993	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66223	 66224	 0.004693	 0.016021	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66223	 66234	 0.008271	 0.021929	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66224	 78064	 0.006771	 0.011907	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66225	 66226	 0.000436	 0.001957	 0.00052	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66227	 66228	 0.000464	 0.001764	 0.00049	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66228	 66233	 0.001229	 0.003193	 0.00096	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76856	 66228	 0.000493	 0.003371	 0.00099	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66229	 78059	 0.017857	 0.011557	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66230	 66231	 0.008579	 0.006793	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66230	 66234	 0.009693	 0.017043	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78057	 66230	 0.013686	 0.013443	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76857	 66232	 0.008257	 0.01635	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66232	 78059	 0.012786	 0.009057	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76856	 66233	 0.001557	 0.005421	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66233	 78059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66233	 78059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76857	 66234	 0.006086	 0.023771	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66235	 66236	 0.00665	 0.013164	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66236	 78060	 0.00435	 0.012471	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66237	 78060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66237	 78060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66238	 66250	 0.002836	 0.015621	 0.00564	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66239	 66279	 0.001079	 0.009543	 0.01691	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66239	 78061	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78062	 66239	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78015	 66240	 0.00115	 0.005707	 0.00184	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66240	 78063	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66240	 78063	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78041	 66242	 0.002664	 0.009421	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66243	 66249	 0.004071	 0.014386	 0.00324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66243	 78064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66243	 78064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76850	 66244	 0.003786	 0.043143	 0.39605	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66244	 78065	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66244	 78065	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66246	 66250	 0.000743	 0.010443	 0.00357	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77997	 66246	 0.000457	 0.0072	 0.00246	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78010	 66247	 0.056607	 0.040093	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66248	 66422	 0.00545	 0.013707	 0.00355	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66249	 78066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66249	 78066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78065	 66250	 0.002907	 0.013736	 0.00439	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76862	 66251	 0.688693	 0.546757	 0.00689	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77184	 66252	 0.746429	 0.531057	 0.00839	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66253	 78067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66253	 78067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76793	 66254	 0.022664	 0.1607	 0.28202	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66254	 78068	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66254	 78068	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76847	 66255	 0.092893	 0.285186	 0.00773	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66255	 78069	 0.057471	 0.191771	 0.00304	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66256	 66258	 0.0211	 0.075107	 0.01671	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66256	 78069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66256	 78069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78069	 66257	 0.137357	 0.4044	 0.0083	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66257	 78071	 0.095814	 0.294186	 0.00798	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66258	 78070	 0.012114	 0.050029	 0.01184	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76844	 66259	 0.001036	 0.016243	 0.16951	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76850	 66259	 0.00265	 0.032957	 0.30686	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66259	 78070	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66259	 78070	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66260	 66261	 0.006693	 0.060807	 0.01982	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78070	 66260	 0.007607	 0.099836	 0.02846	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78070	 66260	 0.007607	 0.099836	 0.02846	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66260	 78071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66260	 78071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66261	 66263	 0.008029	 0.075607	 0.02292	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66262	 78072	 0.070486	 0.091736	 0.00129	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66263	 66264	 0.01135	 0.0541	 0.01284	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76861	 66263	 0.028036	 0.178093	 0.04854	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66263	 78072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66263	 78072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66265	 66266	 0.0196	 0.04725	 0.01334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66266	 78073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66266	 78073	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66267	 66268	 0.054293	 0.086671	 0.002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66267	 78129	 0.199571	 0.164336	 0.00333	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78073	 66268	 0.064371	 0.184664	 0.00284	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78000	 66269	 0.336536	 0.668114	 0.00984	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78073	 66269	 0.26165	 0.518893	 0.00763	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66270	 66271	 0.005	 0.0137	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66270	 78074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66270	 78074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66271	 66272	 0.006157	 0.015993	 0.00388	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66272	 66274	 0.005114	 0.015529	 0.0034	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66273	 78075	 0.103814	 0.073543	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66274	 66277	 0.006021	 0.021793	 0.00468	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66274	 78075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66274	 78075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66275	 78076	 0.066579	 0.052686	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66276	 66277	 0.00455	 0.011821	 0.00287	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66276	 66426	 0.014179	 0.03565	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66277	 78076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66277	 78076	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66278	 78077	 6.9e-05	 0.0055	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78078	 66278	 0.00018	 0.014416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66279	 78082	 0.000757	 0.006157	 0.01131	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66280	 66285	 0.003707	 0.018614	 0.00484	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78078	 66280	 0.011629	 0.105707	 0.03451	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66280	 78079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66280	 78079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66280	 78080	 0.016529	 0.086136	 0.02261	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66280	 78083	 0.0017	 0.0146	 0.00416	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78077	 66281	 0.001621	 0.018014	 0.17174	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66281	 78080	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66281	 78080	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66282	 66284	 0.000307	 0.004829	 0.07931	 1419.0	 1489.95	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78077	 66282	 0.000664	 0.012093	 0.18744	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66282	 78081	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66282	 78081	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66283	 78084	 0.0278	 0.019693	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66284	 78082	 0.000179	 0.012499	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78083	 66284	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78083	 66285	 0.0008	 0.004879	 0.00123	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66285	 78084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66285	 78084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66286	 66287	 0.012986	 0.025707	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78079	 66287	 0.053707	 0.096914	 0.0014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78084	 66287	 0.007221	 0.019086	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78081	 66288	 0.012036	 0.068186	 0.01691	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66290	 66293	 0.018607	 0.043193	 0.01316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66290	 66294	 0.021679	 0.0545	 0.01412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66291	 78085	 0.052936	 0.15185	 0.00234	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66292	 66293	 0.015479	 0.063	 0.01536	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66293	 66294	 0.004536	 0.011993	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66294	 78085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66294	 78085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66295	 66297	 0.000843	 0.002757	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66295	 66298	 0.001657	 0.005407	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66295	 78086	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66295	 78086	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78086	 66296	 0.009764	 0.01815	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66296	 78088	 0.009721	 0.024614	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66297	 66298	 0.000943	 0.002836	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66298	 66300	 0.001836	 0.006964	 0.00195	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66298	 66301	 0.002093	 0.005529	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66299	 66309	 0.001671	 0.0067	 0.00169	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66299	 66420	 0.0012	 0.004814	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66299	 78087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66299	 78087	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66300	 66389	 0.001986	 0.007557	 0.00211	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66300	 78088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66300	 78088	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66301	 66401	 0.001136	 0.004714	 0.0011	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66301	 66420	 0.001621	 0.006607	 0.00161	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66301	 78089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66301	 78089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78088	 66302	 0.003443	 0.009129	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78089	 66302	 0.003229	 0.007386	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78087	 66303	 0.004493	 0.012757	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78088	 66303	 0.008764	 0.028929	 0.00047	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66303	 78117	 0.018	 0.0211	 0.00036	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66304	 66306	 0.000586	 0.003107	 0.00087	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66304	 66308	 0.000936	 0.004793	 0.00131	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66305	 66306	 0.002107	 0.005736	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66305	 66307	 0.001571	 0.003786	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66306	 66311	 0.001214	 0.004621	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66307	 66312	 0.00185	 0.00555	 0.00125	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66308	 66309	 0.001057	 0.003157	 0.00071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66308	 66398	 0.000629	 0.003386	 0.00093	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66309	 78090	 0.001621	 0.006293	 0.00168	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66310	 66352	 0.000686	 0.004829	 0.00822	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76848	 66310	 0.000186	 0.001514	 0.00312	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66310	 78090	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78091	 66310	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66311	 66315	 0.001257	 0.005129	 0.00125	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66312	 66316	 0.001543	 0.0053	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66313	 66316	 0.000843	 0.004486	 0.00126	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66313	 66322	 0.000757	 0.003021	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66313	 78092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66313	 78092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66314	 66315	 0.0006	 0.002336	 0.00062	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66314	 66320	 0.000714	 0.002721	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66315	 66316	 0.0009	 0.003014	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78092	 66317	 0.012014	 0.007779	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78092	 66318	 0.024843	 0.016086	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66319	 78093	 0.026929	 0.017436	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66320	 66321	 0.000529	 0.002157	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66321	 66329	 0.000264	 0.002086	 0.00061	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66321	 78103	 0.001986	 0.006614	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66322	 66323	 0.001586	 0.004314	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66322	 66331	 0.002107	 0.006579	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66323	 66324	 0.000864	 0.00235	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66323	 78093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66323	 78093	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66324	 66325	 0.000829	 0.002536	 0.00055	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66325	 66335	 0.001393	 0.004643	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66325	 78094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66325	 78094	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78094	 66326	 0.004536	 0.008893	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66326	 78095	 0.013679	 0.012343	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66326	 78097	 0.020557	 0.016114	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66327	 66328	 0.000579	 0.002586	 0.0007	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66327	 66332	 0.000636	 0.003221	 0.0009	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66328	 66329	 0.0002	 0.00195	 0.00055	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66328	 66330	 0.00105	 0.003614	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66330	 66331	 0.000986	 0.0035	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66331	 66334	 0.001064	 0.003764	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66331	 78095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66331	 78095	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66331	 78105	 0.002457	 0.014407	 0.00392	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66332	 66350	 0.000907	 0.0045	 0.00145	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66332	 78096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66332	 78096	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78096	 66333	 0.006936	 0.011079	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66333	 78102	 0.005064	 0.012821	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66334	 66336	 0.001407	 0.004593	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66335	 66336	 0.002321	 0.007829	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66335	 78097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66335	 78097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66336	 66340	 0.000407	 0.002414	 0.00064	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66336	 78098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66336	 78098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78097	 66337	 0.038593	 0.027336	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66338	 66339	 0.00755	 0.01495	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78097	 66338	 0.024329	 0.0239	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66339	 66342	 0.01075	 0.007614	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66339	 78099	 0.006014	 0.01375	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66340	 66341	 0.000721	 0.002507	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66340	 66348	 0.000879	 0.003507	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66340	 78099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66340	 78099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66341	 66345	 0.000607	 0.002129	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66343	 66344	 0.029457	 0.019071	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66344	 66360	 0.006543	 0.012957	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66344	 78100	 0.018786	 0.014864	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66345	 66346	 0.000286	 0.001086	 0.00031	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66346	 78100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66346	 78100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66346	 78105	 0.000743	 0.002986	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78100	 66347	 0.006436	 0.004164	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66348	 78105	 0.000793	 0.003021	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66349	 66350	 0.000764	 0.0044	 0.00125	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66349	 78101	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66349	 78101	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66349	 78105	 0.000421	 0.0036	 0.00102	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66350	 78102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66350	 78102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78099	 66351	 0.030279	 0.02145	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78101	 66351	 0.003343	 0.009586	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78102	 66351	 0.002814	 0.007457	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76851	 66352	 0.007607	 0.053421	 0.09116	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66352	 78103	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66352	 78103	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66353	 66354	 0.012271	 0.016121	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78096	 66353	 0.028564	 0.018493	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66354	 78104	 0.014921	 0.023821	 0.00055	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66355	 66357	 0.004243	 0.014493	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66355	 78104	 0.004379	 0.0146	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66356	 66390	 0.010936	 0.045457	 0.01061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66356	 78104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66356	 78104	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66356	 78107	 0.002064	 0.009479	 0.00243	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78101	 66357	 0.006286	 0.012314	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66357	 78106	 0.002993	 0.007936	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66358	 66362	 8.6e-05	 0.001121	 0.01	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66358	 78105	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78106	 66359	 0.003714	 0.008486	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66360	 78108	 0.012114	 0.027707	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66361	 78108	 0.021343	 0.020964	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76850	 66362	 0.001786	 0.018929	 0.19779	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66362	 78107	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66362	 78107	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66363	 66364	 0.004157	 0.010693	 0.00265	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66363	 66365	 0.003307	 0.008893	 0.00249	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66363	 66366	 0.003486	 0.009214	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78105	 66363	 0.002671	 0.010386	 0.00277	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78107	 66363	 0.001264	 0.004964	 0.0013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66363	 78108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66363	 78108	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66364	 66405	 0.004807	 0.01235	 0.00306	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66364	 78109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66364	 78109	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66365	 66366	 0.001079	 0.002943	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66365	 66404	 0.003436	 0.013757	 0.00346	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66365	 78110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66365	 78110	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66366	 78111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66366	 78111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78111	 66367	 0.027543	 0.021593	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66368	 66369	 0.005293	 0.0206	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66368	 66371	 0.019993	 0.015821	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78111	 66368	 0.016607	 0.026514	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66369	 78123	 0.007064	 0.01615	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66369	 78124	 0.049293	 0.064793	 0.00089	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78111	 66370	 0.026836	 0.021236	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66372	 66374	 0.015714	 0.010171	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78109	 66372	 0.074971	 0.053107	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66373	 66405	 0.003464	 0.009443	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66373	 66409	 0.002636	 0.006636	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66373	 78112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66373	 78112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78112	 66374	 0.013229	 0.014121	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78112	 66375	 0.019486	 0.015271	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78112	 66376	 0.02545	 0.022964	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66377	 66378	 0.002586	 0.0065	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66377	 66409	 0.0051	 0.013979	 0.00304	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66377	 78113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66377	 78113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66378	 66413	 0.003564	 0.009771	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66378	 78114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66378	 78114	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66379	 66416	 0.003186	 0.008271	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66379	 66417	 0.0057	 0.016793	 0.00391	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66379	 78115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66379	 78115	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66380	 66381	 0.005043	 0.020514	 0.005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66380	 66384	 0.00205	 0.02075	 0.0061	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66380	 66390	 0.005993	 0.022779	 0.00638	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66381	 66382	 0.002243	 0.005771	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66381	 66397	 0.008029	 0.030521	 0.00854	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66381	 78116	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66381	 78116	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66382	 66422	 0.007336	 0.018429	 0.00478	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66383	 66386	 0.026271	 0.059586	 0.00119	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78116	 66383	 0.029407	 0.045043	 0.00064	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78080	 66384	 0.006407	 0.066986	 0.01841	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66385	 66395	 0.051407	 0.033286	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66385	 78119	 0.020479	 0.031064	 0.00044	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78086	 66386	 0.020321	 0.058286	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78086	 66387	 0.030864	 0.021864	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78086	 66388	 0.040157	 0.040557	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76849	 66389	 0.003543	 0.013779	 0.00368	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66389	 78117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66389	 78117	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66391	 66402	 0.0023	 0.007886	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66391	 78118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66391	 78118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66392	 66394	 0.005214	 0.0142	 0.00313	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66392	 66403	 0.002579	 0.007714	 0.00174	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66393	 66398	 0.001943	 0.006079	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66393	 66403	 0.002271	 0.007407	 0.00196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66394	 66426	 0.015057	 0.045321	 0.01419	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78039	 66395	 0.012464	 0.0255	 0.00063	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66395	 78119	 0.020614	 0.034729	 0.00049	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66395	 78121	 0.023321	 0.046179	 0.00068	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66396	 78120	 0.008379	 0.019457	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66396	 78122	 0.018164	 0.028993	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66397	 66399	 0.001671	 0.005743	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66397	 78119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66397	 78119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66398	 66420	 0.00195	 0.007579	 0.00202	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76849	 66398	 0.003657	 0.014643	 0.00369	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66398	 78120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66398	 78120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66399	 66401	 0.001364	 0.005364	 0.0014	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78090	 66399	 0.007864	 0.029907	 0.00837	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66399	 78121	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66399	 78121	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78039	 66400	 0.018707	 0.042779	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78118	 66400	 0.011107	 0.03185	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66402	 66420	 0.001779	 0.007357	 0.00174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66403	 78122	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66403	 78122	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66404	 66406	 0.003843	 0.009264	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66404	 66421	 0.011079	 0.0469	 0.01056	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66404	 78123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66404	 78123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66405	 66421	 0.011371	 0.053029	 0.01314	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66406	 66421	 0.009979	 0.041207	 0.00975	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66406	 78124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66406	 78124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66407	 66408	 0.004857	 0.0123	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66407	 66411	 0.080357	 0.052021	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78112	 66407	 0.009507	 0.015179	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78124	 66408	 0.015179	 0.038443	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78113	 66410	 0.035007	 0.022664	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78114	 66410	 0.042929	 0.030407	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78114	 66411	 0.08245	 0.058407	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66412	 66417	 0.0027	 0.012393	 0.00317	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76852	 66412	 0.009636	 0.038579	 0.01304	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66413	 66417	 0.003793	 0.010207	 0.00286	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66413	 78125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66413	 78125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78125	 66414	 0.133857	 0.10595	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66415	 66416	 0.009521	 0.025157	 0.00589	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78107	 66415	 0.009943	 0.026286	 0.00615	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66416	 78126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66416	 78126	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66417	 66419	 0.016507	 0.0415	 0.01075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66417	 78127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66417	 78127	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78125	 66418	 0.099236	 0.0703	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78127	 66418	 0.040829	 0.032307	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76852	 66419	 0.013971	 0.047929	 0.01149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66421	 66423	 0.031657	 0.0962	 0.02109	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66421	 78128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66421	 78128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66423	 66425	 0.019814	 0.083914	 0.01889	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66424	 78129	 0.00785	 0.01795	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66425	 66426	 0.006093	 0.023164	 0.00649	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66425	 78129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66425	 78129	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66427	 66437	 0.007929	 0.065993	 0.02	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66427	 66438	 0.003071	 0.023929	 0.00716	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66428	 66430	 0.407636	 0.264293	 0.00503	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66429	 78133	 0.102007	 0.258514	 0.00512	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66430	 66433	 0.055221	 0.097121	 0.00183	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66431	 66432	 0.015021	 0.066186	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66431	 66432	 0.015021	 0.066186	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66431	 66433	 0.014543	 0.056786	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66431	 66433	 0.014543	 0.056786	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66432	 78137	 0.009386	 0.041814	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66432	 78137	 0.009386	 0.041814	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66433	 78133	 0.007236	 0.054743	 0.00182	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76860	 66434	 0.013486	 0.046064	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66435	 78130	 0.032436	 0.074179	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66436	 66437	 0.002729	 0.018729	 0.00546	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66436	 66438	 0.004557	 0.034336	 0.00953	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76859	 66437	 0.002014	 0.020307	 0.01246	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66439	 78130	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66439	 78130	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66439	 78131	 0.000207	 0.001993	 0.00354	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66440	 78131	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66441	 66447	 0.00405	 0.013836	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78130	 66441	 0.012579	 0.049114	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78130	 66441	 0.012579	 0.049114	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66441	 78135	 0.003264	 0.01275	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66441	 78135	 0.003264	 0.01275	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66442	 78134	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78135	 66442	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66442	 78136	 0.000143	 0.002186	 0.00785	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66443	 78136	 0.000104	 0.008333	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77762	 66444	 0.141114	 0.495264	 0.01376	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77762	 66444	 0.141114	 0.495264	 0.01376	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78137	 66444	 0.011886	 0.046429	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78137	 66444	 0.011886	 0.046429	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66445	 66447	 0.003829	 0.015986	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78133	 66445	 0.009057	 0.035364	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78133	 66446	 0.018843	 0.080557	 0.00182	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78068	 66448	 0.112079	 0.298557	 0.07054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66449	 66450	 0.017936	 0.012707	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66449	 66456	 0.026207	 0.018564	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66450	 66451	 0.009579	 0.013957	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66450	 66455	 0.0167	 0.02195	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66451	 66452	 0.005336	 0.009914	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66451	 78138	 0.014586	 0.027114	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66452	 66474	 0.007271	 0.016879	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66453	 66454	 0.001979	 0.006679	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66453	 66460	 0.004436	 0.011393	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66453	 78138	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66453	 78138	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66454	 66460	 0.00125	 0.005193	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66454	 66461	 0.001986	 0.0078	 0.00204	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66454	 78139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66454	 78139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66454	 78144	 0.003257	 0.011507	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66454	 78146	 0.000886	 0.013464	 0.00496	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66455	 66456	 0.010864	 0.013486	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66455	 66458	 0.017829	 0.017514	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78139	 66455	 0.006643	 0.016836	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66457	 66458	 0.020086	 0.014229	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66458	 66459	 0.005621	 0.009379	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66458	 66464	 0.00865	 0.015214	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66458	 66471	 0.121914	 0.194671	 0.00449	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66458	 78140	 0.005793	 0.0198	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66459	 78141	 0.008014	 0.020607	 0.00032	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66460	 66461	 0.001079	 0.0029	 0.00081	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66460	 78140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66460	 78140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66461	 66463	 0.001014	 0.003679	 0.00113	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66461	 78141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66461	 78141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66461	 78144	 0.001493	 0.005986	 0.00202	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66462	 78142	 0.003657	 0.005329	 0.00012	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66462	 78143	 0.021114	 0.014957	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66463	 66467	 0.000607	 0.002557	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66463	 78142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66463	 78142	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66464	 66470	 0.032179	 0.054214	 0.00077	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66465	 66466	 0.000957	 0.003414	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66465	 66498	 0.003971	 0.013829	 0.00321	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66466	 66467	 0.000843	 0.00275	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66467	 78143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66467	 78143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78141	 66468	 0.015064	 0.00975	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66469	 66478	 0.000229	 0.002486	 0.05191	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77996	 66469	 0.001529	 0.016736	 0.1645	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66469	 78144	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66470	 66494	 0.024614	 0.019293	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66470	 78151	 0.026157	 0.025693	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66472	 66473	 0.006136	 0.011407	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66472	 66476	 0.011907	 0.030864	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66473	 66474	 0.008436	 0.017336	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78138	 66475	 0.016821	 0.026843	 0.00062	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66476	 66477	 0.006329	 0.028207	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66477	 78147	 0.006621	 0.029329	 0.00067	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66478	 78146	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78144	 66479	 0.008671	 0.032964	 0.00923	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66480	 66482	 0.008571	 0.03665	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78147	 66480	 0.008093	 0.040157	 0.00096	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77983	 66481	 0.028121	 0.040979	 0.00093	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78145	 66482	 0.029393	 0.058193	 0.00086	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66482	 78148	 0.0207	 0.047343	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66483	 66484	 0.001336	 0.005564	 0.0013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78144	 66483	 0.003021	 0.011479	 0.00321	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66484	 66485	 0.000757	 0.003121	 0.00074	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66484	 66491	 0.000886	 0.002343	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66485	 66486	 0.000836	 0.0034	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66485	 78148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66485	 78148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66487	 66493	 0.02875	 0.018614	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66487	 66495	 0.006143	 0.01405	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78145	 66487	 0.007936	 0.022771	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66488	 66490	 0.0021	 0.006379	 0.00139	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77981	 66488	 0.004879	 0.0129	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78144	 66488	 0.002379	 0.0106	 0.00288	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66488	 78149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66488	 78149	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78145	 66489	 0.01165	 0.029514	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66489	 78150	 0.006321	 0.018129	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66490	 66491	 0.0014	 0.003371	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66490	 78150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66490	 78150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78150	 66492	 0.005871	 0.013436	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78143	 66493	 0.018743	 0.013279	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66494	 66495	 0.006357	 0.018243	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66494	 66496	 0.021586	 0.019343	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66494	 78151	 0.015793	 0.031264	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78149	 66496	 0.007621	 0.021864	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66497	 78151	 0.032671	 0.044571	 0.0008	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77981	 66498	 0.003429	 0.011764	 0.00282	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66498	 78151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66498	 78151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66499	 66509	 0.001393	 0.018171	 1.17171	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66499	 73523	 0.000429	 0.00525	 0.37981	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66499	 78152	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66499	 78152	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66500	 71029	 0.000229	 0.005993	 0.54684	 3531.0	 3707.55	 3884.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66500	 72896	 0.000621	 0.011079	 0.97707	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66500	 78155	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66500	 78155	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78156	 66500	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78156	 66500	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66501	 74746	 7.1e-05	 0.000836	 0.06267	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66501	 78157	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66501	 78157	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66502	 71532	 0.00265	 0.026457	 0.00709	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 71542	 0.005171	 0.031786	 0.00916	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 71573	 0.009471	 0.045121	 0.01071	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 71578	 0.012343	 0.048521	 0.0127	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 71632	 0.008886	 0.036686	 0.00868	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 71751	 0.011621	 0.167536	 0.08699	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 71770	 0.00975	 0.0498	 0.01253	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 71795	 0.006471	 0.031964	 0.00934	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 78160	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66502	 78160	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66502	 79217	 0.022657	 0.135207	 0.03565	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66502	 79403	 0.024336	 0.092571	 0.02594	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66503	 66515	 4.3e-05	 0.000486	 0.0009	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66503	 78161	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66503	 78161	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66503	 78181	 0.000757	 0.006479	 0.01233	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66504	 67842	 0.002171	 0.026836	 1.9925	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 0	 -30.0	 30.0;
	66504	 78162	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66504	 78162	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66505	 70061	 0.000129	 0.001236	 0.00219	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66505	 70362	 0.000243	 0.002243	 0.00884	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66505	 78165	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66505	 78165	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78166	 66505	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78166	 66505	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66506	 72257	 9.3e-05	 0.001643	 0.00674	 1083.0	 1137.15	 1191.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66506	 72507	 0.000314	 0.003557	 0.01326	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66506	 78167	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66506	 78167	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66507	 67139	 0.003936	 0.034664	 0.07239	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66507	 73342	 0.002707	 0.029657	 0.07638	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66507	 78168	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66507	 78168	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78169	 66507	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78169	 66507	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66508	 67351	 0.00015	 0.00175	 0.13119	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66508	 78170	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66508	 78170	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78171	 66508	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	78171	 66508	 0.001384	 0.069186	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	66509	 69602	 0.001307	 0.025893	 2.25243	 2840.0	 2982.0	 3124.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66509	 78172	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66509	 78172	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78173	 66509	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78173	 66509	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66510	 67458	 0.001386	 0.00575	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66510	 67459	 0.002236	 0.009293	 0.00217	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66510	 74290	 0.002114	 0.009214	 0.00263	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66510	 78174	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66510	 78174	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66511	 70567	 0.000129	 0.001843	 0.12754	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66511	 73940	 0.000686	 0.009893	 0.68556	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66511	 78175	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66511	 78175	 0.000433	 0.032442	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66512	 70960	 0.00055	 0.003329	 0.00758	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66512	 71156	 5.7e-05	 0.000614	 0.00113	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66512	 71171	 0.000243	 0.002593	 0.00594	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66512	 78178	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66512	 78178	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66513	 71323	 0.00475	 0.03335	 0.05683	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66513	 74851	 0.003179	 0.03605	 0.13481	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66513	 78179	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66513	 78179	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78180	 66513	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78180	 66513	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66514	 67100	 0.000479	 0.00805	 0.52691	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66514	 67351	 0.0002	 0.002607	 0.16655	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66514	 78181	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66514	 78181	 0.000281	 0.02246	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66515	 73342	 0.005536	 0.036207	 0.07114	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66515	 78184	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66515	 78184	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78185	 66515	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78185	 66515	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66516	 74108	 0.000393	 0.004414	 0.00906	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66516	 74121	 0.000721	 0.004821	 0.00909	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66516	 78186	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66516	 78186	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66517	 67724	 0.009536	 0.055843	 0.01522	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66517	 78293	 0.001807	 0.015657	 0.00562	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78172	 66518	 0.001557	 0.010607	 0.0191	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66518	 78187	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66518	 78187	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66519	 67337	 0.0001	 0.00115	 0.00402	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78181	 66519	 0.000171	 0.001936	 0.00722	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66519	 78188	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66519	 78188	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78189	 66519	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78189	 66519	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66520	 66627	 0.001986	 0.020557	 0.03949	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66520	 72762	 0.0006	 0.004	 0.00754	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66520	 72823	 0.001079	 0.007007	 0.01396	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66520	 78190	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66520	 78190	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78191	 66520	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78191	 66520	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66521	 66603	 0.000107	 0.000414	 0.00011	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66521	 68428	 0.002407	 0.014936	 0.00421	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66521	 69070	 0.002171	 0.007686	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66521	 69073	 0.0006	 0.002129	 0.00048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66521	 69076	 0.000521	 0.0019	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66521	 78192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66521	 78192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66521	 78899	 0.015964	 0.062764	 0.01643	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66522	 71246	 5e-05	 0.000821	 0.06114	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66522	 78193	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66522	 78193	 0.000216	 0.016221	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66523	 68066	 0.0002	 0.001321	 0.0025	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66523	 68189	 6.4e-05	 0.000879	 0.00169	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66523	 68275	 0.001221	 0.008643	 0.01831	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66523	 78195	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66523	 78195	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78196	 66523	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78196	 66523	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66524	 78197	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66524	 78197	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66524	 78276	 0.002836	 0.052971	 0.22965	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66525	 67492	 0.000721	 0.021686	 1.86557	 3775.0	 3963.75	 4152.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66525	 67763	 0.000114	 0.002229	 0.23347	 3450.0	 3622.5	 3795.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66525	 78198	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66525	 78198	 0.000182	 0.014599	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66526	 66566	 0.002979	 0.034979	 0.14142	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66526	 72256	 0.00235	 0.041021	 0.13811	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66526	 78201	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66526	 78201	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78202	 66526	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78202	 66526	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66527	 72099	 0.00055	 0.006207	 0.01136	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66527	 73342	 0.002386	 0.03205	 0.11332	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66527	 78203	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66527	 78203	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66528	 67842	 0.000636	 0.00825	 0.52759	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66528	 69272	 0.001586	 0.018986	 1.46364	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66528	 70320	 0.0006	 0.007936	 0.76157	 2385.0	 2504.25	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66528	 78204	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66528	 78204	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66529	 67915	 0.000971	 0.011771	 0.02478	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78172	 66529	 0.000629	 0.008579	 0.01746	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66529	 78207	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66529	 78207	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66530	 72682	 0.003614	 0.025229	 0.04334	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66530	 78208	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66530	 78208	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78209	 66530	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78209	 66530	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66531	 72313	 0.000143	 0.001743	 0.11935	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66531	 78210	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66531	 78210	 0.000354	 0.026543	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66532	 70067	 0.000207	 0.003214	 0.01123	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66532	 70081	 0.000114	 0.000821	 0.00174	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66532	 70095	 0.000464	 0.004943	 0.00896	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66532	 70105	 0.000786	 0.006971	 0.01225	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66532	 78213	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66532	 78213	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66533	 70374	 3.6e-05	 0.000486	 0.03116	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66533	 78214	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66533	 78214	 0.000521	 0.036496	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66534	 71323	 0.00615	 0.054864	 0.09664	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66534	 78215	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66534	 78215	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66535	 78216	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66535	 78216	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66536	 66815	 7e-06	 2.9e-05	 1e-05	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66536	 67767	 0.001314	 0.013264	 0.0039	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66536	 67769	 0.000757	 0.008279	 0.0023	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66537	 66834	 0.004514	 0.018757	 0.00438	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66537	 67336	 0.003979	 0.024071	 0.00614	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66537	 74291	 0.01795	 0.058579	 0.01556	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66537	 74321	 0.007643	 0.027807	 0.00851	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66538	 66684	 0.000829	 0.005536	 0.01043	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66538	 67337	 0.001093	 0.0153	 0.02934	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66539	 66738	 0.001864	 0.007093	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66539	 67324	 0.004829	 0.035264	 0.00906	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66540	 74225	 5e-05	 0.000757	 0.08733	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66540	 78219	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66540	 78219	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66541	 66646	 0.002379	 0.022143	 0.00686	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66541	 67647	 0.0081	 0.080421	 0.02189	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66541	 78222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66541	 78222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66541	 78546	 0.002264	 0.01895	 0.00491	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66542	 74718	 0.000707	 0.004936	 0.00841	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66542	 74720	 0.000264	 0.001921	 0.00387	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66542	 78223	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66542	 78223	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78224	 66542	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78224	 66542	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66543	 66579	 0.005079	 0.015864	 0.00459	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66543	 67967	 0.009036	 0.0479	 0.01599	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66543	 78225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66543	 78225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66544	 70035	 0.005793	 0.022543	 0.00602	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66544	 70063	 0.000836	 0.002286	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66544	 70066	 0.001457	 0.004764	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66544	 70375	 0.000329	 0.001921	 0.00052	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66545	 72048	 0.002343	 0.037436	 0.07696	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66545	 78226	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66545	 78226	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78227	 66545	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78227	 66545	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66546	 73444	 0.007114	 0.08025	 0.14769	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66546	 78228	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66546	 78228	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78229	 66546	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78229	 66546	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66547	 71834	 0.003879	 0.018086	 0.00448	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66547	 71874	 0.000721	 0.003243	 0.00086	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66547	 78230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66547	 78230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66548	 66621	 0.001507	 0.021664	 0.01117	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66548	 78231	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66548	 78231	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66548	 78361	 0.003257	 0.039686	 0.01312	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66548	 78361	 0.003257	 0.039686	 0.01312	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78198	 66549	 0.006171	 0.065707	 0.12054	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66549	 78232	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66549	 78232	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78233	 66549	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78233	 66549	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66550	 73139	 5e-05	 0.0006	 0.04501	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66550	 78234	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66550	 78234	 0.000333	 0.026613	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66551	 66605	 3.6e-05	 0.000257	 0.00054	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66551	 72143	 0.005507	 0.037586	 0.06776	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66551	 78235	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66551	 78235	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66552	 69939	 0.000243	 0.001621	 0.00314	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66552	 78236	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66552	 78236	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66553	 74240	 0.016314	 0.044707	 0.00972	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66553	 78237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66553	 78237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66553	 78304	 0.010521	 0.025357	 0.00716	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66554	 78238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66554	 78238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66554	 78293	 0.000836	 0.007957	 0.00262	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66555	 74526	 0.004864	 0.023186	 0.00671	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66555	 74537	 0.001157	 0.005879	 0.00213	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66555	 74541	 0.001943	 0.008664	 0.00236	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66555	 78239	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66555	 78239	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66556	 70456	 0.044429	 0.148221	 0.00235	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66556	 70519	 0.050314	 0.222936	 0.00509	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66556	 79165	 0.130721	 0.384821	 0.0079	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66556	 79174	 0.039229	 0.150321	 0.00425	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66557	 66558	 0.000843	 0.004143	 0.00112	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66558	 72412	 0.02315	 0.125421	 0.03049	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66558	 78240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66558	 78240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66559	 70586	 1.4e-05	 0.000207	 0.01471	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66559	 70626	 0.00075	 0.010043	 0.69022	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66559	 78241	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66559	 78241	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66560	 66722	 0.000257	 0.002436	 0.00432	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66560	 74201	 0.000536	 0.006957	 0.01551	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66560	 74207	 0.000429	 0.005657	 0.01209	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66560	 78243	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66560	 78243	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78244	 66560	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78244	 66560	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66561	 66699	 7.9e-05	 0.000336	 8e-05	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66561	 74174	 0.014486	 0.07375	 0.02676	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66561	 79696	 0.001343	 0.005371	 0.00135	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66562	 67806	 0.004729	 0.017964	 0.00503	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66562	 67808	 0.001814	 0.006907	 0.00194	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66562	 78245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66562	 78245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66563	 70380	 0.078157	 0.273843	 0.00759	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66563	 78294	 0.013086	 0.045814	 0.00127	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66563	 78319	 0.049529	 0.296964	 0.00715	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66564	 71323	 0.007536	 0.091364	 0.24151	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66564	 78246	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66564	 78246	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78247	 66564	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78247	 66564	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66564	 78290	 0.000171	 0.001107	 0.0022	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66565	 70353	 0.00045	 0.003371	 0.00641	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66565	 78248	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66565	 78248	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78249	 66565	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78249	 66565	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66566	 66783	 0.000186	 0.002257	 0.00424	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66566	 72256	 0.007007	 0.088679	 0.21395	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66566	 78250	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66566	 78250	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66567	 73460	 0.0008	 0.0035	 0.00121	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66567	 73469	 0.002993	 0.012179	 0.00296	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66567	 78251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66567	 78251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78220	 66568	 0.018757	 0.118964	 0.03235	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66568	 78252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66568	 78252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66568	 78366	 0.000386	 0.001686	 0.00048	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66569	 69736	 0.00075	 0.005186	 0.00915	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66569	 69939	 0.000314	 0.003614	 0.0085	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66569	 70095	 0.000671	 0.008279	 0.0166	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66569	 78253	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66569	 78253	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66570	 66575	 0.044221	 0.1113	 0.02887	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66570	 67291	 0.011636	 0.046586	 0.01174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78228	 66570	 0.000543	 0.002721	 0.00071	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78226	 66571	 0.008093	 0.056186	 0.01604	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66571	 78254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66571	 78254	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66572	 67814	 0.016021	 0.071393	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66572	 67817	 0.027786	 0.051671	 0.00121	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66572	 67818	 0.010807	 0.036914	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66573	 67523	 0.034443	 0.163379	 0.03941	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66573	 71331	 0.016171	 0.06735	 0.02101	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78226	 66574	 0.007879	 0.052821	 0.01619	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66574	 78255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66574	 78255	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66575	 67291	 0.055379	 0.146629	 0.0344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66575	 78256	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66575	 78256	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66576	 66630	 0.003214	 0.0125	 0.00334	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78246	 66576	 0.000707	 0.002786	 0.00073	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66576	 78291	 0.000493	 0.00365	 0.00139	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66577	 67794	 0.078221	 0.278207	 0.06321	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66577	 74584	 0.026179	 0.11905	 0.04141	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78220	 66577	 0.007357	 0.045229	 0.01305	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66577	 78257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66577	 78257	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66578	 71921	 0.0029	 0.011979	 0.00284	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66578	 71956	 0.000757	 0.003014	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66578	 71958	 0.001757	 0.008064	 0.00206	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66578	 78258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66578	 78258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66579	 67952	 0.016607	 0.068579	 0.01624	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66579	 78259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66579	 78259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66580	 66794	 0.000114	 0.000379	 9e-05	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66580	 78260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66580	 78260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66581	 66582	 7e-06	 0.000121	 0.00021	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66581	 67864	 0.001221	 0.008036	 0.01555	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78204	 66581	 0.007879	 0.053571	 0.09777	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66581	 78261	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66581	 78261	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66582	 78262	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66582	 78262	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66583	 66895	 0.000286	 0.001764	 0.00064	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66583	 67037	 0.001086	 0.010886	 0.00291	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66583	 67227	 0.000457	 0.002264	 0.00073	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66583	 78263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66583	 78263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66584	 67529	 0.034007	 0.132821	 0.00294	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66584	 67529	 0.034007	 0.132821	 0.00294	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66584	 67559	 0.089443	 0.263143	 0.0054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66584	 71339	 0.075707	 0.2227	 0.00456	 72.0	 72.0	 72.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66584	 71339	 0.075707	 0.2227	 0.00456	 72.0	 72.0	 72.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66584	 78521	 0.144914	 0.33665	 0.00501	 60.0	 60.0	 60.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66584	 78521	 0.144914	 0.33665	 0.00501	 60.0	 60.0	 60.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66585	 72705	 0.000414	 0.003336	 0.00723	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66585	 72708	 0.000157	 0.001071	 0.00202	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66585	 79463	 0.001364	 0.013464	 0.0287	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66586	 74668	 0.030593	 0.136336	 0.00231	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78229	 66586	 0.070779	 0.276579	 0.00614	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66587	 71870	 0.003071	 0.010021	 0.00266	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66587	 72107	 0.00145	 0.005907	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66587	 72118	 0.000286	 0.000993	 0.00033	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66587	 72121	 0.003264	 0.015407	 0.00493	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66587	 78264	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66587	 78264	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66588	 67272	 0.002136	 0.027357	 0.00817	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78199	 66588	 0.050071	 0.201171	 0.05093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66588	 78265	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66588	 78265	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66588	 78352	 0.001979	 0.028021	 0.00928	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66589	 74501	 0.00115	 0.004671	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66589	 74517	 0.002879	 0.008257	 0.00204	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66589	 78266	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66589	 78266	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66590	 67777	 0.053486	 0.223207	 0.05239	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66590	 78267	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66590	 78267	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66590	 79708	 0.010964	 0.097907	 0.02572	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66591	 66605	 1.4e-05	 0.000143	 0.00028	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66591	 67691	 0.011729	 0.078543	 0.14886	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66591	 78268	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66591	 78268	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66592	 74586	 0.030786	 0.112136	 0.03439	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66592	 78269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66592	 78269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66592	 78318	 0.008307	 0.034543	 0.00806	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66593	 66781	 0.002	 0.005893	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66593	 78270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66593	 78270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66593	 78293	 7e-06	 2.9e-05	 1e-05	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66594	 67534	 0.002179	 0.0218	 0.00584	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66594	 72025	 0.001379	 0.0146	 0.00434	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66594	 78271	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66594	 78271	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66595	 66827	 0.001457	 0.015421	 0.00458	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66595	 78277	 0.0076	 0.057793	 0.01817	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66596	 67263	 0.004357	 0.05935	 0.02123	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66596	 78361	 0.000293	 0.0035	 0.00122	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66597	 70376	 0.001321	 0.0103	 0.00308	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66597	 70377	 0.000657	 0.003414	 0.00089	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66597	 79023	 0.001107	 0.006486	 0.00176	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66598	 70425	 0.000993	 0.009057	 0.01744	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66598	 74379	 0.001571	 0.032821	 0.11295	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66598	 78272	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66598	 78272	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66598	 78513	 1.4e-05	 0.000336	 0.00126	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66599	 67941	 0.015614	 0.05095	 0.01353	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66599	 67949	 0.00675	 0.027029	 0.00681	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66600	 67719	 0.010821	 0.033193	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66600	 67720	 0.010779	 0.0172	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66600	 67721	 0.023279	 0.015071	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66600	 67722	 0.018836	 0.043721	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66600	 67735	 0.023107	 0.045757	 0.00067	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66600	 67738	 0.0315	 0.12255	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66600	 67759	 0.038057	 0.066936	 0.00126	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66601	 66773	 0.001286	 0.002393	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66601	 71681	 0.006643	 0.045093	 0.00111	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66601	 78344	 0.00805	 0.060871	 0.00202	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66601	 79342	 0.019607	 0.044843	 0.00109	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66602	 74474	 0.002886	 0.009629	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66602	 74490	 0.012321	 0.025221	 0.00062	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66602	 74492	 0.005186	 0.015257	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66602	 74493	 0.001121	 0.009064	 0.00024	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66602	 74499	 0.010029	 0.025407	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66603	 66648	 5.7e-05	 0.0002	 6e-05	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66603	 78273	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66603	 78273	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66604	 74330	 0.000579	 0.002314	 0.00059	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66604	 74334	 0.002357	 0.008957	 0.00251	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66604	 74351	 0.004729	 0.025186	 0.00706	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66606	 78307	 0.0013	 0.004443	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66606	 79454	 0.001407	 0.00755	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66607	 71365	 0.000564	 0.009343	 0.00284	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66607	 71393	 0.000657	 0.0095	 0.00301	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66607	 79403	 0.00015	 0.001807	 0.0006	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66607	 79403	 0.00015	 0.001807	 0.0006	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66608	 74472	 0.00335	 0.013407	 0.00338	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66608	 78274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66608	 78274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66609	 67587	 0.001529	 0.006129	 0.00154	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66609	 78275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66609	 78275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66609	 78530	 0.004814	 0.0131	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66610	 72896	 0.001436	 0.023314	 2.78793	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66610	 72896	 0.001436	 0.023314	 2.78793	 3180.0	 3339.0	 3498.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66610	 78276	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66610	 78276	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78277	 66610	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78277	 66610	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66611	 67745	 0.013121	 0.038679	 0.009	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66611	 67748	 0.033457	 0.091157	 0.0201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66611	 78278	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66611	 78278	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66612	 68083	 0.001586	 0.01885	 0.00656	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66612	 70342	 0.000729	 0.002879	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66612	 78279	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66612	 78279	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66612	 79127	 0.004064	 0.026557	 0.00675	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66613	 72277	 0.003043	 0.015543	 0.00391	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66613	 78280	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66613	 78280	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66614	 66792	 0.000593	 0.001493	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66614	 78281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66614	 78281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66614	 78597	 0.059521	 0.163457	 0.03564	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66614	 79115	 0.032386	 0.097571	 0.03056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66615	 66711	 0.004079	 0.016329	 0.00411	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66615	 74902	 0.007471	 0.02615	 0.00866	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66616	 71596	 0.014964	 0.0906	 0.00284	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66616	 73021	 0.016957	 0.075107	 0.00171	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66616	 73028	 0.006086	 0.03255	 0.00099	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66616	 73029	 0.098771	 0.097036	 0.00164	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66616	 73030	 0.01305	 0.083179	 0.00203	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66616	 73032	 0.025293	 0.121436	 0.00363	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66617	 66704	 0.000293	 0.001143	 0.00031	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78208	 66617	 0.000121	 0.000614	 0.00017	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66617	 78282	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66617	 78282	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66618	 66727	 0.00115	 0.002357	 6e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66618	 69000	 0.005	 0.009293	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66618	 69001	 0.00215	 0.00975	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66618	 70364	 0.002364	 0.008279	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66619	 66777	 0.0023	 0.006264	 0.00138	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78277	 66619	 0.004714	 0.037143	 0.01086	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66619	 78283	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66619	 78283	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66620	 66668	 0.004436	 0.033421	 0.00927	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66620	 73760	 0.001436	 0.010179	 0.00279	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66620	 73762	 0.002264	 0.009414	 0.00294	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66620	 73764	 0.000707	 0.002486	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 66620	 0.076979	 0.320557	 0.07673	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66620	 79611	 0.013507	 0.042229	 0.01224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66621	 66715	 0.004414	 0.025843	 0.00704	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66621	 68027	 0.010393	 0.103643	 0.03856	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66621	 78284	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66621	 78284	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66622	 69946	 0.011614	 0.023864	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66622	 79024	 0.005129	 0.017943	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66622	 79146	 0.002779	 0.007371	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66623	 70320	 9.3e-05	 0.002379	 0.19608	 3031.0	 3182.55	 3334.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66623	 78285	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66623	 78285	 0.000205	 0.015367	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78286	 66623	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78286	 66623	 0.000384	 0.028831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66624	 69734	 0.003864	 0.017207	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66624	 69738	 0.0052	 0.009664	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66624	 78938	 0.00505	 0.017686	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66624	 78948	 0.000936	 0.005329	 0.00016	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66625	 71751	 0.003443	 0.020664	 0.00626	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66625	 78287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66625	 78287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66626	 74098	 0.00295	 0.014629	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66626	 79689	 0.000936	 0.005029	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66627	 72611	 0.000343	 0.00235	 0.00423	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66627	 78288	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66627	 78288	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78289	 66627	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78289	 66627	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66628	 67763	 0.000564	 0.013343	 1.08779	 2783.0	 2922.15	 3061.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66628	 74427	 0.0003	 0.006686	 0.4518	 2517.0	 2642.85	 2768.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66628	 78290	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66628	 78290	 0.000135	 0.010814	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66629	 67574	 0.0058	 0.043564	 0.16917	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66629	 67727	 0.0023	 0.029157	 0.05566	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66629	 78293	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66629	 78293	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78294	 66629	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78294	 66629	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66630	 68013	 0.010564	 0.066921	 0.01817	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78246	 66630	 0.003579	 0.014864	 0.00347	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66630	 78295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66630	 78295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66631	 74446	 0.002236	 0.031036	 0.02141	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78291	 66631	 0.000857	 0.011193	 0.00324	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78291	 66631	 0.000857	 0.011193	 0.00324	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66631	 78296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66631	 78296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66632	 70670	 0.006536	 0.054236	 0.01427	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66632	 78297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66632	 78297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66633	 67723	 0.010136	 0.052814	 0.01386	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66633	 78298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66633	 78298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66634	 67459	 0.000421	 0.001464	 0.00034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66634	 67511	 0.001529	 0.006314	 0.00149	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66635	 74231	 0.004664	 0.018221	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66635	 74231	 0.004664	 0.018221	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66635	 74237	 0.0203	 0.071071	 0.00196	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66635	 74237	 0.0203	 0.071071	 0.00196	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78226	 66636	 0.012893	 0.077407	 0.02346	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66636	 78299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66636	 78299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66637	 73344	 0.002957	 0.007679	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66637	 73407	 0.0114	 0.029593	 0.00719	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66637	 78300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66637	 78300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66637	 79524	 0.000957	 0.003114	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78283	 66638	 0.000836	 0.004507	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66639	 70686	 0.051329	 0.175386	 0.00381	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66639	 71276	 0.0281	 0.231121	 0.00448	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66639	 71336	 0.044836	 0.047879	 0.00101	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66639	 74245	 0.05025	 0.304514	 0.00955	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66639	 78314	 0.000543	 0.002114	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66639	 78314	 0.000543	 0.002114	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66640	 74140	 0.005514	 0.038707	 0.06598	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66640	 78301	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66640	 78301	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78302	 66640	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78302	 66640	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66641	 78303	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66641	 78303	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66641	 78315	 5.7e-05	 0.000214	 6e-05	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66641	 79440	 0.000929	 0.003864	 0.00121	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66642	 73672	 0.00275	 0.007064	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66642	 74074	 0.000157	 0.0004	 0.0001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66642	 74075	 0.000621	 0.0025	 0.00063	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66642	 74079	 0.001893	 0.006893	 0.00211	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66642	 74143	 0.000979	 0.003464	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66643	 74229	 0.007571	 0.068771	 0.02243	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66643	 74240	 0.00145	 0.006036	 0.00189	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66643	 74256	 0.025593	 0.19675	 0.05297	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66644	 66766	 0.0015	 0.01035	 0.01828	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66644	 78304	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66644	 78304	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66645	 73100	 0.0095	 0.017657	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66645	 73103	 0.010814	 0.022221	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66645	 73105	 0.001829	 0.008793	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66645	 73118	 0.075157	 0.221079	 0.00454	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66646	 66754	 0.004171	 0.0229	 0.00605	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66646	 70382	 0.018264	 0.053864	 0.01254	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66647	 74459	 0.078221	 0.388571	 0.00928	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66647	 74670	 0.038629	 0.1024	 0.0026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66647	 74673	 0.035614	 0.121671	 0.00264	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66648	 69043	 0.001707	 0.007064	 0.00167	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66648	 78305	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66648	 78305	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66649	 73408	 0.048007	 0.076629	 0.00176	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66649	 73409	 0.012721	 0.0567	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66649	 73409	 0.012721	 0.0567	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66649	 73413	 0.008486	 0.040729	 0.00121	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66650	 69372	 0.003879	 0.0154	 0.00044	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66650	 69490	 0.007736	 0.017779	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66650	 78846	 0.004429	 0.019743	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66651	 73936	 7.9e-05	 0.000893	 0.00174	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66651	 79646	 9.3e-05	 0.001064	 0.00194	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66652	 71377	 0.002871	 0.011157	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66652	 71404	 0.002821	 0.00865	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66652	 71437	 0.004329	 0.019186	 0.00044	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66652	 71440	 0.00285	 0.018379	 0.00059	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66653	 73125	 0.014843	 0.065779	 0.00198	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66654	 66847	 0.000979	 0.004036	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66654	 71808	 0.014236	 0.038764	 0.00854	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66654	 78306	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66654	 78306	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66655	 72761	 0.002686	 0.009364	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66655	 78307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66655	 78307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66656	 67753	 0.031786	 0.082564	 0.02006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78268	 66656	 0.000107	 0.000386	 9e-05	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66657	 66674	 0.000157	 0.00035	 1e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66657	 72845	 0.051429	 0.060286	 0.00105	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66657	 72891	 0.001143	 0.006507	 0.00011	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66657	 72893	 0.005179	 0.01065	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66658	 71874	 0.003457	 0.014393	 0.00449	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66658	 72074	 0.004021	 0.016107	 0.00406	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66658	 78308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66658	 78308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78167	 66659	 0.000714	 0.001786	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66659	 78309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66659	 78309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66660	 72227	 0.001436	 0.010321	 0.00034	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66660	 79326	 0.002443	 0.012114	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66660	 79328	 0.041379	 0.109679	 0.00279	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66661	 71097	 0.005343	 0.015757	 0.00366	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66661	 78310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66661	 78310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66661	 79267	 0.001843	 0.007364	 0.00186	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66662	 69761	 0.00045	 0.001493	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66662	 69772	 0.000679	 0.002829	 0.00088	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66662	 78311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66662	 78311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66663	 70386	 0.000864	 0.002957	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66663	 78312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66663	 78312	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66664	 74511	 0.001443	 0.005243	 0.00161	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66664	 74517	 0.00485	 0.011257	 0.00343	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66664	 74537	 0.009614	 0.037779	 0.00989	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66664	 78313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66664	 78313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66665	 66672	 7e-06	 5e-05	 1e-05	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66665	 74551	 0.000543	 0.002529	 0.00063	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66665	 74558	 0.000964	 0.0055	 0.00159	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66666	 73441	 0.017443	 0.077307	 0.00232	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78274	 66666	 0.000193	 0.00095	 2e-05	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66666	 79762	 0.007407	 0.039657	 0.0012	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66667	 74726	 0.004564	 0.009371	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66667	 74727	 0.018929	 0.028993	 0.00041	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66667	 74753	 0.032571	 0.023071	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66667	 74842	 0.008157	 0.016764	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66667	 78320	 0.000143	 0.000293	 1e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66668	 73765	 0.001979	 0.007521	 0.00211	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 66668	 0.069814	 0.2815	 0.07159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66669	 70682	 0.006229	 0.024936	 0.00628	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66669	 78314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66669	 78314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66670	 71457	 0.000821	 0.00335	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66670	 71472	 0.000864	 0.00345	 0.00116	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66671	 72682	 0.000193	 0.001686	 0.00307	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66671	 72705	 0.000779	 0.005471	 0.00931	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66671	 78315	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66671	 78315	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78316	 66671	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78316	 66671	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66672	 66681	 0.000143	 0.000771	 0.00019	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66673	 67747	 0.20495	 0.201421	 0.0034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66673	 67986	 0.038114	 0.070871	 0.00166	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66673	 67987	 0.013779	 0.08255	 0.00199	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66673	 68007	 0.046907	 0.251171	 0.00762	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66674	 72893	 0.002993	 0.010221	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66674	 72894	 0.005207	 0.0138	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66674	 73131	 0.046786	 0.1075	 0.00164	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66674	 79465	 0.008214	 0.0168	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66675	 67723	 0.022579	 0.100693	 0.02739	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66675	 78317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66675	 78317	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66675	 78318	 0.006729	 0.016207	 0.00458	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66676	 67727	 0.00535	 0.035264	 0.06831	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66676	 74600	 0.003464	 0.048379	 0.13132	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78162	 66676	 0.002679	 0.019379	 0.04518	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66676	 78318	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66676	 78318	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78319	 66676	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78319	 66676	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66677	 74725	 0.002393	 0.006521	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66677	 74846	 0.00025	 0.000807	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66677	 78320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66677	 78320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66678	 66745	 0.005921	 0.030857	 0.00809	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66678	 67964	 0.005914	 0.048029	 0.01529	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66678	 78321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66678	 78321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66679	 66864	 0.002564	 0.010014	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66679	 66864	 0.002564	 0.010014	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78283	 66679	 0.0009	 0.003529	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66679	 78369	 0.002593	 0.017607	 0.00044	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66680	 70582	 0.019493	 0.07095	 0.02174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 66680	 0.086707	 0.285036	 0.07644	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66680	 78322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66680	 78322	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78179	 66681	 0.0017	 0.024536	 0.00779	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78232	 66681	 0.008514	 0.096379	 0.03716	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66681	 78323	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66681	 78323	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66682	 71425	 0.002257	 0.009636	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66682	 71431	 0.006021	 0.026821	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66682	 71458	 0.002686	 0.010479	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66682	 71458	 0.002686	 0.010479	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66682	 71778	 0.0025	 0.012007	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66683	 74355	 0.019771	 0.060664	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66683	 79741	 0.01415	 0.065964	 0.00152	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66684	 78324	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66684	 78324	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66685	 74354	 0.004686	 0.016086	 0.00386	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78324	 66685	 0.001443	 0.005657	 0.00148	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66686	 74554	 0.001193	 0.003979	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66686	 74894	 0.001736	 0.006743	 0.0018	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66686	 78325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66686	 78325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66687	 74310	 0.003143	 0.008307	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66687	 74311	 0.000586	 0.002014	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66687	 78326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66687	 78326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66688	 67326	 0.001264	 0.00335	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66688	 78327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66688	 78327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66689	 70678	 0.064621	 0.0583	 0.00098	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66689	 74900	 0.022964	 0.137621	 0.00331	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66689	 79196	 0.056036	 0.069557	 0.00151	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66689	 79861	 0.075221	 0.248321	 0.00402	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66690	 67745	 0.050757	 0.1278	 0.03317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66690	 67748	 0.018693	 0.048536	 0.01179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66690	 68009	 0.028193	 0.075736	 0.01717	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 66690	 0.1086	 0.33275	 0.07369	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66690	 78328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66690	 78328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66691	 74576	 1.4e-05	 0.000329	 0.03245	 4451.0	 4673.55	 4896.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66691	 74577	 3.6e-05	 0.001	 0.12046	 4451.0	 4673.55	 4896.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66692	 68002	 0.003857	 0.012857	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66692	 78329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66692	 78329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66692	 78530	 0.049743	 0.128064	 0.03176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66693	 67848	 0.0175	 0.0397	 0.00079	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66693	 67852	 0.009271	 0.021036	 0.00042	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66693	 67854	 0.01035	 0.016521	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66694	 67833	 0.0098	 0.043414	 0.00099	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66694	 78591	 0.018793	 0.034943	 0.00081	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66695	 67913	 0.007657	 0.074807	 0.02101	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66695	 78330	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66695	 78330	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66695	 78347	 0.000836	 0.003043	 0.00093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66695	 78584	 0.0033	 0.0156	 0.00375	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66696	 73446	 0.002921	 0.007721	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66696	 73452	 0.001343	 0.003607	 0.00101	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66696	 78331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66696	 78331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78153	 66697	 0.107436	 0.294614	 0.06547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78173	 66697	 0.006879	 0.01885	 0.0041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66697	 78332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66697	 78332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66698	 67173	 0.00075	 0.005243	 0.00893	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66698	 73924	 0.000436	 0.002993	 0.00539	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66698	 73938	 0.000229	 0.001536	 0.00283	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66698	 78333	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66698	 78333	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78334	 66698	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78334	 66698	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66699	 74141	 0.000814	 0.005964	 0.00154	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66699	 79696	 0.001364	 0.004971	 0.00152	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66700	 71672	 0.003771	 0.0181	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66700	 71681	 0.006764	 0.0298	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66700	 71681	 0.006764	 0.0298	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66700	 71684	 0.030479	 0.0772	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66701	 78335	 0.000393	 0.001371	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66701	 78335	 0.000393	 0.001371	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66701	 79404	 0.002507	 0.01345	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66702	 72305	 0.000614	 0.004093	 0.00126	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66702	 78335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66702	 78335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66702	 79403	 0.000643	 0.004179	 0.00106	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66703	 70682	 0.004421	 0.018257	 0.00432	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66703	 71334	 0.008621	 0.030164	 0.01	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66703	 78336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66703	 78336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66704	 73075	 0.001207	 0.004593	 0.00129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66705	 72752	 0.0063	 0.006929	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66705	 72810	 0.002229	 0.007621	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66705	 72811	 0.003643	 0.017479	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66705	 72818	 0.001786	 0.008707	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66706	 71681	 0.010657	 0.024743	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66706	 71692	 0.013843	 0.059171	 0.00134	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66706	 72463	 0.038329	 0.229736	 0.00553	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66707	 68878	 0.008043	 0.015757	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66707	 68879	 0.010736	 0.00695	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66707	 68880	 0.004629	 0.007393	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66707	 68881	 0.001371	 0.002186	 5e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66707	 68884	 0.003907	 0.007271	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66708	 67843	 0.005614	 0.025021	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66708	 67845	 0.018636	 0.032771	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66708	 78565	 0.01695	 0.015293	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66709	 70294	 0.04085	 0.105014	 0.00163	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66709	 70296	 0.0311	 0.079957	 0.00124	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66710	 71303	 0.0017	 0.006814	 0.00171	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66710	 71959	 0.0041	 0.025979	 0.00705	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66710	 78337	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66710	 78337	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66710	 79316	 0.001557	 0.014136	 0.00461	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66711	 67272	 0.0127	 0.076864	 0.01963	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66711	 74902	 0.005864	 0.034371	 0.00936	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66711	 78338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66711	 78338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66712	 66719	 0.000571	 0.00535	 0.00162	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66712	 71652	 0.002393	 0.020529	 0.00584	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66712	 78339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66712	 78339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66713	 72750	 0.021871	 0.049614	 0.00099	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66713	 72778	 0.007893	 0.014679	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66713	 72782	 0.003986	 0.015564	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66714	 71512	 0.010357	 0.009279	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66714	 71513	 0.03105	 0.024571	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66714	 71796	 0.002843	 0.008721	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66715	 68030	 0.052907	 0.127714	 0.03613	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66715	 78340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66715	 78340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66716	 74211	 8.6e-05	 0.001914	 0.19101	 3339.0	 3505.95	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66716	 74573	 0.000136	 0.004086	 0.40112	 4451.0	 4673.55	 4896.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66716	 78341	 9.4e-05	 0.007487	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66716	 78341	 9.4e-05	 0.007487	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66717	 67356	 0.000779	 0.006771	 0.00268	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66717	 67358	 0.001621	 0.007443	 0.00191	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66717	 78491	 0.000371	 0.006086	 0.00191	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66717	 78498	 0.002414	 0.011086	 0.00284	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66718	 67352	 0.001514	 0.005886	 0.00157	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66718	 67354	 0.002629	 0.010321	 0.0027	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66718	 67356	 0.000364	 0.003507	 0.00102	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66718	 78343	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66718	 78343	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66719	 71685	 0.003021	 0.020243	 0.0062	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66719	 78344	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66719	 78344	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66720	 74226	 0.081193	 0.396579	 0.00686	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66720	 74239	 0.144836	 0.297843	 0.00569	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78252	 66720	 0.012257	 0.058829	 0.00176	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66721	 67914	 0.004164	 0.0244	 0.00664	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66721	 73712	 0.031207	 0.1251	 0.03157	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 66721	 0.114814	 0.305971	 0.07233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78207	 66721	 0.000386	 0.004586	 0.0016	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66722	 74201	 0.000314	 0.004814	 0.0106	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66722	 78345	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66722	 78345	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66723	 70583	 0.029357	 0.1427	 0.03269	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 66723	 0.051957	 0.212236	 0.05198	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66723	 78346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66723	 78346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66723	 78349	 0.001907	 0.007621	 0.00192	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66724	 74231	 0.006536	 0.025529	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66724	 74231	 0.006536	 0.025529	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66724	 74232	 0.012693	 0.049564	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66724	 74232	 0.012693	 0.049564	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66724	 74233	 0.0098	 0.022521	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66724	 74234	 0.039786	 0.03275	 0.00066	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66725	 67915	 0.000829	 0.005821	 0.00991	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66725	 67975	 0.005	 0.047414	 0.08511	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66725	 78347	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66725	 78347	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66726	 67529	 0.004243	 0.01125	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66726	 67548	 0.04325	 0.14775	 0.00321	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66727	 69000	 0.0037	 0.007571	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66727	 69008	 0.008329	 0.025543	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66728	 67748	 0.030343	 0.07805	 0.01934	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 66728	 0.113857	 0.314529	 0.06906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66728	 78348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66728	 78348	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66729	 74663	 0.022871	 0.137064	 0.0033	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66729	 78589	 0.21145	 0.167386	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66729	 78591	 0.177171	 0.284393	 0.00526	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66730	 70586	 0.000379	 0.005807	 0.44739	 2056.0	 2158.8	 2261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66730	 73478	 0.000414	 0.00555	 0.38034	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66730	 78349	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66730	 78349	 0.002956	 0.1153	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66731	 68020	 0.044207	 0.172686	 0.00383	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78247	 66731	 0.008436	 0.017336	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66732	 67213	 0.037536	 0.128229	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66732	 67320	 0.025043	 0.058121	 0.00111	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66733	 66734	 0.006171	 0.020793	 0.00516	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66733	 74586	 0.065843	 0.27355	 0.06527	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66733	 78351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66733	 78351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66734	 66735	 0.0028	 0.011221	 0.00283	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66734	 70535	 0.021543	 0.0554	 0.01372	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66735	 67724	 0.017643	 0.138407	 0.03554	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66735	 70535	 0.013429	 0.044814	 0.01137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66736	 67912	 0.009264	 0.049914	 0.01371	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66736	 70318	 0.006436	 0.035693	 0.01085	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78286	 66736	 0.010321	 0.037557	 0.0115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66737	 66759	 0.001014	 0.008121	 0.02734	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66737	 71323	 0.006029	 0.098571	 0.19647	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66737	 78352	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66737	 78352	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66738	 74354	 0.0032	 0.012579	 0.00329	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66739	 70460	 0.0227	 0.088379	 0.02363	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66739	 78353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66739	 78353	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66740	 67739	 0.010193	 0.043579	 0.00099	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66740	 67741	 0.01325	 0.033571	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66740	 78548	 0.016586	 0.034086	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66741	 68029	 0.157257	 0.276729	 0.0052	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66741	 68032	 0.168679	 0.119514	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66741	 78605	 0.140029	 0.260543	 0.0061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66742	 67796	 0.004957	 0.021564	 0.00614	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66742	 67797	 0.000643	 0.003871	 0.00099	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66743	 78354	 0.008493	 0.01745	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66743	 78369	 0.000243	 0.001321	 3e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66744	 66777	 0.002029	 0.005093	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66744	 67797	 0.001579	 0.005614	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66744	 78354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66744	 78354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66745	 78355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66745	 78355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66746	 66752	 0.001179	 0.007121	 0.00022	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66746	 66753	 0.003286	 0.008714	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66746	 67963	 0.016864	 0.095879	 0.00174	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78355	 66746	 0.001771	 0.006914	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78355	 66746	 0.001771	 0.006914	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66747	 70532	 0.038464	 0.146521	 0.04113	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66747	 74240	 0.027793	 0.114864	 0.02721	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66747	 78356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66747	 78356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66748	 68571	 0.002179	 0.004457	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66748	 68572	 0.002243	 0.004607	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66748	 68576	 0.000429	 0.001679	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66749	 71672	 0.005464	 0.022793	 0.00066	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66749	 71692	 0.022443	 0.046114	 0.00088	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78306	 66749	 0.002571	 0.015829	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66750	 70490	 0.018264	 0.081436	 0.02215	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66750	 74464	 0.015586	 0.117536	 0.03267	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66750	 78357	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66750	 78357	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66751	 66752	 0.001771	 0.0047	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66751	 72496	 0.198943	 0.409364	 0.00781	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66752	 66753	 0.000979	 0.005921	 0.00019	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66752	 72494	 0.061486	 0.188693	 0.00511	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78355	 66753	 0.002671	 0.010443	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78355	 66753	 0.002671	 0.010443	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66754	 78358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66754	 78358	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66755	 71408	 0.010757	 0.047921	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66755	 71408	 0.010757	 0.047921	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66755	 79326	 0.009986	 0.034957	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66755	 79422	 0.00395	 0.015414	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66755	 79422	 0.00395	 0.015414	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78222	 66756	 0.007143	 0.018936	 0.00048	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66757	 67796	 0.00955	 0.137879	 0.08888	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66757	 78359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66757	 78359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66758	 72655	 0.000886	 0.002143	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66758	 78360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66758	 78360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66759	 78361	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66759	 78361	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78362	 66759	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78362	 66759	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66760	 72456	 0.004529	 0.011764	 0.00286	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66760	 78363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66760	 78363	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66761	 67279	 0.012007	 0.030857	 0.00048	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66761	 67287	 0.053886	 0.210514	 0.00467	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66761	 67288	 0.036079	 0.110693	 0.003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66761	 67289	 0.006636	 0.019036	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66761	 78475	 0.018043	 0.061636	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66762	 67791	 0.02285	 0.053057	 0.00079	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66762	 67792	 0.082793	 0.148836	 0.00267	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66763	 67291	 0.030093	 0.077407	 0.01918	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66763	 73432	 0.025271	 0.129257	 0.03258	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66763	 78364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66763	 78364	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66764	 73933	 0.001264	 0.004464	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66764	 73934	 0.00015	 0.000586	 0.00016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66765	 73922	 0.003229	 0.007786	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66765	 73935	 0.000943	 0.003436	 0.00105	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66765	 78365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66765	 78365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66765	 79644	 0.001871	 0.007486	 0.00189	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78219	 66766	 0.004257	 0.040907	 0.09199	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66766	 78366	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66766	 78366	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66767	 68995	 0.002164	 0.009236	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66767	 68996	 0.002343	 0.011607	 0.00028	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66767	 79140	 0.000864	 0.005164	 0.00012	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66768	 66841	 0.004014	 0.014286	 0.00318	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78173	 66768	 0.012107	 0.049279	 0.01201	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66769	 74773	 0.0005	 0.001707	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66769	 78367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66769	 78367	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66769	 79819	 0.007864	 0.020779	 0.00486	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66770	 69893	 0.0174	 0.035757	 0.00068	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66770	 69900	 0.004821	 0.008957	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66770	 79024	 0.0054	 0.01225	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66770	 79140	 0.002293	 0.008036	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66770	 79140	 0.002293	 0.008036	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78317	 66771	 0.000107	 0.000243	 1e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78319	 66771	 0.036729	 0.058629	 0.00135	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66772	 74243	 0.019686	 0.065664	 0.00104	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78237	 66772	 0.022257	 0.06545	 0.00134	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66773	 71680	 0.016193	 0.049671	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66773	 71681	 0.0063	 0.049129	 0.00092	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66774	 72149	 0.009493	 0.033236	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66774	 72151	 0.007457	 0.026086	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66774	 72152	 0.013764	 0.031471	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66774	 72503	 0.0184	 0.013036	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66774	 79380	 0.004321	 0.014757	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66775	 69527	 0.000457	 0.001986	 0.00056	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66775	 69758	 0.000486	 0.001957	 0.00049	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66775	 69786	 0.001814	 0.007136	 0.00186	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66775	 78368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66775	 78368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66776	 78538	 0.041243	 0.104479	 0.00207	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66777	 67797	 0.002729	 0.009636	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66777	 78369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66777	 78369	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66778	 68754	 0.000721	 0.004929	 0.00144	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66778	 78370	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66778	 78370	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66778	 78904	 0.000507	 0.002536	 0.00066	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66779	 70535	 0.018929	 0.074436	 0.01949	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66779	 70536	 0.044393	 0.16195	 0.04976	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66779	 78371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66779	 78371	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66780	 71499	 0.008707	 0.053514	 0.00096	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66780	 72353	 0.004971	 0.017414	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66780	 72353	 0.004971	 0.017414	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78335	 66780	 0.001957	 0.008721	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78335	 66780	 0.001957	 0.008721	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78293	 66781	 0.0017	 0.005543	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66782	 72509	 0.065829	 0.165921	 0.04312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78197	 66782	 0.034943	 0.210657	 0.06421	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66782	 78372	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66782	 78372	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66783	 78373	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66783	 78373	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66784	 66785	 0.002007	 0.009136	 0.0029	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66784	 67832	 0.012121	 0.149771	 0.04855	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66784	 74637	 0.016943	 0.142757	 0.04241	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66785	 67954	 0.008757	 0.065107	 0.02485	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66786	 68986	 0.002793	 0.010893	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66786	 78955	 0.007393	 0.032943	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66786	 79140	 0.001257	 0.005579	 0.00016	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66787	 78383	 0.000329	 0.000614	 1e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66787	 78389	 0.003243	 0.014371	 0.00043	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66787	 78596	 0.007843	 0.056464	 0.00185	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66788	 68026	 0.036107	 0.142164	 0.03729	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66788	 68027	 0.010379	 0.133121	 0.03984	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66788	 70531	 0.015086	 0.193893	 0.0582	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66788	 78374	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66788	 78374	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66789	 71680	 0.012957	 0.037171	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66790	 71547	 0.071821	 0.050879	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66790	 71556	 0.002936	 0.013	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66790	 71626	 0.013229	 0.045193	 0.00099	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66791	 67231	 0.116714	 0.075571	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66791	 67299	 0.144393	 0.114286	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66791	 67549	 0.15915	 0.2542	 0.00586	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66791	 74666	 0.029029	 0.219621	 0.00731	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66791	 78468	 0.069521	 0.351929	 0.00613	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66792	 66843	 0.002964	 0.012057	 0.00294	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66793	 74737	 0.011657	 0.026436	 0.00053	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66793	 74741	 0.017471	 0.013829	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66793	 79814	 0.007807	 0.01065	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66794	 69415	 0.001243	 0.006436	 0.00157	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66794	 69443	 0.004414	 0.012014	 0.00265	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66794	 78375	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66794	 78375	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66795	 67300	 0.01985	 0.136286	 0.00249	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66795	 67301	 0.051479	 0.095729	 0.00224	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66795	 67302	 0.025007	 0.110821	 0.00333	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66796	 66998	 0.001964	 0.006707	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66796	 67000	 0.005636	 0.009493	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66796	 67002	 0.000464	 0.003929	 0.0001	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66796	 67003	 0.003179	 0.006293	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66797	 70331	 0.005021	 0.0045	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66797	 70347	 0.0097	 0.046564	 0.00139	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66797	 79128	 0.00805	 0.0231	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66797	 79129	 0.051893	 0.046821	 0.00079	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66798	 72612	 0.001321	 0.003686	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66798	 78376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66798	 78376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66799	 67575	 0.0022	 0.005536	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66799	 67587	 0.0006	 0.002479	 0.00059	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66799	 78530	 0.002993	 0.009764	 0.00259	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66800	 74881	 0.011786	 0.021907	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66801	 67630	 0.058314	 0.19925	 0.00434	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66801	 67754	 0.008314	 0.0443	 0.00078	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	66801	 67755	 0.02325	 0.167336	 0.00549	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66802	 71322	 0.013429	 0.0276	 0.00053	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66802	 71346	 0.011664	 0.03345	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66802	 71348	 0.008371	 0.024621	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66803	 67835	 0.013636	 0.0279	 0.00069	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66803	 78565	 0.010964	 0.01285	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66804	 66833	 0.006936	 0.024279	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66804	 67804	 0.084436	 0.054664	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66804	 67805	 0.018421	 0.091421	 0.00218	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66804	 67825	 0.537843	 0.426464	 0.00537	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66805	 67028	 0.002571	 0.015421	 0.00037	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66805	 67039	 0.004407	 0.012964	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66805	 78467	 0.0116	 0.009543	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66806	 73412	 0.037514	 0.024286	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66806	 73413	 0.006093	 0.036893	 0.00116	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66806	 73414	 0.00195	 0.007736	 0.00022	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66807	 71299	 0.01125	 0.033086	 0.00068	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66807	 71346	 0.011136	 0.022886	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66807	 71347	 0.007736	 0.012414	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66808	 66848	 0.000579	 0.001464	 3e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66808	 79197	 0.017793	 0.04035	 0.00081	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66809	 67456	 0.002364	 0.009186	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66809	 67465	 0.005557	 0.01945	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66810	 66825	 0.004964	 0.018071	 0.00554	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66810	 67967	 0.000171	 0.000893	 0.00023	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66810	 70228	 0.013621	 0.096436	 0.02649	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66811	 66863	 0.002979	 0.018314	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66811	 74249	 0.341943	 0.2216	 0.00421	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66811	 74253	 0.034486	 0.248329	 0.00815	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66812	 73775	 0.002843	 0.010814	 0.00303	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66812	 73944	 0.001893	 0.005679	 0.00128	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66812	 78377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66812	 78377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66812	 79647	 0.000964	 0.003986	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66813	 70044	 0.002571	 0.008971	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66813	 70356	 0.000186	 0.000621	 0.00016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66813	 78378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66813	 78378	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66814	 74240	 0.019093	 0.057493	 0.01799	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78304	 66814	 0.005464	 0.021471	 0.00561	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66814	 78379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66814	 78379	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66815	 78380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66815	 78380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66816	 67855	 0.057321	 0.130036	 0.00259	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66816	 67950	 0.063786	 0.045186	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66816	 67953	 0.174336	 0.143536	 0.00291	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66817	 72624	 0.013321	 0.009436	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66817	 72626	 0.00635	 0.010136	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66817	 73133	 0.003057	 0.0107	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66818	 67230	 0.028021	 0.057343	 0.00141	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66818	 67237	 0.048514	 0.216243	 0.00367	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66818	 67237	 0.048514	 0.216243	 0.00367	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66818	 67296	 0.1452	 0.094014	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66818	 67531	 0.118686	 0.364571	 0.00989	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66818	 67559	 0.057893	 0.278107	 0.00832	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66819	 67529	 0.017886	 0.047414	 0.0012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66819	 67559	 0.099871	 0.205307	 0.00391	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66819	 67560	 0.059707	 0.183221	 0.00496	 88.0	 88.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66820	 70521	 0.008779	 0.031936	 0.00978	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66820	 70524	 0.0171	 0.0444	 0.01078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78301	 66820	 0.001171	 0.009536	 0.00304	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66820	 79696	 0.027136	 0.108757	 0.02744	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66821	 67941	 0.005264	 0.013921	 0.00326	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66821	 67942	 0.0035	 0.010929	 0.00316	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66821	 67947	 0.002486	 0.008514	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66821	 67948	 0.00475	 0.01485	 0.0043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66821	 78381	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66821	 78381	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66822	 68023	 0.056843	 0.099971	 0.00188	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66822	 74450	 0.036607	 0.10765	 0.00221	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66823	 70239	 0.018686	 0.046979	 0.01217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66823	 70289	 0.004279	 0.016257	 0.00455	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66823	 78382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66823	 78382	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66824	 74455	 0.067264	 0.262836	 0.00584	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66824	 74672	 0.035864	 0.066693	 0.00156	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66824	 74673	 0.076471	 0.089643	 0.00156	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66824	 74674	 0.081221	 0.057536	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66825	 66843	 0.001193	 0.004921	 0.00116	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66825	 78383	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66825	 78383	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66826	 74533	 0.007229	 0.030907	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66826	 74540	 0.020514	 0.036079	 0.00068	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78239	 66826	 0.0021	 0.007164	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66827	 67806	 0.002093	 0.023164	 0.00695	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66827	 78384	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66827	 78384	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66828	 67929	 0.023886	 0.115264	 0.00204	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66828	 78385	 0.003707	 0.014471	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66829	 67833	 0.010886	 0.069414	 0.00169	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66829	 78385	 0.004314	 0.009864	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66830	 67949	 0.003264	 0.013079	 0.00329	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66830	 78385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66830	 78385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66831	 68025	 0.013393	 0.071679	 0.00217	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78297	 66831	 0.0049	 0.019136	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66832	 67873	 0.014264	 0.076629	 0.00182	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66832	 78569	 0.025636	 0.047664	 0.00111	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66832	 78591	 0.043207	 0.046143	 0.00098	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66833	 66854	 0.022464	 0.020271	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66833	 67804	 0.033829	 0.069521	 0.00133	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66833	 67810	 0.029693	 0.168979	 0.0052	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77285	 66833	 0.158314	 0.620136	 0.01381	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77285	 66833	 0.158314	 0.620136	 0.01381	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66834	 78386	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66834	 78386	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66835	 73459	 0.014857	 0.030529	 0.00058	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66836	 74529	 0.035314	 0.0801	 0.0016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66837	 67845	 0.021693	 0.019436	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66837	 67862	 0.014557	 0.033014	 0.00066	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66838	 72246	 0.00175	 0.004064	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66838	 72259	 0.000964	 0.003007	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66839	 68034	 0.065879	 0.215814	 0.05762	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66839	 71356	 0.0096	 0.059664	 0.01685	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66839	 78387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66839	 78387	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66840	 67235	 0.024793	 0.056243	 0.00112	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66840	 67293	 0.01755	 0.061457	 0.0017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66841	 67938	 0.00655	 0.043893	 0.01345	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66842	 71752	 0.000371	 0.004643	 0.00144	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66842	 71752	 0.000371	 0.004643	 0.00144	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66842	 71808	 0.008221	 0.107093	 0.031	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66842	 71808	 0.008221	 0.107093	 0.031	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66842	 78388	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66842	 78388	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66843	 70229	 0.019979	 0.075971	 0.02129	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66843	 78389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66843	 78389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66844	 69043	 0.0009	 0.003421	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66844	 69045	 0.0002	 0.001221	 0.00037	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66844	 69046	 0.000243	 0.0023	 0.00067	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66845	 73463	 0.012307	 0.032614	 0.00083	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78251	 66845	 0.004714	 0.009686	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66845	 79542	 0.00545	 0.011207	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66846	 78390	 0.008243	 0.028857	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66846	 78390	 0.008243	 0.028857	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66846	 79342	 0.016457	 0.064271	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66846	 79342	 0.016457	 0.064271	 0.00143	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66847	 71808	 0.012007	 0.039179	 0.0104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66847	 78390	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66847	 78390	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78336	 66848	 0.010007	 0.053757	 0.00128	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78362	 66849	 0.019043	 0.0432	 0.00086	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66850	 67953	 0.247236	 0.272086	 0.00364	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66850	 67970	 0.039429	 0.073314	 0.00171	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66850	 67973	 0.087243	 0.250314	 0.00385	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66851	 66855	 0.01315	 0.023129	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66851	 67970	 0.036864	 0.15765	 0.00356	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78281	 66851	 0.008857	 0.03025	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66852	 67208	 0.004714	 0.019593	 0.00457	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66852	 67218	 0.010421	 0.02855	 0.00621	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66852	 73460	 0.007679	 0.027314	 0.00607	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66853	 71672	 0.018321	 0.016529	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66853	 71674	 0.048821	 0.04405	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66853	 71677	 0.035579	 0.023036	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66854	 67804	 0.028293	 0.072729	 0.00113	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66855	 67974	 0.039464	 0.10145	 0.00157	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66856	 67972	 0.14015	 0.204314	 0.00462	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66856	 67974	 0.053157	 0.079693	 0.00145	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66857	 70728	 0.001607	 0.004364	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66857	 78391	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66857	 78391	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66857	 79206	 0.000993	 0.002386	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66858	 67803	 0.010957	 0.058864	 0.0014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66858	 78562	 0.008871	 0.047664	 0.00113	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66859	 71761	 0.0029	 0.0289	 0.01074	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66859	 71772	 0.008486	 0.132407	 0.04638	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66859	 78392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66859	 78392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66860	 67951	 0.0086	 0.032693	 0.00915	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66860	 74637	 0.025193	 0.102614	 0.02503	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66861	 74596	 0.0507	 0.073886	 0.00167	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66861	 74608	 0.017107	 0.116193	 0.00288	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66861	 79784	 0.031143	 0.191521	 0.00345	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66862	 67547	 0.019121	 0.065321	 0.00142	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66862	 67548	 0.013129	 0.029779	 0.00059	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66863	 74247	 0.075743	 0.337736	 0.00574	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66863	 74248	 0.336629	 0.264071	 0.00339	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66864	 67824	 0.081436	 0.363164	 0.00617	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66864	 67824	 0.081436	 0.363164	 0.00617	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66865	 67770	 0.014793	 0.030271	 0.00074	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66866	 67958	 0.016343	 0.059464	 0.01821	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66866	 72508	 0.069671	 0.196164	 0.05071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66867	 74243	 0.026507	 0.04855	 0.00084	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66868	 71671	 0.04305	 0.080057	 0.00187	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66868	 71774	 0.019129	 0.049164	 0.00076	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66869	 67012	 0.007357	 0.015121	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66869	 67438	 0.010164	 0.020893	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66870	 66872	 0.002493	 0.0057	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66870	 67013	 0.002221	 0.006821	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66871	 66906	 0.001493	 0.010121	 0.00025	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66871	 67010	 0.002321	 0.014957	 0.00048	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66872	 66873	 0.001957	 0.00575	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66873	 67009	 0.005614	 0.011543	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66873	 67014	 0.0022	 0.004521	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66874	 66875	 0.009486	 0.006714	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66875	 66876	 0.015329	 0.009929	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66876	 66877	 0.010464	 0.007414	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66876	 67017	 0.002636	 0.006121	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66876	 78409	 0.004671	 0.006379	 0.00011	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66878	 66879	 0.002186	 0.005793	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66878	 78410	 0.003657	 0.009257	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66879	 66880	 0.0016	 0.0047	 9e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66879	 66882	 0.015314	 0.013814	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66880	 66906	 0.001821	 0.007071	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66881	 66898	 0.001279	 0.004486	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66881	 78410	 0.004786	 0.016743	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66882	 66883	 0.009914	 0.00785	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66882	 66884	 0.001764	 0.007857	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66882	 78410	 0.004043	 0.013814	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66884	 66888	 0.003907	 0.005857	 0.00011	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66884	 66891	 0.001907	 0.007457	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66885	 78393	 0.006443	 0.014614	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66885	 78408	 0.015636	 0.045979	 0.00094	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66886	 78393	 0.0057	 0.004507	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66887	 66978	 0.000421	 0.001821	 0.00052	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66887	 67226	 0.000857	 0.003557	 0.00111	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66887	 67227	 0.000407	 0.002236	 0.00081	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66887	 78393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66887	 78393	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66888	 78405	 0.003693	 0.005386	 0.00012	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66889	 66978	 0.000457	 0.001579	 0.00038	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66889	 78394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66889	 78394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66890	 66895	 0.000343	 0.001179	 0.00029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66890	 78395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66890	 78395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66891	 66892	 0.001136	 0.004421	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66892	 66893	 0.000893	 0.004357	 8e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66893	 66897	 0.001243	 0.0055	 0.00016	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66893	 78396	 0.001564	 0.006929	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66894	 78396	 0.003964	 0.005207	 7e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66895	 78396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66895	 78396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66895	 78407	 0.002864	 0.016421	 0.00546	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78396	 66896	 0.007593	 0.011386	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66897	 66902	 0.003686	 0.007579	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66897	 66920	 0.010564	 0.006836	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66897	 66922	 0.002357	 0.011907	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66898	 66899	 0.004921	 0.003893	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66898	 66900	 0.001486	 0.005693	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66898	 66905	 0.006021	 0.009221	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66898	 66906	 0.007436	 0.013836	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66900	 66901	 0.007579	 0.006	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66900	 66902	 0.000714	 0.003429	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66900	 66904	 0.0021	 0.006029	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66902	 66919	 0.002286	 0.007814	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66903	 66905	 0.005643	 0.0128	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66903	 66918	 0.003279	 0.0075	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66904	 67023	 0.003936	 0.009964	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66905	 66907	 0.001371	 0.003471	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66906	 66907	 0.001671	 0.003829	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66906	 67023	 0.003079	 0.008157	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66908	 66909	 0.001307	 0.007929	 0.00025	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66908	 66912	 0.008557	 0.025157	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66908	 67023	 0.002764	 0.0106	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66909	 66910	 0.009193	 0.018893	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66909	 67013	 0.0018	 0.009671	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66910	 67436	 0.012736	 0.028893	 0.00058	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66911	 66912	 0.009629	 0.013129	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66911	 67022	 0.00535	 0.008543	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66912	 66913	 0.0059	 0.017336	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66912	 78509	 0.021336	 0.0612	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66913	 66914	 0.003993	 0.015543	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66913	 66953	 0.006093	 0.020314	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66913	 78510	 0.006543	 0.025564	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66914	 66915	 0.004107	 0.0084	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66914	 66939	 0.0043	 0.009829	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66915	 66916	 0.002271	 0.006686	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66916	 66917	 0.001814	 0.00415	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66917	 66918	 0.002814	 0.007129	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66919	 66925	 0.001857	 0.00635	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66921	 66922	 0.006893	 0.004464	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66922	 66923	 0.002521	 0.004029	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66922	 66924	 0.008379	 0.005421	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66922	 66925	 0.013107	 0.011821	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66922	 66929	 0.002971	 0.008729	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66923	 66930	 0.004557	 0.007271	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66925	 66926	 0.00185	 0.005671	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66926	 66927	 0.008193	 0.0053	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66926	 66935	 0.001636	 0.0073	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66928	 66929	 0.001757	 0.005164	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66928	 66932	 0.001643	 0.004821	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66930	 67025	 0.002579	 0.010757	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78263	 66930	 0.0058	 0.023	 0.00066	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66931	 66946	 0.000443	 0.0037	 0.00144	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66931	 66955	 0.002521	 0.010079	 0.00341	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66931	 67021	 0.003921	 0.021071	 0.00519	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66931	 78397	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66931	 78397	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66931	 78407	 0.003386	 0.028457	 0.00843	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66932	 66933	 0.002	 0.004536	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66932	 66934	 0.004493	 0.006729	 0.00012	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78397	 66933	 0.003736	 0.008464	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66934	 66936	 0.005171	 0.007921	 0.00011	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66935	 66936	 0.00205	 0.009143	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66936	 66937	 0.004007	 0.009086	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66936	 66942	 0.004586	 0.013157	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66936	 66943	 0.002143	 0.006086	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78397	 66936	 0.027157	 0.017579	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66937	 66938	 0.009343	 0.006614	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66937	 66939	 0.004757	 0.009729	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66940	 66941	 0.002607	 0.005329	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66940	 66953	 0.004293	 0.010864	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66941	 66942	 0.004864	 0.00995	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66941	 66952	 0.010607	 0.007514	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66942	 66951	 0.0031	 0.015121	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66943	 66944	 0.001371	 0.004036	 9e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66943	 66945	 0.006229	 0.008186	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66944	 66949	 0.002186	 0.006429	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78397	 66945	 0.005314	 0.00775	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66946	 66962	 0.000686	 0.004993	 0.00172	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66946	 78398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66946	 78398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66947	 66948	 0.002957	 0.007486	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66947	 66949	 0.002	 0.006136	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78398	 66947	 0.008314	 0.010921	 0.00015	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66948	 66950	 0.003943	 0.00915	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66948	 66960	 0.002757	 0.006979	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66950	 66951	 0.0037	 0.007593	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66951	 78400	 0.005536	 0.011371	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66954	 66955	 0.001243	 0.004986	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66954	 66973	 0.001414	 0.012507	 0.00333	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66954	 67435	 0.00115	 0.011643	 0.00342	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66954	 78399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66954	 78399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66955	 78400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66955	 78400	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66956	 66957	 0.004157	 0.008536	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66956	 66971	 0.003614	 0.012343	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78399	 66956	 0.007714	 0.014343	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78400	 66956	 0.001657	 0.008914	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66957	 66958	 0.003671	 0.007543	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66958	 66959	 0.001843	 0.006293	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66958	 66969	 0.0029	 0.009664	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66959	 66960	 0.002	 0.005879	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66959	 66961	 0.022193	 0.015721	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78398	 66961	 0.003114	 0.013879	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66961	 78401	 0.002243	 0.007671	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66962	 66968	 0.000207	 0.001479	 0.00041	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66962	 78401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66962	 78401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66963	 67034	 0.001136	 0.005179	 0.00164	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66963	 67056	 0.001364	 0.007364	 0.00202	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66964	 66965	 0.008986	 0.006364	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66965	 67058	 0.002643	 0.006036	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66965	 78402	 0.003207	 0.008493	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66966	 66967	 0.000379	 0.002321	 0.00067	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66966	 67056	 0.002421	 0.007886	 0.00209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	66966	 67064	 0.0024	 0.011	 0.00282	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66966	 78402	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66966	 78402	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66967	 66968	 0.000279	 0.001757	 0.00048	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66968	 78403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66968	 78403	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66969	 66970	 0.009993	 0.007079	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66969	 66976	 0.002357	 0.007243	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78403	 66970	 0.024793	 0.017564	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66971	 66974	 0.003571	 0.013893	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78399	 66972	 0.008257	 0.028207	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66972	 78404	 0.004271	 0.019043	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66973	 67061	 0.001714	 0.007086	 0.00168	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66973	 67064	 0.002171	 0.010279	 0.00247	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66973	 78404	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66973	 78404	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66974	 66975	 0.006229	 0.004029	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66974	 66977	 0.004357	 0.008921	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78404	 66974	 0.003143	 0.0156	 0.00037	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66976	 66977	 0.001879	 0.005771	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66977	 67059	 0.005364	 0.018314	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78402	 66977	 0.00565	 0.009021	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66978	 67021	 0.001164	 0.006579	 0.00163	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	66978	 78405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66978	 78405	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66979	 66980	 0.008229	 0.005829	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66980	 67504	 0.005229	 0.008386	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66980	 78406	 0.008186	 0.008043	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66981	 67435	 0.008036	 0.037464	 0.00928	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	66981	 67494	 0.000607	 0.00845	 0.00286	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66981	 67505	 0.000457	 0.0023	 0.00064	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66981	 78406	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66981	 78406	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78406	 66982	 0.005264	 0.007886	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66983	 66984	 0.010143	 0.008029	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66984	 66987	 0.003057	 0.007014	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78406	 66984	 0.004557	 0.013986	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66985	 66986	 0.003136	 0.006421	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66985	 66989	 0.004164	 0.009443	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66986	 66987	 0.004093	 0.008414	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66986	 66988	 0.003221	 0.009471	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66986	 67508	 0.002143	 0.013179	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66988	 66991	 0.002179	 0.0072	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	66989	 66990	 0.00365	 0.008286	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66990	 66999	 0.003314	 0.007521	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	66991	 66998	 0.002686	 0.007714	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66992	 66993	 0.014657	 0.0116	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66993	 66996	 0.001907	 0.005864	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66993	 78408	 0.004136	 0.014486	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	66994	 78407	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78408	 66994	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66994	 78513	 0.000493	 0.00735	 0.02725	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78408	 66995	 0.014357	 0.011364	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78408	 66995	 0.014357	 0.011364	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	66996	 66997	 0.003979	 0.0074	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66996	 67005	 0.003614	 0.006714	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66997	 66998	 0.003357	 0.00625	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	66999	 67000	 0.00255	 0.006557	 0.0001	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67000	 67001	 0.011479	 0.009079	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67002	 67011	 0.000736	 0.003421	 8e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67002	 67012	 0.001864	 0.008257	 0.00025	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67004	 67005	 0.011836	 0.008557	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67005	 67006	 0.001029	 0.005521	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67005	 67007	 0.001607	 0.007107	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78408	 67006	 0.001079	 0.005807	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67007	 67008	 0.002257	 0.006636	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67007	 67017	 0.003164	 0.006479	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67008	 67016	 0.003236	 0.0074	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67009	 67010	 0.001271	 0.006114	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78408	 67009	 0.002986	 0.021486	 0.00071	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67010	 67011	 0.000957	 0.004671	 8e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67010	 67015	 0.006971	 0.004514	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67012	 67013	 0.002721	 0.009093	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67014	 67016	 0.00265	 0.006014	 0.00012	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67018	 67019	 0.007136	 0.005057	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67019	 78409	 0.002771	 0.004879	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67020	 67021	 0.000429	 0.003143	 0.00081	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78407	 67020	 0.000821	 0.006986	 0.00174	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67020	 78409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67020	 78409	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78407	 67021	 0.001193	 0.009757	 0.00265	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67021	 78410	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67021	 78410	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67022	 67023	 0.005529	 0.012536	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67024	 67032	 0.006643	 0.0047	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78397	 67024	 0.002957	 0.009079	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78398	 67024	 0.004914	 0.016793	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67024	 78411	 0.010064	 0.01075	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67025	 67031	 0.011786	 0.008343	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67025	 67036	 0.003407	 0.013321	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78397	 67025	 0.0143	 0.018607	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67026	 67029	 0.0027	 0.009014	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78396	 67026	 0.005214	 0.019979	 0.00056	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67027	 67028	 0.009007	 0.005829	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67028	 67038	 0.002436	 0.0108	 0.00032	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67029	 67030	 0.002957	 0.007836	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67030	 78412	 0.002343	 0.009107	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67033	 67035	 0.000771	 0.003864	 0.00101	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67033	 67037	 0.00085	 0.004443	 0.00107	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67033	 78411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67033	 78411	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67034	 67035	 0.0004	 0.002064	 0.00051	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67034	 67037	 0.001793	 0.009279	 0.00226	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67034	 67056	 0.002821	 0.011293	 0.00381	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78411	 67036	 0.001964	 0.00995	 0.00017	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67036	 78412	 0.002821	 0.005779	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67037	 78412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67037	 78412	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78412	 67038	 0.001929	 0.009	 0.00021	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67039	 79518	 0.024757	 0.0728	 0.00149	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67040	 67042	 0.018657	 0.038336	 0.00073	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67040	 78460	 0.026871	 0.068071	 0.00135	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67041	 67417	 0.01105	 0.062807	 0.00114	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78404	 67041	 0.010071	 0.039957	 0.00114	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67042	 67043	 0.005864	 0.015543	 0.00039	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67042	 67048	 0.011386	 0.021171	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67043	 67044	 0.004136	 0.010964	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67044	 78414	 0.007021	 0.020636	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67045	 67046	 0.002357	 0.00825	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67045	 67074	 0.011879	 0.013929	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67045	 78414	 0.003771	 0.016721	 0.0005	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67046	 67049	 0.002807	 0.011993	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67047	 67049	 0.012657	 0.008964	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67048	 67050	 0.006214	 0.012771	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67048	 67078	 0.028043	 0.019864	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67049	 67050	 0.003864	 0.006164	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67049	 78419	 0.027507	 0.044121	 0.00081	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67050	 67051	 0.004029	 0.009214	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67050	 67052	 0.009357	 0.009193	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67051	 67079	 0.004621	 0.007379	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67052	 67081	 0.015257	 0.010807	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67053	 67054	 0.007657	 0.008971	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67053	 67060	 0.003143	 0.008336	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78404	 67053	 0.005679	 0.014386	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67054	 67055	 0.004686	 0.009279	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78402	 67055	 0.00315	 0.0105	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67056	 78413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67056	 78413	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67056	 78423	 0.003036	 0.027536	 0.00897	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67057	 67059	 0.0064	 0.011257	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78413	 67058	 0.007871	 0.014636	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67059	 67060	 0.005371	 0.011293	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67059	 67065	 0.002143	 0.009979	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78413	 67059	 0.016193	 0.028486	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67061	 67064	 0.001164	 0.004236	 0.0013	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67061	 78414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67061	 78414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78414	 67062	 0.005093	 0.009464	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67062	 78416	 0.003586	 0.008329	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67063	 67064	 0.000364	 0.002371	 0.0006	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67063	 67071	 0.001264	 0.00565	 0.00154	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67063	 67072	 0.000729	 0.002543	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67063	 78415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67063	 78415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67064	 67072	 0.0009	 0.004657	 0.00114	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67064	 78416	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67064	 78416	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78416	 67065	 0.001707	 0.007543	 0.00017	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67066	 67067	 0.01005	 0.009871	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67066	 67070	 0.007086	 0.018207	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78413	 67066	 0.005907	 0.026171	 0.00079	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78415	 67066	 0.006521	 0.012907	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78416	 67066	 0.004979	 0.01155	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67068	 67069	 0.004686	 0.010721	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78413	 67068	 0.009264	 0.027257	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67069	 67070	 0.0041	 0.009307	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67070	 67086	 0.003471	 0.012164	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67071	 67072	 0.000614	 0.003114	 0.00113	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67071	 67093	 0.002143	 0.013064	 0.00329	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67071	 67098	 0.00195	 0.007936	 0.00194	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67071	 78417	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67071	 78417	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67073	 67074	 0.011886	 0.009314	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78417	 67074	 0.004236	 0.005779	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67075	 67092	 0.019993	 0.014164	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67075	 67110	 0.021679	 0.017843	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67075	 78419	 0.023329	 0.021043	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67076	 67118	 0.014221	 0.036036	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67076	 67191	 0.016586	 0.042007	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67077	 78429	 0.03235	 0.022914	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67079	 67091	 0.007414	 0.010121	 0.00018	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67080	 67081	 0.003021	 0.011621	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67080	 67090	 0.012721	 0.01285	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67080	 78419	 0.009486	 0.017636	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67081	 67082	 0.0023	 0.008064	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67082	 67083	 0.002314	 0.007893	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78417	 67083	 0.002357	 0.007236	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78417	 67084	 0.001679	 0.00745	 0.00022	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67084	 78418	 0.002143	 0.008936	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67085	 67088	 0.01445	 0.011436	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67086	 67087	 0.002436	 0.009486	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67087	 67088	 0.004543	 0.013029	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67088	 78418	 0.012014	 0.009886	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67088	 78420	 0.007986	 0.016407	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67089	 67098	 0.000707	 0.002393	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67089	 78418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67089	 78418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67090	 67097	 0.009329	 0.013979	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67091	 78419	 0.008864	 0.012921	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67093	 67109	 0.0011	 0.004279	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67093	 78419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67093	 78419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67093	 78423	 0.004436	 0.016871	 0.00472	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67094	 67095	 0.006636	 0.007779	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78419	 67094	 0.009893	 0.009993	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67095	 78421	 0.006943	 0.012914	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67096	 78420	 0.012057	 0.008543	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67097	 78421	 0.008064	 0.008614	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67098	 67099	 0.001036	 0.004221	 0.00103	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67098	 78420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67098	 78420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67099	 78421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67099	 78421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67100	 73940	 0.0003	 0.004157	 0.35969	 2385.0	 2504.25	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67100	 78422	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67101	 67103	 0.002421	 0.008279	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67101	 67116	 0.003786	 0.010736	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78424	 67101	 0.009971	 0.028593	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78421	 67102	 0.008386	 0.009829	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67103	 67104	 0.003957	 0.00735	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78421	 67103	 0.002221	 0.011943	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67104	 67105	 0.00335	 0.006879	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67105	 78426	 0.005164	 0.009079	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67106	 67113	 0.007029	 0.010543	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67106	 78425	 0.003857	 0.006786	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67107	 67108	 0.000329	 0.001193	 0.00036	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67107	 67115	 0.000793	 0.003171	 0.0008	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67108	 67109	 0.000429	 0.001736	 0.00042	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67108	 78425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67108	 78425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67109	 78426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67109	 78426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78426	 67110	 0.007293	 0.006579	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67111	 67112	 0.01345	 0.009529	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67112	 78428	 0.008993	 0.015814	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67113	 67117	 0.007336	 0.009107	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67113	 78429	 0.008086	 0.016007	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67114	 67120	 0.00015	 0.001757	 0.00392	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78422	 67114	 0.000421	 0.00515	 0.01057	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67114	 78427	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78428	 67114	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78427	 67115	 0.000821	 0.003386	 0.0008	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67115	 78429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67115	 78429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67116	 67117	 0.004343	 0.01245	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67117	 78433	 0.010186	 0.018943	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67118	 78434	 0.013971	 0.031943	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67119	 67135	 0.022529	 0.03795	 0.00054	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67119	 78431	 0.00545	 0.014443	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67120	 67139	 0.001971	 0.012786	 0.02547	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67120	 67156	 0.001614	 0.011314	 0.01927	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67120	 78430	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78431	 67120	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67121	 67126	 0.000886	 0.00355	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67121	 67140	 0.001414	 0.006143	 0.00175	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 67121	 0.002736	 0.013021	 0.00309	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67121	 78432	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67121	 78432	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78432	 67122	 0.015543	 0.010064	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67123	 67141	 0.001636	 0.0093	 0.00017	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78432	 67123	 0.001264	 0.006271	 0.00015	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67124	 67137	 0.005643	 0.010486	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78431	 67124	 0.003764	 0.009979	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67125	 67131	 0.018693	 0.014793	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78431	 67125	 0.0067	 0.019021	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67125	 78434	 0.009029	 0.013536	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67125	 78436	 0.02845	 0.02015	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 67126	 0.0016	 0.009393	 0.00256	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67126	 78433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67126	 78433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78432	 67127	 0.014271	 0.010114	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78428	 67128	 0.008336	 0.017521	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78433	 67128	 0.00415	 0.009493	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78432	 67129	 0.018757	 0.012143	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67130	 67133	 0.002593	 0.006243	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78430	 67130	 0.002607	 0.007693	 0.00179	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67130	 78434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67130	 78434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67131	 67134	 0.024371	 0.015779	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67132	 78435	 0.036729	 0.029071	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67133	 67150	 0.00195	 0.005229	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67133	 78435	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67133	 78435	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78435	 67134	 0.019771	 0.0128	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67135	 78441	 0.020143	 0.014264	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67136	 67142	 0.001243	 0.003129	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67136	 67144	 0.000979	 0.003193	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67136	 67145	 0.001793	 0.0056	 0.00162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78430	 67136	 0.002371	 0.007729	 0.00205	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67136	 78436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67136	 78436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78436	 67137	 0.005443	 0.009579	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78432	 67138	 0.004193	 0.016386	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67138	 78439	 0.004379	 0.017043	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67139	 73924	 0.000886	 0.0059	 0.01112	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67139	 74029	 0.001743	 0.011021	 0.02309	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67139	 78437	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78438	 67139	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67140	 67142	 0.000693	 0.002714	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67140	 67160	 0.005386	 0.017964	 0.00456	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67140	 78439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67140	 78439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78439	 67141	 0.002236	 0.0111	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67142	 67176	 0.001336	 0.004757	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67142	 78440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67142	 78440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78436	 67143	 0.028221	 0.019993	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78440	 67143	 0.010121	 0.00655	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67144	 67145	 0.001093	 0.002843	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67144	 67146	 0.002014	 0.005236	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67145	 67146	 0.000721	 0.002471	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67145	 78441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67145	 78441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67146	 67159	 0.004121	 0.010886	 0.00255	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67146	 67162	 0.000807	 0.001879	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67146	 78442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67146	 78442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67147	 67149	 0.015729	 0.01245	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78442	 67147	 0.027443	 0.019443	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67148	 67152	 0.006364	 0.009543	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67148	 67158	 0.014021	 0.0111	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67148	 78444	 0.006707	 0.011793	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67149	 67153	 0.012993	 0.009207	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78431	 67149	 0.030157	 0.061714	 0.00152	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67149	 78446	 0.060957	 0.043179	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67149	 78448	 0.034779	 0.022514	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67149	 78449	 0.022514	 0.01595	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67150	 67151	 0.001557	 0.004186	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67150	 78443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67150	 78443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67151	 67155	 0.000843	 0.003364	 0.00085	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67151	 67160	 0.002079	 0.006771	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67151	 78444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67151	 78444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67152	 67153	 0.009614	 0.006221	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67152	 78448	 0.016479	 0.010671	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67154	 67155	 0.000807	 0.004421	 0.00117	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67154	 67197	 0.0056	 0.028314	 0.00789	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67155	 78445	 0.001279	 0.004164	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67156	 67170	 0.0002	 0.001279	 0.00255	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67156	 78445	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78446	 67156	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67157	 67159	 0.00115	 0.003036	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67157	 67166	 0.001364	 0.003664	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67157	 67167	 0.001221	 0.003143	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67157	 78447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67157	 78447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78444	 67158	 0.010257	 0.0203	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78446	 67158	 0.007186	 0.014771	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78447	 67158	 0.001821	 0.008079	 0.00019	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67159	 67160	 0.001336	 0.003107	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67159	 78448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67159	 78448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67160	 67161	 0.001221	 0.003064	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67160	 67183	 0.002371	 0.008121	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67160	 78449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67160	 78449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67161	 67162	 0.000771	 0.002014	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67163	 78458	 0.019364	 0.013721	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78449	 67164	 0.014707	 0.010421	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78438	 67165	 0.018321	 0.029243	 0.00067	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78448	 67165	 0.005214	 0.011921	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67166	 67167	 0.000814	 0.001971	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67166	 78450	 0.002486	 0.006443	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78437	 67167	 0.002921	 0.0082	 0.00211	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67168	 67171	 0.000236	 0.001536	 0.00306	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67168	 67174	 0.000264	 0.001786	 0.00329	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67168	 78450	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67168	 78450	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67169	 78451	 0.031293	 0.020257	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67170	 67171	 0.000164	 0.001057	 0.00211	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67170	 78451	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67170	 78451	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67172	 78453	 0.033914	 0.021957	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67173	 67174	 0.000336	 0.002171	 0.00433	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67173	 78452	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78453	 67173	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67174	 78454	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78455	 67174	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78453	 67175	 0.021736	 0.0172	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78455	 67175	 0.005864	 0.008786	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67176	 67181	 0.001564	 0.004886	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67176	 78456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67176	 78456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67177	 67178	 0.0135	 0.012179	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78456	 67177	 0.005079	 0.013057	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67179	 78458	 0.008107	 0.027693	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67179	 79682	 0.049729	 0.115464	 0.00171	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67180	 78457	 0.010714	 0.007586	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67181	 67182	 0.001143	 0.0033	 0.0008	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67181	 78457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67181	 78457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67182	 67183	 0.002007	 0.005393	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78430	 67182	 0.006536	 0.022786	 0.00529	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67182	 78458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67182	 78458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78437	 67183	 0.003964	 0.010479	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67184	 67185	 0.015536	 0.018214	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67185	 67450	 0.017157	 0.027529	 0.00051	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67185	 78459	 0.01035	 0.023479	 0.00047	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67185	 78464	 0.022843	 0.046943	 0.00089	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67186	 78459	 0.019229	 0.01245	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67187	 67188	 0.001	 0.003429	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67187	 67193	 0.001371	 0.0065	 0.00156	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67187	 67201	 0.001893	 0.007186	 0.00201	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78184	 67187	 0.008821	 0.052057	 0.04243	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67187	 78459	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67187	 78459	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67188	 78460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67188	 78460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78460	 67189	 0.015421	 0.009986	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78460	 67190	 0.0452	 0.029264	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67191	 78461	 0.011064	 0.037786	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67192	 67196	 0.016779	 0.01315	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67192	 78461	 0.012257	 0.020093	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67193	 67201	 0.001064	 0.004257	 0.00107	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67193	 67329	 0.017757	 0.092129	 0.02251	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78445	 67193	 0.008671	 0.041329	 0.01198	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67193	 78461	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67193	 78461	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67194	 67195	 0.001086	 0.002514	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67194	 67197	 0.001693	 0.006786	 0.00171	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67194	 67201	 0.0009	 0.0036	 0.00091	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67195	 67197	 0.001093	 0.00455	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67195	 67201	 0.001593	 0.006364	 0.00161	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67197	 78462	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67197	 78462	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67198	 73473	 0.146979	 0.302264	 0.00576	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67198	 73918	 0.03665	 0.107786	 0.00221	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78446	 67198	 0.1768	 0.114493	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78461	 67198	 0.044007	 0.150343	 0.00327	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67199	 67200	 0.014471	 0.029736	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67199	 67204	 0.017114	 0.017286	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78462	 67199	 0.009186	 0.018871	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67200	 67224	 0.006286	 0.021471	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67201	 78463	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67201	 78463	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67202	 67203	 0.005929	 0.019786	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67202	 67205	 0.001993	 0.007629	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78463	 67202	 0.014714	 0.0236	 0.00044	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67203	 67204	 0.007736	 0.017964	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67205	 67206	 0.00335	 0.016614	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67206	 78464	 0.00285	 0.012643	 0.00038	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67207	 67211	 0.003714	 0.014121	 0.00395	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67207	 67423	 0.010829	 0.037736	 0.00875	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67207	 78464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67207	 78464	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78168	 67208	 0.004514	 0.023907	 0.00798	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67209	 67225	 0.019079	 0.01235	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78169	 67210	 0.01645	 0.063021	 0.00178	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67210	 78465	 0.022436	 0.032693	 0.00074	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67210	 78466	 0.005507	 0.015786	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67211	 67445	 0.0065	 0.026029	 0.00656	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67211	 78465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67211	 78465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67212	 67222	 0.022207	 0.039921	 0.00071	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67213	 67214	 0.002693	 0.014407	 0.00044	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67213	 67217	 0.007857	 0.014607	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78465	 67213	 0.00725	 0.032129	 0.00096	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67214	 67215	 0.00115	 0.007093	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67215	 67222	 0.002693	 0.013371	 0.00032	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67216	 67221	 0.005507	 0.021414	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67216	 78466	 0.006057	 0.0212	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67217	 78466	 0.008229	 0.018657	 0.00037	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67218	 78466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67218	 78466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67219	 67220	 0.011414	 0.008086	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78169	 67219	 0.014729	 0.068671	 0.00158	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78466	 67219	 0.003521	 0.009336	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67221	 67222	 0.004114	 0.010907	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67222	 67223	 0.015829	 0.011214	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67222	 67225	 0.004136	 0.012693	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78463	 67222	 0.057564	 0.101236	 0.0019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67224	 67225	 0.00285	 0.009743	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67226	 73208	 0.002643	 0.011764	 0.0032	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67227	 78467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67227	 78467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78263	 67228	 0.00675	 0.004371	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67229	 67523	 0.028286	 0.10005	 0.02257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67229	 67526	 0.021936	 0.075279	 0.01804	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67229	 70536	 0.041743	 0.162786	 0.04362	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67229	 78468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67229	 78468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67230	 67549	 0.056921	 0.144207	 0.00286	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67232	 67237	 0.18305	 0.118543	 0.00226	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67233	 67234	 0.02265	 0.09685	 0.00219	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67233	 67531	 0.026829	 0.142971	 0.00251	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67234	 67235	 0.027021	 0.0618	 0.00151	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78364	 67234	 0.1367	 0.246743	 0.00357	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67236	 67237	 0.021943	 0.085707	 0.0019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67236	 67237	 0.021943	 0.085707	 0.0019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78364	 67236	 0.030593	 0.119493	 0.00265	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78364	 67236	 0.030593	 0.119493	 0.00265	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78364	 67238	 0.098436	 0.063729	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67239	 67240	 0.003079	 0.009443	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67239	 67253	 0.003221	 0.008529	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67240	 67241	 0.004136	 0.016079	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67241	 67243	 0.003329	 0.012986	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67241	 67243	 0.003329	 0.012986	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67241	 78469	 0.0061	 0.021357	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67242	 67244	 0.018614	 0.01205	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67243	 67244	 0.003857	 0.015064	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67243	 67244	 0.003857	 0.015064	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67244	 67246	 0.004643	 0.016243	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67244	 67246	 0.004643	 0.016243	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67244	 78469	 0.010379	 0.036329	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67244	 78469	 0.010379	 0.036329	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67245	 67246	 0.005486	 0.021429	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67245	 67246	 0.005486	 0.021429	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67245	 67261	 0.01445	 0.056443	 0.00125	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67245	 67261	 0.01445	 0.056443	 0.00125	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67246	 67247	 0.022057	 0.021664	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67248	 67251	 0.003507	 0.007214	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67248	 67258	 0.011964	 0.019093	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67249	 67251	 0.016686	 0.011821	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67250	 67251	 0.003043	 0.005657	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67250	 78469	 0.003857	 0.009993	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67252	 67255	 0.003521	 0.009114	 0.00276	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67252	 78469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67252	 78469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67253	 67256	 0.006036	 0.013807	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67254	 78470	 0.046029	 0.0298	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67255	 67260	 0.0011	 0.003779	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67255	 67272	 0.0071	 0.047636	 0.0115	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78352	 67255	 0.007764	 0.080707	 0.02498	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67255	 78470	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67255	 78470	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78470	 67256	 0.00875	 0.020014	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67257	 78471	 0.023657	 0.023893	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67258	 78471	 0.018643	 0.029757	 0.00069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67259	 67262	 0.033064	 0.129143	 0.00286	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67259	 67262	 0.033064	 0.129143	 0.00286	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67259	 78471	 0.007114	 0.031693	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67259	 78471	 0.007114	 0.031693	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67260	 78471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67260	 78471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67261	 67764	 0.032407	 0.126571	 0.00281	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67261	 67764	 0.032407	 0.126571	 0.00281	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67261	 74580	 0.081014	 0.283879	 0.00786	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67261	 74580	 0.081014	 0.283879	 0.00786	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78470	 67261	 0.043471	 0.152221	 0.00421	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78470	 67261	 0.043471	 0.152221	 0.00421	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67262	 67288	 0.029043	 0.144136	 0.00344	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67262	 67765	 0.024179	 0.146421	 0.00459	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78352	 67263	 0.00595	 0.056	 0.01697	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67263	 78472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67263	 78472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67264	 67265	 0.031364	 0.022214	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67265	 67270	 0.019893	 0.061029	 0.00165	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78472	 67265	 0.022329	 0.085557	 0.00242	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78231	 67266	 0.325071	 0.23045	 0.00364	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67267	 67268	 0.045536	 0.032257	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67267	 67270	 0.020471	 0.030686	 0.00056	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67269	 67270	 0.060079	 0.038893	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78265	 67270	 0.079507	 0.157436	 0.00231	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78472	 67270	 0.037421	 0.149771	 0.00316	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67270	 78473	 0.0133	 0.079693	 0.00191	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78470	 67271	 0.018543	 0.114021	 0.00206	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67271	 78473	 0.015071	 0.058871	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67272	 67274	 0.002643	 0.02195	 0.00859	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67272	 78473	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67272	 78473	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78265	 67273	 0.016907	 0.0908	 0.00216	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78338	 67273	 0.025643	 0.12725	 0.00304	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78232	 67274	 0.001729	 0.017179	 0.00467	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67275	 67276	 0.054571	 0.035329	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67276	 67282	 0.012414	 0.0483	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78233	 67276	 0.006414	 0.025664	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67277	 67280	 0.000929	 0.007214	 0.00187	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67277	 67281	 0.001164	 0.0116	 0.00431	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78232	 67277	 0.001186	 0.009257	 0.00276	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78352	 67277	 0.006493	 0.077186	 0.02691	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67278	 78474	 0.009193	 0.02085	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67278	 78475	 0.0178	 0.028414	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67279	 67289	 0.018357	 0.037721	 0.00072	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67279	 78475	 0.011743	 0.041129	 0.00114	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67280	 67281	 0.000493	 0.00635	 0.00189	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78232	 67280	 0.002793	 0.016643	 0.00438	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67280	 78474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67280	 78474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67281	 74565	 0.008479	 0.070386	 0.01853	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67281	 74901	 0.008271	 0.062329	 0.0173	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67281	 78475	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67281	 78475	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78475	 67282	 0.0145	 0.04265	 0.00087	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67283	 67284	 0.010121	 0.038793	 0.0011	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78475	 67283	 0.010107	 0.044771	 0.00134	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67284	 74564	 0.0381	 0.148836	 0.0033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67285	 67287	 0.083	 0.127164	 0.00179	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78475	 67285	 0.02835	 0.12565	 0.00377	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67285	 79777	 0.017771	 0.0853	 0.00255	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67286	 67287	 0.01175	 0.052079	 0.00156	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67286	 67288	 0.0137	 0.065771	 0.00196	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67287	 67304	 0.038721	 0.118814	 0.00322	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67287	 74566	 0.186021	 0.145843	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67287	 79777	 0.019971	 0.107279	 0.00255	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78470	 67289	 0.028807	 0.239721	 0.00454	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67290	 74456	 0.029164	 0.176607	 0.00553	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67290	 78476	 0.016843	 0.108664	 0.00346	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67291	 70460	 0.085443	 0.226836	 0.05338	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67291	 78476	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67291	 78476	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67291	 79362	 0.060871	 0.183921	 0.05781	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67292	 67295	 0.071343	 0.146636	 0.0028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78229	 67292	 0.015929	 0.07055	 0.00161	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78476	 67292	 0.035743	 0.090536	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67293	 67294	 0.055321	 0.102871	 0.00241	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67293	 73431	 0.039786	 0.194193	 0.00335	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78476	 67294	 0.07375	 0.189629	 0.00294	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78364	 67295	 0.056779	 0.105586	 0.00247	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67297	 67298	 0.098207	 0.063586	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78229	 67297	 0.085193	 0.067421	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67300	 74888	 0.043929	 0.218036	 0.0052	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67301	 67304	 0.042314	 0.124443	 0.00255	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67302	 68016	 0.050471	 0.19345	 0.00547	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78200	 67302	 0.088114	 0.392979	 0.00668	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78200	 67302	 0.088114	 0.392979	 0.00668	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67303	 68014	 0.097486	 0.325393	 0.00516	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78200	 67303	 0.032307	 0.099121	 0.00269	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67303	 78553	 0.056579	 0.321807	 0.00583	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67305	 67309	 0.019079	 0.056114	 0.00115	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67305	 79377	 0.026464	 0.07015	 0.00178	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67306	 67307	 0.006286	 0.012857	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67306	 67311	 0.019593	 0.016129	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67307	 67308	 0.039814	 0.025779	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67307	 67309	 0.014236	 0.04285	 0.00084	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78185	 67307	 0.011643	 0.034229	 0.0007	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67310	 67312	 0.009807	 0.038164	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67310	 67443	 0.011557	 0.016843	 0.00038	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67310	 78479	 0.012636	 0.033493	 0.00085	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67312	 67315	 0.007371	 0.016721	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67313	 67318	 0.030679	 0.047	 0.00066	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67313	 67320	 0.043471	 0.088957	 0.00219	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67313	 67323	 0.023771	 0.044207	 0.00104	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78185	 67313	 0.036986	 0.108779	 0.00223	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67314	 67325	 0.004457	 0.01785	 0.0045	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67314	 67445	 0.008514	 0.034079	 0.00859	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78184	 67314	 0.004529	 0.020786	 0.00533	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67314	 78477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67314	 78477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67315	 67316	 0.016479	 0.014764	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67315	 67317	 0.00625	 0.012793	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78477	 67316	 0.012957	 0.025657	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67317	 67318	 0.008336	 0.017057	 0.00042	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67318	 67319	 0.054614	 0.035357	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67321	 67322	 0.032214	 0.022821	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67321	 67323	 0.023193	 0.040786	 0.00076	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67321	 79535	 0.03445	 0.114936	 0.00182	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67324	 67329	 0.001171	 0.005371	 0.00138	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78182	 67324	 0.000471	 0.002743	 0.00064	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78184	 67324	 0.004114	 0.016479	 0.00415	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78188	 67324	 0.002171	 0.010264	 0.00247	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67324	 78478	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67324	 78478	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67325	 67327	 0.00135	 0.004714	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78184	 67325	 0.0006	 0.003614	 0.00092	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67325	 78479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67325	 78479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67326	 67327	 0.000793	 0.002879	 0.00088	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67326	 67329	 0.001157	 0.003607	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67327	 67329	 0.0021	 0.007014	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78161	 67327	 0.000314	 0.003493	 0.00233	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67327	 78480	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67327	 78480	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67328	 78481	 0.022457	 0.015907	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67329	 78481	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67329	 78481	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78183	 67330	 0.023836	 0.018679	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78478	 67331	 0.004986	 0.010207	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78481	 67331	 0.004514	 0.009229	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67332	 67333	 0.019229	 0.013621	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78481	 67332	 0.01665	 0.0137	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78183	 67333	 0.015129	 0.029957	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67334	 67442	 0.025507	 0.020186	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78327	 67334	 0.010186	 0.023107	 0.00046	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67335	 67444	 0.005564	 0.011386	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78479	 67335	 0.007664	 0.015679	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78188	 67336	 0.000307	 0.001921	 0.00054	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78170	 67337	 0.0001	 0.000971	 0.00339	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67337	 78482	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78483	 67337	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67337	 78490	 0.000929	 0.010807	 0.02239	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67338	 67343	 0.001493	 0.005986	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78188	 67338	 0.0013	 0.005407	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78482	 67338	 0.000371	 0.00135	 0.00041	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67338	 78484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67338	 78484	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78189	 67339	 0.006693	 0.015179	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78478	 67339	 0.014729	 0.030264	 0.00058	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67340	 67341	 0.008886	 0.015971	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67340	 67342	 0.042343	 0.029993	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78189	 67340	 0.007021	 0.027321	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67343	 67344	 0.001486	 0.006129	 0.00145	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67343	 78485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67343	 78485	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67344	 67377	 0.00445	 0.014514	 0.00385	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67344	 67454	 0.002729	 0.010914	 0.00275	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67344	 78486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67344	 78486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78485	 67345	 0.002579	 0.006843	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67345	 78487	 0.005007	 0.016714	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78484	 67346	 0.014179	 0.009179	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67347	 67349	 0.001614	 0.006286	 0.00168	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78171	 67347	 0.000843	 0.005357	 0.00145	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67347	 78487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67347	 78487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78487	 67348	 0.013679	 0.024057	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67348	 78488	 0.02115	 0.013693	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67348	 78489	 0.034614	 0.024521	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67349	 67377	 0.004464	 0.017857	 0.0045	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78171	 67349	 0.00235	 0.010729	 0.0034	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67349	 78488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67349	 78488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67349	 78498	 0.005007	 0.024729	 0.00722	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78171	 67350	 0.005179	 0.017264	 0.00438	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67350	 78489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67350	 78489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67351	 67492	 0.000329	 0.004521	 0.39102	 2385.0	 2504.25	 2623.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67351	 78490	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78491	 67351	 0.000197	 0.015726	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 0	 -30.0	 30.0;
	67352	 67354	 0.001214	 0.004943	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67352	 67356	 0.00175	 0.009114	 0.00239	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67352	 74290	 0.001764	 0.011814	 0.00362	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67352	 78492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67352	 78492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78343	 67353	 0.003893	 0.012979	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78492	 67353	 0.002871	 0.0098	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67354	 67458	 0.002	 0.011086	 0.00337	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67354	 78493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67354	 78493	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67355	 67357	 0.004964	 0.011357	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78343	 67355	 0.004207	 0.014357	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67356	 67358	 0.0012	 0.006893	 0.00195	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67357	 67359	 0.004321	 0.009886	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67358	 67362	 0.000886	 0.005071	 0.00169	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67358	 78494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67358	 78494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67359	 67361	 0.003686	 0.016336	 0.00049	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78343	 67359	 0.008257	 0.0282	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78494	 67359	 0.01215	 0.024964	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67360	 67361	 0.005507	 0.014607	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67360	 78495	 0.006229	 0.018314	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67361	 67424	 0.006543	 0.031414	 0.00094	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67362	 67363	 0.000886	 0.004893	 0.00176	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67362	 78495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67362	 78495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67362	 78498	 0.000557	 0.003579	 0.00121	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67363	 67367	 0.001236	 0.00685	 0.00208	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67363	 78496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67363	 78496	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78496	 67364	 0.019371	 0.013721	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67365	 67366	 0.002836	 0.012564	 0.00029	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67365	 78504	 0.007407	 0.018771	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67366	 67386	 0.002257	 0.012136	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67367	 67399	 0.000693	 0.003657	 0.00093	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67367	 78497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67367	 78497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78497	 67368	 0.018314	 0.012971	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78490	 67369	 0.000371	 0.004943	 0.01056	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67369	 78498	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78499	 67369	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67369	 79520	 0.004036	 0.033243	 0.06859	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67370	 67377	 0.002971	 0.011893	 0.00299	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78491	 67370	 0.003486	 0.0145	 0.00452	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78498	 67370	 0.000936	 0.003893	 0.00121	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67370	 78500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67370	 78500	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67371	 67372	 0.006271	 0.00855	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78499	 67371	 0.0091	 0.016929	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78499	 67371	 0.0091	 0.016929	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67372	 67374	 0.01565	 0.02565	 0.00045	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67373	 67382	 0.009071	 0.0118	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67373	 78501	 0.016293	 0.024429	 0.00044	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67374	 67378	 0.009507	 0.022079	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67374	 67451	 0.005629	 0.021971	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67375	 67376	 0.017364	 0.011243	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67376	 67452	 0.0151	 0.024093	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67376	 78511	 0.008436	 0.022364	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67377	 67379	 0.001164	 0.003493	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67377	 78501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67377	 78501	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67378	 67387	 0.005986	 0.012307	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78501	 67378	 0.011464	 0.015636	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67378	 78502	 0.005843	 0.013371	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67379	 78502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67379	 78502	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78502	 67380	 0.005686	 0.004029	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67381	 67397	 0.008229	 0.02115	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67381	 67404	 0.006686	 0.026014	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67381	 67430	 0.00335	 0.010271	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67381	 67432	 0.03015	 0.0452	 0.00082	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67382	 67383	 0.013107	 0.012879	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67383	 67384	 0.00095	 0.004636	 8e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78500	 67383	 0.0026	 0.010114	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67384	 67385	 0.012914	 0.00915	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67384	 67386	 0.003914	 0.010371	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67386	 67388	 0.0041	 0.012571	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67386	 67390	 0.0103	 0.0073	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67387	 67388	 0.005543	 0.010307	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78500	 67388	 0.017157	 0.030964	 0.00045	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67389	 67395	 0.004114	 0.018229	 0.00055	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78502	 67389	 0.003964	 0.019021	 0.00057	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67390	 67391	 0.012171	 0.008621	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67392	 67396	 0.014064	 0.02615	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78500	 67392	 0.012571	 0.038564	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67393	 67394	 0.014079	 0.009114	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67394	 67395	 0.005264	 0.020571	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67394	 67403	 0.004664	 0.014307	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67395	 67396	 0.003921	 0.012036	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67395	 67452	 0.021371	 0.039736	 0.00093	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67396	 67404	 0.0057	 0.019964	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67396	 67453	 0.006036	 0.018521	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67396	 78506	 0.012843	 0.056893	 0.00171	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67397	 67401	 0.00275	 0.016643	 0.00052	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67397	 67402	 0.003379	 0.008943	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67397	 78503	 0.0042	 0.01635	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67398	 67399	 0.000979	 0.004657	 0.00135	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67398	 67426	 0.000943	 0.008264	 0.00327	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78498	 67398	 0.001864	 0.020586	 0.00617	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67398	 78503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67398	 78503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67399	 78504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67399	 78504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78503	 67400	 0.013986	 0.019086	 0.00034	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67401	 67429	 0.007593	 0.0156	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67401	 78508	 0.004571	 0.014014	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67402	 67403	 0.00325	 0.011107	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67404	 67419	 0.029486	 0.020886	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67405	 67406	 0.006021	 0.013771	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67405	 67407	 0.0171	 0.011071	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78459	 67405	 0.025393	 0.0304	 0.00051	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67406	 67410	 0.005593	 0.01145	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67408	 67417	 0.01745	 0.035857	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67408	 78505	 0.005221	 0.010679	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67409	 67410	 0.003407	 0.017243	 0.0003	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67409	 67416	 0.003807	 0.021671	 0.00066	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67410	 67411	 0.033043	 0.021393	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67410	 67414	 0.02925	 0.026386	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67410	 67447	 0.031079	 0.049857	 0.00092	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78460	 67410	 0.018879	 0.047814	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67412	 78507	 0.04025	 0.028514	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67413	 67423	 0.002579	 0.007014	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67413	 78505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67413	 78505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67415	 67416	 0.032457	 0.021014	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78503	 67416	 0.055357	 0.126614	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78505	 67416	 0.004264	 0.0189	 0.00056	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67417	 67418	 0.015064	 0.038721	 0.0006	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78503	 67417	 0.042507	 0.097229	 0.00237	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67418	 67428	 0.008864	 0.026071	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67420	 67421	 0.001407	 0.004929	 0.00164	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67420	 67455	 0.003864	 0.015464	 0.00389	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67421	 67423	 0.002271	 0.009457	 0.00221	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67421	 78506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67421	 78506	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78506	 67422	 0.042086	 0.029814	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67423	 78507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67423	 78507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67424	 67425	 0.00585	 0.032893	 0.00061	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67425	 67427	 0.00545	 0.023286	 0.00053	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67426	 67434	 0.001986	 0.0114	 0.00379	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67426	 67503	 0.011136	 0.046307	 0.01081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67426	 78508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67426	 78508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67427	 67437	 0.007914	 0.023271	 0.00048	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78508	 67427	 0.021414	 0.032107	 0.00059	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67428	 67430	 0.003243	 0.009943	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67429	 67431	 0.011936	 0.01905	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78508	 67431	 0.006057	 0.0207	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67431	 78509	 0.004771	 0.025536	 0.00077	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67432	 67433	 0.045364	 0.029371	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67434	 67435	 0.001421	 0.007664	 0.00211	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67434	 78509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67434	 78509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67435	 78510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67435	 78510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67436	 67437	 0.01	 0.025329	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67438	 67439	 0.016593	 0.030857	 0.00072	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78508	 67439	 0.028064	 0.057429	 0.00141	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67440	 67441	 0.06175	 0.043743	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78477	 67441	 0.020507	 0.036064	 0.00068	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67443	 67444	 0.005064	 0.011493	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67446	 67447	 0.003936	 0.018357	 0.00042	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78507	 67446	 0.006729	 0.032307	 0.00096	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67447	 67448	 0.012286	 0.025243	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67447	 67449	 0.0413	 0.026736	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67448	 67450	 0.012886	 0.020564	 0.00047	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78483	 67451	 0.036464	 0.074936	 0.00143	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78489	 67451	 0.021279	 0.043736	 0.00084	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67452	 67453	 0.006043	 0.021164	 0.00059	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78486	 67452	 0.011836	 0.060229	 0.00136	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67454	 67455	 0.00405	 0.016707	 0.00395	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78182	 67454	 0.006664	 0.027693	 0.00646	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67454	 78511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67454	 78511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67456	 78512	 0.00525	 0.020821	 0.00059	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67457	 67464	 0.076864	 0.05445	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67458	 67511	 0.004071	 0.016793	 0.00397	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67458	 78512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67458	 78512	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67460	 67461	 0.002136	 0.009464	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67460	 67473	 0.003	 0.011714	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67461	 78519	 0.00395	 0.027114	 0.00049	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67462	 67463	 0.002657	 0.007807	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67462	 67466	 0.00465	 0.012329	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67463	 78519	 0.003607	 0.012321	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67464	 67466	 0.00485	 0.016971	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67464	 67467	 0.014286	 0.02935	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67464	 67468	 0.004136	 0.018321	 0.00041	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78493	 67464	 0.026893	 0.079093	 0.00162	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67465	 67466	 0.003807	 0.010086	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67467	 67469	 0.0239	 0.015471	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67467	 67472	 0.006986	 0.015971	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67468	 67470	 0.006736	 0.0288	 0.00065	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67470	 78516	 0.007329	 0.028629	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67471	 67484	 0.013236	 0.008564	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67472	 67475	 0.003314	 0.013157	 0.00038	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67472	 78519	 0.010621	 0.044336	 0.00128	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67473	 67475	 0.003836	 0.011757	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67474	 67481	 0.002436	 0.01655	 0.00041	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78272	 67474	 0.007914	 0.030914	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78272	 67474	 0.007914	 0.030914	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67475	 67476	 0.008071	 0.016579	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67475	 67478	 0.005379	 0.011057	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67475	 67510	 0.006621	 0.022093	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67476	 67477	 0.003236	 0.008193	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67477	 67481	 0.0032	 0.008107	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67478	 67479	 0.004707	 0.008464	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67479	 67482	 0.010629	 0.009529	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67480	 67487	 0.010893	 0.007714	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67481	 67487	 0.005407	 0.0137	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67482	 67483	 0.016571	 0.011743	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67482	 67495	 0.013321	 0.024764	 0.00058	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67484	 67485	 0.000764	 0.005514	 0.00014	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67484	 67498	 0.001307	 0.008857	 0.00022	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67485	 67488	 0.002021	 0.007743	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67485	 67495	 0.001993	 0.008821	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67486	 67487	 0.0177	 0.012536	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67487	 67489	 0.002557	 0.007514	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67488	 67489	 0.001521	 0.006743	 0.0002	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67489	 67491	 0.0012	 0.011179	 0.00021	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67490	 67491	 0.008271	 0.0091	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67491	 67493	 0.009136	 0.009229	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78272	 67491	 0.007636	 0.029821	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78272	 67491	 0.007636	 0.029821	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67491	 78515	 0.006314	 0.02465	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67491	 78515	 0.006314	 0.02465	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67492	 73329	 0.000143	 0.002429	 0.18891	 2226.0	 2337.3	 2448.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67492	 78513	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67492	 78513	 0.000107	 0.008588	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67494	 67501	 0.000471	 0.005393	 0.00164	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78514	 67494	 0.001229	 0.016021	 0.00463	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78514	 67494	 0.001229	 0.016021	 0.00463	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78272	 67495	 0.004736	 0.040279	 0.00105	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67496	 67497	 0.0021	 0.011921	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67496	 78516	 0.001529	 0.009379	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67497	 67504	 0.002821	 0.013786	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67498	 67500	 0.001014	 0.006657	 0.00016	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67499	 67500	 0.001571	 0.010007	 0.00024	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67499	 78517	 0.001686	 0.009029	 0.00027	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67501	 67502	 0.000243	 0.002343	 0.00077	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67501	 78516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67501	 78516	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67502	 67503	 0.000193	 0.002207	 0.00067	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67502	 78517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67502	 78517	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67503	 67505	 0.000257	 0.002279	 0.00061	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67503	 78518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67503	 78518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67504	 67507	 0.002979	 0.005536	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78407	 67505	 0.000557	 0.009121	 0.00287	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78518	 67506	 0.013771	 0.008914	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67507	 67508	 0.002671	 0.006207	 0.00012	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67508	 67509	 0.0118	 0.008357	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78518	 67508	 0.003471	 0.012164	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78272	 67510	 0.008943	 0.053564	 0.00129	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67511	 70412	 0.005343	 0.049743	 0.01541	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67511	 78519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67511	 78519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67512	 78520	 0.035471	 0.034843	 0.00059	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67513	 67767	 0.025057	 0.247143	 0.07814	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67513	 67783	 0.0192	 0.201564	 0.06829	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67513	 78520	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67513	 78520	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78520	 67514	 0.043514	 0.034436	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67515	 67516	 0.021921	 0.076743	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67515	 67516	 0.021921	 0.076743	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 67515	 0.016714	 0.065264	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 67515	 0.016714	 0.065264	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75893	 67516	 0.083371	 0.29215	 0.0081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75893	 67516	 0.083371	 0.29215	 0.0081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 67516	 0.027829	 0.097436	 0.0027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 67516	 0.027829	 0.097436	 0.0027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67517	 67518	 0.062871	 0.192943	 0.00523	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67517	 74250	 0.071629	 0.317743	 0.00956	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 67517	 0.025443	 0.2341	 0.00464	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67518	 67780	 0.133843	 0.469621	 0.01304	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67518	 67780	 0.133843	 0.469621	 0.01304	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 67518	 0.069879	 0.311557	 0.00529	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78520	 67518	 0.069879	 0.311557	 0.00529	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67519	 67523	 0.001586	 0.014157	 0.00371	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67519	 78521	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67519	 78521	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67520	 67521	 0.020121	 0.015921	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78521	 67520	 0.029836	 0.023607	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67522	 67560	 0.023114	 0.070914	 0.00192	 88.0	 88.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78521	 67522	 0.010593	 0.032493	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67523	 67526	 0.006407	 0.021579	 0.00536	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67523	 78522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67523	 78522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78522	 67524	 0.03625	 0.025679	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78521	 67525	 0.043421	 0.028114	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67527	 79312	 0.108714	 0.070386	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67528	 71327	 0.156786	 0.129086	 0.00261	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78254	 67529	 0.014243	 0.08755	 0.00158	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67530	 67557	 0.02175	 0.03825	 0.00072	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67530	 71282	 0.030136	 0.068364	 0.00136	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67531	 67558	 0.019636	 0.099343	 0.00173	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67532	 72042	 0.004371	 0.011586	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67532	 72043	 0.004686	 0.020757	 0.00062	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67532	 78523	 0.007521	 0.026329	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67532	 78523	 0.007521	 0.026329	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67533	 78523	 0.032529	 0.025743	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67534	 67539	 0.00085	 0.011143	 0.00317	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67534	 78523	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67534	 78523	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67535	 78526	 0.081929	 0.058036	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67536	 67541	 0.000464	 0.006671	 0.00211	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67536	 67543	 0.000971	 0.014386	 0.00495	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67536	 78524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67536	 78524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67537	 67553	 0.014271	 0.086421	 0.00271	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67537	 67554	 0.1031	 0.081593	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78524	 67537	 0.008543	 0.041007	 0.00123	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67538	 67558	 0.009757	 0.034171	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67538	 67558	 0.009757	 0.034171	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67538	 78525	 0.0049	 0.017143	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67538	 78525	 0.0049	 0.017143	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67539	 67541	 0.0004	 0.002664	 0.00167	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67539	 78525	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67539	 78525	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67540	 78526	 0.034329	 0.024314	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67541	 78526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67541	 78526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67542	 78527	 0.102364	 0.072514	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67543	 67544	 0.002179	 0.013414	 0.00387	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78226	 67543	 0.003229	 0.023421	 0.00809	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67543	 78527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67543	 78527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67544	 71278	 0.022886	 0.069507	 0.01523	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78226	 67544	 0.001471	 0.013136	 0.00345	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78227	 67545	 0.030029	 0.021271	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78227	 67546	 0.028093	 0.0494	 0.00093	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67547	 67550	 0.021336	 0.05655	 0.00144	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67548	 67551	 0.068021	 0.048186	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67548	 67552	 0.013636	 0.047736	 0.00132	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78255	 67548	 0.013164	 0.0725	 0.00164	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67549	 67552	 0.033936	 0.132029	 0.00221	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67550	 67555	 0.022943	 0.0757	 0.00123	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67553	 67555	 0.018186	 0.052164	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78227	 67553	 0.016829	 0.07195	 0.00163	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78521	 67556	 0.031986	 0.023121	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78271	 67557	 0.009279	 0.04605	 0.0011	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78523	 67557	 0.005721	 0.032521	 0.00059	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78523	 67558	 0.005943	 0.0232	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78523	 67558	 0.005943	 0.0232	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67561	 67567	 0.004457	 0.006071	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67562	 67563	 0.005893	 0.010357	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67562	 67567	 0.014079	 0.013829	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67563	 67571	 0.003636	 0.0092	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67564	 67573	 0.00205	 0.005329	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67564	 78528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67564	 78528	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67564	 78530	 0.001586	 0.006357	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67565	 67566	 0.009114	 0.0059	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67566	 67595	 0.006886	 0.015614	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78528	 67566	 0.005864	 0.017257	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67567	 67594	 0.010643	 0.016993	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67567	 67596	 0.020779	 0.022629	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78528	 67567	 0.004586	 0.022357	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67568	 67592	 0.014021	 0.024657	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67569	 67571	 0.017543	 0.02955	 0.00042	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67569	 67591	 0.072764	 0.051543	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67570	 67571	 0.011793	 0.008529	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67570	 67572	 0.02055	 0.014557	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67571	 78529	 0.003679	 0.016307	 0.00049	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67572	 67590	 0.053021	 0.047843	 0.0008	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67573	 67575	 0.0037	 0.009936	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67573	 67748	 0.051686	 0.136829	 0.03209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67573	 78529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67573	 78529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67573	 78530	 0.001357	 0.005436	 0.00137	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67574	 67691	 0.002207	 0.022629	 0.04448	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67574	 78530	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78531	 67574	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67575	 67740	 0.024993	 0.068507	 0.01491	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78530	 67575	 0.000793	 0.004107	 0.00121	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67575	 78532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67575	 78532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67576	 67577	 0.004579	 0.011771	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67576	 67578	 0.0015	 0.007443	 0.00018	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67576	 67600	 0.003679	 0.014143	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67576	 67602	 0.006529	 0.008107	 0.00018	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78528	 67577	 0.003943	 0.012086	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78531	 67577	 0.0022	 0.013171	 0.00031	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78531	 67578	 0.004221	 0.016479	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78532	 67578	 0.025821	 0.025364	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67579	 67580	 0.011386	 0.009007	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67579	 67581	 0.00905	 0.017921	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67579	 67603	 0.014757	 0.027436	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67579	 67604	 0.004407	 0.008721	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78531	 67579	 0.007214	 0.030843	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67581	 67609	 0.011943	 0.011729	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67582	 67586	 0.010193	 0.023129	 0.00046	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78532	 67582	 0.008071	 0.018464	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67583	 67584	 0.035221	 0.0228	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67583	 67608	 0.033036	 0.026143	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67583	 67609	 0.024107	 0.017079	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67584	 67712	 0.042407	 0.033564	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67585	 67586	 0.012136	 0.021343	 0.0004	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67585	 67712	 0.032579	 0.029393	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67587	 78533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67587	 78533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67588	 67720	 0.096329	 0.079293	 0.00161	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78533	 67588	 0.108971	 0.070557	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67589	 67742	 0.037136	 0.106514	 0.00164	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78275	 67589	 0.009007	 0.04325	 0.00129	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78529	 67590	 0.035979	 0.057429	 0.00132	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67590	 78549	 0.086486	 0.156071	 0.00226	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67592	 67593	 0.006971	 0.014321	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67592	 67622	 0.017964	 0.021057	 0.00036	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67592	 67626	 0.020414	 0.018421	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78529	 67592	 0.027886	 0.071686	 0.00111	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67593	 67594	 0.006993	 0.011779	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67593	 67620	 0.015593	 0.013971	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67595	 67619	 0.008136	 0.016714	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67596	 67618	 0.017686	 0.015957	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67597	 67598	 0.008321	 0.00915	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67597	 67603	 0.01705	 0.01675	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67598	 67599	 0.002907	 0.007371	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67598	 67617	 0.007343	 0.015086	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67599	 67600	 0.002479	 0.007286	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67601	 67602	 0.011771	 0.007621	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67603	 67615	 0.01375	 0.012407	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67604	 67605	 0.011743	 0.009293	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67605	 67606	 0.011571	 0.009157	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67606	 67607	 0.011907	 0.008436	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67607	 67608	 0.024036	 0.017029	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67608	 67711	 0.028943	 0.025936	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78531	 67608	 0.027093	 0.069643	 0.00108	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67609	 67610	 0.011764	 0.009307	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67611	 67612	 0.013029	 0.009229	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67611	 67703	 0.004636	 0.008157	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67613	 67677	 0.006429	 0.0155	 0.00438	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78530	 67613	 0.006607	 0.019879	 0.00622	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67613	 78534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67613	 78534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67614	 67615	 0.011643	 0.007536	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67614	 67667	 0.013064	 0.011707	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67616	 67617	 0.003664	 0.007529	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67616	 67666	 0.022514	 0.022743	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67616	 67668	 0.011743	 0.008314	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67618	 67666	 0.023464	 0.015193	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67619	 67620	 0.010143	 0.013843	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67619	 67666	 0.022679	 0.022907	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67621	 67622	 0.012	 0.009493	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67622	 67660	 0.01055	 0.010364	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67622	 67662	 0.015657	 0.015814	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67623	 67627	 0.023729	 0.039979	 0.00057	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67623	 67629	 0.021707	 0.029614	 0.00053	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67623	 67632	 0.075614	 0.13645	 0.00197	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67624	 67629	 0.033143	 0.021457	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67625	 67634	 0.01495	 0.0204	 0.00036	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67626	 67627	 0.017943	 0.014771	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67628	 67629	 0.0248	 0.017571	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67628	 67634	 0.016714	 0.015079	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67630	 67631	 0.008407	 0.03725	 0.00085	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78278	 67630	 0.026107	 0.0801	 0.00217	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67631	 67632	 0.011557	 0.026436	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67632	 67633	 0.031929	 0.072414	 0.00144	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78278	 67632	 0.03085	 0.137479	 0.00234	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67633	 67635	 0.084136	 0.069257	 0.0014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67633	 70388	 0.0897	 0.157779	 0.00296	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67634	 67639	 0.01075	 0.022093	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67634	 67658	 0.007164	 0.014729	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78531	 67634	 0.028279	 0.126036	 0.00214	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67635	 67639	 0.024486	 0.035686	 0.00081	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67636	 67643	 0.013414	 0.027571	 0.00053	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67636	 67644	 0.013021	 0.029536	 0.00059	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67637	 67638	 0.004757	 0.009779	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67637	 67641	 0.005979	 0.015364	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67638	 67639	 0.00695	 0.017864	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67638	 67642	 0.009221	 0.016221	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67640	 67641	 0.018507	 0.013114	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67641	 67645	 0.007207	 0.016479	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67642	 67643	 0.009671	 0.014093	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67643	 70400	 0.02475	 0.074493	 0.00146	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67644	 78536	 0.007914	 0.020964	 0.00053	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67645	 78536	 0.006857	 0.018179	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67646	 67655	 0.00795	 0.016271	 0.0004	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67646	 67656	 0.005836	 0.013236	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67647	 67651	 0.001129	 0.0046	 0.00112	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67647	 67687	 0.003171	 0.007636	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67647	 78535	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67647	 78535	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67648	 67649	 0.0062	 0.014057	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67648	 67692	 0.006379	 0.014464	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67649	 67676	 0.002721	 0.01165	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78535	 67649	 0.010414	 0.017543	 0.00025	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67649	 78542	 0.0086	 0.015121	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78535	 67650	 0.02815	 0.018229	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67651	 67687	 0.003779	 0.013171	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67651	 78536	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67651	 78536	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67652	 67655	 0.005736	 0.014521	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78536	 67652	 0.003964	 0.012157	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67653	 67654	 0.004093	 0.015907	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78535	 67653	 0.002664	 0.011814	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78536	 67653	 0.027586	 0.022707	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67654	 67655	 0.007264	 0.014929	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67654	 67665	 0.00875	 0.013964	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67654	 67674	 0.0356	 0.025214	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67654	 67680	 0.010257	 0.013479	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67656	 67658	 0.0044	 0.011314	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67657	 67665	 0.023364	 0.01655	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67658	 67659	 0.01175	 0.0106	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67659	 67660	 0.008957	 0.008079	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67661	 67662	 0.010071	 0.011079	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67661	 67663	 0.008564	 0.012471	 0.00028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67661	 67664	 0.010343	 0.0067	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67663	 67666	 0.006036	 0.011229	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67666	 67670	 0.024871	 0.0161	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78535	 67666	 0.019757	 0.0652	 0.00106	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67667	 67673	 0.006364	 0.010164	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67669	 67670	 0.013064	 0.008457	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67670	 67671	 0.003207	 0.00745	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67671	 67674	 0.003607	 0.009264	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67672	 67673	 0.004329	 0.006914	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67672	 67678	 0.006157	 0.012607	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67674	 67679	 0.003221	 0.0073	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67675	 67676	 0.001736	 0.006086	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67675	 67679	 0.013014	 0.008429	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67675	 67680	 0.009464	 0.0129	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67677	 67686	 0.001021	 0.003086	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67677	 67687	 0.001579	 0.004307	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67677	 67723	 0.033414	 0.091621	 0.01994	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67677	 78537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67677	 78537	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78537	 67678	 0.006114	 0.015486	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78537	 67679	 0.010314	 0.02395	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67681	 67682	 0.001929	 0.006621	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67681	 70393	 0.007807	 0.026786	 0.00641	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67681	 78538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67681	 78538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67682	 67683	 0.001029	 0.004257	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67682	 78539	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67682	 78539	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67682	 78543	 0.001914	 0.015293	 0.00377	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67683	 67685	 0.001029	 0.003914	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67683	 78540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67683	 78540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67684	 67692	 0.02	 0.01295	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67685	 67686	 0.001029	 0.003907	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67685	 78541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67685	 78541	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67686	 67687	 0.001229	 0.004336	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67687	 78542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67687	 78542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67688	 67695	 0.0252	 0.01785	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67688	 67704	 0.004171	 0.021114	 0.00036	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67688	 78544	 0.003	 0.017979	 0.00044	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67689	 67690	 0.004171	 0.0128	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67689	 78544	 0.003943	 0.013807	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67690	 67697	 0.016671	 0.016379	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67690	 67704	 0.009357	 0.024807	 0.00063	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78535	 67690	 0.071829	 0.07255	 0.00096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67691	 67727	 0.000936	 0.012264	 0.02694	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67691	 78543	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67691	 78543	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67692	 67693	 0.002557	 0.014064	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78535	 67692	 0.039543	 0.043493	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78539	 67693	 0.002393	 0.014357	 0.00034	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67694	 67695	 0.027879	 0.01975	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78543	 67696	 0.004829	 0.019636	 0.00479	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67696	 78544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67696	 78544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78541	 67697	 0.013829	 0.014771	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78544	 67698	 0.034907	 0.024729	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67699	 67702	 0.006743	 0.010757	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67699	 67704	 0.00205	 0.010964	 0.00034	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67699	 67707	 0.004914	 0.01445	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67700	 67701	 0.01125	 0.009257	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78537	 67700	 0.006364	 0.011193	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67701	 67702	 0.018029	 0.012771	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67702	 67703	 0.003036	 0.007686	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78534	 67703	 0.03555	 0.031857	 0.00065	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67704	 67705	 0.008679	 0.015257	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67705	 67715	 0.016757	 0.01085	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67705	 67716	 0.040271	 0.028529	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67706	 67707	 0.007336	 0.015421	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67706	 67718	 0.017557	 0.04075	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67707	 67710	 0.023571	 0.029257	 0.00064	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67708	 67709	 0.02375	 0.015379	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67708	 67710	 0.008857	 0.017364	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78534	 67710	 0.008271	 0.020943	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78534	 67711	 0.013664	 0.031	 0.00062	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67712	 67719	 0.035171	 0.05125	 0.00116	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67713	 67714	 0.026614	 0.054471	 0.00134	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67713	 67718	 0.023921	 0.049164	 0.00094	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67714	 67722	 0.027021	 0.05025	 0.00118	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78298	 67714	 0.025121	 0.172493	 0.00314	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67716	 67717	 0.02685	 0.02125	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67723	 67730	 0.005121	 0.019479	 0.00545	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67723	 78545	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67723	 78545	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78163	 67724	 0.004136	 0.039736	 0.01156	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78164	 67725	 0.151943	 0.249186	 0.0044	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78269	 67725	 0.201793	 0.198314	 0.00335	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78319	 67725	 0.426271	 0.276407	 0.00526	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78222	 67726	 0.149379	 0.224043	 0.00407	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78298	 67726	 0.023364	 0.09125	 0.00202	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78358	 67726	 0.052621	 0.230614	 0.00496	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78162	 67727	 0.007393	 0.051929	 0.08861	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67727	 78546	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67727	 78546	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67728	 67729	 0.065307	 0.042279	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67728	 74588	 0.02875	 0.06575	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78545	 67728	 0.025643	 0.087586	 0.00191	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67730	 74590	 0.011807	 0.036907	 0.01069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67730	 78547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67730	 78547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67731	 67732	 0.013914	 0.018286	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78547	 67731	 0.034957	 0.022629	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78545	 67732	 0.01995	 0.058664	 0.0012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78547	 67732	 0.009171	 0.014714	 0.00027	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67733	 67734	 0.024179	 0.043629	 0.00063	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78547	 67733	 0.00575	 0.014771	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67734	 67759	 0.059679	 0.05385	 0.0009	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67735	 67759	 0.0248	 0.032593	 0.00045	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67736	 67738	 0.026686	 0.018907	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67737	 67738	 0.053736	 0.038064	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67738	 67739	 0.031136	 0.040921	 0.00056	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67739	 67742	 0.051864	 0.055393	 0.00117	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67740	 74589	 0.005907	 0.016186	 0.00352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67740	 78548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67740	 78548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67740	 79787	 0.027021	 0.071457	 0.01674	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67741	 67984	 0.069186	 0.121679	 0.00229	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67742	 67743	 0.058557	 0.079821	 0.00177	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67743	 67992	 0.170871	 0.11065	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67744	 78549	 0.166921	 0.118264	 0.00187	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67745	 78549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67745	 78549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67746	 67985	 0.077593	 0.105779	 0.00235	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78549	 67746	 0.055043	 0.1579	 0.00243	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78328	 67747	 0.0222	 0.041279	 0.00096	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67748	 67753	 0.030093	 0.0774	 0.01918	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67748	 67937	 0.104093	 0.269421	 0.06725	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78268	 67748	 0.057257	 0.154014	 0.03499	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67748	 78550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67748	 78550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67749	 67752	 0.109679	 0.090286	 0.00183	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78328	 67749	 0.091136	 0.081671	 0.00167	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78348	 67750	 0.014071	 0.022464	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67751	 67752	 0.014079	 0.024764	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78348	 67751	 0.00755	 0.025779	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67753	 78551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67753	 78551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67754	 78552	 0.023536	 0.119071	 0.00207	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67755	 70588	 0.258871	 0.482443	 0.01131	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78235	 67755	 0.00835	 0.032614	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78235	 67755	 0.00835	 0.032614	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67756	 70528	 0.007121	 0.040493	 0.01172	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78268	 67756	 0.008957	 0.05565	 0.01571	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67756	 78552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67756	 78552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78552	 67757	 0.200629	 0.1573	 0.00202	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67758	 67759	 0.019807	 0.034829	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78548	 67758	 0.034843	 0.053379	 0.00075	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67760	 67761	 0.01395	 0.062171	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67760	 67761	 0.01395	 0.062171	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78471	 67760	 0.09735	 0.341229	 0.00946	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78471	 67760	 0.09735	 0.341229	 0.00946	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67760	 78553	 0.097307	 0.434093	 0.00739	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67760	 78553	 0.097307	 0.434093	 0.00739	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67761	 67764	 0.023729	 0.083079	 0.0023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67761	 67764	 0.023729	 0.083079	 0.0023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67761	 79781	 0.049586	 0.1937	 0.0043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67761	 79781	 0.049586	 0.1937	 0.0043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67762	 70467	 0.013336	 0.149736	 0.04776	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78199	 67762	 0.007	 0.07505	 0.02401	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67762	 78553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67762	 78553	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67763	 74579	 0.000193	 0.0053	 0.51626	 4112.0	 4317.6	 4523.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67763	 78554	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67763	 78554	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78554	 67765	 0.017671	 0.127993	 0.00321	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67766	 67778	 0.032664	 0.060743	 0.00142	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67766	 78555	 0.005736	 0.019129	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67767	 67783	 0.007464	 0.042436	 0.01229	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67767	 78555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67767	 78555	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78555	 67768	 0.003857	 0.0135	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78555	 67768	 0.003857	 0.0135	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67768	 78556	 0.0051	 0.01785	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67768	 78556	 0.0051	 0.01785	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67769	 67785	 0.002564	 0.027693	 0.00949	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67769	 78556	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67769	 78556	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67770	 67771	 0.021557	 0.013957	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78555	 67771	 0.033193	 0.023514	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67772	 67773	 0.034157	 0.046607	 0.00084	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78556	 67772	 0.015429	 0.027136	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67773	 67775	 0.055493	 0.085014	 0.00119	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67774	 67775	 0.107971	 0.076486	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67775	 67776	 0.0063	 0.028064	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67775	 67778	 0.010543	 0.053329	 0.00093	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67775	 78557	 0.037871	 0.244507	 0.00779	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67776	 67784	 0.012943	 0.057664	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67777	 67785	 0.010029	 0.060664	 0.01549	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67777	 78557	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67777	 78557	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67778	 78559	 0.012157	 0.072857	 0.00175	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67779	 74255	 0.048564	 0.122264	 0.03173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67779	 78558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67779	 78558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67780	 67781	 0.048686	 0.261629	 0.00621	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67780	 78559	 0.073271	 0.285186	 0.00476	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78557	 67781	 0.048507	 0.240793	 0.00574	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67782	 67795	 0.166243	 0.341943	 0.00653	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67782	 78559	 0.020614	 0.059129	 0.00091	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67783	 78559	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67783	 78559	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67784	 67795	 0.135543	 0.310257	 0.00758	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78559	 67784	 0.003979	 0.02865	 0.00094	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67785	 74584	 0.026564	 0.174129	 0.04444	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67785	 78560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67785	 78560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78380	 67786	 0.024529	 0.095786	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78380	 67786	 0.024529	 0.095786	 0.00212	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78560	 67786	 0.028871	 0.1011	 0.0028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78560	 67786	 0.028871	 0.1011	 0.0028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67787	 67788	 0.025243	 0.088386	 0.00245	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67787	 67788	 0.025243	 0.088386	 0.00245	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78380	 67787	 0.033136	 0.147686	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78380	 67787	 0.033136	 0.147686	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67788	 67790	 0.003964	 0.032071	 0.00083	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67789	 67791	 0.055529	 0.189736	 0.00413	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78557	 67789	 0.062486	 0.244143	 0.00541	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78557	 67789	 0.062486	 0.244143	 0.00541	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67789	 78561	 0.033786	 0.2433	 0.00799	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67789	 79782	 0.211736	 0.435764	 0.00832	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67790	 67791	 0.014707	 0.105843	 0.00347	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67791	 67793	 0.04515	 0.24175	 0.00734	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67793	 70463	 0.076607	 0.368221	 0.01102	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67793	 78561	 0.100221	 0.186407	 0.00436	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67794	 78561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67794	 78561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78558	 67795	 0.018014	 0.1025	 0.00316	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78277	 67796	 0.000879	 0.0098	 0.00652	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78277	 67797	 0.004186	 0.025314	 0.00646	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67798	 67801	 0.021536	 0.115657	 0.00274	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78283	 67798	 0.014236	 0.085307	 0.00205	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67799	 67803	 0.076364	 0.060436	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67800	 67801	 0.007343	 0.019036	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67800	 67803	 0.011821	 0.027443	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67801	 67802	 0.01215	 0.027921	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78384	 67802	 0.006621	 0.015143	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78384	 67803	 0.004836	 0.016507	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78384	 67804	 0.0505	 0.2465	 0.00426	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67805	 67810	 0.02295	 0.101657	 0.00232	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67806	 67808	 0.003943	 0.014979	 0.00419	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67806	 78562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67806	 78562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67807	 78563	 0.120421	 0.099129	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67808	 78563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67808	 78563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67809	 67812	 0.002793	 0.01245	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78563	 67809	 0.003479	 0.010664	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67810	 67811	 0.009236	 0.0492	 0.00086	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78245	 67810	 0.00875	 0.043393	 0.00104	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67811	 67812	 0.002214	 0.0126	 0.00039	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67811	 67813	 0.007721	 0.015871	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67811	 67814	 0.01255	 0.020129	 0.00037	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78245	 67811	 0.001107	 0.007943	 0.00026	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67812	 67813	 0.004536	 0.010371	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67812	 67814	 0.012843	 0.022586	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67812	 67823	 0.112729	 0.395286	 0.01096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67812	 67823	 0.112729	 0.395286	 0.01096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78245	 67812	 0.006464	 0.028793	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78245	 67812	 0.006464	 0.028793	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67813	 67814	 0.011586	 0.010379	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67814	 67816	 0.012329	 0.0153	 0.00034	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67814	 67817	 0.008486	 0.017436	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67815	 67816	 0.017157	 0.011107	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67818	 67821	 0.009	 0.018421	 0.00045	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67819	 67821	 0.020164	 0.014286	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67820	 67821	 0.02715	 0.019229	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67821	 67822	 0.023564	 0.016693	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67823	 73124	 0.122243	 0.478236	 0.01063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67823	 73124	 0.122243	 0.478236	 0.01063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67823	 73125	 0.16605	 0.583314	 0.01622	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67823	 73125	 0.16605	 0.583314	 0.01622	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78563	 67823	 0.109507	 0.428264	 0.00951	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78563	 67823	 0.109507	 0.428264	 0.00951	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67824	 71747	 0.089157	 0.312464	 0.00866	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67824	 71747	 0.089157	 0.312464	 0.00866	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77277	 67826	 0.007686	 0.071536	 0.00139	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78359	 67826	 0.013821	 0.089164	 0.00284	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67827	 67831	 0.053236	 0.134064	 0.0348	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67827	 78564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67827	 78564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78351	 67828	 0.212293	 0.150429	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67829	 67830	 0.047693	 0.033786	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78351	 67830	 0.047814	 0.195464	 0.00396	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78351	 67830	 0.047814	 0.195464	 0.00396	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78564	 67830	 0.051743	 0.202136	 0.00449	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78564	 67830	 0.051743	 0.202136	 0.00449	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67831	 67832	 0.103643	 0.242286	 0.07439	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77788	 67832	 0.012414	 0.1697	 0.06097	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67833	 67838	 0.045914	 0.045107	 0.00076	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67833	 67839	 0.011943	 0.0339	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67833	 78565	 0.007364	 0.028764	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67833	 78568	 0.033107	 0.06555	 0.00096	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78261	 67834	 0.002421	 0.009693	 0.00244	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67834	 78565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67834	 78565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67835	 67836	 0.0129	 0.010207	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67835	 78566	 0.004843	 0.010986	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78565	 67836	 0.004157	 0.019393	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67836	 78566	 0.001507	 0.005786	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67837	 67844	 0.003571	 0.0086	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67837	 78566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67837	 78566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67837	 78567	 0.002557	 0.009036	 0.00204	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67838	 67921	 0.012507	 0.022	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67839	 67840	 0.005893	 0.012057	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67840	 67921	 0.006643	 0.017071	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67840	 78568	 0.04135	 0.032721	 0.00041	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67841	 67921	 0.036479	 0.028864	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67841	 78568	 0.005857	 0.017221	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67842	 78567	 0.000216	 0.017299	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67843	 67861	 0.014486	 0.023121	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67843	 78569	 0.006107	 0.017529	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67843	 78571	 0.01155	 0.018521	 0.00034	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67843	 78572	 0.01335	 0.023479	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78261	 67844	 0.003857	 0.016014	 0.00374	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78262	 67844	 0.003379	 0.013536	 0.00457	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78567	 67844	 0.004764	 0.0166	 0.00385	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67844	 78569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67844	 78569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67844	 78570	 0.001864	 0.007471	 0.00189	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67844	 78597	 0.016464	 0.038221	 0.01165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67845	 67846	 0.004664	 0.00955	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67846	 67847	 0.004107	 0.00655	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67847	 67852	 0.018093	 0.014314	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67848	 67849	 0.012421	 0.011207	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67848	 67857	 0.012214	 0.022714	 0.00053	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67848	 67859	 0.006836	 0.010914	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67849	 67858	 0.011636	 0.008243	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67849	 67860	 0.022536	 0.014593	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67850	 67851	 0.023357	 0.018486	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67850	 67853	 0.004564	 0.009343	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67850	 67874	 0.032529	 0.038129	 0.00066	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67851	 67856	 0.01855	 0.012007	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67852	 67853	 0.005464	 0.0124	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67855	 67856	 0.030414	 0.03775	 0.00082	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67856	 67857	 0.018	 0.018186	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67857	 67873	 0.004779	 0.012393	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67859	 67862	 0.005043	 0.011436	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67860	 67861	 0.014379	 0.014521	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67860	 67863	 0.015164	 0.012479	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67861	 67862	 0.004157	 0.0118	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67861	 67872	 0.015164	 0.020671	 0.00046	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78569	 67862	 0.002064	 0.008614	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67863	 67874	 0.027329	 0.017693	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67863	 78571	 0.013329	 0.023436	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67864	 67975	 0.002114	 0.014821	 0.02524	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67864	 78570	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78571	 67864	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78567	 67865	 0.002586	 0.00725	 0.00186	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78570	 67865	 0.001457	 0.004436	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67865	 78572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67865	 78572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67866	 67868	 0.014964	 0.012314	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67866	 67884	 0.005864	 0.010314	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67866	 78573	 0.0247	 0.017493	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67867	 67885	 0.002071	 0.006764	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78567	 67867	 0.001243	 0.006471	 0.00191	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67867	 78573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67867	 78573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67868	 67869	 0.006943	 0.009471	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67869	 67871	 0.033786	 0.021871	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67869	 67878	 0.0244	 0.0158	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78571	 67869	 0.007979	 0.016329	 0.0004	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67870	 67877	 0.00125	 0.004207	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78570	 67870	 0.000729	 0.004779	 0.00121	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67870	 78574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67870	 78574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67871	 67872	 0.009936	 0.009764	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78574	 67871	 0.016336	 0.012929	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67872	 67874	 0.017071	 0.013514	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78574	 67872	 0.030364	 0.019657	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67873	 67875	 0.0214	 0.034157	 0.00079	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67875	 67876	 0.060614	 0.047971	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67875	 67896	 0.06425	 0.05085	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67875	 67980	 0.100929	 0.0715	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78574	 67876	 0.026286	 0.028071	 0.00059	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67876	 78577	 0.027714	 0.019629	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67877	 67895	 0.00115	 0.004093	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67879	 67881	 0.0195	 0.013814	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78573	 67879	 0.029386	 0.020814	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67880	 67883	 0.028393	 0.018386	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67880	 67890	 0.039571	 0.025621	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78573	 67880	 0.01135	 0.037871	 0.0006	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67882	 67890	 0.021279	 0.015071	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67884	 78575	 0.011964	 0.008471	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67885	 67886	 0.000721	 0.002093	 0.00051	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67885	 78575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67885	 78575	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67886	 67887	 0.000821	 0.002236	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67887	 67897	 0.00125	 0.003021	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67887	 78576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67887	 78576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67888	 67889	 0.003464	 0.008036	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78576	 67888	 0.006879	 0.0121	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67888	 78578	 0.012321	 0.015293	 0.00034	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67889	 67891	 0.006579	 0.0105	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67890	 67891	 0.009071	 0.010629	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67892	 67903	 0.033807	 0.021886	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67893	 67903	 0.018714	 0.014807	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78574	 67894	 0.010964	 0.032236	 0.00066	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78575	 67894	 0.031957	 0.02505	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67894	 78577	 0.018507	 0.0167	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67894	 78579	 0.010393	 0.014171	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67895	 67901	 0.001614	 0.003886	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67895	 78577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67895	 78577	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67896	 78578	 0.069693	 0.045121	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67896	 78581	 0.025443	 0.020136	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67897	 67898	 0.0016	 0.004114	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67897	 67899	 0.001621	 0.0039	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67897	 78578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67897	 78578	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67898	 67902	 0.002236	 0.005186	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67898	 78579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67898	 78579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67899	 67904	 0.001957	 0.005321	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67899	 67905	 0.0051	 0.012286	 0.00347	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67899	 78580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67899	 78580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78580	 67900	 0.023264	 0.016479	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67900	 78581	 0.008757	 0.011936	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67901	 67902	 0.001614	 0.00405	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67902	 67905	 0.003621	 0.009729	 0.00221	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67902	 78581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67902	 78581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67902	 78597	 0.0086	 0.019957	 0.00608	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67903	 78582	 0.006607	 0.025793	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67903	 78583	 0.185579	 0.381807	 0.00729	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67904	 67909	 0.002871	 0.01185	 0.00281	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78567	 67904	 0.00805	 0.0241	 0.00543	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67904	 78582	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67904	 78582	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67904	 78597	 0.013007	 0.034371	 0.00805	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67905	 78597	 0.006386	 0.017379	 0.00383	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67906	 67928	 0.007393	 0.015186	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78330	 67906	 0.171429	 0.319071	 0.00747	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67907	 67909	 0.002886	 0.016014	 0.00486	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 67907	 0.011014	 0.076479	 0.02184	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78580	 67908	 0.009714	 0.015586	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78330	 67910	 0.040221	 0.039507	 0.00066	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78173	 67911	 0.00375	 0.019843	 0.00503	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 67911	 0.002157	 0.009379	 0.00267	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67912	 67913	 0.017557	 0.0612	 0.0142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 67912	 0.044543	 0.185664	 0.0435	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78205	 67912	 0.0144	 0.050186	 0.01164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78347	 67912	 0.029886	 0.137343	 0.03526	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67912	 79127	 0.028857	 0.134786	 0.03345	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67913	 78583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67913	 78583	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67914	 78584	 0.001171	 0.005729	 0.00159	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67915	 78584	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78585	 67915	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78330	 67916	 0.021157	 0.049121	 0.00073	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78585	 67916	 0.007579	 0.0141	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67917	 67933	 0.006486	 0.025479	 0.00666	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 67917	 0.006836	 0.0337	 0.00911	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67918	 67919	 0.048343	 0.051629	 0.00109	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67918	 67932	 0.062793	 0.100243	 0.00231	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67919	 67921	 0.017886	 0.028543	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67919	 67924	 0.066979	 0.071529	 0.00151	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67920	 67921	 0.014314	 0.016779	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67922	 67923	 0.009971	 0.015993	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67922	 67926	 0.023486	 0.015207	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67923	 67927	 0.0197	 0.023586	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78568	 67923	 0.006864	 0.026307	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67925	 67926	 0.023364	 0.01655	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67927	 67928	 0.015593	 0.03205	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67929	 67930	 0.067929	 0.061286	 0.00103	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67929	 78588	 0.146093	 0.156057	 0.0033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67930	 67931	 0.035386	 0.022907	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67931	 67932	 0.006236	 0.012343	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67932	 78586	 0.015186	 0.08155	 0.00194	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67933	 67934	 0.008043	 0.025129	 0.00728	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67933	 78586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67933	 78586	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67934	 67936	 0.002007	 0.005907	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67934	 78587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67934	 78587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78586	 67935	 0.080529	 0.120743	 0.00219	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78587	 67935	 0.084293	 0.059714	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67936	 67937	 0.001279	 0.003207	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67937	 67942	 0.007821	 0.031307	 0.00789	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78187	 67937	 0.020129	 0.087664	 0.025	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78567	 67937	 0.033314	 0.0895	 0.0203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67937	 78588	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67937	 78588	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67938	 68009	 0.020021	 0.0955	 0.0277	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67939	 67940	 0.028621	 0.020279	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67939	 78590	 0.083171	 0.058921	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67940	 74661	 0.030029	 0.079586	 0.00202	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78588	 67940	 0.088471	 0.164543	 0.00385	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67941	 67942	 0.004479	 0.0104	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67941	 78589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67941	 78589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78381	 67943	 0.067479	 0.053407	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78589	 67943	 0.030221	 0.019564	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67944	 67947	 0.003021	 0.007771	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67944	 67948	 0.001614	 0.004329	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67944	 78590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67944	 78590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67944	 79796	 0.032521	 0.088593	 0.01954	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67945	 67946	 0.000971	 0.003421	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67945	 74662	 0.007929	 0.025871	 0.00687	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67946	 67948	 0.001114	 0.003707	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78261	 67949	 0.00345	 0.009393	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78262	 67949	 0.003329	 0.008564	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67949	 78591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67949	 78591	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67951	 67952	 0.019936	 0.0784	 0.02053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67952	 78592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67952	 78592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67954	 67958	 0.014521	 0.038386	 0.00899	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67954	 78593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67954	 78593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67955	 67956	 0.023736	 0.015371	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78593	 67955	 0.057957	 0.084464	 0.00191	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67956	 67957	 0.035307	 0.025521	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67957	 78594	 0.022879	 0.0284	 0.00062	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67958	 78594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67958	 78594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78592	 67959	 0.060543	 0.372543	 0.00672	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78593	 67959	 0.024543	 0.179421	 0.00331	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67960	 67965	 0.03805	 0.1119	 0.00229	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78389	 67960	 0.041414	 0.161771	 0.00359	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67961	 67962	 0.013929	 0.031593	 0.00063	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67961	 67983	 0.019043	 0.102279	 0.00243	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67961	 78595	 0.055471	 0.216721	 0.00481	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78225	 67962	 0.074457	 0.170329	 0.00416	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78240	 67963	 0.061457	 0.262879	 0.00594	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78321	 67963	 0.007193	 0.028093	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78321	 67963	 0.007193	 0.028093	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78355	 67963	 0.013886	 0.083193	 0.002	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67964	 70355	 0.015179	 0.09185	 0.02346	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	67964	 78595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67964	 78595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67965	 67966	 0.03955	 0.028014	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67965	 79112	 0.053486	 0.09945	 0.00233	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67967	 78596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67967	 78596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67968	 67971	 0.107986	 0.069921	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67968	 67972	 0.0778	 0.154064	 0.00226	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67968	 67973	 0.048957	 0.100193	 0.00246	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67969	 67971	 0.067571	 0.047864	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67969	 67974	 0.024021	 0.043343	 0.00063	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78225	 67970	 0.072907	 0.169286	 0.00252	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78259	 67970	 0.037864	 0.085893	 0.00171	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78592	 67970	 0.045071	 0.223721	 0.00534	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78206	 67972	 0.301021	 0.195036	 0.00371	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67973	 67979	 0.2125	 0.150579	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78281	 67974	 0.108064	 0.126693	 0.0022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78389	 67974	 0.105579	 0.1694	 0.00313	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67975	 67976	 0.001436	 0.010057	 0.01713	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67975	 78597	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78598	 67975	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78204	 67976	 0.00345	 0.023014	 0.0434	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	67976	 78599	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67976	 78599	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	67977	 67979	 0.039586	 0.028043	 0.00044	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67977	 67982	 0.040979	 0.081143	 0.00119	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67978	 67979	 0.035621	 0.028193	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78599	 67979	 0.094736	 0.067107	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67980	 67981	 0.022093	 0.0143	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78598	 67980	 0.01655	 0.022557	 0.0005	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67981	 67982	 0.010214	 0.020907	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78598	 67981	 0.006164	 0.010843	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78225	 67983	 0.082879	 0.219764	 0.00558	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78321	 67983	 0.079014	 0.348386	 0.00606	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78321	 67983	 0.079014	 0.348386	 0.00606	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	67984	 67996	 0.11475	 0.090821	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67985	 67988	 0.072236	 0.070964	 0.0012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78550	 67986	 0.066021	 0.122771	 0.00287	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	67987	 67989	 0.004907	 0.0188	 0.00053	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	67988	 67989	 0.009507	 0.024429	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67988	 67991	 0.029936	 0.05265	 0.00099	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67989	 67990	 0.015736	 0.01845	 0.00032	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67991	 67998	 0.031543	 0.04105	 0.00057	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67992	 67993	 0.014979	 0.015993	 0.00034	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67992	 67997	 0.026707	 0.028521	 0.0006	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	67993	 67994	 0.005521	 0.008807	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67994	 67996	 0.015179	 0.031071	 0.00076	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67995	 67996	 0.034143	 0.0221	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67996	 68001	 0.014821	 0.0216	 0.00049	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67996	 79786	 0.327457	 0.212193	 0.00404	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	67997	 67998	 0.00805	 0.023679	 0.00049	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78329	 67997	 0.028029	 0.063571	 0.00127	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	67998	 67999	 0.008464	 0.013514	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	67999	 68000	 0.023557	 0.016686	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78329	 68001	 0.01795	 0.046143	 0.00071	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68001	 78600	 0.127071	 0.090021	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68002	 68009	 0.054636	 0.1376	 0.03572	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68002	 74590	 0.029179	 0.07715	 0.01807	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68002	 78600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68002	 78600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68003	 68004	 0.008521	 0.026143	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78600	 68003	 0.024171	 0.11995	 0.00286	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68004	 68005	 0.007929	 0.015536	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68004	 68008	 0.014593	 0.027129	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68005	 68006	 0.019007	 0.013464	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68007	 68008	 0.055279	 0.082879	 0.00151	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68008	 74644	 0.060064	 0.1117	 0.00261	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68009	 78601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68009	 78601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78601	 68010	 0.119171	 0.077164	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68011	 70470	 0.048679	 0.190164	 0.00422	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68011	 70470	 0.048679	 0.190164	 0.00422	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68011	 78602	 0.097029	 0.340107	 0.00943	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68011	 78602	 0.097029	 0.340107	 0.00943	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68012	 78602	 0.161907	 0.104843	 0.00199	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68013	 78602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68013	 78602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68014	 68015	 0.043436	 0.110021	 0.00218	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78602	 68015	 0.037157	 0.094129	 0.00186	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68016	 68018	 0.028029	 0.09815	 0.00271	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68017	 68020	 0.050621	 0.035857	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68018	 68020	 0.021264	 0.048636	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68018	 68024	 0.0295	 0.0905	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68019	 68020	 0.030271	 0.021443	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68020	 68021	 0.135179	 0.087529	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78602	 68022	 0.084164	 0.110629	 0.00151	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78295	 68023	 0.016414	 0.033593	 0.00083	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68024	 68025	 0.043886	 0.1321	 0.00259	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68025	 70666	 0.032529	 0.235671	 0.00592	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68026	 68034	 0.038314	 0.225479	 0.06183	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68027	 78603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68027	 78603	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68028	 68033	 0.222136	 0.157407	 0.00249	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68028	 78604	 0.065114	 0.05875	 0.00099	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68029	 78604	 0.06425	 0.068621	 0.00145	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68030	 78604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68030	 78604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78603	 68031	 0.03055	 0.173843	 0.00535	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78604	 68031	 0.017514	 0.084093	 0.00251	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68034	 78605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68034	 78605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68035	 68036	 0.013857	 0.009814	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68035	 78606	 0.0041	 0.006543	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68035	 78607	 0.006307	 0.014643	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68036	 70373	 0.018929	 0.013407	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68037	 68039	 0.001193	 0.004771	 0.0012	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68037	 68046	 0.001221	 0.004886	 0.00123	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68037	 78606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68037	 78606	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78606	 68038	 0.01235	 0.008	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68039	 69023	 0.001121	 0.004486	 0.00113	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68040	 70367	 0.010843	 0.017307	 0.0004	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78606	 68040	 0.007607	 0.011407	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68041	 68042	 0.018557	 0.012014	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68041	 68201	 0.018764	 0.013293	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68042	 68043	 0.011436	 0.0081	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68043	 68201	 0.006893	 0.0094	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68043	 69069	 0.006814	 0.014	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68044	 78631	 0.058093	 0.04115	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68045	 68046	 0.0005	 0.002471	 0.0008	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68045	 68047	 0.001221	 0.006457	 0.00216	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68046	 78607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68046	 78607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68047	 68056	 0.00345	 0.013121	 0.00367	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68047	 78608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68047	 78608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78608	 68048	 0.033336	 0.026379	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78607	 68049	 0.012614	 0.010379	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68050	 68051	 0.013293	 0.014621	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68050	 78609	 0.009493	 0.008564	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68051	 68052	 0.006136	 0.006029	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68051	 68055	 0.003207	 0.0066	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68051	 78613	 0.014436	 0.011886	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68052	 78609	 0.020693	 0.018664	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68052	 78615	 0.014286	 0.021886	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68053	 70368	 0.009029	 0.023936	 0.00061	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68053	 78609	 0.004871	 0.018957	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68054	 68055	 0.004193	 0.008621	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68054	 78609	 0.005871	 0.017264	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68054	 78817	 0.002329	 0.010307	 0.00031	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68055	 78610	 0.008793	 0.009393	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68056	 68074	 0.001186	 0.005407	 0.00171	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68056	 78609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68056	 78609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68057	 78610	 0.004093	 0.007614	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68057	 78611	 0.015771	 0.010207	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68057	 78620	 0.00845	 0.035279	 0.00102	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68057	 78622	 0.008357	 0.010986	 0.00015	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68058	 68059	 0.00085	 0.003493	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68058	 68065	 0.000529	 0.001821	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68058	 78610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68058	 78610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68059	 68061	 0.000321	 0.001229	 0.00034	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68059	 68105	 0.000636	 0.002421	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68059	 69092	 0.001314	 0.005471	 0.00128	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68059	 78611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68059	 78611	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78611	 68060	 0.013564	 0.010736	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68061	 68064	 0.000557	 0.002371	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68062	 68163	 0.002393	 0.008371	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68062	 78612	 0.000879	 0.003086	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68063	 78612	 0.003614	 0.003857	 8e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68063	 78613	 0.006907	 0.008571	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78195	 68064	 0.002443	 0.008386	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68064	 78612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68064	 78612	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68065	 68067	 0.000671	 0.0021	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68065	 78613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68065	 78613	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68066	 78614	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78615	 68066	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78614	 68067	 0.00085	 0.003	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68068	 68069	 0.003779	 0.005507	 0.00012	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78615	 68068	 0.005057	 0.0094	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68069	 68070	 0.00445	 0.004843	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68070	 68163	 0.005607	 0.005993	 0.00013	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68071	 68072	 0.016257	 0.016421	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68071	 78617	 0.007764	 0.019671	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68071	 78618	 0.014179	 0.014321	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68071	 78619	 0.00595	 0.03195	 0.00076	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68072	 68073	 0.0215	 0.0177	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68073	 78616	 0.010886	 0.017457	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68074	 68075	 0.000571	 0.002386	 0.00056	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68074	 78616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68074	 78616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68075	 68076	 0.000371	 0.001436	 0.00039	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68076	 68077	 0.000864	 0.003471	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68076	 69089	 0.000671	 0.00225	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68077	 68080	 0.000421	 0.00175	 0.00041	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68077	 68093	 0.000507	 0.001586	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68077	 69089	 0.001357	 0.004429	 0.00118	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68077	 78617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68077	 78617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68078	 68079	 0.000536	 0.00335	 0.00094	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68078	 68081	 0.000493	 0.001864	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68078	 68083	 0.001043	 0.003571	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68078	 78618	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68078	 78618	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68079	 68082	 0.000886	 0.004893	 0.00176	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68080	 68081	 0.000279	 0.001021	 0.00031	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68082	 70333	 0.001779	 0.013386	 0.00371	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68082	 78619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68082	 78619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68083	 68094	 0.001021	 0.004214	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68083	 69092	 0.002093	 0.007964	 0.00223	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68083	 78620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68083	 78620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68084	 68087	 0.0116	 0.051679	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68084	 68087	 0.0116	 0.051679	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78279	 68084	 0.00815	 0.052557	 0.00167	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78619	 68084	 0.0161	 0.033086	 0.00063	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68085	 70369	 0.005686	 0.010571	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78620	 68085	 0.004443	 0.01125	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68086	 68087	 0.019721	 0.013971	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68087	 68088	 0.004343	 0.012764	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68087	 68089	 0.00575	 0.011821	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68087	 68090	 0.003579	 0.012221	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68087	 68112	 0.002871	 0.01005	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68088	 68097	 0.006071	 0.015379	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68089	 70369	 0.006593	 0.013543	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68090	 68103	 0.004771	 0.012643	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68091	 68092	 0.008936	 0.005786	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68091	 78621	 0.010143	 0.007186	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68093	 68094	 0.000464	 0.001657	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68094	 69092	 0.000964	 0.004021	 0.00126	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68094	 78621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68094	 78621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68095	 68096	 0.010521	 0.011236	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68095	 68097	 0.003214	 0.007464	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68095	 68116	 0.006621	 0.013614	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68096	 68099	 0.009364	 0.012314	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68097	 68098	 0.015064	 0.010671	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68099	 68100	 0.007229	 0.016779	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68099	 68114	 0.034686	 0.035036	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68100	 68120	 0.011457	 0.023543	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68100	 70332	 0.010271	 0.0315	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68101	 68102	 0.006386	 0.0093	 0.00021	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68101	 68104	 0.004643	 0.010529	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68101	 78818	 0.004279	 0.013129	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68102	 68103	 0.005036	 0.009971	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68103	 68109	 0.00315	 0.008343	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68104	 68106	 0.0122	 0.010929	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68104	 68108	 0.008593	 0.013164	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68105	 69092	 0.000679	 0.002836	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68105	 78622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68105	 78622	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68106	 68165	 0.009979	 0.009	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68107	 68108	 0.004786	 0.007643	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68107	 68149	 0.0078	 0.008329	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68108	 68119	 0.015614	 0.024929	 0.00057	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68109	 68110	 0.0028	 0.007414	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68109	 68119	 0.01655	 0.013621	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68110	 68151	 0.004414	 0.011186	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68111	 68112	 0.022729	 0.014714	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68112	 68113	 0.002114	 0.008221	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68113	 68117	 0.005893	 0.008036	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68113	 68119	 0.007493	 0.018986	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68113	 78624	 0.012436	 0.049343	 0.00141	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68114	 68115	 0.005657	 0.012936	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68114	 68116	 0.006593	 0.012257	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68114	 78624	 0.010429	 0.030664	 0.00063	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68115	 68139	 0.005164	 0.011714	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68117	 68118	 0.012243	 0.009686	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68120	 68133	 0.005829	 0.010836	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68121	 68134	 0.019371	 0.012543	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68122	 68123	 0.004036	 0.0107	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68122	 79844	 0.014329	 0.036286	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68123	 68124	 0.010314	 0.008493	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68123	 68133	 0.005871	 0.013629	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68124	 68130	 0.016614	 0.011771	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68125	 68129	 0.018793	 0.014871	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68125	 68319	 0.007029	 0.01445	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68125	 70370	 0.011286	 0.008936	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68125	 79844	 0.027564	 0.040171	 0.00091	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68126	 68314	 0.019636	 0.015536	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68127	 68128	 0.00245	 0.006214	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68127	 78661	 0.007907	 0.014707	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68128	 68314	 0.003636	 0.009636	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68128	 78624	 0.002379	 0.01925	 0.00049	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68128	 78627	 0.004579	 0.013121	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68129	 68130	 0.019864	 0.034929	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68129	 70370	 0.013707	 0.009714	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68129	 74810	 0.016429	 0.03375	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68130	 78624	 0.014107	 0.028993	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68131	 68143	 0.001836	 0.00785	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68131	 78624	 0.003143	 0.01785	 0.00032	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68132	 70320	 0.000279	 0.003636	 0.23192	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68132	 74785	 0.0004	 0.005186	 0.33112	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68132	 78623	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78624	 68133	 0.006293	 0.014271	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78624	 68134	 0.018243	 0.014436	 0.00018	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68135	 68289	 0.001064	 0.004436	 0.00104	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68135	 78625	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68135	 78625	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68135	 78626	 0.000986	 0.004864	 0.00131	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68135	 78628	 0.001264	 0.004129	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68136	 68137	 9.3e-05	 0.000907	 0.00182	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78623	 68136	 6.4e-05	 0.000843	 0.00296	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68136	 78626	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78627	 68136	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68137	 70186	 0.001993	 0.013721	 0.02422	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68137	 78628	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68137	 78628	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68138	 68140	 0.002729	 0.010486	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68138	 68153	 0.002943	 0.009029	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68139	 68140	 0.001507	 0.007036	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68139	 68141	 0.003943	 0.007329	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68141	 68142	 0.0036	 0.009536	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68141	 68143	 0.002371	 0.008293	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68142	 68146	 0.0063	 0.01005	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78625	 68142	 0.009607	 0.019657	 0.00049	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68144	 68147	 0.011593	 0.009179	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78625	 68144	 0.010014	 0.011986	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68145	 68146	 0.017086	 0.017257	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68145	 68286	 0.011543	 0.010343	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68148	 68150	 0.002507	 0.00665	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68148	 68159	 0.002771	 0.00515	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68148	 68167	 0.004307	 0.006871	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68149	 68166	 0.007743	 0.008264	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68150	 68151	 0.002464	 0.006529	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68151	 68153	 0.007593	 0.015543	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68152	 68153	 0.013771	 0.008914	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68153	 68154	 0.004	 0.0106	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78625	 68153	 0.023964	 0.049043	 0.00121	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68154	 68155	 0.004043	 0.009243	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68155	 68158	 0.003229	 0.007386	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68156	 68157	 0.004514	 0.004071	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68156	 68159	 0.00685	 0.006136	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68157	 68158	 0.00655	 0.00655	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68158	 78649	 0.002864	 0.005857	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68159	 68161	 0.004486	 0.008336	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68159	 68183	 0.004036	 0.005879	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68160	 68161	 0.0084	 0.005436	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68161	 68181	 0.002429	 0.005557	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68161	 78649	 0.004107	 0.007636	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68162	 68173	 0.005057	 0.011736	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68162	 68190	 0.00665	 0.012357	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68162	 78629	 0.007521	 0.015464	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68163	 68171	 0.003457	 0.00875	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68163	 68173	 0.004893	 0.011186	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78610	 68163	 0.014093	 0.028971	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68164	 68165	 0.004471	 0.009186	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68164	 68166	 0.00555	 0.008321	 0.00015	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68164	 68171	 0.005314	 0.00775	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78622	 68165	 0.009436	 0.021907	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68166	 68170	 0.002686	 0.005	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68167	 68169	 0.003336	 0.007014	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68168	 68169	 0.003079	 0.005729	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68168	 68183	 0.002029	 0.0047	 7e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68169	 68170	 0.002293	 0.004036	 8e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68169	 68171	 0.004429	 0.009093	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68171	 68173	 0.003964	 0.00815	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68172	 68185	 0.00395	 0.005386	 0.00012	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68172	 68197	 0.015071	 0.010671	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68172	 78629	 0.011493	 0.018343	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68173	 68174	 0.004393	 0.0126	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68174	 68179	 0.003429	 0.007779	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68175	 78649	 0.009564	 0.006771	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68176	 68177	 0.002643	 0.004771	 7e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68176	 68181	 0.003021	 0.004821	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68177	 68179	 0.006486	 0.009721	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68177	 68184	 0.004579	 0.008514	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68177	 78646	 0.009064	 0.009679	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68178	 68180	 0.004086	 0.00265	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68179	 68181	 0.004879	 0.006657	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68180	 68183	 0.0101	 0.007157	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68181	 68182	 0.005307	 0.003764	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68184	 68185	 0.005293	 0.007707	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68186	 68191	 0.000671	 0.002271	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68186	 68252	 0.004893	 0.014421	 0.00336	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68186	 78629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68186	 78629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68187	 68193	 0.003164	 0.007179	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78629	 68187	 0.005007	 0.01135	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68188	 68200	 0.012929	 0.008371	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68189	 68952	 0.004079	 0.027529	 0.05072	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68189	 78630	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78631	 68189	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78196	 68190	 0.002136	 0.011464	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68190	 78632	 0.006436	 0.013221	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68191	 68192	 0.000386	 0.001393	 0.00043	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68191	 68196	 0.0012	 0.004	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68192	 68196	 0.000886	 0.004236	 0.00123	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78195	 68192	 0.0003	 0.003164	 0.00106	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68192	 78632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68192	 78632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68193	 68194	 0.010607	 0.017871	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68193	 68197	 0.003764	 0.008729	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68193	 78637	 0.005529	 0.014007	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68194	 68195	 0.006264	 0.007779	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68195	 78633	 0.0065	 0.007786	 0.00013	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68196	 68204	 0.001179	 0.004493	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68196	 78633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68196	 78633	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68197	 68250	 0.015564	 0.01395	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78629	 68197	 0.010764	 0.014671	 0.00033	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68197	 78648	 0.030321	 0.0545	 0.00098	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68198	 68199	 0.005843	 0.003786	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68198	 68205	 0.006021	 0.008214	 0.00015	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78633	 68198	 0.0059	 0.012121	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68198	 78634	 0.013457	 0.01065	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68200	 68201	 0.02065	 0.013364	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78633	 68200	 0.003714	 0.008421	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78632	 68201	 0.014314	 0.033221	 0.00064	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68202	 68203	 0.0117	 0.008286	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68202	 68208	 0.002807	 0.008257	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78633	 68202	 0.003379	 0.012943	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68203	 78634	 0.008286	 0.008136	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68204	 68210	 0.000779	 0.002843	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68204	 69070	 0.002136	 0.008293	 0.00221	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78195	 68204	 0.002707	 0.012636	 0.00313	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78630	 68204	 0.002436	 0.010864	 0.00295	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68204	 78634	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68204	 78634	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68205	 70352	 0.003971	 0.008129	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78634	 68205	 0.008679	 0.007829	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68206	 69079	 0.011807	 0.012986	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68206	 70352	 0.007371	 0.011829	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68207	 69079	 0.014593	 0.010336	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68207	 78640	 0.013321	 0.008621	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68208	 68223	 0.017793	 0.012607	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68208	 78635	 0.004007	 0.004407	 6e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68208	 78636	 0.010471	 0.008286	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68209	 68210	 0.000993	 0.002621	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68209	 68212	 0.000886	 0.002336	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68209	 78635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68209	 78635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68210	 68230	 0.000857	 0.003014	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68210	 78636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68210	 78636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78634	 68211	 0.003071	 0.008136	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68211	 78639	 0.0039	 0.00905	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68211	 78640	 0.00445	 0.008279	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68212	 78637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68212	 78637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68213	 68214	 0.007471	 0.004836	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68213	 68215	 0.01345	 0.008707	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68213	 68216	 0.006343	 0.005686	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78637	 68213	 0.009414	 0.011036	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78637	 68214	 0.004971	 0.006786	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68215	 68216	 0.009764	 0.006914	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68215	 68217	 0.004079	 0.006871	 0.0001	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68216	 68218	 0.0078	 0.010257	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68217	 68268	 0.004793	 0.006986	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68218	 68220	 0.0087	 0.007793	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68218	 68269	 0.008664	 0.01015	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68219	 68221	 0.0159	 0.012464	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68219	 68222	 0.009993	 0.013621	 0.0003	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68219	 68234	 0.012979	 0.0084	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68219	 68277	 0.009621	 0.017893	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68220	 68235	 0.011143	 0.009171	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68222	 68224	 0.005179	 0.01025	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68222	 68238	 0.008979	 0.009586	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68224	 78638	 0.004429	 0.007071	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68225	 68240	 0.013521	 0.013657	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68225	 78643	 0.010986	 0.009843	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68226	 68229	 0.000607	 0.001657	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68226	 68232	 0.000829	 0.002221	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68226	 78638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68226	 78638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68227	 68228	 0.0004	 0.000936	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68227	 78639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68227	 78639	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68228	 68229	 0.0004	 0.00105	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68230	 68232	 0.000771	 0.002693	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68230	 78640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68230	 78640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78638	 68231	 0.012043	 0.009529	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78640	 68231	 0.004407	 0.007743	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68231	 78641	 0.003429	 0.004021	 7e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68232	 68243	 0.000579	 0.002021	 0.00067	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68232	 78641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68232	 78641	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68233	 69080	 0.011386	 0.011186	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78640	 68233	 0.011836	 0.013871	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68235	 68278	 0.011936	 0.008457	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68235	 78642	 0.007386	 0.010071	 0.00022	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68236	 68237	 0.000607	 0.002579	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68236	 68364	 0.001057	 0.003279	 0.00069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68236	 78642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68236	 78642	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68237	 68378	 0.000871	 0.003071	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68237	 78643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68237	 78643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68238	 68239	 0.005871	 0.0046	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68239	 68240	 0.012021	 0.008514	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68240	 68241	 0.011714	 0.009271	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68240	 68377	 0.004329	 0.011479	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78636	 68240	 0.013543	 0.034821	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68241	 68244	 0.0074	 0.009729	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68242	 69079	 0.009429	 0.017529	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78641	 68242	 0.006736	 0.009386	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68242	 78644	 0.005557	 0.005014	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68242	 78645	 0.01005	 0.015064	 0.00027	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68243	 68246	 0.0004	 0.001664	 0.00039	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68243	 78644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68243	 78644	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78644	 68244	 0.003214	 0.005136	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68245	 68247	 0.011314	 0.008957	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78644	 68245	 0.013043	 0.013171	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68246	 68248	 0.000607	 0.002307	 0.00065	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68248	 68375	 0.0006	 0.002764	 0.00071	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68248	 78645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68248	 78645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68249	 68251	 0.003657	 0.008493	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68249	 78646	 0.005743	 0.013021	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68250	 68251	 0.008921	 0.005779	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68251	 68268	 0.004614	 0.008114	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68252	 78646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68252	 78646	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68252	 78647	 0.001114	 0.004593	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78646	 68253	 0.010736	 0.00695	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68254	 78648	 0.012564	 0.0089	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68254	 78649	 0.011436	 0.011236	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68255	 68275	 0.000593	 0.003829	 0.00763	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78623	 68255	 0.0005	 0.006707	 0.02368	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68255	 78647	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78648	 68255	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78647	 68256	 0.001179	 0.003157	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68256	 78649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68256	 78649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68257	 68258	 0.002179	 0.003836	 7e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68257	 68259	 0.003664	 0.006814	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68257	 68260	 0.0029	 0.006729	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68258	 68262	 0.003307	 0.007557	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78648	 68258	 0.002814	 0.010986	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68259	 68296	 0.003607	 0.007379	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68260	 68261	 0.003514	 0.008164	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68261	 68264	 0.01875	 0.012143	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68261	 78650	 0.004379	 0.009	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68262	 68264	 0.002736	 0.006929	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68263	 68264	 0.002457	 0.008186	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68263	 68267	 0.004371	 0.006979	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68264	 68265	 0.004229	 0.006157	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78646	 68264	 0.0031	 0.009514	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68265	 68266	 0.002443	 0.003914	 7e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68266	 78650	 0.004357	 0.005414	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68267	 68270	 0.005264	 0.007171	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68269	 68270	 0.005786	 0.008864	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68269	 68272	 0.0109	 0.007721	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68270	 68271	 0.01085	 0.008586	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68271	 68274	 0.0083	 0.007486	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68273	 78650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68273	 78650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68273	 78651	 0.000829	 0.002186	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68274	 68277	 0.00525	 0.012186	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78650	 68274	 0.001657	 0.006464	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68275	 78651	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78652	 68275	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68276	 68277	 0.005207	 0.009157	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78652	 68276	 0.006814	 0.015814	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68276	 78653	 0.014893	 0.011786	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68277	 68278	 0.008071	 0.009457	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78642	 68279	 0.0066	 0.013064	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68279	 78653	 0.006736	 0.013779	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68280	 70371	 0.009786	 0.006336	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78652	 68280	 0.012214	 0.011021	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68280	 78653	 0.004964	 0.008736	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68281	 68364	 0.002471	 0.008057	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78651	 68281	 0.000607	 0.002514	 0.00059	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68281	 78653	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68281	 78653	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68282	 68369	 0.008907	 0.007329	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78653	 68282	 0.009057	 0.00915	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68283	 68288	 0.000507	 0.001993	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68283	 68289	 0.000764	 0.002771	 0.00085	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68284	 68291	 0.005457	 0.008707	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68284	 78656	 0.012114	 0.010857	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68285	 78655	 0.033114	 0.023457	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68286	 68287	 0.011671	 0.008264	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68287	 78654	 0.008986	 0.008107	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68287	 78655	 0.007657	 0.011479	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68288	 68292	 0.000893	 0.003007	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68288	 78654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68288	 78654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68290	 68291	 0.003036	 0.007679	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78625	 68290	 0.011536	 0.0237	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68290	 78658	 0.004693	 0.009871	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68290	 78662	 0.004007	 0.009093	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68292	 68301	 0.001643	 0.00395	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68292	 78655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68292	 78655	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68293	 68295	 0.016271	 0.011521	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68293	 68297	 0.003014	 0.011729	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78655	 68293	 0.004079	 0.012521	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68294	 68296	 0.005243	 0.015414	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68294	 78657	 0.003443	 0.011471	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68296	 70359	 0.033586	 0.026579	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68297	 70359	 0.00345	 0.011521	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68298	 68301	 0.000836	 0.0021	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68298	 78656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68298	 78656	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68299	 78658	 0.012529	 0.009821	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68300	 68303	 0.000629	 0.00245	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68300	 68304	 0.000507	 0.002093	 0.00049	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68301	 78657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68301	 78657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78657	 68302	 0.010714	 0.007593	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68303	 68325	 0.0008	 0.002907	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68303	 78658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68303	 78658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68304	 68351	 0.00065	 0.002279	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68304	 78659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68304	 78659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68305	 68306	 0.004736	 0.00465	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68305	 68320	 0.005636	 0.008214	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68305	 68321	 0.002379	 0.004893	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68305	 68323	 0.006021	 0.009614	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68305	 78664	 0.005264	 0.010814	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68306	 68323	 0.007621	 0.006879	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78625	 68307	 0.008086	 0.014529	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68307	 78660	 0.009457	 0.007786	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68308	 68309	 0.000207	 0.001593	 0.00041	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78628	 68308	 0.000293	 0.002207	 0.00061	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68309	 68324	 0.000421	 0.002557	 0.00065	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68309	 78660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68309	 78660	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68310	 68327	 0.001886	 0.006464	 0.00155	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78628	 68310	 0.000993	 0.003886	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68310	 78661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68310	 78661	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68311	 68312	 0.019779	 0.014014	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68312	 68317	 0.010707	 0.014593	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68312	 68322	 0.007093	 0.009671	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68312	 68331	 0.0131	 0.014407	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68313	 68315	 0.011929	 0.009436	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68314	 68315	 0.002293	 0.0058	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68315	 68322	 0.003643	 0.008464	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78661	 68315	 0.008371	 0.009814	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68316	 68317	 0.0066	 0.012271	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68316	 68319	 0.007014	 0.016107	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68317	 68318	 0.0175	 0.01385	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68317	 68334	 0.017564	 0.015736	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68320	 68322	 0.004579	 0.00805	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68320	 78664	 0.009236	 0.010157	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68320	 78665	 0.0065	 0.011436	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78661	 68321	 0.004829	 0.008971	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78660	 68323	 0.004821	 0.009457	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68323	 78662	 0.005186	 0.008271	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68324	 68325	 0.000607	 0.002436	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68324	 78662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68324	 78662	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68325	 78663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68325	 78663	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68326	 68350	 0.011229	 0.009243	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78658	 68326	 0.011136	 0.01005	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68327	 68333	 0.000857	 0.003057	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68327	 68345	 0.0024	 0.008243	 0.00197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68327	 78664	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68327	 78664	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78663	 68328	 0.01145	 0.010329	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78664	 68328	 0.016243	 0.011507	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68329	 68338	 0.011964	 0.00985	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78663	 68329	 0.010186	 0.017921	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78664	 68329	 0.007721	 0.010521	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68330	 68331	 0.010021	 0.00825	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68330	 68334	 0.00875	 0.0079	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68331	 78665	 0.011821	 0.008379	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68332	 68337	 0.008636	 0.007736	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78664	 68332	 0.010157	 0.018329	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68332	 78665	 0.010607	 0.008393	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68333	 68343	 0.004036	 0.010364	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68333	 68344	 0.003171	 0.009186	 0.00221	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68333	 78665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68333	 78665	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68333	 79837	 0.013529	 0.053193	 0.01392	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68334	 68335	 0.008957	 0.0088	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68334	 68340	 0.020964	 0.013571	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78665	 68334	 0.024314	 0.020014	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68335	 68336	 0.013579	 0.016857	 0.00036	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68336	 68341	 0.023764	 0.017179	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68337	 78668	 0.018486	 0.013093	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68338	 78667	 0.010493	 0.013786	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78665	 68339	 0.027393	 0.019407	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68340	 70351	 0.015221	 0.010786	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68341	 70188	 0.0364	 0.028529	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68342	 78666	 0.019779	 0.01565	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68342	 78668	 0.013364	 0.013129	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68343	 70189	 0.001829	 0.007129	 0.0019	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68343	 78666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68343	 78666	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68344	 68345	 0.001929	 0.004643	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68344	 68363	 0.001964	 0.006879	 0.00228	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68344	 78667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68344	 78667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68345	 78668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68345	 78668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68346	 68347	 0.007921	 0.016279	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68346	 78672	 0.007043	 0.014471	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78668	 68347	 0.007879	 0.016186	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68348	 78669	 0.0095	 0.008571	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68348	 78670	 0.017286	 0.012243	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68349	 68352	 0.000507	 0.002071	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68349	 68356	 0.000557	 0.0022	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68349	 78669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68349	 78669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68350	 68354	 0.018814	 0.012179	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68351	 68352	 0.0003	 0.001157	 0.00031	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68353	 68355	 0.014407	 0.011857	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78659	 68353	 0.009621	 0.019043	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78667	 68354	 0.033764	 0.024407	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68355	 78670	 0.006429	 0.006493	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68356	 68357	 0.000257	 0.001057	 0.00025	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68356	 78670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68356	 78670	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68357	 68358	 0.000621	 0.002264	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68358	 68359	 0.000986	 0.003957	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68359	 68360	 0.001907	 0.005121	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68359	 68371	 0.001221	 0.004907	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68359	 78671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68359	 78671	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68360	 68361	 0.001536	 0.006036	 0.00158	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68360	 68863	 0.002736	 0.011307	 0.00267	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68361	 68362	 0.000979	 0.0038	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68362	 68363	 0.000943	 0.003764	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68363	 78672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68363	 78672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68364	 68365	 0.000371	 0.001471	 0.00039	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68364	 68437	 0.006564	 0.026279	 0.00662	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68364	 78673	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68364	 78673	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68365	 68366	 0.000643	 0.002586	 0.00065	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68366	 68370	 0.000607	 0.002393	 0.00063	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68366	 78674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68366	 78674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78674	 68367	 0.008964	 0.0058	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68368	 68370	 0.000629	 0.002464	 0.00064	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68368	 68371	 0.000757	 0.003086	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68368	 78675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68368	 78675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78674	 68369	 0.007257	 0.010579	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78675	 68369	 0.002564	 0.00735	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68369	 78676	 0.003257	 0.005486	 8e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68370	 78676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68370	 78676	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68371	 78677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68371	 78677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78671	 68372	 0.034436	 0.024393	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78677	 68372	 0.025636	 0.0166	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78675	 68373	 0.023986	 0.015529	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78674	 68374	 0.024664	 0.019521	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68375	 69088	 0.000521	 0.002371	 0.00082	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68375	 78678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68375	 78678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68376	 68377	 0.014393	 0.014136	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68376	 68381	 0.008007	 0.005179	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68377	 78679	 0.012686	 0.008986	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68378	 68379	 0.000521	 0.001814	 0.00042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68379	 68380	 0.001393	 0.004779	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68380	 68384	 0.000786	 0.002993	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68380	 78679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68380	 78679	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68381	 68382	 0.007571	 0.005364	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68382	 78680	 0.019671	 0.013936	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68383	 68490	 0.00735	 0.015107	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68383	 78816	 0.005321	 0.010936	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68384	 68491	 0.002293	 0.008707	 0.00244	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68384	 69088	 0.002686	 0.006964	 0.00169	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68384	 78680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68384	 78680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78679	 68385	 0.024293	 0.015729	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68386	 68859	 0.014736	 0.023521	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78673	 68386	 0.007107	 0.016121	 0.00032	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68387	 68389	 0.014264	 0.010107	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68388	 68389	 0.004907	 0.012421	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68388	 68415	 0.0062	 0.011186	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68388	 69053	 0.005336	 0.010971	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68389	 68390	 0.021657	 0.015343	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68389	 69032	 0.015157	 0.023221	 0.00033	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68389	 78681	 0.004264	 0.008357	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68391	 69054	 0.002264	 0.0079	 0.00183	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68391	 78681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68391	 78681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68392	 68393	 0.015736	 0.01245	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68392	 68395	 0.003379	 0.006936	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68392	 69419	 0.00935	 0.014021	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68392	 69438	 0.009493	 0.024393	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78681	 68392	 0.008229	 0.024764	 0.00049	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68393	 68394	 0.009064	 0.006421	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68395	 68404	 0.002429	 0.004507	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68396	 68398	 0.015029	 0.011893	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78681	 68397	 0.016614	 0.011771	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68398	 68401	 0.00735	 0.006629	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78681	 68398	 0.010793	 0.012657	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68399	 68401	 0.005407	 0.007879	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68399	 68416	 0.009921	 0.008164	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78681	 68399	 0.010043	 0.009057	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68400	 68416	 0.007836	 0.00555	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68400	 68417	 0.013893	 0.009836	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78681	 68400	 0.011021	 0.007807	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68401	 68402	 0.002057	 0.005286	 8e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68402	 68407	 0.002379	 0.004429	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68403	 68404	 0.002186	 0.004486	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68403	 68407	 0.003557	 0.007314	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68405	 68406	 0.001957	 0.004471	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68405	 68407	 0.0034	 0.007779	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68406	 68532	 0.003043	 0.006957	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68407	 68408	 0.005586	 0.003957	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68407	 68409	 0.017257	 0.011171	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68407	 68417	 0.012693	 0.0236	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68409	 68410	 0.018207	 0.014414	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68410	 68412	 0.00375	 0.010764	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68410	 68413	 0.008757	 0.006207	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68410	 68524	 0.003807	 0.008636	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68411	 68425	 0.009621	 0.006957	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68412	 68418	 0.022236	 0.0144	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68412	 68423	 0.005429	 0.011164	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68413	 68414	 0.007	 0.004957	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68414	 68511	 0.004143	 0.009621	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68414	 68518	 0.003743	 0.008557	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68415	 69053	 0.004136	 0.0096	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68415	 78683	 0.014736	 0.020107	 0.00036	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68416	 68417	 0.003336	 0.004543	 0.0001	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68416	 68418	 0.008643	 0.0078	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68417	 68420	 0.004179	 0.008593	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68417	 78683	 0.0076	 0.017636	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68419	 69064	 0.002729	 0.008029	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68419	 78682	 0.010393	 0.008229	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68419	 78683	 0.002986	 0.0102	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68420	 78683	 0.00445	 0.008279	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68421	 68422	 0.000836	 0.002207	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68421	 69063	 0.001293	 0.003521	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68421	 78682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68421	 78682	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68422	 78683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68422	 78683	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78683	 68423	 0.003064	 0.006293	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68424	 68431	 0.010943	 0.008657	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68425	 68426	 0.003843	 0.0079	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68425	 68511	 0.005171	 0.010629	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68426	 68427	 0.01295	 0.008386	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68426	 68496	 0.015471	 0.018136	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68426	 68513	 0.017193	 0.012179	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68426	 78807	 0.00855	 0.029207	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68428	 68437	 0.004943	 0.013543	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68428	 69046	 0.001043	 0.004164	 0.00105	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68428	 69060	 0.000593	 0.003064	 0.00075	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68428	 78684	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68428	 78684	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68428	 78697	 0.0093	 0.031343	 0.00779	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68429	 68497	 0.009764	 0.006321	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68430	 68433	 0.013143	 0.0104	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68431	 78807	 0.018507	 0.011986	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68432	 68433	 0.004771	 0.007614	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68432	 68499	 0.006407	 0.007507	 0.00013	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68433	 68435	 0.007714	 0.006957	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68433	 68497	 0.0055	 0.008779	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78684	 68433	 0.007893	 0.024207	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68434	 68463	 0.008093	 0.005236	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68435	 68452	 0.013957	 0.013707	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68436	 68450	 0.0111	 0.009136	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68436	 68451	 0.0057	 0.010029	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68436	 78685	 0.004471	 0.014921	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68437	 68438	 0.000829	 0.003307	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68437	 68440	 0.001093	 0.004257	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68437	 78685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68437	 78685	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68438	 68460	 0.000529	 0.002007	 0.00056	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68439	 68448	 0.009957	 0.008193	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78685	 68439	 0.005671	 0.011657	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68440	 69088	 0.001129	 0.004114	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68441	 68449	 0.011593	 0.010386	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68441	 68489	 0.011414	 0.01255	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68442	 68446	 0.000464	 0.001829	 0.00048	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68442	 68491	 0.001007	 0.00415	 0.00098	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68442	 68662	 0.002893	 0.007443	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68442	 78686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68442	 78686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68443	 68446	 0.000543	 0.0014	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68443	 70138	 0.000507	 0.001386	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68444	 68445	 0.004686	 0.003314	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68445	 68447	 0.003386	 0.004621	 9e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68445	 78687	 0.002943	 0.004014	 9e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68446	 68477	 0.001643	 0.004214	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68446	 78687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68446	 78687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68447	 68455	 0.008329	 0.006857	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68447	 78691	 0.004643	 0.010779	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68448	 68455	 0.007129	 0.0072	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68449	 68455	 0.006207	 0.0056	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68450	 68453	 0.006164	 0.005557	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68450	 78689	 0.009814	 0.00695	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68451	 68452	 0.005843	 0.004621	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68451	 68454	 0.002264	 0.003614	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68452	 68453	 0.003036	 0.00485	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68453	 78689	 0.013857	 0.010857	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68454	 68461	 0.002329	 0.0034	 8e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68456	 68457	 0.005621	 0.004629	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68456	 78688	 0.007286	 0.004721	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68456	 78690	 0.009829	 0.006964	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68457	 78691	 0.009836	 0.008871	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68458	 68461	 0.010671	 0.006907	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68458	 68462	 0.010564	 0.008357	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68458	 78688	 0.002721	 0.0056	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68459	 68460	 0.000771	 0.002107	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68459	 78688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68459	 78688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68460	 68482	 0.002136	 0.006514	 0.00141	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68460	 78689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68460	 78689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68461	 68462	 0.005907	 0.004186	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68461	 68463	 0.00545	 0.008171	 0.00015	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68462	 68471	 0.010693	 0.006921	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68462	 68472	 0.003736	 0.0051	 9e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68463	 68465	 0.009343	 0.006614	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68463	 68467	 0.00415	 0.006629	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78684	 68463	 0.014686	 0.043179	 0.00089	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68464	 68465	 0.005857	 0.004636	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68466	 68467	 0.003343	 0.00415	 9e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68466	 68508	 0.004736	 0.006221	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68467	 68468	 0.012071	 0.007814	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68467	 68499	 0.007979	 0.00565	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68468	 68469	 0.002914	 0.004464	 6e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68468	 68470	 0.006357	 0.006786	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68469	 68488	 0.004821	 0.00515	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68470	 68472	 0.004564	 0.006221	 0.00011	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68471	 68474	 0.009414	 0.006664	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68471	 68485	 0.011414	 0.008086	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68473	 68474	 0.007164	 0.004643	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68473	 78690	 0.011486	 0.010364	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68475	 68476	 0.0004	 0.001064	 0.00025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68475	 68477	 0.001	 0.002636	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68475	 78690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68475	 78690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68476	 68478	 0.001036	 0.002664	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68476	 68482	 0.001071	 0.002579	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68477	 68478	 0.000771	 0.001786	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68477	 68657	 0.001779	 0.004471	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68477	 69084	 0.0044	 0.017621	 0.00444	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68477	 78691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68477	 78691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68478	 68657	 0.001014	 0.002757	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68478	 78692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68478	 78692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78692	 68479	 0.011586	 0.008207	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68480	 68658	 0.009093	 0.005886	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68480	 79089	 0.009464	 0.0067	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78692	 68481	 0.008929	 0.010471	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68481	 78693	 0.008129	 0.008679	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68482	 68620	 0.00055	 0.002264	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68482	 78693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68482	 78693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68483	 68484	 0.002486	 0.003986	 7e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78693	 68483	 0.0034	 0.005429	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68484	 68485	 0.002421	 0.003529	 8e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68485	 68486	 0.00185	 0.005436	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78693	 68485	 0.008664	 0.013893	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68486	 68487	 0.001857	 0.003821	 7e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68486	 68488	 0.005443	 0.006757	 0.00015	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68487	 68615	 0.001779	 0.003657	 7e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68488	 68510	 0.003193	 0.005121	 9e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68489	 68490	 0.006157	 0.01145	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78687	 68489	 0.008714	 0.010814	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68490	 78694	 0.010186	 0.018371	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68491	 78694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68491	 78694	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68492	 68858	 0.007893	 0.014671	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78694	 68492	 0.0053	 0.010893	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68493	 68494	 0.010343	 0.007329	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68494	 79090	 0.013771	 0.0109	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68495	 68662	 0.0007	 0.00185	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68495	 70142	 0.001114	 0.00295	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68496	 68501	 0.010229	 0.01395	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68497	 68498	 0.009364	 0.007407	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68498	 68499	 0.009121	 0.007214	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68499	 68500	 0.005536	 0.011371	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68500	 68501	 0.005193	 0.008293	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68501	 68502	 0.004486	 0.007893	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68501	 68514	 0.012793	 0.009064	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68502	 68503	 0.004	 0.007921	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68503	 68504	 0.002686	 0.004293	 0.0001	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68503	 68507	 0.002693	 0.005529	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68503	 68581	 0.00805	 0.016543	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68503	 68586	 0.007329	 0.006036	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68504	 68515	 0.0029	 0.005736	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68505	 68507	 0.008236	 0.005829	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68506	 68507	 0.002293	 0.005329	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68506	 68509	 0.004707	 0.005514	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68506	 68510	 0.003386	 0.005071	 9e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68508	 68509	 0.003257	 0.003479	 7e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68511	 70361	 0.017957	 0.014207	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68512	 68514	 0.007643	 0.00495	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68515	 68581	 0.007021	 0.011257	 0.00021	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68516	 68517	 0.002593	 0.005329	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68516	 68581	 0.003364	 0.007807	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68517	 68564	 0.009657	 0.013171	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68517	 68571	 0.003714	 0.006907	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68518	 68524	 0.015329	 0.013829	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68518	 68525	 0.003064	 0.013643	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68519	 68522	 0.008479	 0.006	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68520	 68522	 0.007064	 0.013993	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68520	 68534	 0.005029	 0.010329	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68521	 68526	 0.009236	 0.006543	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68522	 68524	 0.004764	 0.00885	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68523	 68524	 0.0147	 0.009521	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68525	 68527	 0.003821	 0.008871	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68525	 68544	 0.004664	 0.011821	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68525	 68565	 0.006964	 0.014321	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68526	 68527	 0.005357	 0.006279	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68527	 68543	 0.003471	 0.007129	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68528	 68530	 0.004257	 0.007486	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68528	 68532	 0.005686	 0.009121	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68529	 68535	 0.010486	 0.009464	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68529	 69437	 0.013993	 0.011514	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68530	 68536	 0.003164	 0.005571	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68531	 68532	 0.009621	 0.011279	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68531	 68533	 0.0096	 0.0086	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68533	 68538	 0.011029	 0.010836	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68534	 78895	 0.005129	 0.009536	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68535	 68539	 0.012186	 0.010993	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68535	 69441	 0.011571	 0.012729	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68536	 68539	 0.006836	 0.010243	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68537	 68539	 0.009886	 0.0064	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68538	 68540	 0.00715	 0.008386	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68538	 78895	 0.004107	 0.014371	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68539	 69466	 0.006179	 0.012707	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68539	 78895	 0.008943	 0.025657	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68541	 68542	 0.003929	 0.006279	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68541	 78895	 0.011821	 0.011614	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68542	 68546	 0.002621	 0.004614	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68543	 78895	 0.009307	 0.0173	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68544	 68545	 0.004971	 0.009236	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68544	 68567	 0.0043	 0.01105	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68545	 68554	 0.003536	 0.006571	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68546	 68547	 0.001771	 0.003293	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68547	 68552	 0.003443	 0.003671	 8e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68547	 68553	 0.008536	 0.009114	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68548	 68550	 0.004079	 0.006507	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68548	 69574	 0.004036	 0.007286	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68549	 68558	 0.003793	 0.007764	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68549	 69577	 0.002507	 0.00645	 0.0001	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68550	 68552	 0.005729	 0.008771	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68550	 68558	 0.004807	 0.009836	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68551	 68558	 0.008964	 0.005807	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68553	 68568	 0.009593	 0.017314	 0.00025	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68554	 68555	 0.005571	 0.00395	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68554	 68556	 0.004629	 0.008607	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68556	 68557	 0.003143	 0.006436	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68557	 68558	 0.003286	 0.008314	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68557	 68562	 0.002957	 0.0067	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68558	 68559	 0.0015	 0.005821	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68558	 68560	 0.011586	 0.008207	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68558	 78696	 0.004143	 0.013829	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68559	 78696	 0.002	 0.006136	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68561	 69582	 0.002986	 0.010457	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68561	 69622	 0.014586	 0.028886	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68561	 78696	 0.002057	 0.01105	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68562	 68568	 0.002421	 0.008479	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68562	 78696	 0.000814	 0.00555	 0.00014	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68563	 69602	 2.1e-05	 0.000271	 0.02016	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68563	 78695	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68564	 68565	 0.012871	 0.012643	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68565	 68572	 0.003357	 0.006243	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68565	 78698	 0.007321	 0.025014	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78695	 68566	 0.000336	 0.002236	 0.00421	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68566	 78697	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78698	 68566	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78698	 68567	 0.007414	 0.019064	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78698	 68568	 0.002757	 0.008479	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68569	 68570	 0.00205	 0.006836	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68569	 68575	 0.002043	 0.004679	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68570	 68736	 0.005636	 0.008993	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78698	 68570	 0.002393	 0.010607	 0.00032	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68572	 68573	 0.008407	 0.00595	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68574	 68575	 0.0017	 0.003164	 7e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68574	 68578	 0.002793	 0.006329	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68574	 78699	 0.0042	 0.009757	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68576	 68577	 0.003729	 0.007379	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68576	 68581	 0.008821	 0.013521	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68577	 68578	 0.001657	 0.003393	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68577	 68581	 0.00445	 0.007143	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68579	 68609	 0.000621	 0.002571	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78697	 68579	 0.002014	 0.007836	 0.00209	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68579	 78699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68579	 78699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68580	 68726	 0.009793	 0.006336	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78699	 68580	 0.010443	 0.006757	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68581	 68583	 0.003907	 0.006579	 9e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68582	 68583	 0.003943	 0.003557	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68582	 68599	 0.003529	 0.003186	 5e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68584	 68585	 0.008529	 0.005521	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68584	 68586	 0.01005	 0.006507	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68584	 68595	 0.003207	 0.005643	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68586	 68587	 0.0049	 0.00495	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68587	 68589	 0.006021	 0.005429	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68588	 68589	 0.006436	 0.004557	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68588	 68612	 0.005057	 0.003279	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68589	 68611	 0.014971	 0.010821	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68590	 68591	 0.005164	 0.003343	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68590	 68611	 0.007057	 0.005586	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68591	 68593	 0.003407	 0.002207	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68592	 68595	 0.004386	 0.003107	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68593	 68595	 0.004707	 0.006186	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68594	 68595	 0.000979	 0.003336	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68594	 68597	 0.002121	 0.004357	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68594	 68602	 0.008664	 0.008686	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68594	 68604	 0.002364	 0.00345	 8e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68595	 68596	 0.004386	 0.003107	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68597	 68598	 0.003279	 0.004314	 6e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68597	 68601	 0.007279	 0.005157	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78699	 68597	 0.00385	 0.009757	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68598	 68599	 0.003536	 0.002907	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68598	 68600	 0.006129	 0.00485	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68602	 68634	 0.00645	 0.005307	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68603	 68604	 0.001936	 0.003086	 7e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68603	 68606	 0.002493	 0.004943	 7e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68605	 68607	 0.004407	 0.004329	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68605	 68654	 0.0062	 0.005593	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68606	 68607	 0.005357	 0.005264	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68606	 68608	 0.005671	 0.004014	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68606	 78700	 0.003236	 0.005164	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68609	 68643	 0.003121	 0.010521	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68609	 68704	 0.001529	 0.004036	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68609	 78700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68609	 78700	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68610	 68646	 0.00115	 0.002979	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68610	 68657	 0.001029	 0.002721	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68610	 78701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68610	 78701	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68611	 68613	 0.004571	 0.008036	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68611	 68628	 0.003393	 0.004629	 0.0001	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68611	 68630	 0.008921	 0.005779	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68611	 68633	 0.007314	 0.0066	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78699	 68611	 0.022714	 0.0348	 0.00049	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68612	 68613	 0.00395	 0.00325	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68613	 68615	 0.002243	 0.004164	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68613	 68617	 0.0072	 0.0051	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68614	 68619	 0.006721	 0.00435	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68616	 68619	 0.006579	 0.004257	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68618	 68619	 0.004507	 0.004064	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68618	 78702	 0.007514	 0.007386	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68619	 68625	 0.008857	 0.005736	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68620	 68643	 0.001071	 0.003586	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68620	 78702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68620	 78702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68621	 68622	 0.00965	 0.00625	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78702	 68621	 0.012271	 0.007943	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68621	 78704	 0.015129	 0.011979	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68622	 68623	 0.004521	 0.003721	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68622	 68626	 0.003893	 0.004564	 8e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78702	 68622	 0.006986	 0.006264	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68623	 78703	 0.002507	 0.004957	 7e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68624	 68631	 0.003736	 0.005093	 0.00011	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68624	 78703	 0.005107	 0.008157	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68625	 68626	 0.004136	 0.004064	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68625	 68627	 0.001557	 0.003193	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68627	 68629	 0.001557	 0.002493	 6e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68627	 68631	 0.005871	 0.00465	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68628	 68629	 0.001386	 0.002221	 4e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68631	 68636	 0.002714	 0.0037	 8e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68632	 68634	 0.002214	 0.004379	 6e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68632	 68638	 0.005814	 0.005714	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68632	 68654	 0.001179	 0.002414	 6e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68633	 68634	 0.001593	 0.003279	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68633	 68635	 0.001586	 0.002536	 6e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68635	 68636	 0.002214	 0.003529	 8e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68636	 68639	 0.005793	 0.00375	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68637	 68638	 0.004214	 0.003807	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68637	 68640	 0.005107	 0.003621	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68639	 68640	 0.004329	 0.003907	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68639	 68642	 0.002443	 0.003907	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68641	 68642	 0.004679	 0.003314	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68642	 68650	 0.010207	 0.008079	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68642	 78703	 0.002943	 0.006757	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68643	 68644	 0.000393	 0.000993	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68643	 70139	 0.004921	 0.013	 0.00304	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68643	 78703	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68643	 78703	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68644	 68649	 0.000636	 0.001679	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68644	 68709	 0.001229	 0.00335	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68645	 68648	 0.002607	 0.005357	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78703	 68645	 0.008893	 0.008021	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68645	 78704	 0.006693	 0.007843	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68645	 78706	 0.010664	 0.007557	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68646	 68647	 0.000843	 0.002114	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68646	 78704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68646	 78704	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68647	 68682	 0.0013	 0.003364	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68647	 78705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68647	 78705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78705	 68648	 0.005721	 0.008579	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68648	 78715	 0.009586	 0.007514	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68649	 68709	 0.000614	 0.001664	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68649	 78706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68649	 78706	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68650	 68651	 0.004514	 0.003714	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68651	 68652	 0.005457	 0.005829	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68651	 68705	 0.00895	 0.005793	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68651	 68708	 0.004621	 0.006014	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68652	 68655	 0.006043	 0.010186	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68653	 68655	 0.007964	 0.005643	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68654	 68655	 0.001314	 0.004379	 7e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68655	 68703	 0.001007	 0.003514	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78700	 68655	 0.008036	 0.014129	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78692	 68656	 0.013693	 0.012271	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68656	 78707	 0.0081	 0.0097	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68658	 78707	 0.011221	 0.008886	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68659	 68661	 0.0006	 0.001629	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68659	 78707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68659	 78707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68660	 68668	 0.008064	 0.005714	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68660	 78709	 0.006029	 0.005921	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68661	 68662	 0.00125	 0.003421	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68661	 68667	 0.000357	 0.00095	 0.00021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68661	 68671	 0.001064	 0.002736	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68661	 68680	 0.002193	 0.005514	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68662	 78708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68662	 78708	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78708	 68663	 0.010186	 0.008064	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68663	 78710	 0.011793	 0.008357	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68664	 68666	 0.007521	 0.006786	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78708	 68664	 0.010171	 0.006586	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68665	 68666	 0.0098	 0.006343	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68666	 79090	 0.01355	 0.009793	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68666	 79091	 0.0078	 0.005521	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68667	 78709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68667	 78709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68669	 68670	 0.006814	 0.0095	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78705	 68669	 0.00635	 0.008664	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78709	 68670	 0.005857	 0.008779	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68671	 68676	 0.001114	 0.003043	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68671	 78710	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68671	 78710	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68672	 68678	 0.0008	 0.002107	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68672	 70149	 0.000871	 0.002186	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68672	 78711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68672	 78711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68673	 68677	 0.0167	 0.012071	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78711	 68673	 0.007271	 0.00515	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68673	 79091	 0.004957	 0.007221	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68673	 79092	 0.004171	 0.005686	 0.0001	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68674	 68676	 0.000836	 0.002243	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68674	 68678	 0.0008	 0.001921	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68674	 78712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68674	 78712	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78711	 68675	 0.009493	 0.008564	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68675	 78713	 0.013786	 0.010807	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68676	 78713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68676	 78713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68677	 68905	 0.017636	 0.017321	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78711	 68677	 0.011986	 0.008486	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68678	 68909	 0.000771	 0.002171	 0.00056	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68679	 68685	 0.010814	 0.007	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78713	 68679	 0.011593	 0.008214	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68680	 68683	 0.000757	 0.001957	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68680	 78714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68680	 78714	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68681	 68684	 0.003093	 0.005757	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78705	 68681	 0.006364	 0.0079	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68681	 78715	 0.00385	 0.005614	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68681	 78724	 0.004771	 0.009757	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68682	 68691	 0.000679	 0.001786	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68682	 68709	 0.000593	 0.001614	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68682	 78715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68682	 78715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68683	 68688	 0.000621	 0.00165	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68683	 78716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68683	 78716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68684	 68689	 0.009943	 0.006436	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78714	 68684	 0.01005	 0.009007	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78716	 68684	 0.00705	 0.006314	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68685	 68686	 0.010421	 0.006743	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68685	 68687	 0.005736	 0.006721	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68685	 68700	 0.02705	 0.019157	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78713	 68685	 0.01655	 0.010714	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68686	 68687	 0.011629	 0.008236	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68686	 68699	 0.011743	 0.007607	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68687	 78717	 0.003264	 0.007586	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68688	 68701	 0.001064	 0.002464	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68688	 78717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68688	 78717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68689	 68690	 0.003779	 0.004429	 8e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68689	 68695	 0.017293	 0.01225	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68690	 78721	 0.006164	 0.008407	 0.00015	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68691	 68692	 0.000564	 0.00155	 0.00034	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68692	 68693	 0.000507	 0.0015	 0.00035	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68692	 78718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68692	 78718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68693	 68694	 0.0006	 0.001507	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68693	 68720	 0.000836	 0.002607	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68694	 68781	 0.001014	 0.002436	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68694	 78719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68694	 78719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78718	 68695	 0.010743	 0.011814	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78719	 68695	 0.003929	 0.009114	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68695	 78720	 0.015029	 0.01065	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68695	 78721	 0.003529	 0.007257	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68696	 68701	 0.000771	 0.002107	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68696	 68796	 0.000636	 0.001643	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68696	 78720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68696	 78720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68697	 68698	 0.003764	 0.006336	 9e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68697	 78721	 0.004929	 0.008807	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68698	 68699	 0.0032	 0.004671	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68699	 78722	 0.003929	 0.009114	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68700	 68920	 0.007136	 0.010936	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68700	 78722	 0.005121	 0.006993	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68701	 78721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68701	 78721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68702	 70172	 0.00165	 0.004486	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68702	 78722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68702	 78722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68703	 78723	 0.000886	 0.003086	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68704	 68714	 0.000564	 0.001414	 0.00036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68704	 78723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68704	 78723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68706	 68707	 0.009371	 0.012779	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68706	 78725	 0.004079	 0.007357	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68707	 68710	 0.012921	 0.008364	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68707	 68711	 0.00235	 0.00375	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68707	 78724	 0.001514	 0.004014	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68708	 78724	 0.004121	 0.00585	 9e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68709	 68768	 0.003871	 0.0121	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68709	 78724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68709	 78724	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68710	 68719	 0.009193	 0.007279	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68711	 68712	 0.003107	 0.004964	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68712	 68713	 0.004379	 0.006986	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68712	 68722	 0.007014	 0.004964	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68713	 78725	 0.002914	 0.00465	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68714	 68760	 0.00225	 0.008007	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68714	 78725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68714	 78725	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68715	 68716	 0.009043	 0.007157	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68716	 68718	 0.007271	 0.004707	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68717	 68718	 0.007229	 0.005121	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68718	 68724	 0.011607	 0.007514	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68718	 68727	 0.006014	 0.015943	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68718	 68763	 0.028186	 0.022307	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78725	 68718	 0.01915	 0.01515	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68719	 78726	 0.00785	 0.00785	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68720	 68723	 0.000614	 0.002171	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68720	 68764	 0.000814	 0.002093	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68720	 78726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68720	 78726	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68721	 68722	 0.004479	 0.004529	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68721	 78727	 0.003857	 0.006186	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68723	 68768	 0.001571	 0.005986	 0.00168	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68723	 78727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68723	 78727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78727	 68724	 0.008957	 0.007371	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68725	 68734	 0.011464	 0.007421	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68725	 68762	 0.0114	 0.008079	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68726	 68727	 0.008321	 0.00685	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68727	 68732	 0.00655	 0.006993	 0.00015	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68727	 68734	 0.016686	 0.0108	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68727	 68737	 0.004136	 0.009593	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68727	 78728	 0.008243	 0.016936	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68728	 68730	 0.005757	 0.004557	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68729	 68730	 0.005164	 0.003343	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68730	 68731	 0.006129	 0.006543	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78700	 68730	 0.01425	 0.009229	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78723	 68730	 0.009471	 0.006129	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68731	 68732	 0.005379	 0.004429	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68733	 68734	 0.004771	 0.007614	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68733	 78729	 0.011729	 0.011843	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68735	 68739	 0.000857	 0.003493	 0.00085	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78697	 68735	 0.000757	 0.004436	 0.00121	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68735	 78728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68735	 78728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78728	 68736	 0.006079	 0.008286	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68737	 78729	 0.008529	 0.007693	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78728	 68738	 0.010043	 0.007114	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68739	 68760	 0.001029	 0.003364	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68739	 78729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68739	 78729	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68740	 68741	 0.005643	 0.005543	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78728	 68740	 0.010579	 0.008293	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68741	 68743	 0.005186	 0.006079	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68742	 68753	 0.016786	 0.010864	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68743	 68744	 0.003414	 0.005121	 9e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68744	 68751	 0.004314	 0.006886	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68745	 68746	 0.002229	 0.003914	 7e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78729	 68745	 0.004807	 0.005971	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68746	 68750	 0.002379	 0.004421	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68747	 68748	 0.009607	 0.006807	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68748	 68749	 0.002129	 0.004864	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68748	 68769	 0.002843	 0.005	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68749	 68750	 0.001921	 0.006571	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68750	 68751	 0.002786	 0.006371	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68751	 68752	 0.001814	 0.003729	 7e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68751	 68755	 0.0033	 0.008479	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68751	 68756	 0.006886	 0.005664	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68752	 68753	 0.002793	 0.005736	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68753	 78730	 0.003193	 0.008207	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68754	 68759	 0.0009	 0.004257	 0.00102	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68754	 69608	 0.000693	 0.001993	 0.00049	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68754	 78730	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68754	 78730	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78730	 68755	 0.002557	 0.006771	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68756	 78732	 0.00655	 0.007207	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68757	 78731	 0.009429	 0.006107	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68758	 68759	 0.000514	 0.002057	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68758	 68772	 0.000993	 0.003779	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68758	 68779	 0.000536	 0.00175	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68758	 78731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68758	 78731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68759	 78732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68759	 78732	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68760	 68768	 0.001107	 0.002879	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68761	 68762	 0.002436	 0.008121	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68761	 68763	 0.002157	 0.006193	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68762	 68767	 0.011714	 0.0083	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68762	 68769	 0.006129	 0.012593	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68763	 68766	 0.003614	 0.010371	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78726	 68763	 0.005207	 0.009679	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68763	 78733	 0.003114	 0.007064	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68764	 68765	 0.000829	 0.002236	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68764	 78733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68764	 78733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68765	 68775	 0.000879	 0.002314	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68766	 68773	 0.001571	 0.005364	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68767	 78734	 0.005457	 0.005029	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68768	 68772	 0.00055	 0.002136	 0.00057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68768	 68779	 0.001136	 0.004557	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68768	 78734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68768	 78734	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68769	 78735	 0.005557	 0.007571	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68770	 68772	 0.000607	 0.001557	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68770	 78735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68770	 78735	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68771	 68773	 0.003743	 0.007693	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68771	 78736	 0.005564	 0.004579	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68772	 68778	 0.000836	 0.0022	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68772	 78736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68772	 78736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68773	 68774	 0.006964	 0.005514	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68774	 68777	 0.003857	 0.005786	 0.00011	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68775	 68776	 0.000807	 0.002171	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68775	 68785	 0.001736	 0.004471	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68776	 68802	 0.000721	 0.001686	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68777	 78744	 0.008014	 0.009393	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68777	 78745	 0.0104	 0.007364	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68778	 68779	 0.000607	 0.002157	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68778	 68799	 0.000579	 0.0023	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68779	 68818	 0.000736	 0.001943	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68779	 68819	 0.000857	 0.003379	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78733	 68780	 0.0054	 0.009	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68780	 78737	 0.014707	 0.011643	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68781	 68794	 0.000936	 0.002536	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68781	 78737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68781	 78737	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68782	 68784	 0.006329	 0.008321	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68782	 78741	 0.017236	 0.012207	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68783	 68784	 0.00265	 0.004664	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68783	 78738	 0.003586	 0.005721	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68785	 68786	 0.00055	 0.001286	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68785	 78738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68785	 78738	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68786	 69991	 0.002821	 0.006543	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68786	 78739	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68786	 78739	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68787	 68788	 0.006793	 0.005586	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78738	 68787	 0.018357	 0.014529	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68787	 78740	 0.00805	 0.010979	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68787	 78746	 0.005321	 0.0099	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68788	 68789	 0.007314	 0.004736	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78739	 68788	 0.008879	 0.007029	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68789	 69993	 0.010107	 0.008321	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68790	 69993	 0.014814	 0.011721	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68791	 68792	 0.000779	 0.002057	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68791	 68803	 0.0011	 0.002986	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68791	 69989	 0.001007	 0.002664	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68792	 69990	 0.000964	 0.002321	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68792	 78740	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68792	 78740	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78722	 68793	 0.020779	 0.014714	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68794	 68796	 0.000886	 0.002221	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68794	 70183	 0.002557	 0.006157	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68794	 78741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68794	 78741	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68795	 68797	 0.00645	 0.004571	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78741	 68795	 0.018664	 0.013221	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68796	 68798	 0.001371	 0.003671	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68796	 78742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68796	 78742	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78742	 68797	 0.006857	 0.005429	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68798	 78743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68798	 78743	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68799	 68801	 0.000714	 0.001936	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68799	 68804	 0.000857	 0.002221	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68799	 78744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68799	 78744	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78744	 68800	 0.002814	 0.005764	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68800	 78752	 0.002179	 0.004979	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68801	 68805	 0.000829	 0.002136	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68801	 78745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68801	 78745	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68802	 68803	 0.000814	 0.002214	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68802	 78746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68802	 78746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68803	 78747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68803	 78747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68804	 68805	 0.0006	 0.001543	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68804	 78748	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68804	 78748	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68805	 68811	 0.000786	 0.002857	 0.00088	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78748	 68806	 0.007371	 0.004771	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68807	 68808	 0.000679	 0.001743	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68807	 68820	 0.000607	 0.0014	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68807	 78749	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68807	 78749	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68808	 68809	 0.000379	 0.000971	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68809	 68815	 0.000357	 0.00095	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68810	 68814	 0.012064	 0.007807	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78748	 68810	 0.012921	 0.008364	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68811	 69989	 0.00075	 0.002907	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68811	 78750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68811	 78750	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68812	 69984	 0.001286	 0.003236	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68812	 78751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68812	 78751	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68813	 68817	 0.012129	 0.0096	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78750	 68813	 0.0118	 0.007636	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68813	 79032	 0.014593	 0.015586	 0.00033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68814	 79032	 0.010671	 0.008786	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68815	 68816	 0.000429	 0.001179	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68816	 68834	 0.000636	 0.001686	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78751	 68817	 0.014664	 0.011607	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68818	 68820	 0.000807	 0.002071	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68818	 78752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68818	 78752	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68819	 68822	 0.000829	 0.00215	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68819	 78753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68819	 78753	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68819	 78906	 0.002221	 0.010186	 0.00261	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68820	 68821	 0.000393	 0.001279	 0.00034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68820	 68825	 0.000657	 0.0018	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68821	 68822	 0.000607	 0.00215	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68822	 68823	 0.0006	 0.001586	 0.00037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68822	 78754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68822	 78754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68823	 68824	 0.000407	 0.001021	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68824	 68829	 0.000364	 0.000914	 0.00024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68825	 68826	 0.000379	 0.001014	 0.00023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68826	 68827	 0.000371	 0.000871	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68827	 68828	 0.000436	 0.001043	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68828	 68833	 0.000693	 0.001829	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68828	 78755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68828	 78755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68829	 68830	 0.000407	 0.001043	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68830	 68831	 0.000457	 0.001157	 0.0003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68831	 68837	 0.001279	 0.003993	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68831	 69662	 0.000979	 0.003921	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68831	 78756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68831	 78756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68832	 68838	 0.004986	 0.008771	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78756	 68832	 0.002936	 0.0044	 8e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68832	 78923	 0.005636	 0.010471	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68833	 68834	 0.000921	 0.002507	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68834	 68835	 0.000721	 0.001907	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68834	 69975	 0.0008	 0.002243	 0.00058	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68835	 68836	 0.000579	 0.001579	 0.00035	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68836	 68837	 0.000714	 0.002414	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68836	 68846	 0.000443	 0.001357	 0.0003	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68837	 78757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68837	 78757	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78757	 68838	 0.004821	 0.006579	 0.00011	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68839	 68840	 0.000621	 0.00195	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68839	 69664	 0.0007	 0.002393	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68839	 78758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68839	 78758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68840	 68841	 0.0006	 0.001557	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68840	 78759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68840	 78759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68841	 69700	 0.001943	 0.005286	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68841	 78760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68841	 78760	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68842	 68843	 0.006721	 0.0066	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78760	 68842	 0.007814	 0.00705	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68843	 69699	 0.006036	 0.009043	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68844	 68845	 0.000471	 0.001186	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68844	 78761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68844	 78761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68845	 68846	 0.000929	 0.002493	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68845	 78762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68845	 78762	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68846	 69980	 0.000593	 0.002443	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68847	 68848	 0.011814	 0.00935	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78761	 68847	 0.007307	 0.014329	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78762	 68847	 0.012907	 0.008357	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68847	 78937	 0.027364	 0.017721	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68847	 79036	 0.00285	 0.007221	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68848	 68971	 0.009793	 0.006936	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68849	 78937	 0.009714	 0.006879	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68850	 68854	 0.004629	 0.00835	 0.00012	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68850	 68855	 0.003486	 0.007164	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78759	 68850	 0.003071	 0.009021	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68851	 78925	 0.010014	 0.006479	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68852	 68853	 0.000636	 0.001479	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68852	 78763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68852	 78763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68853	 69666	 0.001236	 0.003643	 0.00085	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68853	 78764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68853	 78764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68854	 78936	 0.004879	 0.007786	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68855	 68856	 0.0049	 0.008614	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68855	 78936	 0.01055	 0.011264	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68856	 68857	 0.004571	 0.006664	 0.00015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68856	 78925	 0.019343	 0.0137	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68857	 69694	 0.006493	 0.007143	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68858	 68859	 0.009971	 0.02315	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68859	 68860	 0.019729	 0.016236	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68860	 68861	 0.022307	 0.022529	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68861	 78765	 0.02075	 0.018721	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68861	 78767	 0.048014	 0.031086	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68862	 68863	 0.002064	 0.005307	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68862	 68864	 0.003021	 0.0076	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68862	 78765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68862	 78765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68863	 68864	 0.00315	 0.008836	 0.00227	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68863	 78766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68863	 78766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68864	 68874	 0.001864	 0.004786	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68864	 68875	 0.002436	 0.006436	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68864	 78767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68864	 78767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78767	 68865	 0.019821	 0.012829	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68866	 70366	 0.019871	 0.031714	 0.00073	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78766	 68866	 0.012236	 0.019629	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68867	 68872	 0.0022	 0.010564	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68867	 78769	 0.011271	 0.020957	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68867	 78770	 0.008807	 0.020436	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68867	 78772	 0.006264	 0.014393	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68868	 68869	 0.002507	 0.006621	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68868	 78768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68868	 78768	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68868	 78771	 0.003657	 0.012936	 0.00291	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68868	 79102	 0.004529	 0.017214	 0.00482	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68869	 68870	 0.0008	 0.003207	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68869	 78769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68869	 78769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68869	 79102	 0.005736	 0.022964	 0.00579	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68870	 78770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68870	 78770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68870	 78771	 0.000879	 0.003507	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68871	 70157	 0.000414	 0.002664	 0.00531	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68871	 70186	 0.001614	 0.010936	 0.01991	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68871	 78771	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78772	 68871	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68872	 70153	 0.00195	 0.010479	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68873	 68877	 0.013407	 0.0095	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68873	 78773	 0.0181	 0.012821	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68874	 68875	 0.000579	 0.00145	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68874	 78773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68874	 78773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68875	 68876	 0.000364	 0.001293	 0.00029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68876	 68897	 0.000621	 0.001829	 0.00043	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68876	 78774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68876	 78774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68877	 70160	 0.004129	 0.008486	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78773	 68877	 0.01715	 0.015471	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68878	 70146	 0.007421	 0.0147	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68880	 68887	 0.003364	 0.006657	 0.0001	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68880	 68890	 0.009779	 0.006929	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68882	 68883	 0.003107	 0.0022	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68882	 68884	 0.002943	 0.005471	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68882	 68886	 0.002979	 0.006914	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68885	 68886	 0.002707	 0.005043	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78767	 68885	 0.00795	 0.013979	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78773	 68885	 0.006829	 0.008471	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68887	 68888	 0.002579	 0.004786	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68888	 68896	 0.006221	 0.014436	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68888	 78775	 0.005186	 0.007771	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68889	 68890	 0.007336	 0.005193	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68891	 68892	 0.017214	 0.013621	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68892	 68903	 0.007829	 0.009721	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68892	 68904	 0.007057	 0.006936	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68892	 78775	 0.003064	 0.011964	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68893	 68900	 0.001714	 0.004964	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68893	 78775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68893	 78775	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68894	 78777	 0.010579	 0.008371	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68895	 68899	 0.008943	 0.005793	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68895	 70161	 0.005521	 0.012814	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68895	 78776	 0.003229	 0.005679	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68896	 78776	 0.001907	 0.003929	 7e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68897	 68898	 0.000629	 0.001714	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68897	 78776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68897	 78776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68898	 68900	 0.000871	 0.002386	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68898	 78777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68898	 78777	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78777	 68899	 0.0102	 0.008071	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68900	 68923	 0.001043	 0.0034	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68900	 70164	 0.001093	 0.003857	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68900	 78778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68900	 78778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68901	 68922	 0.007121	 0.0076	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78775	 68901	 0.006043	 0.009693	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78778	 68901	 0.006629	 0.010157	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68902	 68921	 0.010521	 0.006814	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78775	 68902	 0.013136	 0.0085	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68903	 68904	 0.012943	 0.011679	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68903	 70151	 0.005164	 0.010229	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68904	 68907	 0.014229	 0.010079	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68905	 68906	 0.013043	 0.011686	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68905	 68908	 0.008643	 0.0078	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78775	 68905	 0.019486	 0.031257	 0.00058	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68905	 78784	 0.013393	 0.027521	 0.00052	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68906	 70150	 0.014579	 0.011536	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68906	 79092	 0.018214	 0.011793	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68908	 68910	 0.00965	 0.008707	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68909	 68919	 0.000729	 0.002379	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68909	 78779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68909	 78779	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78779	 68910	 0.005479	 0.005536	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68911	 68912	 0.007271	 0.009921	 0.00018	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78779	 68911	 0.006107	 0.010186	 0.00015	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68911	 78780	 0.009921	 0.00785	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68912	 68918	 0.003443	 0.005157	 9e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68913	 68915	 0.006343	 0.004107	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68913	 68930	 0.0082	 0.005307	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68914	 68917	 0.006936	 0.005486	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68914	 78783	 0.004907	 0.006693	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68916	 68917	 0.002579	 0.004536	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68916	 68918	 0.004307	 0.006914	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68917	 78783	 0.009836	 0.0105	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68918	 79098	 0.015657	 0.012393	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68919	 70172	 0.000721	 0.002507	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68919	 78780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68919	 78780	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78712	 68920	 0.013843	 0.01085	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78779	 68920	 0.004986	 0.007264	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68921	 78784	 0.013479	 0.00955	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68922	 78781	 0.008814	 0.006971	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68922	 78782	 0.017164	 0.015379	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68923	 68925	 0.000814	 0.002664	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68923	 68928	 0.0009	 0.003493	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68923	 78781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68923	 78781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68924	 68933	 0.00085	 0.002043	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68924	 70171	 0.001207	 0.0031	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68925	 68934	 0.001179	 0.004714	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68925	 78782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68925	 78782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68926	 68932	 0.007771	 0.012464	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78782	 68926	 0.003764	 0.007	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68926	 78784	 0.00205	 0.005436	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68927	 68928	 0.000414	 0.001657	 0.00041	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68927	 70172	 0.0032	 0.008586	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68927	 78783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68927	 78783	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68928	 78784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68928	 78784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68929	 68930	 0.003486	 0.005557	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68929	 68931	 0.003457	 0.006843	 0.0001	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68929	 70177	 0.013743	 0.010879	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78783	 68930	 0.011371	 0.009357	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68931	 68932	 0.00455	 0.008	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78782	 68932	 0.014393	 0.0102	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68932	 78785	 0.002021	 0.007079	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68933	 70179	 0.001114	 0.003279	 0.00076	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68934	 70179	 0.000343	 0.001193	 0.00039	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68935	 68944	 0.00125	 0.003421	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68935	 70179	 0.000457	 0.001564	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68935	 78791	 0.001314	 0.004279	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68936	 70178	 0.001336	 0.004093	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68936	 78785	 0.001264	 0.005586	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68937	 70179	 0.000679	 0.002329	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68937	 78785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68937	 78785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68938	 68944	 0.000664	 0.002207	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68938	 70170	 0.000657	 0.002136	 0.00056	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68939	 68940	 0.003836	 0.004757	 0.00011	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68939	 68943	 0.005214	 0.007107	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68939	 78789	 0.0082	 0.013093	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68939	 79094	 0.018121	 0.028929	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68940	 78786	 0.003643	 0.006136	 9e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68941	 68942	 0.000121	 0.000829	 0.00141	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68941	 70168	 0.000136	 0.0009	 0.00165	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68941	 78786	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68941	 78786	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68942	 68952	 0.000493	 0.003271	 0.00616	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68942	 78787	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68942	 78787	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68943	 78788	 0.008993	 0.009086	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68943	 78790	 0.017521	 0.012414	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68944	 68945	 0.000643	 0.001671	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68945	 68947	 0.000614	 0.001543	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68945	 78788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68945	 78788	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78787	 68946	 0.000671	 0.001693	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68946	 78789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68946	 78789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68946	 78797	 0.002357	 0.008321	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68947	 68954	 0.000957	 0.002536	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68947	 70180	 0.000936	 0.002929	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68947	 78790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68947	 78790	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78789	 68948	 0.0209	 0.013529	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68948	 78792	 0.040371	 0.026136	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68949	 68950	 0.002307	 0.00585	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68949	 70175	 0.004007	 0.009307	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68949	 70176	 0.007571	 0.006779	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68950	 68955	 0.002186	 0.007214	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68950	 70178	 0.014264	 0.010107	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68951	 68955	 0.003821	 0.007564	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78785	 68951	 0.009707	 0.009536	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68951	 79099	 0.005043	 0.011586	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68952	 78791	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78792	 68952	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68952	 79142	 0.000714	 0.004836	 0.0089	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78792	 68953	 0.015207	 0.012036	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68954	 70179	 0.000607	 0.002036	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78791	 68954	 0.000793	 0.002657	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68955	 68957	 0.005436	 0.01065	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68956	 68957	 0.005843	 0.015014	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68956	 68961	 0.003529	 0.011764	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68956	 70177	 0.011907	 0.031557	 0.0008	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78792	 68956	 0.00555	 0.012686	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68956	 79144	 0.010293	 0.035157	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68958	 68965	 0.00235	 0.008221	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68958	 68966	 0.002736	 0.009343	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68959	 68966	 0.004643	 0.011757	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68959	 70000	 0.013393	 0.009486	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68959	 70182	 0.007014	 0.012336	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68960	 68961	 0.004293	 0.007557	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68960	 78796	 0.004607	 0.010536	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68961	 78793	 0.00875	 0.014029	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68962	 70180	 0.001486	 0.005107	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78791	 68962	 0.0016	 0.005664	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68962	 78793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68962	 78793	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68962	 78794	 0.00085	 0.002871	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68962	 78797	 0.001207	 0.002907	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68962	 79143	 0.002593	 0.008643	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78793	 68963	 0.006979	 0.009521	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68963	 78795	 0.006536	 0.011671	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68964	 68970	 0.000279	 0.001814	 0.00362	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68964	 78794	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78795	 68964	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68964	 79142	 0.000321	 0.00215	 0.00396	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68965	 78796	 0.003464	 0.013864	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68966	 79045	 0.004657	 0.010814	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68967	 79045	 0.008021	 0.012871	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68968	 70004	 0.011957	 0.007736	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68969	 78796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68969	 78796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68969	 79143	 0.00145	 0.004371	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	68970	 78797	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68970	 78797	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68971	 68972	 0.011793	 0.007636	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68972	 78798	 0.016729	 0.010829	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68973	 69700	 0.002286	 0.005514	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68973	 70036	 0.0008	 0.002064	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68973	 78798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68973	 78798	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68974	 69702	 0.005607	 0.011521	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68974	 70037	 0.0113	 0.0093	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68974	 70040	 0.008229	 0.00905	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78798	 68974	 0.022221	 0.015743	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68975	 78938	 0.00765	 0.011464	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68975	 79062	 0.008079	 0.007936	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68976	 70042	 0.003221	 0.006593	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68976	 78799	 0.007143	 0.018357	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68977	 69741	 0.001186	 0.004514	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68977	 78799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68977	 78799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68977	 79086	 0.001357	 0.005421	 0.00136	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68978	 68979	 0.0036	 0.010586	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68978	 69742	 0.013086	 0.015343	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68978	 79087	 0.00385	 0.014986	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68979	 68980	 0.00465	 0.008643	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68979	 69743	 0.008893	 0.014193	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68979	 69745	 0.002014	 0.008921	 0.0002	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	68979	 79088	 0.00255	 0.01265	 0.0003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68980	 69746	 0.002157	 0.010057	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	68980	 70107	 0.003457	 0.008757	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68981	 68991	 0.0063	 0.011721	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68981	 70118	 0.017057	 0.012079	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68981	 70119	 0.001921	 0.009529	 0.00023	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	68981	 78952	 0.007957	 0.018193	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68982	 68991	 0.009764	 0.006914	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68983	 68984	 0.007843	 0.006207	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68983	 70364	 0.017914	 0.012693	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68984	 68991	 0.007214	 0.007286	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68985	 68994	 0.017493	 0.012393	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68986	 68995	 0.002821	 0.007479	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68987	 68988	 0.00425	 0.008736	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68987	 69750	 0.005271	 0.009271	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68987	 0.002864	 0.011021	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68988	 68990	 0.004336	 0.008057	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	68989	 68991	 0.006779	 0.017179	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68989	 0.003929	 0.0131	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	68990	 69746	 0.006571	 0.013014	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68992	 0.009929	 0.007857	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68993	 0.002757	 0.002179	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	68994	 68995	 0.001229	 0.007814	 0.00019	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	68994	 68996	 0.002071	 0.008207	 0.00024	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68994	 0.001514	 0.005293	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68994	 0.001514	 0.005293	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68997	 68998	 0.001193	 0.004171	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68997	 69000	 0.001921	 0.006557	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68998	 0.001443	 0.005043	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68999	 0.004186	 0.014657	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 68999	 0.004186	 0.014657	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	68999	 79145	 0.004986	 0.023243	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69001	 69004	 0.002521	 0.009793	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69002	 69003	 0.002636	 0.006679	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69002	 69007	 0.002586	 0.0076	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69002	 79145	 0.002771	 0.010986	 0.00031	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69003	 69008	 0.003214	 0.007464	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69004	 69005	 0.013379	 0.020293	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69004	 69006	 0.013429	 0.008693	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69004	 69007	 0.003143	 0.010493	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69004	 70136	 0.006129	 0.011393	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69005	 69011	 0.016014	 0.012671	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69008	 69009	 0.003321	 0.008807	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69008	 69010	 0.009664	 0.006843	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69008	 69012	 0.013757	 0.010886	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69008	 70057	 0.010257	 0.006643	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69009	 69013	 0.013164	 0.009329	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69009	 69014	 0.009493	 0.00615	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69009	 69015	 0.010607	 0.006871	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69009	 69018	 0.006586	 0.013479	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69011	 69017	 0.02095	 0.013564	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69016	 69018	 0.016771	 0.011879	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69018	 69020	 0.013529	 0.009586	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69018	 69973	 0.466407	 0.467414	 0.00632	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69019	 69020	 0.005593	 0.003964	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69021	 78800	 0.022993	 0.014886	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69022	 69023	 0.001793	 0.006514	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69022	 69381	 0.001157	 0.004629	 0.00116	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69022	 78800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69022	 78800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69023	 69381	 0.002643	 0.01005	 0.00281	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78800	 69024	 0.025293	 0.017914	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78800	 69025	 0.012414	 0.008793	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69026	 69027	 0.015736	 0.010186	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69027	 69028	 0.008443	 0.013479	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78800	 69027	 0.025279	 0.022807	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69028	 69029	 0.008271	 0.018757	 0.00037	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69029	 69042	 0.011957	 0.027129	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69030	 69031	 0.018607	 0.021814	 0.00038	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69030	 69380	 0.028271	 0.033136	 0.00058	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69030	 78802	 0.020593	 0.0471	 0.00115	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69031	 69032	 0.014621	 0.017143	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69032	 69383	 0.010271	 0.021114	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69033	 69049	 0.020607	 0.013343	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69034	 69049	 0.011993	 0.0085	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69035	 69036	 0.002457	 0.005043	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69035	 69037	 0.005107	 0.009493	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69036	 69047	 0.003036	 0.006236	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69037	 69038	 0.00265	 0.005571	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69037	 69039	 0.001921	 0.007464	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69038	 78802	 0.002436	 0.005	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69039	 69040	 0.003314	 0.011607	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69040	 69042	 0.002479	 0.008679	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69041	 69042	 0.0052	 0.003364	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69042	 69075	 0.002879	 0.009843	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69042	 78801	 0.002271	 0.008843	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69043	 78801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69043	 78801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69044	 69086	 0.003871	 0.0072	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69044	 70360	 0.039336	 0.031129	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78801	 69044	 0.004357	 0.010114	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69045	 78802	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69045	 78802	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69046	 69048	 0.000571	 0.002164	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69046	 78803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69046	 78803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69047	 69050	 0.003357	 0.009879	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78802	 69047	 0.004757	 0.013643	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69047	 78804	 0.003786	 0.006036	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69048	 69056	 0.000886	 0.003093	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69048	 78804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69048	 78804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69049	 69052	 0.007079	 0.008786	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78803	 69049	 0.008464	 0.017314	 0.00043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69050	 78806	 0.003029	 0.004836	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69051	 69052	 0.006957	 0.004929	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69052	 78805	 0.00595	 0.006357	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69053	 78805	 0.002243	 0.008643	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69054	 69056	 0.00075	 0.002571	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69054	 78805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69054	 78805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78805	 69055	 0.009157	 0.00725	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69056	 78806	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69056	 78806	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69057	 69061	 0.003771	 0.003379	 7e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69057	 69062	 0.005336	 0.007014	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78806	 69057	 0.001657	 0.003386	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69058	 69059	 0.007307	 0.005179	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78804	 69058	 0.003271	 0.005221	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78684	 69059	 0.008143	 0.009743	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78803	 69059	 0.003514	 0.012007	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78804	 69059	 0.00855	 0.010021	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78805	 69059	 0.009964	 0.020479	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69059	 78807	 0.003014	 0.007979	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69060	 69063	 0.000593	 0.001857	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69060	 78807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69060	 78807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69061	 69062	 0.001464	 0.002729	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78807	 69061	 0.014793	 0.013343	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69062	 69064	 0.002307	 0.006114	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69063	 78808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69063	 78808	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78808	 69064	 0.009436	 0.006107	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69065	 69068	 0.00825	 0.014507	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69065	 70367	 0.011379	 0.020007	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69065	 78810	 0.0185	 0.025236	 0.00045	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69066	 69067	 0.014736	 0.010443	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69066	 78812	 0.015586	 0.012336	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69067	 69074	 0.016971	 0.010986	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69068	 78811	 0.004293	 0.00685	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69069	 78809	 0.008207	 0.008764	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69069	 78810	 0.01405	 0.012671	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69070	 69071	 0.000864	 0.002807	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69070	 69084	 0.00295	 0.0116	 0.00304	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78195	 69070	 0.004679	 0.019436	 0.00454	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78630	 69070	 0.005007	 0.0167	 0.00424	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69070	 78809	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69070	 78809	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69071	 69072	 0.000664	 0.002164	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69071	 78810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69071	 78810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69072	 69073	 0.000793	 0.002371	 0.00054	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69072	 78811	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69072	 78811	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69073	 78812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69073	 78812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69074	 69075	 0.0038	 0.008814	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78192	 69074	 0.003329	 0.007557	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78812	 69074	 0.007521	 0.006736	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78273	 69075	 0.002429	 0.011336	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69076	 69083	 0.001379	 0.004714	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69076	 78813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69076	 78813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69077	 69078	 0.013943	 0.012579	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78813	 69077	 0.003314	 0.009757	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69078	 69079	 0.006493	 0.00885	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69078	 69081	 0.013464	 0.011086	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78809	 69078	 0.003514	 0.010336	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78809	 69079	 0.00935	 0.018521	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69080	 69081	 0.005193	 0.008286	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69080	 69082	 0.016529	 0.011707	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69081	 78814	 0.006171	 0.01085	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78645	 69082	 0.001414	 0.006271	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69082	 78814	 0.001893	 0.007907	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69083	 78814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69083	 78814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69084	 78815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69084	 78815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78813	 69085	 0.006471	 0.012036	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78815	 69085	 0.011857	 0.017279	 0.00039	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69086	 69087	 0.0019	 0.0065	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78305	 69087	 0.001007	 0.004471	 0.00014	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69088	 78816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69088	 78816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69089	 78817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69089	 78817	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69090	 69091	 0.007007	 0.007079	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69090	 78818	 0.010421	 0.008171	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78817	 69091	 0.003121	 0.0079	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69091	 78818	 0.015029	 0.012364	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69092	 78818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69092	 78818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69093	 69096	 0.002929	 0.015714	 0.00037	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69093	 69123	 0.0033	 0.019786	 0.00048	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69094	 69095	 0.033136	 0.026221	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69095	 69126	 0.020979	 0.014857	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69096	 69100	 0.003371	 0.01895	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69097	 69117	 0.002186	 0.016507	 0.00055	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69097	 69120	 0.009393	 0.021307	 0.00043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69097	 69122	 0.0018	 0.007979	 0.00024	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69098	 69116	 0.009236	 0.021121	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69098	 69117	 0.001793	 0.0102	 0.00031	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69098	 69119	 0.002771	 0.021621	 0.00041	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69099	 69100	 0.004571	 0.025993	 0.00047	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69099	 69101	 0.041293	 0.026736	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69099	 69108	 0.005221	 0.0207	 0.00059	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69099	 69113	 0.011936	 0.024529	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69102	 69105	 0.0442	 0.028614	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69103	 69106	 0.008657	 0.020107	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69103	 78827	 0.0095	 0.024421	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69104	 69238	 0.009686	 0.022486	 0.00685	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69104	 69302	 0.002821	 0.007336	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69104	 78819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69104	 78819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69105	 69106	 0.0047	 0.018271	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78819	 69105	 0.006171	 0.018921	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69106	 69107	 0.003314	 0.011593	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69106	 69107	 0.003314	 0.011593	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69106	 69191	 0.003564	 0.012164	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69107	 69109	 0.001979	 0.009814	 0.00024	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69107	 69111	 0.0017	 0.010436	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69108	 69109	 0.002314	 0.011693	 0.0002	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69109	 69111	 0.005279	 0.01225	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69110	 69111	 0.004457	 0.012779	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69110	 69112	 0.003679	 0.015729	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69110	 69114	 0.00475	 0.013957	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69111	 69113	 0.007879	 0.035121	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69112	 69113	 0.002307	 0.009143	 0.00026	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69113	 69117	 0.00555	 0.021664	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69113	 69117	 0.00555	 0.021664	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69113	 69118	 0.003221	 0.016293	 0.00029	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69113	 69186	 0.001814	 0.011693	 0.00037	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69113	 78820	 0.015021	 0.075979	 0.00132	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69114	 69185	 0.004793	 0.018707	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69114	 69185	 0.004793	 0.018707	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69114	 69186	 0.001543	 0.012007	 0.00022	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69115	 69116	 0.005664	 0.011593	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69115	 69140	 0.005093	 0.0227	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69115	 69140	 0.005093	 0.0227	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69115	 69182	 0.0125	 0.043764	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69115	 69182	 0.0125	 0.043764	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69117	 69118	 0.003193	 0.014143	 0.00042	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69119	 69121	 0.009121	 0.014636	 0.00027	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69119	 69122	 0.006307	 0.012964	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69119	 69124	 0.0039	 0.019336	 0.00046	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69119	 69133	 0.005514	 0.018829	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69119	 78820	 0.018243	 0.052321	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69120	 69121	 0.004443	 0.012736	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69121	 69122	 0.004336	 0.012757	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69121	 69124	 0.0036	 0.0126	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69121	 69124	 0.0036	 0.0126	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69123	 69125	 0.004864	 0.012893	 0.00033	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69123	 69126	 0.004771	 0.021129	 0.00048	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69124	 69125	 0.001121	 0.007236	 0.00023	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69124	 69128	 0.003464	 0.018536	 0.00056	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69125	 69128	 0.002914	 0.012914	 0.00029	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69125	 69132	 0.003721	 0.014529	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69126	 69128	 0.006143	 0.015557	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69126	 72185	 0.002614	 0.02225	 0.00058	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69127	 69128	 0.004686	 0.018307	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69127	 69128	 0.004686	 0.018307	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69127	 72181	 0.006986	 0.023857	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69127	 72185	 0.002514	 0.013521	 0.00032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69129	 69130	 0.001	 0.008071	 0.00021	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69129	 69131	 0.012764	 0.008264	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69129	 69132	 0.002314	 0.014014	 0.00044	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69129	 69146	 0.004671	 0.010843	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69130	 72156	 0.002721	 0.013514	 0.00032	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69130	 72185	 0.011479	 0.021343	 0.0005	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69132	 69133	 0.002093	 0.017429	 0.00033	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69132	 69144	 0.019271	 0.017386	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69132	 79379	 0.009279	 0.041114	 0.00094	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69133	 69141	 0.010514	 0.0216	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69134	 69136	 0.00135	 0.007657	 0.00014	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69134	 69141	 0.002129	 0.0089	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69135	 69136	 0.002779	 0.010814	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69135	 69144	 0.003057	 0.009386	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69135	 69300	 0.008379	 0.011429	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69136	 69142	 0.007093	 0.007579	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69136	 69300	 0.003271	 0.011457	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69136	 78820	 0.00825	 0.018871	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69137	 69138	 0.000321	 0.004979	 0.00174	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69137	 72161	 0.002321	 0.017229	 0.00657	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69137	 78820	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69137	 78820	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69137	 79392	 0.005157	 0.04955	 0.01441	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69138	 69139	 0.000357	 0.002136	 0.00054	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69138	 69169	 0.004236	 0.018436	 0.00525	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69138	 78821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69138	 78821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69139	 69175	 0.000864	 0.004807	 0.00146	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69140	 69141	 0.002871	 0.010057	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69140	 69141	 0.002871	 0.010057	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78820	 69141	 0.004021	 0.012336	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69142	 69143	 0.002493	 0.006607	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78820	 69142	 0.008086	 0.018493	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69143	 69150	 0.006314	 0.011743	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69143	 69155	 0.005314	 0.010921	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69144	 69147	 0.002479	 0.011057	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69145	 69148	 0.001757	 0.009436	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69145	 69149	 0.004021	 0.009114	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69145	 69300	 0.009793	 0.022736	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69146	 69148	 0.003843	 0.007143	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69147	 69148	 0.002164	 0.00845	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69148	 72159	 0.003907	 0.015257	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69148	 72159	 0.003907	 0.015257	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69149	 69151	 0.003579	 0.00735	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69149	 69300	 0.007393	 0.015193	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69150	 69151	 0.003679	 0.012271	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69150	 69155	 0.0178	 0.017979	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69151	 69153	 0.004543	 0.009343	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69151	 79379	 0.003207	 0.02425	 0.00081	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69152	 69154	 0.003043	 0.009336	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69152	 69155	 0.003643	 0.012143	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69153	 69155	 0.009914	 0.018436	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69154	 69155	 0.005886	 0.020114	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69154	 72144	 0.010343	 0.020264	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69154	 72164	 0.0026	 0.013971	 0.00033	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69154	 79380	 0.01225	 0.037586	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69155	 69163	 0.0012	 0.00775	 0.00025	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69156	 69161	 0.002421	 0.014736	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69156	 69173	 0.002636	 0.018964	 0.00062	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78821	 69156	 0.003707	 0.009829	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69157	 69273	 0.003136	 0.011936	 0.00334	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69157	 78822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69157	 78822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69158	 69159	 0.018436	 0.013057	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78822	 69158	 0.024064	 0.01705	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69160	 69164	 0.002643	 0.0131	 0.00031	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69160	 69168	 0.010136	 0.020836	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78822	 69160	 0.006714	 0.026236	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69161	 69162	 0.002414	 0.011593	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78820	 69162	 0.002357	 0.0126	 0.00038	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69163	 69166	 0.002907	 0.022636	 0.00042	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69164	 69165	 0.002721	 0.014629	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69165	 69166	 0.002279	 0.013664	 0.00033	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69167	 69168	 0.00345	 0.010586	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78822	 69167	 0.007314	 0.0215	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69168	 78823	 0.004571	 0.01785	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69169	 69170	 0.001729	 0.006929	 0.00174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69169	 78823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69169	 78823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69170	 70755	 0.002164	 0.008221	 0.0023	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69170	 78824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69170	 78824	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69171	 69267	 0.011314	 0.008957	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69172	 69173	 0.002186	 0.018136	 0.00044	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69172	 69174	 0.017	 0.012043	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69172	 69266	 0.006364	 0.02835	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69172	 69266	 0.006364	 0.02835	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78822	 69172	 0.006057	 0.01385	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69172	 78826	 0.009186	 0.02435	 0.00061	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69175	 69176	 0.0009	 0.003529	 0.00092	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69175	 78825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69175	 78825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69176	 78826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69176	 78826	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69177	 69178	 0.005193	 0.018186	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69177	 69178	 0.005193	 0.018186	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78826	 69177	 0.005414	 0.021157	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78826	 69177	 0.005414	 0.021157	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69178	 78838	 0.001936	 0.016443	 0.00043	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69179	 69180	 0.002193	 0.014	 0.00034	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78825	 69179	 0.002043	 0.014943	 0.00028	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69180	 69184	 0.002293	 0.012286	 0.00037	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69181	 69182	 0.003571	 0.01395	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69181	 69182	 0.003571	 0.01395	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69181	 69184	 0.00395	 0.013843	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69181	 69184	 0.00395	 0.013843	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69183	 69184	 0.001036	 0.007436	 0.00024	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69183	 69185	 0.004236	 0.012136	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69183	 69225	 0.003129	 0.010943	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69183	 78832	 0.016293	 0.055664	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69184	 69228	 0.005236	 0.018329	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69184	 69228	 0.005236	 0.018329	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69185	 69188	 0.0022	 0.01075	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69187	 69188	 0.015264	 0.010814	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69188	 69189	 0.002736	 0.009571	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69189	 69190	 0.002079	 0.006386	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69190	 69191	 0.014086	 0.013836	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69190	 69194	 0.009271	 0.0101	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69190	 69199	 0.001971	 0.0069	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69190	 69225	 0.004714	 0.011943	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69190	 78827	 0.010686	 0.027471	 0.00043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69191	 69192	 0.013036	 0.010314	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69191	 69193	 0.0037	 0.0076	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69191	 69194	 0.017779	 0.011514	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69193	 69194	 0.00585	 0.010286	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69193	 69195	 0.005107	 0.009493	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69195	 78827	 0.004657	 0.009529	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69196	 69302	 0.006029	 0.015164	 0.00393	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69196	 78827	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69196	 78827	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69196	 78828	 0.002957	 0.009857	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69197	 69198	 0.007793	 0.009136	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78827	 69197	 0.004729	 0.008793	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69198	 69224	 0.008243	 0.0081	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69199	 69224	 0.002971	 0.01155	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69200	 78828	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78829	 69200	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69200	 78841	 0.001407	 0.009143	 0.01821	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69201	 69203	 0.000686	 0.002664	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69201	 69343	 0.001007	 0.003586	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69201	 78830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69201	 78830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69202	 69204	 0.003414	 0.00905	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69202	 69213	 0.010464	 0.026507	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78830	 69202	 0.004836	 0.009929	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69202	 78831	 0.004814	 0.008693	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69202	 78834	 0.006771	 0.019429	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69203	 78831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69203	 78831	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69203	 78833	 0.0007	 0.00265	 0.00074	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69204	 69205	 0.004557	 0.008464	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69204	 69208	 0.004321	 0.008879	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69205	 69206	 0.002843	 0.006607	 0.0001	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69206	 69239	 0.00555	 0.012886	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69207	 69208	 0.0045	 0.008371	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69207	 69210	 0.010686	 0.014043	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69207	 69213	 0.012721	 0.013586	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69208	 69209	 0.008664	 0.005607	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69210	 69212	 0.004179	 0.008593	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78829	 69210	 0.003729	 0.00945	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69211	 69212	 0.012193	 0.013021	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69211	 69217	 0.00365	 0.015593	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78829	 69211	 0.005114	 0.015043	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69212	 69213	 0.003357	 0.007793	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69213	 69214	 0.002564	 0.010029	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69213	 69215	 0.0056	 0.0101	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69214	 69217	 0.0015	 0.007336	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69215	 69216	 0.011207	 0.007257	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69217	 69219	 0.001836	 0.009864	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69217	 78832	 0.004943	 0.021114	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69218	 78832	 0.019514	 0.012636	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69219	 69222	 0.001379	 0.007357	 0.00022	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69220	 69221	 0.017307	 0.0137	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69220	 78832	 0.013871	 0.014814	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69222	 69223	 0.001093	 0.006214	 0.00019	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69223	 69224	 0.0027	 0.009464	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69223	 69226	 0.0143	 0.009257	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69223	 69229	 0.007914	 0.020043	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69225	 69227	 0.006443	 0.011986	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69227	 69228	 0.005429	 0.009543	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69228	 69229	 0.002993	 0.013186	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69228	 69229	 0.002993	 0.013186	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69229	 69230	 0.03815	 0.0247	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69229	 69232	 0.001943	 0.005957	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69229	 78832	 0.017071	 0.035079	 0.00067	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69231	 69233	 0.0019	 0.005836	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69231	 69235	 0.004614	 0.012221	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69231	 69261	 0.004221	 0.00965	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69232	 69233	 0.00155	 0.006036	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69234	 78832	 0.026371	 0.020671	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69235	 69236	 0.004307	 0.011421	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69235	 69259	 0.00585	 0.010286	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69236	 69250	 0.005164	 0.013679	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69237	 69250	 0.014071	 0.010171	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69238	 78832	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69238	 78832	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69238	 78842	 0.00355	 0.014657	 0.00346	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69239	 69250	 0.008086	 0.016543	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69240	 69241	 0.001693	 0.004979	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69240	 69242	 0.006993	 0.0082	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69240	 78834	 0.009986	 0.020521	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69241	 69247	 0.003343	 0.011421	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78831	 69242	 0.006171	 0.009843	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69243	 69594	 0.00185	 0.012986	 0.02211	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69243	 78833	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78834	 69243	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69243	 78841	 0.000629	 0.004407	 0.00751	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69244	 69245	 0.003714	 0.005957	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69244	 78835	 0.008907	 0.020671	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69245	 69277	 0.016807	 0.030321	 0.00044	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69246	 69252	 0.001364	 0.003536	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78833	 69246	 0.0021	 0.008743	 0.00273	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69246	 78835	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69246	 78835	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69246	 78842	 0.000714	 0.003636	 0.00091	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69247	 69248	 0.003143	 0.007293	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69247	 69249	 0.011171	 0.007914	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78835	 69247	 0.006029	 0.011214	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78835	 69248	 0.004821	 0.005986	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69248	 78836	 0.004886	 0.011171	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69250	 69251	 0.013836	 0.0098	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69250	 78836	 0.005057	 0.010007	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69250	 78843	 0.017536	 0.030843	 0.00058	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69252	 78836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69252	 78836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78835	 69253	 0.004329	 0.011479	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78836	 69253	 0.003786	 0.007779	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69253	 78837	 0.002579	 0.010071	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69254	 69255	 0.000543	 0.003857	 0.00119	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69254	 69269	 0.000493	 0.003221	 0.00119	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69255	 78837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69255	 78837	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69255	 78842	 0.000364	 0.003829	 0.00129	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69256	 69258	 0.019743	 0.013986	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69257	 69268	 0.002907	 0.012136	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78837	 69257	 0.0023	 0.012371	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69258	 69259	 0.002464	 0.009614	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78836	 69258	 0.003729	 0.014571	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69259	 69260	 0.002057	 0.008036	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69260	 78838	 0.002943	 0.0115	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69261	 78838	 0.004993	 0.014693	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69262	 69273	 0.003136	 0.010571	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69262	 78838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69262	 78838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69263	 69268	 0.004436	 0.007079	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78838	 69263	 0.008879	 0.014957	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69264	 69265	 0.0102	 0.008071	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69265	 78840	 0.012957	 0.009179	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69266	 69267	 0.00235	 0.01035	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69266	 69267	 0.00235	 0.01035	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69267	 69271	 0.001229	 0.006614	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69267	 78845	 0.004143	 0.012714	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69268	 78839	 0.00325	 0.00665	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69268	 78844	 0.005221	 0.0204	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69269	 69270	 0.000886	 0.002657	 0.0006	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69269	 69273	 0.000864	 0.003957	 0.00101	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69269	 78839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69269	 78839	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69270	 78840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69270	 78840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78840	 69271	 0.001386	 0.008286	 0.0002	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69272	 69601	 0.000221	 0.002821	 0.18031	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69272	 78841	 0.000166	 0.013272	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78842	 69273	 0.00135	 0.009507	 0.0054	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69273	 78844	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69273	 78844	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69273	 78851	 0.001864	 0.011814	 0.00321	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69273	 78853	 0.000414	 0.003114	 0.00153	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69274	 69295	 0.001029	 0.003586	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69274	 78845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69274	 78845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69275	 69277	 0.016357	 0.013464	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78834	 69275	 0.01605	 0.011364	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69276	 69277	 0.00515	 0.010543	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69276	 69371	 0.004457	 0.009364	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69277	 78846	 0.009536	 0.017721	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78835	 69278	 0.0297	 0.024443	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78843	 69278	 0.005764	 0.0146	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69278	 78846	 0.006379	 0.016914	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69279	 69504	 0.001807	 0.007029	 0.00188	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78842	 69279	 0.001429	 0.008593	 0.0026	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69279	 78846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69279	 78846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69280	 69291	 0.000921	 0.003264	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78842	 69280	 0.000879	 0.003129	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69281	 69282	 0.001921	 0.005086	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69281	 69507	 0.002493	 0.006414	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69282	 69286	 0.001014	 0.003486	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78842	 69282	 0.002329	 0.007071	 0.00155	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69282	 78847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69282	 78847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78847	 69283	 0.013129	 0.0093	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69284	 78849	 0.020143	 0.013036	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69285	 69289	 0.000771	 0.0027	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69285	 69292	 0.000729	 0.002864	 0.00075	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69286	 69290	 0.000921	 0.003157	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69286	 78848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69286	 78848	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69287	 69288	 0.002279	 0.009743	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78844	 69287	 0.005193	 0.015271	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69287	 78854	 0.0015	 0.01215	 0.00031	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69288	 78849	 0.003643	 0.015579	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69289	 69487	 0.001986	 0.006807	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69289	 78849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69289	 78849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69290	 69488	 0.002093	 0.00655	 0.00189	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69291	 69292	 0.00055	 0.001893	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69292	 78850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69292	 78850	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69293	 69299	 0.000429	 0.002943	 0.0053	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69293	 70707	 0.0002	 0.002229	 0.00408	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69293	 72223	 0.000993	 0.016036	 0.06223	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69293	 78851	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69293	 78851	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69294	 78852	 0.003857	 0.01135	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69294	 78854	 0.002836	 0.009457	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78851	 69295	 0.002043	 0.007014	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69295	 78852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69295	 78852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78852	 69296	 0.017371	 0.01125	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69297	 78854	 0.022836	 0.018071	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69298	 78854	 0.010436	 0.007393	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69299	 78853	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78854	 69299	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78829	 69301	 0.026529	 0.031093	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69302	 69343	 0.008886	 0.029636	 0.00751	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69302	 70350	 0.010271	 0.039043	 0.01093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69302	 78855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69302	 78855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69303	 69304	 0.006457	 0.009407	 0.00021	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69303	 69305	 0.027421	 0.019821	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69303	 69322	 0.005436	 0.011171	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78829	 69303	 0.00605	 0.0265	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69306	 69307	 0.006043	 0.023607	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78855	 69306	 0.010679	 0.036464	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69307	 69321	 0.001843	 0.007186	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69308	 69319	 0.027393	 0.02455	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69309	 69310	 0.018979	 0.012286	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69310	 69311	 0.014707	 0.009521	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69310	 69409	 0.013971	 0.01905	 0.00042	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69312	 69313	 0.003129	 0.015657	 0.00028	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69312	 69314	 0.008007	 0.012	 0.00022	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69312	 69409	 0.0098	 0.018221	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69312	 69410	 0.002321	 0.008129	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69313	 69316	 0.00655	 0.0152	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69313	 69319	 0.011229	 0.022986	 0.00056	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69314	 69315	 0.002414	 0.002993	 6e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69315	 69425	 0.009571	 0.01435	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69316	 69319	 0.006329	 0.014686	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69317	 69318	 0.004279	 0.009786	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69317	 69320	 0.006036	 0.010607	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69317	 69325	 0.014043	 0.011557	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69318	 69327	 0.017014	 0.018171	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69318	 69328	 0.006743	 0.01385	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69319	 69320	 0.004414	 0.008736	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69319	 69321	 0.002421	 0.008271	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69319	 69323	 0.0066	 0.015314	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69321	 69322	 0.008664	 0.016114	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69323	 69324	 0.020629	 0.014614	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78829	 69323	 0.008129	 0.036371	 0.00075	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69324	 69325	 0.011764	 0.009679	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69326	 69328	 0.020579	 0.016286	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69327	 69338	 0.011421	 0.017129	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69328	 69341	 0.00575	 0.016479	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69328	 69344	 0.022971	 0.028514	 0.00062	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69329	 69330	 0.018121	 0.012836	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69329	 69331	 0.020571	 0.018429	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69329	 69338	 0.011729	 0.024107	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69331	 69426	 0.010236	 0.013457	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69332	 69333	 0.014757	 0.011679	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69333	 69334	 0.013407	 0.012007	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69333	 69451	 0.01635	 0.016064	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69334	 69338	 0.008579	 0.01005	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69335	 69348	 0.022707	 0.0147	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69336	 69337	 0.008907	 0.010443	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69336	 69455	 0.007536	 0.009357	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69337	 69347	 0.010286	 0.0101	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69338	 69339	 0.006293	 0.018493	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69338	 78857	 0.018686	 0.042379	 0.00084	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69339	 69340	 0.007021	 0.008229	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69339	 69342	 0.0026	 0.011586	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69340	 69344	 0.007614	 0.010379	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69341	 78856	 0.004564	 0.0121	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69342	 69352	 0.009571	 0.0178	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69342	 78856	 0.001664	 0.007121	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69343	 78856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69343	 78856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69344	 69351	 0.004214	 0.007836	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69345	 69346	 0.002486	 0.005086	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69345	 69351	 0.004243	 0.011243	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69346	 69348	 0.002779	 0.005707	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69347	 69348	 0.004657	 0.009571	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69347	 69453	 0.012043	 0.010864	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69348	 69451	 0.014107	 0.0252	 0.00037	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69348	 78857	 0.014307	 0.029279	 0.00072	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69349	 69350	 0.0064	 0.004143	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69349	 69360	 0.007779	 0.015407	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69351	 69359	 0.003236	 0.010786	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78834	 69351	 0.009493	 0.033243	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69352	 69353	 0.014786	 0.009571	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69352	 69354	 0.003757	 0.008721	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69352	 69368	 0.003221	 0.005993	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69354	 69355	 0.00215	 0.004936	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69355	 69356	 0.00165	 0.003064	 7e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78830	 69356	 0.004421	 0.008221	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69357	 69358	 0.003321	 0.006171	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69357	 69361	 0.003071	 0.006286	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69358	 69359	 0.003564	 0.006629	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69359	 69368	 0.001214	 0.007471	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69360	 69362	 0.005271	 0.008421	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69360	 69364	 0.00475	 0.009757	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69360	 69478	 0.012329	 0.018893	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69360	 78857	 0.004029	 0.01185	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69361	 69362	 0.003864	 0.006793	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69363	 69364	 0.013521	 0.009579	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69364	 69477	 0.008607	 0.012907	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69364	 69478	 0.007536	 0.011293	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69365	 69369	 0.0019	 0.007229	 0.00202	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69365	 78857	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69365	 78857	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69365	 78896	 0.005721	 0.018664	 0.00496	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69366	 69369	 0.000943	 0.002271	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69366	 78858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69366	 78858	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69367	 69493	 0.013386	 0.021371	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78857	 69367	 0.022964	 0.016264	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69368	 69370	 0.007814	 0.009157	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78834	 69368	 0.003579	 0.019136	 0.00058	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69368	 78859	 0.004186	 0.0086	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78833	 69369	 0.00175	 0.007864	 0.00209	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69369	 78859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69369	 78859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69370	 69371	 0.006079	 0.010857	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69371	 69372	 0.00505	 0.009386	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78859	 69371	 0.004264	 0.007507	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78858	 69372	 0.0028	 0.009564	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69373	 69404	 0.030579	 0.021664	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69374	 69375	 0.011614	 0.018536	 0.00043	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69374	 69387	 0.007743	 0.011286	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69375	 69376	 0.0085	 0.017464	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69375	 69385	 0.039343	 0.027871	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69376	 70348	 0.068121	 0.053907	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69376	 78860	 0.009021	 0.020629	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69377	 69385	 0.013271	 0.010507	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69378	 69379	 0.000786	 0.003193	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69378	 69381	 0.002371	 0.009786	 0.00231	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69378	 69415	 0.006364	 0.025486	 0.00642	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69378	 78860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69378	 78860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69379	 69381	 0.0016	 0.006414	 0.00161	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69379	 78861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69379	 78861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69380	 69382	 0.021029	 0.016486	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78860	 69380	 0.02095	 0.0189	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78861	 69380	 0.013679	 0.013443	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69383	 69393	 0.005907	 0.010979	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69384	 69385	 0.012729	 0.010479	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69384	 69391	 0.006086	 0.0125	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69384	 69392	 0.022986	 0.014879	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78860	 69384	 0.022021	 0.045257	 0.00086	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69386	 69391	 0.0177	 0.012536	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69387	 69388	 0.005743	 0.008614	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69388	 69404	 0.009086	 0.011279	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69389	 69390	 0.013107	 0.011829	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69389	 69403	 0.01115	 0.010057	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69390	 69391	 0.008579	 0.008429	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69391	 69398	 0.017486	 0.015779	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69392	 69393	 0.004486	 0.007893	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69392	 69397	 0.00355	 0.008236	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69394	 69397	 0.006443	 0.009657	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69394	 69417	 0.008407	 0.014793	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69395	 69417	 0.013193	 0.010443	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69396	 69397	 0.002714	 0.0037	 8e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69396	 69398	 0.004529	 0.006179	 0.00011	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69398	 69399	 0.006814	 0.009293	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69399	 69400	 0.004779	 0.005929	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69400	 69402	 0.004221	 0.008671	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69400	 69416	 0.005836	 0.007957	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69401	 69402	 0.005586	 0.006543	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69401	 69403	 0.010664	 0.009621	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69401	 78863	 0.011057	 0.016114	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69402	 78862	 0.006271	 0.012843	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69404	 69406	 0.0104	 0.0166	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69405	 69406	 0.014664	 0.011607	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69406	 69407	 0.015243	 0.010793	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69406	 69408	 0.010236	 0.019029	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69406	 78863	 0.007536	 0.017086	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69408	 69411	 0.010864	 0.021507	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69409	 78862	 0.013729	 0.039364	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69410	 69411	 0.002257	 0.007914	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69411	 69412	 0.003029	 0.006929	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69412	 69413	 0.004343	 0.009929	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69413	 69423	 0.008257	 0.014521	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69413	 78862	 0.004379	 0.009	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69414	 69415	 0.001014	 0.003479	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69414	 78862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69414	 78862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69415	 78863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69415	 78863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69416	 69417	 0.004543	 0.007257	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69417	 69418	 0.012314	 0.011036	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78260	 69417	 0.005264	 0.017557	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69418	 69419	 0.011786	 0.016071	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78375	 69420	 0.009429	 0.009264	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69421	 69422	 0.008457	 0.015721	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78260	 69421	 0.002521	 0.007421	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78375	 69421	 0.003379	 0.007729	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78863	 69421	 0.004271	 0.0131	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69422	 69423	 0.017479	 0.018664	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69422	 78865	 0.035029	 0.037407	 0.00079	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69423	 69424	 0.019936	 0.012907	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69425	 69426	 0.005593	 0.008971	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69426	 69428	 0.00895	 0.014357	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69427	 69428	 0.015507	 0.010036	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69428	 69449	 0.005093	 0.010421	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69429	 69448	 0.015357	 0.012157	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69430	 69449	 0.015136	 0.010721	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69431	 69433	 0.006929	 0.011671	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69431	 69447	 0.0052	 0.007093	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69432	 69433	 0.003464	 0.005043	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69432	 69434	 0.00605	 0.010643	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69432	 78865	 0.010464	 0.008614	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69434	 69435	 0.005729	 0.01065	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69435	 69436	 0.01385	 0.016236	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69435	 69439	 0.004664	 0.007443	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69435	 69441	 0.023343	 0.021057	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78260	 69436	 0.00465	 0.010793	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78375	 69436	 0.007071	 0.008779	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69437	 69438	 0.010407	 0.008564	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69438	 69439	 0.00445	 0.007829	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69440	 69443	 0.001271	 0.003064	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69440	 69446	 0.00215	 0.0054	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69440	 69470	 0.002736	 0.008364	 0.00181	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69440	 78864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69440	 78864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69440	 78894	 0.002936	 0.009786	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69441	 69442	 0.011521	 0.007457	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78864	 69441	 0.004479	 0.0092	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69443	 69446	 0.000821	 0.002357	 0.00058	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69443	 78865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69443	 78865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69444	 69445	 0.010707	 0.007586	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78865	 69444	 0.010936	 0.007079	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69445	 69466	 0.021436	 0.015186	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69446	 69472	 0.0025	 0.008579	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69446	 78866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69446	 78866	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69447	 69448	 0.0054	 0.010036	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 69447	 0.004814	 0.013657	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69448	 69450	 0.004593	 0.009443	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69449	 69450	 0.003593	 0.00835	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69449	 69452	 0.005471	 0.010171	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69449	 69456	 0.011693	 0.024029	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69451	 69452	 0.00435	 0.008086	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69453	 69477	 0.010679	 0.011743	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69454	 69456	 0.01185	 0.008393	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69455	 69456	 0.011886	 0.020021	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69455	 69474	 0.006236	 0.01235	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69456	 69457	 0.00325	 0.006679	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78865	 69456	 0.011671	 0.027107	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69457	 69458	 0.003321	 0.005436	 9e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 69457	 0.011293	 0.010186	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69458	 69460	 0.004121	 0.00725	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 69458	 0.009107	 0.005893	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69459	 69460	 0.00365	 0.005593	 8e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69459	 69461	 0.004514	 0.007943	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69459	 69464	 0.010086	 0.0091	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69460	 69463	 0.00595	 0.00955	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 69460	 0.014643	 0.014793	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69461	 78868	 0.004479	 0.007871	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69462	 69475	 0.007529	 0.012079	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69462	 78868	 0.006764	 0.013393	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69463	 69464	 0.005914	 0.003829	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69463	 78867	 0.009971	 0.01065	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69464	 78867	 0.005557	 0.008329	 0.00015	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69465	 69467	 0.005971	 0.009143	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78866	 69465	 0.038736	 0.027436	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69465	 78867	 0.00635	 0.007886	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69466	 69467	 0.004421	 0.007086	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69468	 69469	 0.005807	 0.011929	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69468	 78895	 0.010286	 0.023871	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69469	 78867	 0.009764	 0.014221	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69470	 69472	 0.001229	 0.002964	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69470	 78867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69470	 78867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69470	 78894	 0.004464	 0.011229	 0.00291	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69471	 69484	 0.008629	 0.017086	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69471	 69485	 0.004636	 0.008621	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78867	 69471	 0.003707	 0.008414	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69471	 78868	 0.00545	 0.012364	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69472	 69504	 0.006029	 0.027657	 0.00709	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69472	 78868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69472	 78868	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69473	 69479	 0.003614	 0.007421	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78868	 69473	 0.003993	 0.007421	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69474	 69475	 0.002221	 0.005707	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69475	 69476	 0.002836	 0.005621	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69475	 69477	 0.005243	 0.010779	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69476	 69479	 0.004114	 0.007229	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69478	 69480	 0.016643	 0.014914	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69478	 69558	 0.014393	 0.03265	 0.00065	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69479	 69480	 0.003721	 0.007643	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69480	 69481	 0.0039	 0.007971	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69481	 69482	 0.00475	 0.012207	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69482	 69556	 0.00575	 0.014771	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69482	 69558	 0.011657	 0.020493	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78857	 69482	 0.028236	 0.030157	 0.00064	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69483	 69486	 0.005036	 0.010307	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78868	 69483	 0.007279	 0.011621	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69484	 69485	 0.005893	 0.006293	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69484	 69567	 0.010007	 0.01365	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69484	 78898	 0.018186	 0.037214	 0.00091	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69486	 69558	 0.004057	 0.0083	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69487	 70700	 0.002079	 0.007143	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69488	 69489	 0.001986	 0.004779	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69488	 70691	 0.001379	 0.0048	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69489	 69540	 0.002079	 0.005229	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69490	 69492	 0.033557	 0.026557	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69490	 69502	 0.015771	 0.027729	 0.00052	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69491	 69492	 0.021229	 0.013743	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69491	 69493	 0.004679	 0.009571	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69491	 69495	 0.004329	 0.010971	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69491	 69496	 0.011507	 0.020679	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69491	 69498	 0.005364	 0.011021	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69491	 69501	 0.005421	 0.011093	 0.00027	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69493	 69557	 0.007329	 0.012893	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69494	 69495	 0.006529	 0.0099	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69494	 69557	 0.006686	 0.008786	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69495	 69560	 0.005486	 0.011279	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69496	 69498	 0.010886	 0.016514	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69496	 69597	 0.008564	 0.013736	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69496	 78877	 0.005879	 0.018029	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69497	 69498	 0.006536	 0.010429	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69497	 69520	 0.006971	 0.013807	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69498	 69499	 0.003064	 0.009021	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69499	 69500	 0.003379	 0.009936	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69500	 69517	 0.003943	 0.0113	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69500	 78875	 0.003071	 0.0123	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69501	 69502	 0.004936	 0.0101	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69502	 78869	 0.004143	 0.0105	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69503	 69505	 0.000843	 0.002986	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69503	 69510	 0.000707	 0.002829	 0.00096	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69503	 69516	 0.001014	 0.003	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69503	 78869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69503	 78869	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69504	 69505	 0.001236	 0.004114	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69505	 78870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69505	 78870	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78870	 69506	 0.00275	 0.007879	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69506	 78872	 0.001993	 0.006964	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69507	 69508	 0.002	 0.005293	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69507	 78871	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69507	 78871	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69508	 69512	 0.000957	 0.002614	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69509	 69511	 0.008236	 0.005836	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69510	 69513	 0.000614	 0.002529	 0.0006	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69510	 78872	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69510	 78872	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78872	 69511	 0.002336	 0.005293	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69511	 78873	 0.003064	 0.007007	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69512	 69513	 0.00075	 0.003429	 0.00088	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69512	 69515	 0.0005	 0.001957	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69513	 78873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69513	 78873	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78873	 69514	 0.005314	 0.007243	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69514	 78880	 0.009186	 0.0188	 0.00046	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69515	 69529	 0.001943	 0.005329	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69515	 69536	 0.000571	 0.003457	 0.00088	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69515	 78874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69515	 78874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69516	 69519	 0.001264	 0.004121	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69516	 78875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69516	 78875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69517	 78876	 0.003829	 0.01015	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69518	 69521	 0.002957	 0.0115	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69518	 78876	 0.003007	 0.00885	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69519	 78876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69519	 78876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69519	 78879	 0.000443	 0.002836	 0.00096	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69519	 78899	 0.005193	 0.02145	 0.00508	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69520	 69521	 0.002293	 0.006071	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69520	 78877	 0.005521	 0.011607	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69522	 69524	 0.000957	 0.004043	 0.00091	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69522	 78877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69522	 78877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69522	 78896	 0.002614	 0.008529	 0.00226	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69522	 78901	 0.002571	 0.010693	 0.00249	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69523	 78878	 0.011129	 0.010043	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69523	 78880	 0.009843	 0.022843	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69524	 69763	 0.0011	 0.004271	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69524	 78878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69524	 78878	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69525	 69555	 0.000364	 0.005971	 0.01179	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69525	 69771	 0.000871	 0.005907	 0.01075	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78841	 69525	 0.001721	 0.01125	 0.02208	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69525	 78879	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78880	 69525	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69525	 78900	 0.00115	 0.008021	 0.01377	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69526	 69759	 0.000943	 0.003779	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69526	 69763	 0.00115	 0.00475	 0.00112	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69526	 78881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69526	 78881	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78879	 69527	 0.0016	 0.006421	 0.00161	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78874	 69528	 0.004	 0.008214	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69528	 78882	 0.005071	 0.010421	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78879	 69529	 0.001414	 0.005371	 0.0015	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69529	 78882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69529	 78882	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69530	 69531	 0.004529	 0.008421	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69530	 69532	 0.013071	 0.008464	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78368	 69530	 0.007114	 0.014629	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69530	 78883	 0.008829	 0.014093	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69531	 78884	 0.007571	 0.012086	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69533	 69535	 0.00055	 0.002829	 0.00071	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69533	 69554	 0.000757	 0.004029	 0.00102	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69533	 78883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69533	 78883	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78883	 69534	 0.010793	 0.008886	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69534	 78886	 0.017	 0.011007	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69535	 69536	 0.00045	 0.002636	 0.00072	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69535	 69541	 0.000936	 0.002821	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69536	 78884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69536	 78884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69537	 69538	 0.013343	 0.008636	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78884	 69538	 0.010807	 0.011536	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69538	 78885	 0.019464	 0.019114	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69539	 78885	 0.006571	 0.013443	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69539	 79198	 0.005236	 0.010757	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69540	 69541	 0.001514	 0.003643	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69540	 78885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69540	 78885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69541	 69543	 0.000757	 0.002643	 0.00088	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69542	 69545	 0.003336	 0.009557	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78885	 69542	 0.003393	 0.009986	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69542	 78886	 0.009286	 0.012664	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69543	 69552	 0.001036	 0.004286	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69543	 78886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69543	 78886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69544	 78887	 0.007107	 0.013214	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69544	 78890	 0.005814	 0.01195	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69545	 69546	 0.003379	 0.011279	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69546	 78887	 0.002971	 0.013229	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69547	 70696	 0.001371	 0.00565	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69547	 71265	 0.00355	 0.014214	 0.00358	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69547	 78887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69547	 78887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69548	 71267	 0.003021	 0.011793	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69548	 78888	 0.00215	 0.008386	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69549	 69550	 0.000629	 0.002293	 0.0007	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69549	 69552	 0.000986	 0.003836	 0.00103	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69549	 78888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69549	 78888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69550	 69551	 0.001107	 0.00335	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69550	 78889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69550	 78889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69551	 69827	 0.000786	 0.004364	 0.00133	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69551	 78892	 0.001721	 0.007014	 0.00171	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69552	 78890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69552	 78890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78890	 69553	 0.009021	 0.009107	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69553	 78891	 0.008871	 0.008714	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69554	 78891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69554	 78891	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69554	 78892	 0.000786	 0.003429	 0.00098	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69555	 69828	 0.000143	 0.001943	 0.00667	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69555	 78892	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78893	 69555	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69556	 69557	 0.003229	 0.008307	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69558	 69559	 0.003479	 0.008936	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69558	 69563	 0.006321	 0.011757	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69558	 78897	 0.008293	 0.021979	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69559	 69561	 0.00245	 0.005557	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69560	 69596	 0.0042	 0.007807	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69561	 78897	 0.0039	 0.010343	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69562	 69563	 0.005093	 0.010079	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69562	 69566	 0.004757	 0.011043	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69563	 69591	 0.008007	 0.012779	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69564	 69591	 0.014557	 0.009421	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69565	 69566	 0.003136	 0.007279	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69565	 69567	 0.005707	 0.010036	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69565	 69587	 0.004957	 0.005814	 0.0001	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69566	 69589	 0.003114	 0.007064	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69567	 69568	 0.004643	 0.009543	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69568	 69576	 0.003079	 0.006986	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69569	 69570	 0.00565	 0.004	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69569	 69573	 0.008121	 0.005757	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69569	 78895	 0.010836	 0.008921	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78695	 69571	 0.0006	 0.005021	 0.00872	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69571	 78894	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78895	 69571	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69572	 69574	 0.003829	 0.008886	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78895	 69572	 0.004586	 0.010636	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69574	 69575	 0.003229	 0.006	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69574	 69577	 0.003186	 0.006529	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69575	 69576	 0.003514	 0.007229	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78895	 69576	 0.019129	 0.020421	 0.00043	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69577	 69578	 0.00935	 0.006621	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69577	 69580	 0.007086	 0.010321	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69579	 69580	 0.006464	 0.004579	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69580	 69582	 0.006679	 0.01125	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69581	 69582	 0.002157	 0.004414	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69581	 69585	 0.008429	 0.014821	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69582	 78898	 0.003143	 0.009236	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69583	 69586	 0.003129	 0.005507	 0.0001	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69583	 78898	 0.004914	 0.012629	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69584	 69585	 0.010036	 0.007107	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69585	 69587	 0.004836	 0.005164	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69585	 69588	 0.009757	 0.007721	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69586	 69590	 0.003043	 0.00485	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69589	 69590	 0.013943	 0.011036	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69589	 69591	 0.005593	 0.012979	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69589	 78898	 0.01025	 0.020971	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69591	 69592	 0.009793	 0.006936	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69591	 69593	 0.002514	 0.008586	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69593	 78897	 0.00265	 0.010314	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69594	 69600	 0.000293	 0.002029	 0.00359	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69594	 78896	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78897	 69594	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69595	 69597	 0.005529	 0.008293	 0.00015	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78897	 69595	 0.003436	 0.005486	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69596	 69598	 0.01405	 0.027821	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69598	 78902	 0.005064	 0.021129	 0.00061	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69599	 78898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69599	 78898	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69599	 78901	 0.001643	 0.008321	 0.00231	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69599	 78904	 0.002171	 0.008979	 0.00212	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69600	 78899	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69600	 78899	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69600	 78900	 0.000236	 0.001871	 0.00321	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69601	 69602	 7.1e-05	 0.000886	 0.06053	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69601	 71029	 0.000329	 0.005536	 0.53911	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69601	 78900	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69601	 78900	 0.000159	 0.012695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69602	 70374	 0.000236	 0.002979	 0.20431	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69602	 78903	 0.000118	 0.009419	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78695	 69603	 0.000464	 0.003093	 0.00583	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78903	 69603	 0.000129	 0.001486	 0.00291	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69603	 78906	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78907	 69603	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69604	 69659	 0.002857	 0.011936	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69604	 78908	 0.001207	 0.005786	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69604	 78909	 0.004336	 0.007829	 0.00011	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69605	 69613	 0.001371	 0.006793	 0.00016	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69605	 78908	 0.000593	 0.002614	 8e-05	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69606	 69608	 0.000821	 0.003879	 0.00094	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69606	 69665	 0.001729	 0.006914	 0.00174	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78906	 69606	 0.000236	 0.001679	 0.00052	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69606	 78908	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69606	 78908	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69607	 69615	 0.002257	 0.0036	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69607	 69616	 0.00875	 0.0062	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78908	 69607	 0.00225	 0.003593	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69608	 69667	 0.003207	 0.008243	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69608	 78909	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69608	 78909	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78730	 69609	 0.006307	 0.010114	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78732	 69609	 0.004771	 0.011079	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69610	 69660	 0.004671	 0.008207	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78753	 69610	 0.00635	 0.014743	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78754	 69610	 0.001414	 0.007571	 0.00023	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78909	 69610	 0.002007	 0.009971	 0.00024	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78909	 69611	 0.0099	 0.007836	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69612	 69661	 0.000743	 0.002557	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69612	 78910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69612	 78910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69613	 69657	 0.007386	 0.010079	 0.00018	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78910	 69613	 0.001214	 0.006886	 0.00012	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69614	 69656	 0.007407	 0.007486	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78908	 69614	 0.00865	 0.009514	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78908	 69615	 0.004479	 0.007879	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69615	 78915	 0.005357	 0.01225	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69617	 69655	 0.003236	 0.006014	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69617	 78912	 0.008421	 0.0085	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69618	 69619	 0.000264	 0.001007	 0.00028	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69618	 69625	 0.000507	 0.001986	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69618	 78911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69618	 78911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69619	 69620	 0.000364	 0.001279	 0.0003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69619	 78912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69619	 78912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69620	 69653	 0.000557	 0.001914	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69621	 69625	 0.000529	 0.001929	 0.00059	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78904	 69621	 0.000871	 0.003164	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69621	 78913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69621	 78913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69622	 69623	 0.004579	 0.004107	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69622	 78914	 0.004729	 0.009357	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78913	 69623	 0.002957	 0.0076	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69623	 78914	 0.003471	 0.008057	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69624	 69632	 0.000407	 0.001679	 0.0004	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69624	 69633	 0.001079	 0.003586	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78904	 69624	 0.001329	 0.006736	 0.00187	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69624	 78914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69624	 78914	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69625	 78915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69625	 78915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69626	 69627	 0.001071	 0.002843	 7e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69626	 69628	 0.002771	 0.004879	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78915	 69626	 0.001164	 0.004536	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78914	 69627	 0.001586	 0.004664	 9e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69628	 69629	 0.002757	 0.004136	 8e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69629	 69630	 0.004321	 0.004614	 0.0001	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69630	 69634	 0.004793	 0.008907	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69630	 69649	 0.00165	 0.004371	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69630	 69650	 0.007114	 0.0076	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78914	 69630	 0.004686	 0.016007	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78914	 69631	 0.001229	 0.004779	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69631	 78916	 0.002279	 0.007964	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69632	 69633	 0.0009	 0.002264	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78901	 69632	 0.001514	 0.007057	 0.00175	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69633	 78916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69633	 78916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69633	 78931	 0.004107	 0.012471	 0.00273	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69634	 69635	 0.006514	 0.004614	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69634	 69636	 0.003693	 0.006871	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69636	 69637	 0.003071	 0.005714	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69637	 69642	 0.001307	 0.004	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69637	 69652	 0.003657	 0.006429	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78902	 69638	 0.007021	 0.012357	 0.00024	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69638	 78917	 0.008393	 0.007571	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69639	 69640	 0.000629	 0.001464	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69639	 69641	 0.001264	 0.003436	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69639	 78917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69639	 78917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69640	 69641	 0.000636	 0.0016	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69641	 69765	 0.001621	 0.005657	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69641	 69767	 0.00175	 0.004221	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78901	 69641	 0.001471	 0.006079	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69641	 78918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69641	 78918	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69642	 69643	 0.00615	 0.004357	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78916	 69642	 0.0094	 0.012814	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78917	 69642	 0.002671	 0.011757	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69644	 69645	 0.0013	 0.005736	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69644	 69648	 0.001707	 0.007614	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69645	 69646	 0.0016	 0.005479	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69646	 78959	 0.002329	 0.008921	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69647	 69648	 0.003236	 0.008207	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69647	 69651	 0.007929	 0.006521	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69647	 69682	 0.001821	 0.007121	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69648	 69652	 0.006179	 0.006793	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69648	 69685	 0.007371	 0.01515	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69649	 69654	 0.001029	 0.003971	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69650	 69651	 0.007286	 0.008014	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69653	 69675	 0.000686	 0.002443	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69653	 78919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69653	 78919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78919	 69654	 0.001786	 0.005479	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69655	 69656	 0.003221	 0.006621	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69655	 69668	 0.004129	 0.008171	 0.00012	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78919	 69655	 0.004293	 0.005857	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69656	 69657	 0.001036	 0.003536	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69657	 69658	 0.007171	 0.006421	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69658	 78926	 0.005443	 0.00535	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69659	 78921	 0.007164	 0.011436	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69659	 78924	 0.014871	 0.009629	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69660	 78920	 0.006843	 0.005629	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69660	 78921	 0.009764	 0.008814	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69661	 69662	 0.000779	 0.001871	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69661	 78920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69661	 78920	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69662	 69665	 0.000921	 0.003264	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69662	 78921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69662	 78921	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69663	 69664	 0.000764	 0.002329	 0.00051	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69663	 69665	 0.000929	 0.003179	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69663	 78922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69663	 78922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69664	 78923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69664	 78923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69665	 78924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69665	 78924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69666	 69670	 0.000657	 0.002321	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69666	 78925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69666	 78925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69667	 69670	 0.000457	 0.001379	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69667	 69675	 0.001057	 0.003693	 0.00122	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69667	 78926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69667	 78926	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69668	 69669	 0.007814	 0.00705	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78919	 69668	 0.002514	 0.008593	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78926	 69668	 0.00105	 0.005957	 0.00011	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69669	 69678	 0.010014	 0.008243	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69670	 78927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69670	 78927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69671	 69673	 0.005129	 0.003321	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78927	 69671	 0.008707	 0.005636	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78927	 69672	 0.01205	 0.009921	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69673	 69674	 0.004836	 0.006593	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78925	 69673	 0.003914	 0.006879	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69674	 69690	 0.008971	 0.00635	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69674	 78934	 0.003386	 0.009714	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69675	 69676	 0.000657	 0.001593	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69676	 69679	 0.000757	 0.002	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69676	 78928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69676	 78928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69677	 69679	 0.000843	 0.002307	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69677	 69691	 0.000786	 0.002029	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69677	 78929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69677	 78929	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78929	 69678	 0.006029	 0.007486	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69678	 78930	 0.002807	 0.005221	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69679	 78930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69679	 78930	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69680	 69681	 0.011286	 0.007993	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69680	 69682	 0.003	 0.008821	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69680	 69688	 0.009393	 0.018593	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78930	 69680	 0.003971	 0.009214	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69682	 69684	 0.003786	 0.012936	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78905	 69682	 0.030443	 0.0486	 0.00112	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78928	 69682	 0.004371	 0.009993	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69683	 69771	 0.000329	 0.004093	 0.00804	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78903	 69683	 0.0009	 0.007329	 0.01347	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69683	 78931	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78932	 69683	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69684	 69685	 0.002421	 0.006129	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78932	 69684	 0.003979	 0.015464	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69685	 69776	 0.009279	 0.021543	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78932	 69685	 0.001757	 0.008186	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69686	 69687	 0.004521	 0.012964	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69686	 69780	 0.011693	 0.007571	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78932	 69686	 0.013529	 0.026793	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69686	 78963	 0.003207	 0.015893	 0.00038	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69687	 69688	 0.005964	 0.012536	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69688	 69689	 0.002893	 0.007679	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69689	 78933	 0.004786	 0.009829	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69689	 78943	 0.012171	 0.010979	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69691	 69692	 0.00055	 0.001893	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69691	 69693	 0.00095	 0.003436	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69692	 69713	 0.000893	 0.003057	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69692	 78933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69692	 78933	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69693	 69695	 0.00075	 0.002579	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69693	 69698	 0.001943	 0.006657	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69693	 78934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69693	 78934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78934	 69694	 0.008971	 0.007386	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69695	 69709	 0.000764	 0.003057	 0.00077	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78904	 69695	 0.0066	 0.020636	 0.00598	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69695	 78935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69695	 78935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78935	 69696	 0.012357	 0.01115	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69696	 78943	 0.004314	 0.008029	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78935	 69697	 0.003479	 0.011879	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69697	 78936	 0.002293	 0.008957	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69698	 69705	 0.0021	 0.004879	 0.00149	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69698	 78936	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69698	 78936	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69699	 69701	 0.008607	 0.019979	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78936	 69699	 0.005814	 0.010814	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69699	 78940	 0.00685	 0.009979	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69700	 78937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69700	 78937	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69701	 78940	 0.002993	 0.013257	 0.0004	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69701	 79059	 0.0072	 0.0221	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78798	 69702	 0.010836	 0.013457	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69702	 78938	 0.005943	 0.01575	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69702	 78939	 0.002379	 0.010543	 0.00031	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69703	 69732	 0.001236	 0.004486	 0.00137	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69703	 70041	 0.001764	 0.005107	 0.00123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69703	 78938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69703	 78938	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69703	 79086	 0.005264	 0.015979	 0.0035	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69704	 69705	 0.000929	 0.003293	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69704	 69731	 0.000807	 0.002379	 0.00056	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69704	 78939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69704	 78939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69705	 78940	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69705	 78940	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69706	 69707	 0.001593	 0.006814	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78940	 69706	 0.00305	 0.00935	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69707	 69708	 0.001421	 0.004964	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69708	 78941	 0.001293	 0.00505	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69709	 69710	 0.000671	 0.002779	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69709	 69726	 0.001057	 0.002657	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69709	 78941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69709	 78941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69710	 69711	 0.000736	 0.002564	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69710	 69716	 0.000643	 0.002214	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69711	 69716	 0.000936	 0.002543	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69711	 69722	 0.00025	 0.0019	 0.00053	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69711	 69727	 0.000957	 0.003479	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69711	 78942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69711	 78942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78942	 69712	 0.004171	 0.006657	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69712	 78946	 0.004029	 0.006436	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69713	 69716	 0.000814	 0.003093	 0.00086	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69713	 78943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69713	 78943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69714	 69715	 0.001671	 0.007357	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78943	 69714	 0.001979	 0.008457	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69715	 69718	 0.0109	 0.011986	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69715	 69806	 0.0026	 0.008879	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69716	 69807	 0.001179	 0.004921	 0.00154	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69716	 78944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69716	 78944	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69717	 69718	 0.001386	 0.004843	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78944	 69717	 0.001986	 0.006786	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69718	 69719	 0.0046	 0.011821	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78944	 69718	 0.005757	 0.011829	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69718	 78975	 0.001607	 0.006707	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69719	 69721	 0.003671	 0.009436	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69720	 69721	 0.00675	 0.009829	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69720	 78975	 0.008307	 0.008164	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69721	 69863	 0.004579	 0.009071	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69721	 78945	 0.010707	 0.016407	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69721	 79000	 0.008343	 0.019157	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69722	 69723	 0.00035	 0.002757	 0.00081	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69723	 69862	 0.000471	 0.00225	 0.00054	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69723	 78945	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69723	 78945	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69723	 78949	 0.001043	 0.005771	 0.00176	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69724	 69725	 0.00295	 0.007807	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69724	 69730	 0.001779	 0.006957	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69724	 69733	 0.003907	 0.008036	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69725	 78946	 0.001729	 0.00675	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69726	 69727	 0.000529	 0.001836	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69727	 78946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69727	 78946	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78946	 69728	 0.014414	 0.009336	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69729	 69730	 0.005664	 0.007714	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78940	 69729	 0.008264	 0.010257	 0.00022	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69730	 78947	 0.00305	 0.011857	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69731	 69732	 0.000871	 0.0031	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69731	 78947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69731	 78947	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69732	 78948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69732	 78948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69733	 69734	 0.004386	 0.007029	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78945	 69734	 0.003707	 0.012979	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78946	 69734	 0.033686	 0.023857	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69735	 69738	 0.007814	 0.018143	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69735	 70372	 0.004136	 0.010486	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69735	 78950	 0.005564	 0.017079	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69736	 78949	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78950	 69736	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69737	 70372	 0.003993	 0.007421	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69737	 78954	 0.001993	 0.0137	 0.00025	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69738	 69739	 0.022771	 0.018021	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69739	 69740	 0.02195	 0.01555	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69740	 78951	 0.009221	 0.01895	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69741	 69751	 0.000579	 0.002257	 0.0006	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69741	 78951	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69741	 78951	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78799	 69742	 0.011886	 0.012	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78951	 69743	 0.018271	 0.012943	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69744	 69745	 0.005164	 0.011986	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69744	 69748	 0.0049	 0.010079	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69745	 78952	 0.003236	 0.014407	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69746	 78952	 0.004307	 0.010914	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69747	 69754	 0.001914	 0.006664	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78248	 69747	 0.001636	 0.0075	 0.00192	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69747	 78952	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69747	 78952	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69748	 69749	 0.001971	 0.007686	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69748	 78953	 0.003421	 0.007764	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69748	 78954	 0.008493	 0.012379	 0.00028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69749	 69750	 0.003407	 0.009043	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69749	 78955	 0.002786	 0.010871	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78249	 69750	 0.007407	 0.021236	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78952	 69750	 0.005471	 0.010179	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69751	 69752	 0.000857	 0.003436	 0.00086	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69752	 69753	 0.000736	 0.002679	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69752	 78953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69752	 78953	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69753	 69754	 0.000707	 0.003621	 0.00091	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69753	 78954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69753	 78954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78253	 69754	 0.000529	 0.002407	 0.00076	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69754	 78955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69754	 78955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78949	 69755	 0.001314	 0.006221	 0.00149	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69755	 78956	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69755	 78956	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69755	 79135	 0.002464	 0.008964	 0.00274	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69756	 69896	 0.006086	 0.009764	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78956	 69756	 0.008407	 0.011471	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78368	 69757	 0.001786	 0.001414	 1e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69758	 69759	 0.00025	 0.002036	 0.00065	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69758	 69787	 0.000914	 0.004064	 0.0011	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69759	 69760	 0.0006	 0.002279	 0.00064	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69760	 69761	 0.000736	 0.003071	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69760	 78957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69760	 78957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78311	 69762	 0.013421	 0.010521	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78881	 69762	 0.014429	 0.009343	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69763	 69765	 0.001257	 0.004093	 0.00109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69764	 69766	 0.0112	 0.013129	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78877	 69764	 0.009779	 0.0172	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69764	 78958	 0.009529	 0.008543	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69765	 69769	 0.000864	 0.002236	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69765	 78958	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69765	 78958	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78918	 69766	 0.006364	 0.008679	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69767	 69777	 0.000907	 0.003214	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69767	 78959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69767	 78959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69768	 78960	 0.010457	 0.008271	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69768	 78962	 0.0128	 0.008286	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69769	 69775	 0.0016	 0.003707	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69769	 78960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69769	 78960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78311	 69770	 0.001793	 0.0086	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78960	 69770	 0.00355	 0.015814	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69771	 69782	 0.000136	 0.000921	 0.00163	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69771	 78961	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69771	 78961	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69772	 69775	 0.001129	 0.00445	 0.00116	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78961	 69772	 0.000964	 0.002429	 0.00063	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69773	 69774	 0.000586	 0.001979	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69773	 69779	 0.000529	 0.001729	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69774	 69775	 0.000957	 0.003329	 0.00077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78961	 69774	 0.00055	 0.0027	 0.00079	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69775	 69777	 0.001	 0.003329	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69775	 78962	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69775	 78962	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78932	 69776	 0.006786	 0.012243	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69778	 69779	 0.000343	 0.002514	 0.00074	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78931	 69778	 0.000393	 0.002957	 0.00082	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69779	 69781	 0.0006	 0.002621	 0.0009	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69781	 69800	 0.000636	 0.002421	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69781	 69802	 0.000771	 0.0021	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69781	 78963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69781	 78963	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69782	 69798	 0.000129	 0.000871	 0.0016	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69782	 78964	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69782	 78964	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69783	 69784	 0.004079	 0.007579	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78964	 69783	 0.008979	 0.016693	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78957	 69784	 0.002443	 0.010871	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69784	 78965	 0.001936	 0.008564	 0.00019	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78957	 69785	 0.001471	 0.007893	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69785	 78965	 0.00135	 0.006493	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69786	 69794	 0.000414	 0.002157	 0.00052	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69786	 78965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69786	 78965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69787	 69793	 0.000629	 0.002879	 0.00074	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69788	 69789	 0.001579	 0.006979	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78368	 69788	 0.002521	 0.010529	 0.00031	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69789	 69790	 0.001836	 0.010429	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69790	 69792	 0.002621	 0.013007	 0.00031	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78893	 69790	 0.000943	 0.004171	 0.00013	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69791	 69793	 0.0005	 0.001993	 0.00067	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69791	 78966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69791	 78966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69791	 78990	 0.001886	 0.007557	 0.00191	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78966	 69792	 0.005043	 0.012964	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69792	 78985	 0.003457	 0.017486	 0.00031	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69794	 69795	 0.000171	 0.001957	 0.00055	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69794	 78979	 0.001471	 0.006557	 0.00178	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69795	 69838	 0.000179	 0.001971	 0.00061	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69795	 78967	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69795	 78967	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78965	 69796	 0.008636	 0.01775	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69796	 78969	 0.0041	 0.007629	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69797	 69816	 8.6e-05	 0.00065	 0.00129	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69797	 78968	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78969	 69797	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69798	 69816	 0.000107	 0.001336	 0.00252	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69798	 78970	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69798	 78970	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69799	 69800	 0.000536	 0.002221	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69799	 69812	 0.000557	 0.002307	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69799	 78971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69799	 78971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69801	 69803	 0.000636	 0.002071	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69801	 69810	 0.000507	 0.002071	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69801	 78972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69801	 78972	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69802	 69803	 0.000707	 0.001714	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69803	 78973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69803	 78973	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69804	 69808	 0.001014	 0.003314	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78931	 69804	 0.004207	 0.011293	 0.00256	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69804	 78974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69804	 78974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78973	 69805	 0.001893	 0.007743	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78974	 69805	 0.001429	 0.005586	 0.00012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78974	 69806	 0.000807	 0.00655	 0.00017	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69806	 78975	 0.002143	 0.006571	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69807	 69808	 0.000843	 0.003486	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69807	 78975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69807	 78975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69808	 78976	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69808	 78976	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69809	 69855	 0.001836	 0.007036	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78976	 69809	 0.001786	 0.006986	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69810	 69811	 0.00055	 0.002143	 0.00057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69810	 78977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69810	 78977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69811	 69856	 0.000629	 0.0026	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69812	 69814	 0.000671	 0.002693	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69813	 69818	 0.014971	 0.010607	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69813	 69820	 0.004336	 0.008907	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78971	 69813	 0.004407	 0.011679	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78977	 69813	 0.0036	 0.015864	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69813	 78978	 0.0042	 0.008629	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69814	 69817	 0.000529	 0.002107	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69814	 78978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69814	 78978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78970	 69815	 0.0002	 0.0017	 0.00049	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69815	 78979	 0.000207	 0.001664	 0.00053	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69816	 78979	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78980	 69816	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69817	 69824	 0.0009	 0.004243	 0.00102	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78979	 69817	 0.000786	 0.002143	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69817	 78981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69817	 78981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69818	 69821	 0.007829	 0.007907	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69819	 69820	 0.001186	 0.005243	 0.00012	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69819	 78983	 0.001693	 0.006493	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78981	 69820	 0.009164	 0.007543	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69821	 69822	 0.001607	 0.0099	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69821	 78999	 0.006336	 0.011779	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69822	 78982	 0.001114	 0.006671	 0.00016	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69822	 78998	 0.003393	 0.009979	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69823	 69824	 0.000507	 0.002107	 0.0005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69823	 69856	 0.001321	 0.005193	 0.00136	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69823	 78982	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69823	 78982	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69824	 69825	 0.000214	 0.001921	 0.00051	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69824	 69852	 0.000643	 0.002243	 0.00074	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69824	 78983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69824	 78983	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69825	 69851	 0.000364	 0.002829	 0.00084	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69825	 78984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69825	 78984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78984	 69826	 0.000979	 0.006643	 0.00016	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69826	 78991	 0.001329	 0.008579	 0.00027	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69827	 69834	 0.000521	 0.002986	 0.00099	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69828	 69833	 7.9e-05	 0.0011	 0.00378	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69828	 69836	 0.000579	 0.003671	 0.00768	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69828	 78985	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69828	 78985	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69829	 69839	 0.011821	 0.008371	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69830	 78992	 0.00585	 0.013436	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69830	 79298	 0.019421	 0.039914	 0.00076	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69831	 69842	 0.000514	 0.002464	 0.00071	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69831	 69843	 0.000721	 0.003693	 0.00093	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69831	 78986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69831	 78986	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69832	 69842	 0.000536	 0.0032	 0.00084	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69832	 69846	 0.000914	 0.003779	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69832	 78987	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69832	 78987	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69832	 78989	 0.000943	 0.002636	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69833	 69835	 5e-05	 0.000664	 0.0025	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69834	 71252	 0.000407	 0.002657	 0.00068	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69834	 78988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69834	 78988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69835	 71249	 0.000107	 0.001443	 0.00526	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69835	 78989	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69835	 78989	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78216	 69836	 0.000914	 0.01025	 0.02103	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69836	 78990	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78991	 69836	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78986	 69837	 0.008479	 0.0153	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78991	 69837	 0.003121	 0.0187	 0.00045	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69837	 78993	 0.001514	 0.009071	 0.00022	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69838	 69840	 0.0002	 0.0022	 0.00066	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78966	 69839	 0.002386	 0.007964	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69839	 78992	 0.002586	 0.007943	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69840	 69841	 0.000171	 0.001986	 0.00061	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69840	 78992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69840	 78992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69841	 69842	 0.000164	 0.002143	 0.00064	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69843	 69844	 0.000379	 0.002086	 0.00064	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69843	 78993	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69843	 78993	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69844	 78994	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69844	 78994	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69844	 79301	 0.000993	 0.008086	 0.00219	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78993	 69845	 0.005429	 0.01115	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78994	 69845	 0.004921	 0.010121	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69846	 69847	 0.0005	 0.00195	 0.00052	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69847	 69850	 0.000493	 0.002207	 0.00059	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69847	 78995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69847	 78995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69848	 69850	 0.000164	 0.002036	 0.00063	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69848	 69915	 0.000157	 0.001964	 0.00061	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69848	 78996	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69848	 78996	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78994	 69849	 0.002029	 0.00975	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78996	 69849	 0.001314	 0.007221	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69849	 78997	 0.005557	 0.007579	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69850	 78997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69850	 78997	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69850	 79304	 0.000614	 0.003793	 0.00107	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69851	 69873	 0.000336	 0.002971	 0.00079	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69852	 69871	 0.000821	 0.003136	 0.00088	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69853	 69854	 0.000764	 0.002993	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69853	 69871	 0.000864	 0.0036	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69854	 78998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69854	 78998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69855	 79003	 0.002857	 0.014193	 0.00034	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69856	 78999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69856	 78999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78998	 69857	 0.012007	 0.007771	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69858	 69861	 0.000336	 0.00215	 0.00059	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69858	 69864	 0.000336	 0.002143	 0.00058	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69859	 69860	 0.006543	 0.004636	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69860	 69884	 0.011993	 0.010821	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69860	 69886	 0.009864	 0.008121	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69861	 69862	 0.000557	 0.0029	 0.00076	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69861	 79000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69861	 79000	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69862	 79001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69862	 79001	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79001	 69863	 0.005593	 0.006936	 0.00015	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69864	 69866	 0.000507	 0.003129	 0.0009	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69864	 79002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69864	 79002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69865	 69868	 0.000607	 0.003107	 0.00078	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78949	 69865	 0.00315	 0.013007	 0.00308	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69865	 79003	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69865	 79003	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69866	 69867	 0.000293	 0.001664	 0.00056	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69866	 79004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69866	 79004	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69867	 69881	 0.000357	 0.001957	 0.00071	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69868	 69869	 0.0007	 0.0032	 0.00082	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69868	 79005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69868	 79005	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69869	 69877	 0.001064	 0.005357	 0.00139	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79005	 69870	 0.001071	 0.005743	 0.00017	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69870	 79006	 0.007329	 0.022057	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69870	 79009	 0.005371	 0.014236	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69871	 69912	 0.001907	 0.007936	 0.00185	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69871	 79006	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69871	 79006	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69872	 69874	 0.002293	 0.012257	 0.00037	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69872	 79007	 0.001743	 0.008364	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69873	 69875	 0.000336	 0.002957	 0.00079	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69873	 79007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69873	 79007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78994	 69874	 0.004486	 0.017521	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78994	 69874	 0.004486	 0.017521	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69874	 79008	 0.004264	 0.012543	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69875	 69876	 0.0002	 0.001993	 0.00054	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69876	 69913	 0.0003	 0.002886	 0.00084	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69876	 79008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69876	 79008	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69877	 69912	 0.000729	 0.003707	 0.00094	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69878	 79009	 0.002821	 0.009643	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69878	 79013	 0.005607	 0.021821	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69879	 69882	 0.0003	 0.002414	 0.00068	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69879	 70365	 0.000643	 0.005486	 0.00156	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69879	 79009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69879	 79009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69880	 69886	 0.004086	 0.007593	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69880	 69888	 0.002179	 0.010807	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78956	 69880	 0.011471	 0.023486	 0.00058	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69881	 69882	 0.000407	 0.002593	 0.00071	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69882	 79010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69882	 79010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69883	 69886	 0.001607	 0.004714	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79004	 69883	 0.0024	 0.007064	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69884	 69885	 0.003229	 0.007314	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78956	 69884	 0.006829	 0.015486	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69885	 69886	 0.001971	 0.003671	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69887	 69890	 0.018943	 0.013414	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69888	 69889	 0.0074	 0.011343	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79010	 69888	 0.002636	 0.009	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69889	 69909	 0.00495	 0.009207	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69890	 69893	 0.017486	 0.015664	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69891	 69896	 0.00905	 0.005857	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69892	 69893	 0.01175	 0.007607	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69893	 69905	 0.003786	 0.007786	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69893	 69906	 0.004857	 0.011021	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69893	 69909	 0.006007	 0.013629	 0.00027	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69894	 69897	 0.006471	 0.004586	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69894	 69898	 0.005057	 0.012807	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78956	 69894	 0.010886	 0.020243	 0.00047	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69894	 79136	 0.005321	 0.014093	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69895	 69896	 0.005157	 0.009064	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69895	 69898	 0.00475	 0.007579	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69898	 69899	 0.001629	 0.007864	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69899	 69900	 0.004536	 0.010421	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69899	 79024	 0.004879	 0.014357	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69900	 69901	 0.00455	 0.009357	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69901	 69903	 0.001686	 0.005893	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69901	 79024	 0.00395	 0.00735	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69902	 69904	 0.001157	 0.003557	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69902	 69907	 0.001843	 0.004879	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69903	 69904	 0.001171	 0.004093	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69904	 79022	 0.003871	 0.007957	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69905	 79022	 0.00735	 0.013671	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69906	 69907	 0.003171	 0.008143	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69907	 69908	 0.001721	 0.007343	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69907	 69934	 0.004343	 0.011164	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69907	 79022	 0.009486	 0.015214	 0.00028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69908	 79011	 0.002136	 0.008479	 0.00024	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69910	 69911	 0.000764	 0.0027	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69910	 70365	 0.002164	 0.005886	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69910	 79011	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69910	 79011	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69911	 69932	 0.001021	 0.004093	 0.00103	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69911	 70365	 0.00195	 0.005143	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69911	 79012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69911	 79012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69912	 69917	 0.000379	 0.003607	 0.00105	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69912	 79013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69912	 79013	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69913	 69916	 0.000379	 0.003443	 0.00112	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69914	 70357	 0.005464	 0.012493	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78994	 69914	 0.003943	 0.013793	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69914	 79015	 0.00405	 0.009271	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69915	 69916	 0.000779	 0.005	 0.00169	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69915	 79014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69915	 79014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69915	 79301	 0.000114	 0.001371	 0.00078	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69916	 69921	 0.000779	 0.002843	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69916	 79015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69916	 79015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69917	 69920	 0.000436	 0.004293	 0.00116	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69918	 79016	 0.017593	 0.012464	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69919	 69929	 0.002086	 0.008107	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79012	 69919	 0.005929	 0.012136	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69919	 79141	 0.007979	 0.0164	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69920	 79016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69920	 79016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69920	 79030	 0.000821	 0.0071	 0.00255	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69921	 69922	 0.000993	 0.004557	 0.00116	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69921	 79017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69921	 79017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78217	 69922	 0.001121	 0.005229	 0.00129	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69923	 69924	 0.001564	 0.008129	 0.00018	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69923	 79018	 0.003786	 0.006043	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69923	 79019	 0.003343	 0.013379	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69923	 79019	 0.003343	 0.013379	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69923	 79031	 0.002086	 0.012507	 0.0003	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69924	 79031	 0.001536	 0.008714	 0.00016	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69925	 69926	 0.0002	 0.002371	 0.00067	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78217	 69925	 0.000357	 0.004421	 0.00143	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69925	 79018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69925	 79018	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69925	 79030	 0.000693	 0.002779	 0.0007	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69926	 69927	 0.000629	 0.002193	 0.00073	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69926	 69961	 0.000636	 0.00665	 0.00183	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69926	 79019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69926	 79019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69927	 79020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69927	 79020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69928	 69929	 0.00205	 0.007186	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69928	 69930	 0.002907	 0.00665	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79020	 69928	 0.001164	 0.008364	 0.00027	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69930	 69933	 0.0037	 0.008393	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69931	 79021	 0.006014	 0.003893	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69932	 69937	 0.00135	 0.008364	 0.00236	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69932	 69961	 0.000157	 0.001486	 0.00046	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69932	 79021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69932	 79021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69933	 69963	 0.001693	 0.012243	 0.00031	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79011	 69933	 0.003114	 0.01865	 0.00045	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69933	 79027	 0.00105	 0.005621	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69934	 69949	 0.003393	 0.008729	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69935	 69936	 0.00295	 0.011529	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79021	 69935	 0.001986	 0.006786	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69936	 69938	 0.001836	 0.005407	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69936	 69947	 0.012721	 0.009971	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69937	 79022	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69937	 79022	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69937	 79023	 0.000643	 0.003629	 0.0009	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79022	 69938	 0.002293	 0.00765	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69939	 70353	 0.00025	 0.003093	 0.0062	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69939	 79023	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79024	 69939	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69940	 69941	 0.0017	 0.003893	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69940	 69943	 0.004443	 0.007129	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79022	 69940	 0.002979	 0.006807	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69941	 69942	 0.001286	 0.003314	 5e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69941	 69944	 0.004157	 0.007307	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69942	 69947	 0.00185	 0.0042	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69943	 69944	 0.005264	 0.005621	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69944	 79025	 0.002171	 0.006393	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69945	 69956	 0.001186	 0.005157	 0.00147	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69945	 70377	 0.001	 0.003993	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69945	 79025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69945	 79025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69946	 69947	 0.003007	 0.006157	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69946	 69949	 0.008986	 0.009593	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69946	 69952	 0.001629	 0.0057	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69948	 69949	 0.005836	 0.003779	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69949	 69950	 0.001443	 0.003664	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69950	 69951	 0.001229	 0.003607	 7e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69951	 69960	 0.001464	 0.004307	 9e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69952	 69953	 0.000857	 0.003671	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69952	 69955	 0.008643	 0.005593	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69953	 69954	 0.005843	 0.003786	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69953	 79026	 0.001321	 0.00585	 0.00018	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	69956	 69957	 0.000493	 0.002643	 0.00065	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69956	 79026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69956	 79026	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69957	 69965	 0.000529	 0.00275	 0.00072	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69958	 69959	 0.001329	 0.005921	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79026	 69958	 0.002136	 0.009507	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69959	 69962	 0.00115	 0.005079	 0.00011	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	69959	 69964	 0.001629	 0.006814	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79021	 69960	 0.001921	 0.005643	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69961	 79027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69961	 79027	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79027	 69962	 0.000736	 0.003079	 9e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	69963	 69971	 0.005621	 0.011557	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79019	 69963	 0.004007	 0.015643	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79019	 69963	 0.004007	 0.015643	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69964	 79028	 0.001714	 0.007321	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69965	 69966	 0.000436	 0.002814	 0.00074	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69965	 79028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69965	 79028	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69966	 79029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69966	 79029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69966	 79030	 0.000829	 0.006743	 0.00183	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79029	 69967	 0.007871	 0.005579	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69968	 69969	 0.004557	 0.00295	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79029	 69968	 0.01695	 0.013414	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78216	 69970	 7.1e-05	 0.000814	 0.00209	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69970	 79030	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79031	 69970	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79029	 69971	 0.004786	 0.009836	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69972	 71206	 0.012693	 0.008993	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69973	 69974	 0.147364	 0.095421	 0.00181	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69975	 69977	 0.001429	 0.003443	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69975	 79032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69975	 79032	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79032	 69976	 0.011357	 0.008043	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69976	 79033	 0.009464	 0.007493	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69977	 69979	 0.000707	 0.002143	 0.00047	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69977	 79033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69977	 79033	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69978	 69979	 0.000521	 0.001571	 0.00036	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69978	 70032	 0.001364	 0.004671	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69978	 79034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69978	 79034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69979	 79035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69979	 79035	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69980	 70033	 0.000671	 0.002764	 0.00065	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69980	 79036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69980	 79036	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69981	 69982	 0.004721	 0.008436	 0.00012	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79034	 69981	 0.005771	 0.007864	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69982	 79037	 0.00585	 0.009336	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69983	 70012	 0.000879	 0.002121	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69983	 70030	 0.00115	 0.002893	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69983	 79037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69983	 79037	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69984	 69985	 0.0008	 0.002121	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69984	 69986	 0.001314	 0.003586	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69985	 70013	 0.001136	 0.002914	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69985	 70014	 0.000807	 0.00195	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69985	 79038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69985	 79038	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69986	 69988	 0.00065	 0.002457	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69986	 79039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69986	 79039	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69986	 79138	 0.004014	 0.015243	 0.00427	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69987	 79042	 0.014771	 0.009564	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69988	 69989	 0.000657	 0.002386	 0.00073	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	69990	 69994	 0.001164	 0.002921	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69991	 69994	 0.000914	 0.002307	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69991	 70001	 0.000886	 0.003143	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69991	 79040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69991	 79040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79040	 69992	 0.010693	 0.006921	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79040	 69993	 0.011614	 0.012643	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69994	 69995	 0.000786	 0.002029	 0.00061	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	69994	 79041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69994	 79041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69995	 69996	 0.000636	 0.002079	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69995	 79042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69995	 79042	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69996	 70009	 0.000486	 0.001521	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	69996	 79043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69996	 79043	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69997	 69999	 0.004093	 0.006529	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	69997	 70005	 0.003821	 0.00785	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79043	 69997	 0.005229	 0.007129	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	69998	 69999	 0.0082	 0.0074	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79040	 69998	 0.017243	 0.012214	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79041	 69999	 0.017693	 0.012536	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79042	 69999	 0.012671	 0.010029	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	69999	 79045	 0.007579	 0.013671	 0.0002	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70000	 70002	 0.008514	 0.006029	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70001	 70003	 0.000686	 0.0032	 0.00079	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70001	 70183	 0.002507	 0.007621	 0.00167	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70001	 79044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70001	 79044	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79044	 70002	 0.008671	 0.006143	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70003	 79045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70003	 79045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70003	 79143	 0.001157	 0.009621	 0.00291	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70004	 70005	 0.005471	 0.009214	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79045	 70004	 0.014336	 0.010157	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70005	 70006	 0.002164	 0.004293	 6e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70005	 79050	 0.008364	 0.021179	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70006	 70007	 0.002664	 0.00495	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70007	 79050	 0.004943	 0.014186	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70008	 70010	 0.000407	 0.0014	 0.00034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70008	 70015	 0.000636	 0.002543	 0.00064	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70008	 70016	 0.000836	 0.002164	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70009	 70010	 0.000307	 0.000964	 0.00028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79043	 70011	 0.016843	 0.013329	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70011	 79046	 0.006836	 0.008014	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70012	 70013	 0.000793	 0.002157	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70012	 70016	 0.00075	 0.001893	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70013	 79046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70013	 79046	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70014	 79047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70014	 79047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70015	 70018	 0.000564	 0.00215	 0.0006	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70015	 79048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70015	 79048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70016	 79049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70016	 79049	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79049	 70017	 0.0047	 0.0075	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70017	 79052	 0.005807	 0.013164	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70018	 70019	 0.000714	 0.002793	 0.00073	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70018	 70022	 0.00125	 0.002907	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70019	 79050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70019	 79050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70019	 79138	 0.001136	 0.004807	 0.00108	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70020	 79051	 0.001121	 0.005993	 0.00018	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70020	 79052	 0.002193	 0.006736	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70021	 79051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70021	 79051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70021	 79075	 0.001536	 0.0048	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70022	 70053	 0.001221	 0.004321	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70022	 79052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70022	 79052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79052	 70023	 0.013307	 0.008614	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79052	 70024	 0.003964	 0.007371	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70024	 79054	 0.0051	 0.006107	 0.0001	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70024	 79067	 0.007071	 0.008286	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70025	 70027	 0.000571	 0.001636	 0.0004	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70025	 70049	 0.000836	 0.001936	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70025	 79053	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70025	 79053	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70026	 70029	 0.000636	 0.002243	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70026	 70049	 0.000836	 0.002093	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70026	 70051	 0.000621	 0.002421	 0.00065	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70026	 79054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70026	 79054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70027	 70031	 0.001007	 0.002979	 0.00069	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70027	 79055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70027	 79055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70028	 70050	 0.008786	 0.006221	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79055	 70028	 0.005879	 0.004164	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70029	 70030	 0.000607	 0.001829	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70030	 70032	 0.001021	 0.004093	 0.00103	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70030	 79056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70030	 79056	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70031	 70035	 0.00105	 0.003657	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70031	 79057	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70031	 79057	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70033	 70034	 0.000514	 0.001857	 0.00057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70033	 79058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70033	 79058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70034	 70035	 0.000829	 0.003421	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70035	 79059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70035	 79059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70036	 70038	 0.000893	 0.002357	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70037	 79061	 0.00805	 0.008079	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70038	 70045	 0.000864	 0.0026	 0.00059	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70038	 79060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70038	 79060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70039	 70043	 0.000771	 0.001864	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70039	 70045	 0.000871	 0.002236	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70039	 79061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70039	 79061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79061	 70040	 0.010686	 0.009643	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70040	 79062	 0.005821	 0.010243	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70041	 70044	 0.000814	 0.00265	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70041	 79062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70041	 79062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79062	 70042	 0.01115	 0.010057	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70042	 79063	 0.01125	 0.01015	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70043	 70044	 0.000736	 0.00225	 0.00049	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70044	 79063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70044	 79063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70045	 70047	 0.0006	 0.002393	 0.0006	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70045	 79064	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70045	 79064	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70046	 70050	 0.013271	 0.0105	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70047	 70048	 0.0008	 0.0033	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70048	 70056	 0.000836	 0.003464	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70048	 79065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70048	 79065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70049	 70052	 0.000864	 0.002964	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70049	 79066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70049	 79066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70050	 79067	 0.013529	 0.014443	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70051	 70053	 0.000621	 0.002479	 0.00063	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70051	 79067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70051	 79067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70052	 70054	 0.001136	 0.003	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70052	 70056	 0.00105	 0.002429	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70052	 79068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70052	 79068	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70053	 79069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70053	 79069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70053	 79075	 0.00035	 0.002886	 0.00113	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70054	 79070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70054	 79070	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79070	 70055	 0.003593	 0.006686	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70055	 79077	 0.0041	 0.007629	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70056	 70070	 0.001164	 0.004671	 0.00118	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70056	 79071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70056	 79071	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70058	 70059	 0.000829	 0.002079	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70058	 79143	 0.001607	 0.004036	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70059	 70375	 0.001279	 0.003486	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70059	 79072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70059	 79072	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70060	 70061	 5e-05	 0.000729	 0.00154	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70060	 79142	 0.0001	 0.001571	 0.00337	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78214	 70061	 6.4e-05	 0.000607	 0.00222	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70061	 79073	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70061	 79073	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78166	 70062	 0.002571	 0.006807	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79073	 70062	 0.027636	 0.019579	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70062	 79074	 0.010493	 0.016079	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70063	 70064	 0.000821	 0.001907	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70063	 79074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70063	 79074	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70064	 70075	 0.000979	 0.002671	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78166	 70065	 0.005193	 0.01775	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79074	 70065	 0.006057	 0.00825	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70066	 79075	 0.001614	 0.004764	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70067	 70362	 0.000507	 0.0034	 0.00626	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78900	 70067	 0.002836	 0.021136	 0.04027	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70067	 79075	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79076	 70067	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70068	 70069	 0.003907	 0.008036	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79070	 70068	 0.005179	 0.009629	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70069	 70072	 0.003336	 0.007636	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78213	 70070	 0.001686	 0.009629	 0.00235	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70070	 79077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70070	 79077	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79077	 70071	 0.004707	 0.008286	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70071	 79085	 0.004093	 0.011736	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70072	 70073	 0.010157	 0.008364	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70072	 70074	 0.010907	 0.012779	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70072	 79081	 0.01	 0.0198	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70073	 70080	 0.004793	 0.009493	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70074	 79078	 0.00785	 0.011764	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70075	 70079	 0.001386	 0.003221	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70075	 79078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70075	 79078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79078	 70076	 0.009636	 0.006821	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70077	 70079	 0.000679	 0.00185	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70077	 79080	 0.001243	 0.003121	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70078	 79079	 0.0042	 0.003321	 4e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70078	 79081	 0.020657	 0.014629	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70079	 79079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70079	 79079	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70080	 79081	 0.003179	 0.005907	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70081	 79080	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79081	 70081	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70082	 70083	 0.000486	 0.002121	 0.00061	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70082	 70097	 0.000664	 0.00315	 0.00076	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78213	 70083	 6.4e-05	 0.001064	 0.00032	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79080	 70083	 0.001329	 0.003343	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70083	 79082	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70083	 79082	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70084	 70085	 0.010421	 0.00825	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70084	 70087	 0.003486	 0.0119	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70084	 70103	 0.016971	 0.010986	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79082	 70084	 0.002936	 0.01455	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70086	 70087	 0.010886	 0.007707	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70087	 70111	 0.005143	 0.011943	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70087	 70115	 0.016586	 0.010736	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70088	 70091	 0.008479	 0.012993	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79063	 70088	 0.013536	 0.013536	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79064	 70088	 0.024943	 0.017671	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70089	 70092	 0.010093	 0.008307	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79071	 70089	 0.010907	 0.010936	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70090	 70092	 0.012264	 0.007936	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79065	 70090	 0.017764	 0.014057	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70091	 70093	 0.007914	 0.015671	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70092	 70093	 0.005043	 0.008407	 0.00012	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78378	 70093	 0.001929	 0.009	 0.00021	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79077	 70094	 0.006686	 0.010671	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70095	 70105	 0.000286	 0.001886	 0.00356	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70095	 79083	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79084	 70095	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79077	 70096	 0.009721	 0.01925	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79084	 70096	 0.011929	 0.019036	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70096	 79085	 0.007736	 0.010557	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79083	 70097	 0.001964	 0.00785	 0.00198	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70097	 79085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70097	 79085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70098	 70099	 0.005779	 0.008421	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70098	 70100	 0.005979	 0.009586	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70098	 70102	 0.005271	 0.011957	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79084	 70098	 0.010121	 0.017807	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79085	 70098	 0.007007	 0.013021	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79085	 70099	 0.005407	 0.008629	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70100	 70101	 0.008843	 0.006393	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79084	 70100	 0.007757	 0.008286	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70102	 70112	 0.006086	 0.0107	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70104	 70110	 0.005279	 0.009814	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70104	 70113	 0.011771	 0.024193	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79084	 70104	 0.0037	 0.016493	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70105	 79086	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79087	 70105	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79083	 70106	 0.0024	 0.007286	 0.00159	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79086	 70106	 0.001307	 0.003979	 0.00087	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70106	 79088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70106	 79088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70107	 70108	 0.003364	 0.0077	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79088	 70108	 0.004757	 0.010886	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70109	 70110	 0.004193	 0.012864	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70109	 70117	 0.008243	 0.016321	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70109	 70120	 0.004779	 0.014664	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79084	 70109	 0.011543	 0.038507	 0.00061	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70110	 70112	 0.004429	 0.008771	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70111	 70113	 0.005793	 0.010764	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70113	 70114	 0.006257	 0.012857	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70114	 70124	 0.005293	 0.009836	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70116	 70117	 0.005636	 0.012886	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70116	 70121	 0.005064	 0.013414	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70116	 70122	 0.014771	 0.010464	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70117	 70123	 0.021071	 0.016679	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70117	 70135	 0.0886	 0.062764	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70119	 70120	 0.001993	 0.006964	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70119	 70121	 0.006057	 0.01065	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70121	 70364	 0.004543	 0.019421	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70124	 70125	 0.035114	 0.022729	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70124	 70126	 0.063136	 0.044721	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70124	 70127	 0.01545	 0.030586	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70124	 70131	 0.021364	 0.016907	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70126	 70133	 0.02995	 0.019386	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70127	 70128	 0.015679	 0.01015	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70127	 70130	 0.025	 0.016186	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70127	 70134	 0.011693	 0.021736	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70128	 70129	 0.015457	 0.01095	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70130	 70132	 0.014314	 0.010143	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70134	 70137	 0.009636	 0.019807	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70136	 70137	 0.007357	 0.013686	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70138	 70139	 0.000393	 0.000979	 0.00026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70139	 79089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70139	 79089	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70140	 70141	 0.0091	 0.0072	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78686	 70140	 0.004721	 0.0083	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70141	 70144	 0.011843	 0.009371	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70141	 79090	 0.020943	 0.013557	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70142	 70149	 0.002193	 0.006114	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78651	 70142	 0.008129	 0.030893	 0.00865	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70142	 79090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70142	 79090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70143	 70144	 0.01045	 0.008271	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70144	 70145	 0.026936	 0.019079	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79090	 70144	 0.014543	 0.0103	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70145	 70146	 0.026229	 0.018579	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70146	 70147	 0.030057	 0.019464	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70147	 70150	 0.015886	 0.01125	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70147	 70151	 0.01995	 0.012914	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79090	 70147	 0.015214	 0.01625	 0.00034	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70148	 70149	 0.000821	 0.002171	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70148	 79091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70148	 79091	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70149	 79092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70149	 79092	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70150	 70151	 0.015229	 0.010786	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79092	 70150	 0.010407	 0.008157	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78773	 70152	 0.012979	 0.010686	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78774	 70152	 0.014436	 0.011429	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78778	 70152	 0.029614	 0.024379	 0.00049	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70153	 70154	 0.002314	 0.007914	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70153	 70155	 0.007093	 0.013193	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70154	 70160	 0.002843	 0.008714	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70155	 70158	 0.00175	 0.005986	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70155	 79093	 0.001357	 0.006729	 0.00016	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70156	 79093	 0.016607	 0.01075	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70157	 70166	 0.000157	 0.00105	 0.00191	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70157	 79093	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70157	 79093	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70158	 70159	 0.003564	 0.004686	 6e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70158	 70161	 0.0063	 0.012893	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70159	 70163	 0.004657	 0.0042	 7e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70160	 70161	 0.0037	 0.005393	 0.00012	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70161	 70162	 0.006057	 0.004293	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70161	 79094	 0.006693	 0.010679	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70163	 79095	 0.0023	 0.005836	 0.00011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70164	 70165	 0.000986	 0.003829	 0.00102	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70164	 70171	 0.001357	 0.003636	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78651	 70164	 0.01655	 0.038429	 0.01171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70164	 79094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70164	 79094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70165	 70169	 0.000629	 0.002057	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70165	 79095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70165	 79095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70165	 79096	 0.000586	 0.003329	 0.00096	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70166	 70167	 0.000164	 0.0011	 0.00201	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70166	 79096	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70166	 79096	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70167	 70168	 0.000107	 0.000721	 0.0013	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70169	 70170	 0.0006	 0.002014	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70171	 79097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70171	 79097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70172	 79098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70172	 79098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70172	 79143	 0.006136	 0.024557	 0.00619	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70173	 70177	 0.005186	 0.011771	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79098	 70173	 0.018207	 0.018386	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70174	 70181	 0.022671	 0.018657	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79098	 70174	 0.013457	 0.012057	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70175	 70181	 0.004829	 0.01015	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70176	 70177	 0.008343	 0.008907	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70177	 70178	 0.003229	 0.007379	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78791	 70179	 0.000586	 0.003243	 0.00099	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70179	 79099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70179	 79099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70180	 79100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70180	 79100	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70181	 70182	 0.015079	 0.015229	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79044	 70181	 0.022271	 0.030357	 0.00067	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70183	 79101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70183	 79101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78738	 70184	 0.0197	 0.013957	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79101	 70184	 0.021571	 0.017071	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78666	 70185	 0.034671	 0.022443	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70186	 70187	 0.000786	 0.0051	 0.01015	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70186	 79102	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70186	 79102	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70187	 70195	 0.000721	 0.004871	 0.00887	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70188	 79103	 0.020529	 0.020171	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70189	 70194	 0.003121	 0.012493	 0.00422	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79102	 70189	 0.006021	 0.015921	 0.00373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70189	 79103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70189	 79103	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70190	 70195	 0.000671	 0.004714	 0.00802	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70190	 74798	 0.000657	 0.005643	 0.01061	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70190	 79104	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79105	 70190	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70191	 79109	 0.032371	 0.025621	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70191	 79826	 0.02505	 0.019821	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70192	 70199	 0.10015	 0.064843	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70192	 70201	 0.066693	 0.090921	 0.00201	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70192	 79826	 0.016479	 0.0263	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70192	 79832	 0.067243	 0.060257	 0.00124	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70193	 70198	 0.002586	 0.006829	 0.0016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79102	 70193	 0.007986	 0.032514	 0.00792	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79104	 70193	 0.0033	 0.008721	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70193	 79106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70193	 79106	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79104	 70194	 0.005779	 0.015843	 0.00344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70194	 79107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70194	 79107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70194	 79833	 0.008479	 0.02765	 0.00734	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70195	 79108	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70195	 79108	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70196	 70201	 0.023393	 0.046307	 0.00068	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79108	 70196	 0.020486	 0.0327	 0.00075	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70197	 70198	 0.002593	 0.00625	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70197	 74800	 0.001843	 0.007364	 0.00186	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79104	 70197	 0.001486	 0.004843	 0.00129	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70197	 79109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70197	 79109	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70198	 79110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70198	 79110	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70200	 70201	 0.104107	 0.07375	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70201	 70202	 0.02805	 0.05765	 0.0011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70202	 70203	 0.035664	 0.051971	 0.00117	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78770	 70203	 0.042764	 0.064121	 0.00116	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70204	 70205	 0.031807	 0.124236	 0.00276	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70204	 70205	 0.031807	 0.124236	 0.00276	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78595	 70204	 0.059107	 0.207029	 0.00574	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70204	 79414	 0.022343	 0.208043	 0.00403	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70205	 70206	 0.014786	 0.057729	 0.00128	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70205	 70206	 0.014786	 0.057729	 0.00128	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70206	 79117	 0.007714	 0.075593	 0.00148	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70207	 70216	 0.167207	 0.108279	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70207	 70354	 0.143464	 0.0929	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70208	 79111	 0.037457	 0.073407	 0.0011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70209	 79111	 0.033886	 0.021936	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70210	 70213	 0.013621	 0.023957	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70210	 70223	 0.016707	 0.026664	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70210	 79111	 0.022343	 0.045914	 0.00088	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70210	 79137	 0.008279	 0.036664	 0.00084	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70211	 70212	 0.011836	 0.008386	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70212	 70213	 0.014364	 0.014507	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70212	 70219	 0.020257	 0.020464	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70213	 70214	 0.023671	 0.018729	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70215	 70216	 0.036986	 0.030443	 0.00061	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70215	 79111	 0.013836	 0.022086	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70217	 70218	 0.011764	 0.007614	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70217	 70219	 0.013093	 0.017207	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70217	 79111	 0.005993	 0.017193	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70219	 70220	 0.016793	 0.011893	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70221	 70222	 0.021193	 0.015014	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70221	 79111	 0.01805	 0.016629	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70222	 70227	 0.023564	 0.016693	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70222	 70234	 0.009864	 0.014371	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70222	 70235	 0.013129	 0.030014	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70222	 79111	 0.013607	 0.0204	 0.00037	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70223	 70224	 0.018164	 0.016386	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70224	 70236	 0.015521	 0.016571	 0.00035	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70225	 70231	 0.020821	 0.047221	 0.00094	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70225	 70233	 0.033343	 0.021586	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70225	 79111	 0.009757	 0.018143	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70226	 79111	 0.023536	 0.018629	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70227	 79111	 0.015307	 0.013807	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70228	 79111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70228	 79111	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70229	 70239	 0.008007	 0.028479	 0.00634	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70229	 79112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70229	 79112	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70230	 70231	 0.00215	 0.015464	 0.00051	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79112	 70230	 0.0148	 0.072236	 0.00125	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70230	 79114	 0.013164	 0.044971	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70231	 70238	 0.01395	 0.028664	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70231	 79113	 0.016429	 0.03055	 0.00071	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70232	 70236	 0.026207	 0.016964	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70234	 70236	 0.01165	 0.015893	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70235	 70238	 0.006464	 0.018543	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70237	 70239	 0.003171	 0.012479	 0.00326	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70237	 70253	 0.003579	 0.012529	 0.00415	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70237	 79113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70237	 79113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70238	 70247	 0.053436	 0.043986	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79113	 70238	 0.011464	 0.015636	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70239	 79114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70239	 79114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78204	 70240	 0.004514	 0.029343	 0.05849	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78285	 70240	 0.002543	 0.0193	 0.03551	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70240	 79115	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79116	 70240	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70241	 70290	 0.131021	 0.092821	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70242	 70290	 0.035721	 0.062829	 0.00118	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79114	 70242	 0.034271	 0.054971	 0.00101	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70243	 70245	 0.072307	 0.077229	 0.00164	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70243	 79117	 0.062857	 0.073686	 0.00128	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70244	 70256	 0.017229	 0.051864	 0.01623	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70244	 70288	 0.009779	 0.029286	 0.0066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70244	 79117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70244	 79117	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70245	 79137	 0.044421	 0.055143	 0.0012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70246	 70260	 0.017421	 0.035657	 0.00088	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79111	 70246	 0.032807	 0.0831	 0.00164	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70246	 79118	 0.0109	 0.028021	 0.00044	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70247	 79119	 0.031964	 0.022643	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70248	 70259	 0.051171	 0.040493	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70248	 70271	 0.039164	 0.035336	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70248	 79121	 0.03735	 0.062921	 0.00089	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70249	 70255	 0.064664	 0.041864	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70250	 79118	 0.025107	 0.016257	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70251	 70252	 0.003293	 0.009871	 0.00222	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70251	 70355	 0.004143	 0.019607	 0.00471	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70251	 79118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70251	 79118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70252	 70253	 0.000871	 0.003171	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70252	 70256	 0.004179	 0.014557	 0.00338	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70253	 79119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70253	 79119	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79113	 70254	 0.035964	 0.023286	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79113	 70255	 0.035679	 0.0469	 0.00064	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79119	 70255	 0.025836	 0.025386	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70256	 70279	 0.005114	 0.017071	 0.00433	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70256	 79120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70256	 79120	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70257	 70258	 0.003264	 0.006671	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70257	 70260	 0.006836	 0.013536	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79120	 70258	 0.00905	 0.021007	 0.0004	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70259	 70260	 0.022136	 0.019971	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70260	 70261	 0.015593	 0.010093	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70260	 70262	 0.007829	 0.013764	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70262	 70263	 0.011807	 0.008364	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70262	 70266	 0.008314	 0.0193	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70263	 70271	 0.02765	 0.0179	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70264	 70265	 0.01015	 0.008357	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70265	 70266	 0.018714	 0.012114	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70265	 70267	 0.010614	 0.014479	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70266	 70273	 0.024786	 0.026471	 0.00056	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70267	 70268	 0.012036	 0.008521	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70267	 70273	 0.013843	 0.012486	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70269	 70270	 0.008679	 0.019679	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70269	 70275	 0.008364	 0.017186	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79117	 70270	 0.020057	 0.089379	 0.00152	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70270	 79137	 0.033871	 0.089786	 0.00228	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70272	 70274	 0.038529	 0.030486	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70273	 70275	 0.010236	 0.013964	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70273	 70277	 0.012714	 0.022357	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70273	 79137	 0.011007	 0.067686	 0.00122	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70274	 70277	 0.0245	 0.017357	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70275	 70276	 0.017814	 0.012614	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70277	 70278	 0.0139	 0.009843	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70278	 70286	 0.073593	 0.058243	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70279	 79121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70279	 79121	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70280	 70285	 0.129129	 0.091479	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70280	 70349	 0.024629	 0.122214	 0.00291	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79121	 70280	 0.013443	 0.071629	 0.00126	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70281	 70282	 0.013621	 0.025321	 0.00059	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70281	 70308	 0.026171	 0.041779	 0.00096	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70281	 79124	 0.007521	 0.017471	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70282	 70284	 0.014364	 0.026714	 0.00063	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70283	 70308	 0.061286	 0.043414	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70284	 70287	 0.036964	 0.068729	 0.00161	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79121	 70287	 0.046993	 0.096579	 0.00184	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70288	 70350	 0.013371	 0.050829	 0.01424	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70288	 79122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70288	 79122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70289	 70298	 0.003836	 0.015079	 0.00394	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78382	 70290	 0.046079	 0.081043	 0.00152	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70291	 70294	 0.020229	 0.020436	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70291	 70302	 0.018779	 0.0436	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70291	 70315	 0.010079	 0.015114	 0.00027	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70292	 70293	 0.018457	 0.014607	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70293	 70295	 0.012371	 0.013607	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70293	 70296	 0.032721	 0.026936	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70294	 70301	 0.016607	 0.037986	 0.00093	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70294	 70324	 0.009671	 0.013186	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70294	 70325	 0.014486	 0.011921	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70295	 70315	 0.026	 0.018414	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70295	 70324	 0.007679	 0.010093	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70296	 70299	 0.013857	 0.031429	 0.00063	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70296	 70303	 0.03875	 0.030664	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70297	 70299	 0.01	 0.015957	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70297	 70301	 0.01375	 0.010879	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70298	 70304	 0.001336	 0.004857	 0.00149	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70299	 70300	 0.011314	 0.009307	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70299	 70305	 0.017943	 0.028643	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70300	 70307	 0.006979	 0.013814	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70301	 70302	 0.00565	 0.014307	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70301	 70307	 0.01245	 0.0133	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70302	 70313	 0.006493	 0.012071	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78279	 70302	 0.010743	 0.024371	 0.00049	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70302	 79131	 0.014507	 0.026971	 0.00063	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70303	 70305	 0.018443	 0.022893	 0.0005	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70303	 79123	 0.016429	 0.026229	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70304	 70311	 0.002007	 0.00655	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70304	 79123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70304	 79123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70305	 79124	 0.022629	 0.024886	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70306	 70307	 0.009436	 0.011064	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70306	 70308	 0.005571	 0.012636	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70306	 70313	 0.013964	 0.02765	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70308	 70309	 0.005436	 0.012621	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70309	 70310	 0.002386	 0.005464	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70309	 70312	 0.020257	 0.016036	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70310	 79124	 0.006793	 0.015529	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70311	 70335	 0.009236	 0.024407	 0.00571	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70311	 79124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70311	 79124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70313	 70314	 0.025457	 0.025007	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78620	 70313	 0.016443	 0.0816	 0.00194	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70313	 79131	 0.018386	 0.041707	 0.00083	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70315	 70316	 0.015007	 0.010629	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70316	 70324	 0.022157	 0.022379	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78286	 70317	 0.004771	 0.017364	 0.00531	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70317	 79125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70317	 79125	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78286	 70318	 0.001093	 0.015771	 0.00501	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70318	 79126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70318	 79126	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70318	 79127	 0.003993	 0.042314	 0.01256	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70319	 74676	 0.019414	 0.075814	 0.00168	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79126	 70319	 0.029379	 0.114743	 0.00254	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70319	 79128	 0.02705	 0.071693	 0.00182	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70320	 79127	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70320	 79127	 0.000173	 0.013839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70321	 70331	 0.054664	 0.035393	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79128	 70321	 0.00845	 0.012671	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70321	 79129	 0.009	 0.020893	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70322	 70323	 0.003514	 0.010343	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70322	 70324	 0.002429	 0.009471	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79128	 70322	 0.004064	 0.021821	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70323	 70324	 0.004336	 0.008064	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70323	 70325	 0.015093	 0.013614	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70326	 70338	 0.001207	 0.004836	 0.00122	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79127	 70326	 0.001157	 0.005471	 0.00175	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70326	 79129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70326	 79129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70327	 70339	 0.000929	 0.004257	 0.00109	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79127	 70327	 0.001979	 0.009071	 0.00232	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70327	 79130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70327	 79130	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70328	 70329	 0.014557	 0.023229	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70328	 70330	 0.010786	 0.02135	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79126	 70328	 0.023457	 0.100286	 0.00226	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79128	 70329	 0.028086	 0.042114	 0.00076	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70330	 70331	 0.022064	 0.043686	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70332	 70337	 0.007457	 0.0447	 0.00108	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70332	 79842	 0.038193	 0.098186	 0.00152	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70333	 70342	 0.001921	 0.006993	 0.00214	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70333	 70344	 0.001514	 0.0079	 0.0019	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70334	 70336	 0.002736	 0.010693	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78619	 70334	 0.020579	 0.063136	 0.00171	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70335	 70342	 0.001229	 0.006371	 0.00156	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79127	 70335	 0.003607	 0.018707	 0.00456	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70335	 79131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70335	 79131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70336	 70340	 0.011629	 0.026993	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70336	 70343	 0.003007	 0.011693	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70336	 79134	 0.007136	 0.010393	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70337	 70346	 0.006193	 0.024179	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70337	 74840	 0.021643	 0.073929	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70337	 79132	 0.009464	 0.050636	 0.00154	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70338	 70339	 0.001586	 0.005636	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70338	 79132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70338	 79132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70339	 70344	 0.0013	 0.007914	 0.00199	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70340	 70341	 0.019543	 0.017629	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70340	 70343	 0.002986	 0.012457	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79128	 70340	 0.00895	 0.044414	 0.00106	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79132	 70340	 0.002879	 0.016379	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70341	 79134	 0.008564	 0.016786	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70342	 79133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70342	 79133	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70344	 79134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70344	 79134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78279	 70345	 0.020193	 0.013071	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79133	 70345	 0.015064	 0.010893	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70346	 70347	 0.006886	 0.026371	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78608	 70349	 0.014807	 0.073464	 0.00175	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78666	 70351	 0.020943	 0.014836	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78634	 70352	 0.008736	 0.015371	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70353	 79135	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79136	 70353	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70355	 79137	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70355	 79137	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79083	 70356	 0.000829	 0.004314	 0.00104	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79014	 70357	 0.002764	 0.009229	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78193	 70358	 1.4e-05	 0.000207	 0.00086	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78216	 70358	 2.9e-05	 0.000393	 0.00147	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78648	 70359	 0.002807	 0.009586	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70362	 79138	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79139	 70362	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70362	 79142	 0.000479	 0.003029	 0.00634	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78236	 70363	 0.000571	 0.002707	 0.00065	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78248	 70363	 0.00165	 0.006479	 0.00169	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79023	 70363	 0.000829	 0.005014	 0.00128	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70363	 79140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70363	 79140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78249	 70364	 0.006279	 0.024529	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78217	 70365	 0.001736	 0.01635	 0.00495	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70365	 79141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70365	 79141	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78672	 70366	 0.031514	 0.055421	 0.00104	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78768	 70366	 0.030021	 0.021264	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78769	 70366	 0.063257	 0.044807	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78608	 70368	 0.003507	 0.010307	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78652	 70371	 0.015036	 0.0119	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79136	 70372	 0.005471	 0.029371	 0.0007	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70374	 79142	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78165	 70375	 0.000814	 0.002864	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70376	 79145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70376	 79145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70377	 79146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70377	 79146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78238	 70378	 0.059443	 0.17485	 0.00359	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70379	 70461	 0.06575	 0.230314	 0.00638	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70379	 70461	 0.06575	 0.230314	 0.00638	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78238	 70379	 0.113943	 0.445679	 0.0099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78238	 70379	 0.113943	 0.445679	 0.0099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70380	 79147	 0.061207	 0.110443	 0.0016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70381	 79147	 0.147679	 0.095629	 0.00182	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70382	 70459	 0.016336	 0.062107	 0.01739	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70382	 79147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70382	 79147	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70383	 70391	 0.048121	 0.164407	 0.00358	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70383	 70520	 0.077943	 0.2664	 0.0058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79147	 70383	 0.02985	 0.143307	 0.00429	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78312	 70384	 0.051221	 0.090079	 0.00169	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70384	 79148	 0.044321	 0.117493	 0.00298	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70385	 70387	 0.072336	 0.164114	 0.00327	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78312	 70385	 0.054357	 0.0549	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70386	 70530	 0.023421	 0.061921	 0.0145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78552	 70387	 0.048486	 0.142593	 0.00292	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70388	 70400	 0.0954	 0.078529	 0.00159	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70388	 79149	 0.036957	 0.036307	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70389	 70397	 0.007964	 0.021393	 0.00485	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78268	 70389	 0.022807	 0.125321	 0.03319	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70389	 79148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70389	 79148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79148	 70390	 0.14285	 0.113064	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70390	 79149	 0.127993	 0.082871	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70391	 79150	 0.04275	 0.101243	 0.00185	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70392	 70393	 0.007764	 0.024271	 0.00703	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70392	 70398	 0.006879	 0.021514	 0.00623	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70394	 70395	 0.018793	 0.013314	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70394	 70396	 0.013236	 0.008564	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70394	 79150	 0.007386	 0.012993	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70397	 70398	 0.002107	 0.005743	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70397	 79149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70397	 79149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70398	 79150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70398	 79150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79150	 70399	 0.009	 0.013114	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70401	 70402	 0.000807	 0.008593	 0.00255	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70401	 74372	 0.002007	 0.019964	 0.00741	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70402	 70405	 0.000829	 0.006621	 0.00163	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70402	 70409	 0.001257	 0.004571	 0.0014	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70402	 70411	 0.000579	 0.005621	 0.00426	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70403	 70404	 0.024321	 0.015743	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70404	 70406	 0.0122	 0.037429	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70404	 70407	 0.030279	 0.02145	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70404	 79151	 0.007043	 0.016107	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70405	 70408	 0.00175	 0.008329	 0.00241	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70405	 70409	 0.001457	 0.006671	 0.00171	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70405	 74373	 0.001807	 0.023507	 0.01486	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70405	 79151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70405	 79151	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70406	 70426	 0.022864	 0.111571	 0.00193	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70406	 79745	 0.012321	 0.104871	 0.00274	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70408	 70409	 0.00045	 0.002593	 0.00074	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70408	 70410	 0.000379	 0.004793	 0.00149	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70410	 70415	 0.000514	 0.006593	 0.00197	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70411	 70412	 0.000343	 0.003907	 0.00219	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70412	 70417	 0.002964	 0.017636	 0.00464	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70412	 79152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70412	 79152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70412	 79157	 0.0023	 0.027207	 0.00774	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70412	 79752	 0.006507	 0.097271	 0.02882	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70413	 79154	 0.04205	 0.041314	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70414	 70420	 0.003014	 0.01825	 0.00057	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79152	 70414	 0.006614	 0.047893	 0.0012	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70415	 70416	 0.0006	 0.006986	 0.00205	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70416	 70417	 0.000529	 0.005829	 0.00175	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70416	 79153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70416	 79153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70417	 70419	 0.000257	 0.003243	 0.00141	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70417	 79154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70417	 79154	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70418	 79155	 0.019879	 0.014079	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70419	 70422	 0.000293	 0.0044	 0.00128	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70420	 70421	 0.041171	 0.02665	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70420	 79158	 0.005036	 0.022321	 0.00067	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70422	 70423	 0.000243	 0.003729	 0.00137	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70422	 79155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70422	 79155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70423	 79156	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70423	 79156	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70423	 79157	 0.000421	 0.002986	 0.0017	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70424	 79158	 0.0132	 0.010864	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70425	 79157	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79158	 70425	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70426	 70427	 0.016657	 0.058329	 0.00161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70427	 70431	 0.006707	 0.022907	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70428	 70429	 0.021436	 0.016964	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79153	 70429	 0.025179	 0.022714	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70430	 70431	 0.017043	 0.011036	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70431	 70432	 0.017957	 0.012721	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79155	 70431	 0.008771	 0.022221	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70433	 70436	 0.0272	 0.019271	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70434	 70436	 0.001321	 0.0107	 0.00028	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79156	 70434	 0.00175	 0.0149	 0.00039	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79156	 70435	 0.015814	 0.011207	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70436	 79159	 0.002064	 0.01535	 0.00036	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70437	 70438	 0.000786	 0.002979	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70437	 79159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70437	 79159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79157	 70438	 0.001929	 0.007964	 0.00189	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70438	 79160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70438	 79160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79158	 70439	 0.029157	 0.020657	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70440	 70441	 0.00685	 0.030343	 0.00091	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70440	 70442	 0.002	 0.009936	 0.00024	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79160	 70441	 0.004764	 0.026229	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70442	 70451	 0.008564	 0.036621	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70443	 70445	 0.003436	 0.013421	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70443	 70449	 0.005293	 0.023586	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70444	 70445	 0.00395	 0.017493	 0.0004	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70444	 70446	 0.009593	 0.015729	 0.00028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70444	 70448	 0.031143	 0.020164	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79159	 70444	 0.00245	 0.016629	 0.00041	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70446	 70452	 0.056071	 0.039721	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70447	 70449	 0.003657	 0.0128	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70447	 70451	 0.008614	 0.033629	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70447	 70451	 0.008614	 0.033629	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79159	 70447	 0.005807	 0.041793	 0.00137	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70450	 70451	 0.006307	 0.025243	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70450	 70451	 0.006307	 0.025243	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70450	 73321	 0.019164	 0.0854	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70450	 73321	 0.019164	 0.0854	 0.00145	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70452	 70453	 0.0995	 0.070486	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70454	 70455	 0.209729	 0.166021	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70455	 79748	 0.049543	 0.092129	 0.00216	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70456	 70457	 0.111236	 0.177607	 0.00409	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70456	 70458	 0.024086	 0.148114	 0.00267	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70457	 79161	 0.085393	 0.174793	 0.0043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78256	 70458	 0.036093	 0.193214	 0.00586	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70459	 70460	 0.011043	 0.045593	 0.01079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70459	 79161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70459	 79161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78293	 70460	 0.060521	 0.160307	 0.03762	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70461	 74671	 0.0808	 0.3603	 0.00613	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70461	 74671	 0.0808	 0.3603	 0.00613	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70462	 70467	 0.004286	 0.053657	 0.0365	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70462	 74585	 0.005979	 0.077743	 0.04922	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70463	 70464	 0.112879	 0.395814	 0.01098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70463	 70464	 0.112879	 0.395814	 0.01098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78561	 70463	 0.073193	 0.393571	 0.00936	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70464	 70465	 0.042829	 0.125957	 0.00259	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70464	 70466	 0.028021	 0.107364	 0.00304	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70464	 70473	 0.068179	 0.126793	 0.00297	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70465	 70466	 0.00835	 0.017093	 0.00042	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70466	 70473	 0.141079	 0.138621	 0.00234	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70466	 79163	 0.114657	 0.402079	 0.01116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70466	 79163	 0.114657	 0.402079	 0.01116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70467	 70468	 0.006586	 0.026371	 0.00664	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70467	 79162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70467	 79162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70468	 79163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70468	 79163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70469	 70470	 0.026829	 0.082307	 0.00223	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70469	 70478	 0.020471	 0.148307	 0.00373	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79163	 70469	 0.021214	 0.165357	 0.00309	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79162	 70470	 0.054314	 0.190236	 0.00527	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79162	 70470	 0.054314	 0.190236	 0.00527	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70471	 70478	 0.016079	 0.130093	 0.00336	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79163	 70471	 0.059379	 0.231993	 0.00515	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79163	 70471	 0.059379	 0.231993	 0.00515	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70472	 70473	 0.257629	 0.203971	 0.00257	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70474	 70476	 0.296743	 0.266186	 0.00545	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70475	 70476	 0.243521	 0.157743	 0.003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70476	 70479	 0.034143	 0.086829	 0.00137	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70477	 70478	 0.040386	 0.028607	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70478	 70479	 0.004414	 0.021314	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70478	 70480	 0.046971	 0.058307	 0.00127	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78602	 70478	 0.083464	 0.3722	 0.00633	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78602	 70478	 0.083464	 0.3722	 0.00633	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70481	 74450	 0.236721	 0.153329	 0.00292	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70482	 74534	 0.0859	 0.086771	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70482	 79165	 0.058679	 0.068786	 0.00119	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70483	 79164	 0.024357	 0.017607	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70484	 70487	 0.005821	 0.020707	 0.00461	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70484	 74539	 0.007186	 0.019329	 0.00542	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70484	 79164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70484	 79164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70485	 70487	 0.002264	 0.007921	 0.00262	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70485	 70492	 0.006121	 0.016771	 0.00365	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70485	 79165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70485	 79165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70486	 79166	 0.038657	 0.045314	 0.00079	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70487	 79166	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70487	 79166	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70488	 70489	 0.106657	 0.069057	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70488	 79771	 0.145086	 0.119443	 0.00242	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70489	 79772	 0.02185	 0.057914	 0.00147	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70490	 70529	 0.008129	 0.029579	 0.00906	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70490	 79167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70490	 79167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70491	 70495	 0.007136	 0.024986	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79165	 70491	 0.033721	 0.078286	 0.00116	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79167	 70491	 0.0065	 0.038943	 0.00094	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70492	 70493	 0.002464	 0.0067	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70493	 70496	 0.0021	 0.005636	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70494	 70498	 0.031236	 0.020221	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70494	 79168	 0.008643	 0.010129	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70495	 79168	 0.00565	 0.021993	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70496	 70497	 0.002079	 0.007121	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70496	 79168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70496	 79168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70497	 70512	 0.008843	 0.023736	 0.00538	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70499	 70501	 0.011193	 0.032907	 0.00067	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79168	 70499	 0.003829	 0.015314	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70500	 79170	 0.045029	 0.09215	 0.00226	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70501	 70505	 0.016786	 0.034493	 0.00066	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70502	 70505	 0.017064	 0.027236	 0.00063	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70503	 70505	 0.009257	 0.01485	 0.00027	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70503	 79169	 0.006786	 0.01575	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70504	 70512	 0.004371	 0.010143	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70504	 70530	 0.0072	 0.019036	 0.00446	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70504	 79169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70504	 79169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70505	 79170	 0.014721	 0.025886	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70506	 70518	 0.006736	 0.026957	 0.00057	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79169	 70506	 0.003843	 0.013464	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70507	 70511	 0.017943	 0.0142	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79169	 70507	 0.017979	 0.030293	 0.00043	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70508	 70509	 0.003821	 0.012757	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70508	 70513	 0.005564	 0.008886	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79169	 70508	 0.002914	 0.016557	 0.0003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70508	 79170	 0.008057	 0.026886	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70509	 70510	 0.015357	 0.012643	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70509	 70515	 0.00755	 0.012057	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70509	 70517	 0.036007	 0.035371	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78268	 70512	 0.035329	 0.184893	 0.04471	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70512	 79170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70512	 79170	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70513	 70514	 0.00285	 0.005829	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79170	 70514	 0.005586	 0.012664	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70515	 70516	 0.014	 0.011529	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70518	 70519	 0.019007	 0.072829	 0.00206	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70519	 70520	 0.0523	 0.138643	 0.00351	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70521	 70524	 0.015771	 0.03965	 0.01027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70521	 70526	 0.019771	 0.051336	 0.01246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70521	 74532	 0.0107	 0.038071	 0.00846	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70521	 74537	 0.030036	 0.081821	 0.01804	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70522	 70525	 0.07275	 0.127957	 0.00241	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78302	 70522	 0.039193	 0.152493	 0.00254	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70522	 79172	 0.214429	 0.176579	 0.00358	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70523	 70525	 0.016479	 0.014764	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70523	 79171	 0.008579	 0.021736	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70524	 70526	 0.004893	 0.012293	 0.00319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70524	 79171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70524	 79171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70526	 70528	 0.010614	 0.049521	 0.01227	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70526	 79172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70526	 79172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70527	 79173	 0.11885	 0.094064	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70528	 79173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70528	 79173	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70529	 79174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70529	 79174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70531	 79175	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70531	 79175	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70532	 79176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70532	 79176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70533	 70534	 0.492793	 0.485371	 0.0082	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79175	 70533	 0.023307	 0.139664	 0.00336	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79176	 70533	 0.0604	 0.344021	 0.01061	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79175	 70534	 0.268186	 0.411286	 0.00578	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78371	 70537	 0.035121	 0.061764	 0.00116	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70538	 70568	 0.035471	 0.022964	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70539	 70540	 0.001607	 0.010914	 0.00027	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70539	 70541	 0.004036	 0.014121	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70539	 70541	 0.004036	 0.014121	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70539	 79177	 0.0031	 0.017629	 0.00054	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70540	 70542	 0.004057	 0.018064	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70540	 70542	 0.004057	 0.018064	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70540	 70569	 0.004	 0.013993	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70540	 70569	 0.004	 0.013993	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70541	 70570	 0.003371	 0.013164	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70541	 70570	 0.003371	 0.013164	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70542	 79177	 0.003864	 0.013536	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70542	 79177	 0.003864	 0.013536	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70543	 79177	 0.020736	 0.013421	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70544	 70546	 2.1e-05	 0.00025	 0.01881	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70544	 70567	 5.7e-05	 0.000786	 0.05392	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70544	 79177	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70544	 79177	 0.00209	 0.091976	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70545	 70546	 7e-06	 0.00015	 0.01059	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70545	 70551	 1.4e-05	 0.00015	 0.00979	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70546	 79178	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70546	 79178	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70547	 70549	 0.002357	 0.009214	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70547	 70549	 0.002357	 0.009214	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70547	 70550	 0.008771	 0.005679	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70547	 79179	 0.004586	 0.016064	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70547	 79179	 0.004586	 0.016064	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70548	 70549	 0.001179	 0.004607	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70548	 70549	 0.001179	 0.004607	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70548	 70572	 0.001493	 0.006629	 0.0002	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70548	 70574	 0.000743	 0.006014	 0.00016	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70550	 70630	 0.0226	 0.017714	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70551	 70626	 2.9e-05	 0.000393	 0.02528	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70551	 79179	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70551	 79179	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70552	 70553	 0.003829	 0.014957	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70552	 70553	 0.003829	 0.014957	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70552	 79188	 0.006971	 0.027221	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70552	 79188	 0.006971	 0.027221	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70553	 70554	 0.013457	 0.009536	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70553	 70559	 0.003679	 0.014379	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70553	 70559	 0.003679	 0.014379	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70555	 70556	 0.001364	 0.011043	 0.00029	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70555	 79188	 0.00335	 0.027107	 0.0007	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70556	 70557	 0.001357	 0.00985	 0.00025	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70557	 70558	 0.001379	 0.008893	 0.00029	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79177	 70558	 0.002371	 0.0135	 0.00041	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79177	 70559	 0.0027	 0.01055	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79177	 70559	 0.0027	 0.01055	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78177	 70560	 0.006886	 0.058571	 0.00153	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70560	 79701	 0.006321	 0.03135	 0.00075	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70561	 70562	 0.071929	 0.05095	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70562	 70563	 0.0532	 0.037686	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70563	 70628	 0.027321	 0.040964	 0.00074	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70564	 70565	 0.026907	 0.029593	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70564	 70623	 0.014864	 0.065879	 0.00198	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78177	 70564	 0.022971	 0.089736	 0.00199	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78177	 70564	 0.022971	 0.089736	 0.00199	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70564	 79180	 0.01425	 0.049886	 0.00138	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70564	 79180	 0.01425	 0.049886	 0.00138	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70566	 72134	 0.0156	 0.074871	 0.00224	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78177	 70566	 0.028564	 0.109443	 0.00309	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70566	 79181	 0.01955	 0.105	 0.00249	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70567	 79180	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70567	 79180	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70568	 70569	 0.010064	 0.006514	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79180	 70569	 0.010579	 0.041307	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79180	 70569	 0.010579	 0.041307	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70570	 70571	 0.00265	 0.012943	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70570	 70575	 0.004886	 0.021779	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70570	 70575	 0.004886	 0.021779	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70570	 79181	 0.0151	 0.058986	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70570	 79181	 0.0151	 0.058986	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70571	 70572	 0.001843	 0.009814	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70573	 70629	 0.007643	 0.046543	 0.01171	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70573	 74196	 0.018814	 0.071543	 0.02004	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70573	 79181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70573	 79181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70574	 70575	 0.00085	 0.006093	 0.0002	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79178	 70575	 0.004414	 0.019671	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79178	 70575	 0.004414	 0.019671	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70576	 70577	 0.002929	 0.0122	 0.00381	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70576	 70621	 0.005164	 0.023707	 0.00607	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70577	 70578	 0.008064	 0.036986	 0.00948	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70578	 70579	 0.004971	 0.024993	 0.00651	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70578	 79182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70578	 79182	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70579	 70582	 0.002107	 0.018371	 0.00504	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70579	 70629	 0.011893	 0.032393	 0.00714	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70579	 79183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70579	 79183	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70580	 70590	 0.251807	 0.163107	 0.00311	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79182	 70580	 0.196464	 0.216164	 0.00289	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79183	 70581	 0.1742	 0.157214	 0.00263	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70582	 70585	 0.004864	 0.035	 0.00928	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70582	 70629	 0.008971	 0.041843	 0.01036	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70582	 79378	 0.010557	 0.064929	 0.01874	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70583	 70585	 0.000536	 0.004057	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78241	 70583	 0.008443	 0.039386	 0.00976	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70583	 79184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70583	 79184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79184	 70584	 0.021307	 0.013793	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70586	 79185	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70586	 79185	 0.011865	 0.36781	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79185	 70587	 0.217336	 0.140764	 0.00268	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78322	 70588	 0.047929	 0.089129	 0.00209	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78346	 70589	 0.029343	 0.044957	 0.00063	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70591	 70592	 0.094564	 0.061229	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70591	 70609	 0.024471	 0.037493	 0.00053	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70593	 70594	 0.020164	 0.01305	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70594	 70595	 0.015029	 0.009729	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70594	 70606	 0.052029	 0.041171	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70596	 70597	 0.035664	 0.023093	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70597	 70603	 0.017086	 0.018243	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70598	 70599	 0.009593	 0.006793	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70599	 70600	 0.006071	 0.0043	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70600	 70601	 0.007229	 0.005721	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70600	 70602	 0.022314	 0.015807	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70600	 70603	 0.007186	 0.012636	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70603	 70604	 0.014014	 0.009929	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70603	 70605	 0.006336	 0.016286	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70605	 70606	 0.013664	 0.014593	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70605	 70607	 0.004729	 0.011986	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70605	 79186	 0.006357	 0.034014	 0.00103	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70607	 70608	 0.0041	 0.012064	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70608	 70610	 0.006707	 0.026093	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70609	 70610	 0.0214	 0.042371	 0.00062	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70610	 70611	 0.020786	 0.014729	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70610	 79186	 0.003264	 0.017464	 0.00053	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70612	 70614	 0.01685	 0.011936	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70613	 70614	 0.015143	 0.009807	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70614	 70615	 0.015393	 0.0109	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70614	 79186	 0.003564	 0.006621	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70615	 70616	 0.009879	 0.007814	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70617	 70621	 0.004586	 0.017421	 0.00488	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78176	 70617	 0.007593	 0.055457	 0.01426	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70617	 79186	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70617	 79186	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70618	 70620	 0.006871	 0.014129	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70618	 70623	 0.0125	 0.021979	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70619	 70622	 0.040364	 0.026136	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70620	 79187	 0.02155	 0.049507	 0.00075	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70621	 79187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70621	 79187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70622	 70623	 0.00405	 0.005529	 0.0001	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70623	 70625	 0.022657	 0.034364	 0.00049	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79186	 70623	 0.027521	 0.080929	 0.00166	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70624	 70625	 0.035671	 0.028229	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70626	 79188	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70626	 79188	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78177	 70627	 0.055457	 0.035907	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78177	 70628	 0.017657	 0.046793	 0.00119	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70631	 70632	 0.000364	 0.002379	 0.00061	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70631	 70650	 0.000343	 0.002079	 0.00063	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70632	 70634	 0.000586	 0.003471	 0.00091	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70632	 79189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70632	 79189	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79189	 70633	 0.013907	 0.009007	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70634	 79190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70634	 79190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79190	 70635	 0.018743	 0.012136	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70636	 70638	 0.001671	 0.016379	 0.00032	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70636	 70662	 0.0036	 0.025886	 0.00085	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70637	 70638	 0.001414	 0.010179	 0.00034	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70637	 70639	 0.015479	 0.010021	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70637	 70644	 0.004107	 0.018293	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70637	 70644	 0.004107	 0.018293	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70638	 70640	 0.018593	 0.014714	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 70638	 0.003279	 0.015736	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70641	 70642	 0.014971	 0.0106	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70641	 70647	 0.005264	 0.012229	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70641	 70659	 0.008271	 0.056171	 0.00139	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 70641	 0.014843	 0.045529	 0.00124	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70643	 70644	 0.001357	 0.010971	 0.00029	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70643	 70657	 0.020707	 0.013407	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70643	 74396	 0.0296	 0.214471	 0.00539	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70643	 79191	 0.004271	 0.014579	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70644	 70647	 0.00455	 0.009343	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70645	 79192	 0.018271	 0.012943	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70646	 70647	 0.01705	 0.011036	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70648	 70651	 0.0389	 0.025186	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70649	 70650	 0.000679	 0.004314	 0.00117	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70649	 70658	 0.00215	 0.00895	 0.00279	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70649	 74357	 0.005543	 0.024121	 0.00687	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70649	 79191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70649	 79191	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70650	 79192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70650	 79192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70651	 74298	 0.028964	 0.113121	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70651	 74298	 0.028964	 0.113121	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 70651	 0.005679	 0.025286	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 70651	 0.005679	 0.025286	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70652	 79194	 0.031614	 0.050714	 0.00094	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70653	 70656	 0.000693	 0.00425	 0.00122	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70653	 74287	 0.001107	 0.006693	 0.00171	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70653	 79193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70653	 79193	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70654	 70655	 0.000607	 0.00795	 0.0035	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70654	 79194	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70654	 79194	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70654	 79752	 0.005979	 0.090736	 0.03349	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70655	 70656	 0.000171	 0.002657	 0.00083	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70656	 74286	 0.000721	 0.004207	 0.00115	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70658	 74357	 0.003907	 0.018479	 0.00444	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70659	 70660	 0.005157	 0.020129	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70659	 70660	 0.005157	 0.020129	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70659	 70661	 0.016614	 0.064879	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70659	 79742	 0.021779	 0.076243	 0.00211	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70660	 70664	 0.036086	 0.126371	 0.0035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70660	 70664	 0.036086	 0.126371	 0.0035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70661	 70663	 0.015443	 0.060307	 0.00134	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70662	 74302	 0.012314	 0.099643	 0.00257	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70663	 74329	 0.036871	 0.125979	 0.00274	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70664	 70666	 0.005836	 0.034979	 0.00084	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70664	 70667	 0.035821	 0.102757	 0.00158	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70664	 79753	 0.058321	 0.199271	 0.00434	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70665	 70666	 0.005914	 0.015686	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70665	 70667	 0.027193	 0.055643	 0.00137	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70667	 70668	 0.068907	 0.141636	 0.0027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70668	 74888	 0.092607	 0.190357	 0.00363	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70669	 79195	 0.081836	 0.052986	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70670	 74410	 0.002657	 0.020671	 0.00537	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70670	 79195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70670	 79195	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70671	 70674	 0.0635	 0.074436	 0.00129	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70671	 70681	 0.065436	 0.110236	 0.00157	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70672	 70674	 0.054064	 0.04845	 0.00099	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70672	 71333	 0.03605	 0.057543	 0.00133	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70672	 79319	 0.05595	 0.085714	 0.00121	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70673	 70676	 0.066271	 0.046943	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70675	 70676	 0.023379	 0.092771	 0.00265	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70675	 71321	 0.035007	 0.143079	 0.00289	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70675	 71329	 0.145593	 0.131386	 0.0022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70676	 70680	 0.020643	 0.042421	 0.00081	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70676	 79196	 0.010779	 0.078071	 0.00196	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70677	 70682	 0.019779	 0.066671	 0.01658	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78215	 70677	 0.004957	 0.025307	 0.00636	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70677	 79196	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70677	 79196	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79196	 70678	 0.064564	 0.0418	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70679	 70680	 0.01235	 0.025386	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70679	 70681	 0.015836	 0.032543	 0.00062	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70679	 70685	 0.037971	 0.031257	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70681	 70683	 0.096721	 0.062621	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78336	 70681	 0.033221	 0.113486	 0.00247	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70682	 79197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70682	 79197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79197	 70684	 0.133379	 0.094493	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70686	 71337	 0.076579	 0.225279	 0.00462	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70687	 70688	 0.017193	 0.04355	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70687	 70690	 0.014236	 0.036064	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70688	 71337	 0.036157	 0.106329	 0.00218	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70689	 70690	 0.075786	 0.049064	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70690	 71335	 0.093279	 0.076786	 0.00156	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70690	 71339	 0.21675	 0.195643	 0.00327	 32.0	 32.0	 32.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70691	 70692	 0.000979	 0.003414	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70692	 70696	 0.000836	 0.003186	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70692	 79198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70692	 79198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70693	 70694	 0.003664	 0.008507	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79198	 70693	 0.002179	 0.009693	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70693	 79200	 0.0207	 0.034871	 0.0005	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70694	 70695	 0.004071	 0.007571	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70695	 70699	 0.004336	 0.008914	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70697	 70698	 0.005529	 0.006486	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70698	 79200	 0.006014	 0.012307	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70699	 70703	 0.010257	 0.0291	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70700	 70702	 0.001564	 0.0042	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70700	 79199	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70700	 79199	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70701	 70703	 0.003279	 0.008307	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79199	 70701	 0.003229	 0.007321	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70702	 79200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70702	 79200	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70703	 70704	 0.006636	 0.019507	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78844	 70703	 0.102907	 0.066629	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70703	 79202	 0.002857	 0.01535	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70704	 70709	 0.008836	 0.016436	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70704	 79202	 0.003893	 0.017343	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70705	 70706	 0.001364	 0.003607	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70705	 79201	 0.001207	 0.003193	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70706	 70710	 0.001636	 0.004107	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70707	 70708	 0.000193	 0.001329	 0.0024	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70707	 70733	 0.001214	 0.008114	 0.01529	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70708	 79201	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79202	 70708	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70709	 79203	 0.009093	 0.015993	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70710	 70713	 0.003236	 0.008557	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70710	 70728	 0.001957	 0.00585	 0.00132	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70711	 70721	 0.016671	 0.013721	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70712	 70715	 0.005329	 0.01095	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79200	 70712	 0.002743	 0.014729	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70712	 79203	 0.009221	 0.021407	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70713	 70725	 0.001736	 0.005843	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70713	 79203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70713	 79203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70714	 70715	 0.00415	 0.012729	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78887	 70714	 0.004321	 0.014757	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79203	 70715	 0.006493	 0.018629	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70716	 70717	 0.002593	 0.007629	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70716	 71078	 0.009421	 0.019357	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70716	 79309	 0.003343	 0.011414	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70717	 70718	 0.002779	 0.007029	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70718	 70720	 0.00325	 0.007436	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70719	 70720	 0.005236	 0.0084	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70719	 70721	 0.011186	 0.010986	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70720	 71076	 0.0026	 0.006036	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70721	 71268	 0.009343	 0.021686	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70721	 79207	 0.01225	 0.037586	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70722	 70723	 0.00355	 0.008243	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70722	 71076	 0.006436	 0.011964	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70723	 70732	 0.003686	 0.008564	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70724	 70732	 0.006986	 0.012993	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70724	 79204	 0.003543	 0.008971	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70725	 79204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70725	 79204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70725	 79206	 0.001993	 0.006657	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70726	 70727	 0.010793	 0.010907	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79204	 70726	 0.0124	 0.008029	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70727	 79205	 0.007314	 0.011207	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70728	 79205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70728	 79205	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70728	 79206	 0.000936	 0.003043	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70729	 70730	 0.015143	 0.011986	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78391	 70729	 0.009079	 0.010643	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70730	 70731	 0.014471	 0.01145	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70731	 70734	 0.016907	 0.025343	 0.00046	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70731	 70735	 0.019007	 0.0123	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78391	 70731	 0.035521	 0.028114	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70732	 71072	 0.02645	 0.018736	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78216	 70733	 0.002107	 0.019479	 0.03666	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70733	 79206	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79207	 70733	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70734	 70736	 0.005686	 0.013071	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70734	 70754	 0.009421	 0.015036	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70736	 70743	 0.005307	 0.010907	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70737	 70738	 0.003493	 0.009921	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70737	 70744	 0.004864	 0.012314	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70738	 70741	 0.022657	 0.01605	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70738	 70747	 0.010186	 0.020929	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70739	 70746	 0.010793	 0.006986	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70740	 70755	 0.005486	 0.021971	 0.00554	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70740	 71071	 0.000936	 0.003571	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79206	 70740	 0.0025	 0.011664	 0.00289	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70740	 79208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70740	 79208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70742	 70747	 0.02605	 0.016864	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70743	 70744	 0.005507	 0.009679	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70744	 70750	 0.002914	 0.009964	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70745	 70747	 0.003707	 0.009521	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70746	 70747	 0.006021	 0.006629	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78391	 70747	 0.003836	 0.016014	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70748	 70751	 0.003507	 0.013907	 0.0004	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70748	 70756	 0.010686	 0.021957	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70748	 70760	 0.0063	 0.024593	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70749	 70757	 0.0047	 0.01075	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70749	 70770	 0.005664	 0.009043	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70749	 79210	 0.008321	 0.044693	 0.00106	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70750	 70751	 0.003071	 0.009429	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70751	 70759	 0.009943	 0.015871	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70752	 70753	 0.024329	 0.017236	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70752	 70756	 0.018636	 0.0132	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70753	 70769	 0.0018	 0.006907	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70753	 70770	 0.014379	 0.032879	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79208	 70753	 0.00545	 0.02615	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70753	 79213	 0.013614	 0.060307	 0.00138	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79202	 70754	 0.008736	 0.02915	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70754	 79209	 0.007029	 0.037729	 0.00089	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70755	 79209	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70755	 79209	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70756	 70757	 0.004664	 0.013386	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70758	 70759	 0.013636	 0.008829	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79208	 70759	 0.01135	 0.023321	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70760	 70761	 0.003007	 0.010536	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79209	 70760	 0.008893	 0.027286	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70761	 70762	 0.016571	 0.010729	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70761	 70763	 0.004121	 0.019786	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70761	 70767	 0.017007	 0.015343	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70763	 70765	 0.003271	 0.015707	 0.00047	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70764	 70766	 0.000279	 0.002114	 0.00104	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70764	 70781	 0.00055	 0.007143	 0.00206	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70764	 79210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70764	 79210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70765	 72153	 0.008364	 0.035764	 0.00081	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79210	 70765	 0.012064	 0.028	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70766	 71478	 0.001821	 0.01565	 0.00446	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70766	 72169	 0.008264	 0.033621	 0.00819	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70767	 70768	 0.018871	 0.013364	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70767	 70770	 0.0171	 0.030857	 0.00044	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70769	 79211	 0.001807	 0.007057	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70770	 70779	 0.016021	 0.026986	 0.00039	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70770	 79212	 0.004043	 0.010236	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70771	 70779	 0.024757	 0.032543	 0.00044	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70771	 71032	 0.041064	 0.040336	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70772	 70777	 0.015929	 0.010314	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70772	 71031	 0.010521	 0.026643	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70772	 71042	 0.012264	 0.025207	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70772	 71049	 0.006707	 0.011793	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70772	 79259	 0.057021	 0.0447	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70773	 71035	 0.040657	 0.026321	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70774	 70775	 0.000586	 0.0046	 0.00118	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70774	 71046	 0.000743	 0.004686	 0.00127	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70774	 79211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70774	 79211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70775	 70778	 0.000736	 0.00525	 0.00163	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70776	 70777	 0.023357	 0.015121	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70778	 70780	 0.000386	 0.003521	 0.00115	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70778	 79212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70778	 79212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70780	 70781	 0.000357	 0.003514	 0.00096	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70781	 79213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70781	 79213	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79213	 70782	 0.03655	 0.025886	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79213	 70783	 0.092157	 0.072936	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70784	 70785	 0.001579	 0.008479	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70784	 70803	 0.002664	 0.011857	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70784	 70805	 0.007529	 0.025721	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70784	 70872	 0.005179	 0.022943	 0.00069	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70785	 70787	 0.002129	 0.013093	 0.0003	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70786	 70884	 0.024571	 0.086029	 0.00238	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70786	 70884	 0.024571	 0.086029	 0.00238	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70786	 71777	 0.023514	 0.094093	 0.00199	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70786	 71777	 0.023514	 0.094093	 0.00199	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70787	 70806	 0.003121	 0.017771	 0.00055	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70788	 70860	 0.025664	 0.016614	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70789	 70790	 0.002307	 0.010214	 0.00031	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70789	 70870	 0.002021	 0.008636	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70790	 70792	 0.008371	 0.056843	 0.00141	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70790	 70795	 0.004493	 0.017486	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70790	 70841	 0.004693	 0.011893	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70791	 70805	 0.019236	 0.013621	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70792	 70823	 0.037836	 0.034136	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70792	 70846	 0.002707	 0.01665	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70792	 70860	 0.004621	 0.022936	 0.00055	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70792	 79215	 0.011471	 0.092807	 0.00239	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70793	 71058	 0.0016	 0.03035	 0.10369	 1083.0	 1137.15	 1191.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78155	 70793	 0.000536	 0.010657	 0.03966	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70793	 79214	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79215	 70793	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70794	 70795	 0.002921	 0.008586	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70794	 70880	 0.006457	 0.016364	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70796	 70797	 0.000607	 0.004107	 0.0001	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70796	 70880	 0.001221	 0.009386	 0.00018	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70797	 70798	 0.005193	 0.012064	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70797	 70799	 0.00145	 0.008229	 0.00025	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70798	 70800	 0.002257	 0.008771	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70798	 70814	 0.004964	 0.013157	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70799	 70803	 0.00185	 0.011207	 0.00035	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70800	 70801	 0.002886	 0.011214	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70801	 70819	 0.005893	 0.024093	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70802	 70804	 0.021114	 0.014957	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70803	 70804	 0.007736	 0.0159	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70804	 70819	 0.007257	 0.014914	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70805	 79216	 0.012086	 0.053536	 0.00122	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70806	 70807	 0.011336	 0.007336	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70806	 70823	 0.006814	 0.009929	 0.00022	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70806	 70825	 0.003357	 0.022786	 0.00056	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70808	 70809	 0.015757	 0.055171	 0.00153	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70808	 70809	 0.015757	 0.055171	 0.00153	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70808	 71575	 0.028257	 0.110379	 0.00245	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70808	 71575	 0.028257	 0.110379	 0.00245	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70809	 70820	 0.009236	 0.040686	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70809	 70820	 0.009236	 0.040686	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70810	 70813	 0.02575	 0.020379	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70811	 70813	 0.008871	 0.039543	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70811	 70820	 0.006514	 0.022807	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70812	 70813	 0.02195	 0.014214	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70813	 79216	 0.005829	 0.024329	 0.0007	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70814	 70815	 0.004964	 0.012571	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70815	 70816	 0.00865	 0.016086	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70816	 70820	 0.010107	 0.039486	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70816	 70820	 0.010107	 0.039486	 0.00088	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70816	 70879	 0.019307	 0.039679	 0.00076	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70816	 70884	 0.007636	 0.026736	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70816	 70884	 0.007636	 0.026736	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70817	 70818	 0.009893	 0.006407	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70818	 70820	 0.01355	 0.013307	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70819	 70820	 0.014679	 0.027293	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79215	 70819	 0.04105	 0.18295	 0.00311	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79215	 70819	 0.04105	 0.18295	 0.00311	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70820	 70821	 0.015986	 0.011321	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70822	 70844	 0.001129	 0.011036	 0.00835	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70822	 70869	 0.00375	 0.047157	 0.01461	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70822	 70869	 0.00375	 0.047157	 0.01461	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79214	 70822	 0.001579	 0.015657	 0.00426	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70822	 79216	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70822	 79216	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70824	 70825	 0.001186	 0.011614	 0.00023	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70824	 70826	 0.001886	 0.016079	 0.00042	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79216	 70825	 0.013964	 0.031679	 0.00063	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70826	 79224	 0.007314	 0.032579	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70826	 79224	 0.007314	 0.032579	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78155	 70827	 0.000429	 0.005579	 0.01264	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70827	 79217	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79218	 70827	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70828	 70829	 0.000321	 0.003479	 0.00119	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70828	 70839	 0.000386	 0.004593	 0.00129	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79217	 70829	 0.000529	 0.006771	 0.00202	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70829	 79219	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70829	 79219	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79219	 70830	 0.009721	 0.007693	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70831	 70835	 0.004064	 0.027893	 0.00051	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70831	 79220	 0.003943	 0.022429	 0.00041	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70832	 79220	 0.004943	 0.019314	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70832	 79220	 0.004943	 0.019314	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70832	 79222	 0.003864	 0.017229	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70832	 79222	 0.003864	 0.017229	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70833	 70838	 0.000729	 0.009514	 0.00275	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70833	 70838	 0.000729	 0.009514	 0.00275	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78156	 70833	 0.002957	 0.033486	 0.01289	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78156	 70833	 0.002957	 0.033486	 0.01289	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79217	 70833	 0.002943	 0.013114	 0.00356	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70833	 79220	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70833	 79220	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79219	 70834	 0.020564	 0.014564	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79218	 70835	 0.002043	 0.011636	 0.00036	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70836	 70839	 0.000486	 0.005457	 0.00158	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70836	 70842	 0.000564	 0.005529	 0.00155	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70836	 79221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70836	 79221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70837	 79222	 0.005671	 0.022143	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70837	 79222	 0.005671	 0.022143	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70837	 79224	 0.00735	 0.028693	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70837	 79224	 0.00735	 0.028693	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70838	 70844	 0.000471	 0.006879	 0.00427	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70838	 79222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70838	 79222	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70840	 70851	 0.00345	 0.012071	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70840	 70851	 0.00345	 0.012071	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70840	 70911	 0.013357	 0.046779	 0.00129	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70840	 70911	 0.013357	 0.046779	 0.00129	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70841	 70854	 0.001629	 0.011743	 0.00022	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70841	 70936	 0.007171	 0.016643	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70842	 70843	 0.000257	 0.002429	 0.00075	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70843	 70844	 0.001457	 0.00555	 0.00156	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70843	 79223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70843	 79223	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70844	 79224	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70844	 79224	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70845	 70850	 0.02705	 0.021407	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70845	 70866	 0.0015	 0.012136	 0.00031	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79221	 70845	 0.002564	 0.018471	 0.00061	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70846	 70857	 0.005479	 0.019179	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70846	 70857	 0.005479	 0.019179	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70846	 70863	 0.010186	 0.016257	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70847	 70851	 0.00235	 0.014064	 0.00034	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70847	 70859	 0.002186	 0.013071	 0.00031	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70848	 70857	 0.004279	 0.016971	 0.00049	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70848	 70863	 0.002786	 0.011914	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70849	 70861	 0.003214	 0.009857	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70849	 70904	 0.009479	 0.066021	 0.00155	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70849	 70926	 0.004236	 0.016529	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70849	 70926	 0.004236	 0.016529	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70849	 70928	 0.005329	 0.018193	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79224	 70849	 0.026264	 0.091957	 0.00254	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79224	 70849	 0.026264	 0.091957	 0.00254	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79223	 70851	 0.009421	 0.036779	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70852	 70853	 0.024136	 0.017093	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70853	 70857	 0.004471	 0.0222	 0.00053	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70853	 70928	 0.005271	 0.023343	 0.00054	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70854	 70855	 0.013086	 0.010357	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70854	 70860	 0.002207	 0.017843	 0.00046	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70854	 70914	 0.02015	 0.013043	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70856	 70857	 0.010221	 0.007386	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70857	 70858	 0.0033	 0.011543	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70857	 70858	 0.0033	 0.011543	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79224	 70857	 0.011636	 0.040743	 0.00113	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79224	 70857	 0.011636	 0.040743	 0.00113	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70858	 70864	 0.005386	 0.018843	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70858	 70864	 0.005386	 0.018843	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70859	 70865	 0.002307	 0.013964	 0.00044	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79223	 70859	 0.008379	 0.021543	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70860	 70861	 0.009907	 0.023	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70861	 70862	 0.00115	 0.007793	 0.00019	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70862	 70863	 0.001614	 0.012586	 0.00024	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79223	 70864	 0.003957	 0.013864	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79223	 70864	 0.003957	 0.013864	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70865	 70866	 0.000979	 0.007071	 0.00018	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70867	 70878	 0.011514	 0.040321	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70867	 70878	 0.011514	 0.040321	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70867	 70883	 0.025907	 0.066607	 0.00103	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70867	 79227	 0.011957	 0.046686	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70867	 79227	 0.011957	 0.046686	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70868	 70872	 0.004336	 0.018521	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70868	 79225	 0.004657	 0.015914	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70869	 70893	 0.0011	 0.014271	 0.00412	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70869	 70893	 0.0011	 0.014271	 0.00412	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70869	 79225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70869	 79225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70870	 70913	 0.024886	 0.019693	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79225	 70870	 0.005421	 0.016621	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70871	 70872	 0.011307	 0.00895	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70873	 70874	 0.00275	 0.01365	 0.00033	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70873	 70877	 0.021164	 0.014993	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70873	 70900	 0.003871	 0.016564	 0.00037	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70874	 70886	 0.004793	 0.01865	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70874	 79227	 0.011479	 0.040186	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70874	 79227	 0.011479	 0.040186	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70875	 70876	 0.005993	 0.023407	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70875	 71033	 0.004857	 0.017007	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70876	 70882	 0.005543	 0.041914	 0.00139	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70876	 79255	 0.02565	 0.087614	 0.00191	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70878	 70881	 0.00445	 0.017379	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70878	 70881	 0.00445	 0.017379	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70879	 70881	 0.008671	 0.016129	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70880	 70881	 0.004314	 0.019236	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70880	 70881	 0.004314	 0.019236	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70882	 70883	 0.016221	 0.056807	 0.00157	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70882	 70883	 0.016221	 0.056807	 0.00157	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70883	 70884	 0.004843	 0.018907	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70883	 70884	 0.004843	 0.018907	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70885	 79226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70885	 79226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70885	 79254	 0.001664	 0.007236	 0.00206	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70886	 70889	 0.009086	 0.016893	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70886	 70901	 0.002179	 0.0091	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70887	 70889	 0.016043	 0.0127	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70888	 70889	 0.002264	 0.011443	 0.0002	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70888	 70891	 0.002393	 0.012121	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70888	 70903	 0.008464	 0.010507	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70889	 70892	 0.001736	 0.011764	 0.00029	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70890	 70892	 0.002071	 0.019314	 0.00037	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70890	 70895	 0.0049	 0.010071	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70890	 70908	 0.003507	 0.014979	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70891	 70896	 0.002243	 0.009943	 0.0003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70892	 79227	 0.007064	 0.0276	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70892	 79227	 0.007064	 0.0276	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70893	 70934	 0.00565	 0.023321	 0.00552	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70893	 79227	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70893	 79227	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70893	 79254	 0.001057	 0.014357	 0.0083	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70894	 70895	 0.003793	 0.0078	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70894	 70898	 0.005493	 0.009914	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70896	 70897	 0.007393	 0.004786	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70896	 70898	 0.006543	 0.011514	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70896	 79255	 0.002079	 0.015729	 0.00052	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70898	 70907	 0.018936	 0.012257	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70899	 70900	 0.005771	 0.019721	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70899	 71033	 0.012943	 0.024064	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70899	 71034	 0.025986	 0.016821	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79226	 70899	 0.003307	 0.013114	 0.00037	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70901	 70902	 0.002286	 0.012821	 0.00024	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70901	 70903	 0.009457	 0.0101	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79226	 70902	 0.003793	 0.016221	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70904	 79229	 0.005464	 0.029257	 0.00089	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70905	 70921	 0.004071	 0.017936	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70905	 70921	 0.004071	 0.017936	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70905	 79229	 0.020743	 0.072629	 0.00201	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70905	 79229	 0.020743	 0.072629	 0.00201	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70906	 70949	 0.001364	 0.005643	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70906	 79228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70906	 79228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70906	 79254	 0.002336	 0.010507	 0.00279	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70906	 79272	 0.0062	 0.021607	 0.00501	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70908	 70916	 0.005893	 0.017336	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70908	 70917	 0.012971	 0.0131	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70908	 79255	 0.014521	 0.038493	 0.00098	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70909	 70915	 0.00515	 0.009579	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79228	 70909	 0.015543	 0.031943	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70909	 79231	 0.011964	 0.024593	 0.00047	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70910	 70911	 0.003514	 0.013714	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70910	 70911	 0.003514	 0.013714	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70910	 70921	 0.003107	 0.012143	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70910	 70921	 0.003107	 0.012143	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70912	 70937	 0.007379	 0.032864	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70912	 70937	 0.007379	 0.032864	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79227	 70912	 0.00965	 0.0377	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79227	 70912	 0.00965	 0.0377	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70915	 70916	 0.00315	 0.006479	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70917	 70919	 0.02525	 0.017886	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70917	 70920	 0.019014	 0.012314	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70918	 70920	 0.0124	 0.009814	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70921	 70926	 0.038957	 0.048357	 0.00106	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70922	 70928	 0.01435	 0.010164	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70923	 70924	 0.0036	 0.014057	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70923	 70924	 0.0036	 0.014057	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70923	 70926	 0.00575	 0.025607	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70923	 70926	 0.00575	 0.025607	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70923	 70930	 0.005657	 0.011621	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70924	 70937	 0.003379	 0.013193	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70924	 70937	 0.003379	 0.013193	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70924	 70938	 0.020586	 0.013329	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70925	 70926	 0.014143	 0.011193	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70926	 70927	 0.014279	 0.011193	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70928	 70929	 0.012179	 0.007886	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70930	 70935	 0.004886	 0.01135	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70931	 70940	 0.017443	 0.0138	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70932	 70934	 0.001357	 0.007179	 0.00182	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70932	 79229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70932	 79229	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70933	 70934	 0.000371	 0.003679	 0.00136	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70933	 70945	 0.0004	 0.003643	 0.00119	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70933	 79230	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70933	 79230	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70935	 70936	 0.003793	 0.00705	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70939	 70940	 0.006779	 0.0126	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70939	 70944	 0.01085	 0.007029	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70939	 70946	 0.005443	 0.012507	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79230	 70940	 0.019864	 0.031864	 0.00059	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70941	 70943	 0.017757	 0.012579	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70942	 70945	 0.000479	 0.003064	 0.00103	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70942	 70948	 0.000579	 0.004257	 0.00108	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70943	 70946	 0.009043	 0.020993	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70943	 79232	 0.007043	 0.014414	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70945	 79231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70945	 79231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79231	 70946	 0.012207	 0.023921	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70947	 70951	 0.004214	 0.00575	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70947	 79233	 0.0078	 0.010636	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70948	 70954	 0.000536	 0.0042	 0.00123	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70948	 79232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70948	 79232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70949	 70950	 0.000736	 0.002893	 0.00076	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70950	 70974	 0.000679	 0.002579	 0.00072	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70950	 79233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70950	 79233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70951	 70952	 0.012064	 0.008543	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70951	 70953	 0.005293	 0.008486	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70952	 79240	 0.011571	 0.007493	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70953	 79234	 0.005129	 0.008186	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70954	 70961	 0.000314	 0.002421	 0.00063	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70954	 79234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70954	 79234	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70955	 70956	 0.016857	 0.011943	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79234	 70955	 0.005079	 0.0063	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70957	 70959	 0.022886	 0.016214	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70958	 71173	 0.000636	 0.0038	 0.001	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70958	 79235	 0.000464	 0.00265	 0.00076	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70959	 79236	 0.0036	 0.007371	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70960	 79235	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79236	 70960	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79235	 70961	 0.0003	 0.002236	 0.00064	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70962	 70969	 0.000493	 0.002043	 0.00049	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79235	 70962	 0.000921	 0.0038	 0.0009	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70962	 79237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70962	 79237	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79234	 70963	 0.003421	 0.009071	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79237	 70963	 0.002179	 0.008471	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70964	 70967	 0.004621	 0.006736	 0.00015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70964	 70970	 0.008421	 0.014186	 0.0002	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70965	 70968	 0.006329	 0.013014	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70965	 79238	 0.010521	 0.014343	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70965	 79276	 0.007171	 0.016657	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70966	 70967	 0.014557	 0.011521	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70967	 71154	 0.00625	 0.011621	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79237	 70968	 0.008629	 0.017729	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70969	 70973	 0.00085	 0.003093	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70969	 79238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70969	 79238	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70970	 70971	 0.006971	 0.011129	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70970	 79239	 0.009621	 0.016929	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70970	 79243	 0.031571	 0.028286	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70971	 70972	 0.006586	 0.011586	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70971	 70976	 0.005121	 0.012979	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79233	 70972	 0.007079	 0.014543	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70973	 70974	 0.000571	 0.002014	 0.00066	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70973	 79239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70973	 79239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70974	 79240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70974	 79240	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70975	 70984	 0.012536	 0.011307	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70975	 79243	 0.012636	 0.017614	 0.0003	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70976	 70980	 0.011386	 0.015514	 0.00034	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79228	 70976	 0.012479	 0.028971	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70977	 70989	 0.000771	 0.004021	 0.00106	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70977	 79241	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70977	 79241	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70977	 79242	 0.003679	 0.012264	 0.00311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70977	 79254	 0.00065	 0.006464	 0.00176	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70978	 70979	 0.003421	 0.010064	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79241	 70978	 0.002457	 0.009407	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70979	 70980	 0.017457	 0.012364	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70979	 70982	 0.014736	 0.014479	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70979	 70988	 0.006929	 0.0086	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70980	 70984	 0.0053	 0.010893	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79241	 70980	 0.00545	 0.018621	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70981	 70982	 0.003121	 0.007914	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70981	 70986	 0.007993	 0.007164	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70981	 79247	 0.017093	 0.013529	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70982	 79245	 0.003993	 0.010271	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70983	 71163	 0.000293	 0.001993	 0.00367	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70983	 79242	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79243	 70983	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79242	 70985	 0.001321	 0.004129	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70985	 79244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70985	 79244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79244	 70986	 0.005029	 0.011664	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70986	 79247	 0.016414	 0.012993	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70987	 70988	 0.005657	 0.008479	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79243	 70987	 0.008143	 0.013064	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70989	 70991	 0.001714	 0.0056	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70989	 79245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70989	 79245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70989	 79267	 0.014486	 0.040407	 0.00849	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70990	 70997	 0.002493	 0.008514	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79241	 70990	 0.004929	 0.010079	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79245	 70990	 0.004257	 0.007907	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70991	 71009	 0.0019	 0.0076	 0.00191	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70991	 71019	 0.001557	 0.007129	 0.00183	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70991	 79246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70991	 79246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70991	 79254	 0.000786	 0.007786	 0.00211	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70992	 79251	 0.010507	 0.010614	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70993	 70994	 0.002043	 0.0098	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70993	 79252	 0.002171	 0.008443	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70994	 70995	 0.004371	 0.004671	 0.0001	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70994	 71028	 0.005386	 0.010007	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79246	 70994	 0.0036	 0.009536	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70995	 71028	 0.004086	 0.00595	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	70996	 70999	 0.010093	 0.006536	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79246	 70997	 0.003057	 0.0119	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70998	 70999	 0.006021	 0.007914	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70998	 71008	 0.012407	 0.008036	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79245	 70999	 0.0069	 0.015657	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71000	 71003	 0.001164	 0.004143	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71000	 71004	 0.001036	 0.003607	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71000	 71005	 0.000957	 0.002529	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71000	 79247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71000	 79247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71000	 79254	 0.0031	 0.015314	 0.00447	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71001	 71008	 0.002936	 0.007471	 0.00012	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79245	 71001	 0.006136	 0.013914	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71002	 71003	 0.000721	 0.002571	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71002	 71007	 0.000857	 0.002407	 0.00062	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71003	 71005	 0.000843	 0.002114	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71003	 79248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71003	 79248	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71004	 71005	 0.000586	 0.00135	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71004	 71149	 0.002743	 0.007386	 0.00207	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71004	 71182	 0.000707	 0.002214	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71004	 79249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71004	 79249	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71005	 71182	 0.001343	 0.003371	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79247	 71006	 0.010507	 0.007443	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71007	 71009	 0.000986	 0.002914	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71007	 79250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71007	 79250	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79250	 71008	 0.0038	 0.006071	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71009	 71019	 0.002236	 0.006264	 0.00161	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71009	 79251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71009	 79251	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71010	 71011	 0.004057	 0.004757	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71010	 71017	 0.003729	 0.008521	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79251	 71010	 0.001443	 0.009886	 0.00018	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71011	 71018	 0.012479	 0.010271	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71012	 71014	 0.005329	 0.01055	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71012	 71016	 0.005429	 0.012307	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79251	 71012	 0.0034	 0.011607	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71013	 71014	 0.004329	 0.010043	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71013	 71144	 0.003829	 0.010986	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79248	 71013	 0.003007	 0.007971	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71015	 71016	 0.005143	 0.013036	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71015	 71054	 0.006443	 0.0138	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71017	 71018	 0.017729	 0.011479	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71017	 71052	 0.007007	 0.018007	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71018	 79259	 0.048521	 0.039936	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71019	 71020	 0.001086	 0.004264	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71019	 79252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71019	 79252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71020	 71051	 0.000921	 0.003607	 0.00094	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71020	 79253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71020	 79253	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79252	 71021	 0.005143	 0.009557	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79253	 71021	 0.00665	 0.0071	 0.00015	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71022	 71023	 0.004036	 0.00915	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71022	 71036	 0.016357	 0.011586	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71022	 71037	 0.012136	 0.019371	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71023	 71025	 0.0043	 0.011393	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79246	 71023	 0.012307	 0.0253	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79252	 71023	 0.006971	 0.017657	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71024	 71025	 0.003657	 0.007507	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71024	 71030	 0.004257	 0.00895	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71025	 71027	 0.004	 0.008221	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79226	 71025	 0.00475	 0.014564	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71026	 71027	 0.003586	 0.006664	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71026	 71028	 0.003807	 0.007079	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71027	 71028	 0.007364	 0.015136	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79226	 71027	 0.002029	 0.008043	 0.00023	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71029	 71217	 0.000236	 0.002779	 0.20831	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71029	 79254	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71029	 79254	 0.000144	 0.011532	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71030	 71033	 0.007014	 0.013043	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71031	 71033	 0.008571	 0.022707	 0.00058	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71032	 71033	 0.02195	 0.027243	 0.00059	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71035	 71041	 0.014871	 0.013414	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79252	 71035	 0.010964	 0.0175	 0.0004	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71037	 71041	 0.008793	 0.015464	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71038	 71048	 0.01615	 0.011436	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71038	 79259	 0.025329	 0.020043	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71039	 71052	 0.024136	 0.025779	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79253	 71039	 0.0076	 0.015621	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71040	 71041	 0.003629	 0.008429	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71040	 71049	 0.004043	 0.007521	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71042	 71047	 0.006607	 0.011921	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71042	 79256	 0.025479	 0.01805	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71043	 71045	 0.022779	 0.018029	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71044	 71045	 0.009593	 0.01125	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71044	 79260	 0.013886	 0.013643	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71045	 71048	 0.014064	 0.014207	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71045	 79259	 0.02735	 0.017707	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71046	 71061	 0.000821	 0.005	 0.00126	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71046	 79256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71046	 79256	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79211	 71047	 0.006864	 0.014107	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79256	 71047	 0.025821	 0.016714	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71048	 71049	 0.006071	 0.008286	 0.00015	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71050	 71051	 0.000771	 0.0031	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71050	 71059	 0.001	 0.003629	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71052	 71053	 0.006936	 0.015736	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71052	 79259	 0.035971	 0.036336	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71053	 71054	 0.0046	 0.016107	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71053	 79258	 0.004129	 0.018279	 0.00055	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71054	 71055	 0.002843	 0.007529	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71055	 71098	 0.008586	 0.017007	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71055	 71126	 0.002236	 0.007836	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71055	 71128	 0.007357	 0.014571	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71055	 71147	 0.004307	 0.011421	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71056	 71057	 0.005857	 0.012029	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71056	 79262	 0.004136	 0.008507	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71057	 79260	 0.008657	 0.016093	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78193	 71058	 0.0019	 0.020536	 0.04077	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71058	 79257	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79258	 71058	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71059	 71061	 0.001279	 0.00485	 0.00136	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71059	 79259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71059	 79259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79259	 71060	 0.011636	 0.007536	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79257	 71061	 0.001257	 0.005107	 0.00124	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71061	 79260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71061	 79260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71062	 71065	 0.003507	 0.0137	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71062	 79263	 0.004336	 0.0115	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71062	 79264	 0.021636	 0.017121	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71063	 71095	 0.00125	 0.005	 0.00169	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79257	 71063	 0.00105	 0.00645	 0.00186	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71063	 79261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71063	 79261	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71064	 71065	 0.010271	 0.00665	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71065	 71066	 0.001414	 0.006914	 0.00012	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79258	 71066	 0.003429	 0.013614	 0.00039	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71067	 71070	 0.003843	 0.007893	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78391	 71067	 0.007464	 0.019186	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78391	 71068	 0.0059	 0.012114	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79207	 71068	 0.005	 0.010229	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71069	 71073	 0.018736	 0.013271	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71070	 79262	 0.007486	 0.013921	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79257	 71071	 0.002193	 0.009121	 0.00213	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71071	 79262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71071	 79262	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71072	 71073	 0.003664	 0.006807	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71072	 71074	 0.007607	 0.013379	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79207	 71073	 0.004743	 0.012564	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71074	 71075	 0.002279	 0.007593	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71075	 71091	 0.002014	 0.009829	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71076	 71087	 0.00225	 0.012043	 0.00036	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71077	 71087	 0.011207	 0.008871	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71078	 71079	 0.007336	 0.012357	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71078	 71264	 0.0031	 0.0123	 0.00035	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71080	 71264	 0.02085	 0.014764	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71081	 71082	 0.00205	 0.007007	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71081	 71257	 0.00365	 0.007493	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71081	 79306	 0.005836	 0.015007	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71082	 71083	 0.002057	 0.007993	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71083	 71084	 0.003657	 0.008407	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71083	 71106	 0.005529	 0.01845	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71084	 71085	 0.003564	 0.006621	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71085	 71086	 0.016493	 0.011686	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71085	 71102	 0.005679	 0.011671	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71087	 71089	 0.011579	 0.018571	 0.00034	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78310	 71087	 0.006071	 0.036379	 0.00087	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71088	 71089	 0.002371	 0.011071	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71088	 71102	 0.001693	 0.008107	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71089	 71090	 0.013436	 0.009514	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71089	 71091	 0.0049	 0.009114	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71091	 79263	 0.004107	 0.014021	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71092	 71093	 0.0006	 0.002393	 0.0006	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79206	 71092	 0.001793	 0.007293	 0.00178	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71092	 79263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71092	 79263	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71093	 71095	 0.000379	 0.001571	 0.00036	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71094	 79264	 0.017843	 0.01155	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71095	 71096	 0.000421	 0.001293	 0.00028	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71095	 79264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71095	 79264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71096	 71271	 0.001314	 0.003986	 0.00087	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71096	 79265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71096	 79265	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71097	 71271	 0.000843	 0.002643	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71097	 79266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71097	 79266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79261	 71098	 0.019529	 0.0175	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71099	 71101	 0.016107	 0.011414	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71100	 71101	 0.015914	 0.011271	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71101	 71102	 0.011629	 0.027	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71101	 71122	 0.002164	 0.008571	 0.00024	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79266	 71101	 0.014086	 0.019629	 0.00034	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78310	 71102	 0.006007	 0.02345	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71103	 71104	 0.011721	 0.007586	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71103	 71109	 0.008707	 0.008714	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71103	 71119	 0.01815	 0.018329	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71105	 71106	 0.002064	 0.007043	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71105	 79268	 0.005236	 0.018343	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71106	 71107	 0.003657	 0.008486	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78310	 71107	 0.002793	 0.006479	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78310	 71108	 0.006329	 0.0041	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78310	 71109	 0.005071	 0.009421	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71110	 71111	 0.011771	 0.009314	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71111	 71112	 0.004186	 0.012007	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71111	 71115	 0.011743	 0.007607	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71111	 79268	 0.003271	 0.010043	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71112	 71113	 0.003093	 0.007014	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71113	 71120	 0.0059	 0.013379	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71114	 71234	 0.000379	 0.002786	 0.00552	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71114	 79267	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79268	 71114	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71116	 71118	 0.004414	 0.007764	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71116	 71121	 0.013421	 0.014329	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71117	 71118	 0.021307	 0.016864	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79268	 71117	 0.02555	 0.0181	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71118	 71133	 0.002929	 0.005993	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71119	 71120	 0.005964	 0.007843	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71120	 71122	 0.004364	 0.007679	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71121	 71131	 0.011757	 0.009307	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71122	 71123	 0.005307	 0.009864	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71123	 71124	 0.0092	 0.010786	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71123	 71129	 0.003029	 0.012	 0.00034	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71124	 71125	 0.006886	 0.008071	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71125	 71126	 0.009057	 0.007457	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79266	 71126	 0.002914	 0.012464	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71127	 71129	 0.014007	 0.014957	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71127	 71141	 0.006771	 0.011914	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71127	 71146	 0.006579	 0.011871	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71128	 71146	 0.002693	 0.006821	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71129	 71130	 0.012257	 0.008686	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71129	 71136	 0.004757	 0.009729	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71129	 79292	 0.011179	 0.038186	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71131	 71132	 0.011807	 0.008364	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71132	 71135	 0.01285	 0.011593	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71133	 71135	 0.009921	 0.017443	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71133	 79292	 0.002736	 0.011693	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71134	 71225	 0.01595	 0.010321	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71134	 79292	 0.0138	 0.009779	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71135	 71136	 0.021743	 0.014079	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71135	 71137	 0.026107	 0.020664	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71136	 71137	 0.004921	 0.011436	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71137	 71138	 0.003893	 0.011171	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71137	 71142	 0.019236	 0.017236	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71138	 71139	 0.009164	 0.012507	 0.00022	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71138	 71150	 0.005786	 0.01075	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71139	 71225	 0.006886	 0.010993	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71140	 71142	 0.011621	 0.007521	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71141	 71142	 0.005114	 0.013136	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71142	 71143	 0.005829	 0.01715	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71142	 71145	 0.005057	 0.010014	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79268	 71142	 0.122771	 0.086971	 0.00137	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71142	 79277	 0.004307	 0.010907	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71143	 71144	 0.002564	 0.0065	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71143	 71146	 0.005579	 0.01105	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71143	 71147	 0.002707	 0.0083	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71145	 79278	 0.003586	 0.009086	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71148	 71162	 0.013321	 0.012014	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79244	 71148	 0.017443	 0.022929	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71148	 79269	 0.013164	 0.015436	 0.00027	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71148	 79277	 0.0036	 0.0067	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71149	 71180	 0.0009	 0.002171	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71149	 71223	 0.004936	 0.013279	 0.00372	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71149	 79269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71149	 79269	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79269	 71150	 0.004357	 0.008629	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71150	 79271	 0.004386	 0.007714	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71151	 71167	 0.0008	 0.002193	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71151	 71192	 0.001207	 0.003186	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71152	 71153	 0.000514	 0.002036	 0.00053	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71152	 71166	 0.000786	 0.003071	 0.00082	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71153	 79270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71153	 79270	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71153	 79275	 0.000814	 0.00295	 0.0009	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79270	 71154	 0.006393	 0.013136	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71155	 79276	 0.010086	 0.007143	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71156	 71187	 0.000157	 0.00135	 0.00246	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71157	 71221	 0.018686	 0.016857	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71157	 79271	 0.009043	 0.009043	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71158	 71180	 0.0022	 0.006486	 0.00151	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71158	 71222	 0.001864	 0.006743	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71158	 79271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71158	 79271	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71159	 71174	 0.01775	 0.013914	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71159	 79279	 0.025964	 0.018393	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71160	 71161	 0.013621	 0.015964	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79271	 71160	 0.025929	 0.016786	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71160	 79279	 0.010786	 0.019457	 0.00028	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71161	 71162	 0.009614	 0.008614	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79244	 71162	 0.006436	 0.011321	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71163	 71185	 0.000821	 0.005386	 0.01057	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71163	 79272	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71163	 79272	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71164	 71165	 0.031943	 0.020679	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71165	 71169	 0.008529	 0.009107	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71165	 71179	 0.018236	 0.01645	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71165	 79273	 0.007871	 0.010736	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71166	 71183	 0.001636	 0.003936	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79272	 71166	 0.00245	 0.006671	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71166	 79273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71166	 79273	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71167	 71168	 0.0008	 0.002014	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71168	 71183	 0.000807	 0.002193	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71168	 71184	 0.001614	 0.004057	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71168	 71198	 0.003443	 0.0083	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71168	 79274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71168	 79274	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71169	 71201	 0.022143	 0.015686	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71170	 71176	 0.023307	 0.015086	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71170	 71177	 0.011693	 0.008279	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71170	 79276	 0.011693	 0.008279	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71171	 79275	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79276	 71171	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71172	 71173	 0.0005	 0.001914	 0.00054	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78178	 71172	 0.000771	 0.003086	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78178	 71173	 0.001243	 0.005121	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71174	 79291	 0.013607	 0.008807	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79274	 71175	 0.01915	 0.015764	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71175	 79291	 0.024279	 0.017193	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71176	 71177	 0.011614	 0.007521	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71176	 79282	 0.009257	 0.009093	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79276	 71177	 0.023386	 0.015136	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71178	 71179	 0.002879	 0.006586	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71178	 79281	 0.002979	 0.00855	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79270	 71179	 0.008321	 0.012471	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71180	 71181	 0.000607	 0.002157	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71181	 71182	 0.000593	 0.001929	 0.00051	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71181	 79277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71181	 79277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71182	 79278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71182	 79278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71183	 71184	 0.000807	 0.00195	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71183	 79279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71183	 79279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79272	 71184	 0.001257	 0.003421	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71185	 71186	 0.000171	 0.001357	 0.00261	 397.0	 416.85	 436.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71185	 71215	 0.001107	 0.007743	 0.01318	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71185	 79280	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79281	 71185	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71186	 71187	 0.000129	 0.001121	 0.00209	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71186	 79282	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71186	 79282	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71188	 71189	 0.020843	 0.016493	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79281	 71189	 0.0058	 0.009307	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71190	 71202	 0.027136	 0.033686	 0.00074	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71190	 79283	 0.006814	 0.011486	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78178	 71191	 0.001214	 0.007386	 0.00186	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79280	 71191	 0.001107	 0.00545	 0.00147	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71191	 79283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71191	 79283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71192	 71199	 0.001207	 0.003307	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79280	 71192	 0.002064	 0.00785	 0.0022	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71192	 79284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71192	 79284	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71192	 79288	 0.003971	 0.013621	 0.00326	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71193	 71194	 0.01955	 0.012657	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71193	 71200	 0.011586	 0.009171	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71194	 71195	 0.0118	 0.009336	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71194	 71197	 0.029921	 0.023679	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71196	 71197	 0.011793	 0.008357	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71197	 71202	 0.0251	 0.026807	 0.00056	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71197	 71203	 0.004086	 0.0076	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71197	 79289	 0.005429	 0.021193	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71198	 71199	 0.000807	 0.002171	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71198	 71219	 0.001429	 0.003836	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71198	 71222	 0.000914	 0.003486	 0.00098	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79284	 71200	 0.013764	 0.012421	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79284	 71201	 0.00925	 0.014764	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71203	 71204	 0.014786	 0.011593	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71203	 71208	 0.01055	 0.00835	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71203	 71214	 0.005907	 0.013714	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71205	 71214	 0.020636	 0.030943	 0.00056	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78218	 71205	 0.017879	 0.036743	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71206	 71212	 0.017164	 0.012157	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78194	 71206	 0.007057	 0.014493	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71207	 71213	 0.007771	 0.005507	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71209	 71210	 0.001479	 0.005764	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71209	 71237	 0.002514	 0.0088	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78194	 71210	 0.002093	 0.008957	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71211	 71212	 0.005536	 0.003921	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71213	 71214	 0.014043	 0.009943	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71215	 79285	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79286	 71215	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71215	 79287	 0.000357	 0.002393	 0.00451	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71216	 71226	 0.004129	 0.01605	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79286	 71216	 0.0111	 0.013014	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71216	 79289	 0.003686	 0.012579	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71217	 71246	 8.6e-05	 0.001264	 0.08111	 1893.0	 1987.65	 2082.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71217	 79287	 0.000101	 0.00811	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79289	 71218	 0.005921	 0.013429	 0.00027	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71218	 79290	 0.003907	 0.008936	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71219	 71223	 0.003671	 0.009536	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79030	 71219	 0.00655	 0.026229	 0.00661	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79285	 71219	 0.001371	 0.004164	 0.00091	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71219	 79290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71219	 79290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71220	 71221	 0.004893	 0.008829	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71220	 71225	 0.004964	 0.008729	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71220	 79293	 0.01315	 0.014464	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71221	 79291	 0.00365	 0.007507	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79242	 71222	 0.007243	 0.018207	 0.00471	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79285	 71222	 0.002621	 0.006743	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71222	 79291	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71222	 79291	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71223	 71224	 0.00075	 0.002564	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71223	 79292	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71223	 79292	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79285	 71224	 0.0009	 0.003543	 0.00093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71224	 79293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71224	 79293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71225	 71228	 0.02635	 0.021686	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71226	 71227	 0.003714	 0.006907	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71226	 71230	 0.009264	 0.012629	 0.00028	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71227	 71228	 0.002064	 0.007043	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71227	 71233	 0.009286	 0.013536	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79268	 71228	 0.011193	 0.025993	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79293	 71228	 0.005207	 0.011814	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71229	 71230	 0.011957	 0.007743	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71230	 79295	 0.018014	 0.017693	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71231	 79295	 0.01495	 0.010593	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71232	 71233	 0.012179	 0.007879	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71233	 79295	 0.006243	 0.011607	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78193	 71234	 0.000607	 0.005764	 0.01034	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79287	 71234	 0.000321	 0.003514	 0.00751	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71234	 79294	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79295	 71234	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71235	 71236	 0.005621	 0.012857	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71235	 79302	 0.004243	 0.012471	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71236	 71237	 0.004007	 0.008229	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78218	 71237	 0.0083	 0.018979	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71238	 71239	 0.011779	 0.008343	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79295	 71238	 0.017121	 0.020064	 0.00035	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78194	 71240	 0.018343	 0.034107	 0.0008	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71240	 79297	 0.007729	 0.015879	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71241	 71242	 0.001064	 0.003771	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71241	 79296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71241	 79296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71241	 79301	 0.000614	 0.002893	 0.00069	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71242	 79297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71242	 79297	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71243	 71253	 0.000321	 0.002021	 0.00055	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71243	 79298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71243	 79298	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71243	 79304	 0.000393	 0.00285	 0.00074	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71244	 71248	 0.000779	 0.002964	 0.00083	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71244	 79299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71244	 79299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71244	 79304	 0.000893	 0.003479	 0.00093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71245	 71255	 0.002129	 0.008307	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79296	 71245	 0.003071	 0.011757	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71246	 72313	 0.0004	 0.009671	 0.83736	 3339.0	 3505.95	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71246	 79300	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71246	 79300	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71247	 71250	 0.007093	 0.018236	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71247	 71257	 0.005079	 0.010386	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71247	 71258	 0.016593	 0.013129	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71247	 79303	 0.004993	 0.010257	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71248	 71261	 0.001214	 0.00505	 0.00157	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71248	 79303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71248	 79303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79300	 71249	 0.000121	 0.002086	 0.00824	 1083.0	 1137.15	 1191.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71249	 79304	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79305	 71249	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71250	 71251	 0.01135	 0.00735	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79295	 71250	 0.004836	 0.027479	 0.0005	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71250	 79306	 0.015186	 0.039043	 0.00061	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71252	 71253	 0.000386	 0.00275	 0.00076	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78989	 71253	 0.000943	 0.003893	 0.00092	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71254	 71255	 0.004243	 0.007886	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78997	 71254	 0.008857	 0.009743	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79296	 71254	 0.009314	 0.026721	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79299	 71255	 0.001236	 0.007043	 0.00021	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71256	 71261	 0.000579	 0.002307	 0.00058	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71256	 79306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71256	 79306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79298	 71259	 0.029579	 0.023407	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71260	 71261	 0.0007	 0.0029	 0.00068	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71260	 71265	 0.000871	 0.003329	 0.00093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71261	 79307	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71261	 79307	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79298	 71262	 0.005986	 0.01225	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79303	 71262	 0.009836	 0.012207	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79306	 71262	 0.00655	 0.012171	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71263	 71264	 0.020093	 0.013007	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78310	 71264	 0.009807	 0.038164	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79307	 71264	 0.005357	 0.013879	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71265	 71270	 0.001721	 0.005743	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79294	 71265	 0.006143	 0.0246	 0.0062	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71265	 79308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71265	 79308	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71266	 71270	 0.001236	 0.002971	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71266	 79309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71266	 79309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71267	 71268	 0.004586	 0.013157	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71267	 79310	 0.002586	 0.010107	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71269	 79310	 0.013157	 0.008514	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71270	 79310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71270	 79310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71272	 71273	 0.067964	 0.044	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71272	 71339	 0.061264	 0.0434	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71274	 71275	 0.015971	 0.025621	 0.00047	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71274	 71335	 0.068757	 0.073436	 0.00155	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71275	 71339	 0.072707	 0.135207	 0.00316	 69.0	 69.0	 69.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78299	 71276	 0.007	 0.056643	 0.00146	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71277	 71278	 0.001307	 0.003679	 0.00094	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71277	 71334	 0.011364	 0.049457	 0.01409	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71277	 79311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71277	 79311	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71278	 71331	 0.006293	 0.016629	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71278	 79312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71278	 79312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79312	 71279	 0.0223	 0.015793	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71280	 71320	 0.005029	 0.036393	 0.00091	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71280	 71326	 0.004129	 0.029686	 0.00097	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79312	 71281	 0.060514	 0.039179	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71282	 71283	 0.006857	 0.033086	 0.00059	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71282	 71284	 0.018914	 0.050136	 0.00127	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79312	 71282	 0.039214	 0.172821	 0.003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79312	 71282	 0.039214	 0.172821	 0.003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71283	 71319	 0.008579	 0.033507	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71284	 71285	 0.009657	 0.019757	 0.00049	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71285	 71286	 0.023864	 0.01545	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78271	 71285	 0.017386	 0.039436	 0.00079	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71287	 71288	 0.006264	 0.01165	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71287	 71292	 0.008	 0.012764	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71288	 71293	 0.007064	 0.013129	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71289	 71290	 0.013393	 0.009486	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71290	 71291	 0.004071	 0.008336	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71290	 71292	 0.011329	 0.015443	 0.00034	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71290	 71295	 0.003186	 0.01115	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71291	 72020	 0.005136	 0.011643	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71292	 72002	 0.009021	 0.012307	 0.00022	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71293	 71316	 0.012	 0.027214	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71293	 71341	 0.022071	 0.015957	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78271	 71293	 0.015186	 0.075357	 0.0018	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71294	 71296	 0.002064	 0.008814	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71294	 71997	 0.004636	 0.018021	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71295	 79313	 0.003564	 0.015786	 0.00047	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71296	 71297	 0.009121	 0.01875	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71296	 79313	 0.006343	 0.032079	 0.00056	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71297	 71302	 0.009371	 0.017429	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71297	 71976	 0.011657	 0.039814	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78337	 71297	 0.014807	 0.061821	 0.00179	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71298	 72025	 0.011521	 0.031579	 0.00686	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71298	 79313	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71298	 79313	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71298	 79316	 0.005607	 0.033657	 0.01019	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71299	 71305	 0.008057	 0.014979	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71299	 71343	 0.013386	 0.012071	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71300	 71304	 0.001121	 0.004264	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71300	 71342	 0.0018	 0.006843	 0.00191	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71300	 79314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71300	 79314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71301	 71302	 0.003893	 0.009857	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71301	 71305	 0.007779	 0.015993	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71301	 71308	 0.018221	 0.012907	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71303	 71304	 0.000593	 0.002814	 0.00068	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71303	 71342	 0.002829	 0.012307	 0.00351	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71303	 79316	 0.002486	 0.01995	 0.00561	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71304	 79315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71304	 79315	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71305	 71306	 0.004957	 0.012557	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78337	 71306	 0.007443	 0.034714	 0.0008	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79314	 71306	 0.01495	 0.026286	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79315	 71306	 0.008093	 0.01445	 0.00021	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71307	 71308	 0.017814	 0.011536	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79313	 71308	 0.010286	 0.026436	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71309	 71311	 0.009393	 0.018593	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71309	 71312	 0.017986	 0.016114	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71309	 71319	 0.006421	 0.030821	 0.00092	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79313	 71309	 0.032479	 0.058607	 0.00085	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71310	 71311	 0.008079	 0.016536	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71310	 71345	 0.009321	 0.019071	 0.00047	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71311	 71316	 0.00675	 0.01255	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71313	 71314	 0.0032	 0.012507	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71313	 71322	 0.007179	 0.025136	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71314	 71319	 0.005693	 0.017457	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71314	 71320	 0.005443	 0.035136	 0.00112	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71315	 71316	 0.011614	 0.010407	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71315	 71344	 0.010186	 0.012643	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71317	 71318	 0.002307	 0.007893	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71317	 71322	 0.004829	 0.016907	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71317	 71345	 0.009529	 0.011829	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71318	 71344	 0.006421	 0.018886	 0.00039	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71321	 71350	 0.011036	 0.066121	 0.00159	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71321	 74898	 0.053707	 0.154071	 0.00237	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71323	 72048	 0.002207	 0.029364	 0.06278	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71323	 74850	 0.002114	 0.029064	 0.05796	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71323	 79316	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79317	 71323	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71324	 71325	 0.023664	 0.018729	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71324	 71350	 0.021336	 0.043657	 0.00107	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71324	 71353	 0.014836	 0.026093	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71325	 71349	 0.023007	 0.023236	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71326	 79318	 0.018443	 0.064579	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71326	 79318	 0.018443	 0.064579	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71327	 71332	 0.047657	 0.088621	 0.00207	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79311	 71327	 0.017679	 0.02195	 0.00048	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79312	 71327	 0.013571	 0.034379	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71327	 79319	 0.033214	 0.138664	 0.004	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71328	 79318	 0.064507	 0.046636	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71329	 71330	 0.0702	 0.082293	 0.00143	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71330	 71333	 0.015579	 0.045814	 0.00094	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71330	 79318	 0.017621	 0.032764	 0.00076	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71331	 79318	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71331	 79318	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71332	 71333	 0.01845	 0.02945	 0.00068	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71332	 79319	 0.013321	 0.066086	 0.00158	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71334	 79319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71334	 79319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71338	 71339	 0.097471	 0.063107	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71339	 71340	 0.161993	 0.114771	 0.00181	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71342	 72063	 0.009907	 0.0446	 0.01187	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71342	 79320	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71342	 79320	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71343	 71344	 0.013479	 0.013243	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79313	 71344	 0.012329	 0.022929	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71345	 71346	 0.005336	 0.0157	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71348	 71349	 0.013543	 0.023814	 0.00045	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71348	 71351	 0.039543	 0.031293	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79317	 71348	 0.024979	 0.063279	 0.00125	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71349	 71355	 0.006757	 0.015336	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71350	 71355	 0.011107	 0.025186	 0.0005	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79317	 71350	 0.039964	 0.074314	 0.00174	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71351	 71352	 0.039114	 0.027707	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71352	 71354	 0.033593	 0.0238	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71353	 71354	 0.034486	 0.022321	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71356	 79321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71356	 79321	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71357	 74245	 0.075371	 0.264071	 0.00731	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71357	 74245	 0.075371	 0.264071	 0.00731	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79321	 71357	 0.089871	 0.351307	 0.0078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79321	 71357	 0.089871	 0.351307	 0.0078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79321	 71358	 0.176929	 0.114571	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78605	 71359	 0.427379	 0.277129	 0.00527	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78340	 71360	 0.078164	 0.260836	 0.00414	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78387	 71360	 0.073186	 0.209957	 0.00323	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79321	 71360	 0.027429	 0.147343	 0.0035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71361	 74242	 0.151464	 0.607779	 0.01288	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71361	 74242	 0.151464	 0.607779	 0.01288	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71361	 74570	 0.039636	 0.300029	 0.00999	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78340	 71361	 0.076307	 0.298229	 0.00662	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78340	 71361	 0.076307	 0.298229	 0.00662	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78603	 71361	 0.10515	 0.309436	 0.00635	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78284	 71362	 0.078714	 0.182779	 0.00272	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78340	 71362	 0.031279	 0.058157	 0.00136	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71363	 79322	 0.007429	 0.013807	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71363	 79330	 0.00495	 0.0092	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71364	 71365	 0.000593	 0.003429	 0.00097	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71364	 71370	 0.000493	 0.002893	 0.00079	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71365	 71399	 0.00205	 0.012293	 0.00372	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71365	 79322	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71365	 79322	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71366	 71367	 0.012086	 0.014171	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71366	 71397	 0.015893	 0.016971	 0.00036	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71367	 71368	 0.009007	 0.012293	 0.00022	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71367	 79323	 0.008993	 0.016721	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71368	 71369	 0.005	 0.011336	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71368	 79323	 0.00495	 0.015179	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71369	 71374	 0.004721	 0.013879	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71369	 71767	 0.007736	 0.017686	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71370	 71493	 0.000479	 0.003693	 0.00129	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71370	 79323	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71370	 79323	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79323	 71371	 0.010379	 0.00735	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71372	 71373	 0.006986	 0.018521	 0.00047	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71372	 71482	 0.008871	 0.0261	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71373	 71374	 0.006343	 0.02115	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71373	 71381	 0.002843	 0.009714	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71375	 71380	 0.020629	 0.016321	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71376	 71380	 0.005664	 0.022043	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71376	 71395	 0.004214	 0.016471	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71377	 71379	 0.002307	 0.013964	 0.00044	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71377	 71386	 0.00375	 0.016043	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71378	 71379	 0.003943	 0.013814	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71378	 71379	 0.003943	 0.013814	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71378	 71380	 0.00545	 0.021286	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71378	 71380	 0.00545	 0.021286	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71379	 71384	 0.002579	 0.009036	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71380	 71381	 0.0047	 0.013814	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79323	 71380	 0.007857	 0.038986	 0.00093	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71382	 71383	 0.002671	 0.007093	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71382	 71385	 0.007393	 0.02175	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71382	 71391	 0.007464	 0.031907	 0.00072	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71382	 71392	 0.013857	 0.017207	 0.00037	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79323	 71382	 0.007607	 0.070793	 0.00137	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71383	 71384	 0.002979	 0.010171	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71385	 71388	 0.005543	 0.014036	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71386	 71444	 0.003371	 0.014857	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71387	 71390	 0.0316	 0.025007	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71387	 71391	 0.0053	 0.00985	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71387	 71442	 0.00705	 0.014486	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71388	 71444	 0.005257	 0.010807	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71389	 71392	 0.032164	 0.020821	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71390	 71391	 0.010607	 0.013164	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71390	 79327	 0.056971	 0.055971	 0.00094	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71393	 71399	 0.000593	 0.007221	 0.00239	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71394	 71401	 0.008743	 0.016257	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71394	 72273	 0.008536	 0.019364	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71395	 71396	 0.021143	 0.013686	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71395	 71397	 0.005129	 0.0136	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71395	 79324	 0.009571	 0.019664	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71397	 71398	 0.001393	 0.007486	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71397	 79324	 0.007457	 0.013864	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79322	 71398	 0.00435	 0.026043	 0.00063	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71399	 71405	 0.000664	 0.009929	 0.00294	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71399	 79324	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71399	 79324	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71400	 71401	 0.005671	 0.02215	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71400	 71401	 0.005671	 0.02215	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79324	 71400	 0.0061	 0.023829	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79324	 71400	 0.0061	 0.023829	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71401	 71406	 0.007429	 0.029014	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71401	 71406	 0.007429	 0.029014	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71402	 71403	 0.004436	 0.019764	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71402	 71439	 0.004193	 0.014686	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71402	 79325	 0.007007	 0.024529	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71402	 79325	 0.007007	 0.024529	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71403	 71406	 0.002521	 0.0204	 0.00053	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71403	 71412	 0.005871	 0.022921	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71403	 71412	 0.005871	 0.022921	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71404	 79325	 0.005271	 0.018	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71405	 71453	 0.007829	 0.035929	 0.00921	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71405	 79325	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71405	 79325	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71406	 71407	 0.005943	 0.017464	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71406	 71408	 0.005886	 0.036179	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79325	 71406	 0.003107	 0.021343	 0.00039	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71407	 71408	 0.002914	 0.0198	 0.00049	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71407	 72271	 0.003071	 0.011779	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71409	 71410	 0.00565	 0.016621	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71409	 71421	 0.010329	 0.026157	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71410	 71412	 0.004957	 0.019357	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71410	 71412	 0.004957	 0.019357	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71410	 79326	 0.002221	 0.021743	 0.00043	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71411	 71412	 0.021936	 0.017357	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71413	 79326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71413	 79326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71413	 79421	 0.003214	 0.013271	 0.00314	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71414	 71415	 0.004721	 0.021043	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71414	 71415	 0.004721	 0.021043	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71414	 72225	 0.009136	 0.040721	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71414	 72225	 0.009136	 0.040721	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71415	 71416	 0.003807	 0.013321	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71415	 71416	 0.003807	 0.013321	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71416	 71417	 0.006164	 0.021571	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71416	 71417	 0.006164	 0.021571	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71417	 71418	 0.009771	 0.018171	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71417	 71433	 0.010636	 0.052786	 0.00126	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79326	 71417	 0.006821	 0.03385	 0.00081	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71418	 71419	 0.009871	 0.019543	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71418	 71420	 0.008914	 0.018321	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71419	 71420	 0.009621	 0.019764	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71419	 71424	 0.018443	 0.0379	 0.00072	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71419	 71768	 0.007686	 0.012264	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71420	 71421	 0.004764	 0.012071	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71420	 71426	 0.007679	 0.015771	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71422	 71769	 0.031186	 0.024679	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71423	 71769	 0.0043	 0.014343	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71423	 79328	 0.006843	 0.020129	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71424	 71425	 0.004029	 0.015993	 0.00046	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71424	 71769	 0.008193	 0.014407	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71424	 79328	 0.002443	 0.015779	 0.0005	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71425	 71426	 0.016121	 0.029979	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71426	 71427	 0.004307	 0.013221	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71427	 71430	 0.004593	 0.015693	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71427	 71433	 0.004286	 0.024371	 0.00044	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71427	 71769	 0.008443	 0.037629	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71428	 71429	 0.001414	 0.007136	 0.00012	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71428	 71430	 0.002193	 0.008529	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71428	 71431	 0.002686	 0.0105	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71428	 71432	 0.009507	 0.025193	 0.00064	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71429	 71449	 0.009629	 0.019793	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71429	 71456	 0.003514	 0.0089	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71431	 71454	 0.007993	 0.010893	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71432	 71433	 0.005686	 0.022114	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71432	 71446	 0.001629	 0.011771	 0.00029	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71433	 71434	 0.015636	 0.011071	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71433	 71435	 0.003386	 0.013221	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71433	 71435	 0.003386	 0.013221	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71435	 71445	 0.0036	 0.012607	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71435	 71445	 0.0036	 0.012607	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71436	 71437	 0.001586	 0.006771	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71436	 71440	 0.001629	 0.006364	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71438	 71439	 0.018786	 0.012164	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71439	 71441	 0.005771	 0.022464	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71440	 71442	 0.004693	 0.018779	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71440	 71452	 0.008307	 0.036793	 0.00084	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71441	 71445	 0.003179	 0.010857	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71442	 71446	 0.0017	 0.013264	 0.00025	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71443	 71444	 0.001329	 0.008579	 0.00027	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71443	 71445	 0.001579	 0.011421	 0.00029	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71445	 71446	 0.003007	 0.009214	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71446	 71451	 0.005221	 0.0097	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71447	 71452	 0.015414	 0.010921	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71448	 71452	 0.019893	 0.014093	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71449	 71450	 0.005564	 0.01035	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71449	 71456	 0.025664	 0.020307	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71450	 71452	 0.003629	 0.012714	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71450	 71456	 0.014314	 0.022843	 0.00053	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71451	 71452	 0.004979	 0.007986	 0.00015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71453	 71493	 0.008257	 0.045843	 0.01394	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71453	 79327	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71453	 79327	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71454	 71455	 0.003479	 0.013543	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71454	 71468	 0.007693	 0.029921	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71454	 71778	 0.002093	 0.011229	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79327	 71454	 0.004786	 0.034414	 0.00113	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71455	 71456	 0.003157	 0.01215	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79327	 71456	 0.004386	 0.024964	 0.00077	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71457	 79328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71457	 79328	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71458	 71459	 0.006264	 0.024464	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71458	 71459	 0.006264	 0.024464	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71458	 71471	 0.00805	 0.009436	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71459	 71461	 0.003293	 0.008721	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71459	 71464	 0.0042	 0.016407	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71459	 71464	 0.0042	 0.016407	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71459	 71466	 0.003679	 0.007557	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71460	 71461	 0.004507	 0.009271	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79328	 71460	 0.005064	 0.010407	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71462	 71465	 0.004957	 0.01655	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71462	 71467	 0.002993	 0.0128	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71462	 71777	 0.011107	 0.022821	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71463	 71465	 0.016907	 0.010943	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71464	 71465	 0.004729	 0.015771	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71464	 71474	 0.002607	 0.010171	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71464	 71474	 0.002607	 0.010171	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71466	 71467	 0.00685	 0.015914	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71467	 71469	 0.002393	 0.017329	 0.00044	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71468	 71469	 0.00465	 0.011771	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71469	 71475	 0.006264	 0.024379	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71470	 71471	 0.015857	 0.01255	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71472	 71479	 0.0005	 0.004164	 0.00126	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71472	 79329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71472	 79329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71473	 71474	 0.008493	 0.0055	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79329	 71474	 0.003357	 0.013121	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79329	 71474	 0.003357	 0.013121	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71475	 71476	 0.023729	 0.068071	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71475	 71776	 0.003986	 0.027071	 0.00067	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79327	 71475	 0.013379	 0.052264	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79327	 71475	 0.013379	 0.052264	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71476	 71483	 0.019921	 0.06805	 0.00148	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71477	 71574	 0.015286	 0.065343	 0.00148	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79327	 71477	 0.033636	 0.1032	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71478	 71479	 0.000479	 0.004243	 0.00113	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71480	 71481	 0.030693	 0.019871	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71481	 71482	 0.018907	 0.028343	 0.00051	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71482	 71489	 0.005879	 0.018029	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71483	 71569	 0.030114	 0.117614	 0.00261	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71484	 71489	 0.112679	 0.072957	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71485	 71486	 0.015979	 0.032693	 0.00081	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71485	 71489	 0.015693	 0.032257	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71486	 71568	 0.039214	 0.057143	 0.00129	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71486	 71569	 0.017614	 0.0362	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71486	 79346	 0.020007	 0.04645	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71487	 71489	 0.0188	 0.022036	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71487	 71498	 0.011407	 0.020586	 0.0003	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71488	 79346	 0.033836	 0.021907	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71489	 79346	 0.010679	 0.032757	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71490	 71491	 0.030157	 0.021357	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71490	 71498	 0.009007	 0.030779	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71490	 71767	 0.003107	 0.010879	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71491	 71492	 0.009371	 0.006636	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71493	 71770	 0.007086	 0.033043	 0.00819	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71493	 79330	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71493	 79330	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71493	 79403	 0.000907	 0.010486	 0.0056	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79330	 71494	 0.010729	 0.006943	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71495	 71796	 0.027393	 0.017736	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71496	 71767	 0.02115	 0.014986	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71497	 71499	 0.016814	 0.042586	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71497	 71509	 0.017286	 0.040136	 0.0006	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71498	 71796	 0.02335	 0.020921	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71498	 71814	 0.012079	 0.0122	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71499	 72360	 0.014486	 0.012979	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79330	 71499	 0.012214	 0.022707	 0.00053	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71500	 71658	 0.091543	 0.07245	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71501	 71533	 0.006171	 0.014	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71501	 79331	 0.011664	 0.045379	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71502	 71507	 0.004457	 0.009129	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71502	 71522	 0.012879	 0.0255	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71503	 71522	 0.0156	 0.01235	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71504	 71505	 0.002457	 0.005029	 0.00012	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71504	 71513	 0.020821	 0.018657	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71504	 71522	 0.012286	 0.014407	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71505	 71508	 0.0037	 0.007607	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71506	 71507	 0.011536	 0.007464	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71507	 71510	 0.003414	 0.015214	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71507	 71526	 0.010414	 0.020621	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71508	 71509	 0.004879	 0.011071	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71509	 71510	 0.0058	 0.013157	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71510	 79331	 0.004029	 0.01785	 0.00054	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71511	 72366	 0.003843	 0.013671	 0.00304	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71511	 79331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71511	 79331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71512	 71513	 0.017407	 0.011271	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71513	 71520	 0.018021	 0.012764	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71513	 79346	 0.021507	 0.039986	 0.00094	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71514	 71770	 0.0041	 0.01065	 0.00259	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71514	 71781	 0.001214	 0.004286	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71514	 79332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71514	 79332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71515	 71517	 0.0073	 0.015	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79332	 71515	 0.007229	 0.013443	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71516	 71517	 0.011593	 0.007507	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71516	 71525	 0.012207	 0.00865	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71516	 71528	 0.0062	 0.01275	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71516	 71783	 0.018193	 0.018371	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79332	 71516	 0.014229	 0.029236	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71517	 71518	 0.004664	 0.013371	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71518	 71519	 0.011693	 0.008279	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71518	 71523	 0.00405	 0.008321	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71520	 71521	 0.011914	 0.007714	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71521	 71522	 0.00435	 0.006343	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71522	 71523	 0.006429	 0.013207	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71524	 71525	 0.011636	 0.009207	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71526	 71527	 0.004843	 0.007057	 0.00016	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71527	 71528	 0.005729	 0.009193	 0.00017	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71528	 71771	 0.021264	 0.013764	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71529	 71530	 0.009036	 0.016307	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71529	 71537	 0.005757	 0.014593	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71529	 71565	 0.018507	 0.033386	 0.00049	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79332	 71529	 0.038393	 0.089129	 0.00133	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71530	 79333	 0.007193	 0.014786	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71531	 71535	 0.040493	 0.062029	 0.00087	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71531	 79333	 0.006236	 0.00995	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71532	 71781	 0.003	 0.010507	 0.00348	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71532	 79333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71532	 79333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71532	 79403	 0.013864	 0.060779	 0.02092	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71533	 71534	 0.006043	 0.011243	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71534	 71780	 0.028193	 0.0221	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79332	 71534	 0.094521	 0.0612	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71535	 71536	 0.008286	 0.038636	 0.00089	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71535	 71784	 0.014486	 0.029636	 0.00073	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71536	 71657	 0.009686	 0.055057	 0.00099	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71537	 71545	 0.012071	 0.032	 0.00081	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71538	 71561	 0.0182	 0.012893	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71539	 71553	 0.01215	 0.022593	 0.00053	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71539	 71554	 0.006107	 0.020371	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71539	 71560	 0.006521	 0.016757	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71540	 71554	 0.014086	 0.028943	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71540	 71560	 0.006171	 0.017693	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71540	 71561	 0.029793	 0.026879	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71541	 71543	 0.005036	 0.011429	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71541	 71765	 0.013529	 0.027679	 0.00068	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71542	 71573	 0.002629	 0.010514	 0.00265	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71542	 79334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71542	 79334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71542	 79484	 0.018771	 0.089543	 0.02596	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71543	 71544	 0.024157	 0.017107	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71543	 71554	 0.009736	 0.024664	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 71545	 0.016507	 0.056393	 0.00123	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71546	 71552	 0.012871	 0.039493	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71546	 71564	 0.012179	 0.03735	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71547	 71548	 0.033014	 0.06785	 0.00129	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71547	 71549	 0.019714	 0.045771	 0.00068	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71547	 71556	 0.093986	 0.066579	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71547	 79338	 0.01375	 0.048157	 0.00134	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71548	 71549	 0.018743	 0.030071	 0.00056	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71548	 71551	 0.006621	 0.016764	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71548	 71557	 0.006371	 0.016893	 0.00043	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71548	 71558	 0.024493	 0.0391	 0.0009	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71550	 71560	 0.004793	 0.023793	 0.00056	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 71550	 0.001479	 0.007107	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 71551	 0.010014	 0.030714	 0.00083	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 71552	 0.007014	 0.02315	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71553	 71566	 0.0038	 0.021614	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 71553	 0.008221	 0.034307	 0.00099	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71554	 71561	 0.047007	 0.038693	 0.00079	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79334	 71554	 0.027764	 0.071371	 0.00111	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71555	 71561	 0.006929	 0.028929	 0.00084	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71555	 71609	 0.014214	 0.029214	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71555	 71612	 0.027593	 0.041364	 0.00075	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71556	 71588	 0.009593	 0.042521	 0.00128	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71557	 71558	 0.027114	 0.024457	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71557	 71561	 0.014493	 0.029786	 0.00057	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71558	 79348	 0.018936	 0.035214	 0.00082	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71559	 71560	 0.014471	 0.009364	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71561	 71562	 0.035071	 0.024843	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 71561	 0.0134	 0.059357	 0.00135	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71563	 71564	 0.015643	 0.060864	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71563	 71640	 0.084729	 0.054857	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71563	 71660	 0.0453	 0.120079	 0.00304	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71565	 71566	 0.0176	 0.040864	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71565	 71569	 0.007729	 0.041507	 0.00099	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78160	 71565	 0.010279	 0.055	 0.00166	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71566	 71567	 0.027907	 0.05735	 0.00109	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71567	 71568	 0.0215	 0.054464	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71567	 79335	 0.037171	 0.076393	 0.00146	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71568	 71569	 0.066379	 0.042979	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79333	 71569	 0.021171	 0.060714	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71570	 71763	 0.002779	 0.017914	 0.00057	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79334	 71570	 0.004179	 0.03005	 0.00099	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71571	 71575	 0.0106	 0.047221	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71571	 71575	 0.0106	 0.047221	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71571	 71577	 0.003243	 0.011064	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71571	 79335	 0.003486	 0.025086	 0.00082	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71572	 71574	 0.010621	 0.047057	 0.00107	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71572	 71576	 0.005857	 0.0205	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71572	 79335	 0.0034	 0.024643	 0.00062	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71573	 79335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71573	 79335	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71576	 71577	 0.00485	 0.014864	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71578	 71793	 0.00325	 0.008586	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71578	 79336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71578	 79336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79336	 71579	 0.024443	 0.017314	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71580	 71788	 0.001457	 0.005829	 0.00147	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71580	 71793	 0.002429	 0.009707	 0.00244	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71580	 71795	 0.01015	 0.029936	 0.00696	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71580	 71798	 0.001643	 0.014079	 0.00401	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71580	 79337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71580	 79337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71581	 71582	 0.009114	 0.016036	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79337	 71581	 0.006279	 0.018014	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71582	 71592	 0.006286	 0.018029	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71582	 71605	 0.005507	 0.0146	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71583	 71584	 0.004064	 0.014236	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71583	 71604	 0.00175	 0.008536	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71584	 71596	 0.005543	 0.021643	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71585	 71610	 0.019643	 0.0176	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71585	 71794	 0.029686	 0.021029	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79336	 71585	 0.0358	 0.041964	 0.00073	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71586	 71587	 0.014021	 0.011543	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71586	 71794	 0.020114	 0.013021	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71587	 71792	 0.017314	 0.015514	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79336	 71587	 0.015221	 0.022179	 0.0005	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71588	 71590	 0.0141	 0.022614	 0.00041	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71588	 71591	 0.021714	 0.038186	 0.00071	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71588	 79348	 0.039114	 0.039507	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71589	 71594	 0.1327	 0.094014	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71590	 71591	 0.021729	 0.0232	 0.00049	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71591	 71594	 0.010393	 0.035493	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71591	 79348	 0.029171	 0.046564	 0.00107	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71592	 71613	 0.011536	 0.033914	 0.00069	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71593	 71603	 0.036086	 0.025564	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79337	 71594	 0.032714	 0.067229	 0.00128	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71595	 71599	 0.013757	 0.009743	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71596	 71597	 0.033171	 0.02625	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71596	 71599	 0.008357	 0.019121	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71598	 73028	 0.011136	 0.053443	 0.0016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79337	 71598	 0.027571	 0.079079	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71598	 79349	 0.025707	 0.059693	 0.00089	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71599	 71600	 0.143293	 0.101514	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71599	 71603	 0.006336	 0.013029	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71601	 71602	 0.005221	 0.013221	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71601	 71605	 0.004307	 0.011407	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71602	 71603	 0.008729	 0.016229	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79337	 71604	 0.002707	 0.011986	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71606	 71607	 0.022486	 0.014557	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71607	 71608	 0.028836	 0.053614	 0.00126	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71607	 71764	 0.012793	 0.036693	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71608	 71789	 0.0208	 0.047179	 0.00094	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71609	 71766	 0.015386	 0.028607	 0.00067	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71610	 71612	 0.028864	 0.026043	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71611	 71792	 0.013821	 0.022064	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71611	 79348	 0.011	 0.032357	 0.00066	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71613	 71791	 0.005571	 0.017086	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71614	 71626	 0.031029	 0.082243	 0.00209	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71614	 71643	 0.017057	 0.052321	 0.00141	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71615	 71616	 0.031457	 0.022286	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71615	 71631	 0.016086	 0.014507	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71616	 71621	 0.008236	 0.016921	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71616	 71625	 0.016079	 0.014507	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71617	 71618	 0.011693	 0.008279	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71617	 71619	 0.0032	 0.014243	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71617	 71621	 0.006486	 0.014714	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71617	 71622	 0.008171	 0.011143	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71617	 71627	 0.007507	 0.01395	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71619	 71620	 0.001343	 0.008664	 0.00028	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71619	 71623	 0.007407	 0.011829	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71620	 71644	 0.001271	 0.00915	 0.0003	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71622	 71623	 0.007036	 0.009593	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71623	 71624	 0.016864	 0.011943	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71625	 71626	 0.027064	 0.0289	 0.00061	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71627	 71628	 0.016643	 0.010771	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71627	 71630	 0.004886	 0.016129	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71627	 71635	 0.012557	 0.024864	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71627	 71636	 0.003514	 0.021271	 0.00066	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71627	 79338	 0.012086	 0.037086	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71629	 71630	 0.021121	 0.013679	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71630	 71631	 0.006029	 0.014	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71630	 71633	 0.016036	 0.010379	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71630	 71634	 0.033057	 0.026164	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71631	 79338	 0.004121	 0.017614	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71632	 79338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71632	 79338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71636	 71638	 0.002986	 0.010193	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71636	 71644	 0.011357	 0.025964	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71637	 71638	 0.012257	 0.028036	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71637	 71641	 0.028386	 0.018379	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71637	 71799	 0.005129	 0.015736	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71638	 71639	 0.021086	 0.014936	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71639	 71644	 0.022207	 0.030293	 0.00054	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71640	 71799	 0.077207	 0.06355	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71641	 71642	 0.019	 0.0123	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71643	 71645	 0.011564	 0.035464	 0.00096	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71643	 79341	 0.025607	 0.1141	 0.00194	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71643	 79341	 0.025607	 0.1141	 0.00194	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71644	 71645	 0.002514	 0.009779	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71644	 71813	 0.003914	 0.038371	 0.00075	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71646	 71650	 0.010464	 0.040264	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71646	 71658	 0.0558	 0.039529	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71646	 71660	 0.018936	 0.095786	 0.00166	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71646	 72396	 0.105079	 0.068036	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71646	 72400	 0.038464	 0.0249	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71646	 72401	 0.005914	 0.023093	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71646	 72401	 0.005914	 0.023093	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71647	 71648	 0.005271	 0.02615	 0.00062	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71647	 71649	 0.004557	 0.021243	 0.00049	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71648	 71664	 0.006143	 0.03775	 0.00068	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71649	 71650	 0.006914	 0.027	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71649	 71653	 0.038436	 0.027229	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71649	 71657	 0.009964	 0.061286	 0.00111	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71649	 71660	 0.006436	 0.036593	 0.00066	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71651	 71660	 0.064479	 0.053079	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71652	 71665	 0.003007	 0.010629	 0.00239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71652	 71669	 0.018293	 0.049114	 0.01114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71652	 79339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71652	 79339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71654	 71655	 0.005743	 0.017614	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71654	 71656	 0.002486	 0.007486	 0.00014	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71654	 71663	 0.0064	 0.028521	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71654	 71663	 0.0064	 0.028521	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71655	 71660	 0.005393	 0.0143	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71656	 71659	 0.004036	 0.013457	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71659	 71660	 0.005186	 0.014871	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78339	 71660	 0.068771	 0.240929	 0.00667	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78339	 71660	 0.068771	 0.240929	 0.00667	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71661	 71662	 0.006586	 0.004664	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71661	 79340	 0.0382	 0.027057	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71663	 79340	 0.017507	 0.061307	 0.0017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71663	 79340	 0.017507	 0.061307	 0.0017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71664	 72493	 0.096186	 0.188543	 0.00283	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71664	 79340	 0.007714	 0.052393	 0.0013	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71665	 79340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71665	 79340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79340	 71666	 0.033986	 0.024079	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71667	 71812	 0.038636	 0.246414	 0.00601	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71667	 79341	 0.026893	 0.143929	 0.00436	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71668	 71727	 0.088393	 0.1644	 0.00385	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71668	 71754	 0.095629	 0.373871	 0.0083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71668	 71754	 0.095629	 0.373871	 0.0083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71668	 73117	 0.172179	 0.769857	 0.01314	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71668	 73117	 0.172179	 0.769857	 0.01314	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71669	 71670	 0.001721	 0.020407	 0.00711	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71669	 71793	 0.009864	 0.090007	 0.03274	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71669	 79341	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71669	 79341	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71670	 71685	 0.002014	 0.022786	 0.00877	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71671	 71679	 0.037086	 0.040793	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71671	 71700	 0.012229	 0.027743	 0.00055	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71672	 71673	 0.031793	 0.028679	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71672	 71675	 0.029607	 0.020971	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71673	 71678	 0.026757	 0.017321	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71674	 71676	 0.012493	 0.020043	 0.00037	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71674	 71678	 0.03095	 0.021929	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71676	 71774	 0.021386	 0.043943	 0.00084	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78344	 71680	 0.020893	 0.071371	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71681	 72468	 0.03555	 0.094221	 0.00239	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78390	 71681	 0.005686	 0.03495	 0.00063	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71682	 71683	 0.01295	 0.020679	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71682	 71686	 0.033086	 0.021414	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71682	 71810	 0.046914	 0.033236	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71683	 71684	 0.006843	 0.026629	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71683	 71687	 0.021186	 0.043543	 0.00083	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71684	 71692	 0.007636	 0.014193	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71684	 71811	 0.009493	 0.013829	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78306	 71684	 0.01165	 0.040779	 0.00113	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71685	 71808	 0.00195	 0.027721	 0.01459	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71685	 79342	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71685	 79342	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71686	 71805	 0.018064	 0.014871	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71686	 71810	 0.03305	 0.023414	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71687	 71809	 0.008007	 0.035679	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71687	 71810	 0.014171	 0.021243	 0.00039	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71688	 79350	 0.029314	 0.020764	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71689	 71690	 0.011729	 0.008307	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71690	 71805	 0.004229	 0.012964	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71690	 71806	 0.029364	 0.023243	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71690	 71812	 0.003686	 0.010829	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71691	 71713	 0.09425	 0.073886	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71692	 71811	 0.013486	 0.025079	 0.00059	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71693	 71695	 0.0118	 0.008357	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71693	 71705	 0.00495	 0.012729	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71693	 71809	 0.010793	 0.014707	 0.00033	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71694	 71706	 0.003586	 0.019257	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71694	 71725	 0.001479	 0.011979	 0.00031	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71694	 71733	 0.0085	 0.029771	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71694	 71733	 0.0085	 0.029771	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71695	 71696	 0.005114	 0.015679	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71695	 71705	 0.006171	 0.014336	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71695	 71804	 0.049507	 0.03205	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71695	 79350	 0.011629	 0.026371	 0.00053	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71696	 71697	 0.007379	 0.025829	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71696	 71700	 0.043243	 0.047564	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71697	 71698	 0.006921	 0.024243	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71697	 71698	 0.006921	 0.024243	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71697	 71700	 0.009664	 0.032243	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71697	 71807	 0.026264	 0.028886	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71698	 71701	 0.009464	 0.03695	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71698	 71708	 0.0349	 0.027621	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71698	 71720	 0.025929	 0.060186	 0.00089	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71698	 71800	 0.031264	 0.109464	 0.00303	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71698	 71800	 0.031264	 0.109464	 0.00303	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71698	 79343	 0.010707	 0.047457	 0.00142	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71699	 71701	 0.003129	 0.011986	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71699	 71707	 0.00595	 0.02775	 0.00064	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71699	 71709	 0.029193	 0.020679	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71702	 71703	 0.011707	 0.009179	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71703	 71704	 0.012943	 0.008379	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71704	 71705	 0.007071	 0.008293	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71705	 71710	 0.026379	 0.017079	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71705	 71810	 0.007964	 0.031107	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71706	 71707	 0.003371	 0.016179	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71710	 71711	 0.011907	 0.008436	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71712	 71808	 0.002707	 0.006521	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71712	 79343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71712	 79343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71713	 71727	 0.036329	 0.06755	 0.00158	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79343	 71713	 0.017657	 0.032829	 0.00077	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71714	 71720	 0.001193	 0.008329	 0.00019	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71714	 71721	 0.025821	 0.018286	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71714	 71722	 0.013407	 0.008679	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71714	 71726	 0.002357	 0.01905	 0.00049	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71715	 71716	 0.016814	 0.010886	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71716	 71723	 0.020957	 0.018779	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71716	 71728	 0.032864	 0.021279	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71717	 71718	 0.004007	 0.01015	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71717	 71727	 0.015836	 0.040114	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71718	 71720	 0.005064	 0.016886	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71719	 71720	 0.028557	 0.020229	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71723	 71724	 0.012129	 0.019357	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71724	 71734	 0.012743	 0.026079	 0.00064	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71725	 71726	 0.002464	 0.019914	 0.00051	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71729	 71734	 0.012664	 0.04945	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71729	 71734	 0.012664	 0.04945	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71729	 71736	 0.006329	 0.021607	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71729	 71738	 0.0294	 0.020821	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71729	 71745	 0.004093	 0.015993	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71729	 71745	 0.004093	 0.015993	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71729	 71746	 0.027693	 0.019614	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71730	 71736	 0.000879	 0.006643	 0.00022	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71730	 71742	 0.004636	 0.016229	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71730	 71742	 0.004636	 0.016229	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71731	 71732	 0.005643	 0.019757	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71731	 71732	 0.005643	 0.019757	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71731	 71736	 0.003879	 0.017271	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71731	 71736	 0.003879	 0.017271	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71732	 71734	 0.007014	 0.024557	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71732	 71734	 0.007014	 0.024557	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71733	 71734	 0.005893	 0.026257	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71733	 71734	 0.005893	 0.026257	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71733	 71741	 0.003679	 0.0143	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71734	 79350	 0.063293	 0.2473	 0.00549	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71734	 79350	 0.063293	 0.2473	 0.00549	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71735	 71744	 0.007757	 0.031036	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71735	 71744	 0.007757	 0.031036	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71735	 71786	 0.007836	 0.030607	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71735	 71786	 0.007836	 0.030607	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71737	 71802	 0.039064	 0.025293	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71739	 71756	 0.00745	 0.033207	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71739	 71756	 0.00745	 0.033207	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71739	 71785	 0.006793	 0.023793	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71739	 71785	 0.006793	 0.023793	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71740	 71744	 0.070886	 0.069636	 0.00118	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71741	 71786	 0.0059	 0.018107	 0.00049	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71742	 71743	 0.001636	 0.01525	 0.00029	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71742	 71744	 0.003036	 0.010636	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71743	 71787	 0.001636	 0.011779	 0.00039	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71744	 0.027129	 0.1209	 0.00205	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71744	 0.027129	 0.1209	 0.00205	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71745	 71785	 0.005107	 0.019943	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71745	 71785	 0.005107	 0.019943	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71745	 71787	 0.001764	 0.010664	 0.00034	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78287	 71747	 0.053343	 0.208393	 0.00462	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78287	 71747	 0.053343	 0.208393	 0.00462	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78287	 71748	 0.041986	 0.067014	 0.00154	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71749	 71750	 0.059807	 0.038721	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71749	 71785	 0.035243	 0.022821	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71751	 71752	 0.000671	 0.00795	 0.00277	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71751	 71752	 0.000671	 0.00795	 0.00277	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71751	 71772	 0.010943	 0.173614	 0.05233	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78277	 71751	 0.019079	 0.236536	 0.07709	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78277	 71751	 0.019079	 0.236536	 0.07709	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71753	 71754	 0.002871	 0.011221	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71753	 71754	 0.002871	 0.011221	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71753	 0.003614	 0.015914	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71753	 0.003614	 0.015914	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71754	 71756	 0.005057	 0.01975	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71754	 71756	 0.005057	 0.01975	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71754	 0.006457	 0.0226	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71754	 0.006457	 0.0226	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71755	 0.008064	 0.005714	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71756	 71802	 0.00715	 0.027929	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71756	 71802	 0.00715	 0.027929	 0.00062	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71756	 0.00485	 0.016979	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78388	 71756	 0.00485	 0.016979	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78197	 71757	 0.007336	 0.025936	 0.00584	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71757	 79344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71757	 79344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71758	 71760	 0.012336	 0.016829	 0.0003	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71758	 71773	 0.004607	 0.015743	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71758	 79345	 0.013171	 0.01975	 0.00036	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71759	 71760	 0.006829	 0.015486	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78392	 71759	 0.023007	 0.107271	 0.00247	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71759	 79345	 0.009107	 0.02115	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71760	 79345	 0.041107	 0.029114	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78197	 71761	 0.001893	 0.020036	 0.00595	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71761	 79345	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71761	 79345	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71762	 71763	 0.011564	 0.070014	 0.00219	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79215	 71762	 0.017679	 0.107036	 0.00335	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71764	 71765	 0.022257	 0.040164	 0.00058	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71764	 71766	 0.014586	 0.02565	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79334	 71765	 0.027329	 0.039829	 0.0009	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79330	 71767	 0.002957	 0.024314	 0.00047	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71768	 71769	 0.010307	 0.013414	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71770	 79346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71770	 79346	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71772	 72461	 0.011521	 0.12225	 0.03636	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71773	 71801	 0.105643	 0.411371	 0.00688	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71774	 71775	 0.112393	 0.079621	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71776	 71777	 0.005157	 0.027693	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71779	 71784	 0.020107	 0.01975	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79332	 71779	 0.029793	 0.021107	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71779	 79347	 0.012686	 0.016514	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71780	 71797	 0.02065	 0.02085	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71781	 79347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71781	 79347	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71782	 71797	 0.013814	 0.009786	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71783	 71797	 0.013707	 0.018021	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71784	 71797	 0.01205	 0.019229	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71786	 71800	 0.009764	 0.034193	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71786	 71800	 0.009764	 0.034193	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71787	 71802	 0.008543	 0.029914	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71787	 71802	 0.008543	 0.029914	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71788	 71793	 0.000979	 0.003907	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71789	 73027	 0.013471	 0.064664	 0.00194	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71789	 79349	 0.021571	 0.057186	 0.00145	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79336	 71790	 0.003636	 0.020664	 0.00037	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71790	 79349	 0.013543	 0.047407	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71791	 79348	 0.007107	 0.034686	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71795	 79348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71795	 79348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71796	 71814	 0.0158	 0.014257	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79347	 71797	 0.029671	 0.039	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71798	 79349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71798	 79349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71798	 79484	 0.01015	 0.0614	 0.01567	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79339	 71799	 0.023857	 0.163807	 0.00299	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71801	 72510	 0.070871	 0.242193	 0.00527	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71803	 71812	 0.105836	 0.068529	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71805	 71811	 0.018364	 0.046514	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71805	 79350	 0.003236	 0.026179	 0.00067	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79343	 71807	 0.0163	 0.017407	 0.00037	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71808	 79350	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71808	 79350	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79343	 71809	 0.002686	 0.0171	 0.00041	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79350	 71809	 0.009164	 0.021279	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71810	 71812	 0.012986	 0.0297	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78306	 71810	 0.051321	 0.09225	 0.00166	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79341	 71813	 0.024257	 0.108093	 0.00184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79341	 71813	 0.024257	 0.108093	 0.00184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78392	 71815	 0.238686	 0.1546	 0.00294	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71816	 71817	 0.001993	 0.008893	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71816	 71894	 0.002693	 0.010314	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71817	 71818	 0.005636	 0.010471	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71817	 71829	 0.006257	 0.014521	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71818	 71819	 0.006057	 0.014057	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71819	 71820	 0.017229	 0.0122	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71819	 71827	 0.004693	 0.0064	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71820	 71824	 0.010171	 0.009993	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71820	 71893	 0.013164	 0.009321	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71821	 71824	 0.006029	 0.008221	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71822	 71823	 0.00905	 0.005857	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71823	 79351	 0.008979	 0.0081	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71824	 71825	 0.009957	 0.006443	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71824	 79351	 0.005757	 0.014593	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71826	 71827	 0.003529	 0.0062	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71826	 71832	 0.011243	 0.0089	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71828	 71831	 0.015607	 0.017164	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71829	 71830	 0.004979	 0.010221	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71830	 71842	 0.004679	 0.010614	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71830	 79351	 0.032221	 0.056664	 0.00106	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71831	 71833	 0.010443	 0.021371	 0.00053	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71831	 71840	 0.014171	 0.009171	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71831	 71841	 0.019521	 0.013829	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71831	 71871	 0.031364	 0.028293	 0.00047	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71832	 71833	 0.006464	 0.010321	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71832	 71839	 0.005036	 0.009971	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71833	 71836	 0.01385	 0.008964	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71833	 79351	 0.002743	 0.012157	 0.00028	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71834	 79351	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71834	 79351	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71834	 79847	 0.000629	 0.003671	 0.001	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71834	 79849	 0.004721	 0.012857	 0.00284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71835	 71837	 0.005571	 0.018593	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71835	 71849	 0.014764	 0.030336	 0.00058	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71835	 74853	 0.01085	 0.022293	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71835	 79848	 0.001814	 0.013743	 0.00046	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71837	 71851	 0.005457	 0.012479	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71838	 71839	 0.008279	 0.009707	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71838	 71851	 0.016871	 0.015221	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71842	 71843	 0.003593	 0.007357	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71843	 71845	 0.003857	 0.008743	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71844	 71848	 0.012943	 0.009171	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71845	 71846	 0.00525	 0.012193	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71846	 71848	 0.011393	 0.012164	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71846	 71875	 0.004786	 0.011107	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71847	 71848	 0.002907	 0.007371	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71847	 71879	 0.003229	 0.007329	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78308	 71848	 0.003907	 0.016714	 0.00038	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71849	 71852	 0.005136	 0.013014	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71849	 71856	 0.014193	 0.0128	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71850	 71857	 0.023143	 0.014979	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71851	 71852	 0.004357	 0.00895	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71851	 71853	 0.003629	 0.008236	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78230	 71852	 0.006093	 0.017907	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71853	 71854	 0.003	 0.006136	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71854	 71872	 0.0052	 0.007793	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71854	 71873	 0.007886	 0.018307	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71855	 71866	 0.018557	 0.012014	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71856	 74853	 0.0191	 0.0204	 0.00043	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71857	 71860	 0.01875	 0.014843	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71857	 71863	 0.016757	 0.016929	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71857	 71867	 0.006943	 0.014207	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71857	 74853	 0.022121	 0.056864	 0.00088	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71858	 71861	 0.008221	 0.013121	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71858	 74857	 0.0061	 0.015686	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71859	 71860	 0.013357	 0.00865	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71861	 71862	 0.00605	 0.0097	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71862	 71863	 0.012314	 0.011036	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71863	 71865	 0.0183	 0.014486	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71864	 71865	 0.009521	 0.00675	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78230	 71866	 0.001307	 0.005586	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71866	 79352	 0.008836	 0.034379	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71866	 79353	 0.006479	 0.012043	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71867	 71868	 0.005021	 0.009343	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71868	 71869	 0.006743	 0.010107	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71868	 79352	 0.003479	 0.010671	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71869	 71881	 0.007657	 0.01045	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71870	 72107	 0.001336	 0.004014	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71870	 79352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71870	 79352	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71871	 71872	 0.00605	 0.00825	 0.00015	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71873	 71875	 0.012593	 0.018343	 0.00041	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71873	 71876	 0.014071	 0.009107	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78230	 71873	 0.00125	 0.006014	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71874	 72107	 0.002464	 0.010736	 0.00306	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71874	 79353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71874	 79353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71875	 71877	 0.007993	 0.018136	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71877	 71882	 0.005914	 0.013414	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79353	 71878	 0.021436	 0.015186	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71879	 71880	 0.002143	 0.006571	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71879	 71888	 0.015643	 0.040207	 0.00062	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78308	 71879	 0.00725	 0.025379	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71880	 71885	 0.003507	 0.011571	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71881	 71882	 0.005464	 0.0124	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71881	 71884	 0.017821	 0.011536	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79353	 71881	 0.003086	 0.013207	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71882	 71883	 0.003336	 0.011393	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71883	 71886	 0.006143	 0.011421	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71883	 72124	 0.001629	 0.007593	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	71885	 71886	 0.003364	 0.008529	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71885	 71887	 0.015614	 0.015771	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71886	 72108	 0.00455	 0.020293	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79353	 71886	 0.008171	 0.031914	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71887	 71888	 0.023121	 0.016379	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71888	 72082	 0.003164	 0.009714	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71889	 71895	 0.003686	 0.008364	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78308	 71889	 0.011136	 0.03275	 0.00067	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71890	 71891	 0.020586	 0.014579	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71891	 71892	 0.00325	 0.01585	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71891	 71896	 0.012457	 0.0219	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71891	 72071	 0.0054	 0.01235	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78308	 71892	 0.001657	 0.006343	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79351	 71893	 0.012486	 0.02555	 0.00063	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71894	 79354	 0.003264	 0.014471	 0.00033	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71895	 71900	 0.005664	 0.011593	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71896	 71905	 0.005807	 0.011929	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71897	 71920	 0.000871	 0.003321	 0.00093	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71897	 71946	 0.010929	 0.02995	 0.00651	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71897	 79354	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71897	 79354	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71898	 71899	 0.003093	 0.009479	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71898	 71903	 0.011886	 0.013929	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71898	 71919	 0.006293	 0.0144	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79354	 71898	 0.003564	 0.012479	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71899	 71902	 0.003321	 0.0076	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71900	 71902	 0.003293	 0.008464	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71901	 71902	 0.00875	 0.005664	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71903	 71904	 0.005514	 0.012807	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71903	 71907	 0.035407	 0.025079	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71903	 71918	 0.017843	 0.01155	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71903	 79365	 0.039143	 0.0888	 0.00177	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71904	 71905	 0.005479	 0.012714	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71906	 71914	 0.020743	 0.014693	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71907	 71909	 0.015157	 0.014886	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71908	 71982	 0.0326	 0.021107	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71909	 71910	 0.010664	 0.017964	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71910	 72053	 0.00525	 0.013493	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71910	 72060	 0.008086	 0.015036	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71911	 71913	 0.006257	 0.015843	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71911	 71915	 0.0072	 0.013393	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71911	 71979	 0.003357	 0.010307	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71912	 71982	 0.01775	 0.014043	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71913	 71982	 0.006793	 0.015414	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71914	 71916	 0.002221	 0.008679	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71914	 71917	 0.004836	 0.014836	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71914	 71982	 0.014364	 0.032993	 0.0005	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71915	 71916	 0.002271	 0.00795	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71915	 71960	 0.004086	 0.012529	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71917	 71919	 0.004943	 0.014536	 0.0003	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71920	 71921	 0.0006	 0.002279	 0.00064	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71921	 79355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71921	 79355	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71922	 71923	 0.007314	 0.015036	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71922	 71951	 0.046843	 0.033179	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78258	 71922	 0.008064	 0.021371	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71923	 71925	 0.010664	 0.018757	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79355	 71924	 0.015143	 0.010721	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71925	 71941	 0.019086	 0.028621	 0.00052	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71926	 71929	 0.006964	 0.012957	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79355	 71926	 0.012786	 0.023779	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71927	 71928	 0.026721	 0.018929	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71928	 71931	 0.015157	 0.025529	 0.00036	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79354	 71928	 0.014636	 0.025736	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71928	 79848	 0.072814	 0.059936	 0.00121	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71929	 71931	 0.00725	 0.01275	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71930	 71935	 0.004014	 0.007464	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71930	 71941	 0.004564	 0.012093	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71931	 71936	 0.010243	 0.010064	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71932	 71933	 0.004593	 0.009443	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71932	 71942	 0.006621	 0.012307	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71933	 71934	 0.003679	 0.007279	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71933	 74848	 0.015636	 0.024957	 0.00057	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71934	 71935	 0.004129	 0.009364	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71934	 71936	 0.007343	 0.011014	 0.0002	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71937	 71938	 0.006293	 0.0144	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71937	 71949	 0.039236	 0.0254	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71937	 79356	 0.00605	 0.025871	 0.00059	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71937	 79846	 0.038336	 0.071279	 0.00167	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71938	 71939	 0.007707	 0.017479	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71939	 71942	 0.006921	 0.014221	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71940	 71941	 0.017236	 0.020207	 0.00035	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71940	 71945	 0.008693	 0.020171	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71941	 71948	 0.006286	 0.021479	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71941	 79848	 0.03415	 0.077457	 0.00154	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71943	 71944	 0.002057	 0.01015	 0.00296	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71943	 74569	 0.00735	 0.042243	 0.01197	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71944	 71946	 0.000679	 0.0031	 0.00079	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71944	 79356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71944	 79356	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71945	 79357	 0.003807	 0.012693	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71946	 79357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71946	 79357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71946	 79847	 0.006121	 0.027271	 0.00741	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71947	 71948	 0.016279	 0.014686	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79357	 71947	 0.02435	 0.015764	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71948	 71954	 0.006929	 0.023657	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71950	 71955	 0.009957	 0.020457	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71950	 79359	 0.014143	 0.026293	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71952	 71953	 0.009514	 0.021586	 0.00043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71952	 71955	 0.017571	 0.02805	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71953	 71964	 0.012521	 0.032193	 0.0005	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71954	 71955	 0.004529	 0.013886	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71956	 71958	 0.001414	 0.005564	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71957	 71958	 0.000493	 0.002664	 0.00066	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71957	 71959	 0.000529	 0.003014	 0.00087	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71957	 79358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71957	 79358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71958	 79359	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71958	 79359	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71959	 79360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	71959	 79360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78258	 71960	 0.002157	 0.008271	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	71961	 71963	 0.002671	 0.007079	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71961	 71972	 0.003429	 0.011436	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71962	 71963	 0.001686	 0.005743	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71962	 71977	 0.002979	 0.011457	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71963	 71967	 0.009286	 0.014229	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71964	 71974	 0.002457	 0.0086	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79360	 71964	 0.0092	 0.0189	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71965	 71976	 0.008443	 0.01775	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71965	 72004	 0.009229	 0.01345	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71966	 71971	 0.008379	 0.008943	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71966	 72007	 0.008857	 0.0087	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71967	 71968	 0.012593	 0.008914	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79358	 71967	 0.014336	 0.0215	 0.00039	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	71969	 71970	 0.003193	 0.009386	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79360	 71969	 0.004071	 0.011979	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71970	 71976	 0.002779	 0.010814	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71971	 71972	 0.006979	 0.009521	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71972	 71976	 0.002529	 0.012864	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	71973	 71974	 0.002843	 0.012679	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71973	 71976	 0.008264	 0.016986	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79320	 71973	 0.002357	 0.015221	 0.00049	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71975	 71976	 0.002014	 0.01145	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79320	 71975	 0.003107	 0.016693	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71977	 71978	 0.002671	 0.013529	 0.00024	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71977	 72008	 0.00855	 0.0175	 0.00043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71977	 72010	 0.016664	 0.013193	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71977	 79363	 0.106629	 0.132386	 0.00289	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71978	 71979	 0.003071	 0.010743	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71978	 71980	 0.024507	 0.015864	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71978	 71989	 0.046029	 0.032607	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71981	 71982	 0.023479	 0.0152	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71982	 71983	 0.024564	 0.0174	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71982	 79365	 0.031486	 0.055371	 0.00104	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71984	 71988	 0.010879	 0.0135	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	71984	 71989	 0.0164	 0.0148	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71985	 72057	 0.023314	 0.016514	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71986	 71998	 0.0152	 0.009836	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71987	 71992	 0.022986	 0.016286	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71988	 71995	 0.010679	 0.015564	 0.00035	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71990	 79361	 0.03115	 0.020164	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71991	 79361	 0.045779	 0.032429	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71992	 72015	 0.016521	 0.015221	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	71993	 71994	 0.005593	 0.012793	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71993	 72001	 0.005393	 0.012336	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71994	 72046	 0.009143	 0.018707	 0.00046	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71995	 72046	 0.014971	 0.029636	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71996	 71997	 0.004714	 0.01385	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	71996	 72009	 0.008171	 0.011907	 0.00027	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	71996	 72012	 0.020021	 0.017943	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71997	 72005	 0.012993	 0.0092	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71998	 72011	 0.008529	 0.008379	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71999	 72012	 0.020779	 0.01345	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	71999	 72013	 0.024493	 0.015857	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72000	 72017	 0.006586	 0.010514	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72000	 72018	 0.0019	 0.010171	 0.00031	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72000	 72022	 0.002686	 0.011907	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72001	 72016	 0.005393	 0.011079	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72001	 72024	 0.002464	 0.011843	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72002	 72003	 0.008964	 0.009571	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72003	 72022	 0.018836	 0.019021	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72004	 72006	 0.011379	 0.011179	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72006	 72009	 0.01065	 0.009607	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72007	 72008	 0.006264	 0.016093	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72007	 72009	 0.005864	 0.0133	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72008	 72011	 0.006721	 0.011821	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72008	 72013	 0.012236	 0.028407	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72013	 72018	 0.00445	 0.011264	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72014	 72015	 0.013021	 0.009221	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72015	 72016	 0.004407	 0.009057	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72015	 72018	 0.003729	 0.013043	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72015	 72046	 0.022214	 0.045464	 0.00112	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72017	 72019	 0.004293	 0.009971	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72019	 72020	 0.00505	 0.012986	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72021	 72022	 0.015179	 0.009829	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72022	 72023	 0.00215	 0.014743	 0.00027	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72022	 79361	 0.019929	 0.03505	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72023	 72030	 0.002871	 0.016314	 0.0005	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72024	 79361	 0.002443	 0.016764	 0.00031	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72025	 79361	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72025	 79361	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72025	 79362	 0.002921	 0.024443	 0.00634	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72026	 72035	 0.010814	 0.022221	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79361	 72026	 0.00695	 0.016129	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79361	 72027	 0.021243	 0.01375	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72028	 72029	 0.024843	 0.019479	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72029	 72030	 0.003207	 0.019429	 0.00061	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78271	 72029	 0.001957	 0.014157	 0.00036	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72031	 72032	 0.002036	 0.016486	 0.00042	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72031	 72037	 0.018543	 0.013136	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72031	 72038	 0.009621	 0.032871	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78271	 72031	 0.005764	 0.025536	 0.00059	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72032	 72033	 0.018286	 0.012957	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72032	 72035	 0.002357	 0.017064	 0.00043	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72034	 72040	 0.006829	 0.01585	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72034	 72132	 0.011036	 0.020514	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72035	 79363	 0.013129	 0.058179	 0.00175	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72036	 72037	 0.013314	 0.008621	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72038	 72039	 0.023114	 0.014964	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72038	 72043	 0.004271	 0.018914	 0.00043	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72040	 72041	 0.005057	 0.012821	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72041	 72042	 0.005793	 0.01325	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72044	 79363	 0.015643	 0.083729	 0.00254	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72044	 79371	 0.023943	 0.136114	 0.00246	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72045	 72046	 0.018179	 0.012879	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72046	 72056	 0.003471	 0.015286	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72046	 79363	 0.017886	 0.0526	 0.00108	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72047	 72049	 0.001657	 0.009693	 0.00264	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72047	 79362	 0.001543	 0.009471	 0.00273	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72048	 72099	 0.001479	 0.020329	 0.04052	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72048	 79362	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79363	 72048	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72049	 72059	 0.000571	 0.006336	 0.00206	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72049	 72063	 0.001736	 0.0104	 0.00315	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72049	 79364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72049	 79364	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72050	 72054	 0.004114	 0.012107	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72050	 72062	 0.013671	 0.012336	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72050	 79365	 0.00425	 0.013036	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72051	 72052	 0.002271	 0.006021	 0.00015	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72051	 72056	 0.003443	 0.013386	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72051	 72057	 0.015493	 0.017043	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72052	 79365	 0.0066	 0.018936	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72053	 72055	 0.002593	 0.005936	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72054	 72055	 0.003086	 0.007807	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72058	 72060	 0.010671	 0.008443	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72059	 72074	 0.002314	 0.010079	 0.00287	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72059	 72092	 0.002271	 0.017729	 0.0053	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72060	 72065	 0.00945	 0.024293	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72060	 72068	 0.021821	 0.015457	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72060	 72073	 0.022607	 0.03975	 0.00075	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72060	 79365	 0.009821	 0.043286	 0.00075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72061	 72062	 0.019193	 0.013593	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79362	 72063	 0.002079	 0.015293	 0.00388	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72063	 79365	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72063	 79365	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79364	 72064	 0.0112	 0.022914	 0.00056	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79365	 72064	 0.004114	 0.016057	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72065	 72070	 0.006893	 0.014107	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72066	 72067	 0.011943	 0.00945	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72066	 72070	 0.003571	 0.0105	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72066	 72071	 0.001464	 0.0043	 9e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72069	 72070	 0.00835	 0.008436	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72069	 72072	 0.013921	 0.014057	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72072	 72073	 0.013693	 0.01605	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72074	 79366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72074	 79366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72075	 72076	 0.024857	 0.017607	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72075	 72096	 0.023336	 0.016529	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72076	 72077	 0.00345	 0.015279	 0.00035	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72076	 72088	 0.01205	 0.02755	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72076	 72112	 0.005321	 0.015271	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72077	 79367	 0.003864	 0.011864	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72078	 72091	 0.004414	 0.018357	 0.00429	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72078	 72128	 0.005286	 0.020093	 0.00563	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72078	 79367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72078	 79367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72079	 72080	 0.026229	 0.020564	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72080	 72081	 0.003557	 0.019086	 0.00045	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72080	 72083	 0.009779	 0.014664	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72080	 72094	 0.023614	 0.015286	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79366	 72080	 0.012407	 0.043443	 0.0012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72081	 72089	 0.015314	 0.019007	 0.00041	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72081	 72097	 0.003871	 0.01715	 0.00039	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72082	 72083	 0.004636	 0.013643	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72083	 72087	 0.015029	 0.01065	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72084	 72085	 0.010779	 0.009729	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72085	 72086	 0.002664	 0.010379	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72085	 72108	 0.004586	 0.014071	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72086	 72109	 0.006507	 0.014879	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72088	 72089	 0.010379	 0.01665	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72088	 72109	 0.008343	 0.019079	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72090	 72097	 0.015621	 0.026314	 0.00037	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72090	 79368	 0.022914	 0.026864	 0.00046	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72091	 72092	 0.001571	 0.012821	 0.00348	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72091	 72098	 0.004036	 0.017679	 0.00608	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72091	 79368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72091	 79368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72092	 79369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72092	 79369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72093	 72096	 0.004136	 0.014486	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79367	 72093	 0.005614	 0.012843	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79369	 72095	 0.033793	 0.023936	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72096	 72097	 0.007507	 0.025029	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72098	 72101	 0.001979	 0.01725	 0.00474	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72098	 79370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72098	 79370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72099	 79371	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72099	 79371	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78203	 72100	 0.0093	 0.032564	 0.0009	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78203	 72100	 0.0093	 0.032564	 0.0009	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79371	 72100	 0.027279	 0.10655	 0.00236	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79371	 72100	 0.027279	 0.10655	 0.00236	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72101	 72106	 0.001136	 0.009443	 0.00286	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72101	 79372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72101	 79372	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79372	 72102	 0.037843	 0.026807	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72103	 72104	 0.047429	 0.030707	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72104	 72105	 0.022343	 0.015821	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79372	 72105	 0.015457	 0.019186	 0.00042	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72106	 73428	 0.001893	 0.014779	 0.00442	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72109	 72129	 0.008393	 0.019043	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78264	 72109	 0.008043	 0.034386	 0.00078	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72110	 72111	 0.001743	 0.010614	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72110	 72114	 0.001521	 0.008157	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72111	 72124	 0.0025	 0.012014	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72112	 72113	 0.005257	 0.010807	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72112	 72129	 0.007164	 0.014664	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72113	 72116	 0.005414	 0.011129	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72114	 72115	 0.001657	 0.008229	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72115	 72116	 0.002464	 0.010907	 0.00033	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72115	 72117	 0.005721	 0.016421	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72115	 79373	 0.004693	 0.028857	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72116	 72122	 0.00265	 0.014236	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72117	 72126	 0.008464	 0.01675	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72118	 79373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72118	 79373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72119	 72120	 0.017343	 0.012286	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79373	 72119	 0.017064	 0.021179	 0.00046	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72121	 72127	 0.000629	 0.003607	 0.00102	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72121	 79374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72121	 79374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72122	 79375	 0.003571	 0.01395	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72123	 72124	 0.011086	 0.007179	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79374	 72125	 0.032164	 0.020821	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79374	 72126	 0.013993	 0.014943	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72127	 72128	 0.002579	 0.013107	 0.00475	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72127	 79375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72127	 79375	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72128	 72131	 0.003171	 0.028779	 0.00938	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72128	 79376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72128	 79376	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72130	 72131	 0.005679	 0.054557	 0.01588	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78184	 72130	 0.003364	 0.027914	 0.00734	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72130	 79377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72130	 79377	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78271	 72132	 0.005686	 0.0129	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72133	 72141	 0.023493	 0.072071	 0.00195	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78302	 72133	 0.040007	 0.227729	 0.00701	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72134	 72141	 0.023829	 0.0814	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72135	 72136	 0.031743	 0.02295	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72136	 72138	 0.013014	 0.017736	 0.00039	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72136	 72139	 0.022236	 0.030314	 0.00067	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72136	 72141	 0.007143	 0.014614	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72137	 72138	 0.017071	 0.01105	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72139	 72142	 0.045164	 0.029236	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72140	 72141	 0.020821	 0.013479	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72143	 79378	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72143	 79378	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72144	 72145	 0.012171	 0.010014	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72145	 72146	 0.025621	 0.01815	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72146	 72147	 0.011371	 0.015493	 0.00034	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72146	 72154	 0.002514	 0.0181	 0.00059	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72146	 79380	 0.006421	 0.034493	 0.00082	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72147	 72151	 0.013257	 0.026243	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72148	 72149	 0.001736	 0.011186	 0.00036	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72148	 72150	 0.008779	 0.029293	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72148	 72154	 0.006857	 0.017371	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72149	 72151	 0.008543	 0.019836	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72150	 72154	 0.0177	 0.028393	 0.00052	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79209	 72150	 0.0092	 0.0494	 0.00117	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72152	 72153	 0.014086	 0.062779	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72152	 72153	 0.014086	 0.062779	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72152	 72225	 0.0162	 0.056729	 0.00157	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72152	 72225	 0.0162	 0.056729	 0.00157	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79210	 72153	 0.024621	 0.0506	 0.00096	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72154	 72155	 0.005971	 0.020914	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72154	 72155	 0.005971	 0.020914	 0.00058	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78823	 72155	 0.007007	 0.024536	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78824	 72155	 0.012471	 0.048507	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72156	 72157	 0.014286	 0.014029	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72156	 72158	 0.003979	 0.015536	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72156	 72158	 0.003979	 0.015536	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72156	 72185	 0.004121	 0.010921	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72158	 72159	 0.002543	 0.019821	 0.00037	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72158	 72160	 0.002014	 0.010714	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72158	 72193	 0.003271	 0.011443	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72158	 72193	 0.003271	 0.011443	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72158	 72197	 0.00615	 0.024014	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72158	 72197	 0.00615	 0.024014	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72159	 79379	 0.0016	 0.007664	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72160	 79379	 0.00235	 0.009321	 0.00026	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72161	 79379	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72161	 79379	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72161	 79386	 0.001014	 0.012036	 0.00419	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79379	 72162	 0.026571	 0.017207	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72163	 72211	 0.002393	 0.014486	 0.00045	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79379	 72163	 0.001629	 0.009771	 0.00024	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72164	 72168	 0.002164	 0.012964	 0.00031	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72165	 72167	 0.02285	 0.016186	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72166	 72170	 0.020507	 0.014529	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72167	 72168	 0.004829	 0.012421	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72167	 72170	 0.006829	 0.022771	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72168	 72172	 0.004086	 0.0159	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72169	 72216	 0.0021	 0.02015	 0.00586	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72169	 79380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72169	 79380	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72170	 72171	 0.00205	 0.006993	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72170	 79387	 0.013436	 0.059871	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72170	 79387	 0.013436	 0.059871	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72171	 72172	 0.001921	 0.007629	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72171	 72173	 0.005157	 0.010607	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72172	 72173	 0.003086	 0.01205	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79380	 72172	 0.002529	 0.01355	 0.00041	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72173	 72224	 0.001779	 0.012236	 0.00022	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72174	 72178	 0.019357	 0.012529	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72175	 72190	 0.015221	 0.009857	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72176	 72232	 0.024921	 0.016136	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72177	 72182	 0.049707	 0.032179	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72178	 72180	 0.022221	 0.014386	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72179	 72181	 0.021836	 0.015464	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72180	 72182	 0.022279	 0.014421	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72181	 72186	 0.003971	 0.0155	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72182	 72186	 0.003614	 0.01545	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72182	 72190	 0.003586	 0.019257	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72183	 72187	 0.007107	 0.030393	 0.00069	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72183	 72232	 0.0039	 0.019343	 0.00046	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72184	 72190	 0.041879	 0.0423	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72185	 72186	 0.00245	 0.014664	 0.00035	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72185	 79391	 0.00745	 0.063379	 0.00166	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72186	 72188	 0.015529	 0.011	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72186	 72190	 0.002943	 0.021193	 0.00069	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72187	 72189	 0.002407	 0.009229	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72189	 72192	 0.007543	 0.015493	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72189	 72193	 0.003057	 0.015171	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72190	 72191	 0.00085	 0.006136	 0.00016	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72190	 79391	 0.010379	 0.036343	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72190	 79391	 0.010379	 0.036343	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72191	 72192	 0.000793	 0.006593	 0.00012	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72192	 72196	 0.008086	 0.015036	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72192	 79382	 0.005614	 0.033636	 0.00081	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72193	 72194	 0.019471	 0.015414	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72193	 72197	 0.00195	 0.007457	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72193	 72206	 0.003293	 0.022379	 0.00056	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72195	 72206	 0.016079	 0.011393	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72196	 72197	 0.002629	 0.009214	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72196	 72197	 0.002629	 0.009214	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72196	 72198	 0.001193	 0.008636	 0.00016	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72196	 72206	 0.002393	 0.0106	 0.00032	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72198	 72203	 0.001114	 0.007107	 0.00017	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72199	 72200	 0.012593	 0.008921	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72199	 72203	 0.001314	 0.00795	 0.00025	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72199	 79381	 0.001307	 0.010857	 0.00026	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72201	 72204	 0.000807	 0.003986	 0.00116	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72201	 79381	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72201	 79381	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72201	 79383	 0.0015	 0.006014	 0.00151	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72202	 72208	 0.001457	 0.008279	 0.00026	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79381	 72202	 0.001193	 0.007207	 0.00023	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72204	 79382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72204	 79382	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72204	 79383	 0.001486	 0.008243	 0.00251	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72204	 79392	 0.000486	 0.005243	 0.0028	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79382	 72205	 0.015114	 0.010707	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72206	 72207	 0.001279	 0.007664	 0.00019	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72206	 72214	 0.002843	 0.013657	 0.00041	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72206	 79384	 0.010464	 0.040871	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72206	 79384	 0.010464	 0.040871	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72207	 72208	 0.001093	 0.007507	 0.00014	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72209	 79384	 0.015207	 0.012036	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72210	 72223	 9.3e-05	 0.001693	 0.00584	 1083.0	 1137.15	 1191.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72210	 72256	 0.0002	 0.003536	 0.01641	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72210	 79383	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79384	 72210	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72211	 72215	 0.001679	 0.012914	 0.00025	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72212	 72213	 0.004414	 0.011186	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72212	 72217	 0.003579	 0.012214	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72212	 72224	 0.0024	 0.015307	 0.00037	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72213	 79387	 0.006557	 0.021886	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72214	 72215	 0.000907	 0.007543	 0.00014	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72214	 79387	 0.0028	 0.013443	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79383	 72216	 0.000436	 0.004571	 0.00126	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72216	 79385	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72216	 79385	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72216	 79386	 0.000364	 0.004236	 0.00226	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72216	 79421	 0.001493	 0.019564	 0.00557	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72216	 79421	 0.001493	 0.019564	 0.00557	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72217	 72221	 0.002564	 0.009964	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72218	 72219	 0.002093	 0.010593	 0.00019	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72218	 72221	 0.003179	 0.012186	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79385	 72219	 0.002879	 0.014271	 0.00034	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72220	 72227	 0.003536	 0.0294	 0.00056	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72220	 72258	 0.00445	 0.017307	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79385	 72220	 0.006357	 0.024829	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79385	 72220	 0.006357	 0.024829	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72221	 79387	 0.007271	 0.016879	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72222	 79387	 0.010771	 0.007636	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72223	 79386	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79387	 72223	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79385	 72225	 0.018664	 0.072614	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72226	 72258	 0.010714	 0.032864	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79385	 72226	 0.011264	 0.02985	 0.00076	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72228	 72238	 0.013621	 0.060714	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72228	 72238	 0.013621	 0.060714	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72228	 79400	 0.011771	 0.045964	 0.00102	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72228	 79400	 0.011771	 0.045964	 0.00102	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72229	 72231	 0.019364	 0.013714	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72230	 72231	 0.030036	 0.019443	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72230	 72232	 0.012693	 0.012464	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72232	 72239	 0.004079	 0.018157	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72232	 72239	 0.004079	 0.018157	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72232	 79391	 0.009936	 0.029221	 0.0006	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72233	 72252	 0.018993	 0.012293	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72234	 72235	 0.022307	 0.014443	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72235	 72239	 0.017743	 0.017436	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72236	 72237	 0.000564	 0.003136	 0.00095	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72236	 72244	 0.000893	 0.005236	 0.00143	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72237	 72416	 0.005064	 0.030186	 0.00794	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72238	 72245	 0.009257	 0.036164	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72238	 72245	 0.009257	 0.036164	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72239	 72240	 0.0013	 0.007386	 0.00023	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72239	 79390	 0.003843	 0.024493	 0.0006	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72240	 72242	 0.003007	 0.013657	 0.00029	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72240	 72243	 0.00435	 0.015221	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72240	 72243	 0.00435	 0.015221	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72241	 72242	 0.001207	 0.00975	 0.00025	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72241	 79391	 0.001936	 0.013929	 0.00046	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72242	 72254	 0.002979	 0.0132	 0.0003	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72243	 79388	 0.004671	 0.016357	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72243	 79388	 0.004671	 0.016357	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72243	 79390	 0.002521	 0.009657	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72244	 72247	 0.000764	 0.003607	 0.00086	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72244	 79388	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72244	 79388	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79388	 72245	 0.004686	 0.0183	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79388	 72245	 0.004686	 0.0183	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72245	 79389	 0.001779	 0.01135	 0.00028	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72246	 79389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72246	 79389	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72247	 72248	 0.0006	 0.002193	 0.00067	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72247	 79390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72247	 79390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72248	 79392	 0.001529	 0.005814	 0.00163	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72249	 72250	 0.003357	 0.013107	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72249	 72250	 0.003357	 0.013107	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79389	 72249	 0.006364	 0.022271	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79389	 72249	 0.006364	 0.022271	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72250	 72262	 0.006886	 0.030679	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72250	 72262	 0.006886	 0.030679	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72251	 72252	 0.0228	 0.018043	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72252	 79391	 0.006671	 0.007264	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72253	 79391	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72253	 79391	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72253	 79392	 0.001386	 0.008321	 0.00252	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72254	 79393	 0.003557	 0.020236	 0.00036	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72255	 79393	 0.003421	 0.019436	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72255	 79422	 0.004479	 0.021507	 0.00064	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72256	 72507	 0.000314	 0.004371	 0.00845	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72256	 79392	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79393	 72256	 0.000298	 0.020873	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78210	 72257	 0.000893	 0.01455	 0.06703	 1083.0	 1137.15	 1191.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72257	 79394	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79395	 72257	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72258	 79422	 0.011807	 0.0526	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72258	 79422	 0.011807	 0.0526	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78167	 72259	 7.1e-05	 0.001171	 0.00035	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79392	 72259	 0.000529	 0.005864	 0.00294	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72259	 79396	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72259	 79396	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72260	 72278	 0.007536	 0.014014	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72260	 79400	 0.0149	 0.0277	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72261	 72262	 0.006157	 0.023957	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72261	 79400	 0.006557	 0.035221	 0.00084	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72262	 72265	 0.002179	 0.015686	 0.00051	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72263	 72264	 0.017029	 0.012057	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72264	 72282	 0.01125	 0.016864	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72264	 72291	 0.008	 0.012771	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72265	 72266	 0.001607	 0.012979	 0.00034	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72265	 79397	 0.007264	 0.02135	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72266	 72280	 0.003136	 0.012243	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72266	 79399	 0.008979	 0.035636	 0.00101	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72267	 72268	 0.000357	 0.004529	 0.0014	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72267	 72268	 0.000357	 0.004529	 0.0014	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79394	 72267	 0.0007	 0.008307	 0.00289	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79394	 72267	 0.0007	 0.008307	 0.00289	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72267	 79397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72267	 79397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72268	 72269	 0.000707	 0.009279	 0.00264	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72268	 72269	 0.000707	 0.009279	 0.00264	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72268	 72275	 0.006779	 0.022114	 0.00587	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72268	 79398	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72268	 79398	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72269	 79399	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72269	 79399	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72269	 79403	 0.002236	 0.028143	 0.00872	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72269	 79403	 0.002236	 0.028143	 0.00872	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72270	 72271	 0.001736	 0.007679	 0.00018	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79395	 72270	 0.006807	 0.034429	 0.0006	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72271	 72272	 0.005086	 0.019871	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72271	 72272	 0.005086	 0.019871	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79399	 72272	 0.008579	 0.030043	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79399	 72272	 0.008579	 0.030043	 0.00083	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79399	 72273	 0.006329	 0.016279	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72274	 72275	 0.000779	 0.003693	 0.00089	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72274	 72277	 0.001879	 0.007521	 0.00254	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72275	 79400	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72275	 79400	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72276	 72295	 0.031236	 0.020221	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72277	 79401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72277	 79401	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72278	 72279	 0.000829	 0.006679	 0.00017	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72278	 72280	 0.003564	 0.015893	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72279	 72283	 0.001086	 0.007829	 0.00026	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72281	 72282	 0.001457	 0.006236	 0.00014	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72281	 72283	 0.002414	 0.008457	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72281	 72283	 0.002414	 0.008457	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72281	 72298	 0.010886	 0.036307	 0.00058	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72282	 72289	 0.002743	 0.008071	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72284	 72285	 0.000771	 0.006593	 0.00017	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79398	 72284	 0.001464	 0.010514	 0.00034	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72285	 72286	 0.003693	 0.014429	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72285	 72286	 0.003693	 0.014429	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72285	 72287	 0.0066	 0.015321	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72286	 72288	 0.006443	 0.014793	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72286	 72290	 0.00225	 0.012807	 0.00039	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79399	 72287	 0.009193	 0.0171	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72288	 72311	 0.007929	 0.035343	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72288	 72311	 0.007929	 0.035343	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79399	 72288	 0.0042	 0.030329	 0.00057	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72289	 72292	 0.011714	 0.0083	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72289	 72298	 0.005107	 0.015664	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72290	 72301	 0.001921	 0.013043	 0.00032	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72291	 72296	 0.005593	 0.011443	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72293	 72294	 0.0237	 0.016793	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72294	 72295	 0.012407	 0.010214	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72294	 72296	 0.007493	 0.015393	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72294	 72297	 0.008271	 0.015379	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72294	 72307	 0.00585	 0.013279	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72294	 72308	 0.018886	 0.013379	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79401	 72294	 0.031729	 0.059	 0.00138	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72296	 72298	 0.0049	 0.0126	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72297	 72306	 0.003543	 0.006593	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72298	 72299	 0.00435	 0.009957	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72298	 79402	 0.003979	 0.03705	 0.00071	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72299	 72300	 0.002471	 0.006543	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72300	 72301	 0.0031	 0.010343	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72301	 72303	 0.005721	 0.022343	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72301	 72303	 0.005721	 0.022343	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72301	 72311	 0.003357	 0.016671	 0.0004	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72302	 72303	 0.005686	 0.012893	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72302	 72321	 0.009721	 0.017093	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72303	 79402	 0.005379	 0.023957	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72303	 79402	 0.005379	 0.023957	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72304	 79402	 0.009336	 0.006043	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72305	 79402	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72305	 79402	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72306	 72310	 0.003279	 0.008307	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72307	 72309	 0.003764	 0.011071	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72309	 72315	 0.018957	 0.025864	 0.00046	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72309	 72317	 0.027421	 0.0217	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72309	 72319	 0.003857	 0.015014	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72310	 72323	 0.006164	 0.017679	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72311	 72312	 0.006229	 0.021821	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72311	 72312	 0.006229	 0.021821	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72312	 79404	 0.008879	 0.034671	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72312	 79404	 0.008879	 0.034671	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72313	 79403	 0.000114	 0.009105	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72313	 79403	 0.000114	 0.009105	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79866	 72313	 0.00087	 0.0195	 1.648	 3949.0	 3949.0	 5153.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72314	 72316	 0.007686	 0.015793	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72314	 72330	 0.024864	 0.0161	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72314	 72332	 0.046164	 0.041364	 0.00084	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78280	 72314	 0.006364	 0.038121	 0.00091	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72315	 72316	 0.009757	 0.014221	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72317	 72318	 0.018236	 0.011807	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72318	 72333	 0.004893	 0.009686	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72319	 72323	 0.003021	 0.011743	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72320	 72335	 0.029107	 0.020621	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72321	 72323	 0.007029	 0.011214	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72322	 72323	 0.002943	 0.011486	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72322	 72323	 0.002943	 0.011486	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72322	 72355	 0.002243	 0.01	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72322	 72355	 0.002243	 0.01	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72323	 72335	 0.026043	 0.0263	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72324	 72476	 0.009514	 0.045657	 0.00136	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78280	 72324	 0.007936	 0.038093	 0.00114	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78280	 72325	 0.021971	 0.014221	 0.00027	 25.0	 25.0	 25.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72326	 72327	 0.01745	 0.015743	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72326	 72336	 0.006629	 0.013557	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78280	 72326	 0.012857	 0.050221	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72327	 72328	 0.005457	 0.00795	 0.00018	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72327	 72331	 0.008136	 0.014307	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72328	 72329	 0.009871	 0.015757	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78280	 72329	 0.005064	 0.0201	 0.00057	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72330	 72331	 0.0331	 0.021429	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72332	 72333	 0.007764	 0.017607	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72332	 72336	 0.012229	 0.027736	 0.00055	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72332	 72340	 0.027879	 0.025157	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72334	 72342	 0.027871	 0.022057	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72335	 72342	 0.008871	 0.01815	 0.00045	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72336	 72337	 0.010486	 0.016064	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72336	 72344	 0.006964	 0.017636	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72337	 72338	 0.004136	 0.008457	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72337	 72345	 0.006279	 0.014571	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72338	 72339	 0.003243	 0.008343	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72339	 72340	 0.004436	 0.007807	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72340	 72341	 0.007357	 0.007857	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72341	 72343	 0.006764	 0.0108	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72342	 72343	 0.005214	 0.0121	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72342	 72352	 0.007479	 0.021993	 0.00045	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72344	 72346	 0.009971	 0.015914	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72344	 72482	 0.011814	 0.050514	 0.00114	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72345	 72348	 0.006257	 0.01285	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72346	 72347	 0.004493	 0.00655	 0.00015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72347	 72349	 0.006214	 0.011557	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72348	 72349	 0.006136	 0.01425	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72348	 72352	 0.016429	 0.026221	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72349	 72351	 0.005643	 0.010493	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72349	 72370	 0.023971	 0.0256	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72350	 72352	 0.020807	 0.013471	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72351	 72376	 0.005807	 0.013279	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78212	 72352	 0.004529	 0.031107	 0.00056	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72353	 72354	 0.00315	 0.0123	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72353	 72354	 0.00315	 0.0123	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72354	 72355	 0.002829	 0.0126	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72354	 72355	 0.002829	 0.0126	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72355	 72356	 0.005986	 0.012579	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72356	 72357	 0.005686	 0.0132	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72357	 72505	 0.006557	 0.0166	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72357	 72506	 0.027293	 0.0216	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72358	 72359	 0.020743	 0.014693	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72358	 72363	 0.019243	 0.015229	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72360	 72361	 0.008043	 0.014143	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72361	 72363	 0.007579	 0.014093	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72362	 72363	 0.020779	 0.014721	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72363	 72367	 0.014043	 0.035571	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72364	 72367	 0.027436	 0.019436	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78211	 72365	 0.000829	 0.005036	 0.00126	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79403	 72365	 0.004493	 0.024157	 0.00594	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72365	 79405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72365	 79405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72366	 72369	 0.001907	 0.007643	 0.00193	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72366	 79406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72366	 79406	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72367	 72368	 0.00645	 0.01325	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79405	 72367	 0.007214	 0.024079	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79406	 72367	 0.0446	 0.044729	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78212	 72368	 0.011207	 0.022929	 0.00056	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72368	 79407	 0.014821	 0.013279	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78211	 72369	 0.0009	 0.007257	 0.00204	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72369	 79407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72369	 79407	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72370	 72372	 0.010514	 0.015764	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72371	 72375	 0.005843	 0.012014	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72371	 72482	 0.027793	 0.064521	 0.00096	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72372	 72373	 0.011757	 0.0093	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72372	 72376	 0.020764	 0.020393	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72372	 72504	 0.00635	 0.0144	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72374	 72375	 0.009043	 0.008164	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72374	 79408	 0.010771	 0.020036	 0.00047	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72375	 72504	 0.004021	 0.011536	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72375	 79408	 0.016986	 0.029864	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72375	 79410	 0.017186	 0.031957	 0.00075	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72376	 72377	 0.0202	 0.013079	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72376	 79424	 0.004057	 0.014214	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72378	 72380	 0.00175	 0.009107	 0.00268	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78211	 72378	 0.002636	 0.011471	 0.00327	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72378	 79408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72378	 79408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78210	 72379	 0.000321	 0.002236	 0.0038	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72379	 79409	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72379	 79409	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72380	 72483	 0.0017	 0.013379	 0.00391	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72380	 79410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72380	 79410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79408	 72381	 0.021129	 0.019057	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79410	 72381	 0.021007	 0.018821	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72382	 72389	 0.005671	 0.021736	 0.00061	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79410	 72382	 0.005593	 0.034386	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72383	 72384	 0.024614	 0.017436	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72384	 72385	 0.018321	 0.011864	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72384	 72386	 0.008943	 0.023	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72384	 72389	 0.03275	 0.026957	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72384	 72392	 0.029321	 0.018979	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79409	 72384	 0.007064	 0.027593	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72386	 72393	 0.022586	 0.041993	 0.00099	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72387	 72388	 0.026357	 0.017064	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79407	 72387	 0.051686	 0.033457	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72389	 72390	 0.025164	 0.017829	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72389	 72394	 0.012893	 0.023971	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72390	 72391	 0.02615	 0.018521	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72391	 72392	 0.025521	 0.018079	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72393	 72398	 0.022293	 0.039207	 0.00074	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72394	 72395	 0.01795	 0.033379	 0.00078	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72395	 72399	 0.017779	 0.028371	 0.00065	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72397	 72398	 0.006129	 0.020936	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72397	 72401	 0.004857	 0.017014	 0.00047	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72398	 72399	 0.011579	 0.022693	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72399	 72403	 0.018879	 0.0388	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79409	 72399	 0.052664	 0.119471	 0.00239	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72401	 72402	 0.005457	 0.012479	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72402	 72403	 0.005814	 0.014786	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78593	 72404	 0.249393	 0.398743	 0.0092	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79122	 72405	 0.053129	 0.186064	 0.00515	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79122	 72405	 0.053129	 0.186064	 0.00515	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72405	 79411	 0.025864	 0.115264	 0.00196	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72405	 79411	 0.025864	 0.115264	 0.00196	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72406	 79411	 0.096314	 0.062357	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72407	 72413	 0.003864	 0.030429	 0.0089	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72407	 72415	 0.003957	 0.023736	 0.00719	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72407	 79411	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72407	 79411	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72408	 72433	 0.05265	 0.0475	 0.00079	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72408	 79413	 0.013071	 0.058243	 0.00099	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72408	 79414	 0.06155	 0.155921	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72408	 79415	 0.012286	 0.065986	 0.00156	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72408	 79416	 0.020493	 0.032707	 0.00075	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72409	 72410	 0.000714	 0.007086	 0.00193	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72409	 72413	 0.000907	 0.007764	 0.00221	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72409	 79412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72409	 79412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72410	 72411	 0.000986	 0.010386	 0.00281	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72411	 72512	 0.001536	 0.008993	 0.00245	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78201	 72411	 0.001157	 0.011479	 0.00312	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72411	 79413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72411	 79413	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78201	 72412	 0.0112	 0.038429	 0.00921	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72412	 79414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72412	 79414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72413	 79415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72413	 79415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72414	 72441	 0.012121	 0.060136	 0.00144	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79411	 72414	 0.023271	 0.0909	 0.00201	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79411	 72414	 0.023271	 0.0909	 0.00201	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79415	 72414	 0.014707	 0.062886	 0.00142	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72415	 72416	 0.005157	 0.030193	 0.00822	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72417	 72419	 0.028857	 0.020443	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72418	 72419	 0.02785	 0.022043	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72418	 72497	 0.084964	 0.060186	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72418	 72498	 0.022029	 0.043614	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72419	 72496	 0.0179	 0.079307	 0.00238	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72419	 72497	 0.107914	 0.085407	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72419	 72498	 0.007636	 0.020236	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72419	 79419	 0.007421	 0.04445	 0.00107	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72420	 79417	 0.0434	 0.047736	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72421	 72422	 0.060914	 0.083107	 0.00149	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72421	 72480	 0.0331	 0.113079	 0.00246	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72421	 79420	 0.0443	 0.172379	 0.00288	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72422	 72423	 0.019421	 0.035043	 0.00051	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72423	 72424	 0.013264	 0.0308	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72424	 72425	 0.088879	 0.057543	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72424	 72428	 0.016093	 0.033071	 0.00063	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72424	 79418	 0.049879	 0.058464	 0.00101	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72426	 72427	 0.037086	 0.02935	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72427	 72428	 0.017286	 0.027586	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72428	 72429	 0.007057	 0.02165	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72428	 72430	 0.039636	 0.025664	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72429	 72500	 0.011436	 0.040036	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72430	 72439	 0.039507	 0.025579	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72431	 72433	 0.027829	 0.022029	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72431	 72439	 0.036064	 0.02335	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72432	 72458	 0.0032	 0.012436	 0.00332	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72432	 72512	 0.004207	 0.0218	 0.00532	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72432	 79416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72432	 79416	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72434	 72435	 0.003829	 0.014729	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72434	 72441	 0.009929	 0.033107	 0.00052	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72435	 72437	 0.006357	 0.016093	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72435	 72442	 0.04335	 0.028064	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72436	 72437	 0.024021	 0.017014	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72436	 72438	 0.016857	 0.029643	 0.00056	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72436	 72457	 0.024229	 0.015686	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79416	 72437	 0.004329	 0.025936	 0.00062	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79416	 72438	 0.014764	 0.022143	 0.0004	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72438	 79418	 0.042414	 0.030043	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79416	 72439	 0.010664	 0.036429	 0.00079	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72440	 79418	 0.0384	 0.024857	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72441	 72448	 0.013236	 0.024614	 0.00058	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79412	 72441	 0.035564	 0.073093	 0.00139	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72442	 72457	 0.031864	 0.02855	 0.00059	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72443	 72444	 0.015657	 0.027536	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72443	 72447	 0.009171	 0.028136	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72443	 79418	 0.005986	 0.023364	 0.00052	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72444	 79417	 0.024114	 0.02575	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72445	 72452	 0.003486	 0.009786	 0.00252	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72445	 72458	 0.004336	 0.017343	 0.00437	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72445	 79417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72445	 79417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72446	 72447	 0.020143	 0.02035	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79417	 72446	 0.026121	 0.032429	 0.00071	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72447	 72448	 0.012443	 0.023136	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72447	 72450	 0.017021	 0.030586	 0.00055	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72448	 72450	 0.026671	 0.0262	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72449	 72450	 0.022743	 0.052007	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78363	 72449	 0.04865	 0.099979	 0.00191	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72451	 72452	 0.001843	 0.004736	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72451	 72455	 0.002936	 0.007886	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72453	 72454	 0.027757	 0.019664	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79417	 72453	 0.029929	 0.0294	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72455	 72456	 0.004164	 0.010814	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72457	 79418	 0.014957	 0.023879	 0.00055	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78201	 72458	 0.00535	 0.032114	 0.00973	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72458	 79418	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72458	 79418	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72459	 72502	 0.012457	 0.18855	 0.11159	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76824	 72459	 0.011714	 0.185514	 0.09972	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77742	 72459	 0.024371	 0.303429	 0.09947	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77742	 72459	 0.024371	 0.303429	 0.09947	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78373	 72459	 0.023107	 0.29865	 0.09034	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78373	 72459	 0.023107	 0.29865	 0.09034	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72460	 72461	 0.013343	 0.137314	 0.04356	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78250	 72460	 0.0195	 0.194129	 0.05306	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72462	 72463	 0.100836	 0.071429	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72463	 72464	 0.028821	 0.053593	 0.00126	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72463	 72473	 0.218714	 0.141657	 0.00269	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72464	 72465	 0.0274	 0.062671	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72464	 72469	 0.041129	 0.072329	 0.00136	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72464	 72471	 0.17185	 0.340486	 0.005	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72465	 72468	 0.025936	 0.068736	 0.00174	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72466	 72471	 0.044807	 0.040421	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72466	 72472	 0.071364	 0.05055	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72467	 72469	 0.155229	 0.112236	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72469	 72470	 0.105007	 0.074386	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72474	 72492	 0.248271	 0.160814	 0.00306	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72475	 79423	 0.052243	 0.279757	 0.00849	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78363	 72476	 0.007229	 0.043293	 0.00104	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72477	 72478	 0.006471	 0.01715	 0.00044	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72477	 72482	 0.023	 0.058257	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78363	 72478	 0.02285	 0.067207	 0.00138	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72479	 72480	 0.011543	 0.045079	 0.001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72479	 72481	 0.005743	 0.022429	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78363	 72480	 0.183014	 0.118521	 0.00226	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72481	 72482	 0.011271	 0.034579	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72483	 72484	 0.003057	 0.024557	 0.0069	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72484	 72489	 0.004079	 0.031807	 0.00951	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72485	 72486	 0.011164	 0.025921	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72485	 72487	 0.037629	 0.02665	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72485	 72490	 0.017986	 0.028857	 0.00054	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72485	 79420	 0.029721	 0.167036	 0.00309	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72486	 72493	 0.048129	 0.111743	 0.00166	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72487	 72488	 0.026786	 0.017343	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72489	 72501	 0.003364	 0.027929	 0.00735	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72490	 72491	 0.036107	 0.025579	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72490	 72492	 0.130757	 0.103493	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72494	 72497	 0.103336	 0.212429	 0.00405	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78240	 72494	 0.004836	 0.031193	 0.00099	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72495	 72496	 0.034571	 0.12105	 0.00335	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72495	 72500	 0.042621	 0.125343	 0.00257	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72498	 79419	 0.00735	 0.041293	 0.00076	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78250	 72499	 0.005364	 0.025586	 0.00741	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78373	 72499	 0.003057	 0.02925	 0.00964	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72499	 79419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72499	 79419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78202	 72500	 0.045071	 0.127907	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72501	 72502	 0.0048	 0.060407	 0.01872	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72501	 79420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72501	 79420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78201	 72502	 0.01125	 0.090429	 0.02544	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78250	 72502	 0.016829	 0.065486	 0.0175	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79405	 72505	 0.005386	 0.0251	 0.00058	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72507	 79421	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79422	 72507	 0.000417	 0.033397	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78373	 72508	 0.039	 0.156471	 0.03954	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72509	 79423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72509	 79423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76898	 72510	 0.023857	 0.044357	 0.00104	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78372	 72510	 0.076229	 0.156043	 0.00384	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79423	 72510	 0.64935	 0.6583	 0.00873	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78211	 72511	 0.000864	 0.004486	 0.00118	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72511	 79424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72511	 79424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78201	 72512	 0.000236	 0.003021	 0.0009	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72513	 72514	 0.017086	 0.012107	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72514	 72515	 0.005307	 0.009536	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72514	 72517	 0.003864	 0.007907	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72514	 72716	 0.016179	 0.010471	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72515	 72622	 0.00655	 0.009821	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72516	 72517	 0.002429	 0.008286	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72516	 72621	 0.005421	 0.00865	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72517	 72519	 0.004171	 0.009464	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72517	 72716	 0.009886	 0.017386	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72517	 79451	 0.012021	 0.027486	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72518	 72519	 0.003071	 0.007021	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72518	 79427	 0.002986	 0.00995	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72519	 72520	 0.00415	 0.007721	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72520	 79425	 0.009721	 0.008771	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72521	 72522	 0.000786	 0.002071	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72521	 72617	 0.001671	 0.004543	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72521	 79425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72521	 79425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72522	 72523	 0.000943	 0.002364	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72522	 79426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72522	 79426	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72523	 72713	 0.003379	 0.007843	 0.00239	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72523	 79427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72523	 79427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72523	 79450	 0.001014	 0.004136	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72524	 72525	 0.011879	 0.007693	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72524	 72532	 0.011686	 0.0137	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79427	 72524	 0.013864	 0.009821	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72524	 79451	 0.00425	 0.009643	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72525	 79428	 0.010014	 0.007093	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72526	 72527	 0.0008	 0.002107	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72526	 79428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72526	 79428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72526	 79450	 0.001936	 0.00665	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72527	 72604	 0.0011	 0.002986	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72528	 72529	 0.013907	 0.009	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72528	 72540	 0.012371	 0.008764	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72528	 79433	 0.038921	 0.0252	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72529	 72530	 0.009864	 0.006386	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72529	 72531	 0.017721	 0.01255	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72529	 72540	 0.0117	 0.007571	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79428	 72529	 0.003993	 0.008171	 0.0002	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72531	 72532	 0.008507	 0.007007	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72533	 72535	 0.009414	 0.012843	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72533	 72555	 0.022571	 0.020364	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72534	 72538	 0.008414	 0.007543	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72534	 72556	 0.0057	 0.007771	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72535	 72537	 0.011157	 0.007221	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72536	 72537	 0.004979	 0.006793	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72536	 72540	 0.009479	 0.006136	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72537	 72539	 0.004907	 0.007871	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72537	 72541	 0.009029	 0.005843	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72538	 72539	 0.008079	 0.005721	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72538	 72549	 0.010029	 0.006493	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72539	 72544	 0.012336	 0.007986	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72539	 72547	 0.011886	 0.024321	 0.0006	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72539	 72549	 0.009386	 0.00665	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72540	 72542	 0.01365	 0.008836	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72542	 72545	 0.018179	 0.014386	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72542	 72603	 0.021843	 0.017286	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72543	 72590	 0.018329	 0.012986	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72543	 72603	 0.015614	 0.011057	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72544	 72545	 0.008657	 0.01015	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72544	 72551	 0.0074	 0.006093	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72545	 72590	 0.017671	 0.012514	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72546	 72547	 0.006571	 0.010486	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72546	 72550	 0.005271	 0.008407	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72546	 72557	 0.006407	 0.011271	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72547	 72553	 0.011086	 0.007179	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72547	 72554	 0.010043	 0.016029	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72547	 72559	 0.005036	 0.009371	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72547	 79461	 0.004107	 0.024614	 0.00059	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72548	 72554	 0.015571	 0.010079	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72550	 72552	 0.006736	 0.009179	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72551	 72552	 0.005393	 0.004864	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72555	 72556	 0.007093	 0.011321	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72555	 72560	 0.00515	 0.0176	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72555	 72741	 0.009457	 0.012893	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72555	 72744	 0.006479	 0.01205	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72557	 72560	 0.014521	 0.01195	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72558	 72559	 0.017736	 0.012564	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72558	 72560	 0.018721	 0.014679	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72559	 72863	 0.004286	 0.008771	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72560	 72561	 0.006636	 0.011671	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72560	 72867	 0.013679	 0.03465	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72561	 72866	 0.004964	 0.010157	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72562	 72563	 0.02715	 0.019236	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72563	 72564	 0.00545	 0.01115	 0.00027	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72563	 79460	 0.005493	 0.012457	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72564	 72572	 0.003293	 0.007471	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72565	 72571	 0.004464	 0.007129	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72565	 72588	 0.018179	 0.011771	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72565	 72589	 0.013736	 0.009729	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72566	 72572	 0.007014	 0.014364	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72566	 72574	 0.011721	 0.007586	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72566	 72575	 0.020271	 0.014357	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72566	 79460	 0.006936	 0.023129	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72567	 72568	 0.01145	 0.008107	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72568	 72569	 0.005993	 0.007021	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72568	 72585	 0.007286	 0.014429	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72568	 72854	 0.011521	 0.015707	 0.00035	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72569	 72854	 0.005857	 0.00935	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72570	 72573	 0.013936	 0.009871	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72570	 72576	 0.0151	 0.0107	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72571	 72572	 0.003621	 0.008286	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72571	 72788	 0.007457	 0.015321	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72572	 72573	 0.015821	 0.010243	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72575	 72584	 0.015021	 0.009721	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72576	 72581	 0.0301	 0.021321	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72577	 72578	 0.020436	 0.018436	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72577	 72582	 0.011221	 0.011029	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72577	 72583	 0.0149	 0.009643	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72577	 72793	 0.0073	 0.011657	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72578	 72796	 0.015321	 0.020136	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72578	 72837	 0.014621	 0.037586	 0.00058	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72579	 72581	 0.007879	 0.013857	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72579	 72836	 0.014836	 0.030357	 0.00075	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72580	 72581	 0.005307	 0.007957	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72580	 72582	 0.007643	 0.008157	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72581	 72584	 0.004193	 0.0078	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72584	 72585	 0.006514	 0.01145	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72586	 72588	 0.017057	 0.012329	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72586	 72589	 0.017907	 0.011593	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72586	 72594	 0.017136	 0.011093	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72586	 72596	 0.0087	 0.010793	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72587	 72787	 0.014429	 0.010221	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72588	 72592	 0.012664	 0.010021	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72590	 72591	 0.015157	 0.016186	 0.00034	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72590	 72592	 0.013779	 0.013921	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72590	 79461	 0.021836	 0.049943	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72591	 72593	 0.014721	 0.010429	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72593	 72594	 0.012107	 0.007836	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72594	 72595	 0.005379	 0.009707	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72595	 72596	 0.003979	 0.0074	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72595	 72600	 0.0122	 0.012236	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78289	 72595	 0.003107	 0.012121	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72596	 72597	 0.007164	 0.006421	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72597	 72786	 0.00785	 0.00855	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72598	 72600	 0.005607	 0.010429	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78289	 72598	 0.002336	 0.007793	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72599	 72600	 0.010843	 0.008579	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72599	 72601	 0.008457	 0.005471	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72600	 79429	 0.029193	 0.023107	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72601	 79429	 0.007207	 0.007079	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72602	 72605	 0.001057	 0.00265	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72602	 72612	 0.002521	 0.006864	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72602	 72860	 0.006243	 0.021414	 0.00513	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78288	 72602	 0.004	 0.010886	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72602	 79429	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72602	 79429	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79429	 72603	 0.02695	 0.019086	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72603	 79430	 0.016693	 0.013086	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72604	 72605	 0.001221	 0.00295	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72604	 79430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72604	 79430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72606	 72609	 0.014829	 0.0096	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72606	 72616	 0.015771	 0.012486	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79429	 72606	 0.004857	 0.008543	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72607	 72608	 0.010986	 0.008693	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72607	 72616	 0.014679	 0.009507	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72608	 72609	 0.005514	 0.005886	 0.00012	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72608	 79432	 0.009957	 0.008193	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72609	 79431	 0.010021	 0.013657	 0.0003	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72610	 79431	 0.011814	 0.008371	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72611	 72727	 0.001236	 0.008657	 0.01474	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72611	 79431	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72611	 79431	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72612	 79432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72612	 79432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72613	 72614	 0.001471	 0.00835	 0.00015	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79432	 72613	 0.002036	 0.009779	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72613	 79433	 0.006171	 0.015636	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72614	 72615	 0.001943	 0.006807	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72614	 72618	 0.006979	 0.011636	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72615	 72780	 0.005357	 0.0183	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72616	 79433	 0.010143	 0.006564	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78288	 72617	 0.006129	 0.01575	 0.0039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72617	 79433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72617	 79433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72618	 72619	 0.010936	 0.0079	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72618	 72620	 0.006957	 0.004929	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72619	 72620	 0.0112	 0.007929	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72619	 72622	 0.019086	 0.0138	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72619	 72623	 0.007771	 0.017621	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79431	 72619	 0.009486	 0.033221	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72620	 72621	 0.004857	 0.007286	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72623	 72624	 0.004757	 0.009729	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72624	 72626	 0.005293	 0.010479	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72625	 72626	 0.003979	 0.007393	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72625	 72722	 0.018221	 0.02395	 0.00033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72625	 79451	 0.019593	 0.057607	 0.00118	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72626	 72628	 0.003843	 0.011293	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72627	 72628	 0.004514	 0.009229	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72627	 72635	 0.005464	 0.011229	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72628	 72629	 0.01245	 0.00985	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72630	 72634	 0.01345	 0.008707	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72630	 73133	 0.016014	 0.016179	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72631	 72632	 0.017786	 0.011514	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72631	 72751	 0.014043	 0.016457	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72633	 72634	 0.01235	 0.009679	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72633	 72637	 0.011329	 0.007336	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72635	 72636	 0.004664	 0.010829	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72636	 72637	 0.003279	 0.006736	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72637	 73133	 0.045557	 0.03605	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72638	 72640	 0.021071	 0.021136	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72638	 72722	 0.008186	 0.01675	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72639	 72640	 0.0056	 0.00505	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72639	 72644	 0.013343	 0.00945	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72641	 72644	 0.005614	 0.016507	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72641	 72653	 0.016929	 0.016936	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72641	 72701	 0.009771	 0.017564	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72641	 72718	 0.01075	 0.021064	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72641	 79448	 0.016921	 0.051907	 0.00141	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72642	 72644	 0.007757	 0.006386	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72642	 72647	 0.009957	 0.007057	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72643	 72646	 0.006264	 0.005771	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72643	 72648	 0.008664	 0.005607	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72644	 72645	 0.010214	 0.007236	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72644	 72646	 0.003714	 0.007593	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72646	 72649	 0.026786	 0.017343	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72648	 72649	 0.010993	 0.007121	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72649	 72659	 0.019936	 0.016407	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72650	 72651	 0.018307	 0.018486	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72650	 72652	 0.006679	 0.010657	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72651	 72659	 0.015286	 0.010829	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72652	 72654	 0.023314	 0.015093	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78360	 72652	 0.011957	 0.040843	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72653	 72699	 0.0197	 0.01765	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72655	 72672	 0.001607	 0.006314	 0.00165	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72655	 72673	 0.00225	 0.007329	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72655	 72674	 0.001693	 0.004543	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72656	 72657	 0.021486	 0.013914	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72656	 72694	 0.021221	 0.016793	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72656	 72699	 0.025093	 0.019857	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72657	 72675	 0.018693	 0.012107	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72657	 72700	 0.014586	 0.017093	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72657	 79438	 0.010529	 0.018521	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72658	 72699	 0.031779	 0.022514	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78360	 72660	 0.021043	 0.02125	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72661	 72694	 0.011929	 0.00845	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72662	 72665	 0.0012	 0.004007	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72662	 72970	 0.001357	 0.004243	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72663	 72665	 0.002286	 0.006614	 0.00159	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72663	 72972	 0.002536	 0.008264	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72663	 79434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72663	 79434	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72664	 73134	 0.036136	 0.0256	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79434	 72664	 0.032893	 0.027079	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72665	 72667	 0.000707	 0.002821	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72665	 72672	 0.002979	 0.011921	 0.003	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72665	 79435	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72665	 79435	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72665	 79477	 0.0099	 0.035214	 0.00784	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79434	 72666	 0.016814	 0.020879	 0.00046	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79435	 72666	 0.022821	 0.016164	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72666	 79437	 0.035743	 0.060207	 0.00086	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72667	 72668	 0.001471	 0.005343	 0.00164	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72668	 72678	 0.001593	 0.006364	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72669	 72937	 0.00335	 0.008414	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72669	 72944	 0.0025	 0.006429	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72669	 79436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72669	 79436	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72670	 72941	 0.031507	 0.0204	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79436	 72670	 0.019129	 0.012386	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79436	 72671	 0.022721	 0.016093	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72672	 79437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72672	 79437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72673	 72674	 0.000964	 0.0033	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72673	 79438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72673	 79438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72673	 79442	 0.002971	 0.012921	 0.00368	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72674	 79439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72674	 79439	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72675	 72695	 0.008557	 0.005543	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79438	 72676	 0.018521	 0.011993	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72677	 72703	 0.003843	 0.010186	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79438	 72677	 0.012436	 0.021864	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72678	 79440	 0.001771	 0.007207	 0.00176	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72679	 72681	 0.01645	 0.01065	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72680	 72683	 0.021286	 0.013779	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72681	 72683	 0.00325	 0.010843	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72681	 72684	 0.008371	 0.014721	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72681	 72688	 0.005814	 0.010493	 0.00015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72682	 79440	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79441	 72682	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79441	 72683	 0.006786	 0.023179	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72684	 72685	 0.0054	 0.007364	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72684	 72687	 0.012693	 0.013957	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72684	 72688	 0.010407	 0.008236	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72685	 72697	 0.011543	 0.013536	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72686	 72687	 0.021421	 0.013871	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72686	 72945	 0.01525	 0.018257	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72686	 72950	 0.019293	 0.012493	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72687	 72691	 0.020271	 0.014357	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72688	 72689	 0.007193	 0.006493	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72689	 72690	 0.010843	 0.007021	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72690	 72692	 0.010036	 0.013064	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72691	 72692	 0.00865	 0.0126	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72691	 72936	 0.013457	 0.017679	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79441	 72692	 0.0103	 0.0316	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72693	 72694	 0.014629	 0.011579	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78360	 72693	 0.012814	 0.008293	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72694	 72695	 0.017686	 0.013014	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72695	 72696	 0.010864	 0.007029	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78360	 72695	 0.02665	 0.018879	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79439	 72695	 0.00625	 0.008521	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72697	 72698	 0.010343	 0.014107	 0.00025	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79436	 72698	 0.013921	 0.020871	 0.00038	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72699	 72700	 0.012229	 0.018736	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72700	 79443	 0.010129	 0.029786	 0.00061	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72701	 72702	 0.007	 0.014321	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72702	 79443	 0.008357	 0.018964	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72703	 72704	 0.002479	 0.009679	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72704	 79443	 0.003286	 0.010086	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72705	 79442	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79443	 72705	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72706	 72707	 0.000157	 0.001093	 0.00186	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72706	 79444	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72706	 79444	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72707	 79445	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79446	 72707	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72708	 79447	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72708	 79447	 0.003027	 0.10896	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72709	 72710	 0.013521	 0.008757	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72709	 72711	 0.03295	 0.023343	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72709	 72719	 0.003771	 0.00855	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79443	 72709	 0.004436	 0.017593	 0.0005	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72711	 72714	 0.015393	 0.016929	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79446	 72712	 0.011764	 0.011557	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72712	 79448	 0.014671	 0.012071	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79445	 72713	 0.002307	 0.0062	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72713	 79448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72713	 79448	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72713	 79450	 0.001479	 0.005393	 0.00165	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72714	 72715	 0.002164	 0.009579	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79448	 72714	 0.002414	 0.008443	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72715	 72716	 0.0037	 0.0098	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72715	 72717	 0.0123	 0.009736	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72716	 72721	 0.009886	 0.025421	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72716	 72723	 0.015414	 0.009979	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72718	 72719	 0.003471	 0.007879	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72718	 72720	 0.007164	 0.013314	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72720	 72721	 0.004807	 0.007679	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72721	 72722	 0.002486	 0.007636	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72724	 72725	 0.00175	 0.004764	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79445	 72724	 0.001721	 0.004143	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72724	 79449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72724	 79449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72725	 79450	 0.001264	 0.003864	 0.00084	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72726	 72729	 0.019914	 0.015764	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79449	 72726	 0.016407	 0.011621	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72727	 79450	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79451	 72727	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72727	 79463	 0.001636	 0.015536	 0.02761	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72728	 72729	 0.017614	 0.0114	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72728	 72740	 0.031386	 0.024843	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79448	 72728	 0.038414	 0.027214	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72729	 72736	 0.025257	 0.020786	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72729	 72738	 0.016464	 0.011664	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72730	 72731	 0.006829	 0.031843	 0.00074	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72730	 72936	 0.013543	 0.039829	 0.00081	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78303	 72730	 0.011857	 0.046129	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72731	 72736	 0.012093	 0.027657	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72731	 72737	 0.011086	 0.018171	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72732	 72912	 0.013064	 0.057864	 0.00132	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72732	 72949	 0.011721	 0.051936	 0.00156	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72733	 72735	 0.011579	 0.021536	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72733	 72904	 0.046207	 0.045393	 0.00076	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72734	 72736	 0.031336	 0.020286	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72735	 72743	 0.020186	 0.016614	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72736	 72738	 0.004529	 0.009271	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72736	 72741	 0.015493	 0.021136	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72736	 79465	 0.02135	 0.113779	 0.00199	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72737	 72738	 0.00815	 0.014329	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72739	 72741	 0.004536	 0.012014	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72739	 72742	 0.002764	 0.009457	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72740	 72741	 0.008843	 0.0149	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72742	 72744	 0.010029	 0.010707	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72742	 72745	 0.004929	 0.01925	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72743	 72745	 0.023557	 0.019393	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72745	 79452	 0.005414	 0.029093	 0.00069	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72746	 72749	 0.028157	 0.018229	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72746	 72868	 0.0034	 0.010421	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72746	 79452	 0.003129	 0.013993	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72747	 72895	 0.001536	 0.007057	 0.00181	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78315	 72747	 0.009171	 0.039907	 0.01137	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72747	 79452	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72747	 79452	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79452	 72748	 0.018914	 0.0134	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72751	 73133	 0.006371	 0.011207	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72752	 72758	 0.006914	 0.007386	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72753	 72754	 0.017021	 0.012057	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72753	 72758	 0.014593	 0.00945	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72754	 72755	 0.004314	 0.008543	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72754	 72758	 0.014321	 0.009271	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72755	 72756	 0.028386	 0.022464	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72755	 72758	 0.012786	 0.015871	 0.00034	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72755	 72759	 0.013271	 0.008593	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72755	 72760	 0.014207	 0.010064	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72755	 79453	 0.013171	 0.05225	 0.00149	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72757	 72758	 0.002579	 0.006836	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72757	 72765	 0.003929	 0.008979	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72758	 72818	 0.006621	 0.012314	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72759	 72769	 0.011893	 0.0077	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78190	 72761	 0.004557	 0.014243	 0.00413	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72761	 79453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72761	 79453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72761	 79458	 0.003079	 0.008264	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72762	 79454	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72762	 79454	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72763	 72776	 0.011857	 0.0139	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72763	 72807	 0.02475	 0.025	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72763	 72811	 0.003679	 0.012879	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72764	 72768	 0.012529	 0.008871	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72765	 72766	 0.007964	 0.012714	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72765	 72768	 0.006929	 0.014243	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72765	 72770	 0.006986	 0.008186	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72765	 72771	 0.067729	 0.0536	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78307	 72765	 0.018657	 0.100193	 0.00238	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72766	 72811	 0.010893	 0.014864	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72767	 72770	 0.035421	 0.025093	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72768	 72774	 0.00985	 0.017771	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72772	 72774	 0.0127	 0.009	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72772	 72775	 0.021957	 0.017379	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72773	 72774	 0.007707	 0.006907	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72773	 72776	 0.010179	 0.010279	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72776	 72777	 0.039957	 0.028307	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72778	 72779	 0.004471	 0.012686	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72778	 72781	 0.010064	 0.006514	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72778	 73136	 0.006764	 0.00535	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72779	 72780	 0.002429	 0.006443	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79431	 72782	 0.012379	 0.047429	 0.00134	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72783	 72784	 0.012486	 0.008843	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72783	 72785	 0.008564	 0.008407	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72783	 72791	 0.011793	 0.00835	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72783	 72793	 0.029921	 0.019371	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72784	 72797	 0.012914	 0.008357	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72785	 72787	 0.0062	 0.010907	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72785	 72788	 0.031536	 0.020414	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72785	 72789	 0.027407	 0.021693	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72785	 73138	 0.016579	 0.011743	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72785	 79496	 0.007579	 0.017186	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72786	 72787	 0.003657	 0.008493	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78289	 72786	 0.004364	 0.013393	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72788	 72789	 0.008564	 0.00705	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72789	 72790	 0.007079	 0.004579	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72792	 72793	 0.012164	 0.008614	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72794	 72796	 0.014693	 0.011629	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72794	 72798	 0.001357	 0.007243	 0.00013	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72794	 72803	 0.002279	 0.008893	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72795	 72796	 0.013957	 0.011043	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72797	 72798	 0.006179	 0.009914	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72798	 72799	 0.007714	 0.012993	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72798	 72802	 0.014914	 0.009657	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72798	 79496	 0.01625	 0.025943	 0.0006	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72799	 72800	 0.020571	 0.016279	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72801	 72805	 0.006764	 0.012579	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72801	 72807	 0.009829	 0.017286	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72801	 79496	 0.017286	 0.035364	 0.00087	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72803	 72804	 0.010157	 0.0091	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72803	 72825	 0.002514	 0.011714	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	72804	 72806	 0.017571	 0.01245	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72805	 72806	 0.004079	 0.012507	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72806	 72808	 0.017586	 0.012457	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72806	 72809	 0.005014	 0.011643	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72806	 72826	 0.013357	 0.030307	 0.00061	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72809	 72810	 0.002886	 0.009529	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72811	 72812	 0.014921	 0.009657	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72813	 72814	 0.004314	 0.008871	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72813	 72819	 0.006243	 0.014279	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72813	 72825	 0.003471	 0.011857	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72814	 72815	 0.003964	 0.008143	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72815	 79455	 0.004507	 0.009271	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72816	 79455	 0.002807	 0.009593	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72816	 79457	 0.001657	 0.006464	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72817	 72822	 0.001064	 0.003879	 0.00119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72817	 73137	 0.006864	 0.022386	 0.00594	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72817	 79455	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72817	 79455	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79455	 72818	 0.001229	 0.0059	 0.00018	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72819	 72830	 0.010993	 0.020443	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72819	 79457	 0.004229	 0.014814	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72820	 79456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72820	 79456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72820	 79458	 0.001543	 0.005879	 0.00164	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72821	 72832	 0.017786	 0.031286	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72821	 72834	 0.011136	 0.017771	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72821	 79459	 0.003536	 0.024279	 0.00044	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72822	 79457	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72822	 79457	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72822	 79458	 0.002393	 0.010121	 0.00228	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72823	 79458	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72823	 79458	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72823	 79463	 0.003279	 0.02235	 0.04026	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78190	 72824	 0.002821	 0.012586	 0.00342	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79458	 72824	 0.004436	 0.011407	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72824	 79459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72824	 79459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72825	 72826	 0.013829	 0.017164	 0.00037	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79456	 72826	 0.006093	 0.03465	 0.00063	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72827	 72833	 0.024871	 0.024436	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72827	 72835	 0.023121	 0.040664	 0.00076	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72827	 72850	 0.01195	 0.024564	 0.00047	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72828	 72832	 0.032957	 0.023343	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72829	 72837	 0.025157	 0.017821	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72830	 72832	 0.014243	 0.022729	 0.00052	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72830	 72836	 0.005721	 0.010643	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72831	 72832	 0.013171	 0.011886	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79456	 72831	 0.006136	 0.012614	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72833	 72834	 0.01015	 0.011893	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79459	 72835	 0.012071	 0.035507	 0.00073	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72836	 72837	 0.001821	 0.005364	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79456	 72836	 0.003707	 0.0222	 0.00054	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72838	 72839	 0.010371	 0.014136	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72838	 72842	 0.002829	 0.014036	 0.00034	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72838	 72847	 0.005907	 0.013407	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72838	 72849	 0.012586	 0.0234	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72839	 72851	 0.009121	 0.010693	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72840	 72841	 0.025607	 0.018136	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72840	 72842	 0.013857	 0.023343	 0.00034	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72842	 72877	 0.008457	 0.021414	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72842	 72893	 0.009914	 0.033879	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72843	 72845	 0.036514	 0.028893	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72843	 72880	 0.03465	 0.022429	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72844	 72845	 0.0154	 0.0139	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72844	 72878	 0.01915	 0.015157	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72845	 72876	 0.028057	 0.038243	 0.00085	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72845	 73131	 0.006357	 0.034007	 0.00103	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72846	 72871	 0.007371	 0.015086	 0.00037	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72846	 72875	 0.006043	 0.012364	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72847	 72848	 0.019943	 0.015786	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72847	 72852	 0.009864	 0.017343	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72848	 72856	 0.010229	 0.016329	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72848	 72871	 0.010114	 0.017043	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72849	 72852	 0.005007	 0.007993	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72849	 72856	 0.018443	 0.011943	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72850	 72854	 0.007036	 0.011236	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72850	 72855	 0.0166	 0.013136	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72851	 72853	 0.006571	 0.010493	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72851	 72855	 0.010036	 0.010721	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72852	 72853	 0.004571	 0.008036	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72852	 72858	 0.01305	 0.025836	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72853	 72854	 0.007379	 0.009157	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72854	 79461	 0.065471	 0.051814	 0.00065	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72856	 72857	 0.020107	 0.014243	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72856	 79461	 0.012521	 0.011221	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72858	 79460	 0.011664	 0.0096	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72859	 79460	 0.019186	 0.013593	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72860	 72862	 0.001514	 0.004721	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72860	 79460	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72860	 79460	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79460	 72861	 0.005143	 0.010814	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72861	 79461	 0.010971	 0.011079	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72862	 79461	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72862	 79461	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72862	 79464	 0.002771	 0.023043	 0.00698	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72863	 72866	 0.015507	 0.015664	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79461	 72863	 0.004507	 0.010229	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72864	 72865	 0.01385	 0.009814	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72864	 72866	 0.00455	 0.009314	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72864	 72867	 0.009621	 0.019779	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72864	 72870	 0.0083	 0.013979	 0.0002	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79461	 72864	 0.028264	 0.020021	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79461	 72865	 0.020279	 0.014364	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72867	 72868	 0.006193	 0.009886	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72867	 72870	 0.005671	 0.012864	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72867	 72873	 0.003057	 0.01195	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79452	 72867	 0.004321	 0.018486	 0.00041	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72868	 72869	 0.005921	 0.011007	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72869	 72870	 0.007414	 0.006686	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72870	 72872	 0.011957	 0.0215	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79460	 72870	 0.022343	 0.045914	 0.00088	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72871	 72872	 0.010121	 0.009943	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79461	 72871	 0.013693	 0.028136	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72872	 72873	 0.009171	 0.013364	 0.0003	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72873	 79465	 0.007679	 0.047229	 0.00085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72874	 72893	 0.018186	 0.012879	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72875	 72877	 0.007929	 0.016221	 0.0004	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72876	 72887	 0.011879	 0.010643	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72876	 72890	 0.004993	 0.009007	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72877	 72892	 0.001793	 0.010214	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72878	 72879	 0.022229	 0.014393	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72879	 72880	 0.028943	 0.0205	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72879	 72886	 0.010757	 0.018914	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72880	 72881	 0.026907	 0.019064	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72880	 72884	 0.029736	 0.01925	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72882	 72883	 0.007993	 0.024514	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72882	 72918	 0.084507	 0.066879	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72882	 72922	 0.006957	 0.027179	 0.0006	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72883	 73128	 0.012043	 0.047029	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72884	 72885	 0.015629	 0.018321	 0.00032	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72884	 72898	 0.022993	 0.018929	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72885	 72900	 0.011821	 0.014671	 0.00032	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72886	 72887	 0.0141	 0.009129	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72886	 72888	 0.012221	 0.009671	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72886	 72900	 0.014671	 0.034064	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72886	 79465	 0.01015	 0.0269	 0.00069	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72887	 72897	 0.0067	 0.012457	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72889	 72890	 0.002493	 0.0051	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72889	 72897	 0.00295	 0.006036	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72890	 72891	 0.003936	 0.007314	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72891	 72892	 0.001114	 0.00535	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79452	 72894	 0.003557	 0.017071	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72894	 79462	 0.010136	 0.015193	 0.00028	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72894	 79465	 0.006157	 0.018886	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72895	 79462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72895	 79462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72895	 79464	 0.00075	 0.004521	 0.00137	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72896	 73139	 0.00035	 0.0059	 0.57466	 2720.0	 2856.0	 2992.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72896	 79463	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72896	 79463	 0.000146	 0.011679	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79465	 72897	 0.008614	 0.02	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72897	 79466	 0.004593	 0.0094	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72898	 72901	 0.006421	 0.011293	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72899	 72900	 0.007564	 0.015543	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72899	 72901	 0.008229	 0.016293	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72899	 72920	 0.022921	 0.018143	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72900	 72922	 0.0123	 0.02855	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72900	 73128	 0.021257	 0.094207	 0.00283	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72901	 79466	 0.002614	 0.009164	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79465	 72902	 0.024221	 0.017157	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79464	 72903	 0.000914	 0.003471	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72903	 79466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72903	 79466	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72904	 72905	 0.017521	 0.014421	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72904	 72914	 0.011321	 0.018071	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72905	 72911	 0.010779	 0.009729	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72906	 72907	 0.0076	 0.014136	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72906	 72917	 0.036871	 0.026121	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72906	 72925	 0.025386	 0.052171	 0.00099	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79465	 72906	 0.008771	 0.0336	 0.00095	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72907	 72925	 0.017871	 0.036729	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72908	 72910	 0.030471	 0.024114	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72909	 72913	 0.020064	 0.012993	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72910	 72912	 0.015457	 0.023179	 0.00042	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72910	 72956	 0.022679	 0.069571	 0.00189	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79465	 72910	 0.028479	 0.059857	 0.00109	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72911	 72912	 0.014979	 0.012329	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72912	 72913	 0.00515	 0.010543	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79465	 72912	 0.007857	 0.0301	 0.00085	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72913	 72915	 0.004014	 0.010629	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79462	 72914	 0.008929	 0.0166	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79465	 72915	 0.005729	 0.019557	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72916	 72921	 0.014914	 0.029529	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79466	 72916	 0.016764	 0.028243	 0.0004	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72917	 72919	 0.014057	 0.026143	 0.00061	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72917	 72921	 0.0199	 0.01795	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72918	 72919	 0.021657	 0.049529	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72918	 72926	 0.09365	 0.066343	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72918	 73128	 0.017029	 0.059614	 0.00165	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72921	 72923	 0.017164	 0.015486	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72922	 72924	 0.016229	 0.019021	 0.00033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72923	 72924	 0.01405	 0.012679	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72925	 73114	 0.018779	 0.100843	 0.00239	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72927	 72930	 0.027043	 0.017507	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72927	 72933	 0.014557	 0.029914	 0.00057	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72927	 72960	 0.020707	 0.01855	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72928	 72948	 0.021443	 0.016971	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72929	 72935	 0.072007	 0.051007	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72929	 72956	 0.046421	 0.041886	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72930	 72931	 0.01465	 0.022443	 0.00031	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72930	 72959	 0.018343	 0.020171	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72930	 79468	 0.044564	 0.035271	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72931	 72933	 0.007271	 0.014879	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72931	 72939	 0.023836	 0.015429	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72932	 72941	 0.015636	 0.021307	 0.00047	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72932	 72943	 0.0221	 0.015657	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72932	 72946	 0.007707	 0.0123	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72932	 79469	 0.028171	 0.022293	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72933	 72956	 0.072507	 0.098843	 0.00219	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72933	 73103	 0.0353	 0.072543	 0.00139	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72933	 73111	 0.023429	 0.048143	 0.00092	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72934	 73113	 0.053979	 0.042721	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72935	 73113	 0.117714	 0.092279	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72936	 72953	 0.025471	 0.016493	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72937	 72965	 0.005	 0.012986	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72937	 79467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72937	 79467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72938	 72941	 0.057129	 0.057293	 0.00093	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72938	 72969	 0.075629	 0.076386	 0.00101	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 72938	 0.088843	 0.062936	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72938	 79468	 0.020664	 0.028164	 0.00062	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72938	 79495	 0.015779	 0.05525	 0.00153	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72939	 79468	 0.03555	 0.023014	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72940	 73098	 0.006107	 0.02445	 0.00616	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72940	 79468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72940	 79468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72942	 72963	 0.015136	 0.015293	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 72942	 0.015879	 0.026743	 0.00038	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72943	 72963	 0.023021	 0.014907	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72944	 79469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72944	 79469	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79469	 72945	 0.008671	 0.011829	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72946	 72949	 0.00995	 0.017879	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72947	 72948	 0.006771	 0.011914	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72947	 72955	 0.0052	 0.018214	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72947	 72957	 0.007736	 0.0096	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72947	 72962	 0.028529	 0.020207	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72949	 72950	 0.016107	 0.021957	 0.00049	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72949	 72951	 0.010743	 0.013336	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72949	 72952	 0.029157	 0.018871	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72951	 72953	 0.022864	 0.016529	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72951	 72954	 0.02345	 0.016614	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72955	 72956	 0.004907	 0.017171	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79465	 72956	 0.025371	 0.125893	 0.003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72957	 72961	 0.034407	 0.024371	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72957	 72962	 0.013257	 0.009393	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72958	 72959	 0.012321	 0.008729	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72960	 72961	 0.020886	 0.017186	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72962	 72963	 0.005693	 0.0083	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79468	 72963	 0.032057	 0.042129	 0.00058	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72964	 72966	 0.016007	 0.018764	 0.00033	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72964	 79470	 0.014886	 0.013429	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72964	 79474	 0.008407	 0.017286	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72965	 72976	 0.004229	 0.011514	 0.00254	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72966	 73066	 0.007807	 0.014514	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72966	 79470	 0.011286	 0.012407	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72966	 79478	 0.011307	 0.01805	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72967	 72976	 0.00165	 0.004771	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72967	 79470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72967	 79470	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72967	 79477	 0.001693	 0.004986	 0.00116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72968	 73063	 0.068793	 0.044543	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72968	 73066	 0.031014	 0.020079	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72969	 79493	 0.044736	 0.052443	 0.00091	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	72970	 72972	 0.002029	 0.006114	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72971	 72972	 0.001286	 0.004014	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72971	 72975	 0.001857	 0.006064	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72971	 79471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72971	 79471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72972	 72976	 0.004229	 0.012721	 0.00398	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72972	 79472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72972	 79472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72973	 72974	 0.009107	 0.017843	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72973	 72977	 0.033929	 0.034264	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79471	 72973	 0.031814	 0.025179	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79434	 72974	 0.0134	 0.026529	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79472	 72974	 0.032029	 0.020736	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72975	 72978	 0.001557	 0.006436	 0.00152	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72975	 79473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72975	 79473	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72976	 79474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72976	 79474	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72976	 79477	 0.002243	 0.007814	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79471	 72977	 0.0384	 0.0272	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79473	 72977	 0.019214	 0.012443	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79474	 72977	 0.007621	 0.015664	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72978	 72980	 0.002943	 0.010093	 0.00242	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	72978	 79475	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72978	 79475	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79475	 72979	 0.018921	 0.0134	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72979	 79478	 0.011936	 0.016286	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	72980	 72989	 0.0017	 0.012221	 0.00324	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72980	 79476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72980	 79476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72980	 79477	 0.001464	 0.00585	 0.00147	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72981	 72984	 0.011443	 0.008107	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79476	 72981	 0.023757	 0.023993	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72981	 79478	 0.023829	 0.016879	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72982	 79477	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79478	 72982	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72982	 79497	 0.001129	 0.007414	 0.01434	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79476	 72983	 0.030071	 0.019471	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72985	 79479	 0.003264	 0.01335	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	72985	 79481	 0.005771	 0.019721	 0.00043	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72985	 79486	 0.011336	 0.0233	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79476	 72986	 0.011764	 0.024179	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72986	 79499	 0.014557	 0.027064	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72987	 72988	 0.000379	 0.003057	 0.00086	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72987	 73054	 0.000464	 0.003757	 0.00106	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78234	 72988	 0.000514	 0.00485	 0.00147	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72989	 72990	 0.000164	 0.002307	 0.00121	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72989	 79498	 0.000393	 0.004564	 0.00134	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78234	 72990	 0.000336	 0.004179	 0.00284	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72991	 72993	 0.000664	 0.005671	 0.00161	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78234	 72991	 0.000593	 0.006736	 0.00189	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72991	 79479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72991	 79479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79479	 72992	 0.010207	 0.007229	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72993	 72994	 0.000507	 0.004314	 0.00108	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72994	 79480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72994	 79480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72994	 79482	 0.00105	 0.006893	 0.00173	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	72995	 72996	 0.008014	 0.006343	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79480	 72996	 0.006057	 0.011264	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72996	 79483	 0.010336	 0.019221	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72997	 73053	 0.001707	 0.008071	 0.00259	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	72997	 79481	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72997	 79481	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72997	 79482	 0.001086	 0.006664	 0.00244	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72998	 73004	 0.0064	 0.018364	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	72998	 73013	 0.013921	 0.013679	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	72998	 73014	 0.012714	 0.025179	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79481	 72999	 0.009186	 0.018871	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	72999	 79483	 0.009579	 0.016129	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73000	 73001	 0.010443	 0.010257	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73000	 79483	 0.0099	 0.017414	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73001	 73005	 0.014443	 0.025407	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79481	 73001	 0.007671	 0.014264	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73001	 79483	 0.007693	 0.019786	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73002	 73003	 0.014929	 0.019429	 0.00027	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73002	 73018	 0.011821	 0.013857	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73003	 73004	 0.008407	 0.022271	 0.00056	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73003	 73006	 0.006336	 0.016057	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73003	 79483	 0.022436	 0.041721	 0.00098	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73004	 73039	 0.008414	 0.016486	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73004	 73041	 0.024643	 0.033621	 0.0006	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73005	 73007	 0.004764	 0.015893	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79481	 73005	 0.019086	 0.020386	 0.00043	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73006	 73008	 0.003979	 0.013264	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73007	 73008	 0.004193	 0.009514	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73007	 79486	 0.006779	 0.0126	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73008	 73009	 0.004043	 0.008307	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73008	 73055	 0.002929	 0.008986	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73009	 73044	 0.003471	 0.00805	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73010	 73018	 0.01125	 0.025521	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73010	 79483	 0.003657	 0.012071	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78155	 73011	 0.001	 0.01695	 0.05992	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73011	 79482	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79483	 73011	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73011	 79497	 0.000507	 0.007671	 0.02755	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73012	 73013	 0.004871	 0.008571	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73012	 73017	 0.0112	 0.019693	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73013	 73014	 0.006764	 0.0139	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73014	 79485	 0.033621	 0.131307	 0.00291	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73015	 73016	 0.008271	 0.028264	 0.00061	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73015	 73026	 0.019279	 0.075307	 0.00167	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73016	 73041	 0.0049	 0.015029	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73017	 73018	 0.003771	 0.007757	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78155	 73019	 0.001829	 0.012193	 0.02298	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73019	 79484	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79485	 73019	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73020	 73026	 0.028757	 0.020371	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73021	 73022	 0.013586	 0.046421	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73021	 73026	 0.018643	 0.042636	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73022	 73037	 0.014729	 0.0573	 0.00096	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73023	 73024	 0.006357	 0.016107	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73023	 73026	 0.023979	 0.038464	 0.00071	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73023	 73027	 0.013157	 0.063157	 0.00189	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73024	 73025	 0.007486	 0.010207	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73024	 73026	 0.012107	 0.021293	 0.0004	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73025	 73026	 0.005357	 0.011007	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79485	 73025	 0.040507	 0.124279	 0.00336	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73030	 73031	 0.006693	 0.035807	 0.00109	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73031	 73038	 0.0204	 0.054071	 0.00137	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73031	 73081	 0.035686	 0.073343	 0.0014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73031	 73082	 0.040714	 0.0757	 0.00177	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73032	 73033	 0.125093	 0.099007	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73032	 73080	 0.044214	 0.082214	 0.00192	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73032	 73090	 0.075521	 0.132836	 0.00249	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73032	 73122	 0.385543	 0.249929	 0.00476	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73034	 73035	 0.015543	 0.015271	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73034	 73041	 0.018693	 0.01675	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73035	 73036	 0.003386	 0.007736	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73035	 73037	 0.007936	 0.030864	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73035	 73042	 0.027957	 0.029857	 0.00063	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73036	 73041	 0.014814	 0.027543	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73036	 73047	 0.003414	 0.00865	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73036	 73049	 0.003436	 0.013421	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73037	 73038	 0.013007	 0.038243	 0.00079	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73039	 73040	 0.011329	 0.0121	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73040	 73042	 0.006436	 0.010271	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73042	 73043	 0.0138	 0.018143	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73042	 73045	 0.004629	 0.013271	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79483	 73042	 0.0529	 0.086721	 0.00153	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73043	 73046	 0.006729	 0.009179	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73044	 73045	 0.003479	 0.011614	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73044	 73051	 0.007093	 0.013186	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73046	 73047	 0.008571	 0.008414	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73047	 73048	 0.002129	 0.008314	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73048	 73051	 0.007007	 0.020607	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73048	 73052	 0.007786	 0.012429	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73049	 73050	 0.00365	 0.011207	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73050	 73059	 0.013386	 0.02355	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73050	 79489	 0.011264	 0.043993	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73051	 73058	 0.004029	 0.013429	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73051	 79486	 0.019593	 0.036421	 0.00085	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73052	 73061	 0.00785	 0.014593	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73053	 73054	 0.000429	 0.003064	 0.00095	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73053	 79486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73053	 79486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79486	 73055	 0.011429	 0.018243	 0.00042	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73055	 79487	 0.00915	 0.03125	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73056	 73067	 0.002736	 0.011364	 0.00265	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73056	 79487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73056	 79487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73056	 79498	 0.002286	 0.00915	 0.00231	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73057	 73058	 0.003829	 0.01175	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79487	 73057	 0.002821	 0.009871	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73059	 73060	 0.027407	 0.019414	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73059	 73061	 0.019429	 0.021371	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73059	 79488	 0.012714	 0.026121	 0.0005	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73061	 73062	 0.007543	 0.015493	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79486	 73061	 0.036243	 0.071757	 0.00105	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73062	 79488	 0.004721	 0.013543	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73063	 73064	 0.02085	 0.020486	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79487	 73063	 0.012921	 0.03425	 0.00087	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73063	 79499	 0.007214	 0.035793	 0.00085	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73064	 73065	 0.012964	 0.011943	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73065	 73066	 0.022386	 0.0202	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73067	 73068	 0.001179	 0.004107	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73067	 73079	 0.002493	 0.008871	 0.00197	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73067	 79488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73067	 79488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73068	 73079	 0.00125	 0.004557	 0.00139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79488	 73069	 0.012271	 0.020671	 0.00029	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73070	 73072	 0.001307	 0.005386	 0.00127	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73070	 73079	 0.002993	 0.008814	 0.00205	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73070	 79489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73070	 79489	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73071	 73078	 0.002071	 0.009193	 0.00028	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79489	 73071	 0.006814	 0.017321	 0.00027	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73071	 79494	 0.005314	 0.015629	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73072	 73073	 0.001207	 0.004693	 0.00125	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73072	 79490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73072	 79490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73073	 73075	 0.001107	 0.004307	 0.00115	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73073	 79491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73073	 79491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73074	 73096	 0.006043	 0.015536	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73074	 79492	 0.003879	 0.009979	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73075	 79492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73075	 79492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73076	 79493	 0.008936	 0.018371	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73076	 79494	 0.012471	 0.01225	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73077	 73079	 0.001971	 0.007179	 0.0022	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73077	 73097	 0.002671	 0.011029	 0.00261	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73077	 79493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73077	 79493	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79490	 73078	 0.040529	 0.026236	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79491	 73078	 0.003443	 0.016514	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73079	 79494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73079	 79494	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73079	 79498	 0.006236	 0.024979	 0.00629	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73080	 73083	 0.017907	 0.033293	 0.00078	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73080	 73091	 0.065929	 0.047657	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73081	 73082	 0.016121	 0.01455	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73081	 73096	 0.008164	 0.014357	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73082	 73083	 0.004614	 0.008579	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73082	 73084	 0.002886	 0.011057	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73083	 73085	 0.012336	 0.011057	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73084	 73094	 0.008264	 0.012657	 0.00018	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73084	 73099	 0.002086	 0.008929	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73085	 73092	 0.0149	 0.013443	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73086	 73090	 0.011021	 0.02265	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73086	 73093	 0.006014	 0.005421	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73086	 73094	 0.013671	 0.012329	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73086	 73107	 0.020929	 0.016564	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73087	 73089	 0.005607	 0.007643	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73087	 73091	 0.014943	 0.017521	 0.00031	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73087	 73092	 0.003929	 0.008907	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73088	 73090	 0.011664	 0.008257	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73088	 73092	 0.013586	 0.01075	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73089	 73091	 0.012536	 0.011307	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73091	 73112	 0.109614	 0.070971	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73092	 73094	 0.008121	 0.018414	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73092	 73107	 0.007529	 0.017486	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73093	 73094	 0.00845	 0.006957	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73094	 73106	 0.009264	 0.016714	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78282	 73094	 0.00795	 0.024393	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79490	 73095	 0.036114	 0.025579	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78208	 73097	 0.001929	 0.007329	 0.00205	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78208	 73098	 0.000736	 0.0064	 0.0023	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73098	 79495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73098	 79495	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73099	 73100	 0.002	 0.007943	 0.00023	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78209	 73100	 0.007007	 0.016029	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78282	 73100	 0.006821	 0.013964	 0.00034	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73101	 73104	 0.024057	 0.015571	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73102	 73104	 0.024457	 0.019357	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73102	 73105	 0.003664	 0.015671	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73102	 73110	 0.016079	 0.014507	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73102	 73111	 0.008636	 0.01605	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73103	 73105	 0.011536	 0.016807	 0.00038	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78209	 73103	 0.011793	 0.026757	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78282	 73103	 0.014279	 0.02935	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79491	 73103	 0.0377	 0.067757	 0.00121	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79495	 73103	 0.004857	 0.018614	 0.00053	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73105	 73106	 0.002321	 0.008886	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78209	 73105	 0.008379	 0.024643	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73106	 73107	 0.004771	 0.008871	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73106	 73110	 0.004893	 0.010007	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73107	 73108	 0.018386	 0.011907	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73109	 73110	 0.042471	 0.0307	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73110	 73111	 0.01625	 0.024643	 0.00035	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73111	 73113	 0.057171	 0.047057	 0.00096	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73114	 73115	 0.011371	 0.037536	 0.00061	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73114	 73116	 0.024064	 0.044743	 0.00105	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73115	 73116	 0.011086	 0.016621	 0.0003	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73115	 73117	 0.018707	 0.074229	 0.00212	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73116	 73118	 0.014707	 0.02205	 0.0004	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73117	 73119	 0.065936	 0.059493	 0.00099	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79465	 73117	 0.06695	 0.2864	 0.00648	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73118	 73119	 0.0073	 0.044193	 0.00139	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73119	 73120	 0.055157	 0.035707	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73119	 73123	 0.020307	 0.108693	 0.00329	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73121	 73123	 0.016843	 0.114393	 0.00283	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73121	 73124	 0.111664	 0.391543	 0.01086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73121	 73124	 0.111664	 0.391543	 0.01086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73121	 73126	 0.035014	 0.122621	 0.00339	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73121	 73126	 0.035014	 0.122621	 0.00339	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73125	 73128	 0.053721	 0.330507	 0.00596	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73125	 73130	 0.098379	 0.438864	 0.00746	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73125	 73130	 0.098379	 0.438864	 0.00746	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73125	 73131	 0.048743	 0.314829	 0.01004	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73126	 73129	 0.032764	 0.114729	 0.00318	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73126	 73129	 0.032764	 0.114729	 0.00318	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73127	 73128	 0.011236	 0.0209	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73127	 73129	 0.020121	 0.046014	 0.00112	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73128	 73129	 0.005643	 0.033821	 0.00081	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73130	 73132	 0.0387	 0.071957	 0.00169	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78191	 73130	 0.030593	 0.121386	 0.00346	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73131	 73132	 0.025179	 0.046821	 0.00109	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79467	 73134	 0.067093	 0.0485	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78289	 73135	 0.023621	 0.042621	 0.00061	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78288	 73137	 0.002243	 0.006114	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73137	 79496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73137	 79496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73139	 79497	 9.9e-05	 0.007891	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73140	 79502	 0.012729	 0.021443	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73141	 73142	 0.008607	 0.005571	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73142	 73146	 0.0062	 0.006814	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73143	 73145	 0.004893	 0.003171	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73144	 73208	 0.0016	 0.008286	 0.00202	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73144	 73326	 0.000179	 0.001014	 0.00029	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73144	 79521	 0.000643	 0.003336	 0.00081	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73145	 73146	 0.004879	 0.003457	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73146	 79519	 0.002464	 0.005043	 0.00012	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73147	 73148	 0.003143	 0.005529	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73147	 73151	 0.001657	 0.003393	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73148	 73149	 0.002971	 0.00405	 7e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73149	 73171	 0.004829	 0.008979	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73149	 73174	 0.006386	 0.004136	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73149	 79500	 0.001636	 0.003343	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73150	 73180	 0.000336	 0.001343	 0.00034	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73150	 79500	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73150	 79500	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73150	 79501	 0.000529	 0.003271	 0.00094	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73151	 73152	 0.005143	 0.004029	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73151	 73155	 0.000757	 0.002579	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73151	 73156	 0.004914	 0.003479	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73151	 79502	 0.001036	 0.007014	 0.00017	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73153	 79501	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79502	 73153	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73153	 79520	 7.1e-05	 0.000721	 0.00149	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 73154	 0.005779	 0.004093	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73155	 73158	 0.001164	 0.002164	 5e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79500	 73155	 0.002057	 0.003829	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73157	 73159	 0.001829	 0.002929	 6e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79500	 73157	 0.001414	 0.002636	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73158	 73161	 0.001521	 0.002829	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73159	 73160	 0.000743	 0.00255	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73159	 73161	 0.001507	 0.003986	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73159	 73163	 0.004571	 0.002964	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73160	 73190	 0.001914	 0.003943	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73160	 79504	 0.002179	 0.003836	 7e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73161	 73162	 0.002479	 0.001757	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73161	 73165	 0.002329	 0.003571	 5e-05	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 73161	 0.000914	 0.007593	 0.00014	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73164	 73180	 0.000857	 0.002529	 0.00059	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73164	 73204	 0.0004	 0.001507	 0.00042	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73164	 79503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73164	 79503	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73165	 73166	 0.002543	 0.00165	 3e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73167	 73170	 0.007936	 0.006279	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73168	 73172	 0.007593	 0.004914	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73169	 73170	 0.009893	 0.0064	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73170	 73176	 0.007714	 0.005464	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79500	 73170	 0.00855	 0.019843	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73171	 73172	 0.002943	 0.004414	 8e-05	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73172	 73173	 0.005814	 0.0046	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73174	 73175	 0.0039	 0.002521	 5e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73177	 73183	 0.007286	 0.005764	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73178	 73182	 0.005329	 0.00345	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73179	 73181	 0.005636	 0.00365	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73180	 73184	 0.00075	 0.002436	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73180	 79504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73180	 79504	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73181	 73189	 0.003707	 0.004607	 0.0001	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79504	 73181	 0.001543	 0.004729	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73181	 79505	 0.002093	 0.003893	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73182	 79505	 0.004186	 0.004907	 9e-05	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73183	 73289	 0.009086	 0.03535	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79500	 73183	 0.004836	 0.0275	 0.0005	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73184	 79505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73184	 79505	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73185	 73186	 0.003364	 0.006921	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73185	 73312	 0.001986	 0.003693	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73186	 73195	 0.0016	 0.00425	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79503	 73186	 0.003679	 0.025257	 0.00046	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73187	 73188	 0.005414	 0.003836	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79505	 73187	 0.005679	 0.005129	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73189	 73191	 0.005493	 0.003557	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79503	 73190	 0.002907	 0.004236	 9e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73192	 73199	 0.001586	 0.003629	 9e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79503	 73192	 0.0017	 0.005007	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73193	 73199	 0.007157	 0.004636	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73194	 73197	 0.001064	 0.004071	 0.00011	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79505	 73194	 0.0019	 0.010807	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73195	 73196	 0.00165	 0.003371	 9e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73196	 73203	 0.002486	 0.005079	 0.00013	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73196	 73270	 0.002814	 0.00985	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73197	 73201	 0.001371	 0.004807	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73198	 73199	 0.001971	 0.004043	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73198	 79507	 0.003836	 0.007886	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73200	 73212	 0.005214	 0.003693	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73201	 73202	 0.001793	 0.004743	 0.00012	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73201	 73215	 0.004871	 0.006643	 0.00012	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73202	 73203	 0.001393	 0.003193	 8e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73204	 73207	 0.000264	 0.001029	 0.00027	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73205	 73210	 0.000507	 0.001764	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73205	 73218	 0.000314	 0.00255	 0.00081	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73205	 73232	 0.000229	 0.001764	 0.00062	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73205	 79506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73205	 79506	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73205	 79517	 0.000329	 0.003664	 0.0011	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73205	 79521	 0.0007	 0.006229	 0.00166	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73206	 79522	 0.009771	 0.006921	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73207	 73209	 0.000364	 0.001507	 0.00035	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73209	 79521	 0.000864	 0.003129	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73210	 79507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73210	 79507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73211	 73212	 0.001143	 0.004	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79507	 73211	 0.000671	 0.002979	 9e-05	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73212	 73215	 0.002364	 0.00725	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73213	 73215	 0.008271	 0.006479	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73214	 73277	 0.010643	 0.007543	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73214	 79511	 0.009543	 0.006179	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73215	 73222	 0.001464	 0.006536	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73216	 79508	 0.0087	 0.006164	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73217	 73218	 0.000164	 0.00095	 0.00026	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73217	 73223	 0.000779	 0.003707	 0.0013	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73217	 79508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73217	 79508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73218	 73232	 0.0003	 0.001564	 0.00038	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73218	 79509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73218	 79509	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73219	 73232	 0.000714	 0.002893	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73219	 79510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73219	 79510	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79510	 73220	 0.005679	 0.003679	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73221	 73224	 0.007121	 0.005043	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73222	 79511	 0.000957	 0.003343	 9e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73223	 73227	 0.000421	 0.0024	 0.00068	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73223	 79511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73223	 79511	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73224	 73225	 0.002521	 0.004686	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79510	 73224	 0.003986	 0.010243	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73225	 73228	 0.004457	 0.008821	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79511	 73226	 0.006107	 0.004321	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73227	 73283	 0.000636	 0.003321	 0.00087	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73227	 79512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73227	 79512	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73228	 73248	 0.0039	 0.006221	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73229	 73230	 0.009507	 0.006736	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73229	 73328	 0.001157	 0.006579	 0.0002	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73229	 79518	 0.001379	 0.012836	 0.00025	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73231	 73328	 0.011093	 0.007857	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73232	 79513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73232	 79513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79506	 73233	 0.006293	 0.010043	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73234	 73236	 0.002364	 0.005486	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79513	 73234	 0.002464	 0.004586	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73235	 73237	 0.009893	 0.007007	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73236	 73237	 0.001664	 0.003493	 6e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73237	 73246	 0.012736	 0.010479	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73237	 73328	 0.001329	 0.007129	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73237	 79523	 0.001271	 0.011814	 0.00023	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73238	 73239	 0.008607	 0.005571	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73238	 73254	 0.001436	 0.006364	 0.00019	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73238	 79523	 0.001757	 0.010536	 0.00025	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73240	 73327	 0.008343	 0.005914	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73241	 73242	 0.012314	 0.008721	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73241	 73333	 0.015629	 0.011071	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73242	 73244	 0.001957	 0.007621	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73242	 79523	 0.003886	 0.015421	 0.00044	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73243	 73334	 0.0011	 0.005364	 0.00148	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73243	 73528	 0.001543	 0.00695	 0.00185	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73243	 79514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73243	 79514	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73244	 73325	 0.003421	 0.009057	 0.00023	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79514	 73244	 0.004271	 0.005829	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73245	 73246	 0.008371	 0.005929	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73247	 73248	 0.001471	 0.005743	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79510	 73247	 0.001757	 0.008879	 0.00016	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73248	 73249	 0.01055	 0.007471	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73248	 73250	 0.000679	 0.003271	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73250	 73252	 0.000907	 0.004886	 0.00011	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73251	 73257	 0.003021	 0.006214	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73251	 73261	 0.00235	 0.008229	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73251	 79516	 0.001757	 0.007836	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73252	 73254	 0.008	 0.014071	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73252	 73258	 0.006471	 0.005121	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73252	 73259	 0.001929	 0.00855	 0.00026	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73253	 73254	 0.009879	 0.006393	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73254	 73256	 0.001321	 0.00525	 0.00015	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79514	 73254	 0.006493	 0.007614	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79514	 73255	 0.008179	 0.006471	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73256	 73332	 0.001757	 0.0078	 0.00018	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73257	 73259	 0.002407	 0.004943	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73259	 73260	 0.002293	 0.005243	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73260	 73264	 0.002943	 0.006721	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73261	 73263	 0.002571	 0.006521	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73261	 73284	 0.01845	 0.011943	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73261	 73287	 0.006764	 0.022571	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73261	 79523	 0.011257	 0.05015	 0.00085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73262	 73283	 0.001179	 0.005493	 0.00136	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73262	 73534	 0.000707	 0.002921	 0.00069	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73262	 79515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73262	 79515	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73263	 73265	 0.003171	 0.005579	 0.00011	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73264	 73529	 0.015436	 0.010936	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73264	 79557	 0.004729	 0.015779	 0.00025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73265	 73530	 0.002864	 0.005164	 7e-05	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73266	 73268	 0.001857	 0.004307	 8e-05	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73266	 73269	 0.002221	 0.005036	 0.0001	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73267	 73325	 0.010786	 0.008536	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73268	 73325	 0.003493	 0.008836	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73269	 79557	 0.002629	 0.004886	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73270	 73271	 0.010157	 0.007964	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73270	 73273	 0.00245	 0.0062	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73272	 73273	 0.00825	 0.005843	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73273	 73274	 0.002807	 0.007143	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73274	 73275	 0.002371	 0.005386	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73275	 73276	 0.00265	 0.0068	 0.00011	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73275	 73293	 0.003921	 0.008064	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73276	 73280	 0.003907	 0.008029	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73278	 73280	 0.015543	 0.011014	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79512	 73279	 0.014729	 0.010429	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73280	 73281	 0.00265	 0.009286	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73280	 73296	 0.016714	 0.013757	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79509	 73280	 0.009657	 0.041279	 0.00094	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73281	 73286	 0.0036	 0.009114	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73281	 73298	 0.004657	 0.009779	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73282	 73284	 0.001179	 0.005664	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73282	 79516	 0.001343	 0.008064	 0.00019	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73283	 79516	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73283	 79516	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73284	 73285	 0.00745	 0.005279	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73284	 73288	 0.001086	 0.005807	 0.00018	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73286	 73287	 0.00265	 0.005414	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73287	 73536	 0.005279	 0.018043	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79515	 73288	 0.000857	 0.003986	 9e-05	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73289	 73290	 0.006236	 0.004936	 6e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73289	 73291	 0.013771	 0.009757	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73289	 73293	 0.005079	 0.010443	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73289	 73294	 0.007964	 0.020257	 0.00032	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73289	 73301	 0.011079	 0.0151	 0.00034	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73289	 73331	 0.001864	 0.005729	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73291	 73295	 0.012114	 0.007843	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73292	 73293	 0.010407	 0.006736	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73294	 73304	 0.004286	 0.007543	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73296	 73297	 0.010671	 0.008364	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73296	 73304	 0.012614	 0.0113	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73298	 73300	 0.005336	 0.007436	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73299	 73300	 0.006586	 0.004664	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73300	 73322	 0.016707	 0.010814	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73301	 73302	 0.011021	 0.007807	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73301	 73303	 0.010821	 0.007	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73304	 73305	 0.009457	 0.0067	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73306	 73307	 0.0085	 0.00615	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73307	 73309	 0.006486	 0.007136	 9e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73307	 73313	 0.003207	 0.007264	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73307	 73314	 0.0023	 0.008979	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73307	 73321	 0.001621	 0.012057	 0.00029	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73308	 73309	 0.007307	 0.004729	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73308	 73311	 0.00935	 0.006621	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73310	 73315	 0.004864	 0.0057	 0.0001	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73310	 73320	 0.008629	 0.015571	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73312	 73313	 0.002657	 0.006171	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73314	 73315	 0.00195	 0.006664	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73315	 73316	 0.001071	 0.003293	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73315	 73317	 0.003429	 0.007043	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73316	 73331	 0.0016	 0.006221	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73317	 73318	 0.00235	 0.004829	 9e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73318	 73320	 0.002714	 0.005579	 0.00011	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73319	 73320	 0.006957	 0.005507	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73320	 73321	 0.006421	 0.02845	 0.00086	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73320	 73330	 0.009136	 0.007229	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79502	 73321	 0.011186	 0.049007	 0.00106	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73323	 73332	 0.001707	 0.007607	 0.00013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73323	 79557	 0.001793	 0.006993	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73324	 73555	 0.000893	 0.012279	 0.02446	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73324	 79517	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79518	 73324	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73324	 79520	 0.0001	 0.001129	 0.00407	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79501	 73326	 0.0002	 0.001329	 0.00041	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73326	 79519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73326	 79519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73327	 79523	 0.010786	 0.010893	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73329	 79520	 0.000111	 0.008848	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79521	 73334	 0.000843	 0.01	 0.00349	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73334	 79523	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73334	 79523	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73335	 73336	 0.013386	 0.012079	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73335	 73338	 0.013493	 0.011107	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73335	 73351	 0.02755	 0.017836	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73335	 79525	 0.008129	 0.024936	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73336	 73337	 0.0164	 0.012979	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73337	 73347	 0.009729	 0.014907	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73339	 73351	 0.011336	 0.008029	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73340	 73341	 0.005843	 0.011957	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73340	 73354	 0.006336	 0.011136	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73341	 79525	 0.006421	 0.024986	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73342	 73444	 0.001136	 0.012793	 0.02341	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73342	 79524	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79525	 73342	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73343	 73346	 0.004057	 0.009286	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78300	 73343	 0.003993	 0.013643	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73344	 73407	 0.010793	 0.028986	 0.00657	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79524	 73344	 0.003607	 0.010957	 0.0024	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73344	 79526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73344	 79526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73345	 73346	 0.006521	 0.008886	 0.0002	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73345	 73373	 0.004643	 0.009543	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79526	 73345	 0.013207	 0.018007	 0.0004	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73346	 73347	 0.005586	 0.014143	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79526	 73346	 0.012364	 0.018021	 0.00041	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73347	 73348	 0.01615	 0.016314	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73347	 73349	 0.024464	 0.019179	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73348	 79527	 0.006886	 0.015621	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73349	 73388	 0.014729	 0.009536	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73350	 73353	 0.002571	 0.006786	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79524	 73350	 0.005921	 0.016521	 0.00346	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73350	 79527	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73350	 79527	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73351	 79528	 0.006964	 0.01225	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79527	 73352	 0.007879	 0.016186	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73352	 79528	 0.008364	 0.010379	 0.00023	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73353	 73359	 0.003007	 0.011443	 0.0032	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73353	 73364	 0.001621	 0.004343	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73353	 73393	 0.003679	 0.022243	 0.00568	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73353	 73403	 0.006836	 0.018614	 0.0041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73353	 79528	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73353	 79528	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73354	 73355	 0.020557	 0.013307	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79528	 73354	 0.005564	 0.018564	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73354	 79532	 0.0103	 0.0316	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73356	 79532	 0.014143	 0.022579	 0.00052	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73357	 73358	 0.014821	 0.009593	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73357	 79529	 0.004836	 0.007714	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73359	 73360	 0.000629	 0.002529	 0.00064	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73359	 73366	 0.001679	 0.006593	 0.00172	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73359	 79529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73359	 79529	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73360	 73362	 0.000957	 0.003843	 0.00097	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73361	 79530	 0.025479	 0.01805	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79524	 73362	 0.001271	 0.006479	 0.00163	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73362	 79530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73362	 79530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79530	 73363	 0.011843	 0.007664	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73364	 73403	 0.005386	 0.0125	 0.00381	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73364	 79531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73364	 79531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79531	 73365	 0.021807	 0.014121	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73366	 73406	 0.002407	 0.009793	 0.00239	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73366	 79532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73366	 79532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73367	 73368	 0.003707	 0.008479	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73367	 73374	 0.009007	 0.020914	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73368	 73384	 0.005271	 0.014971	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73369	 73370	 0.008129	 0.012971	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73369	 73375	 0.004907	 0.011136	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73370	 73373	 0.004064	 0.020171	 0.00048	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73370	 73384	 0.033664	 0.033071	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73370	 73387	 0.002571	 0.01	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73371	 73372	 0.019386	 0.01255	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73371	 73373	 0.004579	 0.011764	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73371	 73385	 0.00945	 0.016621	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73372	 73374	 0.021686	 0.019571	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79525	 73373	 0.035836	 0.0549	 0.00077	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79526	 73374	 0.008921	 0.018336	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73374	 79535	 0.080271	 0.109529	 0.00196	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73375	 73376	 0.003379	 0.008686	 0.00014	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73376	 73378	 0.005371	 0.013807	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73377	 73378	 0.007	 0.014379	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73377	 73409	 0.015036	 0.043129	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73378	 73390	 0.003086	 0.00705	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73379	 73383	 0.0126	 0.008157	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73380	 73381	 0.001864	 0.006143	 0.0001	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73380	 73384	 0.004857	 0.014279	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73381	 73409	 0.00675	 0.0207	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73382	 73409	 0.033914	 0.021957	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73383	 73384	 0.007521	 0.004871	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73385	 73391	 0.012507	 0.0092	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73386	 73387	 0.0122	 0.009657	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73387	 73389	 0.003214	 0.010971	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73389	 73396	 0.003707	 0.010907	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73390	 79533	 0.004336	 0.010979	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73391	 73392	 0.007936	 0.005621	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73393	 73410	 0.00145	 0.014786	 0.00381	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73393	 79533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73393	 79533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73394	 73395	 0.001943	 0.007771	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79533	 73394	 0.00695	 0.014286	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73394	 79536	 0.007507	 0.04015	 0.00121	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73395	 73399	 0.002786	 0.008536	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79533	 73396	 0.003943	 0.011586	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73397	 73398	 0.017486	 0.011321	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73397	 73399	 0.0033	 0.007543	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79527	 73397	 0.010486	 0.027793	 0.00071	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73400	 73401	 0.028843	 0.046264	 0.00086	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79525	 73400	 0.047029	 0.096243	 0.00237	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73400	 79536	 0.011721	 0.045771	 0.00101	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73401	 73402	 0.005736	 0.034743	 0.00109	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79527	 73401	 0.014557	 0.04855	 0.00077	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73402	 73431	 0.016514	 0.106564	 0.00339	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73403	 73432	 0.007793	 0.035743	 0.00916	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73403	 74464	 0.016693	 0.072686	 0.02072	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73404	 73405	 0.021779	 0.015429	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79530	 73404	 0.002457	 0.0151	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73404	 79534	 0.00755	 0.033457	 0.00101	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73406	 79534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73406	 79534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73406	 79538	 0.006507	 0.016729	 0.00414	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78184	 73407	 0.018179	 0.069143	 0.01936	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73407	 79535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73407	 79535	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79377	 73408	 0.089507	 0.183979	 0.00351	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73410	 73425	 0.000864	 0.011814	 0.00422	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73410	 79536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73410	 79536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73411	 73414	 0.031357	 0.022214	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73414	 73416	 0.00225	 0.012786	 0.00039	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73415	 73416	 0.014186	 0.011229	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73416	 73417	 0.002607	 0.006914	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73416	 79537	 0.002429	 0.015479	 0.00038	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73417	 73418	 0.006057	 0.011264	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73418	 73419	 0.005993	 0.012257	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73418	 73421	 0.00895	 0.015736	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73418	 79537	 0.003407	 0.020964	 0.00038	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73419	 73420	 0.018336	 0.016543	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73421	 73422	 0.010757	 0.006964	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73423	 73424	 0.01005	 0.017671	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73424	 79537	 0.005907	 0.012086	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73425	 73427	 0.00015	 0.002536	 0.00076	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73426	 73429	 0.009636	 0.069329	 0.00227	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73426	 79537	 0.001229	 0.008357	 0.00021	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73427	 73428	 0.002221	 0.017007	 0.00456	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79362	 73427	 0.017336	 0.126779	 0.03265	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73427	 79537	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73427	 79537	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73429	 73431	 0.018243	 0.081286	 0.00138	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78203	 73429	 0.060214	 0.268436	 0.00456	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78203	 73429	 0.060214	 0.268436	 0.00456	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78203	 73430	 0.131729	 0.118864	 0.00199	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73433	 73434	 0.022893	 0.040257	 0.00076	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73433	 79761	 0.034207	 0.07	 0.00172	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73435	 73437	 0.021464	 0.029264	 0.00065	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78274	 73435	 0.003657	 0.0068	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78274	 73436	 0.024121	 0.054721	 0.00109	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73437	 73438	 0.055743	 0.059529	 0.00126	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73438	 73443	 0.041986	 0.052121	 0.00114	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73439	 73441	 0.002236	 0.016214	 0.00041	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73439	 73447	 0.000743	 0.005636	 0.00019	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73440	 73441	 0.004014	 0.007464	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73440	 73455	 0.008821	 0.015514	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73441	 73442	 0.013014	 0.010707	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73443	 73455	 0.003336	 0.006207	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78331	 73443	 0.013921	 0.054171	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73444	 79538	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79539	 73444	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79539	 73445	 0.037986	 0.040564	 0.00086	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79538	 73446	 0.002264	 0.007757	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73446	 79540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73446	 79540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79539	 73447	 0.005736	 0.030807	 0.00073	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79540	 73447	 0.002229	 0.009543	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73448	 73456	 0.011086	 0.00785	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79540	 73449	 0.02605	 0.023343	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79539	 73450	 0.025293	 0.020014	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73451	 79541	 0.011743	 0.0076	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73452	 79541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73452	 79541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79539	 73453	 0.032307	 0.083057	 0.00129	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73454	 73455	 0.0103	 0.00815	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79540	 73456	 0.023421	 0.016586	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79532	 73457	 0.068257	 0.080014	 0.00139	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79539	 73457	 0.026079	 0.030564	 0.00053	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73458	 73464	 0.003643	 0.011879	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79538	 73458	 0.005414	 0.029093	 0.00716	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73459	 79542	 0.014657	 0.050057	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78168	 73460	 0.010086	 0.03035	 0.0095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73460	 79542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73460	 79542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73461	 79544	 0.017829	 0.015971	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73462	 73463	 0.0098	 0.01565	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73462	 73473	 0.042457	 0.096307	 0.00192	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73462	 79544	 0.011707	 0.02965	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73464	 73465	 0.000793	 0.002821	 0.00063	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73465	 73471	 0.001414	 0.0041	 0.00099	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73465	 79543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73465	 79543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73466	 73467	 0.005307	 0.009336	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79525	 73466	 0.069807	 0.230429	 0.00374	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79542	 73466	 0.049793	 0.061807	 0.00135	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79543	 73466	 0.014664	 0.014407	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73466	 79544	 0.032136	 0.02645	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73467	 73468	 0.009007	 0.009093	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73468	 79544	 0.017507	 0.011336	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73469	 73471	 0.001271	 0.003464	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73469	 79544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73469	 79544	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79543	 73470	 0.026157	 0.018529	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73470	 79545	 0.011993	 0.007764	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73471	 79545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73471	 79545	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73472	 74530	 0.044379	 0.189786	 0.00429	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78331	 73472	 0.02695	 0.094371	 0.00261	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78251	 73473	 0.025021	 0.111514	 0.00189	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73474	 73526	 0.091936	 0.188986	 0.00361	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78350	 73474	 0.064236	 0.197129	 0.00534	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73475	 79546	 0.078136	 0.08345	 0.00176	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73476	 79546	 0.0389	 0.025186	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73477	 73478	 5.7e-05	 0.000671	 0.04589	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73477	 73523	 0.000164	 0.002214	 0.15159	 1813.0	 1903.65	 1994.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73477	 79546	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73477	 79546	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73479	 73480	 0.015764	 0.032257	 0.00079	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73479	 79547	 0.154429	 0.210614	 0.00467	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73480	 73481	 0.005121	 0.013164	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79546	 73481	 0.008414	 0.024136	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 73482	 0.062629	 0.170929	 0.03776	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73482	 79547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73482	 79547	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73483	 73484	 0.061079	 0.043271	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73484	 73526	 0.104236	 0.09405	 0.00157	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73485	 73486	 0.0771	 0.055736	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73485	 73488	 0.018564	 0.029629	 0.00069	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73485	 73490	 0.036286	 0.082314	 0.00164	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73485	 73526	 0.064164	 0.214093	 0.00339	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73487	 73488	 0.010464	 0.0167	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73487	 73490	 0.017993	 0.036814	 0.00091	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73489	 73490	 0.020843	 0.014764	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73490	 73491	 0.035671	 0.028229	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78154	 73490	 0.017007	 0.101907	 0.00245	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73492	 79549	 0.041993	 0.041257	 0.00069	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73493	 73496	 0.021393	 0.016936	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73494	 73495	 0.010921	 0.019214	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73494	 73503	 0.024071	 0.032836	 0.00059	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73495	 73496	 0.007471	 0.015279	 0.00038	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73496	 79548	 0.019321	 0.023979	 0.00052	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73496	 79549	 0.015586	 0.022714	 0.00051	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73496	 79550	 0.016557	 0.034029	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73497	 79548	 0.010171	 0.012629	 0.00028	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73498	 73500	 0.002179	 0.009007	 0.00213	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73498	 79548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73498	 79548	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73499	 73501	 0.003343	 0.009679	 0.00234	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73499	 79549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73499	 79549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73499	 79551	 0.024036	 0.085007	 0.01917	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 73500	 0.009871	 0.035914	 0.01099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73500	 79550	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73500	 79550	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73501	 73524	 0.017236	 0.041536	 0.01173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 73501	 0.010279	 0.048993	 0.01162	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78241	 73501	 0.095557	 0.292179	 0.06454	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73502	 73503	 0.059664	 0.053829	 0.0009	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73502	 73506	 0.019421	 0.098264	 0.00171	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79550	 73502	 0.00445	 0.025286	 0.00046	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73503	 73504	 0.0683	 0.056221	 0.00114	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73503	 73508	 0.034479	 0.132657	 0.00226	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73503	 73514	 0.117943	 0.30335	 0.0047	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78154	 73503	 0.033786	 0.181479	 0.00431	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79548	 73503	 0.007943	 0.030436	 0.00086	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73503	 79612	 0.161243	 0.300079	 0.00703	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78154	 73505	 0.032171	 0.107321	 0.0017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79550	 73505	 0.026879	 0.060971	 0.00121	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73506	 73507	 0.005479	 0.018721	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73507	 73512	 0.008621	 0.021829	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73508	 73509	 0.024271	 0.023843	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73508	 73510	 0.0136	 0.025279	 0.00059	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73509	 79552	 0.065721	 0.089671	 0.0016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73510	 73511	 0.011957	 0.010714	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73510	 73513	 0.027571	 0.01785	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73511	 73512	 0.009543	 0.011193	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73511	 73513	 0.022607	 0.017886	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73514	 73522	 0.457943	 0.324914	 0.00514	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73514	 73733	 0.202307	 0.198829	 0.00336	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73515	 73517	 0.00065	 0.004093	 0.00857	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73515	 79551	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79552	 73515	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73516	 79553	 0.009693	 0.022157	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73516	 79613	 0.034429	 0.064021	 0.0015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73517	 73737	 0.000929	 0.006007	 0.01196	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78152	 73517	 0.002736	 0.034829	 0.06591	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73517	 79553	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73517	 79553	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73518	 73519	 0.002979	 0.007186	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73518	 79554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73518	 79554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73519	 73524	 0.000864	 0.002229	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73519	 79555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73519	 79555	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73520	 73521	 0.059836	 0.043257	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79546	 73520	 0.041657	 0.122514	 0.00251	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79554	 73520	 0.013371	 0.027486	 0.00052	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79554	 73521	 0.018021	 0.01925	 0.00041	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78332	 73522	 0.083879	 0.2867	 0.00624	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73523	 79556	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73523	 79556	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79555	 73525	 0.066636	 0.078114	 0.00136	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73527	 73528	 0.001029	 0.004593	 0.00125	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73527	 79562	 0.002736	 0.009557	 0.00317	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73528	 79557	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73528	 79557	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73530	 73531	 0.007736	 0.0076	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79515	 73531	 0.010121	 0.00655	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73532	 79558	 0.016043	 0.011364	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73533	 73535	 0.004464	 0.0113	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73533	 79559	 0.007029	 0.011843	 0.00017	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73534	 73540	 0.001229	 0.005086	 0.0012	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73534	 79558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73534	 79558	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73535	 73536	 0.003064	 0.007007	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73536	 73539	 0.011007	 0.013664	 0.0003	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73537	 73541	 0.018229	 0.0118	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73538	 73539	 0.014179	 0.009179	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73540	 73544	 0.001121	 0.004557	 0.00111	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73540	 79559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73540	 79559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73541	 73542	 0.004914	 0.009729	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79559	 73541	 0.005571	 0.012643	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73542	 73543	 0.010221	 0.010229	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73543	 73546	 0.009043	 0.008164	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73544	 79560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73544	 79560	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73544	 79562	 0.003243	 0.013379	 0.00316	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73545	 73547	 0.0044	 0.008714	 0.00013	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73545	 73548	 0.0135	 0.008736	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73545	 73549	 0.005207	 0.013386	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79560	 73546	 0.012786	 0.017421	 0.00039	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73547	 73560	 0.013029	 0.0128	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73549	 73556	 0.004593	 0.0135	 0.00028	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73549	 79561	 0.002936	 0.0098	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73550	 73552	 0.017907	 0.012686	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73551	 79561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73551	 79561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73551	 79562	 0.002821	 0.008557	 0.00187	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73552	 73554	 0.013486	 0.014836	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79557	 73553	 0.009607	 0.0368	 0.00104	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73553	 79563	 0.006193	 0.011514	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73553	 79565	 0.005607	 0.0269	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73554	 79563	 0.005471	 0.0112	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73555	 73628	 0.001336	 0.018757	 0.03598	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78513	 73555	 0.001614	 0.0202	 0.08231	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73555	 79562	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79563	 73555	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73556	 79565	 0.003914	 0.013371	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73557	 73567	 0.012079	 0.009564	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73558	 73559	 0.018693	 0.0121	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73558	 73562	 0.033586	 0.021743	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79561	 73558	 0.010479	 0.026943	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73560	 73561	 0.014114	 0.009136	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73563	 73682	 0.034271	 0.022186	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73564	 73565	 0.027636	 0.017893	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73565	 73678	 0.027271	 0.037179	 0.00082	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73565	 79565	 0.031364	 0.064186	 0.00158	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73566	 73569	 0.053386	 0.041843	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73567	 73682	 0.011721	 0.011514	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73567	 79565	 0.010907	 0.021593	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73568	 73569	 0.001743	 0.004614	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73568	 79564	 0.003614	 0.010621	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73569	 79565	 0.006293	 0.014393	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73570	 73573	 0.001129	 0.0055	 0.00152	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73570	 73577	 0.000979	 0.003914	 0.00099	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73570	 73578	 0.001336	 0.006029	 0.00161	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73570	 79564	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73570	 79564	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73571	 73572	 0.013571	 0.010636	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73572	 73574	 0.0009	 0.005136	 9e-05	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79564	 73572	 0.001914	 0.009179	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73573	 73586	 0.005086	 0.024243	 0.00575	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79562	 73573	 0.000557	 0.006243	 0.00181	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73573	 79565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73573	 79565	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79563	 73574	 0.0032	 0.020421	 0.0005	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73575	 73579	 0.012986	 0.0092	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73575	 73683	 0.004121	 0.016086	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73575	 79568	 0.016121	 0.033129	 0.00063	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79564	 73576	 0.0156	 0.01105	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73577	 73578	 0.000793	 0.002779	 0.00092	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73578	 73580	 0.000571	 0.00235	 0.00056	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73578	 73581	 0.0011	 0.004579	 0.00143	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73578	 79566	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73578	 79566	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79566	 73579	 0.011386	 0.0115	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73580	 73581	 0.000721	 0.002929	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73581	 73582	 0.001371	 0.005657	 0.00134	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73581	 73599	 0.00405	 0.018571	 0.00476	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73582	 73584	 0.001193	 0.003736	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73582	 73586	 0.001786	 0.006493	 0.00199	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73582	 73594	 0.003543	 0.0142	 0.00358	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79562	 73582	 0.001693	 0.015914	 0.00482	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73582	 79567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73582	 79567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79567	 73583	 0.018657	 0.012079	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73584	 73595	 0.002157	 0.009893	 0.00254	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73584	 79568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73584	 79568	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79568	 73585	 0.005214	 0.013214	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73585	 79569	 0.014014	 0.011093	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73586	 73589	 0.000629	 0.002286	 0.0007	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73586	 73591	 0.000986	 0.004086	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73586	 79569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73586	 79569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79568	 73587	 0.0291	 0.020614	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73588	 73589	 0.001714	 0.005579	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73588	 73599	 0.001729	 0.006107	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73589	 73595	 0.001021	 0.004836	 0.00116	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73590	 79570	 0.012479	 0.008079	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73591	 73593	 0.000607	 0.002657	 0.00076	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73591	 79570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73591	 79570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79570	 73592	 0.014964	 0.0106	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73593	 73595	 0.001293	 0.003007	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73593	 73608	 0.00095	 0.0036	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73593	 79571	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73593	 79571	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73594	 73595	 0.000543	 0.001864	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73594	 73607	 0.000871	 0.003057	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73594	 73609	 0.000929	 0.003264	 0.00108	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73594	 79572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73594	 79572	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73595	 73605	 0.001714	 0.005871	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73595	 79573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73595	 79573	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73595	 79583	 0.005357	 0.020357	 0.0057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79573	 73596	 0.0146	 0.00945	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79573	 73597	 0.006636	 0.013136	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73597	 79577	 0.015193	 0.012021	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73598	 73599	 0.001757	 0.004643	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73598	 73605	 0.001079	 0.002929	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73598	 79574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73598	 79574	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73599	 73643	 0.005771	 0.025107	 0.00715	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73599	 79575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73599	 79575	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79575	 73600	 0.018357	 0.011886	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73601	 73625	 0.003571	 0.012193	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79575	 73601	 0.003529	 0.010829	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73602	 73604	 0.002221	 0.009886	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73602	 73624	 0.003514	 0.0123	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73603	 73606	 0.001164	 0.004129	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73603	 79576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73603	 79576	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73603	 79583	 0.002864	 0.010893	 0.00305	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79574	 73604	 0.002064	 0.011721	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79576	 73604	 0.018607	 0.013179	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73605	 79577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73605	 79577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73606	 73607	 0.001071	 0.003621	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73606	 79578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73606	 79578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73607	 79579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73607	 79579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73608	 73611	 0.001493	 0.005129	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73608	 79580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73608	 79580	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73609	 73610	 0.000664	 0.002064	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73609	 79581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73609	 79581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73610	 73611	 0.000793	 0.002164	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73610	 73614	 0.001393	 0.004771	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73611	 73614	 0.000671	 0.002557	 0.00071	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73612	 73616	 0.009193	 0.013393	 0.0003	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73612	 73617	 0.015286	 0.0099	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73612	 73619	 0.011564	 0.00915	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73613	 73616	 0.012886	 0.009129	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73614	 79582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73614	 79582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73614	 79583	 0.004393	 0.014657	 0.00371	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73615	 73616	 0.009007	 0.007129	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73616	 73647	 0.007764	 0.017607	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73617	 73618	 0.009314	 0.006029	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73620	 73621	 0.002636	 0.009007	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79582	 73620	 0.004443	 0.017107	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73621	 73622	 0.002571	 0.006814	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73621	 73624	 0.018921	 0.020814	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73622	 73623	 0.003379	 0.008557	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73623	 73647	 0.0088	 0.015471	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73624	 73626	 0.014457	 0.025421	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73624	 73627	 0.003914	 0.011236	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73624	 79584	 0.026629	 0.028436	 0.0006	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73625	 73626	 0.004814	 0.011014	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73627	 73630	 0.007721	 0.013579	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78422	 73628	 0.002029	 0.013779	 0.03174	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73628	 79583	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79584	 73628	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73629	 73631	 0.002593	 0.0101	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73629	 73632	 0.010921	 0.008643	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73629	 73636	 0.016021	 0.025579	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 73629	 0.002457	 0.009429	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73630	 73633	 0.004314	 0.009779	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 73630	 0.002921	 0.008593	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73631	 73640	 0.002979	 0.00915	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73633	 73634	 0.004714	 0.010686	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73634	 73635	 0.003793	 0.0086	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73635	 73636	 0.003793	 0.008607	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73636	 73637	 0.004836	 0.016521	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73637	 79590	 0.00535	 0.020571	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73638	 73640	 0.003757	 0.013164	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73638	 79590	 0.004107	 0.012607	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73639	 73640	 0.011186	 0.00885	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73640	 79585	 0.008493	 0.009957	 0.00017	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73641	 73643	 0.000579	 0.002014	 0.00067	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 73641	 0.001521	 0.005786	 0.00162	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73641	 79585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73641	 79585	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73642	 73643	 0.000943	 0.003586	 0.001	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73642	 73649	 0.000543	 0.002371	 0.00068	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 73642	 0.002536	 0.012007	 0.00289	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73642	 79586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73642	 79586	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73643	 73652	 0.001521	 0.005536	 0.00169	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73643	 74063	 0.006936	 0.031807	 0.00815	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 73643	 0.001771	 0.008371	 0.00201	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73643	 79587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73643	 79587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73644	 73654	 0.011943	 0.009364	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79586	 73644	 0.014943	 0.009671	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79587	 73644	 0.003743	 0.012493	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 73645	 0.005364	 0.018336	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73646	 73647	 0.01915	 0.017157	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 73647	 0.0041	 0.015714	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73648	 79588	 0.001614	 0.007736	 0.00023	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73648	 79591	 0.005107	 0.022636	 0.00068	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73649	 73651	 0.000421	 0.002121	 0.00055	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73650	 79588	 0.005886	 0.0094	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73650	 79589	 0.003221	 0.008157	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73651	 73660	 0.000671	 0.003293	 0.00091	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73651	 79588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73651	 79588	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73652	 73658	 0.001286	 0.005314	 0.00126	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73652	 79589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73652	 79589	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79589	 73653	 0.008943	 0.005793	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79589	 73655	 0.0195	 0.015286	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73656	 73657	 0.001221	 0.0042	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73656	 79590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73656	 79590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73657	 73658	 0.000714	 0.002393	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73658	 73659	 0.000721	 0.002886	 0.00097	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73659	 73668	 0.001457	 0.006057	 0.00189	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73660	 73667	 0.000729	 0.003779	 0.00092	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73661	 79591	 0.028621	 0.020279	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73661	 79597	 0.022943	 0.01625	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73662	 73663	 0.001107	 0.005086	 0.00131	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73662	 73664	 0.002864	 0.00965	 0.0024	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 73662	 0.002971	 0.029621	 0.011	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73662	 79591	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73662	 79591	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73663	 73664	 0.002057	 0.005164	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73663	 79592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73663	 79592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73663	 79640	 0.006536	 0.017536	 0.00397	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73664	 73666	 0.001371	 0.003621	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73664	 79640	 0.0047	 0.0122	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79592	 73665	 0.025036	 0.016207	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73665	 79593	 0.014871	 0.010536	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73666	 73668	 0.003507	 0.009414	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73666	 73681	 0.00125	 0.004207	 0.00104	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73666	 74068	 0.001371	 0.004607	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73666	 79593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73666	 79593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73667	 73681	 0.001007	 0.003821	 0.00107	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73667	 79594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73667	 79594	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73668	 74075	 0.000857	 0.003379	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73668	 79595	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73668	 79595	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73669	 73670	 0.004057	 0.007543	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79595	 73669	 0.003057	 0.007736	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73670	 79683	 0.008464	 0.013514	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73671	 73672	 0.001221	 0.003229	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73671	 74074	 0.002336	 0.006264	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73672	 79596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73672	 79596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73673	 79684	 0.08635	 0.061171	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79590	 73674	 0.02845	 0.02015	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79596	 73675	 0.066643	 0.059721	 0.00122	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73676	 73677	 0.069057	 0.048921	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73676	 73678	 0.048721	 0.066414	 0.00147	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79567	 73676	 0.051021	 0.06955	 0.00154	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79584	 73679	 0.090857	 0.123971	 0.00221	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73680	 74080	 0.235386	 0.152464	 0.0029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73681	 79597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73681	 79597	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79563	 73683	 0.0054	 0.029736	 0.00067	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73684	 73685	 0.000186	 0.002207	 0.00428	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73684	 73755	 0.00055	 0.006079	 0.01156	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73684	 79598	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73684	 79598	 0.001863	 0.072643	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73685	 73687	 0.000107	 0.001229	 0.00459	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73685	 79599	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73685	 79599	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73686	 73712	 0.021664	 0.086793	 0.02189	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79599	 73686	 0.002721	 0.010593	 0.00283	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73687	 73697	 0.000343	 0.002736	 0.0092	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73687	 79600	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79601	 73687	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73688	 79602	 0.012286	 0.007957	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73689	 73698	 0.001621	 0.005557	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79600	 73689	 0.000943	 0.003779	 0.00095	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73689	 79602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73689	 79602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73690	 73693	 0.006114	 0.017971	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79602	 73690	 0.002479	 0.009679	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73691	 73692	 0.0494	 0.034993	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79601	 73692	 0.00605	 0.01405	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79602	 73692	 0.012221	 0.016671	 0.0003	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73693	 73695	 0.004107	 0.010407	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73694	 73695	 0.0567	 0.040164	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73695	 79603	 0.00545	 0.0112	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73696	 73697	 0.000171	 0.001393	 0.00456	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73696	 73710	 0.001271	 0.014914	 0.03329	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73696	 79603	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73696	 79603	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73697	 79604	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73697	 79604	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73698	 73704	 0.001171	 0.006107	 0.0016	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79604	 73698	 0.000529	 0.002021	 0.00056	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73698	 79605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73698	 79605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73699	 73700	 0.004864	 0.008564	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79602	 73699	 0.006407	 0.011264	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73700	 73701	 0.015021	 0.010643	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79605	 73700	 0.010879	 0.007707	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73701	 73703	 0.011336	 0.008029	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79603	 73702	 0.008336	 0.021114	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79605	 73702	 0.003714	 0.010914	 0.00022	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73704	 73705	 0.000664	 0.003829	 0.00109	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73705	 73769	 0.001214	 0.00735	 0.00188	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79603	 73706	 0.053614	 0.042429	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73707	 73711	 0.034514	 0.098993	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79603	 73707	 0.014586	 0.056964	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73708	 73709	 0.011521	 0.009486	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73708	 73711	 0.025007	 0.043979	 0.00083	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73709	 79607	 0.019786	 0.033329	 0.00047	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73710	 74718	 0.003036	 0.026593	 0.04851	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73710	 79606	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79607	 73710	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73712	 79608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73712	 79608	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73713	 73738	 0.025493	 0.083193	 0.02211	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73713	 79609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73713	 79609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73713	 79618	 0.025807	 0.068236	 0.01598	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73714	 73716	 0.0016	 0.012179	 0.02216	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73714	 73753	 0.003036	 0.020464	 0.03769	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73714	 79610	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73714	 79610	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79608	 73715	 0.127571	 0.252679	 0.00371	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79609	 73715	 0.083507	 0.133314	 0.00307	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79610	 73715	 0.080864	 0.129093	 0.00297	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73716	 73755	 0.001429	 0.016221	 0.03563	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73716	 79611	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73716	 79611	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73717	 73721	 0.037114	 0.026286	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73717	 73752	 0.224129	 0.158821	 0.00251	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73718	 73722	 0.029436	 0.068343	 0.00101	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73718	 73733	 0.046021	 0.085571	 0.002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79609	 73718	 0.294143	 0.208493	 0.00329	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73719	 73720	 0.009936	 0.022543	 0.00045	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73719	 73723	 0.011479	 0.032914	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73720	 73721	 0.010179	 0.01715	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73720	 73722	 0.023943	 0.0216	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73721	 73722	 0.023493	 0.016643	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73721	 73724	 0.022729	 0.016429	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73723	 73725	 0.039714	 0.028129	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73723	 79615	 0.005071	 0.027129	 0.00082	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73726	 73727	 0.011893	 0.0077	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73726	 73730	 0.005814	 0.008907	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73727	 73728	 0.018386	 0.013293	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73728	 79615	 0.031343	 0.033471	 0.00071	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73729	 73730	 0.0117	 0.007571	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73730	 79612	 0.006571	 0.01345	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73731	 79613	 0.01835	 0.014521	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73732	 73733	 0.013779	 0.028314	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73732	 79612	 0.012886	 0.02395	 0.00056	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73733	 79615	 0.028314	 0.072793	 0.00113	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73734	 79612	 0.003657	 0.007514	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73734	 79613	 0.003657	 0.0085	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73735	 73736	 0.001236	 0.003857	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73735	 73738	 0.003207	 0.008057	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79611	 73735	 0.044914	 0.154379	 0.03708	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73735	 79612	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73735	 79612	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73736	 79613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73736	 79613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73736	 79614	 0.001957	 0.00795	 0.00194	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73737	 79614	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73737	 79614	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79551	 73738	 0.007279	 0.0303	 0.00945	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79614	 73738	 0.002857	 0.010393	 0.00318	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73738	 79615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73738	 79615	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73738	 79617	 0.016457	 0.066993	 0.01633	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73739	 73740	 0.0118	 0.009336	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79612	 73739	 0.004407	 0.007036	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79615	 73739	 0.038307	 0.0248	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79552	 73741	 0.047693	 0.1082	 0.00216	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79615	 73741	 0.132714	 0.094021	 0.00149	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73742	 73770	 0.01795	 0.046614	 0.01131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73742	 79616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73742	 79616	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73742	 79617	 0.004664	 0.016314	 0.00541	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73742	 79618	 0.003679	 0.009721	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73743	 73750	 0.001364	 0.009643	 0.02041	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78152	 73743	 0.003564	 0.043429	 0.14104	 794.0	 833.7	 873.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73743	 79617	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73743	 79617	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73744	 73746	 0.00925	 0.007614	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73744	 73748	 0.012114	 0.009586	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73744	 79619	 0.009964	 0.020471	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73745	 73747	 0.012393	 0.008021	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73745	 73749	 0.014993	 0.009707	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79616	 73745	 0.084414	 0.066807	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73745	 79619	 0.032107	 0.025407	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73745	 79625	 0.177579	 0.1284	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73746	 73751	 0.016121	 0.012757	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73747	 73749	 0.025721	 0.018221	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73747	 79619	 0.014007	 0.0154	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73750	 73753	 0.001286	 0.009029	 0.01537	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73750	 79618	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79619	 73750	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79616	 73752	 0.055307	 0.054329	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73754	 73758	 0.006036	 0.023493	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73754	 79620	 0.024193	 0.032979	 0.00073	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73754	 79621	 0.004307	 0.021557	 0.00039	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73755	 79620	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73755	 79620	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73756	 79623	 0.0155	 0.010979	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73757	 73758	 0.004586	 0.01215	 0.00031	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79602	 73757	 0.0286	 0.082036	 0.00126	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73758	 79624	 0.018057	 0.016629	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73759	 73763	 0.005214	 0.009179	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73759	 79623	 0.007693	 0.013529	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73760	 73762	 0.00075	 0.002907	 0.00078	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73760	 73764	 0.001693	 0.007614	 0.00203	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73760	 73766	 0.000979	 0.00725	 0.00276	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73760	 79621	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73760	 79621	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79621	 73761	 0.005143	 0.009564	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73761	 79622	 0.001864	 0.003464	 8e-05	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73762	 79622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73762	 79622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79622	 73763	 0.00465	 0.0092	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73764	 79623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73764	 79623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79611	 73765	 0.005657	 0.02	 0.00451	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73766	 73767	 0.000736	 0.00395	 0.00109	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79599	 73766	 0.004829	 0.016107	 0.00409	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73766	 79624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73766	 79624	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73767	 73768	 0.001657	 0.004264	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73767	 73769	 0.001021	 0.0054	 0.0018	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79598	 73768	 0.001179	 0.003021	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73770	 73772	 0.069271	 0.161286	 0.04931	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73770	 79625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73770	 79625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79621	 73771	 0.019671	 0.015564	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73773	 73774	 0.008307	 0.012457	 0.00023	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73773	 73783	 0.005271	 0.012243	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73773	 73784	 0.016507	 0.011693	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73773	 79636	 0.004521	 0.01765	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73775	 73818	 0.01	 0.027229	 0.006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73775	 73832	 0.00485	 0.012821	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73775	 79626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73775	 79626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73776	 73941	 0.018021	 0.012764	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73777	 73795	 0.003793	 0.0086	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73777	 73941	 0.008843	 0.016436	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79626	 73778	 0.013064	 0.008457	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73779	 73780	 0.006814	 0.010936	 0.0002	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73779	 73792	 0.008086	 0.011029	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79626	 73779	 0.003843	 0.013129	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73780	 73781	 0.004743	 0.004657	 8e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73780	 73782	 0.003621	 0.008414	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73780	 73786	 0.013529	 0.008757	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73781	 73791	 0.004786	 0.005114	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73782	 73783	 0.0036	 0.0067	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73785	 73787	 0.014136	 0.010014	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73787	 73788	 0.010843	 0.007021	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73787	 73789	 0.016643	 0.016814	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73787	 79634	 0.003279	 0.007443	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73789	 73790	 0.010329	 0.007321	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73789	 73876	 0.006971	 0.007043	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73791	 73826	 0.00475	 0.008357	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73792	 73827	 0.014136	 0.010014	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73793	 73794	 0.015664	 0.010143	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73794	 73798	 0.011536	 0.015729	 0.00035	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73794	 73802	 0.017486	 0.012386	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79626	 73794	 0.009086	 0.0186	 0.00046	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73795	 73796	 0.00345	 0.010157	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73795	 73966	 0.018507	 0.011986	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73796	 73798	 0.00335	 0.009843	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73797	 73798	 0.0108	 0.010607	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73797	 73967	 0.006079	 0.008286	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73798	 73799	 0.004521	 0.006586	 0.00015	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73799	 73800	 0.007643	 0.008407	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73800	 73805	 0.008614	 0.011329	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73801	 73802	 0.011771	 0.009314	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73801	 73804	 0.0223	 0.0158	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73803	 73804	 0.014393	 0.012986	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73803	 79628	 0.018321	 0.016421	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73804	 73819	 0.006636	 0.00995	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73805	 73806	 0.016679	 0.0108	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73805	 73820	 0.029229	 0.029314	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73806	 73807	 0.01425	 0.010093	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73807	 73812	 0.032257	 0.020886	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73807	 79655	 0.006129	 0.010771	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73808	 73811	 0.013736	 0.010871	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73808	 79655	 0.013779	 0.011343	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73809	 73980	 0.011621	 0.013621	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73809	 79655	 0.033443	 0.02165	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73810	 73811	 0.025921	 0.016779	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73810	 73816	 0.008657	 0.0118	 0.00026	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73812	 73813	 0.008964	 0.010507	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73813	 73819	 0.007307	 0.011664	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73814	 74091	 0.0071	 0.014064	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73814	 79627	 0.008721	 0.015343	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73815	 73817	 0.016793	 0.013293	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73816	 73981	 0.027686	 0.021907	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73816	 79627	 0.008486	 0.024336	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73817	 73821	 0.004964	 0.010157	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73817	 79627	 0.001936	 0.005686	 0.00011	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73818	 74119	 0.001343	 0.004786	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73818	 79627	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73818	 79627	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73819	 73820	 0.005864	 0.008793	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73820	 73821	 0.004807	 0.009886	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73820	 74093	 0.012443	 0.019964	 0.00037	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73821	 74093	 0.025379	 0.016429	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73822	 73826	 0.01195	 0.010707	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73822	 73830	 0.009421	 0.006671	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73823	 73828	 0.022636	 0.014657	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73823	 73834	 0.008814	 0.01745	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73823	 73842	 0.041721	 0.033021	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73823	 79686	 0.029429	 0.058271	 0.00086	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73824	 73830	 0.009607	 0.006807	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73824	 73833	 0.034614	 0.027393	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73824	 73866	 0.012607	 0.008164	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73824	 73868	 0.007707	 0.013557	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73825	 73831	 0.007571	 0.0049	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73826	 79628	 0.0072	 0.014729	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73828	 73829	 0.019514	 0.013821	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73829	 73835	 0.026607	 0.017229	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73829	 74093	 0.019321	 0.015143	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73829	 74095	 0.00465	 0.008643	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73831	 73833	 0.020429	 0.013229	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73831	 73839	 0.006593	 0.010529	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73831	 73867	 0.015493	 0.012257	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73832	 74099	 0.007093	 0.019036	 0.00431	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73832	 79628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73832	 79628	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73832	 79647	 0.00805	 0.028464	 0.00641	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79628	 73833	 0.005593	 0.016036	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79628	 73834	 0.005771	 0.009207	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73835	 73841	 0.010079	 0.012507	 0.00027	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73835	 73844	 0.003879	 0.011407	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73836	 73838	 0.0117	 0.008293	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73837	 74094	 0.012257	 0.0097	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73838	 73843	 0.011221	 0.007264	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73838	 73865	 0.018421	 0.016621	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73839	 73840	 0.006179	 0.007671	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73839	 73845	 0.004507	 0.010471	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73840	 73842	 0.026121	 0.020671	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73841	 73842	 0.010943	 0.01095	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73843	 73844	 0.010114	 0.007164	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73843	 74096	 0.024936	 0.019736	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73844	 74097	 0.004921	 0.0168	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73845	 79629	 0.003007	 0.008843	 0.00018	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73846	 73850	 0.001186	 0.003257	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73846	 73862	 0.003107	 0.008064	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73846	 79629	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73846	 79629	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73846	 79635	 0.007307	 0.021993	 0.00688	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73847	 73868	 0.005307	 0.009864	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79629	 73847	 0.004407	 0.01295	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73848	 73849	 0.033164	 0.021471	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73849	 73854	 0.013479	 0.013486	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73849	 73856	 0.013279	 0.0119	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73850	 73857	 0.0016	 0.004364	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73850	 79630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73850	 79630	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73851	 73852	 0.018114	 0.011729	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73851	 73853	 0.011321	 0.012086	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73851	 73874	 0.0109	 0.011643	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79629	 73851	 0.005721	 0.0145	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73852	 73872	 0.01285	 0.009107	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73853	 73854	 0.005993	 0.0064	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73854	 73855	 0.007943	 0.007807	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79630	 73855	 0.006121	 0.009771	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73856	 73859	 0.018157	 0.02475	 0.00055	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73857	 73862	 0.000693	 0.001936	 0.0005	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73857	 79631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73857	 79631	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79631	 73858	 0.013479	 0.010664	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73859	 79685	 0.016079	 0.049321	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73860	 79633	 0.028543	 0.020214	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73861	 79633	 0.039464	 0.02555	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73862	 73863	 0.001907	 0.0075	 0.00196	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73862	 79632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73862	 79632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73863	 74092	 0.001886	 0.006657	 0.0015	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73863	 74113	 0.003779	 0.012329	 0.00327	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73863	 79633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73863	 79633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73864	 73865	 0.008971	 0.009057	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79632	 73864	 0.017129	 0.015457	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73868	 73870	 0.00285	 0.005643	 9e-05	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73869	 73870	 0.008236	 0.005329	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73869	 73873	 0.013521	 0.008757	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73870	 73877	 0.004921	 0.00965	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73871	 73872	 0.015829	 0.011443	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73871	 73873	 0.013379	 0.010586	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73873	 73874	 0.007693	 0.010114	 0.00014	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73873	 73890	 0.007971	 0.01195	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73875	 73935	 0.004743	 0.015986	 0.00397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73875	 74110	 0.0112	 0.042571	 0.01192	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73875	 79634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73875	 79634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73875	 79635	 0.002543	 0.007657	 0.00239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73876	 73877	 0.011679	 0.010464	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73877	 73881	 0.013479	 0.012164	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73878	 73881	 0.005943	 0.007729	 0.00011	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79634	 73878	 0.006586	 0.010557	 0.00019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73879	 73880	 0.012371	 0.008764	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73880	 73883	 0.008979	 0.012236	 0.00027	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73880	 73904	 0.004436	 0.011414	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73881	 73882	 0.008421	 0.005457	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73883	 73884	 0.008257	 0.00535	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73883	 73889	 0.013479	 0.012164	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73885	 73887	 0.009	 0.013786	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73885	 73894	 0.018457	 0.01195	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73886	 73887	 0.01395	 0.009036	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73887	 73888	 0.012643	 0.0135	 0.00029	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73887	 73896	 0.008057	 0.016564	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79634	 73887	 0.010793	 0.02775	 0.00043	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73888	 73889	 0.009543	 0.008607	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73888	 73892	 0.01225	 0.007929	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73890	 73891	 0.008357	 0.008443	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73890	 73893	 0.0139	 0.011443	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79634	 73891	 0.024336	 0.025986	 0.00055	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73892	 73893	 0.011007	 0.007121	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73893	 73895	 0.035371	 0.025057	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73896	 73906	 0.004571	 0.010371	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73897	 73899	 0.047357	 0.03355	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73898	 73902	 0.002321	 0.009043	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73898	 79636	 0.002521	 0.008607	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73899	 73900	 0.00425	 0.009857	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73899	 73906	 0.007293	 0.014443	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73900	 73910	 0.003171	 0.009086	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73901	 73902	 0.002464	 0.005636	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73901	 73906	 0.004643	 0.008164	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73903	 79635	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79636	 73903	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73903	 79646	 0.000586	 0.005329	 0.01026	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79636	 73904	 0.01015	 0.020779	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73905	 73906	 0.017621	 0.011407	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73906	 73908	 0.0084	 0.014771	 0.00028	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73907	 73908	 0.004636	 0.009486	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79636	 73907	 0.002693	 0.016157	 0.00039	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73908	 73909	 0.00185	 0.009943	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73909	 73915	 0.003914	 0.010371	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73909	 73923	 0.011257	 0.022286	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73910	 73915	 0.004029	 0.0102	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73910	 73916	 0.036393	 0.025779	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73911	 73917	 0.002136	 0.008321	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73911	 73918	 0.011757	 0.021857	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73911	 79637	 0.005914	 0.013593	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73912	 73925	 0.005379	 0.007336	 0.00013	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73912	 79637	 0.008079	 0.007236	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73913	 73919	 0.000643	 0.003336	 0.00081	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73913	 73922	 0.001136	 0.00455	 0.00154	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78333	 73913	 0.003193	 0.009414	 0.00219	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73913	 79637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73913	 79637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73914	 73915	 0.003014	 0.007629	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73914	 73921	 0.002586	 0.006857	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73915	 79638	 0.007179	 0.0147	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73917	 73921	 0.002271	 0.008836	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73919	 73920	 0.000457	 0.002321	 0.00065	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78452	 73920	 0.001107	 0.003457	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78454	 73920	 0.003836	 0.010136	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79635	 73922	 0.003164	 0.012014	 0.00336	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73922	 79638	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73922	 79638	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73922	 79639	 0.001993	 0.008286	 0.00259	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79638	 73923	 0.003779	 0.012907	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73923	 79643	 0.035014	 0.022671	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73924	 79639	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73924	 79639	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78334	 73925	 0.0112	 0.022179	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73926	 73928	 0.000579	 0.003793	 0.00734	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73926	 79640	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73926	 79640	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78333	 73927	 0.002821	 0.01315	 0.00326	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78437	 73927	 0.00325	 0.014921	 0.00382	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73928	 74029	 0.000793	 0.005021	 0.01051	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73928	 79641	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73928	 79641	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73929	 73934	 0.001586	 0.004271	 0.0012	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73929	 79642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73929	 79642	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73929	 79665	 0.002307	 0.00705	 0.00152	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73930	 74032	 0.008471	 0.00905	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79642	 73931	 0.01255	 0.011321	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73932	 74031	 0.009979	 0.006464	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73933	 79644	 0.000957	 0.003286	 0.00079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78186	 73935	 0.018821	 0.061414	 0.01631	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78333	 73935	 0.002	 0.009314	 0.00231	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73935	 79643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73935	 79643	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73936	 73937	 0.000286	 0.002164	 0.00394	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73936	 79644	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73936	 79644	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73937	 73938	 0.000136	 0.001029	 0.00187	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73938	 79645	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73938	 79645	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73939	 73941	 0.006993	 0.020057	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78377	 73939	 0.002843	 0.015264	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73940	 79646	 0.000104	 0.008342	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73942	 79651	 0.014121	 0.01	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73943	 73945	 5e-05	 0.000743	 0.00143	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 73943	 0.0001	 0.001264	 0.00287	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73943	 79649	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73943	 79649	 0.010769	 0.33383	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79647	 73944	 0.000864	 0.003464	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73944	 79650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73944	 79650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73945	 73946	 7.1e-05	 0.000771	 0.00139	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	73945	 79651	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73945	 79651	 0.002854	 0.1113	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73946	 74029	 0.000371	 0.002593	 0.00441	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	73946	 79652	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79653	 73946	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73947	 73949	 0.002036	 0.007929	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79651	 73947	 0.0028	 0.012486	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79649	 73948	 0.023593	 0.016707	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73949	 73956	 0.001721	 0.007536	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	73949	 73958	 0.003321	 0.012736	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79648	 73949	 0.006043	 0.032471	 0.00077	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73950	 73952	 0.008886	 0.014179	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73950	 73955	 0.002629	 0.008971	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73950	 73957	 0.028021	 0.018143	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79650	 73950	 0.002407	 0.012157	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73951	 73952	 0.00915	 0.010064	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73952	 73953	 0.018486	 0.011964	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73952	 73954	 0.009893	 0.019586	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79626	 73952	 0.014671	 0.034064	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79650	 73952	 0.005314	 0.018607	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73954	 73955	 0.00345	 0.007879	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73954	 73962	 0.003136	 0.010721	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73956	 73958	 0.001807	 0.006321	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73958	 73960	 0.001129	 0.006057	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73959	 73960	 0.005793	 0.017757	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73959	 73971	 0.003557	 0.009436	 0.00024	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73959	 74004	 0.004064	 0.009221	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73960	 79654	 0.003814	 0.007086	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73961	 73985	 0.007657	 0.029779	 0.00796	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73961	 74009	 0.001343	 0.003236	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73961	 74011	 0.002464	 0.006407	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73961	 79654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73961	 79654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73962	 73963	 0.00825	 0.011243	 0.00025	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73962	 73964	 0.004543	 0.009293	 0.00023	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73963	 73967	 0.014864	 0.012236	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73964	 73965	 0.003957	 0.008121	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79654	 73964	 0.003636	 0.01115	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73965	 73968	 0.008493	 0.013557	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73965	 73974	 0.011943	 0.007729	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73967	 73968	 0.011764	 0.009686	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73968	 73970	 0.006243	 0.011607	 0.00027	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73969	 73982	 0.002843	 0.010814	 0.00303	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79647	 73969	 0.006536	 0.026157	 0.00659	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73969	 79655	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73969	 79655	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73970	 73975	 0.019486	 0.015271	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79655	 73970	 0.00455	 0.010571	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73971	 73972	 0.024036	 0.015557	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73971	 73973	 0.007593	 0.01335	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73972	 73977	 0.01545	 0.01	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73973	 73976	 0.005907	 0.012143	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73973	 73993	 0.016514	 0.010686	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73973	 73994	 0.0489	 0.0387	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79655	 73973	 0.01875	 0.037121	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73976	 73978	 0.018607	 0.013179	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73976	 73988	 0.008014	 0.014086	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73977	 73978	 0.008186	 0.010164	 0.00022	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79655	 73977	 0.005443	 0.011129	 0.00027	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73978	 73987	 0.010829	 0.014779	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73979	 73987	 0.018029	 0.011671	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79655	 73979	 0.042007	 0.041264	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73980	 79656	 0.004493	 0.007171	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73981	 74091	 0.019029	 0.015664	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	73981	 79656	 0.025714	 0.01665	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73982	 73985	 0.001807	 0.009364	 0.00229	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73982	 79656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73982	 79656	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73983	 73986	 0.017714	 0.0364	 0.00069	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73983	 79657	 0.006393	 0.019621	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73984	 73986	 0.008386	 0.019179	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73984	 73991	 0.053664	 0.038014	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73984	 79703	 0.041443	 0.161257	 0.00269	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	73985	 74081	 0.0025	 0.014629	 0.00399	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73985	 74183	 0.013029	 0.068007	 0.01639	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73985	 79657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73985	 79657	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73986	 73987	 0.007679	 0.017407	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73986	 73988	 0.011	 0.022607	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73986	 73989	 0.018143	 0.01285	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73988	 73990	 0.034443	 0.0223	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73992	 73994	 0.023486	 0.0152	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73992	 74003	 0.00955	 0.016793	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	73994	 73995	 0.03735	 0.029557	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73996	 73998	 0.035579	 0.0252	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73996	 74000	 0.004757	 0.009736	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	73996	 74001	 0.007657	 0.011721	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	73997	 74002	 0.028657	 0.0203	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	73999	 74000	 0.002179	 0.009664	 0.00022	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	73999	 74016	 0.002171	 0.010414	 0.00031	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74000	 74080	 0.02385	 0.07015	 0.00144	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74000	 79659	 0.012707	 0.028821	 0.00057	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74001	 74002	 0.009771	 0.010429	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74002	 74005	 0.007371	 0.007871	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74003	 74004	 0.003343	 0.006871	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74003	 74006	 0.008964	 0.007379	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74003	 74007	 0.027736	 0.01965	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74005	 74006	 0.011471	 0.008121	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74005	 74007	 0.016743	 0.015	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74007	 74010	 0.006879	 0.015971	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74008	 79658	 0.011636	 0.007536	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74009	 74011	 0.001579	 0.004243	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74009	 79658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74009	 79658	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74010	 79659	 0.006493	 0.013279	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74011	 79659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74011	 79659	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74011	 79665	 0.003514	 0.013357	 0.00374	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74012	 74014	 0.001907	 0.009464	 0.00023	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79653	 74012	 0.003143	 0.016893	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74013	 74014	 0.001521	 0.006736	 0.00016	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74013	 74017	 0.002279	 0.007	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74015	 74016	 0.003043	 0.01005	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74015	 74017	 0.005443	 0.014414	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74015	 74055	 0.011179	 0.014693	 0.0002	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74016	 74017	 0.001721	 0.006021	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74017	 79661	 0.0043	 0.013193	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74018	 74020	 0.001307	 0.00355	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74018	 74053	 0.001607	 0.003729	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74019	 74020	 0.000993	 0.002314	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74019	 74021	 0.001379	 0.003543	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74020	 79660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74020	 79660	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74021	 74022	 0.000586	 0.002057	 0.00046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74021	 79661	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74021	 79661	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74022	 74023	 0.000643	 0.002571	 0.00065	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74023	 74025	 0.000471	 0.001907	 0.00046	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74023	 79662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74023	 79662	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74024	 74025	 0.000414	 0.001686	 0.00041	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 74024	 0.000486	 0.001843	 0.00051	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74026	 74027	 0.000614	 0.002771	 0.00074	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74026	 74035	 0.000564	 0.002264	 0.00057	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74027	 74028	 0.001029	 0.0039	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74027	 74033	 0.002021	 0.005236	 0.00159	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74027	 79663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74027	 79663	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74027	 79665	 0.00145	 0.0059	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 74028	 0.001379	 0.005014	 0.00154	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74028	 79664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74028	 79664	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74028	 79665	 0.001264	 0.003179	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78175	 74029	 0.003357	 0.038279	 0.18999	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74029	 79665	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79666	 74029	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74030	 74032	 0.012186	 0.008629	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79666	 74031	 0.013814	 0.012464	 0.00021	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79666	 74032	 0.005143	 0.017564	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74032	 79667	 0.015286	 0.015014	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74033	 74037	 0.001221	 0.004957	 0.00121	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79665	 74033	 0.002914	 0.008914	 0.00193	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74033	 79667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74033	 79667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74034	 74035	 0.000964	 0.002843	 0.00066	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74034	 74049	 0.001193	 0.003157	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74035	 74037	 0.002493	 0.0064	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74035	 74039	 0.003271	 0.007893	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74035	 79668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74035	 79668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79668	 74036	 0.007971	 0.00565	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74037	 74039	 0.001529	 0.003686	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74037	 74043	 0.003857	 0.010564	 0.0023	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74037	 79669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74037	 79669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79669	 74038	 0.005579	 0.009814	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74038	 79677	 0.026679	 0.017271	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74039	 74040	 0.000629	 0.0026	 0.00061	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74040	 74043	 0.001621	 0.004071	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74040	 74063	 0.0025	 0.008579	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74040	 79670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74040	 79670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74041	 74042	 0.000821	 0.0022	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74041	 79671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74041	 79671	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74042	 74047	 0.001307	 0.003357	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74042	 79672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74042	 79672	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74043	 74063	 0.000914	 0.004207	 0.00108	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74043	 79673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74043	 79673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74044	 74046	 0.000964	 0.002486	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74044	 74061	 0.001407	 0.003721	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74044	 74062	 0.001671	 0.0043	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74045	 74046	 0.000879	 0.002314	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74045	 74047	 0.00075	 0.001893	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74045	 79674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74045	 79674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74046	 79675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74046	 79675	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74047	 74048	 0.000907	 0.002393	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74047	 79676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74047	 79676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74048	 74049	 0.000886	 0.002221	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74048	 79677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74048	 79677	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74050	 74051	 0.008829	 0.007264	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79677	 74050	 0.005321	 0.009364	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74051	 79679	 0.019479	 0.012607	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74052	 74053	 0.001279	 0.003421	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74052	 74057	 0.001386	 0.003671	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74052	 79678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74052	 79678	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74053	 79679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74053	 79679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74054	 74055	 0.008993	 0.014429	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74054	 74077	 0.024236	 0.017171	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79679	 74054	 0.004464	 0.013136	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74055	 74056	 0.013957	 0.009886	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74057	 74058	 0.001064	 0.002671	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74058	 74076	 0.001786	 0.0049	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74058	 79680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74058	 79680	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79676	 74059	 0.023657	 0.015314	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79675	 74060	 0.023764	 0.015386	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74061	 74062	 0.000979	 0.002586	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74061	 74079	 0.002829	 0.007343	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74062	 74073	 0.001586	 0.00565	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74062	 79681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74062	 79681	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74063	 74067	 0.001207	 0.003643	 0.00114	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79640	 74063	 0.001979	 0.00555	 0.00143	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74063	 79682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74063	 79682	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74064	 74065	 0.005379	 0.01065	 0.00016	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79671	 74064	 0.00675	 0.010114	 0.00019	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79681	 74065	 0.007857	 0.008393	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79682	 74065	 0.004193	 0.008586	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74066	 74072	 0.006121	 0.012521	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79681	 74066	 0.006279	 0.010021	 0.00023	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74067	 74068	 0.001	 0.003257	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79640	 74067	 0.002943	 0.007786	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74068	 74143	 0.003193	 0.008743	 0.0019	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74069	 74070	 0.005743	 0.010107	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79593	 74069	 0.003686	 0.00835	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74070	 74071	 0.005186	 0.010164	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74070	 74072	 0.0036	 0.010579	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79595	 74071	 0.00345	 0.014743	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74073	 74143	 0.000764	 0.002914	 0.00081	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74074	 79683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74074	 79683	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74076	 74079	 0.004036	 0.010143	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79680	 74078	 0.046014	 0.029793	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74079	 79684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74079	 79684	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74080	 74169	 0.052136	 0.1067	 0.00263	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74081	 74174	 0.003279	 0.019814	 0.00506	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74082	 74083	 0.009679	 0.006264	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74082	 74084	 0.009871	 0.025371	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74082	 74085	 0.0145	 0.009386	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74082	 74088	 0.014671	 0.027279	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74084	 74087	 0.026336	 0.0236	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74084	 79694	 0.039814	 0.139429	 0.00386	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74086	 74087	 0.013779	 0.018786	 0.00041	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74086	 79690	 0.023486	 0.048264	 0.00092	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74088	 74089	 0.018843	 0.0122	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74088	 74091	 0.005121	 0.011893	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79627	 74090	 0.0113	 0.008857	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74092	 74110	 0.002386	 0.009293	 0.00248	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74092	 74113	 0.002257	 0.006657	 0.00155	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74092	 79685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74092	 79685	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74093	 79686	 0.0102	 0.039686	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74094	 74115	 0.008936	 0.008057	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74094	 79686	 0.030721	 0.024079	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74095	 74096	 0.002657	 0.007807	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74096	 79687	 0.003043	 0.01485	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74097	 74098	 0.002964	 0.012686	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74098	 74104	 0.00525	 0.009229	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74098	 74116	 0.005936	 0.01	 0.00014	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74099	 74102	 0.000943	 0.003236	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74099	 74119	 0.003357	 0.010193	 0.00224	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74099	 79686	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74099	 79686	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74099	 79688	 0.000757	 0.007236	 0.00211	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74100	 74103	 0.016086	 0.010414	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74101	 74103	 0.015164	 0.010736	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74101	 79687	 0.013571	 0.014929	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74102	 79687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74102	 79687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79627	 74103	 0.013436	 0.024236	 0.00035	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79686	 74103	 0.016693	 0.02935	 0.00055	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79687	 74103	 0.016707	 0.021957	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74103	 79692	 0.006521	 0.008093	 0.00018	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74104	 74112	 0.015207	 0.012036	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74104	 74117	 0.028771	 0.022764	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79686	 74104	 0.002429	 0.010693	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74104	 79689	 0.002736	 0.0164	 0.00039	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74105	 74106	 0.003171	 0.009729	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74105	 74117	 0.002986	 0.010457	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74106	 74111	 0.013807	 0.009779	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74106	 79689	 0.002936	 0.012557	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74107	 74109	 0.00335	 0.009857	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74107	 79689	 0.006464	 0.015007	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74107	 79691	 0.026336	 0.01705	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 74108	 0.002871	 0.018664	 0.03719	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74108	 79688	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79689	 74108	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74109	 79690	 0.002621	 0.008957	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74110	 74113	 0.00035	 0.002936	 0.00089	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78186	 74110	 0.000293	 0.003	 0.00114	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74110	 79690	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74110	 79690	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74110	 79693	 0.002357	 0.0152	 0.00399	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79688	 74113	 0.001686	 0.007743	 0.00199	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74113	 79691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74113	 79691	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79689	 74114	 0.02065	 0.013364	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74115	 74116	 0.009986	 0.008943	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74117	 74118	 0.001736	 0.007421	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74118	 74120	 0.002564	 0.006807	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74119	 79692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74119	 79692	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79692	 74120	 0.003871	 0.009807	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74121	 79693	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74121	 79693	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74122	 74134	 0.111943	 0.0793	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74123	 74131	 0.019607	 0.013886	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74124	 74127	 0.014064	 0.017457	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74124	 74132	 0.017907	 0.045357	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74125	 74127	 0.043536	 0.035836	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74125	 79694	 0.033371	 0.027464	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74126	 74127	 0.038464	 0.027243	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74127	 74129	 0.010714	 0.0171	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74127	 74130	 0.0254	 0.017993	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74127	 74131	 0.020929	 0.028557	 0.00051	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74127	 79695	 0.029071	 0.0892	 0.00241	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74128	 74136	 0.009979	 0.039221	 0.01026	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79693	 74128	 0.001843	 0.015507	 0.00459	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74128	 79694	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74128	 79694	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74128	 79696	 0.006936	 0.051	 0.01293	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79694	 74129	 0.015457	 0.021064	 0.00046	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74132	 74133	 0.054386	 0.044764	 0.00091	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74132	 79695	 0.01065	 0.046936	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74134	 74135	 0.029271	 0.032193	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74135	 79695	 0.005271	 0.010436	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74136	 74141	 0.001393	 0.006336	 0.0022	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74136	 79695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74136	 79695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74137	 79698	 0.021457	 0.013893	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74138	 79698	 0.025064	 0.019836	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74139	 74141	 0.001029	 0.008521	 0.00224	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74139	 74196	 0.004614	 0.023936	 0.00584	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78176	 74139	 0.0142	 0.06515	 0.0167	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78186	 74139	 0.012721	 0.074557	 0.02032	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78241	 74139	 0.050571	 0.228807	 0.06129	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74140	 79696	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79697	 74140	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74141	 79698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74141	 79698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79695	 74142	 0.003229	 0.010764	 0.00017	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79698	 74142	 0.003307	 0.020343	 0.00036	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79697	 74144	 0.139021	 0.222014	 0.00511	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74145	 74178	 0.026964	 0.021336	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74146	 74152	 0.007714	 0.011243	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74147	 74172	 0.00395	 0.010757	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74147	 74192	 0.011914	 0.049629	 0.01548	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74147	 79699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74147	 79699	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79699	 74148	 0.013336	 0.017529	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74149	 74156	 0.022643	 0.016043	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74150	 74154	 0.017571	 0.01245	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74151	 74152	 0.005593	 0.010393	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79699	 74151	 0.00695	 0.017857	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74152	 74153	 0.003864	 0.008843	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74152	 74154	 0.00495	 0.011314	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74152	 79704	 0.009736	 0.038029	 0.00084	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74153	 74180	 0.002629	 0.008971	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74154	 74155	 0.016929	 0.011993	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74154	 74156	 0.023321	 0.031821	 0.00057	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74157	 74159	 0.001093	 0.004264	 0.00114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74157	 74196	 0.003757	 0.014779	 0.00386	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74157	 79700	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74157	 79700	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79700	 74158	 0.018186	 0.011771	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74159	 74160	 0.001	 0.004	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74160	 74192	 0.001079	 0.010371	 0.00301	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78176	 74160	 0.001557	 0.017379	 0.01156	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74160	 79701	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74160	 79701	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74161	 74162	 0.003193	 0.009393	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79701	 74161	 0.003964	 0.013893	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74162	 74163	 0.005821	 0.010821	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74162	 74194	 0.0341	 0.028071	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74163	 74164	 0.014186	 0.013929	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74163	 74193	 0.011543	 0.061779	 0.00187	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79701	 74163	 0.00595	 0.02545	 0.00057	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74164	 74195	 0.036407	 0.025786	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74165	 79703	 0.100586	 0.233579	 0.00445	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74166	 74167	 0.007986	 0.016343	 0.0004	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74166	 74168	 0.018221	 0.046157	 0.00091	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74166	 74170	 0.061321	 0.043443	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74167	 74171	 0.023021	 0.05265	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74168	 74169	 0.025293	 0.064064	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74170	 74173	 0.024536	 0.033443	 0.00074	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79699	 74171	 0.016321	 0.041336	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74171	 79702	 0.018993	 0.025914	 0.00046	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74172	 79702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74172	 79702	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74173	 74176	 0.023379	 0.043464	 0.00101	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74173	 79703	 0.037021	 0.075771	 0.00186	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74174	 74186	 0.00425	 0.022043	 0.00539	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74174	 79703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74174	 79703	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74175	 74176	 0.017907	 0.031493	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74175	 74185	 0.017779	 0.036529	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79703	 74175	 0.030671	 0.057036	 0.00134	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79702	 74176	 0.0153	 0.028457	 0.00066	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74177	 74179	 0.033386	 0.026421	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74178	 74179	 0.014764	 0.009557	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74179	 74180	 0.002707	 0.009479	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74179	 74181	 0.021957	 0.014214	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74179	 79704	 0.001579	 0.01085	 0.0002	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74182	 79704	 0.0217	 0.015371	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78176	 74183	 0.003486	 0.054286	 0.01896	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74183	 79704	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74183	 79704	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79704	 74184	 0.023743	 0.016814	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74185	 79706	 0.017093	 0.058393	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74186	 74189	 0.003164	 0.012021	 0.00336	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74186	 79705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74186	 79705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74187	 74188	 0.016379	 0.0106	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79704	 74187	 0.025064	 0.034164	 0.00076	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79705	 74187	 0.026379	 0.053979	 0.00133	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74189	 74192	 0.004657	 0.0243	 0.00585	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74189	 79706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74189	 79706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74190	 74191	 0.011064	 0.007164	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79706	 74191	 0.034679	 0.024564	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79705	 74193	 0.014014	 0.049071	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74197	 74207	 0.000121	 0.002493	 0.00856	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78198	 74197	 0.004379	 0.087914	 0.33731	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74197	 79707	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74197	 79707	 0.000872	 0.043591	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74198	 74206	 0.005021	 0.0154	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74198	 79709	 0.009693	 0.021993	 0.00044	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74199	 79709	 0.011429	 0.039029	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74199	 79711	 0.011757	 0.024064	 0.00059	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74199	 79716	 0.0188	 0.016957	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74200	 74213	 4.3e-05	 0.000821	 0.00296	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78341	 74200	 0.0002	 0.004193	 0.01456	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74201	 74202	 5.7e-05	 0.0011	 0.00416	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74201	 79708	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79709	 74201	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74202	 74215	 0.000114	 0.002214	 0.00851	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78345	 74203	 0.009793	 0.033443	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79709	 74203	 0.006	 0.017636	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78345	 74204	 0.0525	 0.037193	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78345	 74205	 0.040393	 0.02615	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74206	 79710	 0.005514	 0.015821	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74207	 79712	 9.3e-05	 0.001714	 0.00738	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74208	 74213	 0.000164	 0.003329	 0.01238	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74208	 79710	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74208	 79710	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74208	 79712	 0.000164	 0.002779	 0.01464	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79710	 74209	 0.035936	 0.025457	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74210	 74218	 0.0014	 0.005714	 0.00139	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74210	 74219	 0.00295	 0.008871	 0.00278	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74210	 74227	 0.001771	 0.015164	 0.00431	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74210	 79711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74210	 79711	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74211	 74225	 2.1e-05	 0.000543	 0.04513	 3339.0	 3505.95	 3672.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74211	 79712	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74211	 79712	 0.000126	 0.010068	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79713	 74212	 0.047071	 0.033343	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74213	 79714	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74213	 79714	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78342	 74214	 0.014471	 0.023214	 0.00043	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78341	 74215	 0.000121	 0.002386	 0.00888	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74215	 79715	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74215	 79715	 0.004637	 0.16694	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79715	 74216	 0.040336	 0.028571	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79714	 74217	 0.004357	 0.015264	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79714	 74217	 0.004357	 0.015264	 0.00042	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74217	 79717	 0.00365	 0.016257	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74217	 79717	 0.00365	 0.016257	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74218	 74219	 0.0019	 0.005321	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74218	 74227	 0.002943	 0.021164	 0.00561	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79707	 74218	 0.0027	 0.012386	 0.00317	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79708	 74218	 0.001714	 0.012429	 0.00429	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74218	 79716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74218	 79716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74219	 79717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74219	 79717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74220	 74222	 0.013757	 0.053743	 0.00119	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74220	 74222	 0.013757	 0.053743	 0.00119	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79717	 74220	 0.00345	 0.012079	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79717	 74220	 0.00345	 0.012079	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79716	 74221	 0.044757	 0.032357	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74222	 74232	 0.014086	 0.049329	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74222	 74232	 0.014086	 0.049329	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74222	 74235	 0.012471	 0.048714	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74222	 74235	 0.012471	 0.048714	 0.00108	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78221	 74223	 0.015793	 0.070393	 0.00119	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78221	 74223	 0.015793	 0.070393	 0.00119	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78244	 74223	 0.018757	 0.073257	 0.00162	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78244	 74223	 0.018757	 0.073257	 0.00162	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78257	 74223	 0.0294	 0.130307	 0.00391	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78267	 74223	 0.03	 0.2554	 0.00667	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74223	 79718	 0.012464	 0.055529	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74223	 79718	 0.012464	 0.055529	 0.00094	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79713	 74224	 0.009886	 0.0386	 0.00086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79713	 74224	 0.009886	 0.0386	 0.00086	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74224	 79718	 0.004579	 0.017893	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74224	 79718	 0.004579	 0.017893	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74225	 79718	 0.001472	 0.073585	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74225	 79718	 0.001472	 0.073585	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79718	 74226	 0.007064	 0.027579	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79718	 74226	 0.007064	 0.027579	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74226	 79719	 0.007843	 0.041971	 0.00127	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74227	 74228	 0.0015	 0.011143	 0.00425	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74227	 74256	 0.020407	 0.222321	 0.07	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78352	 74227	 0.028357	 0.361729	 0.11436	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78352	 74227	 0.028357	 0.361729	 0.11436	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74228	 74229	 0.001914	 0.015936	 0.00483	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74229	 79719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74229	 79719	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78237	 74230	 0.198007	 0.5025	 0.00998	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79711	 74230	 0.026379	 0.067807	 0.00105	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74231	 74233	 0.009443	 0.033057	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74231	 74233	 0.009443	 0.033057	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74232	 74233	 0.008714	 0.034036	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74232	 74233	 0.008714	 0.034036	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74233	 74242	 0.045129	 0.3067	 0.0076	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78342	 74235	 0.020614	 0.072179	 0.002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78342	 74235	 0.020614	 0.072179	 0.002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78342	 74236	 0.0782	 0.050629	 0.00096	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74237	 74571	 0.028957	 0.113107	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74237	 74571	 0.028957	 0.113107	 0.00251	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78257	 74238	 0.163314	 0.105757	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74239	 74258	 0.034429	 0.206357	 0.00496	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78252	 74239	 0.12855	 0.26325	 0.00649	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78366	 74240	 0.008193	 0.0328	 0.00826	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74241	 74242	 0.067407	 0.13855	 0.00264	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74241	 74243	 0.135314	 0.529593	 0.01178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74241	 74243	 0.135314	 0.529593	 0.01178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74241	 74570	 0.09345	 0.416836	 0.00709	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74241	 74570	 0.09345	 0.416836	 0.00709	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78356	 74242	 0.085021	 0.408786	 0.01224	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78237	 74243	 0.034729	 0.118643	 0.00258	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78356	 74243	 0.044929	 0.174814	 0.00292	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78379	 74243	 0.024964	 0.134093	 0.00319	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78356	 74244	 0.025586	 0.089593	 0.00248	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78356	 74244	 0.025586	 0.089593	 0.00248	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78374	 74244	 0.053943	 0.21075	 0.00468	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78374	 74244	 0.053943	 0.21075	 0.00468	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74246	 74259	 0.0493	 0.318407	 0.01015	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79176	 74246	 0.084857	 0.429736	 0.00749	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75507	 74247	 0.067036	 0.357421	 0.00628	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74250	 74251	 0.059179	 0.262429	 0.00789	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74251	 74252	 0.041564	 0.202871	 0.0035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74252	 74253	 0.008579	 0.05195	 0.00163	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74252	 79721	 0.08785	 0.307864	 0.00854	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74252	 79721	 0.08785	 0.307864	 0.00854	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74253	 74254	 0.04035	 0.028586	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74255	 74256	 0.052086	 0.142043	 0.03136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74255	 79720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74255	 79720	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75916	 74256	 0.026671	 0.345807	 0.10509	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75916	 74256	 0.026671	 0.345807	 0.10509	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74256	 79721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74256	 79721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74257	 74258	 0.017429	 0.099164	 0.00305	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79721	 74257	 0.019564	 0.12625	 0.00402	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78379	 74259	 0.052036	 0.336143	 0.01071	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74260	 74262	 0.008693	 0.013871	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74260	 79723	 0.007893	 0.012657	 0.00024	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74261	 79722	 0.015371	 0.00995	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74262	 74263	 0.034671	 0.027436	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74262	 74299	 0.04735	 0.064543	 0.00143	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74262	 79726	 0.004593	 0.017936	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74264	 74265	 0.000329	 0.00245	 0.00094	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74264	 74292	 0.001029	 0.003357	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74264	 74294	 0.001536	 0.007807	 0.00283	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74264	 79722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74264	 79722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74265	 74279	 0.000707	 0.005243	 0.002	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74265	 79723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74265	 79723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74266	 74267	 0.001793	 0.007679	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74266	 74276	 0.002464	 0.009636	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74267	 74268	 0.002071	 0.010107	 0.00017	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74268	 74271	 0.008986	 0.018471	 0.00035	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74268	 79730	 0.009979	 0.023171	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74269	 74272	 0.028457	 0.020157	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74270	 74271	 0.0184	 0.014564	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78174	 74271	 0.009693	 0.018021	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78512	 74271	 0.0081	 0.028371	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74271	 79730	 0.031107	 0.024614	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74272	 74275	 0.007714	 0.012371	 0.00023	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74272	 74276	 0.015471	 0.010014	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74272	 74280	 0.009707	 0.022021	 0.00044	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78174	 74272	 0.009771	 0.034207	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74273	 79725	 0.025721	 0.041057	 0.00094	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74274	 74275	 0.003936	 0.008921	 0.00018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74274	 74281	 0.003307	 0.0075	 0.00015	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74276	 74277	 0.002029	 0.007107	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74277	 74278	 0.00175	 0.009936	 0.00018	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74277	 74280	 0.005371	 0.012186	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79723	 74277	 0.005136	 0.01055	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74278	 79724	 0.001764	 0.00875	 0.00021	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74279	 74284	 0.001	 0.0038	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74279	 74287	 0.000679	 0.003414	 0.00089	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74279	 79724	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74279	 79724	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74280	 74282	 0.0228	 0.014757	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79724	 74280	 0.00355	 0.012436	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74281	 74282	 0.004043	 0.007507	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74282	 74283	 0.002129	 0.006264	 0.00013	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74283	 79725	 0.003871	 0.012921	 0.00021	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74284	 74285	 0.000593	 0.003571	 0.00091	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74284	 79725	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74284	 79725	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74285	 74286	 0.000686	 0.003636	 0.00121	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74287	 79726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74287	 79726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79193	 74288	 0.019514	 0.012629	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79193	 74289	 0.023814	 0.015421	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74290	 74297	 0.00045	 0.002071	 0.00053	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74290	 79727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74290	 79727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74291	 79728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74291	 79728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74292	 79729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74292	 79729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79728	 74293	 0.0095	 0.033264	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79729	 74293	 0.008529	 0.025086	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74293	 79731	 0.007079	 0.020293	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74294	 74295	 0.000586	 0.003343	 0.00081	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74294	 79730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74294	 79730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74295	 74297	 0.000907	 0.004171	 0.00107	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74295	 79731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74295	 79731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79727	 74296	 0.007914	 0.01795	 0.00036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79731	 74296	 0.004821	 0.011029	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74298	 74300	 0.007871	 0.057007	 0.00143	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74298	 79732	 0.070679	 0.144664	 0.00356	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74299	 74300	 0.011914	 0.059121	 0.00141	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79728	 74299	 0.011764	 0.063193	 0.0015	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78326	 74300	 0.010821	 0.020129	 0.00047	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74301	 79734	 0.016707	 0.013221	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74302	 74303	 0.01295	 0.029621	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74302	 74304	 0.007721	 0.033007	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74303	 74305	 0.008714	 0.019936	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74304	 79734	 0.002871	 0.010064	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74305	 74307	 0.00735	 0.019479	 0.00049	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74305	 74340	 0.0074	 0.050771	 0.00093	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74305	 79732	 0.0222	 0.041279	 0.00096	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74306	 74315	 0.019107	 0.012371	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74307	 74308	 0.002671	 0.007843	 0.00016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74308	 74318	 0.006671	 0.011736	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74308	 74326	 0.012129	 0.019357	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74309	 74311	 0.011464	 0.027621	 0.0078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74309	 74336	 0.000793	 0.007264	 0.00291	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78324	 74309	 0.003593	 0.028886	 0.00812	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74309	 79732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74309	 79732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74310	 74311	 0.003264	 0.008629	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74310	 74314	 0.001336	 0.003364	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74310	 79733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74310	 79733	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74311	 74314	 0.004586	 0.012307	 0.00279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74311	 74321	 0.006821	 0.027321	 0.00689	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74312	 74317	 0.011507	 0.009471	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74312	 79734	 0.015457	 0.012721	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74313	 74323	 0.040443	 0.032007	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79733	 74313	 0.00735	 0.012921	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74314	 79734	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74314	 79734	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74315	 74316	 0.012821	 0.009079	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79734	 74315	 0.005564	 0.009793	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74316	 74318	 0.0072	 0.007221	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74317	 74322	 0.009914	 0.007029	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74318	 74320	 0.010564	 0.007486	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74319	 74326	 0.017657	 0.013971	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74322	 74323	 0.017907	 0.011593	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74323	 74324	 0.019964	 0.012921	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74323	 74326	 0.017143	 0.015357	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74323	 74355	 0.093471	 0.060514	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74324	 74325	 0.026079	 0.018471	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74325	 74355	 0.050207	 0.0325	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74327	 74328	 0.013186	 0.010436	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74327	 74355	 0.008929	 0.020257	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79732	 74327	 0.0106	 0.0217	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74329	 74349	 0.017793	 0.060779	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74330	 74334	 0.002114	 0.009693	 0.00249	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74330	 74351	 0.005957	 0.0282	 0.00678	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74330	 79735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74330	 79735	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74331	 74335	 0.000557	 0.004507	 0.00144	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74331	 74336	 0.000557	 0.004771	 0.00136	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74331	 79736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74331	 79736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74332	 79738	 0.034043	 0.024607	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74333	 74337	 0.012793	 0.008286	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79736	 74333	 0.005064	 0.010407	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74333	 79739	 0.003357	 0.020114	 0.00049	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74333	 79740	 0.030436	 0.120764	 0.00345	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74334	 74335	 0.000364	 0.003314	 0.00108	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74334	 79737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74334	 79737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74335	 79738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74335	 79738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74336	 79739	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74336	 79739	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74337	 74338	 0.026571	 0.020829	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74339	 74344	 0.026764	 0.018957	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79739	 74339	 0.009914	 0.015043	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74340	 74343	 0.0078	 0.026014	 0.00041	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74340	 74346	 0.002957	 0.013107	 0.0003	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79738	 74341	 0.003364	 0.014907	 0.00045	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79739	 74341	 0.004843	 0.02945	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74342	 74343	 0.002057	 0.008593	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79736	 74342	 0.00145	 0.007714	 0.00014	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79739	 74343	 0.009757	 0.018136	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74345	 74347	 0.035079	 0.022714	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74346	 74347	 0.003386	 0.015007	 0.00045	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74347	 74348	 0.003793	 0.012643	 0.0002	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74347	 74349	 0.006964	 0.020486	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79737	 74348	 0.00715	 0.01895	 0.00048	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79735	 74349	 0.021757	 0.0317	 0.00071	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74350	 79740	 0.01115	 0.025286	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74351	 79740	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74351	 79740	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74351	 79849	 0.006579	 0.065314	 0.01777	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79740	 74352	 0.03755	 0.0266	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74353	 74858	 0.013114	 0.078571	 0.00189	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79740	 74353	 0.003336	 0.016021	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74354	 79741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74354	 79741	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74356	 79744	 0.060664	 0.0884	 0.002	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74357	 74364	 0.003279	 0.022836	 0.00859	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74357	 74368	 0.0101	 0.04635	 0.01188	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74357	 79742	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74357	 79742	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74358	 74359	 0.020557	 0.014564	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79742	 74359	 0.020214	 0.040029	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74360	 74362	 0.007743	 0.029657	 0.00084	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74360	 79751	 0.024893	 0.103914	 0.003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74361	 74362	 0.031107	 0.020136	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74362	 74363	 0.036621	 0.026471	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79742	 74362	 0.014393	 0.042336	 0.00086	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74364	 74391	 0.003893	 0.033957	 0.00933	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74365	 74366	 0.007743	 0.009079	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74365	 79745	 0.015429	 0.016971	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74366	 74367	 0.009864	 0.014786	 0.00027	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74367	 74371	 0.038521	 0.027286	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74367	 79745	 0.011536	 0.023714	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74367	 79746	 0.003564	 0.019143	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74368	 74370	 0.000207	 0.001764	 0.00151	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74368	 74390	 0.001	 0.010529	 0.00591	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74368	 79743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74368	 79743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74369	 74370	 0.000114	 0.001271	 0.0006	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74369	 74376	 0.000271	 0.002479	 0.00129	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74372	 74373	 0.001364	 0.015457	 0.00595	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74372	 79744	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74372	 79744	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74373	 74376	 0.000371	 0.003293	 0.00181	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74373	 74380	 0.001736	 0.021	 0.01191	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74373	 79745	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74373	 79745	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74374	 74375	 0.050907	 0.040286	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74375	 79746	 0.048336	 0.047479	 0.0008	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74376	 79746	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74376	 79746	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79745	 74377	 0.003307	 0.019814	 0.00048	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79746	 74377	 0.001279	 0.009321	 0.00017	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79746	 74378	 0.022443	 0.030593	 0.00068	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74379	 74392	 0.000614	 0.010257	 0.03726	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78290	 74379	 0.001871	 0.039007	 0.13435	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74379	 79747	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79748	 74379	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79747	 74380	 0.002586	 0.016043	 0.00389	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74380	 79749	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74380	 79749	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74380	 79752	 0.002586	 0.022557	 0.00619	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74380	 79757	 0.0012	 0.013943	 0.00745	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74381	 74382	 0.00255	 0.009764	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74381	 74383	 0.004464	 0.015621	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74381	 74383	 0.004464	 0.015621	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74381	 79751	 0.004793	 0.019171	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74381	 79751	 0.004793	 0.019171	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79749	 74382	 0.002657	 0.011764	 0.00035	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74383	 74384	 0.003586	 0.013993	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74383	 74384	 0.003586	 0.013993	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74384	 79750	 0.004571	 0.017857	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74384	 79750	 0.004571	 0.017857	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74385	 79750	 0.016971	 0.010986	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74386	 79750	 0.022986	 0.014886	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74387	 74389	 0.000364	 0.004114	 0.00231	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74387	 79750	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74387	 79750	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74387	 79757	 0.000536	 0.00725	 0.00419	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74388	 74393	 0.077979	 0.055236	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74389	 74390	 0.000236	 0.002714	 0.00145	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74390	 79751	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74390	 79751	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74391	 79752	 0.000557	 0.0045	 0.00144	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78198	 74392	 0.006093	 0.08015	 0.26214	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74392	 79752	 0.000105	 0.008384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79753	 74392	 0.000298	 0.020873	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74392	 79756	 7.1e-05	 0.001329	 0.00616	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74393	 74394	 0.010429	 0.034779	 0.00055	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79753	 74393	 0.009964	 0.044407	 0.00076	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74394	 74397	 0.008493	 0.024979	 0.00051	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74395	 74398	 0.024393	 0.015793	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74396	 74397	 0.020221	 0.057393	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74396	 79754	 0.014686	 0.070514	 0.00211	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74398	 74399	 0.013171	 0.023164	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74398	 74404	 0.014121	 0.017529	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74398	 74408	 0.00325	 0.015157	 0.00035	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79753	 74398	 0.03115	 0.057921	 0.00136	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74399	 74406	 0.029714	 0.02105	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74400	 74401	 0.012179	 0.007886	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74401	 74405	 0.013414	 0.0095	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74401	 79755	 0.007507	 0.0193	 0.0003	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74402	 74403	 0.01315	 0.008514	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74402	 74414	 0.007064	 0.011271	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74402	 74419	 0.0221	 0.014307	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74407	 74413	 0.017057	 0.03505	 0.00067	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74407	 79754	 0.015771	 0.070279	 0.00119	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74408	 74409	 0.003121	 0.015236	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74409	 79754	 0.013636	 0.041829	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74410	 79754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74410	 79754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74410	 79757	 0.010714	 0.040721	 0.0114	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74411	 74413	 0.010257	 0.039286	 0.00111	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74411	 74442	 0.012379	 0.043343	 0.0012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74411	 74444	 0.031129	 0.034236	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74412	 74413	 0.00515	 0.034993	 0.00086	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74412	 74418	 0.0533	 0.042186	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74412	 74443	 0.013771	 0.045443	 0.00074	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74412	 74444	 0.023936	 0.032657	 0.00059	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74412	 79760	 0.018914	 0.116221	 0.00266	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74413	 74414	 0.00515	 0.018036	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74413	 74417	 0.006414	 0.016486	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74413	 79758	 0.042771	 0.097021	 0.00194	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74414	 79755	 0.018543	 0.0381	 0.00073	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74415	 74416	 0.005314	 0.009879	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74415	 74419	 0.00795	 0.010836	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74416	 74417	 0.0046	 0.008557	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74419	 79755	 0.0093	 0.023557	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74420	 74421	 0.0095	 0.009329	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74421	 74423	 0.022707	 0.020486	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74421	 79755	 0.004421	 0.00905	 0.00022	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74422	 79759	 0.053129	 0.058436	 0.00078	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74424	 74425	 0.01585	 0.011229	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79753	 74424	 0.003671	 0.0209	 0.00064	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74424	 79755	 0.001707	 0.010486	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74426	 74446	 0.004336	 0.054579	 0.01691	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79752	 74426	 0.000921	 0.009314	 0.00274	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74426	 79755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74426	 79755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74427	 79756	 0.000152	 0.012166	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79757	 74428	 0.0022	 0.008964	 0.00219	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74428	 79759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74428	 79759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74429	 74434	 0.022271	 0.03555	 0.00082	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79759	 74429	 0.027329	 0.061993	 0.00124	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74430	 74431	 0.034957	 0.022629	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74430	 74432	 0.070207	 0.045457	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74430	 74433	 0.112493	 0.072836	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79759	 74430	 0.013121	 0.026857	 0.00066	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74434	 74452	 0.150664	 0.106743	 0.00169	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74435	 74436	 0.091986	 0.0728	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74436	 79760	 0.082286	 0.144736	 0.00272	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74437	 74438	 0.064179	 0.04155	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74437	 74439	 0.043007	 0.053386	 0.00116	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74439	 74443	 0.006807	 0.026071	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74439	 79760	 0.014671	 0.070436	 0.00211	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74440	 74443	 0.023129	 0.014971	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74441	 74443	 0.017686	 0.012529	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74442	 74445	 0.018271	 0.0814	 0.00139	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74445	 79760	 0.006543	 0.03245	 0.00077	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74446	 79760	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74446	 79760	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79760	 74447	 0.01685	 0.010907	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79760	 74448	 0.113314	 0.080271	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78292	 74449	 0.087357	 0.078286	 0.0016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74450	 74451	 0.03205	 0.081521	 0.00129	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74451	 74454	 0.110786	 0.161479	 0.00365	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74453	 74454	 0.177286	 0.114807	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74455	 74457	 0.041786	 0.122893	 0.00252	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74456	 74459	 0.02015	 0.078707	 0.00174	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74456	 74520	 0.03715	 0.098464	 0.0025	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74457	 74458	 0.006807	 0.015807	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74458	 74459	 0.00435	 0.020879	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74458	 74463	 0.0109	 0.067014	 0.00121	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74460	 74461	 0.02095	 0.016421	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74460	 74462	 0.0088	 0.015479	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74460	 74463	 0.00255	 0.012664	 0.0003	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74460	 79761	 0.021929	 0.031957	 0.00072	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74462	 79761	 0.024164	 0.02165	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74464	 74518	 0.006493	 0.027029	 0.00843	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79538	 74464	 0.015564	 0.070093	 0.01866	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74464	 79761	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74464	 79761	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74465	 74466	 0.02325	 0.01505	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74466	 74482	 0.015536	 0.020421	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74466	 74483	 0.009793	 0.020036	 0.00049	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79761	 74466	 0.005293	 0.026764	 0.00046	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74467	 74468	 0.017343	 0.040257	 0.0006	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78274	 74467	 0.013443	 0.047064	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74468	 74469	 0.00735	 0.015036	 0.00037	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74468	 74476	 0.011429	 0.026529	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74468	 79762	 0.003314	 0.01645	 0.00039	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74469	 74470	 0.008129	 0.0143	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74470	 74471	 0.013793	 0.016171	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74470	 74478	 0.019279	 0.015871	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74471	 74475	 0.01025	 0.021064	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79761	 74471	 0.011686	 0.034357	 0.00071	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74472	 74496	 0.005393	 0.022443	 0.007	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74472	 79762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74472	 79762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74473	 74474	 0.009214	 0.0209	 0.00041	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79762	 74473	 0.016236	 0.041736	 0.00064	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74474	 74494	 0.01735	 0.026014	 0.00047	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74475	 74482	 0.018507	 0.0167	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74475	 74492	 0.024529	 0.024779	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74476	 74477	 0.013236	 0.014129	 0.0003	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74476	 74479	 0.014779	 0.009571	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74477	 74478	 0.014964	 0.0106	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74477	 74493	 0.006879	 0.012793	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74480	 74486	 0.007157	 0.012593	 0.00024	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74480	 74488	 0.015414	 0.013807	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74480	 74502	 0.007029	 0.016307	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74481	 74502	 0.018093	 0.019893	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74481	 74522	 0.019621	 0.01615	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74482	 74484	 0.012843	 0.011829	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74483	 74485	 0.007871	 0.011807	 0.00021	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74484	 74490	 0.013529	 0.012207	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74485	 74488	 0.016857	 0.015207	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74486	 74487	 0.01605	 0.014786	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74487	 74488	 0.037636	 0.035293	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74487	 74522	 0.025629	 0.025886	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79761	 74487	 0.01665	 0.048957	 0.00101	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74489	 74490	 0.006621	 0.011643	 0.00022	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74489	 74500	 0.0149	 0.01335	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74491	 74492	 0.006443	 0.011986	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74491	 74499	 0.006329	 0.011136	 0.00021	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74494	 79763	 0.011657	 0.0205	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74495	 74497	 0.005607	 0.012714	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74495	 74498	 0.012957	 0.013086	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74495	 74506	 0.017543	 0.011357	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74496	 74511	 0.004343	 0.010914	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74496	 74527	 0.008936	 0.024493	 0.00533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74496	 79763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74496	 79763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74497	 74507	 0.014629	 0.012036	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74497	 74510	 0.021464	 0.017664	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79763	 74497	 0.001179	 0.007157	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74498	 74499	 0.008714	 0.010814	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74499	 74508	 0.01015	 0.020857	 0.0004	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74500	 74505	 0.010193	 0.017171	 0.00024	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74501	 79764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74501	 79764	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74502	 74503	 0.010086	 0.0091	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78266	 74502	 0.004871	 0.0195	 0.00041	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74503	 74504	 0.011786	 0.00835	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74505	 74508	 0.011357	 0.017029	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78266	 74505	 0.011179	 0.025564	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74507	 74510	 0.016514	 0.013071	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74507	 79765	 0.011386	 0.026436	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74508	 74519	 0.005657	 0.016221	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74509	 74510	 0.011179	 0.007236	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74511	 74518	 0.003829	 0.010286	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74511	 79765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74511	 79765	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74512	 74514	 0.013236	 0.012193	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79765	 74513	 0.011279	 0.013221	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74514	 79766	 0.007214	 0.013421	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74514	 79768	 0.012021	 0.02235	 0.00052	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74515	 74516	 0.003193	 0.0094	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74515	 79766	 0.002779	 0.007357	 0.00019	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74516	 74519	 0.006121	 0.014214	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79765	 74516	 0.022871	 0.0231	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74517	 74518	 0.001079	 0.004379	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74517	 74526	 0.0027	 0.010271	 0.00288	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74517	 79766	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74517	 79766	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74518	 79767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74518	 79767	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79767	 74519	 0.005843	 0.01325	 0.00026	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74520	 74523	 0.0398	 0.090286	 0.0018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79764	 74521	 0.028229	 0.064036	 0.00128	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74523	 74534	 0.025686	 0.089929	 0.00249	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78357	 74523	 0.059629	 0.20375	 0.00444	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74524	 74525	 0.0235	 0.041971	 0.00062	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74524	 79774	 0.043736	 0.081321	 0.0019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79766	 74525	 0.012471	 0.021929	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74526	 79768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74526	 79768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74527	 74528	 0.009136	 0.024879	 0.00548	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74527	 79769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74527	 79769	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74528	 74532	 0.019407	 0.048793	 0.01264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74528	 79770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74528	 79770	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74529	 74530	 0.0714	 0.11455	 0.00211	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79769	 74529	 0.164357	 0.106429	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79770	 74529	 0.0148	 0.0267	 0.00039	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74530	 74531	 0.121814	 0.241264	 0.00354	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78302	 74531	 0.048643	 0.215643	 0.00648	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74532	 79771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74532	 79771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79769	 74533	 0.097307	 0.127907	 0.00175	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74534	 74545	 0.023343	 0.061879	 0.00157	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74535	 74536	 0.007807	 0.00915	 0.00016	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74535	 74547	 0.00425	 0.009643	 0.00019	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74537	 79772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74537	 79772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74538	 74540	 0.022893	 0.016214	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74538	 79773	 0.01005	 0.0154	 0.00021	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74539	 74541	 0.004714	 0.012843	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74539	 79773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74539	 79773	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74540	 74546	 0.016093	 0.0114	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74540	 79774	 0.022693	 0.022293	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74541	 79774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74541	 79774	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74542	 74543	 0.018093	 0.014321	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74542	 74545	 0.019657	 0.029807	 0.00043	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78239	 74542	 0.057093	 0.056086	 0.00095	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79773	 74542	 0.015821	 0.011436	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74544	 74545	 0.005671	 0.013171	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74544	 74546	 0.011107	 0.012214	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79774	 74547	 0.005793	 0.014729	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79762	 74548	 0.072979	 0.06585	 0.0011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74549	 74550	 0.014593	 0.013164	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74550	 74562	 0.033064	 0.036371	 0.00049	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78323	 74550	 0.005293	 0.0121	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74550	 79776	 0.010521	 0.014343	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74551	 74552	 0.000879	 0.003507	 0.00089	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74551	 79775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74551	 79775	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74552	 74554	 0.000736	 0.003443	 0.00085	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74552	 74890	 0.002307	 0.011	 0.00261	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74552	 79776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74552	 79776	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79775	 74553	 0.023529	 0.015236	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74554	 74894	 0.002436	 0.00925	 0.00259	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78325	 74555	 0.019757	 0.015486	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74556	 74557	 0.027507	 0.019486	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78325	 74557	 0.019529	 0.019186	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74558	 74559	 0.000243	 0.003521	 0.00128	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74558	 74561	 0.000714	 0.007636	 0.00244	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74559	 74560	 0.000514	 0.0074	 0.00235	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78179	 74560	 0.000807	 0.009993	 0.00433	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74561	 74565	 0.001879	 0.0193	 0.0073	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78323	 74563	 0.021186	 0.017443	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74564	 79777	 0.013757	 0.042193	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74565	 79777	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74565	 79777	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78180	 74567	 0.154157	 0.099821	 0.0019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78180	 74568	 0.03755	 0.033643	 0.00069	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74569	 74897	 0.007929	 0.041271	 0.01216	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74569	 79778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74569	 79778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74571	 79779	 0.031957	 0.111893	 0.0031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74571	 79779	 0.031957	 0.111893	 0.0031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74572	 79779	 0.464671	 0.368271	 0.00464	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74573	 74576	 5e-05	 0.001364	 0.14649	 4451.0	 4673.55	 4896.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74573	 79779	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74573	 79779	 0.003144	 0.12263	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74574	 79780	 0.039879	 0.043864	 0.00059	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74575	 79780	 0.029036	 0.04635	 0.00106	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74576	 79780	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74576	 79780	 0.005109	 0.18393	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74577	 74579	 9.3e-05	 0.002643	 0.28355	 4451.0	 4673.55	 4896.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74578	 79781	 0.168486	 0.119371	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74579	 79781	 0.000973	 0.052562	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74579	 79781	 0.000973	 0.052562	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79781	 74580	 0.027129	 0.105964	 0.00235	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79781	 74580	 0.027129	 0.105964	 0.00235	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78267	 74581	 0.141564	 0.116543	 0.00236	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74582	 74583	 0.436736	 0.394779	 0.00661	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78267	 74582	 0.049557	 0.211957	 0.00479	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79720	 74582	 0.090093	 0.315736	 0.00875	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78267	 74583	 0.171857	 0.442271	 0.00686	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78558	 74583	 0.066886	 0.298179	 0.00506	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74584	 74585	 0.005936	 0.067221	 0.03779	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74584	 79782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74584	 79782	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74585	 79783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74585	 79783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74586	 74637	 0.034179	 0.141336	 0.03351	 171.0	 171.0	 171.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78163	 74586	 0.036771	 0.14005	 0.03931	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74586	 79784	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74586	 79784	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74587	 74588	 0.0284	 0.058121	 0.00143	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74587	 74595	 0.065964	 0.066629	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74589	 74590	 0.009164	 0.024607	 0.00558	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74589	 79785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74589	 79785	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74590	 74599	 0.007936	 0.023407	 0.00544	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74591	 74592	 0.002157	 0.008421	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78547	 74591	 0.009764	 0.043257	 0.0013	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74592	 74593	 0.004907	 0.014429	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74593	 74594	 0.006357	 0.012457	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74594	 74595	 0.081179	 0.121714	 0.00221	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79785	 74594	 0.048343	 0.0659	 0.00146	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74595	 74598	 0.100964	 0.090486	 0.00185	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74596	 74597	 0.035514	 0.0281	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74598	 74601	 0.152929	 0.099029	 0.00189	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74599	 79786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74599	 79786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74599	 79787	 0.005071	 0.012221	 0.00345	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74600	 74645	 0.004657	 0.0311	 0.05866	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74600	 79787	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79788	 74600	 0.000495	 0.037108	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74601	 74604	 0.009864	 0.017621	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74601	 74606	 0.0123	 0.036164	 0.00074	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79788	 74601	 0.011814	 0.046136	 0.00102	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79788	 74602	 0.028429	 0.0225	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74603	 74619	 0.001293	 0.004207	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79787	 74603	 0.002264	 0.006821	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74603	 79789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74603	 79789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74604	 74605	 0.004707	 0.009321	 0.00014	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74605	 74613	 0.008836	 0.017486	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74605	 74616	 0.004914	 0.010057	 0.00025	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74606	 74607	 0.014721	 0.025893	 0.00049	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74607	 74610	 0.049543	 0.092121	 0.00216	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74607	 74614	 0.00695	 0.017864	 0.00028	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79788	 74607	 0.014779	 0.079386	 0.00189	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74608	 79790	 0.005014	 0.024071	 0.00072	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74609	 74635	 0.008164	 0.025529	 0.00739	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74609	 79790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74609	 79790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79790	 74610	 0.0078	 0.01975	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74611	 74612	 0.042157	 0.033364	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74612	 74614	 0.029214	 0.046636	 0.00107	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74613	 74615	 0.045057	 0.029171	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74616	 79791	 0.005829	 0.014757	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74617	 74618	 0.011329	 0.008029	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74617	 74620	 0.010979	 0.017614	 0.00033	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79787	 74619	 0.003529	 0.011886	 0.00296	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74619	 79791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74619	 79791	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74620	 74621	 0.023286	 0.015071	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74620	 74623	 0.0143	 0.025143	 0.00047	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79791	 74620	 0.002671	 0.015179	 0.00027	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74622	 74626	 0.13055	 0.084529	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79788	 74622	 0.053121	 0.052186	 0.00088	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74623	 74631	 0.025914	 0.058779	 0.00117	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79788	 74623	 0.029514	 0.084657	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74624	 74625	 0.011229	 0.007957	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79789	 74625	 0.0298	 0.023586	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74627	 74628	 0.021607	 0.016936	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74627	 74629	 0.0197	 0.012757	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74627	 74642	 0.011993	 0.01075	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74627	 79795	 0.012929	 0.026564	 0.00051	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74629	 74631	 0.008514	 0.016857	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74630	 74640	 0.024193	 0.019143	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74631	 79795	 0.048143	 0.0341	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74632	 79795	 0.024857	 0.016093	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74633	 79792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74633	 79792	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74633	 79794	 0.004157	 0.014486	 0.00336	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74634	 74636	 0.062964	 0.0446	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79792	 74634	 0.149771	 0.135157	 0.00226	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74634	 79793	 0.03495	 0.022621	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74635	 79793	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74635	 79793	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74635	 79796	 0.020429	 0.066643	 0.0177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74636	 74638	 0.0123	 0.021636	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79793	 74636	 0.02105	 0.023157	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74638	 74646	 0.012643	 0.052764	 0.00152	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79793	 74638	 0.003557	 0.019114	 0.00046	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74639	 74645	 0.002236	 0.014521	 0.02893	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74639	 79794	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79795	 74639	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79795	 74640	 0.012093	 0.015007	 0.00033	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79795	 74641	 0.022843	 0.018071	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74642	 74643	 0.019671	 0.015564	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79795	 74644	 0.022221	 0.088157	 0.00251	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78152	 74645	 0.022629	 0.145536	 0.31159	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74645	 79796	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79797	 74645	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74646	 74648	 0.025357	 0.058864	 0.00088	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74646	 74649	 0.018043	 0.055343	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79793	 74646	 0.035357	 0.0802	 0.0016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74647	 74658	 0.045371	 0.029371	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74647	 74659	 0.017271	 0.016964	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74647	 74663	 0.028407	 0.140957	 0.00336	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74648	 74650	 0.032836	 0.027029	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74648	 74651	 0.022671	 0.039871	 0.00075	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74649	 74651	 0.018129	 0.029714	 0.00052	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74649	 74652	 0.015571	 0.027386	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74650	 74651	 0.017786	 0.014079	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74651	 74652	 0.048657	 0.034464	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74651	 74653	 0.007229	 0.016386	 0.00033	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74651	 74658	 0.0105	 0.023814	 0.00048	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79792	 74651	 0.033807	 0.180943	 0.00549	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74653	 74654	 0.007629	 0.013414	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74654	 74655	 0.010629	 0.016964	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74654	 74658	 0.01285	 0.015064	 0.00026	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74655	 74656	 0.075464	 0.048857	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74655	 74657	 0.043593	 0.028221	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74658	 74659	 0.020929	 0.01355	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74660	 74662	 0.010129	 0.025457	 0.00659	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79796	 74660	 0.010236	 0.027064	 0.00634	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79797	 74661	 0.318314	 0.206264	 0.00393	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74661	 79798	 0.074929	 0.058736	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74662	 79798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74662	 79798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74664	 74665	 0.037907	 0.024543	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74665	 74667	 0.009014	 0.061893	 0.00113	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74665	 74670	 0.015993	 0.090929	 0.00164	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78229	 74666	 0.01855	 0.133521	 0.00438	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74667	 74669	 0.07945	 0.180264	 0.0036	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78229	 74667	 0.024371	 0.130914	 0.00311	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78256	 74668	 0.081171	 0.277429	 0.00604	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78256	 74669	 0.044686	 0.102214	 0.00249	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74670	 74672	 0.035757	 0.073179	 0.0018	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78256	 74671	 0.078107	 0.305257	 0.00678	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78256	 74671	 0.078107	 0.305257	 0.00678	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78357	 74673	 0.051829	 0.096379	 0.00226	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74675	 74688	 0.040521	 0.158279	 0.00351	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78583	 74675	 0.051607	 0.277329	 0.00659	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74676	 74821	 0.02865	 0.097864	 0.00213	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74677	 74679	 0.043486	 0.076471	 0.00144	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74677	 74821	 0.054686	 0.0873	 0.00201	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74678	 74679	 0.055243	 0.054271	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74679	 74682	 0.071764	 0.097829	 0.00217	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74680	 74682	 0.027286	 0.047993	 0.0009	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74680	 74688	 0.046657	 0.106714	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74681	 74683	 0.02405	 0.025686	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74681	 74758	 0.020971	 0.047579	 0.00095	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74682	 74683	 0.0107	 0.015593	 0.00035	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74683	 74684	 0.011957	 0.007743	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74683	 74685	 0.05235	 0.046914	 0.00096	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74683	 79815	 0.057971	 0.1326	 0.00324	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74686	 74687	 0.039986	 0.05995	 0.00109	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74686	 74690	 0.023321	 0.03065	 0.00042	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74687	 74688	 0.035643	 0.081893	 0.00124	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74689	 74691	 0.021236	 0.0168	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74690	 74692	 0.033986	 0.027979	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74691	 74692	 0.022129	 0.019964	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74692	 74695	 0.047643	 0.094336	 0.00139	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74693	 74697	 0.028786	 0.020393	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74694	 74699	 0.0104	 0.013671	 0.00019	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74694	 79800	 0.0199	 0.031764	 0.00073	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74695	 79803	 0.0271	 0.0904	 0.00144	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74696	 74713	 0.005229	 0.02035	 0.00544	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79606	 74696	 0.007679	 0.02795	 0.00856	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74697	 74698	 0.026293	 0.017021	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74697	 79817	 0.019414	 0.03415	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74699	 79799	 0.016036	 0.017464	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74700	 74703	 0.000764	 0.003007	 0.00079	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74700	 74757	 0.000864	 0.003593	 0.00084	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74700	 79799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74700	 79799	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74701	 74702	 0.001114	 0.004614	 0.00109	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74701	 79800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74701	 79800	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74701	 79805	 0.001079	 0.004807	 0.00131	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74702	 74703	 0.000864	 0.003464	 0.00087	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74702	 79801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74702	 79801	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79800	 74704	 0.021593	 0.019486	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74705	 74706	 0.025657	 0.018171	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79801	 74705	 0.013114	 0.008493	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74706	 74717	 0.007036	 0.013086	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79800	 74706	 0.008714	 0.010214	 0.00018	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74707	 74708	 0.039021	 0.025264	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74708	 74709	 0.025543	 0.018093	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74708	 74717	 0.017443	 0.026721	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74710	 74716	 0.008329	 0.013293	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74710	 79802	 0.030364	 0.024029	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74710	 79803	 0.0324	 0.026671	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74711	 74712	 0.001636	 0.003936	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74711	 74714	 0.000979	 0.002586	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74712	 74713	 0.000736	 0.002393	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74712	 79802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74712	 79802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74713	 79803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74713	 79803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74714	 74715	 0.003657	 0.009964	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78223	 74715	 0.003457	 0.013836	 0.00349	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74715	 79804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74715	 79804	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74715	 79805	 0.003	 0.00805	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79804	 74716	 0.026014	 0.023471	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79804	 74717	 0.017957	 0.028807	 0.00053	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74717	 79806	 0.010857	 0.022321	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78157	 74718	 0.002057	 0.013714	 0.02585	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74718	 79805	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79806	 74718	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74719	 74722	 0.00095	 0.003621	 0.00101	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74719	 79807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74719	 79807	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74719	 79808	 0.001657	 0.006036	 0.00185	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78157	 74720	 0.001557	 0.010086	 0.02009	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74720	 79808	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79809	 74720	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74721	 74722	 0.000493	 0.002036	 0.00048	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74721	 74725	 0.0009	 0.003429	 0.00096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74722	 79810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74722	 79810	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74723	 74724	 0.009521	 0.007536	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79807	 74723	 0.0153	 0.024543	 0.00045	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74723	 79811	 0.032671	 0.025857	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74723	 79817	 0.007871	 0.014629	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79810	 74724	 0.010093	 0.009043	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74725	 74754	 0.002093	 0.008386	 0.00211	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74725	 74846	 0.002714	 0.007164	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74725	 79811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74725	 79811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79811	 74726	 0.0096	 0.0154	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79810	 74727	 0.012964	 0.012736	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74728	 74739	 0.00975	 0.012107	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74728	 74844	 0.005814	 0.011943	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78224	 74728	 0.009829	 0.03015	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74728	 79812	 0.00655	 0.014857	 0.00029	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74729	 74842	 0.006336	 0.011779	 0.00028	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74729	 74844	 0.004179	 0.00895	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74730	 74745	 0.006136	 0.016221	 0.0038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78223	 74730	 0.002086	 0.007157	 0.00171	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74730	 79812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74730	 79812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78159	 74731	 0.320764	 0.20785	 0.00396	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74732	 74734	 0.00445	 0.00915	 0.00017	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74732	 74844	 0.004621	 0.0095	 0.00018	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74733	 74734	 0.013	 0.0094	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74733	 74842	 0.013029	 0.010314	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74734	 74735	 0.006493	 0.010936	 0.00016	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74734	 74737	 0.004686	 0.009586	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74735	 79845	 0.0164	 0.016114	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74736	 74737	 0.010029	 0.010129	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74736	 74749	 0.011914	 0.008436	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74737	 74738	 0.01145	 0.010736	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74737	 74845	 0.012771	 0.009236	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74738	 74740	 0.022743	 0.016107	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74738	 74744	 0.010607	 0.009571	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74739	 74844	 0.004586	 0.01065	 0.00016	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79809	 74739	 0.020721	 0.038536	 0.0009	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78159	 74742	 0.009164	 0.023214	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74742	 79813	 0.003364	 0.006907	 0.00013	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74742	 79814	 0.011586	 0.009079	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78158	 74743	 0.003243	 0.008836	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74743	 79813	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74743	 79813	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74744	 79814	 0.008393	 0.007571	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78158	 74745	 0.002721	 0.007186	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74745	 79814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74745	 79814	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74746	 74785	 0.000236	 0.002929	 0.20052	 1725.0	 1811.25	 1897.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74747	 74752	 0.004271	 0.020514	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78367	 74747	 0.010236	 0.054971	 0.00131	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74748	 74749	 0.0108	 0.006993	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74748	 74752	 0.002157	 0.009543	 0.00021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79813	 74748	 0.003986	 0.012229	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78159	 74750	 0.003843	 0.02065	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74751	 74752	 0.017586	 0.017764	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74751	 79845	 0.016907	 0.01515	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74754	 74770	 0.002607	 0.018429	 0.00506	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78158	 74754	 0.004671	 0.023879	 0.00601	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74754	 79815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74754	 79815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74755	 74756	 0.001357	 0.005436	 0.00137	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74755	 74762	 0.002886	 0.011929	 0.00282	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74755	 79816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74755	 79816	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74756	 74757	 0.000907	 0.003621	 0.00091	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74757	 79817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74757	 79817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74758	 74759	 0.015979	 0.032693	 0.00081	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74759	 79818	 0.008814	 0.018036	 0.00044	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74760	 74761	 0.001221	 0.004264	 0.00141	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74760	 74770	 0.001029	 0.00585	 0.00169	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74760	 79818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74760	 79818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74760	 79819	 0.001564	 0.008143	 0.00214	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74760	 79821	 0.000821	 0.002993	 0.00091	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74761	 74762	 0.001507	 0.005714	 0.0016	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74763	 74767	 0.000279	 0.001936	 0.00341	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74763	 79819	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79820	 74763	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74764	 74765	 0.026264	 0.046186	 0.00087	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74764	 74766	 0.021079	 0.014929	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79820	 74764	 0.009286	 0.021557	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74765	 74766	 0.018514	 0.034429	 0.00081	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74765	 74815	 0.020621	 0.047879	 0.00071	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74765	 79829	 0.018564	 0.038	 0.00094	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74766	 79822	 0.018543	 0.034471	 0.00081	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74767	 79821	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79822	 74767	 0.001897	 0.083478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74767	 79827	 0.001421	 0.009493	 0.01789	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74768	 74772	 0.014429	 0.011879	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79820	 74768	 0.021686	 0.0213	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79822	 74768	 0.010764	 0.011493	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74768	 79823	 0.020014	 0.016479	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79820	 74769	 0.017329	 0.012279	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79822	 74769	 0.014129	 0.009143	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74770	 79823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74770	 79823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79823	 74771	 0.013579	 0.009621	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79818	 74772	 0.014607	 0.012021	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79823	 74772	 0.0181	 0.011721	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74773	 79824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74773	 79824	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78367	 74774	 0.003129	 0.006429	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79824	 74774	 0.004936	 0.009171	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74775	 74776	 0.010843	 0.014793	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74775	 74777	 0.011614	 0.023879	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79824	 74775	 0.014114	 0.062879	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74776	 74784	 0.016836	 0.024529	 0.00056	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74777	 74782	 0.008321	 0.017093	 0.00033	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74777	 74784	 0.02215	 0.019986	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74777	 74799	 0.092479	 0.059879	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74778	 74779	 0.002321	 0.006221	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74778	 74796	 0.002171	 0.005586	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74778	 79825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74778	 79825	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74779	 79826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74779	 79826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74780	 74781	 0.015921	 0.018664	 0.00032	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74780	 74782	 0.006607	 0.012279	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74780	 74783	 0.014393	 0.033421	 0.0005	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74780	 79829	 0.005686	 0.022114	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79109	 74781	 0.083064	 0.109186	 0.0015	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79825	 74783	 0.018621	 0.036864	 0.00054	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74784	 79829	 0.008586	 0.019936	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74785	 79827	 0.000122	 0.009733	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79828	 74786	 0.001579	 0.006214	 0.00163	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74786	 79830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74786	 79830	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74786	 79837	 0.0093	 0.032871	 0.00741	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74787	 74788	 0.00845	 0.015714	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79829	 74787	 0.018864	 0.038764	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79830	 74787	 0.026007	 0.0286	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74788	 74789	 0.021	 0.024621	 0.00043	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74788	 74791	 0.013764	 0.0139	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74789	 74807	 0.032386	 0.020964	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74789	 79836	 0.048514	 0.039929	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74790	 74793	 0.02335	 0.018479	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74791	 79831	 0.037807	 0.029921	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74792	 74793	 0.007314	 0.0136	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79830	 74792	 0.007729	 0.017521	 0.00035	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74793	 74797	 0.018686	 0.0121	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74793	 74807	 0.038807	 0.025129	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74793	 79831	 0.028279	 0.020029	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74794	 74795	 0.000686	 0.003886	 0.00096	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79828	 74794	 0.001736	 0.010671	 0.00308	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74794	 79831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74794	 79831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74795	 74796	 0.00105	 0.005171	 0.00151	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74796	 79832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74796	 79832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74796	 79833	 0.000886	 0.004193	 0.00101	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79110	 74797	 0.058679	 0.080064	 0.00143	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79831	 74797	 0.042536	 0.030129	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79827	 74798	 0.000729	 0.008421	 0.01614	 512.0	 537.6	 563.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74798	 79833	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74798	 79833	 0.001238	 0.054486	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79833	 74800	 0.00155	 0.005636	 0.00173	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74800	 79834	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74800	 79834	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74801	 74803	 0.02835	 0.018357	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79110	 74801	 0.020779	 0.01645	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74802	 74810	 0.051914	 0.046521	 0.00095	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79106	 74802	 0.03615	 0.0386	 0.00081	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79834	 74803	 0.041579	 0.026914	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74804	 74812	 0.001064	 0.002471	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74804	 74824	 0.002179	 0.005764	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74804	 79835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74804	 79835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74805	 74823	 0.056171	 0.044457	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74806	 74812	 0.002457	 0.005921	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74806	 79836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74806	 79836	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74807	 74809	 0.036736	 0.026021	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79836	 74807	 0.048529	 0.043786	 0.00074	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74808	 74809	 0.014214	 0.017643	 0.00039	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79834	 74808	 0.025071	 0.026779	 0.00056	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79836	 74809	 0.011343	 0.02245	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74810	 74811	 0.033379	 0.030114	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74811	 74828	 0.026679	 0.031271	 0.00054	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74813	 74817	 0.032036	 0.063436	 0.00093	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79836	 74813	 0.018821	 0.022064	 0.00039	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74813	 79838	 0.009971	 0.018536	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74814	 74818	 0.029186	 0.0189	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74815	 74818	 0.025771	 0.025321	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74815	 74819	 0.017757	 0.014614	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74816	 74818	 0.017414	 0.012336	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74817	 74818	 0.028829	 0.018664	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74818	 74819	 0.024621	 0.017443	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74818	 74820	 0.02015	 0.039893	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74818	 74821	 0.08575	 0.070586	 0.00143	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79829	 74818	 0.111157	 0.112286	 0.00149	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74820	 79838	 0.0089	 0.034757	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74821	 79838	 0.027379	 0.056264	 0.00107	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78285	 74822	 0.002436	 0.033136	 0.0675	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79827	 74822	 0.002007	 0.013521	 0.0249	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74822	 79837	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79838	 74822	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79835	 74823	 0.018543	 0.013136	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74823	 79839	 0.005386	 0.009479	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74824	 74826	 0.001179	 0.00385	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79837	 74824	 0.002214	 0.008714	 0.00228	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74824	 79839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74824	 79839	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74825	 74841	 0.043614	 0.030893	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74825	 79840	 0.027486	 0.017793	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74826	 74831	 0.001271	 0.003693	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74826	 79840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74826	 79840	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74827	 74829	 0.011779	 0.008343	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79840	 74827	 0.01335	 0.008643	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74828	 79841	 0.004786	 0.010943	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74829	 74830	 0.014379	 0.014129	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79840	 74829	 0.024693	 0.017493	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79835	 74830	 0.010586	 0.011307	 0.00024	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74831	 74832	 0.002986	 0.008136	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74831	 79841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74831	 79841	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74832	 74836	 0.004357	 0.011507	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74832	 79842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74832	 79842	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79841	 74833	 0.005407	 0.010057	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79842	 74833	 0.009807	 0.01565	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74834	 74836	 0.001664	 0.004536	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74834	 79843	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74834	 79843	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74835	 74838	 0.012907	 0.010621	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79843	 74835	 0.019764	 0.015643	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74835	 79844	 0.011021	 0.020493	 0.00048	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74836	 79844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74836	 79844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74837	 74840	 0.02095	 0.038957	 0.00091	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79843	 74837	 0.014093	 0.025436	 0.00036	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79842	 74838	 0.024421	 0.0173	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79843	 74838	 0.018764	 0.01215	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79842	 74839	 0.016321	 0.011564	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74840	 74841	 0.033386	 0.060243	 0.00087	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79838	 74841	 0.072236	 0.079457	 0.00106	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74842	 74843	 0.014507	 0.010279	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74846	 79845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74846	 79845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78158	 74847	 0.101507	 0.278143	 0.06175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74848	 79848	 0.0255	 0.0255	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74849	 74876	 0.012957	 0.033314	 0.00825	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74849	 74885	 0.001579	 0.012279	 0.00367	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78179	 74849	 0.008736	 0.094786	 0.02966	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74849	 79846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74849	 79846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74850	 74851	 0.000407	 0.003021	 0.00576	 383.0	 402.15	 421.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74850	 79847	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79848	 74850	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78513	 74851	 0.006579	 0.089057	 0.1871	 579.0	 607.95	 636.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74851	 79849	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79850	 74851	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79848	 74852	 0.011664	 0.0096	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74853	 74855	 0.02375	 0.015379	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79850	 74853	 0.005936	 0.026307	 0.00079	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74853	 79851	 0.017264	 0.030364	 0.00057	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79847	 74854	 0.002757	 0.01285	 0.00319	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79849	 74854	 0.002221	 0.007414	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74854	 79851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74854	 79851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79851	 74856	 0.112121	 0.13145	 0.00229	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79851	 74857	 0.016764	 0.0343	 0.00084	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74858	 74865	 0.001629	 0.013393	 0.00026	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79740	 74858	 0.01495	 0.091879	 0.0021	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74858	 79852	 0.007364	 0.059571	 0.00154	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74859	 74885	 0.00465	 0.020943	 0.00557	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74859	 79852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74859	 79852	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74860	 74865	 0.016093	 0.0114	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74861	 74862	 0.002864	 0.012679	 0.00029	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74861	 74873	 0.002543	 0.009729	 0.00028	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79852	 74862	 0.004414	 0.019564	 0.00059	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74863	 74872	 0.021764	 0.017221	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74864	 74865	 0.001079	 0.006964	 0.00022	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74864	 74872	 0.00085	 0.006886	 0.00018	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74866	 74870	 0.006586	 0.015279	 0.00023	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74866	 74871	 0.002014	 0.007057	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79852	 74866	 0.0122	 0.043586	 0.00086	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74867	 74868	 0.023636	 0.0153	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74868	 74870	 0.008236	 0.014486	 0.00027	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74869	 74870	 0.023586	 0.015271	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79851	 74870	 0.033414	 0.114143	 0.00249	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74871	 74873	 0.002264	 0.00695	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74872	 74873	 0.000629	 0.006179	 0.00012	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74874	 74875	 0.001343	 0.00605	 0.00161	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74874	 74876	 0.001871	 0.006607	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74874	 79853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74874	 79853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74875	 74876	 0.000514	 0.002107	 0.0005	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74875	 74887	 0.007964	 0.040679	 0.01024	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74876	 79854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74876	 79854	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74877	 74878	 0.011771	 0.007621	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79854	 74877	 0.003571	 0.0081	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74878	 74882	 0.013371	 0.010586	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74879	 74880	 0.0117	 0.007579	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74880	 74881	 0.002043	 0.007943	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74880	 74883	 0.018507	 0.013107	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79853	 74880	 0.003086	 0.015614	 0.00027	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79852	 74881	 0.022536	 0.087664	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79853	 74884	 0.005636	 0.025114	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74884	 79855	 0.013057	 0.038386	 0.00079	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74885	 79855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74885	 79855	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79740	 74886	 0.1199	 0.191457	 0.00441	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78179	 74887	 0.016886	 0.070321	 0.02194	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74887	 79856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74887	 79856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79856	 74888	 0.082021	 0.187643	 0.00459	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78323	 74889	 0.032993	 0.043364	 0.00059	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79776	 74889	 0.012186	 0.0219	 0.00039	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74889	 79857	 0.004064	 0.018	 0.00041	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74890	 74901	 0.005707	 0.041043	 0.01088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74890	 79857	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74890	 79857	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74891	 74893	 0.002343	 0.011636	 0.00028	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79857	 74891	 0.006364	 0.034193	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79857	 74892	 0.005871	 0.026007	 0.00078	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74892	 79858	 0.0063	 0.024129	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74893	 74899	 0.057321	 0.037114	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74893	 79859	 0.005393	 0.021064	 0.00046	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74894	 74895	 0.001279	 0.005564	 0.00159	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74894	 79858	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74894	 79858	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74895	 74896	 0.000943	 0.004829	 0.00121	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74895	 79859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74895	 79859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74896	 74897	 0.003714	 0.018143	 0.00501	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74897	 79860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74897	 79860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74898	 74900	 0.016629	 0.082521	 0.00196	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79860	 74898	 0.042807	 0.11005	 0.0017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78215	 74902	 0.004279	 0.0305	 0.00946	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74902	 79861	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74902	 79861	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75433	 75434	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75433	 75434	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75433	 75851	 0.000936	 0.006071	 0.01209	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75435	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75434	 75435	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75434	 75449	 0.041857	 0.152664	 0.04689	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75759	 0.079736	 0.290607	 0.06289	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75763	 0.095864	 0.223864	 0.06866	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75434	 75840	 0.043407	 0.1797	 0.04267	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75435	 75757	 0.306457	 0.608114	 0.00894	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75435	 75847	 0.017614	 0.028264	 0.00052	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75437	 75450	 0.205607	 0.590864	 0.00911	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75437	 75755	 0.058064	 0.102121	 0.00192	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75438	 75439	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75438	 75439	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75438	 75780	 0.003786	 0.048514	 0.01449	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75438	 75780	 0.003786	 0.048514	 0.01449	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75440	 75441	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75440	 75441	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75442	 75443	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75442	 75443	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75443	 75787	 0.064493	 0.467907	 0.01178	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75445	 75462	 0.007121	 0.007193	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75447	 75448	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75447	 75448	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75449	 75450	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75449	 75450	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75451	 75452	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75451	 75452	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75454	 75835	 0.025979	 0.058929	 0.00118	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75457	 75458	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75457	 75458	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75459	 75804	 0.321214	 0.2901	 0.00486	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75460	 75461	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75460	 75461	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75461	 75462	 0.0001	 0.000271	 1e-05	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75463	 75464	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75463	 75464	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75465	 76082	 9.3e-05	 0.00215	 0.04072	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75466	 75467	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75466	 75467	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75467	 75468	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75467	 75468	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75467	 75912	 0.012864	 0.077257	 0.02341	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75468	 75555	 0.564157	 0.510614	 0.00855	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75469	 75482	 0.008614	 0.05245	 0.11982	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75470	 75888	 0.129536	 0.300893	 0.00448	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75472	 75473	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75472	 75473	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75475	 75495	 0.019564	 0.076143	 0.02035	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75475	 75983	 0.0086	 0.030586	 0.0068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75476	 75477	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75476	 75477	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75478	 75479	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75478	 75479	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75478	 75516	 0.000279	 0.004336	 0.04516	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75480	 75501	 0.020364	 0.079264	 0.02119	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75481	 75482	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75481	 75482	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75483	 75484	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75483	 75484	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75484	 76572	 0.01425	 0.093257	 0.02374	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75485	 75923	 0.131279	 0.236943	 0.00343	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 75492	 0.005843	 0.015164	 0.00368	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75486	 75508	 0.002821	 0.010729	 0.003	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75487	 75488	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75487	 75488	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75490	 75491	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75490	 75491	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75492	 75983	 0.068414	 0.1842	 0.04189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75492	 76063	 0.018021	 0.054736	 0.01199	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75493	 75494	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75493	 75494	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75493	 75544	 0.000871	 0.009879	 0.08998	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75494	 75495	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75494	 75495	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75494	 75511	 0.004114	 0.037771	 0.1495	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75494	 76133	 0.00225	 0.015186	 0.02796	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75500	 75501	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75500	 75501	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75500	 76073	 0.00265	 0.04685	 0.4493	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75503	 75914	 0.030636	 0.136529	 0.00232	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75503	 75914	 0.030636	 0.136529	 0.00232	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75506	 75507	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75506	 75507	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75506	 75930	 0.001329	 0.011014	 0.0029	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75507	 75933	 0.030571	 0.1194	 0.00265	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75507	 75933	 0.030571	 0.1194	 0.00265	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75509	 75510	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75509	 75510	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75511	 75512	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75511	 75512	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75512	 75513	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75512	 75513	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75512	 76122	 0.041993	 0.111107	 0.02604	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75513	 76135	 0.141157	 0.363129	 0.00562	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75514	 75515	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75514	 75515	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75516	 75517	 0.000507	 0.037997	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75516	 75517	 0.000507	 0.037997	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75517	 76081	 0.146457	 0.308029	 0.00561	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75518	 75519	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75518	 75519	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75519	 76167	 0.087629	 0.062079	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75519	 76188	 0.020071	 0.041243	 0.00079	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75520	 75521	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75520	 75521	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75520	 76394	 0.002071	 0.0245	 0.00697	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75525	 75526	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75525	 75526	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75527	 75528	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75527	 75528	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75529	 76078	 0.004743	 0.031664	 0.05974	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75530	 75531	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75530	 75531	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75532	 75533	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75532	 75533	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75532	 76199	 0.0245	 0.1352	 0.04896	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75533	 75571	 0.188957	 0.133886	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75533	 76398	 0.141686	 0.175943	 0.00384	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75536	 75538	 0.0033	 0.037071	 0.06791	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75537	 75538	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75537	 75538	 0.000222	 0.016665	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75539	 76212	 0.017064	 0.068329	 0.01722	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75539	 76589	 0.002807	 0.029321	 0.00987	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75540	 75541	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75540	 75541	 9.6e-05	 0.007692	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75540	 75554	 0.001143	 0.0208	 0.3906	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75541	 75542	 0.000209	 0.016699	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75541	 75542	 0.000209	 0.016699	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75543	 76389	 0.08605	 0.160043	 0.00375	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75544	 75545	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75544	 75545	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75545	 76132	 0.002857	 0.010864	 0.00304	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75547	 75548	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75547	 75548	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75547	 76602	 0.00385	 0.02995	 0.10751	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75548	 75549	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75548	 75549	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75549	 76609	 0.1293	 0.327786	 0.0065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75550	 75551	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75550	 75551	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75551	 76131	 0.016314	 0.039321	 0.01111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75551	 76207	 0.014157	 0.035586	 0.00922	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75551	 76212	 0.078771	 0.271936	 0.06569	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75553	 76389	 0.11905	 0.221464	 0.00519	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75555	 76144	 0.043336	 0.169271	 0.00376	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75556	 75557	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75556	 75557	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75556	 76203	 0.001057	 0.014871	 0.06171	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75557	 75558	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75557	 75558	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75559	 75560	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75559	 75560	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75559	 75707	 0.007357	 0.117293	 0.39841	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75561	 76559	 0.001571	 0.014286	 0.00466	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75562	 76398	 0.538729	 0.349664	 0.00665	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75562	 76451	 0.092357	 0.182893	 0.00269	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75566	 75567	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75566	 75567	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75568	 76204	 0.420543	 0.494143	 0.0086	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75569	 75575	 0.064793	 0.221421	 0.00481	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75570	 75571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75570	 75571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75572	 75573	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75572	 75573	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75573	 75574	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75573	 75574	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75575	 76398	 0.523821	 0.470943	 0.00964	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75577	 75578	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75577	 75578	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75579	 75580	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75579	 75580	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75579	 76366	 0.001564	 0.010136	 0.02019	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75580	 75581	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75580	 75581	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75583	 75584	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75583	 75584	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75585	 76367	 0.001764	 0.008593	 0.00237	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75587	 76138	 0.009579	 0.051571	 0.01417	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75589	 75590	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75589	 75590	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75589	 76678	 0.001407	 0.024464	 0.08221	 1023.0	 1074.15	 1125.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75590	 75605	 0.068536	 0.2712	 0.07159	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75590	 76676	 0.020143	 0.110636	 0.02929	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75591	 75592	 0.000194	 0.015544	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75591	 75592	 0.000194	 0.015544	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75591	 76664	 0.000843	 0.009821	 0.17419	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75593	 75594	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75593	 75594	 0.000264	 0.019816	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75594	 75606	 0.046357	 0.202586	 0.05804	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 76631	 0.069014	 0.185821	 0.04226	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 76686	 0.044436	 0.211086	 0.05101	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75594	 76688	 0.055279	 0.259293	 0.06474	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75595	 75605	 0.041636	 0.194814	 0.04846	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75595	 76651	 0.039243	 0.187507	 0.04466	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75595	 76672	 0.043	 0.2058	 0.05996	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75596	 75597	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75596	 75597	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75598	 75599	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75598	 75599	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75600	 76623	 0.016543	 0.041907	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75601	 75602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75601	 75602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75604	 76629	 0.054893	 0.16575	 0.05206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75605	 76672	 0.036207	 0.09865	 0.02176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75606	 76686	 0.014871	 0.051829	 0.01202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75607	 75608	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75607	 75608	 0.00107	 0.055656	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75607	 76674	 0.003771	 0.024486	 0.0488	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75610	 75611	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75610	 75611	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75612	 75679	 0.142979	 0.117714	 0.00239	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75612	 75713	 0.228443	 0.224536	 0.00379	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75613	 75614	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75613	 75614	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75613	 75657	 0.006971	 0.047614	 0.08589	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75614	 75615	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75614	 75615	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75616	 75617	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75616	 75617	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75617	 75618	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75617	 75618	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75619	 75620	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75619	 75620	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75619	 75719	 0.003836	 0.013421	 0.00445	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75621	 75704	 0.048229	 0.1884	 0.00418	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75622	 75672	 0.092557	 0.324393	 0.00899	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75623	 75643	 0.023743	 0.135214	 0.03924	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75623	 75696	 0.011393	 0.044329	 0.01184	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75624	 75744	 0.019664	 0.111914	 0.03245	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75625	 75690	 0.005057	 0.063607	 0.01971	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75625	 75690	 0.005057	 0.063607	 0.01971	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75629	 75697	 0.080686	 0.141914	 0.00266	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75630	 75704	 0.107343	 0.2493	 0.00371	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75630	 75705	 0.110629	 0.253164	 0.00619	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75633	 75635	 0.01785	 0.028643	 0.00053	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75633	 75644	 0.076629	 0.084286	 0.00113	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75634	 75637	 0.001314	 0.008586	 0.00219	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75634	 75649	 0.000486	 0.006143	 0.0019	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75637	 75638	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75639	 75641	 0.003571	 0.013943	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75641	 75644	 0.049943	 0.068143	 0.00122	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75642	 75643	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75643	 75644	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75645	 75653	 0.013607	 0.030871	 0.00061	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75645	 75654	 0.029264	 0.060136	 0.00115	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75650	 75651	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75651	 75652	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75653	 75654	 0.014057	 0.028893	 0.00055	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75653	 75684	 0.077714	 0.124064	 0.00286	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75655	 75656	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75656	 75697	 0.157479	 0.323886	 0.00618	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75657	 75658	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75657	 75750	 0.003343	 0.049036	 0.18871	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75658	 75659	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75660	 75666	 0.012079	 0.112457	 0.00218	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75661	 75690	 0.008921	 0.112329	 0.03486	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75664	 75665	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75664	 75742	 0.010736	 0.110593	 0.03141	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75673	 75674	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75674	 75676	 0.0036	 0.045271	 0.01403	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75675	 75676	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75677	 75681	 0.016107	 0.036843	 0.0009	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75680	 75681	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75688	 75703	 0.03865	 0.185593	 0.00555	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75691	 75692	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75692	 76681	 0.035721	 0.213679	 0.05654	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75694	 75710	 0.031321	 0.1295	 0.0307	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75695	 75751	 0.0269	 0.308007	 0.12076	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75695	 75751	 0.0269	 0.308007	 0.12076	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75696	 75697	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75698	 75699	 0.240071	 0.298314	 0.00651	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75700	 75701	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75700	 75701	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75701	 75702	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75701	 75702	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75702	 75703	 8.7e-05	 0.006944	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75705	 75747	 0.038543	 0.219171	 0.00396	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75707	 75708	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75709	 75710	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75713	 75745	 0.198814	 0.511843	 0.00794	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75715	 75749	 0.024843	 0.123279	 0.00294	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75717	 75718	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75719	 75720	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75720	 75721	 0.0121	 0.037107	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75728	 75729	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75730	 75731	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75730	 75731	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75730	 75821	 0.005807	 0.081393	 0.85864	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75731	 75732	 8.7e-05	 0.006944	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75732	 75734	 0.134286	 0.095136	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75737	 75738	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75740	 75741	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75744	 75745	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75750	 75751	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75752	 75753	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75756	 76665	 0.02665	 0.148964	 0.03815	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75758	 75759	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75758	 76668	 0.004464	 0.039807	 0.07004	 417.0	 437.85	 458.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75771	 75772	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75775	 75832	 0.132364	 0.45285	 0.00986	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75776	 75777	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75778	 75779	 0.017929	 0.074064	 0.01754	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75780	 75781	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75784	 75785	 0.0141	 0.022514	 0.00052	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75785	 75786	 0.0138	 0.031564	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75789	 75790	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75789	 75792	 0.000264	 0.002986	 0.05744	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75790	 75791	 0.005643	 0.056207	 0.02089	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75790	 75794	 0.007864	 0.026971	 0.00646	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75791	 75801	 0.025321	 0.139764	 0.05063	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75792	 75793	 9.3e-05	 0.007407	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75792	 75824	 0.001371	 0.017043	 0.17146	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75793	 75794	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75793	 75811	 0.004086	 0.055857	 0.19279	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75794	 75795	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75796	 75797	 0.01935	 0.030886	 0.00071	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75801	 75802	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75805	 75807	 0.0445	 0.071036	 0.00164	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75806	 75808	 0.259329	 0.167993	 0.0032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75809	 75831	 0.09145	 0.246793	 0.05628	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75811	 75812	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75812	 75813	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75813	 75839	 0.708121	 0.562286	 0.00708	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75814	 75845	 0.022521	 0.16795	 0.06439	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75815	 75816	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75816	 75823	 0.166571	 0.387043	 0.00576	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75817	 75818	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75817	 75821	 0.000814	 0.010293	 0.15696	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75821	 75822	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75821	 75822	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75822	 75823	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75824	 75825	 0.000214	 0.017099	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75824	 75842	 0.001736	 0.019321	 0.20371	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75826	 75827	 0.000318	 0.023855	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75831	 75832	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75836	 75837	 0.084743	 0.362657	 0.00821	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75840	 75841	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75840	 75845	 0.025907	 0.32965	 0.10385	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75840	 75845	 0.025907	 0.32965	 0.10385	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75843	 75844	 0.000883	 0.047706	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75848	 75850	 0.061579	 0.048729	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75849	 75850	 0.036236	 0.028679	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75851	 75852	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75851	 76620	 0.015036	 0.102093	 0.18974	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75852	 75853	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75855	 75856	 0.00019	 0.015181	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75858	 75859	 0.015371	 0.028586	 0.00067	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75862	 75935	 0.1254	 0.439879	 0.01221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75862	 75935	 0.1254	 0.439879	 0.01221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75862	 75953	 0.012757	 0.081343	 0.00198	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75864	 76087	 0.027786	 0.055014	 0.00081	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75865	 75866	 0.002636	 0.0162	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75867	 75875	 0.016514	 0.0327	 0.00048	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75869	 75872	 0.012471	 0.03825	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75869	 75873	 0.013121	 0.0244	 0.00057	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75871	 75872	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75871	 75874	 0.000864	 0.010464	 0.00594	 523.0	 549.15	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75873	 76040	 0.00515	 0.020436	 0.00059	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75877	 75885	 0.0059	 0.0376	 0.00091	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75878	 75885	 0.008129	 0.031736	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75879	 75883	 0.086307	 0.137793	 0.00317	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75882	 75883	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75883	 75886	 0.049479	 0.219364	 0.00659	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75884	 75909	 0.001221	 0.016	 0.05181	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75884	 76151	 0.0053	 0.03655	 0.06459	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	75886	 75923	 0.061564	 0.446586	 0.01124	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75891	 75894	 0.107321	 0.4197	 0.00932	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75891	 75894	 0.107321	 0.4197	 0.00932	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75895	 75897	 0.017821	 0.062407	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75895	 75897	 0.017821	 0.062407	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75896	 75897	 0.007286	 0.028457	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75896	 75897	 0.007286	 0.028457	 0.00063	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75901	 75902	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75903	 75922	 0.117721	 0.41285	 0.01146	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75903	 75922	 0.117721	 0.41285	 0.01146	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75904	 75905	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75906	 75985	 0.01294	 0.11887	 0.24927	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75907	 75908	 0.004675	 0.0944	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75909	 75910	 0.001929	 0.020586	 0.03731	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75910	 75911	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75911	 76080	 0.012621	 0.072536	 0.02056	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75912	 76080	 0.011243	 0.068	 0.01736	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75916	 75917	 8.2e-05	 0.006578	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75917	 75918	 0.028229	 0.098843	 0.00274	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75917	 75918	 0.028229	 0.098843	 0.00274	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75928	 75931	 0.016943	 0.066179	 0.00146	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75928	 75931	 0.016943	 0.066179	 0.00146	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75929	 75932	 0.019721	 0.067379	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75930	 75931	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75934	 75940	 0.305829	 0.606857	 0.00893	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75936	 75942	 0.009621	 0.054757	 0.00169	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 75940	 0.029607	 0.11565	 0.00256	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 75940	 0.029607	 0.11565	 0.00256	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 75943	 0.030021	 0.105121	 0.00291	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75939	 75943	 0.030021	 0.105121	 0.00291	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75940	 75941	 0.008686	 0.038486	 0.00116	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75942	 75944	 0.037307	 0.046307	 0.00101	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75945	 75946	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75949	 75950	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75949	 75950	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75950	 75951	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75950	 75951	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75951	 75952	 8.7e-05	 0.006944	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75952	 75953	 0.00665	 0.042386	 0.00104	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75952	 75969	 0.1238	 0.284564	 0.00432	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75952	 75982	 0.039664	 0.090714	 0.00221	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75954	 75955	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75956	 75980	 0.089393	 0.263007	 0.00539	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75960	 75961	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75960	 75963	 0.011064	 0.029764	 0.00835	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	75962	 75963	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75963	 75964	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75965	 75967	 0.009379	 0.016493	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75966	 75971	 0.011736	 0.024021	 0.00059	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	75967	 75968	 0.001879	 0.01005	 0.00031	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75968	 75972	 0.0104	 0.024136	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75976	 75977	 0.014629	 0.062543	 0.00141	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	75977	 75978	 0.012971	 0.069671	 0.00166	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75979	 75981	 0.023164	 0.11495	 0.00274	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75984	 75985	 0.0	 1e-05	 0.0	 1150.0	 1437.5	 1725.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75992	 75994	 0.02735	 0.017707	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	75992	 76034	 0.023871	 0.049057	 0.00094	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	75992	 76037	 0.003707	 0.018407	 0.00044	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	75992	 76041	 0.037143	 0.0461	 0.00101	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	75996	 75997	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	75999	 76001	 0.005879	 0.010936	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76003	 76031	 0.001036	 0.009186	 0.00504	 437.0	 458.85	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76003	 76060	 0.003007	 0.010329	 0.00247	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76004	 76005	 0.000371	 0.027831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76005	 76189	 0.028443	 0.052893	 0.00124	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76006	 76059	 0.000429	 0.002879	 0.00542	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76007	 76008	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76009	 76012	 9.3e-05	 0.000986	 0.0097	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76010	 76011	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76010	 76012	 5.7e-05	 0.000671	 0.00604	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76011	 76014	 0.001	 0.003793	 0.00106	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76011	 76028	 0.001943	 0.006543	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76012	 76013	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76012	 76013	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76013	 76014	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76014	 76060	 0.003879	 0.0151	 0.00403	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76015	 76016	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76016	 76060	 0.000843	 0.00495	 0.00135	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76018	 76021	 0.010543	 0.02795	 0.00071	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76022	 76025	 0.00905	 0.018593	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76023	 76024	 0.020093	 0.021464	 0.00046	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76025	 76026	 0.003464	 0.011829	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76029	 76030	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76029	 76030	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76030	 76031	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76030	 76031	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76031	 76032	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76031	 76044	 0.007086	 0.025043	 0.00564	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76031	 76179	 0.00415	 0.022779	 0.00602	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76032	 76035	 0.010593	 0.040764	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76032	 76171	 0.042179	 0.067657	 0.00125	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76032	 76187	 0.079293	 0.065271	 0.00132	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76033	 76034	 0.002843	 0.012607	 0.00038	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76035	 76047	 0.035907	 0.075471	 0.00137	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76037	 76038	 0.012293	 0.012079	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76039	 76040	 0.003636	 0.019371	 0.00034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76043	 76050	 0.000307	 0.002064	 0.00376	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76044	 76045	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76044	 76179	 0.007443	 0.019979	 0.00453	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76048	 76049	 0.006957	 0.02975	 0.00067	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76049	 76052	 0.005193	 0.020607	 0.00059	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76049	 76057	 0.009614	 0.01975	 0.00038	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76050	 76051	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76051	 76052	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76053	 76054	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76054	 76056	 0.009614	 0.048629	 0.00084	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76054	 76186	 0.040936	 0.055807	 0.00124	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76059	 76060	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76060	 76061	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76064	 76065	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76066	 76067	 9.4e-05	 0.007517	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76067	 76576	 0.008071	 0.048114	 0.01266	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76068	 76069	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76071	 76072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76073	 76074	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76073	 76074	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76074	 76075	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76078	 76079	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76080	 76081	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76082	 76083	 8.6e-05	 0.006896	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76085	 76086	 0.022329	 0.035636	 0.00082	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76085	 76090	 0.02735	 0.019371	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76087	 76103	 0.006836	 0.044107	 0.00141	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76089	 76100	 0.003614	 0.015086	 0.00044	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76092	 76093	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76094	 76096	 0.016929	 0.027029	 0.00062	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76099	 76100	 0.011443	 0.023521	 0.00045	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76099	 76102	 0.0113	 0.018129	 0.00034	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76103	 76105	 0.012914	 0.057214	 0.00131	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76120	 76211	 0.010414	 0.068286	 0.13458	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76122	 76123	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76134	 76608	 0.104621	 0.207193	 0.00304	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76135	 76609	 0.160293	 0.199064	 0.00434	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76136	 76138	 0.038793	 0.138221	 0.0308	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76138	 76139	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76144	 76145	 0.085407	 0.158843	 0.00372	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76146	 76147	 0.000321	 0.004093	 0.00774	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76147	 76148	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76147	 76196	 0.001879	 0.012171	 0.02425	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76148	 76149	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76151	 76152	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76151	 76184	 0.000536	 0.006729	 0.02739	 871.0	 914.55	 958.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76154	 76186	 0.005614	 0.016521	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76157	 76159	 0.010607	 0.019714	 0.00046	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76157	 76165	 0.0419	 0.027121	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76160	 76161	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76162	 76163	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76163	 76164	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76165	 76166	 0.009729	 0.022586	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76166	 76167	 0.002614	 0.014871	 0.00027	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76170	 76182	 0.018679	 0.01685	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76171	 76174	 0.0237	 0.016793	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76173	 76174	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76175	 76176	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76176	 76180	 0.014986	 0.027864	 0.00065	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76178	 76179	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76179	 76180	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76181	 76184	 0.000514	 0.004036	 0.01401	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76184	 76185	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76185	 76186	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76187	 76189	 0.005057	 0.023564	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76187	 76190	 0.005564	 0.011436	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76191	 76195	 0.015471	 0.035907	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76194	 76195	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76196	 76197	 0.000405	 0.030361	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76196	 76198	 0.000807	 0.0103	 0.01947	 541.0	 568.05	 595.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76198	 76199	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76203	 76204	 0.000119	 0.009542	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76204	 76404	 0.259564	 0.5346	 0.01021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76204	 76405	 0.342507	 0.550814	 0.01019	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76212	 76576	 0.071914	 0.193679	 0.04406	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76215	 76218	 0.074129	 0.19655	 0.00499	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76217	 76218	 0.008543	 0.054479	 0.00133	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76234	 76238	 0.005936	 0.015736	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76236	 76238	 0.019943	 0.017871	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76239	 76241	 0.010007	 0.017593	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76245	 76246	 0.021921	 0.014193	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76250	 76251	 0.012836	 0.008307	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76252	 76272	 0.006729	 0.027964	 0.00653	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76256	 76257	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76256	 76272	 0.00705	 0.024571	 0.0057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76265	 76266	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76265	 76313	 0.011021	 0.029129	 0.00682	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76270	 76271	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76270	 76271	 8.9e-05	 0.007142	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76271	 76272	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76271	 76272	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76271	 76288	 0.001314	 0.008343	 0.01748	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76271	 76351	 0.002843	 0.0192	 0.03537	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76272	 76273	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76279	 76280	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76280	 76281	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76280	 76282	 8.6e-05	 0.0013	 0.00272	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76281	 76284	 0.0003	 0.0036	 0.00126	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76281	 76328	 0.015357	 0.037021	 0.01046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76282	 76283	 0.000318	 0.022264	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76286	 76287	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76289	 76291	 0.037093	 0.026271	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76290	 76292	 0.038357	 0.024836	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76298	 76303	 0.035093	 0.053764	 0.00076	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76300	 76302	 0.025443	 0.027986	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76300	 76303	 0.029286	 0.018957	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76310	 76311	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76313	 76314	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76319	 76444	 0.044293	 0.112207	 0.00222	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76322	 76323	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76322	 76328	 0.004636	 0.015121	 0.00401	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76327	 76328	 7.6e-05	 0.006055	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76328	 76329	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76329	 76349	 0.214421	 0.169743	 0.00214	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76336	 76337	 0.016779	 0.017914	 0.00038	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76337	 76341	 0.0403	 0.026086	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76339	 76462	 0.051986	 0.033657	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76343	 76344	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76344	 76347	 0.013914	 0.047543	 0.00104	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76351	 76352	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76351	 76366	 0.001143	 0.01785	 0.03836	 647.0	 679.35	 711.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76352	 76353	 0.003493	 0.011393	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76353	 76354	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76354	 76357	 0.023264	 0.02785	 0.00046	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76359	 76360	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76366	 76367	 0.00013	 0.01038	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76368	 76369	 0.000204	 0.016284	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76368	 76383	 0.000143	 0.00195	 0.01947	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76372	 76373	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76372	 76373	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76373	 76374	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76374	 76375	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76377	 76378	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76380	 76381	 0.000194	 0.015544	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76385	 76386	 0.031436	 0.02035	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76389	 76596	 0.197586	 0.406557	 0.00776	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76393	 76394	 0.005357	 0.025529	 0.0074	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76394	 76395	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76396	 76397	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76397	 76398	 0.288236	 0.186743	 0.00356	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76402	 76445	 0.114021	 0.089386	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76407	 76408	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76410	 76411	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76412	 76414	 0.0323	 0.025564	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76414	 76420	 0.004343	 0.02025	 0.00046	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76415	 76416	 0.008971	 0.012229	 0.00027	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76419	 76420	 0.009093	 0.015986	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76427	 76458	 0.040193	 0.042921	 0.00091	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76429	 76435	 0.078636	 0.055707	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76438	 76439	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76438	 76448	 0.007707	 0.019379	 0.00502	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76438	 76448	 0.007707	 0.019379	 0.00502	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76447	 76448	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76447	 76448	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76448	 76449	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76450	 76568	 0.136043	 0.107671	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76452	 76453	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76459	 76460	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76459	 76461	 0.002271	 0.009386	 0.00222	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76461	 76462	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76472	 76476	 0.059914	 0.07875	 0.00108	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76475	 76476	 0.007893	 0.030714	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76477	 76478	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76480	 76481	 0.024864	 0.022436	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76480	 76482	 0.043314	 0.028043	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76480	 76500	 0.019621	 0.034507	 0.00065	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76480	 76515	 0.022693	 0.046436	 0.00114	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76484	 76485	 0.0475	 0.03075	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76490	 76491	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76500	 76511	 0.02055	 0.070193	 0.00153	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76501	 76504	 0.020221	 0.037607	 0.00088	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76506	 76507	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76513	 76524	 0.080193	 0.056807	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76533	 76537	 0.006593	 0.040529	 0.00073	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76534	 76535	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76535	 76536	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76538	 76539	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76541	 76542	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76541	 76546	 0.004893	 0.016321	 0.00414	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76542	 76543	 0.005836	 0.017157	 0.00035	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76546	 76547	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76550	 76551	 0.11305	 0.073193	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76560	 76563	 0.034879	 0.061343	 0.00115	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76566	 76569	 0.035029	 0.065129	 0.00152	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76568	 76569	 0.024236	 0.069521	 0.00107	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76572	 76573	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76577	 76579	 0.021314	 0.096771	 0.0021	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76578	 76579	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76578	 76583	 0.007193	 0.027343	 0.00766	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76583	 76584	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76586	 76587	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76587	 76588	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76593	 76600	 0.024929	 0.043843	 0.00082	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76593	 76605	 0.018907	 0.035157	 0.00082	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76594	 76595	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76595	 76596	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76595	 76598	 0.0058	 0.019886	 0.00476	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76595	 76607	 0.011143	 0.056736	 0.02058	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76598	 76599	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76602	 76603	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76604	 76605	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76606	 76607	 9.7e-05	 0.007789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76616	 76617	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76616	 76647	 0.00755	 0.108986	 0.03965	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76616	 77566	 0.027121	 0.222657	 0.06081	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76617	 76618	 0.024921	 0.097329	 0.00216	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76617	 76618	 0.024921	 0.097329	 0.00216	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76620	 76621	 8.3e-05	 0.006605	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76620	 76668	 0.009564	 0.065414	 0.11821	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76621	 76661	 0.041429	 0.109607	 0.02569	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76627	 76628	 0.000109	 0.008695	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76627	 76664	 0.001971	 0.022764	 0.19999	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76632	 76633	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76635	 76636	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76638	 76639	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76638	 76642	 0.000214	 0.001493	 0.00254	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76639	 76640	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76642	 76643	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76643	 76644	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76644	 76646	 0.012057	 0.047079	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76644	 76646	 0.012057	 0.047079	 0.00104	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76649	 76650	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76649	 76670	 0.03345	 0.130329	 0.03489	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76651	 76672	 0.074364	 0.204464	 0.04464	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76652	 76657	 0.028757	 0.051893	 0.00075	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76652	 76658	 0.009829	 0.038386	 0.00085	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76655	 76656	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76659	 76660	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76661	 76662	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76665	 76666	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76665	 76667	 0.014736	 0.073357	 0.0237	 193.0	 202.65	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76668	 76669	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76671	 76672	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76671	 76672	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76673	 76675	 0.001743	 0.011871	 0.02137	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76673	 76678	 0.002857	 0.01905	 0.03591	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76674	 76675	 0.002657	 0.017243	 0.03436	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76675	 76676	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76676	 76679	 0.005243	 0.021836	 0.00681	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76678	 76679	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76679	 76680	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76681	 76682	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76687	 76688	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76689	 76690	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76689	 76690	 8.3e-05	 0.006666	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76690	 76691	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76690	 76691	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76690	 76699	 0.001764	 0.017114	 0.06056	 731.0	 767.55	 804.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76691	 76692	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76691	 76692	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76691	 76706	 0.085393	 0.280629	 0.07523	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76691	 76709	 0.048286	 0.131643	 0.02905	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 76705	 0.017993	 0.062993	 0.00174	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 76705	 0.017993	 0.062993	 0.00174	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 76707	 0.018979	 0.066443	 0.00184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 76707	 0.018979	 0.066443	 0.00184	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 76901	 0.167836	 0.494436	 0.01016	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76692	 76902	 0.165029	 0.486143	 0.00999	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76693	 76694	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 0	 -30.0	 30.0;
	76693	 76694	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 0	 -30.0	 30.0;
	76694	 76695	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76694	 76695	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76695	 76716	 0.002393	 0.028429	 0.0099	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76695	 76716	 0.002393	 0.028429	 0.0099	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76696	 76697	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76696	 76697	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76698	 76718	 0.025671	 0.308343	 0.10919	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76698	 76718	 0.025671	 0.308343	 0.10919	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76699	 76700	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76699	 76700	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76700	 76912	 0.034043	 0.140779	 0.03338	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76701	 76702	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76701	 76702	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76704	 76705	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76704	 76705	 0.001336	 0.066787	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76708	 77170	 0.032221	 0.232007	 0.00761	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76709	 76711	 0.004675	 1e-05	 0.0	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76710	 76711	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76710	 76711	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76711	 76712	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76711	 76712	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76713	 76714	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76713	 76714	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76715	 77102	 0.007779	 0.015993	 0.00031	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76716	 76882	 0.000471	 0.006179	 0.00379	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76716	 76884	 0.030029	 0.118164	 0.03096	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 77186	 0.003786	 0.046643	 0.01507	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76718	 77186	 0.003786	 0.046643	 0.01507	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76719	 76720	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76719	 76720	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76720	 77261	 0.009121	 0.024186	 0.00061	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76722	 77224	 0.030864	 0.019986	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76724	 77190	 0.01655	 0.065657	 0.00188	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 76741	 0.024236	 0.056264	 0.00084	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77277	 0.0099	 0.033821	 0.00074	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77279	 0.012314	 0.0253	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77280	 0.01025	 0.019064	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77281	 0.019164	 0.021079	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77282	 0.067271	 0.053236	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77283	 0.0841	 0.059571	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77285	 0.038243	 0.0786	 0.0015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77286	 0.099764	 0.175486	 0.0033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77287	 0.082021	 0.144271	 0.00271	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76725	 77288	 0.054371	 0.101107	 0.00236	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 77254	 0.017214	 0.085421	 0.00204	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76726	 77258	 0.029614	 0.131243	 0.00394	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76727	 76728	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76727	 76728	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76727	 77179	 0.003971	 0.027093	 0.04881	 366.0	 384.3	 402.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76728	 77169	 0.006536	 0.0651	 0.02419	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76728	 77180	 0.028364	 0.077757	 0.01692	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76729	 76730	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76729	 76730	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76730	 77106	 0.052943	 0.0419	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76731	 76732	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76731	 76732	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76732	 77218	 0.062793	 0.192707	 0.00522	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76733	 76734	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76733	 76734	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76733	 77179	 0.004129	 0.043807	 0.111	 528.0	 554.4	 580.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76734	 76735	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76734	 76735	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76734	 76812	 0.000664	 0.009257	 0.00638	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76736	 77132	 0.100757	 0.187414	 0.00439	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76737	 76899	 0.048864	 0.193929	 0.00554	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76739	 77219	 0.014457	 0.050621	 0.0014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76739	 77220	 0.010471	 0.021521	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76739	 77221	 0.066379	 0.059886	 0.001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76739	 77233	 0.089171	 0.089193	 0.00121	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76740	 76741	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76740	 76741	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76742	 76743	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76742	 76743	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76743	 76744	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76743	 76744	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76745	 76746	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76745	 76746	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76747	 76748	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76747	 76748	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76749	 77652	 0.076171	 0.339636	 0.00577	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76749	 77652	 0.076171	 0.339636	 0.00577	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76752	 76753	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76752	 76753	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76753	 77636	 0.00745	 0.040029	 0.00095	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76753	 77639	 0.045686	 0.103629	 0.00206	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76754	 76755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76754	 76755	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76756	 76757	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76756	 76757	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76757	 76758	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76757	 76758	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76760	 77371	 0.057779	 0.350257	 0.01099	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76761	 76762	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76761	 76762	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76763	 76764	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76763	 76764	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77559	 76763	 0.001214	 0.023393	 0.46001	 1959.0	 2056.95	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76764	 76765	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76764	 76765	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76768	 77398	 0.035893	 0.172329	 0.00515	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76768	 77601	 0.060421	 0.231629	 0.00655	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76769	 77594	 0.026171	 0.102221	 0.00226	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76774	 77558	 0.010493	 0.04485	 0.00101	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76780	 77594	 0.038107	 0.096536	 0.00191	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76781	 77457	 0.033636	 0.1155	 0.02771	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76781	 77481	 0.008464	 0.020393	 0.00576	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76784	 76785	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76784	 76785	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76786	 77581	 0.105007	 0.184721	 0.00347	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76787	 76788	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76787	 76788	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76787	 77944	 0.00425	 0.045986	 0.01936	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76787	 77944	 0.00425	 0.045986	 0.01936	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76787	 77945	 0.000157	 0.001771	 0.00069	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76787	 77945	 0.000157	 0.001771	 0.00069	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76788	 76795	 0.039336	 0.13775	 0.00381	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76788	 76795	 0.039336	 0.13775	 0.00381	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76790	 76791	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76790	 76791	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76791	 76801	 0.01355	 0.039843	 0.00081	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76792	 76793	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76792	 76793	 0.00019	 0.013332	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76793	 76794	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76793	 76794	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76794	 76795	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76794	 76795	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76794	 77945	 0.003136	 0.041143	 0.01171	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76794	 77945	 0.003136	 0.041143	 0.01171	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76795	 77954	 0.020479	 0.190671	 0.00369	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76796	 76797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76796	 76797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76798	 76799	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76798	 76799	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76801	 77905	 0.018293	 0.070079	 0.00198	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76803	 77873	 0.050079	 0.284821	 0.00516	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76803	 77937	 0.083986	 0.478093	 0.00866	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76807	 77903	 0.12005	 0.353357	 0.00725	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76809	 77953	 0.029357	 0.090064	 0.00244	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76810	 76811	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76810	 76811	 0.0001	 0.007999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76811	 76812	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76811	 76812	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76812	 76813	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76812	 76813	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76813	 77172	 0.023157	 0.0681	 0.00139	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76814	 76815	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76814	 76815	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76818	 76819	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76818	 76819	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76820	 76821	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76820	 76821	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76820	 76823	 7.9e-05	 0.000643	 0.0021	 635.0	 666.75	 698.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76822	 77742	 0.008207	 0.093964	 0.02635	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76824	 76831	 0.00035	 0.00375	 0.0012	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76825	 76826	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76825	 76826	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76825	 76828	 0.006379	 0.064786	 0.13093	 473.0	 496.65	 520.3	 0.0	 0.0	 1	 -30.0	 30.0;
	76827	 76828	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76827	 76828	 0.00014	 0.010525	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76827	 77737	 0.00055	 0.009564	 0.19723	 1877.0	 1970.85	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76828	 78136	 0.005471	 0.064543	 0.26246	 834.0	 875.7	 917.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76829	 76830	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76829	 76830	 0.00021	 0.016768	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76831	 76836	 0.001143	 0.005464	 0.00159	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76831	 77743	 0.006036	 0.040443	 0.01239	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76832	 77715	 0.004764	 0.021221	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76832	 77715	 0.004764	 0.021221	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76833	 76834	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76833	 76834	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76834	 77791	 0.004264	 0.028579	 0.00876	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76835	 77655	 0.13125	 0.511386	 0.00856	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76836	 77742	 0.004043	 0.057193	 0.01895	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76838	 77722	 0.003464	 0.014807	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76841	 77739	 0.141757	 0.226393	 0.00521	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76842	 76843	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76842	 76843	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76844	 76845	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76844	 76845	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76846	 76847	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76846	 76847	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76846	 78070	 0.017829	 0.107921	 0.02758	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76848	 76849	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76848	 76849	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76850	 76851	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76850	 76851	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76851	 76852	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76851	 76852	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76853	 78128	 0.0901	 0.4848	 0.01154	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76854	 76855	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76854	 76855	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76854	 78012	 0.000157	 0.001564	 0.00103	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	76855	 78014	 0.0043	 0.016486	 0.00046	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76856	 76857	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76856	 76857	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76856	 78058	 0.00045	 0.004936	 0.00148	 317.0	 332.85	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76857	 78051	 0.036657	 0.025964	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76857	 78064	 0.02005	 0.058971	 0.00121	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76858	 78020	 0.080686	 0.079271	 0.00134	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76859	 76860	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76859	 76860	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76859	 78132	 0.000843	 0.007	 0.00212	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76860	 78133	 0.004664	 0.028671	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76863	 76864	 0.06475	 0.368864	 0.01137	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76867	 77915	 0.315514	 0.532457	 0.00759	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76869	 76872	 0.049214	 0.19225	 0.00426	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76869	 76875	 0.145721	 0.330821	 0.00661	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76870	 76871	 0.052336	 0.203643	 0.0034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76874	 76875	 0.040771	 0.065086	 0.0015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76882	 76883	 0.009886	 0.058343	 0.04756	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76889	 76890	 0.025079	 0.076936	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76901	 76905	 0.045514	 0.041064	 0.00069	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76901	 76917	 0.026286	 0.048879	 0.00114	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76911	 76912	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76912	 76913	 0.002371	 0.011307	 0.00269	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76912	 76925	 0.005043	 0.031929	 0.00866	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76913	 76914	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76913	 76927	 0.0031	 0.02195	 0.00602	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76919	 76923	 0.019664	 0.036557	 0.00086	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76919	 76926	 0.011907	 0.039714	 0.00063	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76920	 76926	 0.009157	 0.020936	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76921	 76922	 0.004807	 0.016029	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76922	 76926	 0.017264	 0.0321	 0.00075	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76922	 76941	 0.009364	 0.024814	 0.00063	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76927	 76928	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76931	 76939	 0.187379	 0.148321	 0.00186	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76933	 76936	 0.081079	 0.057436	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76934	 76935	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76936	 76947	 0.013536	 0.0307	 0.00061	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76937	 76938	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76940	 76941	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76940	 76959	 0.001593	 0.0058	 0.00178	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76944	 76950	 0.015057	 0.043186	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76945	 77144	 0.005943	 0.017043	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76951	 76970	 0.003114	 0.013314	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	76953	 76986	 0.006164	 0.018136	 0.00037	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76954	 76956	 0.014343	 0.011807	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76955	 76958	 0.027086	 0.03695	 0.00066	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	76958	 76963	 0.010914	 0.02765	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76960	 77039	 0.064007	 0.045343	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76962	 76963	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76963	 76972	 0.032857	 0.094243	 0.00145	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76964	 76986	 0.0058	 0.016629	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76965	 76966	 0.003514	 0.013714	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	76967	 76982	 0.005621	 0.016543	 0.00034	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76975	 77082	 0.044729	 0.065179	 0.00147	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	76977	 76994	 0.010179	 0.01625	 0.00037	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76978	 76979	 0.028307	 0.020057	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76987	 76988	 0.008614	 0.01515	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76991	 76992	 0.008143	 0.012214	 0.00022	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	76991	 77007	 0.017036	 0.0582	 0.00126	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76992	 76993	 0.002643	 0.006686	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	76995	 77011	 0.011136	 0.037157	 0.00059	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77007	 77009	 0.019836	 0.039271	 0.00058	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77009	 77013	 0.002729	 0.010836	 0.00031	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77010	 77027	 0.008671	 0.033879	 0.00075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77012	 77025	 0.009207	 0.016193	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77014	 77015	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77014	 77076	 0.003271	 0.012436	 0.00348	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77015	 77020	 0.004093	 0.013986	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77020	 77078	 0.008129	 0.018679	 0.00029	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77022	 77023	 0.02985	 0.023621	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77023	 77029	 0.036593	 0.032786	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77023	 77030	 0.022521	 0.02275	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77024	 77030	 0.006636	 0.015171	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77025	 77031	 0.007629	 0.029243	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77029	 77048	 0.009336	 0.0149	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77029	 77049	 0.009314	 0.014871	 0.00034	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77032	 77077	 0.003571	 0.013679	 0.00039	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77032	 77078	 0.007364	 0.013686	 0.00032	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77033	 77035	 0.021964	 0.019814	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77036	 77043	 0.00555	 0.018964	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77038	 77043	 0.0189	 0.043229	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77040	 77041	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77040	 77041	 0.000119	 0.009523	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77041	 77042	 8.5e-05	 0.006812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77042	 77043	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77048	 77052	 0.025636	 0.025893	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77054	 77055	 0.011107	 0.019529	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77054	 77057	 0.030136	 0.021343	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77058	 77060	 0.024357	 0.017257	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77059	 77068	 0.048786	 0.049279	 0.00065	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77059	 77079	 0.024079	 0.017057	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77062	 77063	 0.0292	 0.020686	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77063	 77064	 0.0029	 0.007336	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77064	 77081	 0.012379	 0.036393	 0.00074	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77067	 77068	 0.011536	 0.020293	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77068	 77069	 0.035229	 0.027879	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77068	 77098	 0.0168	 0.04255	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77076	 77077	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77080	 77081	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77082	 77086	 0.040593	 0.102829	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77088	 77089	 0.003129	 0.0096	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77090	 77092	 0.008086	 0.021421	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77091	 77100	 0.014	 0.024629	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77092	 77095	 0.017607	 0.0114	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77093	 77095	 0.012364	 0.02175	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77096	 77097	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77097	 77098	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77097	 77099	 0.000779	 0.005443	 0.00204	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77098	 77102	 0.017464	 0.046286	 0.00117	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77099	 77100	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77100	 77114	 0.014543	 0.060693	 0.00175	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77102	 77104	 0.023464	 0.016621	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77103	 77104	 0.013657	 0.016014	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77107	 77123	 0.034064	 0.054364	 0.00125	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77108	 77109	 0.028586	 0.022621	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77108	 77113	 0.024093	 0.0156	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77109	 77110	 0.009193	 0.016164	 0.00031	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77110	 77113	 0.004764	 0.014021	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77111	 77112	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77115	 77116	 0.008379	 0.024021	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77117	 77118	 0.004007	 0.012293	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77118	 77121	 0.004793	 0.0141	 0.00029	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77128	 77132	 0.084964	 0.16825	 0.00247	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77132	 77135	 0.005493	 0.027257	 0.00065	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77140	 77146	 0.0025	 0.009579	 0.00027	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77151	 77161	 0.006921	 0.015821	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77156	 77157	 0.0251	 0.01625	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77163	 77181	 0.123193	 0.540886	 0.01166	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77165	 77166	 0.06655	 0.195757	 0.00401	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77165	 77181	 0.13875	 0.368214	 0.00935	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77166	 77167	 0.133414	 0.522136	 0.01161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77167	 77168	 0.062671	 0.184329	 0.00378	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77169	 77170	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77170	 77172	 0.009821	 0.071143	 0.00179	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77171	 77172	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77173	 77174	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77175	 77176	 0.0164	 0.023893	 0.00054	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77178	 77181	 0.024979	 0.057129	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77179	 77180	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77179	 78131	 0.020314	 0.198114	 0.36479	 435.0	 456.75	 478.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77180	 77181	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77180	 77182	 0.008507	 0.10905	 0.03261	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77188	 77189	 0.073564	 0.132743	 0.00192	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77197	 77241	 0.005121	 0.023486	 0.00601	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77202	 77212	 0.023	 0.020607	 0.00042	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77215	 77216	 0.12165	 0.109021	 0.00223	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77219	 77229	 0.008943	 0.047629	 0.00084	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77222	 77223	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77224	 77226	 0.031214	 0.070807	 0.00141	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77226	 77229	 0.014579	 0.021236	 0.00048	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77226	 77231	 0.019093	 0.015107	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77228	 77229	 0.010743	 0.0189	 0.00036	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77229	 77231	 0.015243	 0.020793	 0.00037	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77229	 77236	 0.0031	 0.015129	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77230	 77231	 0.014893	 0.019571	 0.00027	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77234	 77235	 0.003036	 0.011636	 0.00033	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77237	 77238	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77238	 77239	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77238	 77241	 0.00355	 0.014657	 0.00346	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77240	 77241	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77241	 77242	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77250	 77251	 0.008871	 0.020293	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77250	 77256	 0.119886	 0.108179	 0.00181	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77252	 77253	 0.008757	 0.026857	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77252	 77254	 0.074821	 0.061586	 0.00125	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77253	 77254	 0.018443	 0.032436	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77258	 77259	 0.057657	 0.118507	 0.00226	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77263	 77269	 0.038843	 0.247757	 0.00604	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77267	 77268	 0.011386	 0.030179	 0.00076	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77274	 77275	 0.021964	 0.0939	 0.00212	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77278	 77281	 0.004679	 0.008693	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77284	 77285	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77296	 77297	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77301	 77302	 0.012029	 0.030471	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77302	 77327	 0.114129	 0.0739	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77303	 77310	 0.057829	 0.037443	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77305	 77306	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77307	 77308	 0.022657	 0.01605	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77311	 77327	 0.030336	 0.048429	 0.00111	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77312	 77313	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77318	 77327	 0.047421	 0.050643	 0.00107	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77319	 77525	 0.013207	 0.02225	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77321	 77322	 0.006429	 0.0147	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77326	 77327	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77328	 77329	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77329	 77345	 0.045486	 0.139557	 0.00378	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77330	 77341	 0.019657	 0.026814	 0.00048	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77331	 77332	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77332	 77546	 0.113307	 0.080271	 0.00127	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77342	 77343	 0.017521	 0.012407	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77352	 77363	 0.018807	 0.043021	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77355	 77356	 0.002021	 0.010029	 0.00024	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77357	 77360	 0.01495	 0.037864	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77359	 77360	 0.029714	 0.026629	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77361	 77365	 0.010643	 0.024143	 0.00048	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77365	 77367	 0.003921	 0.01525	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77366	 77367	 0.013957	 0.017321	 0.00038	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77370	 77562	 0.0923	 0.360836	 0.00801	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77372	 77373	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77372	 77373	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77372	 77519	 0.000714	 0.006486	 0.13254	 1097.0	 1151.85	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77373	 77374	 9.8e-05	 0.007812	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77380	 77382	 0.004093	 0.018136	 0.00054	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77383	 77384	 0.026607	 0.042471	 0.00098	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77388	 77389	 0.036707	 0.055029	 0.001	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77390	 77396	 0.050414	 0.045486	 0.00076	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77391	 77557	 0.015264	 0.038671	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77392	 77394	 0.008043	 0.027471	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77395	 77396	 0.009936	 0.025164	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77398	 77399	 0.1862	 0.244821	 0.00336	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77401	 77402	 0.0176	 0.077957	 0.00178	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77407	 77541	 0.030971	 0.02005	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77412	 77427	 0.063264	 0.052071	 0.00106	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77420	 77425	 0.015871	 0.013064	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77430	 77431	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77437	 77545	 0.024007	 0.055736	 0.00083	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77438	 77439	 0.000153	 0.011473	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77439	 77440	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77441	 77446	 0.084207	 0.05965	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77443	 77449	 0.026364	 0.066779	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77445	 77458	 0.044107	 0.126521	 0.00194	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77453	 77454	 0.028664	 0.050407	 0.00095	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77457	 77458	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77461	 77513	 0.143657	 0.1137	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77464	 77487	 0.207943	 0.412129	 0.00606	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77465	 77501	 0.005571	 0.017093	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77466	 77467	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77467	 77468	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77468	 77496	 0.014686	 0.045043	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77469	 77471	 0.025486	 0.0165	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77472	 77473	 0.0088	 0.017421	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77472	 77476	 0.002721	 0.010793	 0.00031	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77481	 77482	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77486	 77507	 0.006686	 0.033179	 0.00079	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77488	 77489	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77489	 77490	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77490	 77491	 0.018807	 0.038657	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77508	 77608	 0.098586	 0.261464	 0.00664	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77510	 77511	 0.019836	 0.034886	 0.00066	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77515	 77613	 0.046871	 0.3027	 0.00965	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77516	 77521	 0.261157	 0.185086	 0.00293	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77519	 77520	 9.5e-05	 0.007589	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77520	 77521	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77521	 77529	 0.038157	 0.133629	 0.0037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77523	 77556	 0.005279	 0.012071	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77530	 77534	 0.006807	 0.028421	 0.00082	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77532	 77533	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77539	 77541	 0.009264	 0.028414	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77540	 77541	 0.004786	 0.010864	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77542	 77543	 0.019464	 0.034236	 0.00064	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77546	 77550	 0.138793	 0.089871	 0.00171	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77548	 77549	 0.066479	 0.043043	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77559	 77560	 9.5e-05	 0.007589	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77560	 77561	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77562	 77563	 0.216543	 0.212821	 0.00359	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77566	 77567	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77567	 77570	 0.008836	 0.041193	 0.00095	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	77573	 77576	 0.037064	 0.126614	 0.00276	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77574	 77577	 0.010407	 0.029843	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77575	 77576	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77576	 77649	 0.0451	 0.1169	 0.00221	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77583	 77584	 0.022593	 0.032921	 0.00074	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77588	 77589	 0.3477	 0.246521	 0.0039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77597	 77612	 0.193064	 0.569107	 0.0117	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77601	 77620	 0.079871	 0.181214	 0.00361	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77628	 77630	 0.011786	 0.03615	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77632	 77633	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77637	 77638	 0.008786	 0.02695	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77642	 77643	 0.032707	 0.025886	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77642	 77644	 0.036664	 0.033086	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77645	 77646	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77653	 77654	 0.080507	 0.313357	 0.00524	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77663	 77664	 0.018186	 0.021314	 0.00037	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77665	 77666	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77674	 77688	 0.011271	 0.011071	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77687	 77698	 0.0374	 0.037779	 0.0005	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77687	 77700	 0.021136	 0.056014	 0.00142	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77687	 77746	 0.012957	 0.032814	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77689	 77693	 0.0042	 0.012871	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77689	 77695	 0.009671	 0.025636	 0.00065	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77689	 77765	 0.0049	 0.021821	 0.00037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77690	 77692	 0.010607	 0.028114	 0.00071	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77691	 77692	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77696	 77698	 0.03335	 0.023621	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77711	 77717	 0.035036	 0.055929	 0.00129	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77712	 77763	 0.004971	 0.024679	 0.00059	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77713	 77717	 0.006957	 0.015907	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77716	 77717	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77719	 77720	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77719	 77721	 0.002593	 0.00985	 0.00276	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77721	 77722	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77723	 77725	 0.006771	 0.036229	 0.0011	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77730	 77732	 0.00755	 0.022207	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77737	 77738	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77737	 77738	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77738	 77739	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77738	 77739	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77744	 77745	 0.007479	 0.021443	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77749	 77767	 0.056336	 0.301743	 0.00916	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77750	 77753	 0.011536	 0.030579	 0.00078	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77752	 77753	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77758	 77759	 0.011693	 0.008286	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77764	 77765	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77781	 77785	 0.257679	 0.232636	 0.00389	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77782	 77783	 0.000389	 0.027247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77783	 77820	 0.006786	 0.024686	 0.00756	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77784	 77785	 0.163964	 0.335907	 0.00828	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77786	 77787	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77790	 77791	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77791	 77792	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77803	 77807	 0.107564	 0.118314	 0.00158	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77804	 77807	 0.156371	 0.140157	 0.00286	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77806	 77807	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77806	 77817	 0.019214	 0.091	 0.0219	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77813	 77814	 0.10515	 0.368636	 0.01022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77813	 77814	 0.10515	 0.368636	 0.01022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77819	 77821	 0.034186	 0.0866	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77820	 77821	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77826	 77830	 0.007693	 0.019493	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77827	 77843	 0.006421	 0.021943	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77828	 77838	 0.023193	 0.018357	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77829	 77831	 0.002486	 0.009871	 0.00028	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77837	 77855	 0.034636	 0.024536	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77846	 77847	 0.0124	 0.023057	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77849	 77850	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77851	 77968	 0.155993	 0.290293	 0.0068	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77852	 77853	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77853	 77854	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77854	 77972	 0.308329	 0.303193	 0.00512	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77856	 77857	 0.013571	 0.021664	 0.0005	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77856	 77858	 0.007829	 0.019829	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77868	 77869	 0.016843	 0.065536	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77869	 77901	 0.059414	 0.404014	 0.01001	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77870	 77871	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77871	 77909	 0.532257	 0.37785	 0.00597	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77874	 77875	 0.009386	 0.060571	 0.00193	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77876	 77877	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77879	 77929	 0.049657	 0.238493	 0.00714	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77881	 77884	 0.011864	 0.026914	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77882	 77883	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77883	 77887	 0.059207	 0.237036	 0.00501	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77883	 77888	 0.01545	 0.068464	 0.00206	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77889	 77892	 0.050214	 0.088314	 0.00166	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77895	 77896	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77896	 77897	 0.307814	 0.462321	 0.00841	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77898	 77899	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77898	 77900	 0.000493	 0.009571	 0.03804	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77900	 77901	 0.000596	 0.041746	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77906	 77907	 0.003693	 0.030721	 0.00058	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77911	 77912	 0.000699	 0.036327	 0.0	 375.0	 375.0	 375.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77912	 77913	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77917	 77918	 0.044871	 0.2155	 0.00644	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77917	 77921	 0.236986	 0.253286	 0.00536	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77917	 77923	 0.237543	 0.213	 0.00436	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77919	 77922	 0.049129	 0.15075	 0.00409	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77920	 77940	 0.1512	 0.592114	 0.01318	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77920	 77940	 0.1512	 0.592114	 0.01318	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77931	 77935	 0.012386	 0.0841	 0.00208	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77931	 77936	 0.021121	 0.144993	 0.00264	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	77942	 77943	 7.8e-05	 0.006249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77943	 77944	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77943	 77946	 0.000214	 0.004257	 0.01584	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77948	 77952	 0.084464	 0.075693	 0.00155	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77949	 77950	 0.177114	 0.125493	 0.00199	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77956	 77957	 0.186429	 0.34705	 0.00814	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77956	 77958	 0.580943	 0.412593	 0.00652	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77960	 77961	 0.056886	 0.044586	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77981	 77982	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77981	 78144	 0.007014	 0.023636	 0.00587	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77982	 77989	 0.027786	 0.063557	 0.00155	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77982	 78008	 0.580471	 0.376921	 0.00717	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77987	 77990	 0.027843	 0.024943	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77992	 77998	 0.018329	 0.053907	 0.00111	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77995	 77999	 0.033986	 0.026893	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77996	 77997	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77996	 77997	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78003	 78004	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78003	 78068	 0.112986	 0.274536	 0.07824	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78004	 78067	 0.338457	 0.544279	 0.01007	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78005	 78006	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78007	 78080	 0.0251	 0.183843	 0.04745	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78014	 78063	 0.001036	 0.007429	 0.00024	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78017	 78022	 0.0167	 0.0423	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78021	 78028	 0.062743	 0.04965	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78022	 78048	 0.026693	 0.042614	 0.00098	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78023	 78027	 0.006179	 0.026429	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78026	 78027	 0.0237	 0.021386	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78029	 78042	 0.034329	 0.046829	 0.00084	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78040	 78046	 0.022507	 0.035921	 0.00083	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78041	 78042	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78042	 78045	 0.012671	 0.049279	 0.00082	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78042	 78047	 0.0515	 0.090571	 0.0017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78046	 78066	 0.01595	 0.042271	 0.00107	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78048	 78055	 0.006986	 0.0375	 0.00089	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78055	 78056	 0.00225	 0.013479	 0.00032	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78058	 78061	 0.001943	 0.017336	 0.00455	 261.0	 274.05	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78061	 78062	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78062	 78066	 0.135414	 0.121364	 0.00249	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78062	 78084	 0.070579	 0.181471	 0.00281	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78071	 78072	 0.04345	 0.313014	 0.01028	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78073	 78076	 0.124479	 0.2849	 0.00696	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78077	 78078	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78082	 78083	 0.000242	 0.018165	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78086	 78119	 0.0079	 0.020929	 0.00053	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78086	 78121	 0.008043	 0.024664	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78087	 78091	 0.015743	 0.0463	 0.00095	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78090	 78091	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78091	 78096	 0.03245	 0.082193	 0.00163	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78091	 78122	 0.027979	 0.084214	 0.00165	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78092	 78093	 0.00625	 0.012793	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78092	 78094	 0.014036	 0.027786	 0.00041	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78098	 78101	 0.006579	 0.019343	 0.0004	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78100	 78101	 0.018257	 0.021407	 0.00037	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78105	 78106	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78105	 78107	 0.000579	 0.005321	 0.00214	 307.0	 322.35	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78109	 78110	 0.008957	 0.014293	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78113	 78126	 0.065343	 0.046286	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78114	 78115	 0.015671	 0.018371	 0.00032	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78115	 78125	 0.045357	 0.035893	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78118	 78122	 0.00905	 0.035907	 0.00103	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78131	 78132	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78131	 78136	 0.000214	 0.004171	 0.01659	 1216.0	 1216.0	 1216.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78132	 78133	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78132	 78134	 0.000864	 0.011229	 0.00324	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78132	 78134	 0.000864	 0.011229	 0.00324	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78134	 78135	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78136	 78137	 0.000262	 0.019645	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78140	 78145	 0.0086	 0.025279	 0.00052	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78144	 78145	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78144	 78146	 0.001807	 0.020229	 0.00643	 325.0	 341.25	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78146	 78147	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78152	 78153	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78152	 78153	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78153	 78154	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78153	 78154	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78153	 78187	 0.123621	 0.329907	 0.07811	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 78207	 0.113571	 0.297264	 0.07284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 78241	 0.086779	 0.311121	 0.06989	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78153	 79551	 0.007907	 0.082657	 0.02274	 293.0	 307.65	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78155	 78156	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	78155	 78156	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	78157	 78158	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78157	 78158	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78157	 79827	 0.001036	 0.016207	 0.05446	 946.0	 993.3	 1040.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78158	 78159	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78158	 78159	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78162	 78163	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78162	 78163	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78163	 78164	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78163	 78164	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78165	 78166	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78165	 78166	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78166	 79144	 0.038514	 0.034514	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78168	 78169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78168	 78169	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78169	 79542	 0.079629	 0.12775	 0.00236	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78170	 78171	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78170	 78171	 0.000699	 0.036327	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78171	 78188	 0.000829	 0.00475	 0.00158	 219.0	 229.95	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78172	 78173	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78172	 78173	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78174	 79722	 0.024057	 0.044736	 0.00105	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78174	 79725	 0.022121	 0.075557	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78175	 78176	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78175	 78176	 0.000577	 0.031138	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78176	 78177	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78176	 78177	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78179	 78180	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78179	 78180	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78180	 79777	 0.065593	 0.256293	 0.00569	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78180	 79777	 0.065593	 0.256293	 0.00569	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78180	 79853	 0.090486	 0.353729	 0.00786	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78181	 78182	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78181	 78182	 0.000272	 0.021798	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78182	 78183	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78182	 78183	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78184	 78185	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78184	 78185	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78185	 78483	 0.063793	 0.112207	 0.00211	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78186	 78452	 0.031386	 0.085507	 0.01885	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78188	 78189	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78188	 78189	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78189	 78480	 0.036221	 0.067357	 0.00158	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78190	 78191	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78190	 78191	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78191	 79453	 0.0215	 0.049179	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78193	 78194	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78193	 78194	 0.000321	 0.02569	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78194	 79031	 0.004086	 0.014293	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78194	 79031	 0.004086	 0.014293	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78195	 78196	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78195	 78196	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78195	 79127	 0.014171	 0.071214	 0.01854	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78198	 78199	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78198	 78199	 0.000208	 0.01557	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78199	 78200	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78199	 78200	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78201	 78202	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78201	 78202	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78204	 78205	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78204	 78205	 0.000195	 0.013624	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78205	 78206	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78205	 78206	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78205	 79115	 0.032271	 0.090043	 0.01891	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78208	 78209	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78208	 78209	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78208	 79464	 0.02785	 0.09915	 0.02207	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78210	 78211	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78210	 78211	 0.000323	 0.02422	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78211	 78212	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78211	 78212	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78216	 78217	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78216	 78217	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78216	 79300	 0.000443	 0.004729	 0.00961	 491.0	 515.55	 540.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78217	 78218	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78217	 78218	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78218	 79012	 0.009793	 0.052586	 0.00125	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78219	 78220	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78219	 78220	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78219	 79712	 0.000314	 0.006129	 0.02356	 1158.0	 1215.9	 1273.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78220	 78221	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78220	 78221	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78220	 78243	 0.001679	 0.02375	 0.00786	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78221	 79719	 0.020407	 0.079707	 0.00176	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78223	 78224	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78223	 78224	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78224	 79803	 0.044857	 0.115314	 0.00179	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78226	 78227	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78226	 78227	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78227	 78523	 0.035271	 0.242171	 0.00441	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78228	 78229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78228	 78229	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78232	 78233	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78232	 78233	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78232	 79316	 0.01915	 0.159536	 0.06271	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78233	 78338	 0.055914	 0.195829	 0.00542	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78233	 78338	 0.055914	 0.195829	 0.00542	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78233	 78473	 0.029029	 0.144064	 0.00344	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78241	 78242	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78241	 78242	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78242	 78322	 0.000286	 0.002629	 5e-05	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78243	 78244	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78243	 78244	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78243	 79708	 0.003386	 0.019836	 0.00541	 205.0	 215.25	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78246	 78247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78246	 78247	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78248	 78249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78248	 78249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78253	 79135	 0.000579	 0.002014	 0.00067	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78254	 78255	 0.002279	 0.008907	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78254	 78255	 0.002279	 0.008907	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78256	 78353	 0.002293	 0.017357	 0.00058	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78259	 78596	 0.033336	 0.178443	 0.00541	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78264	 79367	 0.020007	 0.079371	 0.00226	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78266	 79767	 0.006786	 0.022636	 0.00036	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78267	 79782	 0.129264	 0.397157	 0.01078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78269	 78317	 0.019314	 0.064436	 0.00102	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78270	 78358	 0.019929	 0.077821	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78273	 78801	 0.009843	 0.028243	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78273	 78809	 0.033486	 0.030214	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78273	 78813	 0.0036	 0.00835	 0.00012	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78275	 78532	 0.020007	 0.039607	 0.00058	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78276	 78277	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 0	 -30.0	 30.0;
	78276	 78277	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 0	 -30.0	 30.0;
	78278	 78551	 0.205736	 0.162864	 0.00205	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78279	 79134	 0.018564	 0.03265	 0.00061	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78280	 79400	 0.012736	 0.0771	 0.00241	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78284	 78387	 0.000343	 0.001207	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78284	 78387	 0.000343	 0.001207	 4e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78285	 78286	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78285	 78286	 0.000208	 0.014532	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78288	 78289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78288	 78289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78290	 78291	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78290	 78291	 0.000136	 0.010899	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78291	 78292	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78291	 78292	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78293	 78294	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78293	 78294	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78294	 78358	 0.01995	 0.077907	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78296	 78297	 0.002286	 0.010179	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78296	 78297	 0.002286	 0.010179	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78301	 78302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78301	 78302	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78303	 79441	 0.002629	 0.014114	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78305	 78813	 0.001943	 0.005971	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78305	 78814	 0.013814	 0.02205	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78309	 79396	 0.000407	 0.002943	 9e-05	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78313	 79768	 0.02145	 0.032157	 0.00059	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78314	 79319	 0.044336	 0.196529	 0.00591	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78315	 78316	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78315	 78316	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78316	 79438	 0.009107	 0.035421	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78318	 78319	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78318	 78319	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78318	 78546	 0.038229	 0.102729	 0.02331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78324	 78491	 0.013886	 0.06045	 0.01723	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78327	 78479	 0.010721	 0.022036	 0.00042	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78327	 78480	 0.003529	 0.006557	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78327	 78483	 0.04055	 0.0754	 0.00176	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78332	 78586	 0.141436	 0.328564	 0.00489	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78333	 78334	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78333	 78334	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78337	 79320	 0.013471	 0.047171	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78337	 79860	 0.073907	 0.226843	 0.00615	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78338	 79861	 0.030807	 0.120321	 0.00267	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78339	 79342	 0.010186	 0.077029	 0.00256	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78341	 78342	 0.000174	 0.013916	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78341	 78342	 0.000174	 0.013916	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78343	 79728	 0.033307	 0.084364	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78344	 79340	 0.045193	 0.17655	 0.00391	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78344	 79340	 0.045193	 0.17655	 0.00391	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78345	 79713	 0.0059	 0.050179	 0.00131	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78348	 78551	 0.639479	 0.507464	 0.00639	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78349	 78350	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78349	 78350	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78353	 78357	 0.070843	 0.340436	 0.01019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78354	 78369	 0.011071	 0.021914	 0.00032	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78357	 79174	 0.040257	 0.187757	 0.00432	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78361	 78362	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78361	 78362	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78365	 79645	 0.019671	 0.019329	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78370	 78696	 0.013236	 0.023271	 0.00044	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78370	 78907	 0.0021	 0.008207	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78376	 79431	 0.001243	 0.002186	 4e-05	 44.0	 44.0	 44.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78378	 79084	 0.006857	 0.015914	 0.00024	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78380	 78556	 0.003193	 0.03125	 0.00061	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78381	 78590	 0.032271	 0.051514	 0.00119	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78382	 79124	 0.0786	 0.146171	 0.00342	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78382	 79125	 0.013729	 0.111071	 0.00286	 141.0	 148.05	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78386	 79377	 0.012529	 0.055521	 0.00166	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78391	 79205	 0.01365	 0.017764	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78392	 79344	 0.014743	 0.079164	 0.00188	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78394	 78395	 0.000707	 0.004336	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78401	 78402	 0.004964	 0.0194	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78406	 78408	 0.0051	 0.029007	 0.00052	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78406	 78518	 0.010114	 0.019821	 0.0003	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78407	 78408	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78417	 78418	 0.0041	 0.018171	 0.00041	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78420	 78424	 0.013821	 0.047214	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78421	 78424	 0.009379	 0.036614	 0.00081	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78422	 78423	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78423	 78424	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78423	 78430	 0.003936	 0.018043	 0.00462	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 79521	 0.015364	 0.077236	 0.02011	 185.0	 194.25	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78423	 79640	 0.01255	 0.047714	 0.01336	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78427	 78428	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78430	 78431	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78434	 78443	 0.065914	 0.046693	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78437	 78438	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78437	 78454	 0.003979	 0.0111	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78442	 78458	 0.03015	 0.029621	 0.0005	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78445	 78446	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78445	 78452	 0.004807	 0.019236	 0.00484	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78452	 78453	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78452	 79639	 0.00175	 0.005993	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78454	 78455	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78460	 78463	 0.0226	 0.036079	 0.00083	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78461	 78462	 0.012407	 0.032886	 0.00084	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78469	 78471	 0.006014	 0.028729	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78482	 78483	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78483	 78486	 0.010029	 0.048929	 0.00084	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78488	 78489	 0.043579	 0.030864	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78490	 78491	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78493	 79727	 0.022407	 0.041664	 0.00098	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78495	 78500	 0.013707	 0.028171	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78498	 78499	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78505	 78506	 0.008579	 0.038029	 0.00114	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78513	 78514	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78513	 78514	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78514	 78515	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78524	 78525	 0.013914	 0.054336	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78524	 78525	 0.013914	 0.054336	 0.00121	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78530	 78531	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78538	 78540	 0.043057	 0.035443	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78545	 79785	 0.033143	 0.11605	 0.00321	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78557	 79782	 0.0542	 0.328514	 0.0103	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78561	 79783	 0.110014	 0.385757	 0.0107	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78561	 79783	 0.110014	 0.385757	 0.0107	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78562	 78563	 0.019014	 0.084721	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78562	 78563	 0.019014	 0.084721	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78566	 78572	 0.016157	 0.025793	 0.00059	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78567	 78568	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78567	 78570	 0.004464	 0.011586	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78570	 78571	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78572	 78573	 0.016357	 0.033614	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78577	 78578	 0.02295	 0.031286	 0.00069	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78578	 78582	 0.0302	 0.021393	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78584	 78585	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78587	 78588	 0.01375	 0.024179	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78597	 78598	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78601	 79547	 0.186071	 0.346386	 0.00811	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78607	 78631	 0.015771	 0.064457	 0.00131	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78607	 78800	 0.02275	 0.066914	 0.00137	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78614	 78615	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78614	 78630	 0.001443	 0.005779	 0.00146	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78615	 78631	 0.010271	 0.02385	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78616	 78620	 0.013757	 0.036471	 0.00093	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78616	 78817	 0.015379	 0.020214	 0.00028	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78617	 78618	 0.00525	 0.010786	 0.00021	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78617	 78621	 0.018393	 0.013029	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78617	 78817	 0.006407	 0.016229	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78618	 78620	 0.019807	 0.015679	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78623	 78624	 0.000155	 0.012369	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78626	 78627	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78630	 78631	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78635	 78639	 0.006393	 0.012657	 0.00019	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78638	 78640	 0.01875	 0.014836	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78642	 78653	 0.010786	 0.022071	 0.00054	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78647	 78648	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78651	 78652	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78652	 78679	 0.029693	 0.060757	 0.00149	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78652	 78765	 0.0457	 0.07295	 0.00168	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78653	 78675	 0.009743	 0.019293	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78654	 78656	 0.011743	 0.021193	 0.00031	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78655	 78656	 0.003657	 0.007514	 0.00014	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78655	 78657	 0.0099	 0.017864	 0.00026	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78656	 78664	 0.087886	 0.062257	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78657	 78669	 0.004864	 0.012886	 0.00033	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78659	 78664	 0.020529	 0.042179	 0.00081	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78659	 78671	 0.024564	 0.057029	 0.00085	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78663	 78664	 0.029579	 0.02095	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78665	 78668	 0.039479	 0.027964	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78666	 78668	 0.038664	 0.027393	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78671	 78675	 0.01115	 0.025493	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78673	 78674	 0.012386	 0.014521	 0.00025	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78673	 78676	 0.017221	 0.021379	 0.00046	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78678	 78679	 0.042636	 0.0302	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78678	 78815	 0.012057	 0.01645	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78684	 78803	 0.008907	 0.014221	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78689	 78691	 0.027821	 0.019707	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78691	 78693	 0.032271	 0.022857	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78695	 78696	 0.000247	 0.018554	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78697	 78698	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78697	 78904	 0.001814	 0.009457	 0.00248	 191.0	 200.55	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78698	 78905	 0.013636	 0.039114	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78701	 78703	 0.011257	 0.016407	 0.00037	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78701	 79089	 0.022629	 0.028093	 0.00061	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78703	 78706	 0.014964	 0.0106	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78705	 78714	 0.005079	 0.009443	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78707	 78708	 0.004779	 0.007164	 0.00013	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78707	 78709	 0.013314	 0.009436	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78709	 78710	 0.006186	 0.009479	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78709	 78714	 0.013621	 0.020871	 0.00029	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78709	 79091	 0.038357	 0.030357	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78710	 78712	 0.013443	 0.015757	 0.00027	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78712	 78779	 0.007136	 0.009743	 0.00017	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78719	 78726	 0.003457	 0.007079	 0.00017	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78719	 78733	 0.006721	 0.010729	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78720	 78741	 0.006	 0.008171	 0.00018	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78721	 78722	 0.011236	 0.023093	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78730	 78907	 0.003857	 0.0153	 0.00044	 95.0	 99.75	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78731	 78735	 0.009364	 0.01	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78731	 78753	 0.004593	 0.007336	 0.00017	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78740	 79040	 0.022621	 0.020407	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78743	 79101	 0.010093	 0.013757	 0.00031	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78744	 78746	 0.004407	 0.015043	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78744	 78749	 0.007564	 0.010321	 0.00019	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78744	 78753	 0.007429	 0.02185	 0.00045	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78747	 78750	 0.003264	 0.006679	 0.00016	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78749	 78754	 0.012464	 0.021	 0.0003	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78751	 79033	 0.003986	 0.009114	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78755	 78756	 0.005079	 0.010429	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78755	 79032	 0.011221	 0.022214	 0.00033	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78756	 78758	 0.011214	 0.013143	 0.00023	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78757	 78762	 0.017007	 0.012293	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78759	 78761	 0.001621	 0.007786	 0.00024	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78763	 78923	 0.005057	 0.0104	 0.0002	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78763	 78925	 0.002729	 0.006907	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78764	 78923	 0.000971	 0.004536	 0.00011	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78769	 78772	 0.013729	 0.021914	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78771	 78772	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78771	 79096	 0.0014	 0.008957	 0.00301	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78778	 79097	 0.009729	 0.019264	 0.00029	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78784	 79097	 0.015664	 0.02755	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78786	 78789	 0.01705	 0.014036	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78787	 78797	 0.003721	 0.009571	 0.00237	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78787	 79096	 0.002286	 0.008971	 0.00235	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78788	 79099	 0.017521	 0.0157	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78791	 78792	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78792	 79100	 0.023893	 0.018914	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78794	 78795	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78797	 79143	 0.004036	 0.010671	 0.0025	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78798	 79059	 0.007936	 0.014757	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78802	 78803	 0.003279	 0.0093	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78802	 78860	 0.059129	 0.104	 0.00196	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78819	 78827	 0.030371	 0.039914	 0.00055	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78824	 78852	 0.01225	 0.054593	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78828	 78829	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78833	 78834	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78840	 78844	 0.0064	 0.014707	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78841	 78842	 0.000171	 0.012822	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78842	 78843	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78844	 78845	 0.008921	 0.023636	 0.0006	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78847	 78850	 0.004714	 0.010693	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78848	 78849	 0.007771	 0.0159	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78848	 78850	 0.0099	 0.012286	 0.00026	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78851	 79201	 0.003314	 0.010121	 0.00219	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78853	 78854	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78857	 78858	 0.005243	 0.017914	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78871	 78872	 0.008836	 0.023421	 0.00059	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78872	 78875	 0.002686	 0.009164	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78873	 78874	 0.002114	 0.01015	 0.0003	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78877	 78960	 0.019479	 0.038171	 0.00057	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78879	 78880	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78882	 78884	 0.007521	 0.017464	 0.00026	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78882	 78885	 0.0343	 0.042571	 0.00093	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78889	 79308	 0.01265	 0.025993	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78889	 79310	 0.002793	 0.013007	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78890	 78893	 0.012579	 0.029207	 0.00044	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78892	 78893	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78894	 78895	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78896	 78897	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78897	 78902	 0.016036	 0.029814	 0.0007	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78900	 78901	 7.8e-05	 0.006228	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78901	 78902	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78902	 78916	 0.00475	 0.018471	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78903	 78904	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78904	 78905	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78906	 78907	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78907	 78911	 0.006843	 0.012721	 0.0003	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78909	 78910	 0.001607	 0.007693	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	78911	 78919	 0.008607	 0.017043	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78917	 78918	 0.009107	 0.012429	 0.00022	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78921	 78922	 0.009214	 0.005964	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78924	 78927	 0.006871	 0.013607	 0.0002	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78929	 78934	 0.007521	 0.013229	 0.00025	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78931	 78932	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78932	 78962	 0.013	 0.033429	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78933	 78935	 0.014486	 0.012979	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78935	 78943	 0.006786	 0.0154	 0.00031	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78941	 78944	 0.008464	 0.015743	 0.00037	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78949	 78950	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78950	 79000	 0.009807	 0.022764	 0.00034	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78960	 78962	 0.02325	 0.0184	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78963	 78964	 0.006264	 0.018421	 0.00038	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78966	 78967	 0.010607	 0.012429	 0.00021	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	78968	 78969	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78968	 78990	 0.000571	 0.004129	 0.00222	 381.0	 400.05	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78971	 78972	 0.003143	 0.010721	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78972	 78974	 0.002657	 0.014257	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78974	 78976	 0.004793	 0.010957	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78976	 79003	 0.003886	 0.020807	 0.00063	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78978	 78980	 0.00075	 0.002871	 8e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	78979	 78980	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78980	 78981	 0.011471	 0.008121	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	78982	 78984	 0.001886	 0.012821	 0.00031	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78985	 78988	 0.008136	 0.015129	 0.00036	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78986	 78987	 0.011221	 0.011329	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78988	 79308	 0.011214	 0.02085	 0.00049	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	78990	 78991	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	78991	 78992	 0.009721	 0.014164	 0.00032	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	78993	 78995	 0.006936	 0.018379	 0.00046	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78995	 79305	 0.003829	 0.010143	 0.00026	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	78996	 79302	 0.004171	 0.018579	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78996	 79302	 0.004171	 0.018579	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	78998	 79003	 0.001564	 0.010607	 0.00026	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	78999	 79003	 0.002271	 0.011271	 0.00027	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79002	 79003	 0.004779	 0.010829	 0.00021	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79004	 79005	 0.003443	 0.014707	 0.00034	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79006	 79007	 0.003614	 0.012643	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79006	 79007	 0.003614	 0.012643	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79008	 79013	 0.002879	 0.016364	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79011	 79024	 0.0091	 0.034864	 0.00099	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79013	 79141	 0.0105	 0.021579	 0.00041	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79016	 79017	 0.002443	 0.012136	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79016	 79020	 0.005136	 0.009543	 0.00022	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79023	 79024	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79030	 79031	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79032	 79039	 0.020593	 0.033036	 0.00061	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79034	 79036	 0.004443	 0.008257	 0.00019	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79034	 79058	 0.014357	 0.0093	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79035	 79036	 0.001436	 0.003643	 7e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79037	 79047	 0.004164	 0.006071	 0.00014	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79038	 79039	 0.01405	 0.0091	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79039	 79043	 0.016621	 0.015	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79040	 79041	 0.006614	 0.009029	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79041	 79044	 0.011193	 0.01715	 0.00024	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79046	 79047	 0.011721	 0.007593	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79048	 79049	 0.0035	 0.0065	 0.00015	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79048	 79052	 0.013857	 0.020779	 0.00038	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79051	 79139	 0.00625	 0.014286	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79053	 79054	 0.004479	 0.004043	 6e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79056	 79057	 0.022829	 0.016171	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79056	 79139	 0.022386	 0.046	 0.00088	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79059	 79060	 0.004736	 0.009693	 0.00024	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79060	 79061	 0.006957	 0.009143	 0.00013	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79061	 79064	 0.00975	 0.008793	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79065	 79066	 0.010807	 0.012671	 0.00022	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79066	 79067	 0.008836	 0.007971	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79068	 79069	 0.010871	 0.010879	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79069	 79070	 0.01375	 0.011314	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79070	 79076	 0.00325	 0.012643	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79072	 79073	 0.009243	 0.014157	 0.0002	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79072	 79139	 0.00975	 0.015643	 0.00029	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79074	 79078	 0.011686	 0.017521	 0.00032	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79075	 79076	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79080	 79081	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79081	 79082	 0.007264	 0.0116	 0.00026	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79083	 79084	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79086	 79087	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79089	 79090	 0.022607	 0.0265	 0.00046	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79090	 79091	 0.020843	 0.013493	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79096	 79837	 0.037064	 0.113393	 0.02454	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79104	 79105	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79105	 79106	 0.014979	 0.030771	 0.00059	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79105	 79110	 0.009236	 0.01555	 0.00022	 37.0	 38.85	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79105	 79825	 0.038214	 0.061	 0.00141	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79106	 79107	 0.0139	 0.022193	 0.00051	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79107	 79108	 0.016936	 0.031493	 0.00074	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79109	 79825	 0.074993	 0.05935	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79115	 79116	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79116	 79125	 0.056679	 0.128586	 0.00256	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79118	 79120	 0.009971	 0.025264	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79120	 79137	 0.022407	 0.087164	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79127	 79128	 8.9e-05	 0.007142	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79129	 79130	 0.002136	 0.009471	 0.00029	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79130	 79131	 0.011071	 0.032564	 0.00066	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79135	 79136	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79138	 79139	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79138	 79143	 0.002179	 0.008993	 0.00213	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79142	 79143	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79143	 79144	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79154	 79156	 0.005814	 0.035186	 0.0011	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79157	 79158	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79157	 79501	 0.002514	 0.034093	 0.01971	 567.0	 595.35	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79157	 79747	 0.006029	 0.095443	 0.02868	 399.0	 418.95	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79158	 79159	 0.005564	 0.033336	 0.0008	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79167	 79168	 0.013464	 0.072321	 0.00171	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 79191	 0.004371	 0.033071	 0.0011	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 79194	 0.028679	 0.100429	 0.00278	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79190	 79194	 0.028679	 0.100429	 0.00278	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79193	 79194	 0.018879	 0.0661	 0.00183	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79193	 79194	 0.018879	 0.0661	 0.00183	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79193	 79724	 0.004793	 0.037329	 0.0007	 125.0	 131.25	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79196	 79861	 0.04185	 0.195186	 0.00449	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79200	 79207	 0.016429	 0.06415	 0.00142	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79201	 79202	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79201	 79206	 0.007343	 0.0177	 0.005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79204	 79205	 0.010379	 0.016564	 0.00038	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79206	 79207	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79214	 79215	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79215	 79483	 0.042221	 0.272607	 0.00869	 131.0	 137.55	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79217	 79218	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79219	 79220	 0.011393	 0.025836	 0.00051	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79221	 79222	 0.006171	 0.024114	 0.00054	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79228	 79231	 0.018343	 0.042586	 0.00064	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79235	 79236	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79236	 79238	 0.00985	 0.018314	 0.00043	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79242	 79243	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79242	 79254	 0.002364	 0.0161	 0.00549	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79244	 79248	 0.031457	 0.031779	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79244	 79249	 0.024793	 0.019621	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79245	 79247	 0.013993	 0.024614	 0.00046	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79254	 79255	 8e-05	 0.00641	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79257	 79258	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79258	 79259	 0.004507	 0.01325	 0.00027	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79261	 79265	 0.008557	 0.019407	 0.00039	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79267	 79268	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79268	 79292	 0.010314	 0.026129	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79269	 79271	 0.016464	 0.016171	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79273	 79274	 0.025007	 0.017714	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79275	 79276	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79280	 79281	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79282	 79283	 0.005507	 0.009693	 0.00018	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79285	 79286	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79286	 79292	 0.006993	 0.020557	 0.00042	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79287	 79288	 0.000114	 0.009083	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79288	 79289	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79294	 79295	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79295	 79297	 0.008914	 0.016579	 0.00039	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79300	 79301	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79300	 79301	 0.000124	 0.009908	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79301	 79302	 9.5e-05	 0.007575	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79303	 79306	 0.00225	 0.013829	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79304	 79305	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79307	 79310	 0.01965	 0.036536	 0.00086	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79308	 79309	 0.005379	 0.015807	 0.00032	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79311	 79318	 0.021993	 0.0409	 0.00096	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79316	 79317	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79317	 79778	 0.023514	 0.091829	 0.00204	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79344	 79345	 0.037886	 0.098186	 0.00186	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79359	 79360	 0.002421	 0.015414	 0.00038	 119.0	 124.95	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79362	 79363	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79370	 79371	 0.033779	 0.150529	 0.00256	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79370	 79371	 0.033779	 0.150529	 0.00256	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79372	 79376	 0.022357	 0.104257	 0.0024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	79373	 79374	 0.0164	 0.050321	 0.00136	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79381	 79393	 0.014564	 0.056879	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79381	 79393	 0.014564	 0.056879	 0.00126	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79383	 79384	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79385	 79387	 0.007193	 0.025193	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79385	 79387	 0.007193	 0.025193	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79386	 79387	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79389	 79396	 0.013414	 0.027571	 0.00053	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79392	 79393	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79394	 79395	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79394	 79421	 0.001329	 0.017314	 0.00501	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79394	 79421	 0.001329	 0.017314	 0.00501	 347.0	 364.35	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79403	 79404	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79403	 79404	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79405	 79409	 0.015886	 0.040843	 0.00063	 59.0	 61.95	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79408	 79424	 0.033193	 0.035443	 0.00075	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79413	 79414	 0.16565	 0.107264	 0.00204	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79421	 79422	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79426	 79428	 0.013521	 0.0107	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79436	 79468	 0.092729	 0.073393	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79437	 79441	 0.014236	 0.048636	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79440	 79441	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79442	 79443	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79442	 79444	 0.001264	 0.003343	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79442	 79445	 0.001421	 0.0057	 0.00144	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79442	 79447	 0.001914	 0.0079	 0.00187	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79445	 79446	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79448	 79449	 0.024936	 0.016143	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79450	 79451	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79453	 79457	 0.025271	 0.051936	 0.00099	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79454	 79457	 0.022179	 0.085336	 0.00146	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79463	 79464	 7.2e-05	 0.005736	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79464	 79465	 0.000108	 0.00862	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79477	 79478	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79482	 79483	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79482	 79484	 0.005579	 0.043421	 0.01128	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79484	 79485	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79497	 79498	 9.7e-05	 0.007785	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79498	 79499	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79501	 79502	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79501	 79517	 0.000557	 0.005264	 0.00159	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79514	 79515	 0.028271	 0.055979	 0.00082	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79517	 79518	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79520	 79521	 0.000109	 0.008719	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79521	 79522	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79524	 79525	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79538	 79539	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79539	 79541	 0.00255	 0.0113	 0.00034	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79549	 79550	 0.008007	 0.024564	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79551	 79552	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79554	 79556	 0.008279	 0.062614	 0.00209	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79562	 79563	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79568	 79569	 0.00345	 0.011779	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79571	 79572	 0.006157	 0.009429	 0.00014	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79575	 79576	 0.012879	 0.029443	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79577	 79578	 0.012707	 0.012836	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79579	 79581	 0.012157	 0.007871	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79580	 79581	 0.00395	 0.00575	 0.00013	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79583	 79584	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79584	 79596	 0.018064	 0.080057	 0.00241	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79589	 79590	 0.036536	 0.032964	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79591	 79595	 0.071636	 0.046379	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79594	 79595	 0.001336	 0.005914	 0.00018	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79600	 79601	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79604	 79606	 0.01065	 0.04795	 0.01276	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79606	 79607	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79607	 79803	 0.091129	 0.169493	 0.00397	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79609	 79610	 0.036307	 0.1114	 0.00301	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79612	 79615	 0.046664	 0.033057	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79618	 79619	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79619	 79625	 0.209571	 0.1659	 0.00209	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79622	 79623	 0.01365	 0.028043	 0.00054	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79623	 79625	 0.209443	 0.390021	 0.00914	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79629	 79686	 0.081243	 0.073307	 0.00123	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79635	 79636	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79640	 79652	 0.011029	 0.033714	 0.00729	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79641	 79673	 0.044957	 0.040564	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79644	 79647	 0.001271	 0.004829	 0.00135	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79646	 79647	 0.000101	 0.008073	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79647	 79648	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79647	 79652	 0.0016	 0.00735	 0.00189	 175.0	 183.75	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79652	 79653	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79653	 79666	 0.027171	 0.026693	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79660	 79663	 0.003171	 0.012371	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79661	 79666	 0.011343	 0.032529	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79662	 79664	 0.01255	 0.011243	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79665	 79666	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79667	 79668	 0.018257	 0.020079	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79668	 79678	 0.03415	 0.03355	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79670	 79672	 0.00405	 0.006457	 0.00015	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79671	 79673	 0.007407	 0.011243	 0.00016	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79672	 79674	 0.014064	 0.009964	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79673	 79675	 0.028421	 0.0184	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79678	 79680	 0.034871	 0.022579	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79681	 79682	 0.0106	 0.018636	 0.00035	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79685	 79689	 0.046407	 0.030043	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79688	 79689	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79696	 79697	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79699	 79704	 0.037757	 0.066407	 0.00125	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79707	 79708	 0.000207	 0.002429	 0.00124	 501.0	 526.05	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79708	 79709	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79709	 79714	 0.005243	 0.02805	 0.00085	 115.0	 120.75	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79712	 79713	 0.00011	 0.008789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79714	 79715	 0.009364	 0.031993	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79724	 79725	 0.007121	 0.016364	 0.00025	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79729	 79730	 0.008921	 0.026236	 0.00054	 71.0	 74.55	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79732	 79734	 0.042793	 0.068307	 0.00157	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79735	 79738	 0.010457	 0.040064	 0.00114	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79743	 79748	 0.019193	 0.08205	 0.00186	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79746	 79748	 0.029864	 0.116657	 0.00259	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79746	 79748	 0.029864	 0.116657	 0.00259	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79747	 79748	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79752	 79753	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79753	 79759	 0.0117	 0.040964	 0.00114	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	79756	 79757	 0.000161	 0.01211	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79757	 79758	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79776	 79858	 0.012429	 0.048343	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79787	 79788	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79787	 79794	 0.013264	 0.044693	 0.01111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	79792	 79797	 0.071643	 0.133229	 0.00312	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79794	 79795	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79796	 79797	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79797	 79798	 0.296321	 0.210043	 0.00332	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79799	 79816	 0.033886	 0.051907	 0.00073	 35.0	 36.75	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	79805	 79806	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79806	 79807	 0.019643	 0.031357	 0.00072	 41.0	 43.05	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	79808	 79809	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79811	 79817	 0.050664	 0.040093	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79815	 79816	 0.028157	 0.025229	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79815	 79824	 0.045729	 0.085036	 0.00199	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79819	 79820	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79819	 79828	 0.0052	 0.021479	 0.00508	 159.0	 166.95	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79821	 79822	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79822	 79823	 0.035214	 0.027864	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79825	 79831	 0.02515	 0.040343	 0.00074	 39.0	 40.95	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	79827	 79828	 0.000118	 0.009477	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79828	 79829	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79832	 79834	 0.054871	 0.035529	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79835	 79838	 0.014964	 0.03075	 0.00059	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79837	 79838	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79838	 79841	 0.029186	 0.059979	 0.00114	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79842	 79843	 0.042186	 0.029879	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	79846	 79853	 0.047814	 0.102471	 0.00179	 57.0	 59.85	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	79847	 79848	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79849	 79850	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79850	 79855	 0.127014	 0.148914	 0.00259	 33.0	 34.65	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79852	 79853	 0.017693	 0.0878	 0.00209	 103.0	 108.15	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	79858	 79860	 0.008793	 0.066471	 0.00221	 147.0	 154.35	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Setting Flat Start
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Branch 75985-60048 connects two different voltage levels (230.0, 138.0), changing tap ratio 0.0 => 1.0
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : Updated Thermal Rating: on line 59592-59611 : Rate C - 381.7 -> 390.35
% INFO    : Updated Thermal Rating: on line 59611-59612 : Rate B - 364.35 -> 370.0
% INFO    : Updated Thermal Rating: on line 59611-59612 : Rate B - 364.35 -> 370.0
% INFO    : Updated Thermal Rating: on line 62189-62219 : Rate B - 194.25 -> 200.0
% INFO    : Updated Thermal Rating: on line 62219-62220 : Rate B, Rate C - 183.75, 192.5 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 62221-62223 : Rate C - 174.9 -> 175.95
% INFO    : Updated Thermal Rating: on line 62221-62223 : Rate C - 174.9 -> 175.95
% INFO    : Updated Thermal Rating: on line 62223-62339 : Rate B - 166.95 -> 170.0
% INFO    : Updated Thermal Rating: on line 62223-62339 : Rate B - 166.95 -> 170.0
% INFO    : Updated Thermal Rating: on line 62435-62436 : Rate C - 174.9 -> 180.95
% INFO    : Updated Thermal Rating: on line 62457-77076 : Rate B, Rate C - 193.75, 192.5 -> 195.0, 195.0
% INFO    : Updated Thermal Rating: on line 62478-62479 : Rate C - 174.9 -> 200.95
% INFO    : Updated Thermal Rating: on line 62478-62480 : Rate C - 210.1 -> 250.55
% INFO    : Updated Thermal Rating: on line 62480-62481 : Rate B, Rate C - 250.25, 250.5 -> 270.0, 270.0
% INFO    : Updated Thermal Rating: on line 76721-62481 : Rate B, Rate C - 280.5, 270.0 -> 290.0, 290.0
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 58575	: V=1.0277406, theta=12.672159 -> V=1.0, theta=0.0
% INFO    : Bus 58576	: V=1.0310271, theta=13.20879 -> V=1.0, theta=0.0
% INFO    : Bus 58577	: V=1.0158498, theta=17.231556 -> V=1.0, theta=0.0
% INFO    : Bus 58578	: V=1.0381017, theta=16.086458 -> V=1.0, theta=0.0
% INFO    : Bus 58579	: V=1.0377125, theta=15.831312 -> V=1.0, theta=0.0
% INFO    : Bus 58580	: V=1.0349745, theta=21.368874 -> V=1.0, theta=0.0
% INFO    : Bus 58581	: V=1.0188172, theta=17.067972 -> V=1.0, theta=0.0
% INFO    : Bus 58582	: V=1.0262671, theta=14.4143 -> V=1.0, theta=0.0
% INFO    : Bus 58583	: V=1.0100006, theta=18.434469 -> V=1.0, theta=0.0
% INFO    : Bus 58584	: V=1.0300006, theta=17.935634 -> V=1.0, theta=0.0
% INFO    : Bus 58585	: V=1.0100005, theta=12.429121 -> V=1.0, theta=0.0
% INFO    : Bus 58586	: V=1.0300005, theta=17.937442 -> V=1.0, theta=0.0
% INFO    : Bus 58587	: V=1.0100006, theta=7.057651 -> V=1.0, theta=0.0
% INFO    : Bus 58588	: V=1.0300006, theta=12.503478 -> V=1.0, theta=0.0
% INFO    : Bus 58589	: V=1.0100006, theta=15.386205 -> V=1.0, theta=0.0
% INFO    : Bus 58590	: V=1.0159626, theta=13.553383 -> V=1.0, theta=0.0
% INFO    : Bus 58591	: V=1.0300006, theta=12.252993 -> V=1.0, theta=0.0
% INFO    : Bus 58592	: V=1.0238478, theta=16.588607 -> V=1.0, theta=0.0
% INFO    : Bus 58593	: V=1.038953, theta=13.323302 -> V=1.0, theta=0.0
% INFO    : Bus 58594	: V=1.0190513, theta=11.876504 -> V=1.0, theta=0.0
% INFO    : Bus 58595	: V=1.0004904, theta=12.902577 -> V=1.0, theta=0.0
% INFO    : Bus 58596	: V=1.0389645, theta=13.662886 -> V=1.0, theta=0.0
% INFO    : Bus 58597	: V=1.0262533, theta=14.415563 -> V=1.0, theta=0.0
% INFO    : Bus 58598	: V=1.0289565, theta=20.770883 -> V=1.0, theta=0.0
% INFO    : Bus 58599	: V=1.0171331, theta=11.809703 -> V=1.0, theta=0.0
% INFO    : Bus 58600	: V=1.0505935, theta=13.694834 -> V=1.0, theta=0.0
% INFO    : Bus 58601	: V=1.0300007, theta=16.772142 -> V=1.0, theta=0.0
% INFO    : Bus 58602	: V=1.0300007, theta=8.139028 -> V=1.0, theta=0.0
% INFO    : Bus 58603	: V=1.0300006, theta=25.843387 -> V=1.0, theta=0.0
% INFO    : Bus 58604	: V=1.0129253, theta=0.525079 -> V=1.0, theta=0.0
% INFO    : Bus 58605	: V=1.0200006, theta=24.615628 -> V=1.0, theta=0.0
% INFO    : Bus 58606	: V=1.0200006, theta=24.892839 -> V=1.0, theta=0.0
% INFO    : Bus 58607	: V=1.0200006, theta=23.871976 -> V=1.0, theta=0.0
% INFO    : Bus 58608	: V=1.0200027, theta=23.87126 -> V=1.0, theta=0.0
% INFO    : Bus 58609	: V=1.0300005, theta=-59.812225 -> V=1.0, theta=0.0
% INFO    : Bus 58610	: V=1.0300007, theta=18.475977 -> V=1.0, theta=0.0
% INFO    : Bus 58611	: V=1.0200006, theta=12.766903 -> V=1.0, theta=0.0
% INFO    : Bus 58612	: V=1.0300006, theta=20.574368 -> V=1.0, theta=0.0
% INFO    : Bus 58613	: V=1.0213666, theta=21.748718 -> V=1.0, theta=0.0
% INFO    : Bus 58614	: V=1.0100006, theta=-7.402741 -> V=1.0, theta=0.0
% INFO    : Bus 58615	: V=1.0300006, theta=18.607822 -> V=1.0, theta=0.0
% INFO    : Bus 58616	: V=1.0100007, theta=21.47687 -> V=1.0, theta=0.0
% INFO    : Bus 58617	: V=1.0300006, theta=14.417195 -> V=1.0, theta=0.0
% INFO    : Bus 58618	: V=1.0300006, theta=19.157333 -> V=1.0, theta=0.0
% INFO    : Bus 58619	: V=1.0100006, theta=21.151603 -> V=1.0, theta=0.0
% INFO    : Bus 58620	: V=1.0100007, theta=21.77688 -> V=1.0, theta=0.0
% INFO    : Bus 58621	: V=1.0100007, theta=18.086775 -> V=1.0, theta=0.0
% INFO    : Bus 58622	: V=1.0107879, theta=21.150272 -> V=1.0, theta=0.0
% INFO    : Bus 58623	: V=1.0200006, theta=19.852176 -> V=1.0, theta=0.0
% INFO    : Bus 58624	: V=1.0200006, theta=19.856654 -> V=1.0, theta=0.0
% INFO    : Bus 58625	: V=1.0100006, theta=23.882158 -> V=1.0, theta=0.0
% INFO    : Bus 58626	: V=1.0300006, theta=22.540731 -> V=1.0, theta=0.0
% INFO    : Bus 58627	: V=1.0300007, theta=0.083006 -> V=1.0, theta=0.0
% INFO    : Bus 58628	: V=1.0144272, theta=-19.028979 -> V=1.0, theta=0.0
% INFO    : Bus 58629	: V=1.0158964, theta=-16.823193 -> V=1.0, theta=0.0
% INFO    : Bus 58630	: V=1.0021169, theta=-34.141227 -> V=1.0, theta=0.0
% INFO    : Bus 58631	: V=1.0300006, theta=-6.617244 -> V=1.0, theta=0.0
% INFO    : Bus 58632	: V=1.0100005, theta=-59.247036 -> V=1.0, theta=0.0
% INFO    : Bus 58633	: V=1.0300006, theta=12.866794 -> V=1.0, theta=0.0
% INFO    : Bus 58634	: V=0.9853883, theta=-8.463578 -> V=1.0, theta=0.0
% INFO    : Bus 58635	: V=1.0154609, theta=-40.986286 -> V=1.0, theta=0.0
% INFO    : Bus 58636	: V=1.0100006, theta=21.557414 -> V=1.0, theta=0.0
% INFO    : Bus 58637	: V=1.006697, theta=-57.604911 -> V=1.0, theta=0.0
% INFO    : Bus 58638	: V=1.0147217, theta=-14.673488 -> V=1.0, theta=0.0
% INFO    : Bus 58639	: V=1.0163323, theta=-20.012783 -> V=1.0, theta=0.0
% INFO    : Bus 58640	: V=1.0148261, theta=-39.001039 -> V=1.0, theta=0.0
% INFO    : Bus 58641	: V=0.9759808, theta=-18.785003 -> V=1.0, theta=0.0
% INFO    : Bus 58642	: V=1.0099043, theta=-2.695664 -> V=1.0, theta=0.0
% INFO    : Bus 58643	: V=1.0146419, theta=-5.148942 -> V=1.0, theta=0.0
% INFO    : Bus 58644	: V=1.0125722, theta=-5.01079 -> V=1.0, theta=0.0
% INFO    : Bus 58645	: V=1.0091401, theta=-54.490337 -> V=1.0, theta=0.0
% INFO    : Bus 58646	: V=1.0000006, theta=-28.401353 -> V=1.0, theta=0.0
% INFO    : Bus 58647	: V=1.0200005, theta=-59.846515 -> V=1.0, theta=0.0
% INFO    : Bus 58648	: V=1.0204154, theta=-17.808017 -> V=1.0, theta=0.0
% INFO    : Bus 58649	: V=1.0143701, theta=-39.034081 -> V=1.0, theta=0.0
% INFO    : Bus 58650	: V=1.0000007, theta=-1.556107 -> V=1.0, theta=0.0
% INFO    : Bus 58651	: V=1.0060237, theta=21.746443 -> V=1.0, theta=0.0
% INFO    : Bus 58652	: V=1.0033266, theta=19.886865 -> V=1.0, theta=0.0
% INFO    : Bus 58653	: V=1.0223114, theta=-53.775587 -> V=1.0, theta=0.0
% INFO    : Bus 58654	: V=1.020021, theta=19.896969 -> V=1.0, theta=0.0
% INFO    : Bus 58655	: V=1.0111721, theta=3.737695 -> V=1.0, theta=0.0
% INFO    : Bus 58656	: V=1.011105, theta=-2.366868 -> V=1.0, theta=0.0
% INFO    : Bus 58657	: V=1.0037905, theta=-10.847493 -> V=1.0, theta=0.0
% INFO    : Bus 58658	: V=1.0000006, theta=-15.083069 -> V=1.0, theta=0.0
% INFO    : Bus 58659	: V=1.0300007, theta=46.805376 -> V=1.0, theta=0.0
% INFO    : Bus 58660	: V=1.0200006, theta=25.46015 -> V=1.0, theta=0.0
% INFO    : Bus 58661	: V=1.0300007, theta=4.858451 -> V=1.0, theta=0.0
% INFO    : Bus 58662	: V=1.024161, theta=19.554016 -> V=1.0, theta=0.0
% INFO    : Bus 58663	: V=1.0100146, theta=-0.367222 -> V=1.0, theta=0.0
% INFO    : Bus 58664	: V=1.0200007, theta=3.598712 -> V=1.0, theta=0.0
% INFO    : Bus 58665	: V=1.0200007, theta=19.96007 -> V=1.0, theta=0.0
% INFO    : Bus 58666	: V=1.0100007, theta=20.892769 -> V=1.0, theta=0.0
% INFO    : Bus 58667	: V=1.0201096, theta=0.49842 -> V=1.0, theta=0.0
% INFO    : Bus 58668	: V=1.0107221, theta=1.427677 -> V=1.0, theta=0.0
% INFO    : Bus 58669	: V=1.0300006, theta=22.48943 -> V=1.0, theta=0.0
% INFO    : Bus 58670	: V=1.0300007, theta=-1.962174 -> V=1.0, theta=0.0
% INFO    : Bus 58671	: V=1.0300007, theta=15.857444 -> V=1.0, theta=0.0
% INFO    : Bus 58672	: V=1.0200006, theta=22.80712 -> V=1.0, theta=0.0
% INFO    : Bus 58673	: V=1.0190701, theta=2.642531 -> V=1.0, theta=0.0
% INFO    : Bus 58674	: V=1.0200006, theta=21.084292 -> V=1.0, theta=0.0
% INFO    : Bus 58675	: V=1.0200007, theta=17.210068 -> V=1.0, theta=0.0
% INFO    : Bus 58676	: V=1.0200006, theta=23.638357 -> V=1.0, theta=0.0
% INFO    : Bus 58677	: V=1.0300006, theta=24.409012 -> V=1.0, theta=0.0
% INFO    : Bus 58678	: V=1.0200006, theta=22.060018 -> V=1.0, theta=0.0
% INFO    : Bus 58679	: V=1.0300007, theta=13.71075 -> V=1.0, theta=0.0
% INFO    : Bus 58680	: V=1.0300007, theta=12.758592 -> V=1.0, theta=0.0
% INFO    : Bus 58681	: V=1.0155277, theta=15.056773 -> V=1.0, theta=0.0
% INFO    : Bus 58682	: V=1.0123766, theta=20.572001 -> V=1.0, theta=0.0
% INFO    : Bus 58683	: V=1.0170132, theta=19.890832 -> V=1.0, theta=0.0
% INFO    : Bus 58684	: V=1.0300006, theta=22.653841 -> V=1.0, theta=0.0
% INFO    : Bus 58685	: V=1.0141232, theta=3.967696 -> V=1.0, theta=0.0
% INFO    : Bus 58686	: V=1.0300007, theta=21.49208 -> V=1.0, theta=0.0
% INFO    : Bus 58687	: V=1.0200006, theta=22.652435 -> V=1.0, theta=0.0
% INFO    : Bus 58688	: V=1.0300007, theta=12.315746 -> V=1.0, theta=0.0
% INFO    : Bus 58689	: V=1.0100007, theta=19.378445 -> V=1.0, theta=0.0
% INFO    : Bus 58690	: V=1.0100007, theta=-0.765523 -> V=1.0, theta=0.0
% INFO    : Bus 58691	: V=1.0300007, theta=23.92038 -> V=1.0, theta=0.0
% INFO    : Bus 58692	: V=1.0100007, theta=4.277044 -> V=1.0, theta=0.0
% INFO    : Bus 58693	: V=1.0100007, theta=3.71912 -> V=1.0, theta=0.0
% INFO    : Bus 58694	: V=1.0111797, theta=5.103542 -> V=1.0, theta=0.0
% INFO    : Bus 58695	: V=1.0087328, theta=2.271949 -> V=1.0, theta=0.0
% INFO    : Bus 58696	: V=1.031045, theta=22.74709 -> V=1.0, theta=0.0
% INFO    : Bus 58697	: V=1.0202148, theta=20.919315 -> V=1.0, theta=0.0
% INFO    : Bus 58698	: V=1.0200006, theta=26.913757 -> V=1.0, theta=0.0
% INFO    : Bus 58699	: V=1.0144972, theta=1.079975 -> V=1.0, theta=0.0
% INFO    : Bus 58700	: V=1.0080836, theta=-0.201185 -> V=1.0, theta=0.0
% INFO    : Bus 58701	: V=1.0148488, theta=1.366976 -> V=1.0, theta=0.0
% INFO    : Bus 58702	: V=1.0100007, theta=0.593791 -> V=1.0, theta=0.0
% INFO    : Bus 58703	: V=1.0138086, theta=3.642124 -> V=1.0, theta=0.0
% INFO    : Bus 58704	: V=1.0114086, theta=22.438243 -> V=1.0, theta=0.0
% INFO    : Bus 58705	: V=1.0283999, theta=20.594101 -> V=1.0, theta=0.0
% INFO    : Bus 58706	: V=1.0193732, theta=3.23402 -> V=1.0, theta=0.0
% INFO    : Bus 58707	: V=1.0128197, theta=30.082099 -> V=1.0, theta=0.0
% INFO    : Bus 58708	: V=1.0062477, theta=21.481561 -> V=1.0, theta=0.0
% INFO    : Bus 58709	: V=1.0100007, theta=0.621584 -> V=1.0, theta=0.0
% INFO    : Bus 58710	: V=1.0100007, theta=19.835631 -> V=1.0, theta=0.0
% INFO    : Bus 58711	: V=0.9987102, theta=-3.061753 -> V=1.0, theta=0.0
% INFO    : Bus 58712	: V=1.0128809, theta=1.959217 -> V=1.0, theta=0.0
% INFO    : Bus 58713	: V=1.0100007, theta=3.693084 -> V=1.0, theta=0.0
% INFO    : Bus 58714	: V=1.0233962, theta=10.353109 -> V=1.0, theta=0.0
% INFO    : Bus 58715	: V=1.0100007, theta=1.985448 -> V=1.0, theta=0.0
% INFO    : Bus 58716	: V=1.0100007, theta=2.543114 -> V=1.0, theta=0.0
% INFO    : Bus 58717	: V=1.0151184, theta=27.29244 -> V=1.0, theta=0.0
% INFO    : Bus 58718	: V=1.0188724, theta=5.739293 -> V=1.0, theta=0.0
% INFO    : Bus 58719	: V=1.0129122, theta=20.375791 -> V=1.0, theta=0.0
% INFO    : Bus 58720	: V=1.0118748, theta=2.298647 -> V=1.0, theta=0.0
% INFO    : Bus 58721	: V=1.003722, theta=1.997377 -> V=1.0, theta=0.0
% INFO    : Bus 58722	: V=1.0071495, theta=-1.135228 -> V=1.0, theta=0.0
% INFO    : Bus 58723	: V=1.0141025, theta=2.048363 -> V=1.0, theta=0.0
% INFO    : Bus 58724	: V=1.0117206, theta=32.248184 -> V=1.0, theta=0.0
% INFO    : Bus 58725	: V=1.0144728, theta=22.087939 -> V=1.0, theta=0.0
% INFO    : Bus 58726	: V=1.0000006, theta=19.448546 -> V=1.0, theta=0.0
% INFO    : Bus 58727	: V=1.0045272, theta=0.599679 -> V=1.0, theta=0.0
% INFO    : Bus 58728	: V=1.0000006, theta=17.944689 -> V=1.0, theta=0.0
% INFO    : Bus 58729	: V=1.0200007, theta=4.861874 -> V=1.0, theta=0.0
% INFO    : Bus 58730	: V=1.0159033, theta=5.306886 -> V=1.0, theta=0.0
% INFO    : Bus 58731	: V=1.009369, theta=-0.357316 -> V=1.0, theta=0.0
% INFO    : Bus 58732	: V=1.0100006, theta=22.350408 -> V=1.0, theta=0.0
% INFO    : Bus 58733	: V=1.0200007, theta=16.242879 -> V=1.0, theta=0.0
% INFO    : Bus 58734	: V=1.017801, theta=1.314634 -> V=1.0, theta=0.0
% INFO    : Bus 58735	: V=1.0300004, theta=30.741612 -> V=1.0, theta=0.0
% INFO    : Bus 58736	: V=1.0300004, theta=35.601846 -> V=1.0, theta=0.0
% INFO    : Bus 58737	: V=1.0300005, theta=25.062353 -> V=1.0, theta=0.0
% INFO    : Bus 58738	: V=1.0200004, theta=31.442446 -> V=1.0, theta=0.0
% INFO    : Bus 58739	: V=1.030213, theta=19.797093 -> V=1.0, theta=0.0
% INFO    : Bus 58740	: V=1.0300004, theta=30.918054 -> V=1.0, theta=0.0
% INFO    : Bus 58741	: V=1.0171238, theta=26.850652 -> V=1.0, theta=0.0
% INFO    : Bus 58742	: V=1.0100004, theta=30.132839 -> V=1.0, theta=0.0
% INFO    : Bus 58743	: V=1.0100004, theta=32.85226 -> V=1.0, theta=0.0
% INFO    : Bus 58744	: V=1.0300003, theta=22.349269 -> V=1.0, theta=0.0
% INFO    : Bus 58745	: V=1.0100004, theta=30.085775 -> V=1.0, theta=0.0
% INFO    : Bus 58746	: V=1.0171208, theta=26.850113 -> V=1.0, theta=0.0
% INFO    : Bus 58747	: V=1.0171334, theta=26.918414 -> V=1.0, theta=0.0
% INFO    : Bus 58748	: V=1.0200005, theta=27.687246 -> V=1.0, theta=0.0
% INFO    : Bus 58749	: V=1.0215074, theta=20.72236 -> V=1.0, theta=0.0
% INFO    : Bus 58750	: V=1.0210042, theta=20.894171 -> V=1.0, theta=0.0
% INFO    : Bus 58751	: V=1.0100672, theta=28.132906 -> V=1.0, theta=0.0
% INFO    : Bus 58752	: V=1.0114966, theta=26.104988 -> V=1.0, theta=0.0
% INFO    : Bus 58753	: V=1.0100004, theta=23.401596 -> V=1.0, theta=0.0
% INFO    : Bus 58754	: V=1.0100004, theta=27.381388 -> V=1.0, theta=0.0
% INFO    : Bus 58755	: V=1.0088586, theta=23.556144 -> V=1.0, theta=0.0
% INFO    : Bus 58756	: V=1.0100004, theta=32.343951 -> V=1.0, theta=0.0
% INFO    : Bus 58757	: V=1.0109041, theta=27.826064 -> V=1.0, theta=0.0
% INFO    : Bus 58758	: V=1.0300004, theta=32.308593 -> V=1.0, theta=0.0
% INFO    : Bus 58759	: V=1.0100004, theta=28.308969 -> V=1.0, theta=0.0
% INFO    : Bus 58760	: V=1.0300004, theta=22.856481 -> V=1.0, theta=0.0
% INFO    : Bus 58761	: V=1.0200004, theta=27.592372 -> V=1.0, theta=0.0
% INFO    : Bus 58762	: V=1.0100004, theta=24.421697 -> V=1.0, theta=0.0
% INFO    : Bus 58763	: V=1.0258978, theta=22.675298 -> V=1.0, theta=0.0
% INFO    : Bus 58764	: V=1.0143847, theta=25.438692 -> V=1.0, theta=0.0
% INFO    : Bus 58765	: V=1.0027162, theta=24.605595 -> V=1.0, theta=0.0
% INFO    : Bus 58766	: V=1.0100004, theta=27.039637 -> V=1.0, theta=0.0
% INFO    : Bus 58767	: V=1.0000005, theta=27.660122 -> V=1.0, theta=0.0
% INFO    : Bus 58768	: V=1.0095396, theta=27.448723 -> V=1.0, theta=0.0
% INFO    : Bus 58769	: V=1.0118976, theta=27.151778 -> V=1.0, theta=0.0
% INFO    : Bus 58770	: V=1.0107872, theta=27.812267 -> V=1.0, theta=0.0
% INFO    : Bus 58771	: V=0.99845, theta=27.562528 -> V=1.0, theta=0.0
% INFO    : Bus 58772	: V=1.0100004, theta=29.750542 -> V=1.0, theta=0.0
% INFO    : Bus 58773	: V=1.0174304, theta=19.918616 -> V=1.0, theta=0.0
% INFO    : Bus 58774	: V=1.0300006, theta=1.821742 -> V=1.0, theta=0.0
% INFO    : Bus 58775	: V=1.0100005, theta=5.944121 -> V=1.0, theta=0.0
% INFO    : Bus 58776	: V=1.0200006, theta=11.363879 -> V=1.0, theta=0.0
% INFO    : Bus 58777	: V=1.0300006, theta=19.389093 -> V=1.0, theta=0.0
% INFO    : Bus 58778	: V=1.0121546, theta=19.621544 -> V=1.0, theta=0.0
% INFO    : Bus 58779	: V=1.0100005, theta=6.24213 -> V=1.0, theta=0.0
% INFO    : Bus 58780	: V=1.0100005, theta=-3.819804 -> V=1.0, theta=0.0
% INFO    : Bus 58781	: V=1.0100006, theta=20.25485 -> V=1.0, theta=0.0
% INFO    : Bus 58782	: V=1.0000005, theta=-7.171074 -> V=1.0, theta=0.0
% INFO    : Bus 58783	: V=1.0200006, theta=2.006622 -> V=1.0, theta=0.0
% INFO    : Bus 58784	: V=0.9991615, theta=-8.426408 -> V=1.0, theta=0.0
% INFO    : Bus 58785	: V=1.0300005, theta=8.09011 -> V=1.0, theta=0.0
% INFO    : Bus 58786	: V=1.0000006, theta=22.707054 -> V=1.0, theta=0.0
% INFO    : Bus 58787	: V=1.0000006, theta=24.51142 -> V=1.0, theta=0.0
% INFO    : Bus 58788	: V=1.0200004, theta=7.081533 -> V=1.0, theta=0.0
% INFO    : Bus 58789	: V=1.0300005, theta=-0.071725 -> V=1.0, theta=0.0
% INFO    : Bus 58790	: V=1.0100004, theta=4.819461 -> V=1.0, theta=0.0
% INFO    : Bus 58791	: V=1.0300005, theta=-0.626046 -> V=1.0, theta=0.0
% INFO    : Bus 58792	: V=1.0100006, theta=0.835446 -> V=1.0, theta=0.0
% INFO    : Bus 58793	: V=1.0000006, theta=0.3655 -> V=1.0, theta=0.0
% INFO    : Bus 58794	: V=1.0100005, theta=-3.300224 -> V=1.0, theta=0.0
% INFO    : Bus 58795	: V=1.0059189, theta=3.694656 -> V=1.0, theta=0.0
% INFO    : Bus 58796	: V=1.0035137, theta=-2.781901 -> V=1.0, theta=0.0
% INFO    : Bus 58797	: V=1.0113094, theta=0.936124 -> V=1.0, theta=0.0
% INFO    : Bus 58798	: V=1.0105516, theta=0.743904 -> V=1.0, theta=0.0
% INFO    : Bus 58799	: V=1.010012, theta=-3.666429 -> V=1.0, theta=0.0
% INFO    : Bus 58800	: V=1.0088988, theta=-4.029556 -> V=1.0, theta=0.0
% INFO    : Bus 58801	: V=1.0207271, theta=19.395977 -> V=1.0, theta=0.0
% INFO    : Bus 58802	: V=1.015358, theta=1.074694 -> V=1.0, theta=0.0
% INFO    : Bus 58803	: V=1.0047221, theta=-0.302211 -> V=1.0, theta=0.0
% INFO    : Bus 58804	: V=0.9959988, theta=-1.275601 -> V=1.0, theta=0.0
% INFO    : Bus 58805	: V=0.9984828, theta=-1.123494 -> V=1.0, theta=0.0
% INFO    : Bus 58806	: V=1.0044336, theta=-0.528376 -> V=1.0, theta=0.0
% INFO    : Bus 58807	: V=1.0100006, theta=0.675205 -> V=1.0, theta=0.0
% INFO    : Bus 58808	: V=1.0100006, theta=0.646688 -> V=1.0, theta=0.0
% INFO    : Bus 58809	: V=1.0057003, theta=-0.205459 -> V=1.0, theta=0.0
% INFO    : Bus 58810	: V=1.0052349, theta=-0.257407 -> V=1.0, theta=0.0
% INFO    : Bus 58811	: V=1.0048988, theta=-0.290048 -> V=1.0, theta=0.0
% INFO    : Bus 58812	: V=0.9990166, theta=-1.222153 -> V=1.0, theta=0.0
% INFO    : Bus 58813	: V=0.9964059, theta=-1.302359 -> V=1.0, theta=0.0
% INFO    : Bus 58814	: V=1.006915, theta=-0.128674 -> V=1.0, theta=0.0
% INFO    : Bus 58815	: V=0.9981523, theta=-1.325897 -> V=1.0, theta=0.0
% INFO    : Bus 58816	: V=0.9987783, theta=-1.238405 -> V=1.0, theta=0.0
% INFO    : Bus 58817	: V=0.997496, theta=-1.346269 -> V=1.0, theta=0.0
% INFO    : Bus 58818	: V=0.9992899, theta=-1.196943 -> V=1.0, theta=0.0
% INFO    : Bus 58819	: V=1.0006411, theta=-1.117457 -> V=1.0, theta=0.0
% INFO    : Bus 58820	: V=1.0102521, theta=0.637538 -> V=1.0, theta=0.0
% INFO    : Bus 58821	: V=1.0042398, theta=-0.667103 -> V=1.0, theta=0.0
% INFO    : Bus 58822	: V=1.0023698, theta=-0.875463 -> V=1.0, theta=0.0
% INFO    : Bus 58823	: V=1.0064582, theta=-0.15798 -> V=1.0, theta=0.0
% INFO    : Bus 58824	: V=0.999708, theta=-1.195452 -> V=1.0, theta=0.0
% INFO    : Bus 58825	: V=0.9997503, theta=-1.209518 -> V=1.0, theta=0.0
% INFO    : Bus 58826	: V=1.0010108, theta=-1.174683 -> V=1.0, theta=0.0
% INFO    : Bus 58827	: V=1.0071881, theta=-0.103865 -> V=1.0, theta=0.0
% INFO    : Bus 58828	: V=0.9995282, theta=-0.999314 -> V=1.0, theta=0.0
% INFO    : Bus 58829	: V=1.0054893, theta=-0.269531 -> V=1.0, theta=0.0
% INFO    : Bus 58830	: V=1.0300006, theta=2.531771 -> V=1.0, theta=0.0
% INFO    : Bus 58831	: V=0.9963979, theta=-1.358353 -> V=1.0, theta=0.0
% INFO    : Bus 58832	: V=0.9966632, theta=-1.152029 -> V=1.0, theta=0.0
% INFO    : Bus 58833	: V=0.9956651, theta=-1.478341 -> V=1.0, theta=0.0
% INFO    : Bus 58834	: V=0.99671, theta=-1.385296 -> V=1.0, theta=0.0
% INFO    : Bus 58835	: V=0.9991479, theta=-1.014624 -> V=1.0, theta=0.0
% INFO    : Bus 58836	: V=1.0034323, theta=-0.139805 -> V=1.0, theta=0.0
% INFO    : Bus 58837	: V=1.0044115, theta=-0.083584 -> V=1.0, theta=0.0
% INFO    : Bus 58838	: V=0.9960909, theta=-1.496396 -> V=1.0, theta=0.0
% INFO    : Bus 58839	: V=1.0043369, theta=-0.499143 -> V=1.0, theta=0.0
% INFO    : Bus 58840	: V=1.0052691, theta=-0.024641 -> V=1.0, theta=0.0
% INFO    : Bus 58841	: V=1.0063826, theta=0.066894 -> V=1.0, theta=0.0
% INFO    : Bus 58842	: V=1.0056185, theta=-0.000152 -> V=1.0, theta=0.0
% INFO    : Bus 58843	: V=0.9949879, theta=-1.90107 -> V=1.0, theta=0.0
% INFO    : Bus 58844	: V=1.0200006, theta=3.47466 -> V=1.0, theta=0.0
% INFO    : Bus 58845	: V=1.004584, theta=0.506189 -> V=1.0, theta=0.0
% INFO    : Bus 58846	: V=1.0100006, theta=0.785453 -> V=1.0, theta=0.0
% INFO    : Bus 58847	: V=1.0039689, theta=-0.345524 -> V=1.0, theta=0.0
% INFO    : Bus 58848	: V=1.0181593, theta=3.07104 -> V=1.0, theta=0.0
% INFO    : Bus 58849	: V=0.9860576, theta=-2.250864 -> V=1.0, theta=0.0
% INFO    : Bus 58850	: V=1.0001873, theta=-0.221318 -> V=1.0, theta=0.0
% INFO    : Bus 58851	: V=0.9974344, theta=-0.278562 -> V=1.0, theta=0.0
% INFO    : Bus 58852	: V=1.0015125, theta=-0.004111 -> V=1.0, theta=0.0
% INFO    : Bus 58853	: V=0.9999084, theta=-0.15585 -> V=1.0, theta=0.0
% INFO    : Bus 58854	: V=1.0008241, theta=-0.193476 -> V=1.0, theta=0.0
% INFO    : Bus 58855	: V=0.9878165, theta=-1.80286 -> V=1.0, theta=0.0
% INFO    : Bus 58856	: V=0.9894357, theta=-1.721898 -> V=1.0, theta=0.0
% INFO    : Bus 58857	: V=0.9812068, theta=-2.54905 -> V=1.0, theta=0.0
% INFO    : Bus 58858	: V=0.998667, theta=-1.114416 -> V=1.0, theta=0.0
% INFO    : Bus 58859	: V=0.9931839, theta=-0.940706 -> V=1.0, theta=0.0
% INFO    : Bus 58860	: V=1.0100006, theta=0.914727 -> V=1.0, theta=0.0
% INFO    : Bus 58861	: V=1.0039319, theta=-0.601844 -> V=1.0, theta=0.0
% INFO    : Bus 58862	: V=1.0246141, theta=11.667838 -> V=1.0, theta=0.0
% INFO    : Bus 58863	: V=1.0249704, theta=10.75078 -> V=1.0, theta=0.0
% INFO    : Bus 58864	: V=1.0100005, theta=1.88923 -> V=1.0, theta=0.0
% INFO    : Bus 58865	: V=1.0056103, theta=0.129276 -> V=1.0, theta=0.0
% INFO    : Bus 58866	: V=1.0068929, theta=0.284682 -> V=1.0, theta=0.0
% INFO    : Bus 58867	: V=1.0056343, theta=0.270254 -> V=1.0, theta=0.0
% INFO    : Bus 58868	: V=1.0099333, theta=1.356185 -> V=1.0, theta=0.0
% INFO    : Bus 58869	: V=1.0100005, theta=1.145599 -> V=1.0, theta=0.0
% INFO    : Bus 58870	: V=1.0110521, theta=0.872228 -> V=1.0, theta=0.0
% INFO    : Bus 58871	: V=1.01106, theta=0.799511 -> V=1.0, theta=0.0
% INFO    : Bus 58872	: V=1.008257, theta=0.408932 -> V=1.0, theta=0.0
% INFO    : Bus 58873	: V=1.0059857, theta=0.232546 -> V=1.0, theta=0.0
% INFO    : Bus 58874	: V=1.0066719, theta=0.266571 -> V=1.0, theta=0.0
% INFO    : Bus 58875	: V=1.0081638, theta=0.317227 -> V=1.0, theta=0.0
% INFO    : Bus 58876	: V=1.011169, theta=0.745243 -> V=1.0, theta=0.0
% INFO    : Bus 58877	: V=1.0111706, theta=0.711897 -> V=1.0, theta=0.0
% INFO    : Bus 58878	: V=1.0117778, theta=0.869444 -> V=1.0, theta=0.0
% INFO    : Bus 58879	: V=1.0115978, theta=0.732643 -> V=1.0, theta=0.0
% INFO    : Bus 58880	: V=1.0119839, theta=0.732926 -> V=1.0, theta=0.0
% INFO    : Bus 58881	: V=1.0112658, theta=0.860303 -> V=1.0, theta=0.0
% INFO    : Bus 58882	: V=1.0110706, theta=1.021547 -> V=1.0, theta=0.0
% INFO    : Bus 58883	: V=1.0108457, theta=3.691487 -> V=1.0, theta=0.0
% INFO    : Bus 58884	: V=1.0029552, theta=0.555004 -> V=1.0, theta=0.0
% INFO    : Bus 58885	: V=1.0107704, theta=1.428692 -> V=1.0, theta=0.0
% INFO    : Bus 58886	: V=1.0101368, theta=10.640075 -> V=1.0, theta=0.0
% INFO    : Bus 58887	: V=1.0200004, theta=7.161017 -> V=1.0, theta=0.0
% INFO    : Bus 58888	: V=0.9779337, theta=16.172911 -> V=1.0, theta=0.0
% INFO    : Bus 58889	: V=0.94567, theta=13.463498 -> V=1.0, theta=0.0
% INFO    : Bus 58890	: V=0.9999633, theta=1.135023 -> V=1.0, theta=0.0
% INFO    : Bus 58891	: V=1.0049585, theta=3.6792 -> V=1.0, theta=0.0
% INFO    : Bus 58892	: V=1.0111931, theta=5.812946 -> V=1.0, theta=0.0
% INFO    : Bus 58893	: V=1.0085114, theta=2.718963 -> V=1.0, theta=0.0
% INFO    : Bus 58894	: V=1.0011164, theta=2.731226 -> V=1.0, theta=0.0
% INFO    : Bus 58895	: V=0.9940246, theta=0.841095 -> V=1.0, theta=0.0
% INFO    : Bus 58896	: V=1.001735, theta=2.680055 -> V=1.0, theta=0.0
% INFO    : Bus 58897	: V=0.9980527, theta=0.451336 -> V=1.0, theta=0.0
% INFO    : Bus 58898	: V=1.0218001, theta=0.901885 -> V=1.0, theta=0.0
% INFO    : Bus 58899	: V=1.0242731, theta=0.783051 -> V=1.0, theta=0.0
% INFO    : Bus 58900	: V=1.0240095, theta=2.502139 -> V=1.0, theta=0.0
% INFO    : Bus 58901	: V=1.0243552, theta=1.351927 -> V=1.0, theta=0.0
% INFO    : Bus 58902	: V=0.9596004, theta=-6.682356 -> V=1.0, theta=0.0
% INFO    : Bus 58903	: V=1.010312, theta=19.538259 -> V=1.0, theta=0.0
% INFO    : Bus 58904	: V=1.0094255, theta=20.115285 -> V=1.0, theta=0.0
% INFO    : Bus 58905	: V=1.0200006, theta=20.307001 -> V=1.0, theta=0.0
% INFO    : Bus 58906	: V=1.0200006, theta=20.650189 -> V=1.0, theta=0.0
% INFO    : Bus 58907	: V=0.9910944, theta=21.961722 -> V=1.0, theta=0.0
% INFO    : Bus 58908	: V=1.0100006, theta=21.190645 -> V=1.0, theta=0.0
% INFO    : Bus 58909	: V=0.9883568, theta=21.902384 -> V=1.0, theta=0.0
% INFO    : Bus 58910	: V=1.0120429, theta=19.478559 -> V=1.0, theta=0.0
% INFO    : Bus 58911	: V=1.0200006, theta=19.998646 -> V=1.0, theta=0.0
% INFO    : Bus 58912	: V=1.0166859, theta=7.340788 -> V=1.0, theta=0.0
% INFO    : Bus 58913	: V=0.9994829, theta=3.391919 -> V=1.0, theta=0.0
% INFO    : Bus 58914	: V=1.0003792, theta=3.173364 -> V=1.0, theta=0.0
% INFO    : Bus 58915	: V=0.9998195, theta=3.469985 -> V=1.0, theta=0.0
% INFO    : Bus 58916	: V=1.0024188, theta=4.511791 -> V=1.0, theta=0.0
% INFO    : Bus 58917	: V=1.0033511, theta=4.73541 -> V=1.0, theta=0.0
% INFO    : Bus 58918	: V=1.002667, theta=4.617781 -> V=1.0, theta=0.0
% INFO    : Bus 58919	: V=1.0001897, theta=3.47957 -> V=1.0, theta=0.0
% INFO    : Bus 58920	: V=1.0013189, theta=3.199425 -> V=1.0, theta=0.0
% INFO    : Bus 58921	: V=1.0017356, theta=3.348063 -> V=1.0, theta=0.0
% INFO    : Bus 58922	: V=1.0021307, theta=4.51099 -> V=1.0, theta=0.0
% INFO    : Bus 58923	: V=1.0100005, theta=4.181037 -> V=1.0, theta=0.0
% INFO    : Bus 58924	: V=1.0010545, theta=3.185876 -> V=1.0, theta=0.0
% INFO    : Bus 58925	: V=1.0009294, theta=3.208449 -> V=1.0, theta=0.0
% INFO    : Bus 58926	: V=0.9999552, theta=3.007416 -> V=1.0, theta=0.0
% INFO    : Bus 58927	: V=1.0015401, theta=3.190344 -> V=1.0, theta=0.0
% INFO    : Bus 58928	: V=1.0005129, theta=3.09607 -> V=1.0, theta=0.0
% INFO    : Bus 58929	: V=0.9989814, theta=2.963663 -> V=1.0, theta=0.0
% INFO    : Bus 58930	: V=0.9968676, theta=3.002004 -> V=1.0, theta=0.0
% INFO    : Bus 58931	: V=1.005323, theta=3.59608 -> V=1.0, theta=0.0
% INFO    : Bus 58932	: V=0.9899971, theta=2.715885 -> V=1.0, theta=0.0
% INFO    : Bus 58933	: V=1.0103298, theta=20.804761 -> V=1.0, theta=0.0
% INFO    : Bus 58934	: V=1.0100006, theta=21.299857 -> V=1.0, theta=0.0
% INFO    : Bus 58935	: V=1.0291469, theta=2.064336 -> V=1.0, theta=0.0
% INFO    : Bus 58936	: V=1.0207283, theta=1.747022 -> V=1.0, theta=0.0
% INFO    : Bus 58937	: V=0.9877974, theta=-2.529318 -> V=1.0, theta=0.0
% INFO    : Bus 58938	: V=0.9887624, theta=-2.453754 -> V=1.0, theta=0.0
% INFO    : Bus 58939	: V=0.9871401, theta=-2.547121 -> V=1.0, theta=0.0
% INFO    : Bus 58940	: V=1.0100006, theta=1.311943 -> V=1.0, theta=0.0
% INFO    : Bus 58941	: V=0.9865772, theta=-2.586256 -> V=1.0, theta=0.0
% INFO    : Bus 58942	: V=0.9851185, theta=-2.62853 -> V=1.0, theta=0.0
% INFO    : Bus 58943	: V=0.9855514, theta=-2.607041 -> V=1.0, theta=0.0
% INFO    : Bus 58944	: V=0.9864417, theta=-2.587918 -> V=1.0, theta=0.0
% INFO    : Bus 58945	: V=0.9881321, theta=-2.331969 -> V=1.0, theta=0.0
% INFO    : Bus 58946	: V=0.9878017, theta=-2.45936 -> V=1.0, theta=0.0
% INFO    : Bus 58947	: V=0.9872707, theta=-2.364369 -> V=1.0, theta=0.0
% INFO    : Bus 58948	: V=0.9843581, theta=-2.802161 -> V=1.0, theta=0.0
% INFO    : Bus 58949	: V=0.9819247, theta=-3.20112 -> V=1.0, theta=0.0
% INFO    : Bus 58950	: V=0.9760837, theta=-1.782255 -> V=1.0, theta=0.0
% INFO    : Bus 58951	: V=0.9948165, theta=-0.001409 -> V=1.0, theta=0.0
% INFO    : Bus 58952	: V=0.9959778, theta=0.167712 -> V=1.0, theta=0.0
% INFO    : Bus 58953	: V=0.9768593, theta=-1.747437 -> V=1.0, theta=0.0
% INFO    : Bus 58954	: V=0.9782063, theta=-1.705483 -> V=1.0, theta=0.0
% INFO    : Bus 58955	: V=0.978506, theta=-1.696644 -> V=1.0, theta=0.0
% INFO    : Bus 58956	: V=0.9958854, theta=0.484749 -> V=1.0, theta=0.0
% INFO    : Bus 58957	: V=0.9789955, theta=-1.609328 -> V=1.0, theta=0.0
% INFO    : Bus 58958	: V=0.9952023, theta=0.549228 -> V=1.0, theta=0.0
% INFO    : Bus 58959	: V=0.994789, theta=2.173884 -> V=1.0, theta=0.0
% INFO    : Bus 58960	: V=1.0010674, theta=2.407105 -> V=1.0, theta=0.0
% INFO    : Bus 58961	: V=1.002728, theta=2.879509 -> V=1.0, theta=0.0
% INFO    : Bus 58962	: V=1.0011316, theta=2.105874 -> V=1.0, theta=0.0
% INFO    : Bus 58963	: V=0.9979227, theta=1.250706 -> V=1.0, theta=0.0
% INFO    : Bus 58964	: V=0.9685016, theta=-3.679923 -> V=1.0, theta=0.0
% INFO    : Bus 58965	: V=0.9797581, theta=-2.93901 -> V=1.0, theta=0.0
% INFO    : Bus 58966	: V=1.0100005, theta=4.313676 -> V=1.0, theta=0.0
% INFO    : Bus 58967	: V=1.0200005, theta=8.211177 -> V=1.0, theta=0.0
% INFO    : Bus 58968	: V=1.0046379, theta=-3.154937 -> V=1.0, theta=0.0
% INFO    : Bus 58969	: V=1.0064843, theta=-5.425236 -> V=1.0, theta=0.0
% INFO    : Bus 58970	: V=0.9990168, theta=-6.391662 -> V=1.0, theta=0.0
% INFO    : Bus 58971	: V=0.9922238, theta=-6.903723 -> V=1.0, theta=0.0
% INFO    : Bus 58972	: V=1.0005718, theta=-5.345164 -> V=1.0, theta=0.0
% INFO    : Bus 58973	: V=0.9601545, theta=-14.724023 -> V=1.0, theta=0.0
% INFO    : Bus 58974	: V=1.0100005, theta=5.998057 -> V=1.0, theta=0.0
% INFO    : Bus 58975	: V=1.0129542, theta=17.798231 -> V=1.0, theta=0.0
% INFO    : Bus 58976	: V=0.9891326, theta=11.4091 -> V=1.0, theta=0.0
% INFO    : Bus 58977	: V=1.0200005, theta=6.479867 -> V=1.0, theta=0.0
% INFO    : Bus 58978	: V=1.0153987, theta=1.063234 -> V=1.0, theta=0.0
% INFO    : Bus 58979	: V=1.0140636, theta=0.844692 -> V=1.0, theta=0.0
% INFO    : Bus 58980	: V=1.0156555, theta=1.459489 -> V=1.0, theta=0.0
% INFO    : Bus 58981	: V=1.0114027, theta=1.200866 -> V=1.0, theta=0.0
% INFO    : Bus 58982	: V=1.0100006, theta=0.51446 -> V=1.0, theta=0.0
% INFO    : Bus 58983	: V=1.0084247, theta=4.119315 -> V=1.0, theta=0.0
% INFO    : Bus 58984	: V=0.9866623, theta=0.864917 -> V=1.0, theta=0.0
% INFO    : Bus 58985	: V=0.9583457, theta=-2.121882 -> V=1.0, theta=0.0
% INFO    : Bus 58986	: V=0.9645771, theta=-1.776106 -> V=1.0, theta=0.0
% INFO    : Bus 58987	: V=0.9640198, theta=0.001587 -> V=1.0, theta=0.0
% INFO    : Bus 58988	: V=1.0159734, theta=4.783422 -> V=1.0, theta=0.0
% INFO    : Bus 58989	: V=1.0243929, theta=4.935611 -> V=1.0, theta=0.0
% INFO    : Bus 58990	: V=1.0130829, theta=3.67976 -> V=1.0, theta=0.0
% INFO    : Bus 58991	: V=1.0061141, theta=-2.56504 -> V=1.0, theta=0.0
% INFO    : Bus 58992	: V=1.0012034, theta=-4.540789 -> V=1.0, theta=0.0
% INFO    : Bus 58993	: V=1.0072259, theta=15.725302 -> V=1.0, theta=0.0
% INFO    : Bus 58994	: V=1.0079334, theta=15.27045 -> V=1.0, theta=0.0
% INFO    : Bus 58995	: V=1.0177289, theta=14.139006 -> V=1.0, theta=0.0
% INFO    : Bus 58996	: V=1.0134327, theta=15.444867 -> V=1.0, theta=0.0
% INFO    : Bus 58997	: V=1.0300006, theta=13.081537 -> V=1.0, theta=0.0
% INFO    : Bus 58998	: V=1.0200005, theta=6.3673 -> V=1.0, theta=0.0
% INFO    : Bus 58999	: V=1.0042964, theta=3.990836 -> V=1.0, theta=0.0
% INFO    : Bus 59000	: V=1.002, theta=3.622763 -> V=1.0, theta=0.0
% INFO    : Bus 59001	: V=0.9966104, theta=3.2778 -> V=1.0, theta=0.0
% INFO    : Bus 59002	: V=0.9939715, theta=-8.475826 -> V=1.0, theta=0.0
% INFO    : Bus 59003	: V=0.9887097, theta=-6.051826 -> V=1.0, theta=0.0
% INFO    : Bus 59004	: V=0.9830454, theta=-6.46213 -> V=1.0, theta=0.0
% INFO    : Bus 59005	: V=0.989017, theta=-6.165903 -> V=1.0, theta=0.0
% INFO    : Bus 59006	: V=0.9845817, theta=-6.78598 -> V=1.0, theta=0.0
% INFO    : Bus 59007	: V=0.9980961, theta=18.409014 -> V=1.0, theta=0.0
% INFO    : Bus 59008	: V=1.0075481, theta=19.060476 -> V=1.0, theta=0.0
% INFO    : Bus 59009	: V=1.0085309, theta=19.654141 -> V=1.0, theta=0.0
% INFO    : Bus 59010	: V=1.0105097, theta=19.505073 -> V=1.0, theta=0.0
% INFO    : Bus 59011	: V=1.0009365, theta=18.244335 -> V=1.0, theta=0.0
% INFO    : Bus 59012	: V=1.0027638, theta=18.041095 -> V=1.0, theta=0.0
% INFO    : Bus 59013	: V=1.0132532, theta=19.641422 -> V=1.0, theta=0.0
% INFO    : Bus 59014	: V=1.0039712, theta=18.672511 -> V=1.0, theta=0.0
% INFO    : Bus 59015	: V=1.0041958, theta=18.574868 -> V=1.0, theta=0.0
% INFO    : Bus 59016	: V=1.0100006, theta=19.73249 -> V=1.0, theta=0.0
% INFO    : Bus 59017	: V=1.0028842, theta=18.562576 -> V=1.0, theta=0.0
% INFO    : Bus 59018	: V=0.9958432, theta=17.187129 -> V=1.0, theta=0.0
% INFO    : Bus 59019	: V=1.0068073, theta=19.056257 -> V=1.0, theta=0.0
% INFO    : Bus 59020	: V=1.0065279, theta=19.019824 -> V=1.0, theta=0.0
% INFO    : Bus 59021	: V=1.0037996, theta=18.399512 -> V=1.0, theta=0.0
% INFO    : Bus 59022	: V=0.9932756, theta=17.098647 -> V=1.0, theta=0.0
% INFO    : Bus 59023	: V=0.9935886, theta=16.918125 -> V=1.0, theta=0.0
% INFO    : Bus 59024	: V=0.9909175, theta=16.812994 -> V=1.0, theta=0.0
% INFO    : Bus 59025	: V=0.9928093, theta=16.901063 -> V=1.0, theta=0.0
% INFO    : Bus 59026	: V=0.989906, theta=16.777839 -> V=1.0, theta=0.0
% INFO    : Bus 59027	: V=0.9890637, theta=16.796278 -> V=1.0, theta=0.0
% INFO    : Bus 59028	: V=1.0059444, theta=18.944078 -> V=1.0, theta=0.0
% INFO    : Bus 59029	: V=1.0022953, theta=18.398256 -> V=1.0, theta=0.0
% INFO    : Bus 59030	: V=0.9953966, theta=17.673519 -> V=1.0, theta=0.0
% INFO    : Bus 59031	: V=0.9859941, theta=16.812607 -> V=1.0, theta=0.0
% INFO    : Bus 59032	: V=0.9979663, theta=17.608579 -> V=1.0, theta=0.0
% INFO    : Bus 59033	: V=0.9937695, theta=17.269615 -> V=1.0, theta=0.0
% INFO    : Bus 59034	: V=0.99145, theta=17.066976 -> V=1.0, theta=0.0
% INFO    : Bus 59035	: V=1.0100899, theta=19.782989 -> V=1.0, theta=0.0
% INFO    : Bus 59036	: V=0.9853339, theta=14.336848 -> V=1.0, theta=0.0
% INFO    : Bus 59037	: V=0.9889717, theta=12.052246 -> V=1.0, theta=0.0
% INFO    : Bus 59038	: V=1.0100006, theta=19.414217 -> V=1.0, theta=0.0
% INFO    : Bus 59039	: V=0.9890259, theta=6.256005 -> V=1.0, theta=0.0
% INFO    : Bus 59040	: V=1.0095032, theta=7.60759 -> V=1.0, theta=0.0
% INFO    : Bus 59041	: V=1.0201946, theta=6.597484 -> V=1.0, theta=0.0
% INFO    : Bus 59042	: V=0.9823995, theta=12.456356 -> V=1.0, theta=0.0
% INFO    : Bus 59043	: V=0.994063, theta=13.290969 -> V=1.0, theta=0.0
% INFO    : Bus 59044	: V=1.0105641, theta=16.212878 -> V=1.0, theta=0.0
% INFO    : Bus 59045	: V=0.9507141, theta=-8.979194 -> V=1.0, theta=0.0
% INFO    : Bus 59046	: V=0.9855538, theta=1.967394 -> V=1.0, theta=0.0
% INFO    : Bus 59047	: V=0.9779029, theta=0.99995 -> V=1.0, theta=0.0
% INFO    : Bus 59048	: V=0.9789958, theta=1.143859 -> V=1.0, theta=0.0
% INFO    : Bus 59049	: V=0.9791403, theta=1.12636 -> V=1.0, theta=0.0
% INFO    : Bus 59050	: V=0.9762241, theta=0.053162 -> V=1.0, theta=0.0
% INFO    : Bus 59051	: V=0.9820524, theta=1.408022 -> V=1.0, theta=0.0
% INFO    : Bus 59052	: V=0.9917594, theta=-7.782573 -> V=1.0, theta=0.0
% INFO    : Bus 59053	: V=1.0028344, theta=-5.239467 -> V=1.0, theta=0.0
% INFO    : Bus 59054	: V=0.9913608, theta=-3.314421 -> V=1.0, theta=0.0
% INFO    : Bus 59055	: V=1.0012051, theta=-6.107702 -> V=1.0, theta=0.0
% INFO    : Bus 59056	: V=1.0292129, theta=-0.766685 -> V=1.0, theta=0.0
% INFO    : Bus 59057	: V=1.0009436, theta=18.130671 -> V=1.0, theta=0.0
% INFO    : Bus 59058	: V=1.0100006, theta=19.28343 -> V=1.0, theta=0.0
% INFO    : Bus 59059	: V=1.0300006, theta=19.566471 -> V=1.0, theta=0.0
% INFO    : Bus 59060	: V=1.0196789, theta=19.36009 -> V=1.0, theta=0.0
% INFO    : Bus 59061	: V=1.0195294, theta=19.353018 -> V=1.0, theta=0.0
% INFO    : Bus 59062	: V=1.0197416, theta=19.35719 -> V=1.0, theta=0.0
% INFO    : Bus 59063	: V=1.0126257, theta=17.139359 -> V=1.0, theta=0.0
% INFO    : Bus 59064	: V=1.0125196, theta=18.777618 -> V=1.0, theta=0.0
% INFO    : Bus 59065	: V=1.0131248, theta=18.811604 -> V=1.0, theta=0.0
% INFO    : Bus 59066	: V=1.0143578, theta=18.86984 -> V=1.0, theta=0.0
% INFO    : Bus 59067	: V=1.0061652, theta=-0.540416 -> V=1.0, theta=0.0
% INFO    : Bus 59068	: V=0.9887368, theta=-0.050524 -> V=1.0, theta=0.0
% INFO    : Bus 59069	: V=0.9692899, theta=-1.259186 -> V=1.0, theta=0.0
% INFO    : Bus 59070	: V=0.9913285, theta=-1.498208 -> V=1.0, theta=0.0
% INFO    : Bus 59071	: V=1.0200006, theta=6.002135 -> V=1.0, theta=0.0
% INFO    : Bus 59072	: V=1.0162467, theta=5.400238 -> V=1.0, theta=0.0
% INFO    : Bus 59073	: V=1.0100006, theta=4.86875 -> V=1.0, theta=0.0
% INFO    : Bus 59074	: V=1.0109072, theta=3.918823 -> V=1.0, theta=0.0
% INFO    : Bus 59075	: V=1.0301908, theta=0.150638 -> V=1.0, theta=0.0
% INFO    : Bus 59076	: V=1.0300005, theta=-0.219022 -> V=1.0, theta=0.0
% INFO    : Bus 59077	: V=0.9638825, theta=14.996135 -> V=1.0, theta=0.0
% INFO    : Bus 59078	: V=0.9954863, theta=17.59924 -> V=1.0, theta=0.0
% INFO    : Bus 59079	: V=0.9954592, theta=17.43213 -> V=1.0, theta=0.0
% INFO    : Bus 59080	: V=1.0117162, theta=6.523189 -> V=1.0, theta=0.0
% INFO    : Bus 59081	: V=0.9883657, theta=-8.457857 -> V=1.0, theta=0.0
% INFO    : Bus 59082	: V=0.9980206, theta=-5.81439 -> V=1.0, theta=0.0
% INFO    : Bus 59083	: V=0.9966206, theta=-6.04255 -> V=1.0, theta=0.0
% INFO    : Bus 59084	: V=0.9931797, theta=-6.677427 -> V=1.0, theta=0.0
% INFO    : Bus 59085	: V=0.9831131, theta=-8.553875 -> V=1.0, theta=0.0
% INFO    : Bus 59086	: V=0.9878259, theta=-8.067007 -> V=1.0, theta=0.0
% INFO    : Bus 59087	: V=0.9865108, theta=-8.445553 -> V=1.0, theta=0.0
% INFO    : Bus 59088	: V=0.990536, theta=-8.491377 -> V=1.0, theta=0.0
% INFO    : Bus 59089	: V=0.9917295, theta=-7.120183 -> V=1.0, theta=0.0
% INFO    : Bus 59090	: V=0.9884959, theta=-8.262303 -> V=1.0, theta=0.0
% INFO    : Bus 59091	: V=0.9909509, theta=-7.274184 -> V=1.0, theta=0.0
% INFO    : Bus 59092	: V=0.9890665, theta=-8.241203 -> V=1.0, theta=0.0
% INFO    : Bus 59093	: V=0.9935811, theta=-7.832842 -> V=1.0, theta=0.0
% INFO    : Bus 59094	: V=0.9786413, theta=-7.226301 -> V=1.0, theta=0.0
% INFO    : Bus 59095	: V=1.0200006, theta=7.464852 -> V=1.0, theta=0.0
% INFO    : Bus 59096	: V=0.9980146, theta=9.562876 -> V=1.0, theta=0.0
% INFO    : Bus 59097	: V=1.0214057, theta=8.862169 -> V=1.0, theta=0.0
% INFO    : Bus 59098	: V=1.0208162, theta=8.290221 -> V=1.0, theta=0.0
% INFO    : Bus 59099	: V=1.0194301, theta=6.804361 -> V=1.0, theta=0.0
% INFO    : Bus 59100	: V=0.9817711, theta=5.53684 -> V=1.0, theta=0.0
% INFO    : Bus 59101	: V=1.0100005, theta=8.128872 -> V=1.0, theta=0.0
% INFO    : Bus 59102	: V=1.0213354, theta=8.140966 -> V=1.0, theta=0.0
% INFO    : Bus 59103	: V=1.0243371, theta=8.300469 -> V=1.0, theta=0.0
% INFO    : Bus 59104	: V=1.0242455, theta=13.431253 -> V=1.0, theta=0.0
% INFO    : Bus 59105	: V=1.0100005, theta=15.939759 -> V=1.0, theta=0.0
% INFO    : Bus 59106	: V=1.0294197, theta=15.9119 -> V=1.0, theta=0.0
% INFO    : Bus 59107	: V=1.0211729, theta=16.727616 -> V=1.0, theta=0.0
% INFO    : Bus 59108	: V=1.0300005, theta=18.858514 -> V=1.0, theta=0.0
% INFO    : Bus 59109	: V=0.994012, theta=8.585767 -> V=1.0, theta=0.0
% INFO    : Bus 59110	: V=1.0155638, theta=10.285138 -> V=1.0, theta=0.0
% INFO    : Bus 59111	: V=1.0185261, theta=10.349254 -> V=1.0, theta=0.0
% INFO    : Bus 59112	: V=1.0094645, theta=9.831425 -> V=1.0, theta=0.0
% INFO    : Bus 59113	: V=1.0261699, theta=9.219178 -> V=1.0, theta=0.0
% INFO    : Bus 59114	: V=1.0400031, theta=11.844258 -> V=1.0, theta=0.0
% INFO    : Bus 59115	: V=1.0218703, theta=12.402565 -> V=1.0, theta=0.0
% INFO    : Bus 59116	: V=1.0227295, theta=13.483625 -> V=1.0, theta=0.0
% INFO    : Bus 59117	: V=1.0166603, theta=13.319877 -> V=1.0, theta=0.0
% INFO    : Bus 59118	: V=1.0100005, theta=13.505284 -> V=1.0, theta=0.0
% INFO    : Bus 59119	: V=1.0218094, theta=14.039554 -> V=1.0, theta=0.0
% INFO    : Bus 59120	: V=1.0110542, theta=23.098131 -> V=1.0, theta=0.0
% INFO    : Bus 59121	: V=1.0160088, theta=12.022241 -> V=1.0, theta=0.0
% INFO    : Bus 59122	: V=1.0166906, theta=11.860344 -> V=1.0, theta=0.0
% INFO    : Bus 59123	: V=1.017545, theta=11.733468 -> V=1.0, theta=0.0
% INFO    : Bus 59124	: V=1.0173312, theta=11.747538 -> V=1.0, theta=0.0
% INFO    : Bus 59125	: V=1.0181378, theta=11.331458 -> V=1.0, theta=0.0
% INFO    : Bus 59126	: V=1.0142575, theta=10.797872 -> V=1.0, theta=0.0
% INFO    : Bus 59127	: V=1.0080998, theta=10.347813 -> V=1.0, theta=0.0
% INFO    : Bus 59128	: V=1.0097659, theta=10.793463 -> V=1.0, theta=0.0
% INFO    : Bus 59129	: V=1.0158089, theta=11.993446 -> V=1.0, theta=0.0
% INFO    : Bus 59130	: V=1.0100006, theta=12.390719 -> V=1.0, theta=0.0
% INFO    : Bus 59131	: V=1.0187117, theta=11.410511 -> V=1.0, theta=0.0
% INFO    : Bus 59132	: V=1.0098743, theta=9.830664 -> V=1.0, theta=0.0
% INFO    : Bus 59133	: V=1.0300006, theta=12.529558 -> V=1.0, theta=0.0
% INFO    : Bus 59134	: V=1.0151676, theta=11.181941 -> V=1.0, theta=0.0
% INFO    : Bus 59135	: V=1.0175473, theta=11.869264 -> V=1.0, theta=0.0
% INFO    : Bus 59136	: V=1.0174981, theta=11.250135 -> V=1.0, theta=0.0
% INFO    : Bus 59137	: V=1.0173055, theta=11.214172 -> V=1.0, theta=0.0
% INFO    : Bus 59138	: V=1.0014856, theta=9.407673 -> V=1.0, theta=0.0
% INFO    : Bus 59139	: V=1.0186513, theta=11.477762 -> V=1.0, theta=0.0
% INFO    : Bus 59140	: V=1.0300006, theta=12.468105 -> V=1.0, theta=0.0
% INFO    : Bus 59141	: V=1.0148196, theta=10.740748 -> V=1.0, theta=0.0
% INFO    : Bus 59142	: V=1.0147752, theta=10.813694 -> V=1.0, theta=0.0
% INFO    : Bus 59143	: V=1.0213769, theta=13.298312 -> V=1.0, theta=0.0
% INFO    : Bus 59144	: V=1.0146865, theta=11.820344 -> V=1.0, theta=0.0
% INFO    : Bus 59145	: V=1.0417596, theta=14.886352 -> V=1.0, theta=0.0
% INFO    : Bus 59146	: V=1.038596, theta=14.103369 -> V=1.0, theta=0.0
% INFO    : Bus 59147	: V=1.0398735, theta=14.141692 -> V=1.0, theta=0.0
% INFO    : Bus 59148	: V=1.038872, theta=14.021794 -> V=1.0, theta=0.0
% INFO    : Bus 59149	: V=1.0421508, theta=14.274669 -> V=1.0, theta=0.0
% INFO    : Bus 59150	: V=1.0388064, theta=14.032577 -> V=1.0, theta=0.0
% INFO    : Bus 59151	: V=0.9362792, theta=1.870415 -> V=1.0, theta=0.0
% INFO    : Bus 59152	: V=1.0330179, theta=13.485806 -> V=1.0, theta=0.0
% INFO    : Bus 59153	: V=1.0306025, theta=13.782856 -> V=1.0, theta=0.0
% INFO    : Bus 59154	: V=1.0219533, theta=12.367166 -> V=1.0, theta=0.0
% INFO    : Bus 59155	: V=0.9799888, theta=4.901304 -> V=1.0, theta=0.0
% INFO    : Bus 59156	: V=0.9774996, theta=4.690844 -> V=1.0, theta=0.0
% INFO    : Bus 59157	: V=0.970488, theta=4.471734 -> V=1.0, theta=0.0
% INFO    : Bus 59158	: V=1.0354425, theta=18.759763 -> V=1.0, theta=0.0
% INFO    : Bus 59159	: V=1.0100005, theta=11.676987 -> V=1.0, theta=0.0
% INFO    : Bus 59160	: V=1.0300005, theta=13.068016 -> V=1.0, theta=0.0
% INFO    : Bus 59161	: V=1.0271773, theta=16.250485 -> V=1.0, theta=0.0
% INFO    : Bus 59162	: V=1.0300006, theta=20.130426 -> V=1.0, theta=0.0
% INFO    : Bus 59163	: V=1.0293121, theta=17.340538 -> V=1.0, theta=0.0
% INFO    : Bus 59164	: V=1.0010893, theta=15.08381 -> V=1.0, theta=0.0
% INFO    : Bus 59165	: V=0.9990044, theta=15.049918 -> V=1.0, theta=0.0
% INFO    : Bus 59166	: V=1.0095303, theta=15.258273 -> V=1.0, theta=0.0
% INFO    : Bus 59167	: V=1.0032891, theta=15.105618 -> V=1.0, theta=0.0
% INFO    : Bus 59168	: V=1.0053649, theta=14.717593 -> V=1.0, theta=0.0
% INFO    : Bus 59169	: V=1.0247302, theta=16.338776 -> V=1.0, theta=0.0
% INFO    : Bus 59170	: V=1.0205108, theta=16.334549 -> V=1.0, theta=0.0
% INFO    : Bus 59171	: V=1.0176125, theta=16.121083 -> V=1.0, theta=0.0
% INFO    : Bus 59172	: V=1.0114901, theta=15.111843 -> V=1.0, theta=0.0
% INFO    : Bus 59173	: V=1.0164682, theta=16.016494 -> V=1.0, theta=0.0
% INFO    : Bus 59174	: V=1.0163123, theta=16.001488 -> V=1.0, theta=0.0
% INFO    : Bus 59175	: V=1.0190735, theta=16.234278 -> V=1.0, theta=0.0
% INFO    : Bus 59176	: V=1.0096622, theta=14.747313 -> V=1.0, theta=0.0
% INFO    : Bus 59177	: V=1.0111134, theta=14.727155 -> V=1.0, theta=0.0
% INFO    : Bus 59178	: V=1.0102449, theta=15.031566 -> V=1.0, theta=0.0
% INFO    : Bus 59179	: V=1.0183366, theta=17.100381 -> V=1.0, theta=0.0
% INFO    : Bus 59180	: V=1.015177, theta=9.53274 -> V=1.0, theta=0.0
% INFO    : Bus 59181	: V=1.0172387, theta=9.093326 -> V=1.0, theta=0.0
% INFO    : Bus 59182	: V=1.030615, theta=11.051072 -> V=1.0, theta=0.0
% INFO    : Bus 59183	: V=1.0300005, theta=11.43842 -> V=1.0, theta=0.0
% INFO    : Bus 59184	: V=1.0300005, theta=11.534331 -> V=1.0, theta=0.0
% INFO    : Bus 59185	: V=1.0300005, theta=11.471184 -> V=1.0, theta=0.0
% INFO    : Bus 59186	: V=1.0140395, theta=9.038567 -> V=1.0, theta=0.0
% INFO    : Bus 59187	: V=1.0164389, theta=9.09882 -> V=1.0, theta=0.0
% INFO    : Bus 59188	: V=1.0312939, theta=11.447037 -> V=1.0, theta=0.0
% INFO    : Bus 59189	: V=1.0190372, theta=9.387274 -> V=1.0, theta=0.0
% INFO    : Bus 59190	: V=1.0311284, theta=11.46925 -> V=1.0, theta=0.0
% INFO    : Bus 59191	: V=1.0220043, theta=9.360402 -> V=1.0, theta=0.0
% INFO    : Bus 59192	: V=1.0318129, theta=10.596602 -> V=1.0, theta=0.0
% INFO    : Bus 59193	: V=1.0215244, theta=9.33658 -> V=1.0, theta=0.0
% INFO    : Bus 59194	: V=1.021889, theta=9.340605 -> V=1.0, theta=0.0
% INFO    : Bus 59195	: V=1.0190251, theta=9.257401 -> V=1.0, theta=0.0
% INFO    : Bus 59196	: V=1.0185284, theta=9.281772 -> V=1.0, theta=0.0
% INFO    : Bus 59197	: V=1.0205217, theta=9.293796 -> V=1.0, theta=0.0
% INFO    : Bus 59198	: V=1.0193833, theta=9.34878 -> V=1.0, theta=0.0
% INFO    : Bus 59199	: V=1.0000205, theta=8.970843 -> V=1.0, theta=0.0
% INFO    : Bus 59200	: V=1.0484237, theta=8.979342 -> V=1.0, theta=0.0
% INFO    : Bus 59201	: V=1.0356179, theta=8.622541 -> V=1.0, theta=0.0
% INFO    : Bus 59202	: V=1.0424766, theta=12.513167 -> V=1.0, theta=0.0
% INFO    : Bus 59203	: V=1.0300006, theta=15.923247 -> V=1.0, theta=0.0
% INFO    : Bus 59204	: V=1.0175256, theta=15.345435 -> V=1.0, theta=0.0
% INFO    : Bus 59205	: V=1.0030522, theta=13.309323 -> V=1.0, theta=0.0
% INFO    : Bus 59206	: V=1.0288269, theta=16.097639 -> V=1.0, theta=0.0
% INFO    : Bus 59207	: V=1.0036447, theta=11.006019 -> V=1.0, theta=0.0
% INFO    : Bus 59208	: V=0.9801248, theta=5.59105 -> V=1.0, theta=0.0
% INFO    : Bus 59209	: V=0.9923733, theta=8.386218 -> V=1.0, theta=0.0
% INFO    : Bus 59210	: V=1.0100006, theta=11.803551 -> V=1.0, theta=0.0
% INFO    : Bus 59211	: V=1.0096234, theta=10.37208 -> V=1.0, theta=0.0
% INFO    : Bus 59212	: V=1.0013936, theta=9.01772 -> V=1.0, theta=0.0
% INFO    : Bus 59213	: V=1.0037001, theta=9.339766 -> V=1.0, theta=0.0
% INFO    : Bus 59214	: V=0.9960797, theta=8.51183 -> V=1.0, theta=0.0
% INFO    : Bus 59215	: V=0.9975442, theta=7.563239 -> V=1.0, theta=0.0
% INFO    : Bus 59216	: V=1.0470584, theta=12.275419 -> V=1.0, theta=0.0
% INFO    : Bus 59217	: V=1.0364569, theta=11.06779 -> V=1.0, theta=0.0
% INFO    : Bus 59218	: V=1.0259012, theta=11.914372 -> V=1.0, theta=0.0
% INFO    : Bus 59219	: V=0.9905661, theta=13.610477 -> V=1.0, theta=0.0
% INFO    : Bus 59220	: V=1.0088971, theta=14.792369 -> V=1.0, theta=0.0
% INFO    : Bus 59221	: V=0.9956937, theta=13.732487 -> V=1.0, theta=0.0
% INFO    : Bus 59222	: V=1.0082285, theta=15.214847 -> V=1.0, theta=0.0
% INFO    : Bus 59223	: V=1.0118525, theta=14.96166 -> V=1.0, theta=0.0
% INFO    : Bus 59224	: V=1.0152902, theta=14.663118 -> V=1.0, theta=0.0
% INFO    : Bus 59225	: V=1.0211664, theta=14.492791 -> V=1.0, theta=0.0
% INFO    : Bus 59226	: V=1.0242644, theta=14.192748 -> V=1.0, theta=0.0
% INFO    : Bus 59227	: V=1.016426, theta=10.946151 -> V=1.0, theta=0.0
% INFO    : Bus 59228	: V=1.0116099, theta=9.937947 -> V=1.0, theta=0.0
% INFO    : Bus 59229	: V=1.0092025, theta=10.661109 -> V=1.0, theta=0.0
% INFO    : Bus 59230	: V=1.012051, theta=9.761513 -> V=1.0, theta=0.0
% INFO    : Bus 59231	: V=1.0110087, theta=9.687611 -> V=1.0, theta=0.0
% INFO    : Bus 59232	: V=0.9978442, theta=7.829719 -> V=1.0, theta=0.0
% INFO    : Bus 59233	: V=0.9921196, theta=7.339484 -> V=1.0, theta=0.0
% INFO    : Bus 59234	: V=0.9909887, theta=7.241192 -> V=1.0, theta=0.0
% INFO    : Bus 59235	: V=0.9904752, theta=7.216404 -> V=1.0, theta=0.0
% INFO    : Bus 59236	: V=0.9961902, theta=7.54792 -> V=1.0, theta=0.0
% INFO    : Bus 59237	: V=0.9933691, theta=7.337285 -> V=1.0, theta=0.0
% INFO    : Bus 59238	: V=1.0159544, theta=9.904388 -> V=1.0, theta=0.0
% INFO    : Bus 59239	: V=1.0171641, theta=10.25643 -> V=1.0, theta=0.0
% INFO    : Bus 59240	: V=1.0211643, theta=10.717264 -> V=1.0, theta=0.0
% INFO    : Bus 59241	: V=1.0035453, theta=9.80809 -> V=1.0, theta=0.0
% INFO    : Bus 59242	: V=1.0223355, theta=19.152248 -> V=1.0, theta=0.0
% INFO    : Bus 59243	: V=1.02411, theta=20.212754 -> V=1.0, theta=0.0
% INFO    : Bus 59244	: V=1.0268138, theta=20.371087 -> V=1.0, theta=0.0
% INFO    : Bus 59245	: V=0.9753702, theta=16.199609 -> V=1.0, theta=0.0
% INFO    : Bus 59246	: V=1.0214033, theta=20.414102 -> V=1.0, theta=0.0
% INFO    : Bus 59247	: V=1.0300005, theta=13.466947 -> V=1.0, theta=0.0
% INFO    : Bus 59248	: V=1.0498214, theta=9.284504 -> V=1.0, theta=0.0
% INFO    : Bus 59249	: V=1.0555092, theta=11.628866 -> V=1.0, theta=0.0
% INFO    : Bus 59250	: V=1.0470004, theta=9.244836 -> V=1.0, theta=0.0
% INFO    : Bus 59251	: V=1.0300006, theta=12.542108 -> V=1.0, theta=0.0
% INFO    : Bus 59252	: V=0.9941359, theta=12.046888 -> V=1.0, theta=0.0
% INFO    : Bus 59253	: V=0.9875363, theta=15.74689 -> V=1.0, theta=0.0
% INFO    : Bus 59254	: V=1.0163474, theta=12.330883 -> V=1.0, theta=0.0
% INFO    : Bus 59255	: V=1.0300006, theta=14.941256 -> V=1.0, theta=0.0
% INFO    : Bus 59256	: V=1.0300006, theta=14.920413 -> V=1.0, theta=0.0
% INFO    : Bus 59257	: V=1.0153506, theta=12.138045 -> V=1.0, theta=0.0
% INFO    : Bus 59258	: V=1.0123627, theta=12.048622 -> V=1.0, theta=0.0
% INFO    : Bus 59259	: V=1.0102007, theta=11.935389 -> V=1.0, theta=0.0
% INFO    : Bus 59260	: V=1.0143677, theta=12.115487 -> V=1.0, theta=0.0
% INFO    : Bus 59261	: V=1.0160492, theta=12.249747 -> V=1.0, theta=0.0
% INFO    : Bus 59262	: V=1.0225326, theta=13.229602 -> V=1.0, theta=0.0
% INFO    : Bus 59263	: V=1.0221078, theta=13.276334 -> V=1.0, theta=0.0
% INFO    : Bus 59264	: V=1.0139508, theta=12.094946 -> V=1.0, theta=0.0
% INFO    : Bus 59265	: V=1.0131742, theta=12.05892 -> V=1.0, theta=0.0
% INFO    : Bus 59266	: V=1.0126126, theta=12.016254 -> V=1.0, theta=0.0
% INFO    : Bus 59267	: V=1.0048905, theta=11.814548 -> V=1.0, theta=0.0
% INFO    : Bus 59268	: V=1.0128591, theta=11.993536 -> V=1.0, theta=0.0
% INFO    : Bus 59269	: V=1.0207717, theta=12.941263 -> V=1.0, theta=0.0
% INFO    : Bus 59270	: V=1.0191331, theta=12.400811 -> V=1.0, theta=0.0
% INFO    : Bus 59271	: V=1.0178685, theta=12.759592 -> V=1.0, theta=0.0
% INFO    : Bus 59272	: V=1.0341546, theta=15.558357 -> V=1.0, theta=0.0
% INFO    : Bus 59273	: V=1.0199979, theta=12.865998 -> V=1.0, theta=0.0
% INFO    : Bus 59274	: V=0.9690651, theta=9.645641 -> V=1.0, theta=0.0
% INFO    : Bus 59275	: V=0.9779708, theta=9.863035 -> V=1.0, theta=0.0
% INFO    : Bus 59276	: V=1.0162852, theta=11.260994 -> V=1.0, theta=0.0
% INFO    : Bus 59277	: V=1.0159672, theta=11.063402 -> V=1.0, theta=0.0
% INFO    : Bus 59278	: V=1.0320156, theta=11.943876 -> V=1.0, theta=0.0
% INFO    : Bus 59279	: V=1.0318919, theta=11.948662 -> V=1.0, theta=0.0
% INFO    : Bus 59280	: V=1.0005269, theta=10.44568 -> V=1.0, theta=0.0
% INFO    : Bus 59281	: V=0.9982998, theta=10.359357 -> V=1.0, theta=0.0
% INFO    : Bus 59282	: V=1.0182102, theta=11.513805 -> V=1.0, theta=0.0
% INFO    : Bus 59283	: V=1.0100006, theta=10.826716 -> V=1.0, theta=0.0
% INFO    : Bus 59284	: V=1.0216315, theta=14.779108 -> V=1.0, theta=0.0
% INFO    : Bus 59285	: V=0.9982469, theta=14.258985 -> V=1.0, theta=0.0
% INFO    : Bus 59286	: V=1.0074346, theta=20.528908 -> V=1.0, theta=0.0
% INFO    : Bus 59287	: V=1.0173389, theta=11.259117 -> V=1.0, theta=0.0
% INFO    : Bus 59288	: V=1.0069338, theta=7.830959 -> V=1.0, theta=0.0
% INFO    : Bus 59289	: V=1.0523342, theta=13.636951 -> V=1.0, theta=0.0
% INFO    : Bus 59290	: V=1.0007476, theta=10.204348 -> V=1.0, theta=0.0
% INFO    : Bus 59291	: V=0.9919971, theta=9.14863 -> V=1.0, theta=0.0
% INFO    : Bus 59292	: V=0.9873349, theta=7.818011 -> V=1.0, theta=0.0
% INFO    : Bus 59293	: V=0.9801505, theta=7.458156 -> V=1.0, theta=0.0
% INFO    : Bus 59294	: V=0.969827, theta=6.433452 -> V=1.0, theta=0.0
% INFO    : Bus 59295	: V=0.9954959, theta=8.693345 -> V=1.0, theta=0.0
% INFO    : Bus 59296	: V=0.9630998, theta=5.662896 -> V=1.0, theta=0.0
% INFO    : Bus 59297	: V=0.9981343, theta=8.386496 -> V=1.0, theta=0.0
% INFO    : Bus 59298	: V=0.946896, theta=5.052405 -> V=1.0, theta=0.0
% INFO    : Bus 59299	: V=0.9394241, theta=4.651091 -> V=1.0, theta=0.0
% INFO    : Bus 59300	: V=1.026655, theta=13.80669 -> V=1.0, theta=0.0
% INFO    : Bus 59301	: V=1.025829, theta=13.346867 -> V=1.0, theta=0.0
% INFO    : Bus 59302	: V=1.0175976, theta=13.433792 -> V=1.0, theta=0.0
% INFO    : Bus 59303	: V=1.0170226, theta=13.393122 -> V=1.0, theta=0.0
% INFO    : Bus 59304	: V=1.0196401, theta=14.297149 -> V=1.0, theta=0.0
% INFO    : Bus 59306	: V=1.0397956, theta=13.479131 -> V=1.0, theta=0.0
% INFO    : Bus 59307	: V=1.0374365, theta=12.532082 -> V=1.0, theta=0.0
% INFO    : Bus 59308	: V=1.0170861, theta=16.475936 -> V=1.0, theta=0.0
% INFO    : Bus 59309	: V=1.0153526, theta=16.238302 -> V=1.0, theta=0.0
% INFO    : Bus 59310	: V=1.014146, theta=17.846472 -> V=1.0, theta=0.0
% INFO    : Bus 59311	: V=0.9972181, theta=15.382 -> V=1.0, theta=0.0
% INFO    : Bus 59312	: V=1.0190901, theta=18.6125 -> V=1.0, theta=0.0
% INFO    : Bus 59313	: V=1.007163, theta=15.029607 -> V=1.0, theta=0.0
% INFO    : Bus 59314	: V=1.0243934, theta=13.861209 -> V=1.0, theta=0.0
% INFO    : Bus 59315	: V=0.9989678, theta=13.685474 -> V=1.0, theta=0.0
% INFO    : Bus 59316	: V=0.9873325, theta=5.852797 -> V=1.0, theta=0.0
% INFO    : Bus 59317	: V=0.9858769, theta=5.695373 -> V=1.0, theta=0.0
% INFO    : Bus 59318	: V=0.9902069, theta=5.921777 -> V=1.0, theta=0.0
% INFO    : Bus 59319	: V=0.9903979, theta=5.947978 -> V=1.0, theta=0.0
% INFO    : Bus 59320	: V=0.9890279, theta=5.867484 -> V=1.0, theta=0.0
% INFO    : Bus 59321	: V=1.0076828, theta=7.018654 -> V=1.0, theta=0.0
% INFO    : Bus 59322	: V=0.9907217, theta=5.917079 -> V=1.0, theta=0.0
% INFO    : Bus 59323	: V=1.0091778, theta=7.002364 -> V=1.0, theta=0.0
% INFO    : Bus 59324	: V=1.0375436, theta=14.500804 -> V=1.0, theta=0.0
% INFO    : Bus 59325	: V=1.0100005, theta=12.993466 -> V=1.0, theta=0.0
% INFO    : Bus 59326	: V=1.0300005, theta=13.474896 -> V=1.0, theta=0.0
% INFO    : Bus 59327	: V=1.0300005, theta=12.693168 -> V=1.0, theta=0.0
% INFO    : Bus 59328	: V=0.9921505, theta=13.025889 -> V=1.0, theta=0.0
% INFO    : Bus 59329	: V=1.0158305, theta=10.690579 -> V=1.0, theta=0.0
% INFO    : Bus 59330	: V=0.9671797, theta=13.084277 -> V=1.0, theta=0.0
% INFO    : Bus 59331	: V=0.9642632, theta=10.358289 -> V=1.0, theta=0.0
% INFO    : Bus 59332	: V=1.0389375, theta=15.684023 -> V=1.0, theta=0.0
% INFO    : Bus 59333	: V=1.0217804, theta=16.642574 -> V=1.0, theta=0.0
% INFO    : Bus 59334	: V=1.0165059, theta=14.977497 -> V=1.0, theta=0.0
% INFO    : Bus 59335	: V=1.0248691, theta=11.259623 -> V=1.0, theta=0.0
% INFO    : Bus 59336	: V=1.0226901, theta=11.381042 -> V=1.0, theta=0.0
% INFO    : Bus 59337	: V=1.0004877, theta=8.509572 -> V=1.0, theta=0.0
% INFO    : Bus 59338	: V=1.0300005, theta=13.229874 -> V=1.0, theta=0.0
% INFO    : Bus 59339	: V=1.0121455, theta=12.019011 -> V=1.0, theta=0.0
% INFO    : Bus 59340	: V=1.0073862, theta=12.332898 -> V=1.0, theta=0.0
% INFO    : Bus 59341	: V=1.0100005, theta=12.581253 -> V=1.0, theta=0.0
% INFO    : Bus 59342	: V=1.003123, theta=11.936276 -> V=1.0, theta=0.0
% INFO    : Bus 59343	: V=1.0062127, theta=12.242893 -> V=1.0, theta=0.0
% INFO    : Bus 59344	: V=1.0004433, theta=11.739249 -> V=1.0, theta=0.0
% INFO    : Bus 59345	: V=1.0060726, theta=12.257345 -> V=1.0, theta=0.0
% INFO    : Bus 59346	: V=1.0002566, theta=11.609525 -> V=1.0, theta=0.0
% INFO    : Bus 59347	: V=1.0069832, theta=12.017842 -> V=1.0, theta=0.0
% INFO    : Bus 59348	: V=1.006425, theta=12.274526 -> V=1.0, theta=0.0
% INFO    : Bus 59349	: V=1.0076574, theta=12.275023 -> V=1.0, theta=0.0
% INFO    : Bus 59350	: V=1.0082067, theta=12.302362 -> V=1.0, theta=0.0
% INFO    : Bus 59351	: V=1.0300005, theta=12.675083 -> V=1.0, theta=0.0
% INFO    : Bus 59352	: V=1.0053031, theta=12.168109 -> V=1.0, theta=0.0
% INFO    : Bus 59353	: V=1.0069985, theta=12.321673 -> V=1.0, theta=0.0
% INFO    : Bus 59354	: V=1.004551, theta=12.101435 -> V=1.0, theta=0.0
% INFO    : Bus 59355	: V=0.996251, theta=11.041721 -> V=1.0, theta=0.0
% INFO    : Bus 59356	: V=0.9948714, theta=11.013309 -> V=1.0, theta=0.0
% INFO    : Bus 59357	: V=0.9969967, theta=11.352885 -> V=1.0, theta=0.0
% INFO    : Bus 59358	: V=1.0300005, theta=12.885639 -> V=1.0, theta=0.0
% INFO    : Bus 59359	: V=1.0012765, theta=11.244177 -> V=1.0, theta=0.0
% INFO    : Bus 59360	: V=0.9905664, theta=11.683728 -> V=1.0, theta=0.0
% INFO    : Bus 59361	: V=0.9718563, theta=11.011553 -> V=1.0, theta=0.0
% INFO    : Bus 59362	: V=1.0044377, theta=12.070594 -> V=1.0, theta=0.0
% INFO    : Bus 59363	: V=1.0100005, theta=12.391489 -> V=1.0, theta=0.0
% INFO    : Bus 59364	: V=1.0037898, theta=11.964422 -> V=1.0, theta=0.0
% INFO    : Bus 59365	: V=0.991846, theta=11.087457 -> V=1.0, theta=0.0
% INFO    : Bus 59366	: V=0.9964611, theta=11.164922 -> V=1.0, theta=0.0
% INFO    : Bus 59367	: V=1.003679, theta=11.944661 -> V=1.0, theta=0.0
% INFO    : Bus 59368	: V=1.0039934, theta=11.963442 -> V=1.0, theta=0.0
% INFO    : Bus 59369	: V=1.0117572, theta=11.631629 -> V=1.0, theta=0.0
% INFO    : Bus 59370	: V=1.0115625, theta=11.618364 -> V=1.0, theta=0.0
% INFO    : Bus 59371	: V=0.9804687, theta=11.009744 -> V=1.0, theta=0.0
% INFO    : Bus 59372	: V=1.0057735, theta=11.793436 -> V=1.0, theta=0.0
% INFO    : Bus 59373	: V=1.0253442, theta=13.039547 -> V=1.0, theta=0.0
% INFO    : Bus 59374	: V=1.0234753, theta=11.7412 -> V=1.0, theta=0.0
% INFO    : Bus 59375	: V=1.024841, theta=12.952701 -> V=1.0, theta=0.0
% INFO    : Bus 59376	: V=1.0300006, theta=14.180163 -> V=1.0, theta=0.0
% INFO    : Bus 59377	: V=1.0039504, theta=9.903495 -> V=1.0, theta=0.0
% INFO    : Bus 59378	: V=0.9842893, theta=-16.578245 -> V=1.0, theta=0.0
% INFO    : Bus 59379	: V=0.9850054, theta=-16.380713 -> V=1.0, theta=0.0
% INFO    : Bus 59380	: V=0.9953365, theta=-15.174189 -> V=1.0, theta=0.0
% INFO    : Bus 59381	: V=1.0015013, theta=-14.19219 -> V=1.0, theta=0.0
% INFO    : Bus 59382	: V=1.0076444, theta=-13.511079 -> V=1.0, theta=0.0
% INFO    : Bus 59383	: V=0.9929088, theta=-15.256513 -> V=1.0, theta=0.0
% INFO    : Bus 59384	: V=0.9929014, theta=-15.578978 -> V=1.0, theta=0.0
% INFO    : Bus 59385	: V=0.9916903, theta=-15.782788 -> V=1.0, theta=0.0
% INFO    : Bus 59386	: V=0.9872233, theta=-16.32537 -> V=1.0, theta=0.0
% INFO    : Bus 59387	: V=0.9905364, theta=-15.98029 -> V=1.0, theta=0.0
% INFO    : Bus 59388	: V=1.0044186, theta=-12.124187 -> V=1.0, theta=0.0
% INFO    : Bus 59389	: V=0.9735122, theta=-17.698949 -> V=1.0, theta=0.0
% INFO    : Bus 59390	: V=0.9636139, theta=-17.148882 -> V=1.0, theta=0.0
% INFO    : Bus 59391	: V=0.9810237, theta=-18.21077 -> V=1.0, theta=0.0
% INFO    : Bus 59392	: V=0.9897198, theta=-16.106785 -> V=1.0, theta=0.0
% INFO    : Bus 59393	: V=0.9951961, theta=-14.574184 -> V=1.0, theta=0.0
% INFO    : Bus 59394	: V=0.9816824, theta=-16.758302 -> V=1.0, theta=0.0
% INFO    : Bus 59395	: V=0.9831267, theta=-16.442488 -> V=1.0, theta=0.0
% INFO    : Bus 59396	: V=0.9937491, theta=-4.07482 -> V=1.0, theta=0.0
% INFO    : Bus 59397	: V=0.9949596, theta=-3.904405 -> V=1.0, theta=0.0
% INFO    : Bus 59398	: V=0.993239, theta=-4.423757 -> V=1.0, theta=0.0
% INFO    : Bus 59399	: V=0.9934946, theta=-4.205924 -> V=1.0, theta=0.0
% INFO    : Bus 59400	: V=0.9982079, theta=-3.241787 -> V=1.0, theta=0.0
% INFO    : Bus 59401	: V=0.9846797, theta=-6.038088 -> V=1.0, theta=0.0
% INFO    : Bus 59402	: V=0.9908849, theta=-4.247004 -> V=1.0, theta=0.0
% INFO    : Bus 59403	: V=0.9920476, theta=-4.213338 -> V=1.0, theta=0.0
% INFO    : Bus 59404	: V=0.9919037, theta=-4.783047 -> V=1.0, theta=0.0
% INFO    : Bus 59405	: V=0.9925432, theta=-4.128403 -> V=1.0, theta=0.0
% INFO    : Bus 59406	: V=0.9926642, theta=-4.594215 -> V=1.0, theta=0.0
% INFO    : Bus 59407	: V=0.9936001, theta=-4.232794 -> V=1.0, theta=0.0
% INFO    : Bus 59408	: V=1.0019598, theta=-3.730835 -> V=1.0, theta=0.0
% INFO    : Bus 59409	: V=0.9940276, theta=-4.501498 -> V=1.0, theta=0.0
% INFO    : Bus 59410	: V=0.9987945, theta=-3.037809 -> V=1.0, theta=0.0
% INFO    : Bus 59411	: V=0.9968145, theta=-3.348422 -> V=1.0, theta=0.0
% INFO    : Bus 59412	: V=1.0001011, theta=-2.758171 -> V=1.0, theta=0.0
% INFO    : Bus 59413	: V=0.9965252, theta=-3.481972 -> V=1.0, theta=0.0
% INFO    : Bus 59414	: V=0.9940532, theta=-3.897817 -> V=1.0, theta=0.0
% INFO    : Bus 59415	: V=0.9930845, theta=-4.037347 -> V=1.0, theta=0.0
% INFO    : Bus 59416	: V=0.9944645, theta=-3.892112 -> V=1.0, theta=0.0
% INFO    : Bus 59417	: V=1.0002326, theta=-2.905347 -> V=1.0, theta=0.0
% INFO    : Bus 59418	: V=0.9999835, theta=-2.828643 -> V=1.0, theta=0.0
% INFO    : Bus 59419	: V=0.9979793, theta=-3.438463 -> V=1.0, theta=0.0
% INFO    : Bus 59420	: V=0.9942234, theta=-4.214863 -> V=1.0, theta=0.0
% INFO    : Bus 59421	: V=0.9953363, theta=-4.091456 -> V=1.0, theta=0.0
% INFO    : Bus 59422	: V=0.9948724, theta=-4.157172 -> V=1.0, theta=0.0
% INFO    : Bus 59423	: V=0.9966069, theta=-4.262323 -> V=1.0, theta=0.0
% INFO    : Bus 59424	: V=0.9969149, theta=-4.128863 -> V=1.0, theta=0.0
% INFO    : Bus 59425	: V=0.9970269, theta=-3.916943 -> V=1.0, theta=0.0
% INFO    : Bus 59426	: V=0.9978879, theta=-3.600338 -> V=1.0, theta=0.0
% INFO    : Bus 59427	: V=1.0045373, theta=-2.44472 -> V=1.0, theta=0.0
% INFO    : Bus 59428	: V=0.9989593, theta=-3.592424 -> V=1.0, theta=0.0
% INFO    : Bus 59429	: V=1.0200007, theta=-1.689224 -> V=1.0, theta=0.0
% INFO    : Bus 59430	: V=1.0005448, theta=-2.711382 -> V=1.0, theta=0.0
% INFO    : Bus 59431	: V=0.9989498, theta=-3.522873 -> V=1.0, theta=0.0
% INFO    : Bus 59432	: V=1.0008079, theta=-2.633519 -> V=1.0, theta=0.0
% INFO    : Bus 59433	: V=0.9974135, theta=-3.593812 -> V=1.0, theta=0.0
% INFO    : Bus 59434	: V=0.9961921, theta=-2.207686 -> V=1.0, theta=0.0
% INFO    : Bus 59435	: V=0.998159, theta=-3.727606 -> V=1.0, theta=0.0
% INFO    : Bus 59436	: V=0.9942069, theta=-3.816034 -> V=1.0, theta=0.0
% INFO    : Bus 59437	: V=1.0200007, theta=-2.350524 -> V=1.0, theta=0.0
% INFO    : Bus 59438	: V=1.0032575, theta=-3.590732 -> V=1.0, theta=0.0
% INFO    : Bus 59439	: V=0.9940668, theta=-4.513524 -> V=1.0, theta=0.0
% INFO    : Bus 59440	: V=0.9940518, theta=-4.322575 -> V=1.0, theta=0.0
% INFO    : Bus 59441	: V=1.0018971, theta=-3.667028 -> V=1.0, theta=0.0
% INFO    : Bus 59442	: V=0.9938649, theta=-4.514584 -> V=1.0, theta=0.0
% INFO    : Bus 59443	: V=0.9971565, theta=-4.236929 -> V=1.0, theta=0.0
% INFO    : Bus 59444	: V=0.9886984, theta=-5.572459 -> V=1.0, theta=0.0
% INFO    : Bus 59445	: V=0.9831256, theta=-6.425898 -> V=1.0, theta=0.0
% INFO    : Bus 59446	: V=0.9865747, theta=-6.40047 -> V=1.0, theta=0.0
% INFO    : Bus 59447	: V=0.9740185, theta=-7.437259 -> V=1.0, theta=0.0
% INFO    : Bus 59448	: V=0.9769037, theta=-7.317776 -> V=1.0, theta=0.0
% INFO    : Bus 59449	: V=0.9787513, theta=-7.338524 -> V=1.0, theta=0.0
% INFO    : Bus 59450	: V=0.9772409, theta=-7.380623 -> V=1.0, theta=0.0
% INFO    : Bus 59451	: V=0.9808261, theta=-7.189828 -> V=1.0, theta=0.0
% INFO    : Bus 59452	: V=0.9788004, theta=-7.275319 -> V=1.0, theta=0.0
% INFO    : Bus 59453	: V=0.9939445, theta=-4.010436 -> V=1.0, theta=0.0
% INFO    : Bus 59454	: V=0.9906722, theta=-4.390897 -> V=1.0, theta=0.0
% INFO    : Bus 59455	: V=0.9950934, theta=-3.232593 -> V=1.0, theta=0.0
% INFO    : Bus 59456	: V=1.0066517, theta=-0.804902 -> V=1.0, theta=0.0
% INFO    : Bus 59457	: V=1.005695, theta=-1.383812 -> V=1.0, theta=0.0
% INFO    : Bus 59458	: V=1.0068089, theta=-0.638535 -> V=1.0, theta=0.0
% INFO    : Bus 59459	: V=1.0053117, theta=-0.529784 -> V=1.0, theta=0.0
% INFO    : Bus 59460	: V=1.009481, theta=0.344299 -> V=1.0, theta=0.0
% INFO    : Bus 59461	: V=1.0087502, theta=0.413229 -> V=1.0, theta=0.0
% INFO    : Bus 59462	: V=1.0013301, theta=-1.766289 -> V=1.0, theta=0.0
% INFO    : Bus 59463	: V=1.0082925, theta=-2.841786 -> V=1.0, theta=0.0
% INFO    : Bus 59464	: V=0.9911475, theta=-5.7808 -> V=1.0, theta=0.0
% INFO    : Bus 59465	: V=0.9890493, theta=-6.930305 -> V=1.0, theta=0.0
% INFO    : Bus 59466	: V=0.9909165, theta=-6.616055 -> V=1.0, theta=0.0
% INFO    : Bus 59467	: V=0.9953996, theta=-5.404435 -> V=1.0, theta=0.0
% INFO    : Bus 59468	: V=0.9896034, theta=-3.844331 -> V=1.0, theta=0.0
% INFO    : Bus 59469	: V=1.0020842, theta=-3.824134 -> V=1.0, theta=0.0
% INFO    : Bus 59470	: V=1.0113677, theta=-2.03348 -> V=1.0, theta=0.0
% INFO    : Bus 59471	: V=1.0184478, theta=2.3064 -> V=1.0, theta=0.0
% INFO    : Bus 59472	: V=1.0200007, theta=2.70646 -> V=1.0, theta=0.0
% INFO    : Bus 59473	: V=1.0200007, theta=3.119414 -> V=1.0, theta=0.0
% INFO    : Bus 59474	: V=0.9895846, theta=-6.330247 -> V=1.0, theta=0.0
% INFO    : Bus 59475	: V=1.0110367, theta=-3.004372 -> V=1.0, theta=0.0
% INFO    : Bus 59476	: V=0.9654344, theta=-8.842915 -> V=1.0, theta=0.0
% INFO    : Bus 59477	: V=0.9667896, theta=-8.812622 -> V=1.0, theta=0.0
% INFO    : Bus 59478	: V=0.9700794, theta=-8.623997 -> V=1.0, theta=0.0
% INFO    : Bus 59479	: V=0.9864659, theta=-7.424356 -> V=1.0, theta=0.0
% INFO    : Bus 59480	: V=0.972355, theta=-8.137007 -> V=1.0, theta=0.0
% INFO    : Bus 59481	: V=0.9608411, theta=-8.600003 -> V=1.0, theta=0.0
% INFO    : Bus 59482	: V=0.9668307, theta=-8.423204 -> V=1.0, theta=0.0
% INFO    : Bus 59483	: V=0.9715496, theta=-8.058793 -> V=1.0, theta=0.0
% INFO    : Bus 59484	: V=0.968434, theta=-8.693952 -> V=1.0, theta=0.0
% INFO    : Bus 59485	: V=1.0013063, theta=-2.4069 -> V=1.0, theta=0.0
% INFO    : Bus 59486	: V=0.9680568, theta=-8.417909 -> V=1.0, theta=0.0
% INFO    : Bus 59487	: V=1.0094803, theta=-1.004688 -> V=1.0, theta=0.0
% INFO    : Bus 59488	: V=1.0098355, theta=0.452004 -> V=1.0, theta=0.0
% INFO    : Bus 59489	: V=1.010537, theta=0.31735 -> V=1.0, theta=0.0
% INFO    : Bus 59490	: V=1.0025932, theta=-1.380675 -> V=1.0, theta=0.0
% INFO    : Bus 59491	: V=0.9982648, theta=-2.028729 -> V=1.0, theta=0.0
% INFO    : Bus 59492	: V=1.0029685, theta=-1.362063 -> V=1.0, theta=0.0
% INFO    : Bus 59493	: V=1.0012044, theta=-1.551271 -> V=1.0, theta=0.0
% INFO    : Bus 59494	: V=1.001669, theta=-1.549327 -> V=1.0, theta=0.0
% INFO    : Bus 59495	: V=0.9953691, theta=-2.928769 -> V=1.0, theta=0.0
% INFO    : Bus 59496	: V=1.003143, theta=-2.835125 -> V=1.0, theta=0.0
% INFO    : Bus 59497	: V=0.9742829, theta=-35.74148 -> V=1.0, theta=0.0
% INFO    : Bus 59498	: V=0.9803254, theta=-34.516284 -> V=1.0, theta=0.0
% INFO    : Bus 59499	: V=0.9742981, theta=-36.91389 -> V=1.0, theta=0.0
% INFO    : Bus 59500	: V=0.9754224, theta=-36.870895 -> V=1.0, theta=0.0
% INFO    : Bus 59501	: V=0.9700966, theta=-37.818848 -> V=1.0, theta=0.0
% INFO    : Bus 59502	: V=0.9743609, theta=-36.920734 -> V=1.0, theta=0.0
% INFO    : Bus 59503	: V=0.9737735, theta=-37.324708 -> V=1.0, theta=0.0
% INFO    : Bus 59504	: V=0.972082, theta=-37.404033 -> V=1.0, theta=0.0
% INFO    : Bus 59505	: V=0.9826062, theta=-35.985546 -> V=1.0, theta=0.0
% INFO    : Bus 59506	: V=0.9789245, theta=-36.581609 -> V=1.0, theta=0.0
% INFO    : Bus 59507	: V=0.9777184, theta=-39.135988 -> V=1.0, theta=0.0
% INFO    : Bus 59508	: V=0.9893701, theta=-41.81703 -> V=1.0, theta=0.0
% INFO    : Bus 59509	: V=0.9836938, theta=-41.101726 -> V=1.0, theta=0.0
% INFO    : Bus 59510	: V=0.9899927, theta=-0.504873 -> V=1.0, theta=0.0
% INFO    : Bus 59511	: V=0.9844894, theta=-3.723463 -> V=1.0, theta=0.0
% INFO    : Bus 59512	: V=0.9891443, theta=-9.037862 -> V=1.0, theta=0.0
% INFO    : Bus 59513	: V=1.0150741, theta=2.924461 -> V=1.0, theta=0.0
% INFO    : Bus 59514	: V=0.9727277, theta=-46.725358 -> V=1.0, theta=0.0
% INFO    : Bus 59515	: V=0.9759532, theta=-49.641889 -> V=1.0, theta=0.0
% INFO    : Bus 59516	: V=0.9807049, theta=-51.695461 -> V=1.0, theta=0.0
% INFO    : Bus 59517	: V=0.988093, theta=-54.079703 -> V=1.0, theta=0.0
% INFO    : Bus 59518	: V=0.9865469, theta=-54.703512 -> V=1.0, theta=0.0
% INFO    : Bus 59519	: V=1.0039923, theta=-8.487603 -> V=1.0, theta=0.0
% INFO    : Bus 59520	: V=0.9869001, theta=-24.302305 -> V=1.0, theta=0.0
% INFO    : Bus 59521	: V=0.9900767, theta=-21.140032 -> V=1.0, theta=0.0
% INFO    : Bus 59522	: V=0.9920032, theta=-19.123143 -> V=1.0, theta=0.0
% INFO    : Bus 59523	: V=0.99057, theta=-20.685882 -> V=1.0, theta=0.0
% INFO    : Bus 59524	: V=0.9972199, theta=-18.344074 -> V=1.0, theta=0.0
% INFO    : Bus 59525	: V=0.99871, theta=-15.176781 -> V=1.0, theta=0.0
% INFO    : Bus 59526	: V=0.99544, theta=-10.967624 -> V=1.0, theta=0.0
% INFO    : Bus 59527	: V=0.9933353, theta=-11.277612 -> V=1.0, theta=0.0
% INFO    : Bus 59528	: V=0.9917852, theta=-11.45255 -> V=1.0, theta=0.0
% INFO    : Bus 59529	: V=0.9917603, theta=-11.855772 -> V=1.0, theta=0.0
% INFO    : Bus 59530	: V=0.9920804, theta=-13.231279 -> V=1.0, theta=0.0
% INFO    : Bus 59531	: V=0.9953993, theta=-15.809983 -> V=1.0, theta=0.0
% INFO    : Bus 59532	: V=0.99509, theta=-14.009469 -> V=1.0, theta=0.0
% INFO    : Bus 59533	: V=0.9947701, theta=-17.090363 -> V=1.0, theta=0.0
% INFO    : Bus 59534	: V=0.9936869, theta=-17.360795 -> V=1.0, theta=0.0
% INFO    : Bus 59535	: V=0.9938787, theta=-16.825736 -> V=1.0, theta=0.0
% INFO    : Bus 59536	: V=0.9938682, theta=-16.502054 -> V=1.0, theta=0.0
% INFO    : Bus 59537	: V=0.9935676, theta=-16.036173 -> V=1.0, theta=0.0
% INFO    : Bus 59538	: V=0.9940305, theta=-16.70349 -> V=1.0, theta=0.0
% INFO    : Bus 59539	: V=0.9961584, theta=-14.999044 -> V=1.0, theta=0.0
% INFO    : Bus 59540	: V=0.9956757, theta=-15.889869 -> V=1.0, theta=0.0
% INFO    : Bus 59541	: V=0.9934263, theta=-17.502403 -> V=1.0, theta=0.0
% INFO    : Bus 59542	: V=0.9934324, theta=-17.812669 -> V=1.0, theta=0.0
% INFO    : Bus 59543	: V=0.9695201, theta=-29.235244 -> V=1.0, theta=0.0
% INFO    : Bus 59544	: V=0.9838196, theta=-30.548332 -> V=1.0, theta=0.0
% INFO    : Bus 59545	: V=0.9910635, theta=-26.73639 -> V=1.0, theta=0.0
% INFO    : Bus 59546	: V=0.9902979, theta=-29.929174 -> V=1.0, theta=0.0
% INFO    : Bus 59547	: V=1.0027657, theta=-28.895928 -> V=1.0, theta=0.0
% INFO    : Bus 59548	: V=1.0031544, theta=-31.142546 -> V=1.0, theta=0.0
% INFO    : Bus 59549	: V=0.9971894, theta=-33.137529 -> V=1.0, theta=0.0
% INFO    : Bus 59550	: V=0.9774885, theta=-34.443026 -> V=1.0, theta=0.0
% INFO    : Bus 59551	: V=0.99702, theta=-33.925928 -> V=1.0, theta=0.0
% INFO    : Bus 59552	: V=1.0023369, theta=-31.575279 -> V=1.0, theta=0.0
% INFO    : Bus 59553	: V=1.0110216, theta=-38.36573 -> V=1.0, theta=0.0
% INFO    : Bus 59554	: V=0.9931209, theta=-37.83993 -> V=1.0, theta=0.0
% INFO    : Bus 59555	: V=0.9999959, theta=-34.555324 -> V=1.0, theta=0.0
% INFO    : Bus 59556	: V=0.9990349, theta=-35.121656 -> V=1.0, theta=0.0
% INFO    : Bus 59557	: V=1.0001146, theta=-34.596997 -> V=1.0, theta=0.0
% INFO    : Bus 59558	: V=1.0010075, theta=-33.647428 -> V=1.0, theta=0.0
% INFO    : Bus 59559	: V=1.0200006, theta=-28.686447 -> V=1.0, theta=0.0
% INFO    : Bus 59560	: V=0.9973041, theta=-35.60204 -> V=1.0, theta=0.0
% INFO    : Bus 59561	: V=0.9886954, theta=-41.656323 -> V=1.0, theta=0.0
% INFO    : Bus 59562	: V=0.9926519, theta=-38.136144 -> V=1.0, theta=0.0
% INFO    : Bus 59563	: V=0.9810037, theta=-35.347511 -> V=1.0, theta=0.0
% INFO    : Bus 59564	: V=0.9978137, theta=-48.349249 -> V=1.0, theta=0.0
% INFO    : Bus 59565	: V=1.0300006, theta=18.71088 -> V=1.0, theta=0.0
% INFO    : Bus 59566	: V=1.0136546, theta=4.517195 -> V=1.0, theta=0.0
% INFO    : Bus 59567	: V=0.9800265, theta=-2.708836 -> V=1.0, theta=0.0
% INFO    : Bus 59569	: V=0.9807636, theta=-33.420866 -> V=1.0, theta=0.0
% INFO    : Bus 59570	: V=1.0200007, theta=10.824267 -> V=1.0, theta=0.0
% INFO    : Bus 59571	: V=1.0200007, theta=11.046557 -> V=1.0, theta=0.0
% INFO    : Bus 59572	: V=1.0100007, theta=11.849204 -> V=1.0, theta=0.0
% INFO    : Bus 59573	: V=1.0200007, theta=11.95207 -> V=1.0, theta=0.0
% INFO    : Bus 59574	: V=1.0080378, theta=-61.576462 -> V=1.0, theta=0.0
% INFO    : Bus 59575	: V=1.0047336, theta=-61.763851 -> V=1.0, theta=0.0
% INFO    : Bus 59576	: V=1.0048712, theta=-61.741663 -> V=1.0, theta=0.0
% INFO    : Bus 59577	: V=1.0039143, theta=-61.797097 -> V=1.0, theta=0.0
% INFO    : Bus 59578	: V=1.0091731, theta=-61.459826 -> V=1.0, theta=0.0
% INFO    : Bus 59579	: V=1.0028323, theta=-61.520791 -> V=1.0, theta=0.0
% INFO    : Bus 59580	: V=1.003674, theta=-61.489403 -> V=1.0, theta=0.0
% INFO    : Bus 59581	: V=1.0037534, theta=-61.552914 -> V=1.0, theta=0.0
% INFO    : Bus 59582	: V=1.0042824, theta=-61.531466 -> V=1.0, theta=0.0
% INFO    : Bus 59583	: V=1.0046127, theta=-61.852735 -> V=1.0, theta=0.0
% INFO    : Bus 59584	: V=1.0043756, theta=-61.664735 -> V=1.0, theta=0.0
% INFO    : Bus 59585	: V=1.0041298, theta=-62.14414 -> V=1.0, theta=0.0
% INFO    : Bus 59586	: V=1.0067539, theta=-61.730948 -> V=1.0, theta=0.0
% INFO    : Bus 59587	: V=1.0002846, theta=-62.046515 -> V=1.0, theta=0.0
% INFO    : Bus 59588	: V=1.0062733, theta=-61.575914 -> V=1.0, theta=0.0
% INFO    : Bus 59589	: V=1.0208832, theta=-62.515347 -> V=1.0, theta=0.0
% INFO    : Bus 59590	: V=1.0052107, theta=-61.405308 -> V=1.0, theta=0.0
% INFO    : Bus 59591	: V=1.006611, theta=-61.290409 -> V=1.0, theta=0.0
% INFO    : Bus 59592	: V=1.004882, theta=-59.202681 -> V=1.0, theta=0.0
% INFO    : Bus 59593	: V=1.0044381, theta=-61.516956 -> V=1.0, theta=0.0
% INFO    : Bus 59594	: V=1.0067832, theta=-57.764926 -> V=1.0, theta=0.0
% INFO    : Bus 59595	: V=1.003025, theta=-61.177424 -> V=1.0, theta=0.0
% INFO    : Bus 59596	: V=1.0102805, theta=-58.082361 -> V=1.0, theta=0.0
% INFO    : Bus 59597	: V=1.0097496, theta=-61.291009 -> V=1.0, theta=0.0
% INFO    : Bus 59598	: V=1.0069434, theta=-61.715536 -> V=1.0, theta=0.0
% INFO    : Bus 59599	: V=0.9965342, theta=-62.203057 -> V=1.0, theta=0.0
% INFO    : Bus 59600	: V=1.006237, theta=-61.77012 -> V=1.0, theta=0.0
% INFO    : Bus 59601	: V=1.0058639, theta=-61.6483 -> V=1.0, theta=0.0
% INFO    : Bus 59602	: V=1.0019736, theta=-62.716108 -> V=1.0, theta=0.0
% INFO    : Bus 59603	: V=1.0058703, theta=-61.681984 -> V=1.0, theta=0.0
% INFO    : Bus 59604	: V=1.0035363, theta=-62.588591 -> V=1.0, theta=0.0
% INFO    : Bus 59605	: V=0.9998975, theta=-62.798893 -> V=1.0, theta=0.0
% INFO    : Bus 59606	: V=0.9970179, theta=-62.92136 -> V=1.0, theta=0.0
% INFO    : Bus 59607	: V=1.005925, theta=-61.735677 -> V=1.0, theta=0.0
% INFO    : Bus 59608	: V=1.0086902, theta=-62.248081 -> V=1.0, theta=0.0
% INFO    : Bus 59609	: V=1.013267, theta=-54.344589 -> V=1.0, theta=0.0
% INFO    : Bus 59610	: V=1.0130636, theta=-53.074841 -> V=1.0, theta=0.0
% INFO    : Bus 59611	: V=0.9987704, theta=-55.854008 -> V=1.0, theta=0.0
% INFO    : Bus 59612	: V=0.9876408, theta=-50.600016 -> V=1.0, theta=0.0
% INFO    : Bus 59613	: V=1.0027061, theta=-60.261554 -> V=1.0, theta=0.0
% INFO    : Bus 59614	: V=0.9908705, theta=-61.753466 -> V=1.0, theta=0.0
% INFO    : Bus 59615	: V=1.0092665, theta=-6.823892 -> V=1.0, theta=0.0
% INFO    : Bus 59616	: V=0.9930098, theta=-6.741103 -> V=1.0, theta=0.0
% INFO    : Bus 59617	: V=1.0074394, theta=-6.720378 -> V=1.0, theta=0.0
% INFO    : Bus 59618	: V=1.004131, theta=-6.849671 -> V=1.0, theta=0.0
% INFO    : Bus 59619	: V=1.0035607, theta=-9.396455 -> V=1.0, theta=0.0
% INFO    : Bus 59620	: V=1.0060479, theta=-10.143125 -> V=1.0, theta=0.0
% INFO    : Bus 59621	: V=0.9832799, theta=-47.142522 -> V=1.0, theta=0.0
% INFO    : Bus 59622	: V=0.9854157, theta=-51.04657 -> V=1.0, theta=0.0
% INFO    : Bus 59623	: V=0.9861943, theta=-49.946042 -> V=1.0, theta=0.0
% INFO    : Bus 59624	: V=0.9866988, theta=-51.732022 -> V=1.0, theta=0.0
% INFO    : Bus 59625	: V=0.9854252, theta=-49.592398 -> V=1.0, theta=0.0
% INFO    : Bus 59626	: V=0.9851955, theta=-49.447844 -> V=1.0, theta=0.0
% INFO    : Bus 59627	: V=0.9872215, theta=-51.602097 -> V=1.0, theta=0.0
% INFO    : Bus 59628	: V=0.9865166, theta=-51.613705 -> V=1.0, theta=0.0
% INFO    : Bus 59629	: V=0.9788367, theta=-53.786412 -> V=1.0, theta=0.0
% INFO    : Bus 59630	: V=0.9861742, theta=-52.291537 -> V=1.0, theta=0.0
% INFO    : Bus 59631	: V=0.9865383, theta=-51.956013 -> V=1.0, theta=0.0
% INFO    : Bus 59632	: V=0.9852482, theta=-51.683516 -> V=1.0, theta=0.0
% INFO    : Bus 59633	: V=0.9887402, theta=-53.63167 -> V=1.0, theta=0.0
% INFO    : Bus 59634	: V=0.9915455, theta=-56.361364 -> V=1.0, theta=0.0
% INFO    : Bus 59635	: V=0.985323, theta=-53.493709 -> V=1.0, theta=0.0
% INFO    : Bus 59636	: V=0.9691806, theta=-55.419977 -> V=1.0, theta=0.0
% INFO    : Bus 59637	: V=0.9853188, theta=-34.624748 -> V=1.0, theta=0.0
% INFO    : Bus 59638	: V=0.9810685, theta=-45.074409 -> V=1.0, theta=0.0
% INFO    : Bus 59639	: V=0.9853386, theta=-61.273939 -> V=1.0, theta=0.0
% INFO    : Bus 59640	: V=1.0085728, theta=-59.616464 -> V=1.0, theta=0.0
% INFO    : Bus 59641	: V=0.9684131, theta=-62.294668 -> V=1.0, theta=0.0
% INFO    : Bus 59642	: V=1.012771, theta=-62.657401 -> V=1.0, theta=0.0
% INFO    : Bus 59643	: V=1.0154957, theta=-61.503496 -> V=1.0, theta=0.0
% INFO    : Bus 59644	: V=1.017774, theta=-59.65202 -> V=1.0, theta=0.0
% INFO    : Bus 59645	: V=1.0145433, theta=-59.557952 -> V=1.0, theta=0.0
% INFO    : Bus 59646	: V=1.0119813, theta=-59.457555 -> V=1.0, theta=0.0
% INFO    : Bus 59647	: V=1.0112638, theta=-60.155345 -> V=1.0, theta=0.0
% INFO    : Bus 59648	: V=1.0155319, theta=-59.901961 -> V=1.0, theta=0.0
% INFO    : Bus 59649	: V=1.0125891, theta=-60.31434 -> V=1.0, theta=0.0
% INFO    : Bus 59650	: V=1.011445, theta=-60.356503 -> V=1.0, theta=0.0
% INFO    : Bus 59651	: V=1.0296881, theta=-59.804011 -> V=1.0, theta=0.0
% INFO    : Bus 59652	: V=1.0163629, theta=-59.871264 -> V=1.0, theta=0.0
% INFO    : Bus 59653	: V=1.0149286, theta=-59.742459 -> V=1.0, theta=0.0
% INFO    : Bus 59654	: V=1.0152932, theta=-59.075 -> V=1.0, theta=0.0
% INFO    : Bus 59655	: V=1.0154515, theta=-59.568351 -> V=1.0, theta=0.0
% INFO    : Bus 59656	: V=1.0115222, theta=-58.275197 -> V=1.0, theta=0.0
% INFO    : Bus 59657	: V=0.9748964, theta=-44.681581 -> V=1.0, theta=0.0
% INFO    : Bus 59658	: V=0.9702915, theta=-54.820755 -> V=1.0, theta=0.0
% INFO    : Bus 59659	: V=1.0190079, theta=-17.715745 -> V=1.0, theta=0.0
% INFO    : Bus 59660	: V=1.0114564, theta=-17.799868 -> V=1.0, theta=0.0
% INFO    : Bus 59661	: V=0.9900075, theta=-20.684257 -> V=1.0, theta=0.0
% INFO    : Bus 59662	: V=0.9974342, theta=-18.952902 -> V=1.0, theta=0.0
% INFO    : Bus 59663	: V=1.0036005, theta=-17.217929 -> V=1.0, theta=0.0
% INFO    : Bus 59664	: V=0.997892, theta=-19.036198 -> V=1.0, theta=0.0
% INFO    : Bus 59665	: V=0.9681371, theta=-21.811831 -> V=1.0, theta=0.0
% INFO    : Bus 59666	: V=0.9573502, theta=-28.131899 -> V=1.0, theta=0.0
% INFO    : Bus 59667	: V=0.9638659, theta=-27.843494 -> V=1.0, theta=0.0
% INFO    : Bus 59668	: V=0.9638159, theta=-26.998775 -> V=1.0, theta=0.0
% INFO    : Bus 59669	: V=0.9638658, theta=-27.728788 -> V=1.0, theta=0.0
% INFO    : Bus 59670	: V=0.9595125, theta=-23.199786 -> V=1.0, theta=0.0
% INFO    : Bus 59671	: V=0.9922367, theta=-23.437797 -> V=1.0, theta=0.0
% INFO    : Bus 59672	: V=0.9795825, theta=-21.293195 -> V=1.0, theta=0.0
% INFO    : Bus 59673	: V=0.9966908, theta=-21.346909 -> V=1.0, theta=0.0
% INFO    : Bus 59674	: V=0.9950175, theta=-22.013859 -> V=1.0, theta=0.0
% INFO    : Bus 59675	: V=0.9947596, theta=-19.814489 -> V=1.0, theta=0.0
% INFO    : Bus 59676	: V=1.0033697, theta=-18.560338 -> V=1.0, theta=0.0
% INFO    : Bus 59677	: V=0.9988109, theta=-21.686572 -> V=1.0, theta=0.0
% INFO    : Bus 59678	: V=1.0003701, theta=-22.870422 -> V=1.0, theta=0.0
% INFO    : Bus 59679	: V=0.9994739, theta=-23.241962 -> V=1.0, theta=0.0
% INFO    : Bus 59680	: V=0.9995486, theta=-23.47729 -> V=1.0, theta=0.0
% INFO    : Bus 59681	: V=1.0070071, theta=-23.320605 -> V=1.0, theta=0.0
% INFO    : Bus 59682	: V=1.005353, theta=-24.190603 -> V=1.0, theta=0.0
% INFO    : Bus 59683	: V=1.0035679, theta=-25.423167 -> V=1.0, theta=0.0
% INFO    : Bus 59684	: V=0.9951456, theta=-28.757054 -> V=1.0, theta=0.0
% INFO    : Bus 59685	: V=1.0163838, theta=-19.637723 -> V=1.0, theta=0.0
% INFO    : Bus 59686	: V=1.012439, theta=-19.707922 -> V=1.0, theta=0.0
% INFO    : Bus 59687	: V=1.0120985, theta=-19.04086 -> V=1.0, theta=0.0
% INFO    : Bus 59688	: V=1.0074052, theta=-20.195557 -> V=1.0, theta=0.0
% INFO    : Bus 59689	: V=1.0124209, theta=-18.917788 -> V=1.0, theta=0.0
% INFO    : Bus 59690	: V=1.0024157, theta=-20.397266 -> V=1.0, theta=0.0
% INFO    : Bus 59691	: V=1.0136534, theta=-19.070554 -> V=1.0, theta=0.0
% INFO    : Bus 59692	: V=1.0129175, theta=-19.087464 -> V=1.0, theta=0.0
% INFO    : Bus 59693	: V=0.9980019, theta=-20.491449 -> V=1.0, theta=0.0
% INFO    : Bus 59694	: V=0.9978276, theta=-20.537108 -> V=1.0, theta=0.0
% INFO    : Bus 59695	: V=0.991368, theta=-20.293627 -> V=1.0, theta=0.0
% INFO    : Bus 59696	: V=0.9964975, theta=-20.504777 -> V=1.0, theta=0.0
% INFO    : Bus 59697	: V=0.9959169, theta=-20.213937 -> V=1.0, theta=0.0
% INFO    : Bus 59698	: V=0.9956444, theta=-20.400022 -> V=1.0, theta=0.0
% INFO    : Bus 59699	: V=0.9959207, theta=-20.10429 -> V=1.0, theta=0.0
% INFO    : Bus 59700	: V=0.9945415, theta=-20.015215 -> V=1.0, theta=0.0
% INFO    : Bus 59701	: V=0.9948598, theta=-19.86485 -> V=1.0, theta=0.0
% INFO    : Bus 59702	: V=0.9961921, theta=-19.825848 -> V=1.0, theta=0.0
% INFO    : Bus 59703	: V=0.9962189, theta=-19.966636 -> V=1.0, theta=0.0
% INFO    : Bus 59704	: V=0.9976304, theta=-19.843881 -> V=1.0, theta=0.0
% INFO    : Bus 59705	: V=0.9988641, theta=-19.891058 -> V=1.0, theta=0.0
% INFO    : Bus 59706	: V=1.004997, theta=-18.1587 -> V=1.0, theta=0.0
% INFO    : Bus 59707	: V=0.9992848, theta=-19.787233 -> V=1.0, theta=0.0
% INFO    : Bus 59708	: V=0.997839, theta=-19.886614 -> V=1.0, theta=0.0
% INFO    : Bus 59709	: V=0.9977642, theta=-19.917609 -> V=1.0, theta=0.0
% INFO    : Bus 59710	: V=0.9958127, theta=-20.193294 -> V=1.0, theta=0.0
% INFO    : Bus 59711	: V=0.9975782, theta=-20.09713 -> V=1.0, theta=0.0
% INFO    : Bus 59712	: V=0.9980271, theta=-20.085693 -> V=1.0, theta=0.0
% INFO    : Bus 59713	: V=0.9968603, theta=-20.162903 -> V=1.0, theta=0.0
% INFO    : Bus 59714	: V=0.9929722, theta=-20.256203 -> V=1.0, theta=0.0
% INFO    : Bus 59715	: V=0.9985956, theta=-20.439387 -> V=1.0, theta=0.0
% INFO    : Bus 59716	: V=0.9987704, theta=-20.496962 -> V=1.0, theta=0.0
% INFO    : Bus 59717	: V=0.9990146, theta=-20.510118 -> V=1.0, theta=0.0
% INFO    : Bus 59718	: V=0.9988045, theta=-20.524315 -> V=1.0, theta=0.0
% INFO    : Bus 59719	: V=0.999676, theta=-20.501705 -> V=1.0, theta=0.0
% INFO    : Bus 59720	: V=1.0013525, theta=-20.415563 -> V=1.0, theta=0.0
% INFO    : Bus 59721	: V=1.0110891, theta=-19.043745 -> V=1.0, theta=0.0
% INFO    : Bus 59722	: V=1.0009407, theta=-20.463918 -> V=1.0, theta=0.0
% INFO    : Bus 59723	: V=0.9965248, theta=-20.395616 -> V=1.0, theta=0.0
% INFO    : Bus 59724	: V=0.9980254, theta=-20.338157 -> V=1.0, theta=0.0
% INFO    : Bus 59725	: V=0.9991963, theta=-20.269061 -> V=1.0, theta=0.0
% INFO    : Bus 59726	: V=0.9995894, theta=-20.147305 -> V=1.0, theta=0.0
% INFO    : Bus 59727	: V=0.9989722, theta=-19.915598 -> V=1.0, theta=0.0
% INFO    : Bus 59728	: V=1.0050823, theta=-18.220157 -> V=1.0, theta=0.0
% INFO    : Bus 59729	: V=1.0200006, theta=-13.708759 -> V=1.0, theta=0.0
% INFO    : Bus 59730	: V=1.0012732, theta=-19.661632 -> V=1.0, theta=0.0
% INFO    : Bus 59731	: V=1.0064101, theta=-18.33701 -> V=1.0, theta=0.0
% INFO    : Bus 59732	: V=1.0006576, theta=-19.831085 -> V=1.0, theta=0.0
% INFO    : Bus 59733	: V=1.0007352, theta=-19.777448 -> V=1.0, theta=0.0
% INFO    : Bus 59734	: V=0.9988542, theta=-20.235842 -> V=1.0, theta=0.0
% INFO    : Bus 59735	: V=0.999592, theta=-20.215496 -> V=1.0, theta=0.0
% INFO    : Bus 59736	: V=0.9984486, theta=-20.244936 -> V=1.0, theta=0.0
% INFO    : Bus 59737	: V=0.9998912, theta=-20.149724 -> V=1.0, theta=0.0
% INFO    : Bus 59738	: V=0.9969234, theta=-20.361819 -> V=1.0, theta=0.0
% INFO    : Bus 59739	: V=0.9954974, theta=-20.421244 -> V=1.0, theta=0.0
% INFO    : Bus 59740	: V=1.0003302, theta=-20.375208 -> V=1.0, theta=0.0
% INFO    : Bus 59741	: V=1.0001595, theta=-20.287846 -> V=1.0, theta=0.0
% INFO    : Bus 59742	: V=0.9997469, theta=-20.012306 -> V=1.0, theta=0.0
% INFO    : Bus 59743	: V=1.0001293, theta=-20.003177 -> V=1.0, theta=0.0
% INFO    : Bus 59744	: V=0.9983607, theta=-20.339182 -> V=1.0, theta=0.0
% INFO    : Bus 59745	: V=0.9524546, theta=-16.447823 -> V=1.0, theta=0.0
% INFO    : Bus 59746	: V=0.9606678, theta=-15.318633 -> V=1.0, theta=0.0
% INFO    : Bus 59747	: V=0.9597415, theta=-15.762724 -> V=1.0, theta=0.0
% INFO    : Bus 59748	: V=0.9595776, theta=-16.156176 -> V=1.0, theta=0.0
% INFO    : Bus 59749	: V=0.9541395, theta=-16.422909 -> V=1.0, theta=0.0
% INFO    : Bus 59750	: V=0.9664613, theta=-17.737863 -> V=1.0, theta=0.0
% INFO    : Bus 59751	: V=0.9647495, theta=-18.373525 -> V=1.0, theta=0.0
% INFO    : Bus 59752	: V=0.9661081, theta=-18.686907 -> V=1.0, theta=0.0
% INFO    : Bus 59753	: V=0.9654937, theta=-18.72184 -> V=1.0, theta=0.0
% INFO    : Bus 59754	: V=0.9662493, theta=-18.718857 -> V=1.0, theta=0.0
% INFO    : Bus 59755	: V=0.9716685, theta=-19.574724 -> V=1.0, theta=0.0
% INFO    : Bus 59756	: V=0.9726565, theta=-16.59683 -> V=1.0, theta=0.0
% INFO    : Bus 59757	: V=0.9696415, theta=-18.819444 -> V=1.0, theta=0.0
% INFO    : Bus 59758	: V=0.9703861, theta=-20.820532 -> V=1.0, theta=0.0
% INFO    : Bus 59759	: V=0.9701048, theta=-21.549415 -> V=1.0, theta=0.0
% INFO    : Bus 59760	: V=0.9676239, theta=-22.813581 -> V=1.0, theta=0.0
% INFO    : Bus 59761	: V=0.972563, theta=-19.059231 -> V=1.0, theta=0.0
% INFO    : Bus 59762	: V=0.9701275, theta=-21.56269 -> V=1.0, theta=0.0
% INFO    : Bus 59763	: V=1.0300006, theta=-7.118465 -> V=1.0, theta=0.0
% INFO    : Bus 59764	: V=1.0051363, theta=-13.04107 -> V=1.0, theta=0.0
% INFO    : Bus 59765	: V=1.0074311, theta=-12.962819 -> V=1.0, theta=0.0
% INFO    : Bus 59766	: V=1.0128783, theta=-11.929058 -> V=1.0, theta=0.0
% INFO    : Bus 59767	: V=1.0094383, theta=-12.558805 -> V=1.0, theta=0.0
% INFO    : Bus 59768	: V=1.0030099, theta=-13.089465 -> V=1.0, theta=0.0
% INFO    : Bus 59769	: V=1.0057684, theta=-13.034306 -> V=1.0, theta=0.0
% INFO    : Bus 59770	: V=1.0121124, theta=-12.139546 -> V=1.0, theta=0.0
% INFO    : Bus 59771	: V=1.0165019, theta=-10.718777 -> V=1.0, theta=0.0
% INFO    : Bus 59772	: V=0.9929754, theta=-13.245826 -> V=1.0, theta=0.0
% INFO    : Bus 59773	: V=1.0302433, theta=-6.81404 -> V=1.0, theta=0.0
% INFO    : Bus 59774	: V=1.0155278, theta=-15.740811 -> V=1.0, theta=0.0
% INFO    : Bus 59775	: V=0.9962949, theta=-15.249939 -> V=1.0, theta=0.0
% INFO    : Bus 59776	: V=1.010907, theta=-15.73947 -> V=1.0, theta=0.0
% INFO    : Bus 59777	: V=0.9782983, theta=-15.833204 -> V=1.0, theta=0.0
% INFO    : Bus 59778	: V=1.0058924, theta=-15.783162 -> V=1.0, theta=0.0
% INFO    : Bus 59779	: V=1.002375, theta=-13.226366 -> V=1.0, theta=0.0
% INFO    : Bus 59780	: V=1.0084889, theta=-11.996069 -> V=1.0, theta=0.0
% INFO    : Bus 59781	: V=0.9967738, theta=-14.849636 -> V=1.0, theta=0.0
% INFO    : Bus 59782	: V=0.9977243, theta=-14.599804 -> V=1.0, theta=0.0
% INFO    : Bus 59783	: V=0.9976605, theta=-14.745897 -> V=1.0, theta=0.0
% INFO    : Bus 59784	: V=1.0042021, theta=4.267669 -> V=1.0, theta=0.0
% INFO    : Bus 59785	: V=1.009819, theta=4.428195 -> V=1.0, theta=0.0
% INFO    : Bus 59786	: V=1.0184041, theta=6.524802 -> V=1.0, theta=0.0
% INFO    : Bus 59787	: V=1.0171756, theta=6.295516 -> V=1.0, theta=0.0
% INFO    : Bus 59788	: V=0.9864884, theta=3.295422 -> V=1.0, theta=0.0
% INFO    : Bus 59789	: V=0.993345, theta=0.986432 -> V=1.0, theta=0.0
% INFO    : Bus 59790	: V=1.000033, theta=3.085993 -> V=1.0, theta=0.0
% INFO    : Bus 59791	: V=0.9664737, theta=-12.553835 -> V=1.0, theta=0.0
% INFO    : Bus 59792	: V=0.9673785, theta=-12.662996 -> V=1.0, theta=0.0
% INFO    : Bus 59793	: V=0.9674122, theta=-12.405725 -> V=1.0, theta=0.0
% INFO    : Bus 59794	: V=0.9664293, theta=-13.573079 -> V=1.0, theta=0.0
% INFO    : Bus 59795	: V=0.966177, theta=-13.530797 -> V=1.0, theta=0.0
% INFO    : Bus 59796	: V=0.9674073, theta=-12.834986 -> V=1.0, theta=0.0
% INFO    : Bus 59797	: V=0.9680736, theta=-13.095474 -> V=1.0, theta=0.0
% INFO    : Bus 59798	: V=0.9666449, theta=-13.835205 -> V=1.0, theta=0.0
% INFO    : Bus 59799	: V=0.9695633, theta=-13.310458 -> V=1.0, theta=0.0
% INFO    : Bus 59800	: V=0.9652537, theta=-14.361033 -> V=1.0, theta=0.0
% INFO    : Bus 59801	: V=0.9668057, theta=-14.014507 -> V=1.0, theta=0.0
% INFO    : Bus 59802	: V=0.9639139, theta=-14.238736 -> V=1.0, theta=0.0
% INFO    : Bus 59803	: V=0.9639201, theta=-12.980917 -> V=1.0, theta=0.0
% INFO    : Bus 59804	: V=0.9636518, theta=-13.020695 -> V=1.0, theta=0.0
% INFO    : Bus 59805	: V=0.9681304, theta=-11.984372 -> V=1.0, theta=0.0
% INFO    : Bus 59806	: V=0.9678296, theta=-12.137314 -> V=1.0, theta=0.0
% INFO    : Bus 59807	: V=0.9675544, theta=-12.297298 -> V=1.0, theta=0.0
% INFO    : Bus 59808	: V=0.9648127, theta=-13.375098 -> V=1.0, theta=0.0
% INFO    : Bus 59809	: V=0.9685672, theta=-12.627676 -> V=1.0, theta=0.0
% INFO    : Bus 59810	: V=0.9695441, theta=-12.339524 -> V=1.0, theta=0.0
% INFO    : Bus 59811	: V=0.9681184, theta=-12.786189 -> V=1.0, theta=0.0
% INFO    : Bus 59812	: V=0.9677531, theta=-12.986689 -> V=1.0, theta=0.0
% INFO    : Bus 59813	: V=0.9678897, theta=-12.929744 -> V=1.0, theta=0.0
% INFO    : Bus 59814	: V=0.9684295, theta=-13.817811 -> V=1.0, theta=0.0
% INFO    : Bus 59815	: V=0.96801, theta=-13.995243 -> V=1.0, theta=0.0
% INFO    : Bus 59816	: V=0.9687338, theta=-13.904412 -> V=1.0, theta=0.0
% INFO    : Bus 59817	: V=0.968375, theta=-14.149251 -> V=1.0, theta=0.0
% INFO    : Bus 59818	: V=0.9592529, theta=-14.910659 -> V=1.0, theta=0.0
% INFO    : Bus 59819	: V=0.964246, theta=-14.396561 -> V=1.0, theta=0.0
% INFO    : Bus 59820	: V=0.9623656, theta=-14.74737 -> V=1.0, theta=0.0
% INFO    : Bus 59821	: V=0.9634991, theta=-14.414032 -> V=1.0, theta=0.0
% INFO    : Bus 59822	: V=0.9627911, theta=-14.640603 -> V=1.0, theta=0.0
% INFO    : Bus 59823	: V=0.9614042, theta=-14.82783 -> V=1.0, theta=0.0
% INFO    : Bus 59824	: V=0.9624431, theta=-14.78726 -> V=1.0, theta=0.0
% INFO    : Bus 59825	: V=0.9604138, theta=-14.866969 -> V=1.0, theta=0.0
% INFO    : Bus 59826	: V=0.9602545, theta=-14.739669 -> V=1.0, theta=0.0
% INFO    : Bus 59827	: V=0.9686075, theta=-11.802518 -> V=1.0, theta=0.0
% INFO    : Bus 59828	: V=0.9699755, theta=-11.213959 -> V=1.0, theta=0.0
% INFO    : Bus 59829	: V=0.9722494, theta=-11.600395 -> V=1.0, theta=0.0
% INFO    : Bus 59830	: V=0.9752032, theta=-13.378343 -> V=1.0, theta=0.0
% INFO    : Bus 59831	: V=0.957741, theta=-14.972275 -> V=1.0, theta=0.0
% INFO    : Bus 59832	: V=0.9793331, theta=-9.606718 -> V=1.0, theta=0.0
% INFO    : Bus 59833	: V=0.9800564, theta=-7.865675 -> V=1.0, theta=0.0
% INFO    : Bus 59834	: V=0.978631, theta=-8.332374 -> V=1.0, theta=0.0
% INFO    : Bus 59835	: V=0.9732005, theta=-9.730741 -> V=1.0, theta=0.0
% INFO    : Bus 59836	: V=0.974496, theta=-9.235907 -> V=1.0, theta=0.0
% INFO    : Bus 59837	: V=0.9758953, theta=-8.911314 -> V=1.0, theta=0.0
% INFO    : Bus 59838	: V=0.9740302, theta=-9.35508 -> V=1.0, theta=0.0
% INFO    : Bus 59839	: V=0.9748265, theta=-9.164038 -> V=1.0, theta=0.0
% INFO    : Bus 59840	: V=0.9826076, theta=-8.881146 -> V=1.0, theta=0.0
% INFO    : Bus 59841	: V=0.99418, theta=-10.316338 -> V=1.0, theta=0.0
% INFO    : Bus 59842	: V=0.9789481, theta=-10.425359 -> V=1.0, theta=0.0
% INFO    : Bus 59843	: V=0.9764657, theta=-10.59821 -> V=1.0, theta=0.0
% INFO    : Bus 59844	: V=1.0186593, theta=-5.021522 -> V=1.0, theta=0.0
% INFO    : Bus 59845	: V=0.9862995, theta=-13.2834 -> V=1.0, theta=0.0
% INFO    : Bus 59846	: V=0.9873481, theta=-13.057589 -> V=1.0, theta=0.0
% INFO    : Bus 59847	: V=0.9884828, theta=-13.245003 -> V=1.0, theta=0.0
% INFO    : Bus 59848	: V=0.991026, theta=-13.132098 -> V=1.0, theta=0.0
% INFO    : Bus 59849	: V=1.0100006, theta=23.730777 -> V=1.0, theta=0.0
% INFO    : Bus 59850	: V=1.0300006, theta=24.160579 -> V=1.0, theta=0.0
% INFO    : Bus 59851	: V=0.9978396, theta=-3.331233 -> V=1.0, theta=0.0
% INFO    : Bus 59852	: V=1.0018216, theta=-2.375843 -> V=1.0, theta=0.0
% INFO    : Bus 59853	: V=1.0020805, theta=-2.282238 -> V=1.0, theta=0.0
% INFO    : Bus 59854	: V=1.0003011, theta=-2.646469 -> V=1.0, theta=0.0
% INFO    : Bus 59855	: V=1.0009471, theta=-2.531619 -> V=1.0, theta=0.0
% INFO    : Bus 59856	: V=0.999408, theta=-2.845693 -> V=1.0, theta=0.0
% INFO    : Bus 59857	: V=0.9993893, theta=-2.892361 -> V=1.0, theta=0.0
% INFO    : Bus 59858	: V=1.0018512, theta=-2.176493 -> V=1.0, theta=0.0
% INFO    : Bus 59859	: V=0.9989536, theta=-2.394501 -> V=1.0, theta=0.0
% INFO    : Bus 59860	: V=0.9993935, theta=-3.075228 -> V=1.0, theta=0.0
% INFO    : Bus 59861	: V=1.0006552, theta=-2.423171 -> V=1.0, theta=0.0
% INFO    : Bus 59862	: V=1.0001617, theta=-2.505828 -> V=1.0, theta=0.0
% INFO    : Bus 59863	: V=1.0019937, theta=-2.260184 -> V=1.0, theta=0.0
% INFO    : Bus 59864	: V=1.001547, theta=-2.376951 -> V=1.0, theta=0.0
% INFO    : Bus 59865	: V=1.0027322, theta=-2.125426 -> V=1.0, theta=0.0
% INFO    : Bus 59866	: V=1.0024453, theta=-2.196707 -> V=1.0, theta=0.0
% INFO    : Bus 59867	: V=0.9992428, theta=-3.03661 -> V=1.0, theta=0.0
% INFO    : Bus 59868	: V=1.0039642, theta=-2.079478 -> V=1.0, theta=0.0
% INFO    : Bus 59869	: V=0.9993388, theta=-2.88117 -> V=1.0, theta=0.0
% INFO    : Bus 59870	: V=1.0038154, theta=-2.019193 -> V=1.0, theta=0.0
% INFO    : Bus 59871	: V=1.0003219, theta=-2.950581 -> V=1.0, theta=0.0
% INFO    : Bus 59872	: V=1.0034521, theta=-2.027293 -> V=1.0, theta=0.0
% INFO    : Bus 59873	: V=1.0030779, theta=-2.078172 -> V=1.0, theta=0.0
% INFO    : Bus 59874	: V=1.002817, theta=-2.068391 -> V=1.0, theta=0.0
% INFO    : Bus 59875	: V=1.0031158, theta=-2.01716 -> V=1.0, theta=0.0
% INFO    : Bus 59876	: V=1.0041424, theta=-1.803532 -> V=1.0, theta=0.0
% INFO    : Bus 59877	: V=1.0020447, theta=-2.098021 -> V=1.0, theta=0.0
% INFO    : Bus 59878	: V=1.0051275, theta=-1.595035 -> V=1.0, theta=0.0
% INFO    : Bus 59879	: V=1.0016939, theta=-2.143961 -> V=1.0, theta=0.0
% INFO    : Bus 59880	: V=1.0038129, theta=-1.903708 -> V=1.0, theta=0.0
% INFO    : Bus 59881	: V=1.0034905, theta=-1.95627 -> V=1.0, theta=0.0
% INFO    : Bus 59882	: V=1.0013967, theta=-2.377258 -> V=1.0, theta=0.0
% INFO    : Bus 59883	: V=1.0042127, theta=-1.926488 -> V=1.0, theta=0.0
% INFO    : Bus 59884	: V=1.000947, theta=-2.598093 -> V=1.0, theta=0.0
% INFO    : Bus 59885	: V=1.0070641, theta=-1.67171 -> V=1.0, theta=0.0
% INFO    : Bus 59886	: V=1.0100007, theta=-0.91691 -> V=1.0, theta=0.0
% INFO    : Bus 59887	: V=1.0031957, theta=-2.142175 -> V=1.0, theta=0.0
% INFO    : Bus 59888	: V=1.0032844, theta=-2.177312 -> V=1.0, theta=0.0
% INFO    : Bus 59889	: V=1.0052465, theta=-1.721614 -> V=1.0, theta=0.0
% INFO    : Bus 59890	: V=1.0047676, theta=-1.816336 -> V=1.0, theta=0.0
% INFO    : Bus 59891	: V=1.0037782, theta=-2.027943 -> V=1.0, theta=0.0
% INFO    : Bus 59892	: V=1.0038169, theta=-2.037658 -> V=1.0, theta=0.0
% INFO    : Bus 59893	: V=1.0023225, theta=-2.26356 -> V=1.0, theta=0.0
% INFO    : Bus 59894	: V=1.0052189, theta=-1.6364 -> V=1.0, theta=0.0
% INFO    : Bus 59895	: V=1.0043881, theta=-1.794295 -> V=1.0, theta=0.0
% INFO    : Bus 59896	: V=1.0063092, theta=-1.425276 -> V=1.0, theta=0.0
% INFO    : Bus 59897	: V=1.0061175, theta=-1.398582 -> V=1.0, theta=0.0
% INFO    : Bus 59898	: V=1.0065338, theta=-1.308789 -> V=1.0, theta=0.0
% INFO    : Bus 59899	: V=1.0044137, theta=-1.882092 -> V=1.0, theta=0.0
% INFO    : Bus 59900	: V=1.0043439, theta=-1.834369 -> V=1.0, theta=0.0
% INFO    : Bus 59901	: V=1.0047851, theta=-1.779447 -> V=1.0, theta=0.0
% INFO    : Bus 59902	: V=1.0053858, theta=-1.74015 -> V=1.0, theta=0.0
% INFO    : Bus 59903	: V=1.0051668, theta=-1.729212 -> V=1.0, theta=0.0
% INFO    : Bus 59904	: V=1.0087273, theta=-1.42294 -> V=1.0, theta=0.0
% INFO    : Bus 59905	: V=1.0078913, theta=-1.542779 -> V=1.0, theta=0.0
% INFO    : Bus 59906	: V=1.0080462, theta=-1.358312 -> V=1.0, theta=0.0
% INFO    : Bus 59907	: V=1.0077276, theta=-1.500347 -> V=1.0, theta=0.0
% INFO    : Bus 59908	: V=1.0200007, theta=-0.046333 -> V=1.0, theta=0.0
% INFO    : Bus 59909	: V=1.0093237, theta=-1.26927 -> V=1.0, theta=0.0
% INFO    : Bus 59910	: V=1.008905, theta=-1.246892 -> V=1.0, theta=0.0
% INFO    : Bus 59911	: V=1.0200007, theta=-0.015284 -> V=1.0, theta=0.0
% INFO    : Bus 59912	: V=1.0091808, theta=-1.365181 -> V=1.0, theta=0.0
% INFO    : Bus 59913	: V=1.0100007, theta=-0.435671 -> V=1.0, theta=0.0
% INFO    : Bus 59914	: V=1.0198205, theta=0.023604 -> V=1.0, theta=0.0
% INFO    : Bus 59915	: V=1.0084288, theta=-1.288491 -> V=1.0, theta=0.0
% INFO    : Bus 59916	: V=1.0200007, theta=0.13854 -> V=1.0, theta=0.0
% INFO    : Bus 59917	: V=1.0085931, theta=-1.176973 -> V=1.0, theta=0.0
% INFO    : Bus 59918	: V=1.0208766, theta=0.265663 -> V=1.0, theta=0.0
% INFO    : Bus 59919	: V=1.0091366, theta=-1.11821 -> V=1.0, theta=0.0
% INFO    : Bus 59920	: V=1.0120398, theta=-0.952078 -> V=1.0, theta=0.0
% INFO    : Bus 59921	: V=1.0300007, theta=1.477091 -> V=1.0, theta=0.0
% INFO    : Bus 59922	: V=1.0300007, theta=1.449699 -> V=1.0, theta=0.0
% INFO    : Bus 59923	: V=1.0300007, theta=1.581588 -> V=1.0, theta=0.0
% INFO    : Bus 59924	: V=1.0200007, theta=-0.132458 -> V=1.0, theta=0.0
% INFO    : Bus 59925	: V=1.0011413, theta=-3.018916 -> V=1.0, theta=0.0
% INFO    : Bus 59926	: V=1.0006056, theta=-3.068075 -> V=1.0, theta=0.0
% INFO    : Bus 59927	: V=1.0064774, theta=-1.976557 -> V=1.0, theta=0.0
% INFO    : Bus 59928	: V=1.0012727, theta=-2.99368 -> V=1.0, theta=0.0
% INFO    : Bus 59929	: V=1.0013513, theta=-2.988121 -> V=1.0, theta=0.0
% INFO    : Bus 59930	: V=1.0057886, theta=-1.966909 -> V=1.0, theta=0.0
% INFO    : Bus 59931	: V=1.0100007, theta=-1.036258 -> V=1.0, theta=0.0
% INFO    : Bus 59932	: V=0.9999605, theta=-3.077241 -> V=1.0, theta=0.0
% INFO    : Bus 59933	: V=0.999537, theta=-3.084759 -> V=1.0, theta=0.0
% INFO    : Bus 59934	: V=1.003987, theta=-2.237989 -> V=1.0, theta=0.0
% INFO    : Bus 59935	: V=0.9996059, theta=-2.986511 -> V=1.0, theta=0.0
% INFO    : Bus 59936	: V=1.0026004, theta=-2.518366 -> V=1.0, theta=0.0
% INFO    : Bus 59937	: V=0.9979953, theta=-3.341672 -> V=1.0, theta=0.0
% INFO    : Bus 59938	: V=0.9998667, theta=-3.193297 -> V=1.0, theta=0.0
% INFO    : Bus 59939	: V=0.9974956, theta=-3.384967 -> V=1.0, theta=0.0
% INFO    : Bus 59940	: V=1.0014192, theta=-2.713685 -> V=1.0, theta=0.0
% INFO    : Bus 59941	: V=0.9973424, theta=-3.403724 -> V=1.0, theta=0.0
% INFO    : Bus 59942	: V=0.9952095, theta=-3.792972 -> V=1.0, theta=0.0
% INFO    : Bus 59943	: V=0.9950275, theta=-3.463275 -> V=1.0, theta=0.0
% INFO    : Bus 59944	: V=0.9986793, theta=-3.16433 -> V=1.0, theta=0.0
% INFO    : Bus 59945	: V=0.9984449, theta=-3.204693 -> V=1.0, theta=0.0
% INFO    : Bus 59946	: V=0.9959759, theta=-3.441377 -> V=1.0, theta=0.0
% INFO    : Bus 59947	: V=0.9994481, theta=-3.041198 -> V=1.0, theta=0.0
% INFO    : Bus 59948	: V=0.9972676, theta=-3.553619 -> V=1.0, theta=0.0
% INFO    : Bus 59949	: V=1.0000639, theta=-2.946849 -> V=1.0, theta=0.0
% INFO    : Bus 59950	: V=1.0014112, theta=-2.768264 -> V=1.0, theta=0.0
% INFO    : Bus 59951	: V=1.0006814, theta=-2.848057 -> V=1.0, theta=0.0
% INFO    : Bus 59952	: V=1.0019143, theta=-2.683405 -> V=1.0, theta=0.0
% INFO    : Bus 59953	: V=1.0025566, theta=-2.58175 -> V=1.0, theta=0.0
% INFO    : Bus 59954	: V=1.0038956, theta=-2.379958 -> V=1.0, theta=0.0
% INFO    : Bus 59955	: V=1.0105863, theta=-1.641218 -> V=1.0, theta=0.0
% INFO    : Bus 59956	: V=1.0007005, theta=-1.21737 -> V=1.0, theta=0.0
% INFO    : Bus 59957	: V=1.0091425, theta=-0.737671 -> V=1.0, theta=0.0
% INFO    : Bus 59958	: V=1.0100007, theta=-0.448576 -> V=1.0, theta=0.0
% INFO    : Bus 59959	: V=1.0300007, theta=2.762173 -> V=1.0, theta=0.0
% INFO    : Bus 59960	: V=1.0084403, theta=-1.21736 -> V=1.0, theta=0.0
% INFO    : Bus 59961	: V=1.0073794, theta=-1.370467 -> V=1.0, theta=0.0
% INFO    : Bus 59962	: V=1.007159, theta=-1.267876 -> V=1.0, theta=0.0
% INFO    : Bus 59963	: V=1.0052202, theta=-1.59679 -> V=1.0, theta=0.0
% INFO    : Bus 59964	: V=1.0068786, theta=-1.228669 -> V=1.0, theta=0.0
% INFO    : Bus 59965	: V=1.0072737, theta=-1.145462 -> V=1.0, theta=0.0
% INFO    : Bus 59966	: V=1.0054432, theta=-1.359382 -> V=1.0, theta=0.0
% INFO    : Bus 59967	: V=1.0055038, theta=-1.349853 -> V=1.0, theta=0.0
% INFO    : Bus 59968	: V=1.0051673, theta=-1.45517 -> V=1.0, theta=0.0
% INFO    : Bus 59969	: V=1.0032322, theta=-1.882049 -> V=1.0, theta=0.0
% INFO    : Bus 59970	: V=1.0042126, theta=-1.789194 -> V=1.0, theta=0.0
% INFO    : Bus 59971	: V=1.0022988, theta=-2.121858 -> V=1.0, theta=0.0
% INFO    : Bus 59972	: V=1.0028363, theta=-2.07327 -> V=1.0, theta=0.0
% INFO    : Bus 59973	: V=1.0033923, theta=-1.989446 -> V=1.0, theta=0.0
% INFO    : Bus 59974	: V=1.0034807, theta=-2.063006 -> V=1.0, theta=0.0
% INFO    : Bus 59975	: V=0.9982177, theta=-3.198808 -> V=1.0, theta=0.0
% INFO    : Bus 59976	: V=1.000513, theta=-2.639077 -> V=1.0, theta=0.0
% INFO    : Bus 59977	: V=1.0003621, theta=-2.6491 -> V=1.0, theta=0.0
% INFO    : Bus 59978	: V=0.9989192, theta=-2.141871 -> V=1.0, theta=0.0
% INFO    : Bus 59979	: V=1.0012208, theta=-2.54094 -> V=1.0, theta=0.0
% INFO    : Bus 59980	: V=1.0033855, theta=-2.015596 -> V=1.0, theta=0.0
% INFO    : Bus 59981	: V=1.0030839, theta=-1.298886 -> V=1.0, theta=0.0
% INFO    : Bus 59982	: V=1.0025121, theta=-1.619302 -> V=1.0, theta=0.0
% INFO    : Bus 59983	: V=1.0061737, theta=-1.073396 -> V=1.0, theta=0.0
% INFO    : Bus 59984	: V=1.0066939, theta=-0.90119 -> V=1.0, theta=0.0
% INFO    : Bus 59985	: V=1.0065443, theta=-0.887411 -> V=1.0, theta=0.0
% INFO    : Bus 59986	: V=1.0058416, theta=-1.308439 -> V=1.0, theta=0.0
% INFO    : Bus 59987	: V=1.0083467, theta=-0.606096 -> V=1.0, theta=0.0
% INFO    : Bus 59988	: V=1.008013, theta=-0.763054 -> V=1.0, theta=0.0
% INFO    : Bus 59989	: V=1.0076178, theta=-0.950421 -> V=1.0, theta=0.0
% INFO    : Bus 59990	: V=1.0200007, theta=1.607435 -> V=1.0, theta=0.0
% INFO    : Bus 59991	: V=1.0200007, theta=1.586637 -> V=1.0, theta=0.0
% INFO    : Bus 59992	: V=1.0113656, theta=0.857578 -> V=1.0, theta=0.0
% INFO    : Bus 59993	: V=1.0074181, theta=-0.706107 -> V=1.0, theta=0.0
% INFO    : Bus 59994	: V=1.0072106, theta=-0.723187 -> V=1.0, theta=0.0
% INFO    : Bus 59995	: V=1.0080125, theta=-0.487247 -> V=1.0, theta=0.0
% INFO    : Bus 59996	: V=1.0085763, theta=-0.289421 -> V=1.0, theta=0.0
% INFO    : Bus 59997	: V=1.0040072, theta=-0.998329 -> V=1.0, theta=0.0
% INFO    : Bus 59998	: V=1.0034874, theta=-1.152119 -> V=1.0, theta=0.0
% INFO    : Bus 59999	: V=1.0050087, theta=-0.759247 -> V=1.0, theta=0.0
% INFO    : Bus 60000	: V=1.0053475, theta=-0.617203 -> V=1.0, theta=0.0
% INFO    : Bus 60001	: V=1.0048769, theta=-0.631056 -> V=1.0, theta=0.0
% INFO    : Bus 60002	: V=1.0065786, theta=-0.470307 -> V=1.0, theta=0.0
% INFO    : Bus 60003	: V=1.0079235, theta=-0.140074 -> V=1.0, theta=0.0
% INFO    : Bus 60004	: V=1.0095904, theta=0.451203 -> V=1.0, theta=0.0
% INFO    : Bus 60005	: V=1.0065764, theta=-0.58467 -> V=1.0, theta=0.0
% INFO    : Bus 60006	: V=1.0197097, theta=1.640195 -> V=1.0, theta=0.0
% INFO    : Bus 60007	: V=1.0106397, theta=0.050363 -> V=1.0, theta=0.0
% INFO    : Bus 60008	: V=1.0112325, theta=1.422686 -> V=1.0, theta=0.0
% INFO    : Bus 60009	: V=1.0100007, theta=1.311571 -> V=1.0, theta=0.0
% INFO    : Bus 60010	: V=1.0094468, theta=0.328703 -> V=1.0, theta=0.0
% INFO    : Bus 60011	: V=1.0088436, theta=0.226249 -> V=1.0, theta=0.0
% INFO    : Bus 60012	: V=1.0123132, theta=0.896553 -> V=1.0, theta=0.0
% INFO    : Bus 60013	: V=1.0102723, theta=0.596914 -> V=1.0, theta=0.0
% INFO    : Bus 60014	: V=1.0094397, theta=0.326875 -> V=1.0, theta=0.0
% INFO    : Bus 60015	: V=1.0086237, theta=0.146318 -> V=1.0, theta=0.0
% INFO    : Bus 60016	: V=1.005815, theta=-0.255798 -> V=1.0, theta=0.0
% INFO    : Bus 60017	: V=1.0081618, theta=0.032308 -> V=1.0, theta=0.0
% INFO    : Bus 60018	: V=1.0091046, theta=0.286545 -> V=1.0, theta=0.0
% INFO    : Bus 60019	: V=1.0167947, theta=4.219249 -> V=1.0, theta=0.0
% INFO    : Bus 60020	: V=1.0043939, theta=-2.122199 -> V=1.0, theta=0.0
% INFO    : Bus 60021	: V=1.0200007, theta=-0.00768 -> V=1.0, theta=0.0
% INFO    : Bus 60022	: V=0.9654526, theta=-13.987579 -> V=1.0, theta=0.0
% INFO    : Bus 60023	: V=0.9637841, theta=-14.120964 -> V=1.0, theta=0.0
% INFO    : Bus 60024	: V=0.9633793, theta=-13.926193 -> V=1.0, theta=0.0
% INFO    : Bus 60025	: V=0.9650652, theta=-13.494553 -> V=1.0, theta=0.0
% INFO    : Bus 60026	: V=0.9649143, theta=-13.440132 -> V=1.0, theta=0.0
% INFO    : Bus 60027	: V=0.9675261, theta=-11.764814 -> V=1.0, theta=0.0
% INFO    : Bus 60028	: V=0.9625685, theta=-13.449157 -> V=1.0, theta=0.0
% INFO    : Bus 60029	: V=0.9734022, theta=-13.650848 -> V=1.0, theta=0.0
% INFO    : Bus 60030	: V=0.9664405, theta=-13.740522 -> V=1.0, theta=0.0
% INFO    : Bus 60031	: V=0.9678945, theta=-13.771792 -> V=1.0, theta=0.0
% INFO    : Bus 60032	: V=0.9564178, theta=-13.646617 -> V=1.0, theta=0.0
% INFO    : Bus 60033	: V=0.9709855, theta=-10.964081 -> V=1.0, theta=0.0
% INFO    : Bus 60034	: V=1.0300007, theta=18.395274 -> V=1.0, theta=0.0
% INFO    : Bus 60035	: V=1.000866, theta=-6.059949 -> V=1.0, theta=0.0
% INFO    : Bus 60036	: V=0.9750761, theta=-9.538506 -> V=1.0, theta=0.0
% INFO    : Bus 60037	: V=1.0039171, theta=-6.336707 -> V=1.0, theta=0.0
% INFO    : Bus 60038	: V=1.0308221, theta=-3.456669 -> V=1.0, theta=0.0
% INFO    : Bus 60039	: V=0.9847497, theta=-8.54935 -> V=1.0, theta=0.0
% INFO    : Bus 60040	: V=0.9807877, theta=-8.640271 -> V=1.0, theta=0.0
% INFO    : Bus 60041	: V=1.000971, theta=-6.771748 -> V=1.0, theta=0.0
% INFO    : Bus 60042	: V=0.9655887, theta=-13.599736 -> V=1.0, theta=0.0
% INFO    : Bus 60043	: V=0.9943574, theta=17.271371 -> V=1.0, theta=0.0
% INFO    : Bus 60044	: V=1.0200006, theta=18.847259 -> V=1.0, theta=0.0
% INFO    : Bus 60045	: V=1.0100006, theta=20.239848 -> V=1.0, theta=0.0
% INFO    : Bus 60046	: V=1.0125215, theta=20.90116 -> V=1.0, theta=0.0
% INFO    : Bus 60047	: V=1.019392, theta=20.450756 -> V=1.0, theta=0.0
% INFO    : Bus 60048	: V=1.0158302, theta=24.074674 -> V=1.0, theta=0.0
% INFO    : Bus 60049	: V=1.0153754, theta=19.185779 -> V=1.0, theta=0.0
% INFO    : Bus 60050	: V=1.0162651, theta=19.502019 -> V=1.0, theta=0.0
% INFO    : Bus 60051	: V=1.0213712, theta=23.518805 -> V=1.0, theta=0.0
% INFO    : Bus 60052	: V=1.0214657, theta=23.798945 -> V=1.0, theta=0.0
% INFO    : Bus 60053	: V=1.0216875, theta=24.230545 -> V=1.0, theta=0.0
% INFO    : Bus 60054	: V=1.0206873, theta=24.439829 -> V=1.0, theta=0.0
% INFO    : Bus 60055	: V=1.0197691, theta=24.483182 -> V=1.0, theta=0.0
% INFO    : Bus 60056	: V=1.0072332, theta=23.034293 -> V=1.0, theta=0.0
% INFO    : Bus 60057	: V=1.0151005, theta=17.297792 -> V=1.0, theta=0.0
% INFO    : Bus 60058	: V=1.0301048, theta=15.097619 -> V=1.0, theta=0.0
% INFO    : Bus 60059	: V=1.0186745, theta=13.649915 -> V=1.0, theta=0.0
% INFO    : Bus 60060	: V=0.9967434, theta=11.845063 -> V=1.0, theta=0.0
% INFO    : Bus 60061	: V=1.0198073, theta=14.831656 -> V=1.0, theta=0.0
% INFO    : Bus 60062	: V=1.0186009, theta=14.704713 -> V=1.0, theta=0.0
% INFO    : Bus 60063	: V=1.0166938, theta=15.661789 -> V=1.0, theta=0.0
% INFO    : Bus 60064	: V=1.0178442, theta=14.623573 -> V=1.0, theta=0.0
% INFO    : Bus 60065	: V=1.0172646, theta=14.293494 -> V=1.0, theta=0.0
% INFO    : Bus 60066	: V=1.0072325, theta=12.163326 -> V=1.0, theta=0.0
% INFO    : Bus 60067	: V=0.9962041, theta=14.864782 -> V=1.0, theta=0.0
% INFO    : Bus 60068	: V=1.0324917, theta=14.070633 -> V=1.0, theta=0.0
% INFO    : Bus 60069	: V=1.0200007, theta=16.196462 -> V=1.0, theta=0.0
% INFO    : Bus 60070	: V=1.0187741, theta=15.043984 -> V=1.0, theta=0.0
% INFO    : Bus 60071	: V=1.018552, theta=14.837266 -> V=1.0, theta=0.0
% INFO    : Bus 60072	: V=1.0181647, theta=15.014091 -> V=1.0, theta=0.0
% INFO    : Bus 60073	: V=1.0300007, theta=15.37321 -> V=1.0, theta=0.0
% INFO    : Bus 60074	: V=1.0100007, theta=13.688 -> V=1.0, theta=0.0
% INFO    : Bus 60075	: V=1.0164704, theta=13.142477 -> V=1.0, theta=0.0
% INFO    : Bus 60076	: V=1.0003885, theta=5.275271 -> V=1.0, theta=0.0
% INFO    : Bus 60077	: V=1.0100007, theta=-1.843716 -> V=1.0, theta=0.0
% INFO    : Bus 60078	: V=1.0064018, theta=-2.389363 -> V=1.0, theta=0.0
% INFO    : Bus 60079	: V=1.0040411, theta=-2.731931 -> V=1.0, theta=0.0
% INFO    : Bus 60080	: V=1.0002749, theta=-2.973689 -> V=1.0, theta=0.0
% INFO    : Bus 60081	: V=1.0002571, theta=-3.134521 -> V=1.0, theta=0.0
% INFO    : Bus 60082	: V=1.0006745, theta=-2.93756 -> V=1.0, theta=0.0
% INFO    : Bus 60083	: V=1.0002378, theta=-3.106192 -> V=1.0, theta=0.0
% INFO    : Bus 60084	: V=0.9999339, theta=-3.0836 -> V=1.0, theta=0.0
% INFO    : Bus 60085	: V=0.9989408, theta=-3.207378 -> V=1.0, theta=0.0
% INFO    : Bus 60086	: V=0.998024, theta=-3.275247 -> V=1.0, theta=0.0
% INFO    : Bus 60087	: V=0.9901015, theta=-5.017719 -> V=1.0, theta=0.0
% INFO    : Bus 60088	: V=0.9888554, theta=-5.252919 -> V=1.0, theta=0.0
% INFO    : Bus 60089	: V=0.9881472, theta=-5.40479 -> V=1.0, theta=0.0
% INFO    : Bus 60090	: V=0.9920643, theta=-4.698472 -> V=1.0, theta=0.0
% INFO    : Bus 60091	: V=0.9984338, theta=-3.269447 -> V=1.0, theta=0.0
% INFO    : Bus 60092	: V=0.9994218, theta=-3.313625 -> V=1.0, theta=0.0
% INFO    : Bus 60093	: V=0.9922667, theta=-4.68471 -> V=1.0, theta=0.0
% INFO    : Bus 60094	: V=1.0008542, theta=-3.083217 -> V=1.0, theta=0.0
% INFO    : Bus 60095	: V=0.9941445, theta=-4.311846 -> V=1.0, theta=0.0
% INFO    : Bus 60096	: V=0.9951616, theta=-4.20391 -> V=1.0, theta=0.0
% INFO    : Bus 60097	: V=1.0001673, theta=-3.231961 -> V=1.0, theta=0.0
% INFO    : Bus 60098	: V=1.0026832, theta=-2.932536 -> V=1.0, theta=0.0
% INFO    : Bus 60099	: V=1.0080176, theta=-1.558024 -> V=1.0, theta=0.0
% INFO    : Bus 60100	: V=0.9985619, theta=-3.921209 -> V=1.0, theta=0.0
% INFO    : Bus 60101	: V=0.998745, theta=-3.696379 -> V=1.0, theta=0.0
% INFO    : Bus 60102	: V=0.995867, theta=-4.401584 -> V=1.0, theta=0.0
% INFO    : Bus 60103	: V=1.0046962, theta=-2.60182 -> V=1.0, theta=0.0
% INFO    : Bus 60104	: V=1.0059109, theta=-2.447474 -> V=1.0, theta=0.0
% INFO    : Bus 60105	: V=1.0074539, theta=-2.242011 -> V=1.0, theta=0.0
% INFO    : Bus 60106	: V=0.9961114, theta=-4.092457 -> V=1.0, theta=0.0
% INFO    : Bus 60107	: V=1.0036448, theta=-2.726122 -> V=1.0, theta=0.0
% INFO    : Bus 60108	: V=1.0050031, theta=-2.556987 -> V=1.0, theta=0.0
% INFO    : Bus 60109	: V=1.0076149, theta=-2.122815 -> V=1.0, theta=0.0
% INFO    : Bus 60110	: V=0.9983034, theta=-4.051736 -> V=1.0, theta=0.0
% INFO    : Bus 60111	: V=0.9938721, theta=-4.562749 -> V=1.0, theta=0.0
% INFO    : Bus 60112	: V=1.0013901, theta=-3.04043 -> V=1.0, theta=0.0
% INFO    : Bus 60113	: V=0.9959248, theta=-4.139028 -> V=1.0, theta=0.0
% INFO    : Bus 60114	: V=1.0029224, theta=-2.84557 -> V=1.0, theta=0.0
% INFO    : Bus 60115	: V=0.9960719, theta=-4.311154 -> V=1.0, theta=0.0
% INFO    : Bus 60116	: V=1.0014572, theta=-3.0716 -> V=1.0, theta=0.0
% INFO    : Bus 60117	: V=0.9932213, theta=-4.61285 -> V=1.0, theta=0.0
% INFO    : Bus 60118	: V=0.9927084, theta=-4.65651 -> V=1.0, theta=0.0
% INFO    : Bus 60119	: V=1.0023393, theta=-2.909438 -> V=1.0, theta=0.0
% INFO    : Bus 60120	: V=0.9946389, theta=-4.578915 -> V=1.0, theta=0.0
% INFO    : Bus 60121	: V=0.9971919, theta=-3.894938 -> V=1.0, theta=0.0
% INFO    : Bus 60122	: V=0.9901714, theta=-4.794699 -> V=1.0, theta=0.0
% INFO    : Bus 60123	: V=0.9956815, theta=-4.310517 -> V=1.0, theta=0.0
% INFO    : Bus 60124	: V=0.9967058, theta=-4.266163 -> V=1.0, theta=0.0
% INFO    : Bus 60125	: V=0.9925324, theta=-4.749773 -> V=1.0, theta=0.0
% INFO    : Bus 60126	: V=0.9932138, theta=-4.618866 -> V=1.0, theta=0.0
% INFO    : Bus 60127	: V=0.9952173, theta=-4.438534 -> V=1.0, theta=0.0
% INFO    : Bus 60128	: V=0.9944921, theta=-4.474384 -> V=1.0, theta=0.0
% INFO    : Bus 60129	: V=0.9915391, theta=-4.7532 -> V=1.0, theta=0.0
% INFO    : Bus 60130	: V=0.9915227, theta=-4.759442 -> V=1.0, theta=0.0
% INFO    : Bus 60131	: V=0.9933377, theta=-4.600048 -> V=1.0, theta=0.0
% INFO    : Bus 60132	: V=0.9916445, theta=-4.753385 -> V=1.0, theta=0.0
% INFO    : Bus 60133	: V=0.991056, theta=-4.740533 -> V=1.0, theta=0.0
% INFO    : Bus 60134	: V=0.987216, theta=-5.499947 -> V=1.0, theta=0.0
% INFO    : Bus 60135	: V=0.9879561, theta=-5.282365 -> V=1.0, theta=0.0
% INFO    : Bus 60136	: V=0.9889535, theta=-5.095686 -> V=1.0, theta=0.0
% INFO    : Bus 60137	: V=0.9915941, theta=-4.74621 -> V=1.0, theta=0.0
% INFO    : Bus 60138	: V=0.9915567, theta=-4.75053 -> V=1.0, theta=0.0
% INFO    : Bus 60139	: V=0.9924019, theta=-4.520446 -> V=1.0, theta=0.0
% INFO    : Bus 60140	: V=0.9870085, theta=-5.617833 -> V=1.0, theta=0.0
% INFO    : Bus 60141	: V=0.9905213, theta=-5.268324 -> V=1.0, theta=0.0
% INFO    : Bus 60142	: V=0.9866467, theta=-5.961595 -> V=1.0, theta=0.0
% INFO    : Bus 60143	: V=0.9911816, theta=-4.992474 -> V=1.0, theta=0.0
% INFO    : Bus 60144	: V=0.98649, theta=-6.215052 -> V=1.0, theta=0.0
% INFO    : Bus 60145	: V=0.9877781, theta=-5.885372 -> V=1.0, theta=0.0
% INFO    : Bus 60146	: V=0.9889679, theta=-5.587445 -> V=1.0, theta=0.0
% INFO    : Bus 60147	: V=0.9867852, theta=-5.947159 -> V=1.0, theta=0.0
% INFO    : Bus 60148	: V=0.986156, theta=-6.000134 -> V=1.0, theta=0.0
% INFO    : Bus 60149	: V=0.9891837, theta=-5.476129 -> V=1.0, theta=0.0
% INFO    : Bus 60150	: V=0.9883078, theta=-5.97105 -> V=1.0, theta=0.0
% INFO    : Bus 60151	: V=0.9931256, theta=-4.766131 -> V=1.0, theta=0.0
% INFO    : Bus 60152	: V=0.990083, theta=-5.227533 -> V=1.0, theta=0.0
% INFO    : Bus 60153	: V=0.9993803, theta=-3.250512 -> V=1.0, theta=0.0
% INFO    : Bus 60154	: V=0.9925191, theta=-4.887349 -> V=1.0, theta=0.0
% INFO    : Bus 60155	: V=0.9920875, theta=-4.971832 -> V=1.0, theta=0.0
% INFO    : Bus 60156	: V=0.989357, theta=-5.331432 -> V=1.0, theta=0.0
% INFO    : Bus 60157	: V=0.9885244, theta=-5.354029 -> V=1.0, theta=0.0
% INFO    : Bus 60158	: V=0.9941751, theta=-3.634036 -> V=1.0, theta=0.0
% INFO    : Bus 60159	: V=0.9891533, theta=-5.370725 -> V=1.0, theta=0.0
% INFO    : Bus 60160	: V=0.9900697, theta=-5.234902 -> V=1.0, theta=0.0
% INFO    : Bus 60161	: V=0.9876902, theta=-5.166236 -> V=1.0, theta=0.0
% INFO    : Bus 60162	: V=0.9882365, theta=-5.455254 -> V=1.0, theta=0.0
% INFO    : Bus 60163	: V=0.9895353, theta=-5.359671 -> V=1.0, theta=0.0
% INFO    : Bus 60164	: V=1.0003734, theta=-2.934194 -> V=1.0, theta=0.0
% INFO    : Bus 60165	: V=0.9978701, theta=-3.253063 -> V=1.0, theta=0.0
% INFO    : Bus 60166	: V=0.9879287, theta=-5.418104 -> V=1.0, theta=0.0
% INFO    : Bus 60167	: V=0.9882941, theta=-5.409359 -> V=1.0, theta=0.0
% INFO    : Bus 60168	: V=0.9912313, theta=-1.75522 -> V=1.0, theta=0.0
% INFO    : Bus 60169	: V=0.987498, theta=-6.303559 -> V=1.0, theta=0.0
% INFO    : Bus 60170	: V=0.9860185, theta=-6.374213 -> V=1.0, theta=0.0
% INFO    : Bus 60171	: V=0.9864794, theta=-6.30948 -> V=1.0, theta=0.0
% INFO    : Bus 60172	: V=0.9845792, theta=-6.951883 -> V=1.0, theta=0.0
% INFO    : Bus 60173	: V=0.985416, theta=-6.422364 -> V=1.0, theta=0.0
% INFO    : Bus 60174	: V=0.9851326, theta=-6.422447 -> V=1.0, theta=0.0
% INFO    : Bus 60175	: V=0.9855334, theta=-6.32711 -> V=1.0, theta=0.0
% INFO    : Bus 60176	: V=0.9864262, theta=-6.366679 -> V=1.0, theta=0.0
% INFO    : Bus 60177	: V=0.9980576, theta=-5.337608 -> V=1.0, theta=0.0
% INFO    : Bus 60178	: V=0.9966216, theta=-4.146403 -> V=1.0, theta=0.0
% INFO    : Bus 60179	: V=1.0012188, theta=-4.662843 -> V=1.0, theta=0.0
% INFO    : Bus 60180	: V=1.0005859, theta=-5.527331 -> V=1.0, theta=0.0
% INFO    : Bus 60181	: V=1.0077436, theta=6.664922 -> V=1.0, theta=0.0
% INFO    : Bus 60182	: V=0.9833246, theta=-6.960153 -> V=1.0, theta=0.0
% INFO    : Bus 60183	: V=0.9836221, theta=-8.206548 -> V=1.0, theta=0.0
% INFO    : Bus 60184	: V=0.9842766, theta=-8.364247 -> V=1.0, theta=0.0
% INFO    : Bus 60185	: V=0.9837111, theta=-7.162095 -> V=1.0, theta=0.0
% INFO    : Bus 60186	: V=0.9816401, theta=-7.700901 -> V=1.0, theta=0.0
% INFO    : Bus 60187	: V=0.9833107, theta=-7.424651 -> V=1.0, theta=0.0
% INFO    : Bus 60188	: V=0.9809248, theta=-9.507351 -> V=1.0, theta=0.0
% INFO    : Bus 60189	: V=0.9754371, theta=-10.672177 -> V=1.0, theta=0.0
% INFO    : Bus 60190	: V=0.9824452, theta=-11.098936 -> V=1.0, theta=0.0
% INFO    : Bus 60191	: V=0.9690874, theta=-10.931295 -> V=1.0, theta=0.0
% INFO    : Bus 60192	: V=0.9734509, theta=-10.682574 -> V=1.0, theta=0.0
% INFO    : Bus 60193	: V=0.9721236, theta=-10.718269 -> V=1.0, theta=0.0
% INFO    : Bus 60194	: V=0.9745827, theta=-9.990265 -> V=1.0, theta=0.0
% INFO    : Bus 60195	: V=0.9750699, theta=-9.689003 -> V=1.0, theta=0.0
% INFO    : Bus 60196	: V=0.9746474, theta=-9.888873 -> V=1.0, theta=0.0
% INFO    : Bus 60197	: V=0.9775143, theta=-8.747797 -> V=1.0, theta=0.0
% INFO    : Bus 60198	: V=0.9659646, theta=-11.864377 -> V=1.0, theta=0.0
% INFO    : Bus 60199	: V=1.0200006, theta=25.94367 -> V=1.0, theta=0.0
% INFO    : Bus 60200	: V=1.0300006, theta=24.65103 -> V=1.0, theta=0.0
% INFO    : Bus 60201	: V=1.0052309, theta=21.136131 -> V=1.0, theta=0.0
% INFO    : Bus 60202	: V=1.0180889, theta=24.108865 -> V=1.0, theta=0.0
% INFO    : Bus 60203	: V=1.005726, theta=21.270869 -> V=1.0, theta=0.0
% INFO    : Bus 60204	: V=1.0118047, theta=18.371668 -> V=1.0, theta=0.0
% INFO    : Bus 60205	: V=1.0169388, theta=19.78758 -> V=1.0, theta=0.0
% INFO    : Bus 60206	: V=1.0109756, theta=17.839911 -> V=1.0, theta=0.0
% INFO    : Bus 60207	: V=1.0164462, theta=18.857969 -> V=1.0, theta=0.0
% INFO    : Bus 60208	: V=1.019895, theta=19.401383 -> V=1.0, theta=0.0
% INFO    : Bus 60209	: V=1.0195801, theta=19.428596 -> V=1.0, theta=0.0
% INFO    : Bus 60210	: V=1.0009482, theta=20.384684 -> V=1.0, theta=0.0
% INFO    : Bus 60211	: V=1.0022476, theta=20.46187 -> V=1.0, theta=0.0
% INFO    : Bus 60212	: V=1.0011351, theta=20.388786 -> V=1.0, theta=0.0
% INFO    : Bus 60213	: V=0.9977237, theta=19.680617 -> V=1.0, theta=0.0
% INFO    : Bus 60214	: V=0.998921, theta=19.711592 -> V=1.0, theta=0.0
% INFO    : Bus 60215	: V=1.000672, theta=20.42198 -> V=1.0, theta=0.0
% INFO    : Bus 60216	: V=1.00037, theta=20.380077 -> V=1.0, theta=0.0
% INFO    : Bus 60217	: V=0.9915278, theta=19.356475 -> V=1.0, theta=0.0
% INFO    : Bus 60218	: V=1.0013609, theta=20.092198 -> V=1.0, theta=0.0
% INFO    : Bus 60219	: V=0.9937248, theta=19.475058 -> V=1.0, theta=0.0
% INFO    : Bus 60220	: V=0.9937651, theta=19.412929 -> V=1.0, theta=0.0
% INFO    : Bus 60221	: V=0.994505, theta=19.443054 -> V=1.0, theta=0.0
% INFO    : Bus 60222	: V=0.99309, theta=19.181054 -> V=1.0, theta=0.0
% INFO    : Bus 60223	: V=1.0007037, theta=20.430238 -> V=1.0, theta=0.0
% INFO    : Bus 60224	: V=0.9910775, theta=19.355918 -> V=1.0, theta=0.0
% INFO    : Bus 60225	: V=1.0014816, theta=20.524468 -> V=1.0, theta=0.0
% INFO    : Bus 60226	: V=0.9946659, theta=19.477803 -> V=1.0, theta=0.0
% INFO    : Bus 60227	: V=0.9898656, theta=19.086998 -> V=1.0, theta=0.0
% INFO    : Bus 60228	: V=0.9917351, theta=19.569065 -> V=1.0, theta=0.0
% INFO    : Bus 60229	: V=0.9867246, theta=18.998359 -> V=1.0, theta=0.0
% INFO    : Bus 60230	: V=1.0026227, theta=20.646157 -> V=1.0, theta=0.0
% INFO    : Bus 60231	: V=0.9964225, theta=19.805664 -> V=1.0, theta=0.0
% INFO    : Bus 60232	: V=0.9984957, theta=19.955114 -> V=1.0, theta=0.0
% INFO    : Bus 60233	: V=0.9979498, theta=19.87161 -> V=1.0, theta=0.0
% INFO    : Bus 60234	: V=0.9980494, theta=19.836041 -> V=1.0, theta=0.0
% INFO    : Bus 60235	: V=1.00015, theta=19.870488 -> V=1.0, theta=0.0
% INFO    : Bus 60236	: V=1.0103151, theta=21.241152 -> V=1.0, theta=0.0
% INFO    : Bus 60237	: V=1.0115513, theta=21.354307 -> V=1.0, theta=0.0
% INFO    : Bus 60238	: V=1.013049, theta=21.492073 -> V=1.0, theta=0.0
% INFO    : Bus 60239	: V=1.0300006, theta=22.645851 -> V=1.0, theta=0.0
% INFO    : Bus 60240	: V=1.0100006, theta=22.228883 -> V=1.0, theta=0.0
% INFO    : Bus 60241	: V=1.0169688, theta=21.826361 -> V=1.0, theta=0.0
% INFO    : Bus 60242	: V=1.0200006, theta=22.31654 -> V=1.0, theta=0.0
% INFO    : Bus 60243	: V=0.9994929, theta=18.677948 -> V=1.0, theta=0.0
% INFO    : Bus 60244	: V=1.000452, theta=18.947121 -> V=1.0, theta=0.0
% INFO    : Bus 60245	: V=1.0003403, theta=19.408829 -> V=1.0, theta=0.0
% INFO    : Bus 60246	: V=1.0100007, theta=22.916557 -> V=1.0, theta=0.0
% INFO    : Bus 60247	: V=0.9503758, theta=18.651443 -> V=1.0, theta=0.0
% INFO    : Bus 60248	: V=1.0100007, theta=11.542196 -> V=1.0, theta=0.0
% INFO    : Bus 60249	: V=1.0100007, theta=17.081088 -> V=1.0, theta=0.0
% INFO    : Bus 60250	: V=1.0100007, theta=18.746622 -> V=1.0, theta=0.0
% INFO    : Bus 60251	: V=1.0072074, theta=12.416069 -> V=1.0, theta=0.0
% INFO    : Bus 60252	: V=1.0074412, theta=13.32197 -> V=1.0, theta=0.0
% INFO    : Bus 60253	: V=1.0223337, theta=14.333356 -> V=1.0, theta=0.0
% INFO    : Bus 60254	: V=1.0053395, theta=14.020086 -> V=1.0, theta=0.0
% INFO    : Bus 60255	: V=1.0165053, theta=14.862242 -> V=1.0, theta=0.0
% INFO    : Bus 60256	: V=1.0042232, theta=14.030715 -> V=1.0, theta=0.0
% INFO    : Bus 60257	: V=1.0040782, theta=14.104832 -> V=1.0, theta=0.0
% INFO    : Bus 60258	: V=1.0200007, theta=15.755162 -> V=1.0, theta=0.0
% INFO    : Bus 60259	: V=0.9986454, theta=13.823012 -> V=1.0, theta=0.0
% INFO    : Bus 60260	: V=0.999291, theta=13.842331 -> V=1.0, theta=0.0
% INFO    : Bus 60261	: V=0.9547781, theta=-10.28768 -> V=1.0, theta=0.0
% INFO    : Bus 60262	: V=0.9713938, theta=-8.226104 -> V=1.0, theta=0.0
% INFO    : Bus 60263	: V=0.9631273, theta=-9.923572 -> V=1.0, theta=0.0
% INFO    : Bus 60264	: V=0.9698749, theta=-9.047509 -> V=1.0, theta=0.0
% INFO    : Bus 60265	: V=0.9551248, theta=-8.306691 -> V=1.0, theta=0.0
% INFO    : Bus 60266	: V=0.9523813, theta=-9.304393 -> V=1.0, theta=0.0
% INFO    : Bus 60267	: V=0.9509415, theta=-9.401077 -> V=1.0, theta=0.0
% INFO    : Bus 60268	: V=0.9506359, theta=-9.385937 -> V=1.0, theta=0.0
% INFO    : Bus 60269	: V=0.9475098, theta=-9.536721 -> V=1.0, theta=0.0
% INFO    : Bus 60270	: V=0.9505755, theta=-9.317017 -> V=1.0, theta=0.0
% INFO    : Bus 60271	: V=0.9522779, theta=-9.152035 -> V=1.0, theta=0.0
% INFO    : Bus 60272	: V=0.9551849, theta=-8.654532 -> V=1.0, theta=0.0
% INFO    : Bus 60273	: V=0.9527067, theta=-8.851809 -> V=1.0, theta=0.0
% INFO    : Bus 60274	: V=0.961577, theta=-7.569095 -> V=1.0, theta=0.0
% INFO    : Bus 60275	: V=0.9650382, theta=-6.880847 -> V=1.0, theta=0.0
% INFO    : Bus 60276	: V=0.9596198, theta=-7.48771 -> V=1.0, theta=0.0
% INFO    : Bus 60277	: V=0.9676055, theta=-5.782812 -> V=1.0, theta=0.0
% INFO    : Bus 60278	: V=0.977837, theta=-3.678859 -> V=1.0, theta=0.0
% INFO    : Bus 60279	: V=0.9770934, theta=-3.750421 -> V=1.0, theta=0.0
% INFO    : Bus 60280	: V=0.9664573, theta=-6.282938 -> V=1.0, theta=0.0
% INFO    : Bus 60281	: V=0.9592328, theta=-12.598932 -> V=1.0, theta=0.0
% INFO    : Bus 60282	: V=0.9630907, theta=-6.917769 -> V=1.0, theta=0.0
% INFO    : Bus 60283	: V=1.0074473, theta=1.394752 -> V=1.0, theta=0.0
% INFO    : Bus 60284	: V=1.0035407, theta=-0.195809 -> V=1.0, theta=0.0
% INFO    : Bus 60285	: V=1.0091064, theta=-0.377524 -> V=1.0, theta=0.0
% INFO    : Bus 60286	: V=1.0086996, theta=-0.021044 -> V=1.0, theta=0.0
% INFO    : Bus 60287	: V=1.008099, theta=-0.001624 -> V=1.0, theta=0.0
% INFO    : Bus 60288	: V=1.0200007, theta=0.368843 -> V=1.0, theta=0.0
% INFO    : Bus 60289	: V=1.0170037, theta=0.615252 -> V=1.0, theta=0.0
% INFO    : Bus 60290	: V=1.0075279, theta=-0.30665 -> V=1.0, theta=0.0
% INFO    : Bus 60291	: V=1.0027998, theta=-0.496492 -> V=1.0, theta=0.0
% INFO    : Bus 60292	: V=1.000605, theta=-1.060394 -> V=1.0, theta=0.0
% INFO    : Bus 60293	: V=1.0067885, theta=-0.568527 -> V=1.0, theta=0.0
% INFO    : Bus 60294	: V=1.0069621, theta=-0.553915 -> V=1.0, theta=0.0
% INFO    : Bus 60295	: V=1.007311, theta=-0.512721 -> V=1.0, theta=0.0
% INFO    : Bus 60296	: V=0.9989685, theta=-1.098696 -> V=1.0, theta=0.0
% INFO    : Bus 60297	: V=1.0044587, theta=-0.631109 -> V=1.0, theta=0.0
% INFO    : Bus 60298	: V=1.0017208, theta=-0.818055 -> V=1.0, theta=0.0
% INFO    : Bus 60299	: V=1.0020444, theta=-0.752761 -> V=1.0, theta=0.0
% INFO    : Bus 60300	: V=1.0061454, theta=-0.100053 -> V=1.0, theta=0.0
% INFO    : Bus 60301	: V=1.0007305, theta=-1.035836 -> V=1.0, theta=0.0
% INFO    : Bus 60302	: V=1.0300007, theta=4.242244 -> V=1.0, theta=0.0
% INFO    : Bus 60303	: V=1.0178982, theta=1.922507 -> V=1.0, theta=0.0
% INFO    : Bus 60304	: V=1.0167096, theta=1.673519 -> V=1.0, theta=0.0
% INFO    : Bus 60305	: V=1.0172476, theta=1.74406 -> V=1.0, theta=0.0
% INFO    : Bus 60306	: V=1.0134525, theta=1.014722 -> V=1.0, theta=0.0
% INFO    : Bus 60307	: V=1.0099241, theta=0.272381 -> V=1.0, theta=0.0
% INFO    : Bus 60308	: V=1.0060387, theta=-0.185881 -> V=1.0, theta=0.0
% INFO    : Bus 60309	: V=1.0122169, theta=0.89827 -> V=1.0, theta=0.0
% INFO    : Bus 60310	: V=1.012193, theta=0.196228 -> V=1.0, theta=0.0
% INFO    : Bus 60311	: V=1.0198488, theta=1.581845 -> V=1.0, theta=0.0
% INFO    : Bus 60312	: V=1.014792, theta=0.980767 -> V=1.0, theta=0.0
% INFO    : Bus 60313	: V=0.9992777, theta=-1.344803 -> V=1.0, theta=0.0
% INFO    : Bus 60314	: V=0.9996144, theta=-1.337178 -> V=1.0, theta=0.0
% INFO    : Bus 60315	: V=0.9993907, theta=-1.348619 -> V=1.0, theta=0.0
% INFO    : Bus 60316	: V=1.0006282, theta=-1.181814 -> V=1.0, theta=0.0
% INFO    : Bus 60317	: V=1.0018266, theta=-0.705683 -> V=1.0, theta=0.0
% INFO    : Bus 60318	: V=1.0011628, theta=-0.794961 -> V=1.0, theta=0.0
% INFO    : Bus 60319	: V=0.9973155, theta=-1.410432 -> V=1.0, theta=0.0
% INFO    : Bus 60320	: V=1.0067084, theta=-0.585295 -> V=1.0, theta=0.0
% INFO    : Bus 60321	: V=1.0062813, theta=-0.62219 -> V=1.0, theta=0.0
% INFO    : Bus 60322	: V=1.0010964, theta=-1.276003 -> V=1.0, theta=0.0
% INFO    : Bus 60323	: V=1.0060658, theta=-0.644132 -> V=1.0, theta=0.0
% INFO    : Bus 60324	: V=1.0066321, theta=-0.593416 -> V=1.0, theta=0.0
% INFO    : Bus 60325	: V=1.0067847, theta=-0.571354 -> V=1.0, theta=0.0
% INFO    : Bus 60326	: V=1.0083498, theta=-0.489915 -> V=1.0, theta=0.0
% INFO    : Bus 60327	: V=1.0078736, theta=-0.664573 -> V=1.0, theta=0.0
% INFO    : Bus 60328	: V=1.0100007, theta=-0.141665 -> V=1.0, theta=0.0
% INFO    : Bus 60329	: V=1.0069548, theta=-0.724954 -> V=1.0, theta=0.0
% INFO    : Bus 60330	: V=1.010484, theta=-0.119931 -> V=1.0, theta=0.0
% INFO    : Bus 60331	: V=1.0170646, theta=0.692347 -> V=1.0, theta=0.0
% INFO    : Bus 60332	: V=1.0081355, theta=-0.508634 -> V=1.0, theta=0.0
% INFO    : Bus 60333	: V=1.0100007, theta=-0.282162 -> V=1.0, theta=0.0
% INFO    : Bus 60334	: V=1.0080759, theta=-0.515124 -> V=1.0, theta=0.0
% INFO    : Bus 60335	: V=1.0052096, theta=-0.869757 -> V=1.0, theta=0.0
% INFO    : Bus 60336	: V=1.0080446, theta=-0.514407 -> V=1.0, theta=0.0
% INFO    : Bus 60337	: V=1.0071277, theta=-0.500847 -> V=1.0, theta=0.0
% INFO    : Bus 60338	: V=1.0072296, theta=-0.761853 -> V=1.0, theta=0.0
% INFO    : Bus 60339	: V=1.0063206, theta=-0.655828 -> V=1.0, theta=0.0
% INFO    : Bus 60340	: V=1.0004659, theta=-1.389493 -> V=1.0, theta=0.0
% INFO    : Bus 60341	: V=1.0061109, theta=-0.659419 -> V=1.0, theta=0.0
% INFO    : Bus 60342	: V=1.0062468, theta=-0.731833 -> V=1.0, theta=0.0
% INFO    : Bus 60343	: V=1.0064061, theta=-0.680501 -> V=1.0, theta=0.0
% INFO    : Bus 60344	: V=1.0067517, theta=-0.708996 -> V=1.0, theta=0.0
% INFO    : Bus 60345	: V=1.0032232, theta=-1.178083 -> V=1.0, theta=0.0
% INFO    : Bus 60346	: V=1.0085017, theta=-0.708955 -> V=1.0, theta=0.0
% INFO    : Bus 60347	: V=1.0063884, theta=-0.715358 -> V=1.0, theta=0.0
% INFO    : Bus 60348	: V=1.0074605, theta=-0.682715 -> V=1.0, theta=0.0
% INFO    : Bus 60349	: V=1.0080471, theta=-0.654841 -> V=1.0, theta=0.0
% INFO    : Bus 60350	: V=1.0099739, theta=-0.655785 -> V=1.0, theta=0.0
% INFO    : Bus 60351	: V=1.0080245, theta=-0.271885 -> V=1.0, theta=0.0
% INFO    : Bus 60352	: V=1.0068848, theta=-0.606366 -> V=1.0, theta=0.0
% INFO    : Bus 60353	: V=1.0067254, theta=-0.639703 -> V=1.0, theta=0.0
% INFO    : Bus 60354	: V=1.0084138, theta=-0.579448 -> V=1.0, theta=0.0
% INFO    : Bus 60355	: V=1.0087919, theta=-0.496342 -> V=1.0, theta=0.0
% INFO    : Bus 60356	: V=1.0084352, theta=-0.441182 -> V=1.0, theta=0.0
% INFO    : Bus 60357	: V=1.0077944, theta=-0.282443 -> V=1.0, theta=0.0
% INFO    : Bus 60358	: V=1.0100007, theta=0.850533 -> V=1.0, theta=0.0
% INFO    : Bus 60359	: V=1.0130472, theta=0.372587 -> V=1.0, theta=0.0
% INFO    : Bus 60360	: V=1.0130168, theta=0.614613 -> V=1.0, theta=0.0
% INFO    : Bus 60361	: V=1.0084914, theta=-0.170161 -> V=1.0, theta=0.0
% INFO    : Bus 60362	: V=1.002986, theta=-1.073906 -> V=1.0, theta=0.0
% INFO    : Bus 60363	: V=1.0080289, theta=-0.257684 -> V=1.0, theta=0.0
% INFO    : Bus 60364	: V=1.01969, theta=1.350329 -> V=1.0, theta=0.0
% INFO    : Bus 60365	: V=1.0200007, theta=1.168802 -> V=1.0, theta=0.0
% INFO    : Bus 60366	: V=1.0032076, theta=-1.079145 -> V=1.0, theta=0.0
% INFO    : Bus 60367	: V=1.0069724, theta=-0.644644 -> V=1.0, theta=0.0
% INFO    : Bus 60368	: V=1.0078862, theta=-0.505481 -> V=1.0, theta=0.0
% INFO    : Bus 60369	: V=1.0075364, theta=-0.538813 -> V=1.0, theta=0.0
% INFO    : Bus 60370	: V=1.0200007, theta=1.76242 -> V=1.0, theta=0.0
% INFO    : Bus 60371	: V=1.0155773, theta=1.434869 -> V=1.0, theta=0.0
% INFO    : Bus 60372	: V=1.0064109, theta=-0.716437 -> V=1.0, theta=0.0
% INFO    : Bus 60373	: V=1.0050843, theta=-1.022762 -> V=1.0, theta=0.0
% INFO    : Bus 60374	: V=1.0073588, theta=-0.754551 -> V=1.0, theta=0.0
% INFO    : Bus 60375	: V=1.0076487, theta=-0.698418 -> V=1.0, theta=0.0
% INFO    : Bus 60376	: V=1.0079617, theta=-0.648146 -> V=1.0, theta=0.0
% INFO    : Bus 60377	: V=1.0079335, theta=-0.694785 -> V=1.0, theta=0.0
% INFO    : Bus 60378	: V=1.0079277, theta=-0.746526 -> V=1.0, theta=0.0
% INFO    : Bus 60379	: V=1.0079851, theta=-0.78054 -> V=1.0, theta=0.0
% INFO    : Bus 60380	: V=1.0056226, theta=-1.048067 -> V=1.0, theta=0.0
% INFO    : Bus 60381	: V=1.0069091, theta=-0.906622 -> V=1.0, theta=0.0
% INFO    : Bus 60382	: V=1.0070658, theta=-0.839095 -> V=1.0, theta=0.0
% INFO    : Bus 60383	: V=1.0072371, theta=-0.828041 -> V=1.0, theta=0.0
% INFO    : Bus 60384	: V=1.0074766, theta=-0.808847 -> V=1.0, theta=0.0
% INFO    : Bus 60385	: V=1.0076547, theta=-0.793206 -> V=1.0, theta=0.0
% INFO    : Bus 60386	: V=1.0079557, theta=-0.766244 -> V=1.0, theta=0.0
% INFO    : Bus 60387	: V=1.0081278, theta=19.773884 -> V=1.0, theta=0.0
% INFO    : Bus 60388	: V=1.0100007, theta=1.032864 -> V=1.0, theta=0.0
% INFO    : Bus 60389	: V=1.0096828, theta=0.599211 -> V=1.0, theta=0.0
% INFO    : Bus 60390	: V=1.0064344, theta=-0.027556 -> V=1.0, theta=0.0
% INFO    : Bus 60391	: V=1.0073282, theta=-0.009364 -> V=1.0, theta=0.0
% INFO    : Bus 60392	: V=1.0099145, theta=0.612474 -> V=1.0, theta=0.0
% INFO    : Bus 60393	: V=1.0097664, theta=0.602779 -> V=1.0, theta=0.0
% INFO    : Bus 60394	: V=1.007336, theta=0.052069 -> V=1.0, theta=0.0
% INFO    : Bus 60395	: V=1.0060152, theta=-0.096286 -> V=1.0, theta=0.0
% INFO    : Bus 60396	: V=1.0097827, theta=0.559585 -> V=1.0, theta=0.0
% INFO    : Bus 60397	: V=1.0045054, theta=-0.187693 -> V=1.0, theta=0.0
% INFO    : Bus 60398	: V=1.0005724, theta=-0.32266 -> V=1.0, theta=0.0
% INFO    : Bus 60399	: V=1.0023561, theta=-0.19681 -> V=1.0, theta=0.0
% INFO    : Bus 60400	: V=1.0099389, theta=1.026243 -> V=1.0, theta=0.0
% INFO    : Bus 60401	: V=1.0054765, theta=0.180988 -> V=1.0, theta=0.0
% INFO    : Bus 60402	: V=0.9983262, theta=-0.388063 -> V=1.0, theta=0.0
% INFO    : Bus 60403	: V=1.0097507, theta=1.177804 -> V=1.0, theta=0.0
% INFO    : Bus 60404	: V=1.0190141, theta=0.367069 -> V=1.0, theta=0.0
% INFO    : Bus 60405	: V=1.0200007, theta=0.908468 -> V=1.0, theta=0.0
% INFO    : Bus 60406	: V=0.9963053, theta=-0.082559 -> V=1.0, theta=0.0
% INFO    : Bus 60407	: V=1.0120211, theta=1.501956 -> V=1.0, theta=0.0
% INFO    : Bus 60408	: V=1.0110412, theta=0.492971 -> V=1.0, theta=0.0
% INFO    : Bus 60409	: V=1.0095153, theta=0.440231 -> V=1.0, theta=0.0
% INFO    : Bus 60410	: V=1.0131698, theta=1.355376 -> V=1.0, theta=0.0
% INFO    : Bus 60411	: V=1.0099001, theta=0.62264 -> V=1.0, theta=0.0
% INFO    : Bus 60412	: V=1.0294673, theta=23.946947 -> V=1.0, theta=0.0
% INFO    : Bus 60413	: V=0.9909435, theta=23.959353 -> V=1.0, theta=0.0
% INFO    : Bus 60414	: V=1.0103881, theta=15.459145 -> V=1.0, theta=0.0
% INFO    : Bus 60415	: V=1.0090943, theta=14.151527 -> V=1.0, theta=0.0
% INFO    : Bus 60416	: V=1.0046687, theta=14.108412 -> V=1.0, theta=0.0
% INFO    : Bus 60417	: V=1.0063792, theta=14.128265 -> V=1.0, theta=0.0
% INFO    : Bus 60418	: V=1.0082629, theta=14.778461 -> V=1.0, theta=0.0
% INFO    : Bus 60419	: V=1.0082886, theta=14.852636 -> V=1.0, theta=0.0
% INFO    : Bus 60420	: V=1.009558, theta=38.276249 -> V=1.0, theta=0.0
% INFO    : Bus 60421	: V=1.007369, theta=24.242189 -> V=1.0, theta=0.0
% INFO    : Bus 60422	: V=1.0120234, theta=26.074378 -> V=1.0, theta=0.0
% INFO    : Bus 60423	: V=1.0200006, theta=22.743113 -> V=1.0, theta=0.0
% INFO    : Bus 60424	: V=1.0095335, theta=21.260497 -> V=1.0, theta=0.0
% INFO    : Bus 60425	: V=1.002652, theta=20.979359 -> V=1.0, theta=0.0
% INFO    : Bus 60426	: V=1.0077648, theta=21.115384 -> V=1.0, theta=0.0
% INFO    : Bus 60427	: V=1.0030019, theta=20.680911 -> V=1.0, theta=0.0
% INFO    : Bus 60428	: V=1.0051058, theta=20.878173 -> V=1.0, theta=0.0
% INFO    : Bus 60429	: V=1.0004358, theta=21.320706 -> V=1.0, theta=0.0
% INFO    : Bus 60430	: V=1.0024025, theta=20.621069 -> V=1.0, theta=0.0
% INFO    : Bus 60431	: V=0.9977841, theta=20.216722 -> V=1.0, theta=0.0
% INFO    : Bus 60432	: V=1.0016266, theta=20.534313 -> V=1.0, theta=0.0
% INFO    : Bus 60433	: V=1.0200006, theta=24.082594 -> V=1.0, theta=0.0
% INFO    : Bus 60434	: V=0.9543819, theta=14.929391 -> V=1.0, theta=0.0
% INFO    : Bus 60435	: V=1.0035475, theta=21.100231 -> V=1.0, theta=0.0
% INFO    : Bus 60436	: V=1.0100006, theta=20.849745 -> V=1.0, theta=0.0
% INFO    : Bus 60437	: V=1.0100007, theta=35.950475 -> V=1.0, theta=0.0
% INFO    : Bus 60438	: V=0.9977794, theta=26.790577 -> V=1.0, theta=0.0
% INFO    : Bus 60439	: V=0.9898487, theta=22.751979 -> V=1.0, theta=0.0
% INFO    : Bus 60440	: V=0.9955462, theta=22.899282 -> V=1.0, theta=0.0
% INFO    : Bus 60441	: V=0.9917071, theta=16.137529 -> V=1.0, theta=0.0
% INFO    : Bus 60442	: V=1.0021495, theta=17.920961 -> V=1.0, theta=0.0
% INFO    : Bus 60443	: V=1.0072696, theta=19.035742 -> V=1.0, theta=0.0
% INFO    : Bus 60444	: V=0.9969284, theta=22.503525 -> V=1.0, theta=0.0
% INFO    : Bus 60445	: V=0.9964287, theta=21.446923 -> V=1.0, theta=0.0
% INFO    : Bus 60446	: V=0.9966915, theta=21.767472 -> V=1.0, theta=0.0
% INFO    : Bus 60447	: V=0.9950718, theta=21.61216 -> V=1.0, theta=0.0
% INFO    : Bus 60448	: V=0.9963048, theta=21.68844 -> V=1.0, theta=0.0
% INFO    : Bus 60449	: V=0.9791043, theta=22.467023 -> V=1.0, theta=0.0
% INFO    : Bus 60450	: V=1.0033364, theta=21.865031 -> V=1.0, theta=0.0
% INFO    : Bus 60451	: V=1.0032243, theta=20.298536 -> V=1.0, theta=0.0
% INFO    : Bus 60452	: V=0.9944034, theta=18.480634 -> V=1.0, theta=0.0
% INFO    : Bus 60453	: V=0.9658186, theta=-7.483885 -> V=1.0, theta=0.0
% INFO    : Bus 60454	: V=0.9942479, theta=-3.964874 -> V=1.0, theta=0.0
% INFO    : Bus 60455	: V=1.0299079, theta=-2.040156 -> V=1.0, theta=0.0
% INFO    : Bus 60456	: V=1.0259026, theta=-2.11493 -> V=1.0, theta=0.0
% INFO    : Bus 60457	: V=1.0015429, theta=-3.867744 -> V=1.0, theta=0.0
% INFO    : Bus 60458	: V=1.0206815, theta=-2.346273 -> V=1.0, theta=0.0
% INFO    : Bus 60459	: V=1.0196728, theta=-3.002471 -> V=1.0, theta=0.0
% INFO    : Bus 60460	: V=1.0033769, theta=-5.4938 -> V=1.0, theta=0.0
% INFO    : Bus 60461	: V=1.0007627, theta=-5.706708 -> V=1.0, theta=0.0
% INFO    : Bus 60462	: V=1.0005484, theta=-5.736833 -> V=1.0, theta=0.0
% INFO    : Bus 60463	: V=1.0009039, theta=-5.707902 -> V=1.0, theta=0.0
% INFO    : Bus 60464	: V=1.0112157, theta=-4.228068 -> V=1.0, theta=0.0
% INFO    : Bus 60465	: V=0.9973328, theta=-6.160411 -> V=1.0, theta=0.0
% INFO    : Bus 60466	: V=0.992172, theta=-6.097348 -> V=1.0, theta=0.0
% INFO    : Bus 60467	: V=0.9791298, theta=-7.669275 -> V=1.0, theta=0.0
% INFO    : Bus 60468	: V=0.9798483, theta=-4.380155 -> V=1.0, theta=0.0
% INFO    : Bus 60469	: V=1.0053927, theta=0.915163 -> V=1.0, theta=0.0
% INFO    : Bus 60470	: V=1.0030056, theta=0.47378 -> V=1.0, theta=0.0
% INFO    : Bus 60471	: V=1.0030013, theta=0.574442 -> V=1.0, theta=0.0
% INFO    : Bus 60472	: V=1.0011678, theta=0.122341 -> V=1.0, theta=0.0
% INFO    : Bus 60473	: V=0.9993013, theta=-0.223857 -> V=1.0, theta=0.0
% INFO    : Bus 60474	: V=0.9963706, theta=-0.688667 -> V=1.0, theta=0.0
% INFO    : Bus 60475	: V=0.9998995, theta=-0.124022 -> V=1.0, theta=0.0
% INFO    : Bus 60476	: V=0.9940954, theta=-0.990597 -> V=1.0, theta=0.0
% INFO    : Bus 60477	: V=0.9964984, theta=-0.672745 -> V=1.0, theta=0.0
% INFO    : Bus 60478	: V=1.0012145, theta=0.255895 -> V=1.0, theta=0.0
% INFO    : Bus 60479	: V=0.9935839, theta=-1.508889 -> V=1.0, theta=0.0
% INFO    : Bus 60480	: V=0.9894742, theta=-2.08278 -> V=1.0, theta=0.0
% INFO    : Bus 60481	: V=0.9846, theta=-2.573073 -> V=1.0, theta=0.0
% INFO    : Bus 60482	: V=0.9977001, theta=-0.248015 -> V=1.0, theta=0.0
% INFO    : Bus 60483	: V=0.9944031, theta=-0.555047 -> V=1.0, theta=0.0
% INFO    : Bus 60484	: V=0.995951, theta=-0.562602 -> V=1.0, theta=0.0
% INFO    : Bus 60485	: V=0.9936124, theta=-1.003783 -> V=1.0, theta=0.0
% INFO    : Bus 60486	: V=0.986494, theta=-2.096918 -> V=1.0, theta=0.0
% INFO    : Bus 60487	: V=0.9915092, theta=-1.41687 -> V=1.0, theta=0.0
% INFO    : Bus 60488	: V=0.9902679, theta=-1.679046 -> V=1.0, theta=0.0
% INFO    : Bus 60489	: V=0.9850072, theta=-2.891359 -> V=1.0, theta=0.0
% INFO    : Bus 60490	: V=0.9832593, theta=-2.71133 -> V=1.0, theta=0.0
% INFO    : Bus 60491	: V=0.9936412, theta=-1.705238 -> V=1.0, theta=0.0
% INFO    : Bus 60492	: V=0.9910735, theta=-1.738168 -> V=1.0, theta=0.0
% INFO    : Bus 60493	: V=0.9825357, theta=-3.07095 -> V=1.0, theta=0.0
% INFO    : Bus 60494	: V=0.9915497, theta=-1.60799 -> V=1.0, theta=0.0
% INFO    : Bus 60495	: V=0.9816524, theta=-3.215923 -> V=1.0, theta=0.0
% INFO    : Bus 60496	: V=0.9842725, theta=-7.71874 -> V=1.0, theta=0.0
% INFO    : Bus 60497	: V=0.9917297, theta=-2.161765 -> V=1.0, theta=0.0
% INFO    : Bus 60498	: V=0.9995501, theta=-0.651702 -> V=1.0, theta=0.0
% INFO    : Bus 60499	: V=1.0004995, theta=-0.566185 -> V=1.0, theta=0.0
% INFO    : Bus 60500	: V=1.0009437, theta=-0.53 -> V=1.0, theta=0.0
% INFO    : Bus 60501	: V=1.0018305, theta=-0.417538 -> V=1.0, theta=0.0
% INFO    : Bus 60502	: V=0.9965155, theta=-1.193231 -> V=1.0, theta=0.0
% INFO    : Bus 60503	: V=1.0016684, theta=-0.428064 -> V=1.0, theta=0.0
% INFO    : Bus 60504	: V=1.0004435, theta=-0.544641 -> V=1.0, theta=0.0
% INFO    : Bus 60505	: V=0.992782, theta=-2.076967 -> V=1.0, theta=0.0
% INFO    : Bus 60506	: V=0.9925261, theta=-2.08347 -> V=1.0, theta=0.0
% INFO    : Bus 60507	: V=0.9992503, theta=-0.915323 -> V=1.0, theta=0.0
% INFO    : Bus 60508	: V=1.0012745, theta=-0.436187 -> V=1.0, theta=0.0
% INFO    : Bus 60509	: V=1.0017729, theta=-0.396734 -> V=1.0, theta=0.0
% INFO    : Bus 60510	: V=0.9973073, theta=-1.154547 -> V=1.0, theta=0.0
% INFO    : Bus 60511	: V=1.0029452, theta=-0.273714 -> V=1.0, theta=0.0
% INFO    : Bus 60512	: V=1.0001178, theta=-1.144222 -> V=1.0, theta=0.0
% INFO    : Bus 60513	: V=0.9995978, theta=-1.172535 -> V=1.0, theta=0.0
% INFO    : Bus 60514	: V=0.9987437, theta=-1.187247 -> V=1.0, theta=0.0
% INFO    : Bus 60515	: V=1.0036396, theta=-0.181563 -> V=1.0, theta=0.0
% INFO    : Bus 60516	: V=0.9981423, theta=-0.850782 -> V=1.0, theta=0.0
% INFO    : Bus 60517	: V=1.0025189, theta=-0.299579 -> V=1.0, theta=0.0
% INFO    : Bus 60518	: V=0.9999869, theta=-0.81583 -> V=1.0, theta=0.0
% INFO    : Bus 60519	: V=1.0019567, theta=-0.330491 -> V=1.0, theta=0.0
% INFO    : Bus 60520	: V=0.9944544, theta=-1.896494 -> V=1.0, theta=0.0
% INFO    : Bus 60521	: V=0.9963264, theta=-1.721388 -> V=1.0, theta=0.0
% INFO    : Bus 60522	: V=1.0026731, theta=-0.231193 -> V=1.0, theta=0.0
% INFO    : Bus 60523	: V=1.0029539, theta=-0.192687 -> V=1.0, theta=0.0
% INFO    : Bus 60524	: V=1.0032502, theta=-0.190073 -> V=1.0, theta=0.0
% INFO    : Bus 60525	: V=1.0040263, theta=-0.109362 -> V=1.0, theta=0.0
% INFO    : Bus 60526	: V=1.0047225, theta=-0.025833 -> V=1.0, theta=0.0
% INFO    : Bus 60527	: V=1.0049121, theta=-0.014688 -> V=1.0, theta=0.0
% INFO    : Bus 60528	: V=1.0007821, theta=-1.101815 -> V=1.0, theta=0.0
% INFO    : Bus 60529	: V=1.0058717, theta=0.105692 -> V=1.0, theta=0.0
% INFO    : Bus 60530	: V=1.0058064, theta=0.108546 -> V=1.0, theta=0.0
% INFO    : Bus 60531	: V=0.9942046, theta=-1.871084 -> V=1.0, theta=0.0
% INFO    : Bus 60532	: V=0.9947419, theta=-1.856446 -> V=1.0, theta=0.0
% INFO    : Bus 60533	: V=1.0035694, theta=-0.131691 -> V=1.0, theta=0.0
% INFO    : Bus 60534	: V=0.9978037, theta=-1.548723 -> V=1.0, theta=0.0
% INFO    : Bus 60535	: V=0.9972956, theta=-1.596315 -> V=1.0, theta=0.0
% INFO    : Bus 60536	: V=0.9953854, theta=-1.677967 -> V=1.0, theta=0.0
% INFO    : Bus 60537	: V=0.9954416, theta=-1.695201 -> V=1.0, theta=0.0
% INFO    : Bus 60538	: V=1.0026513, theta=-0.200974 -> V=1.0, theta=0.0
% INFO    : Bus 60539	: V=1.0038271, theta=-0.082776 -> V=1.0, theta=0.0
% INFO    : Bus 60540	: V=1.0038168, theta=-0.056833 -> V=1.0, theta=0.0
% INFO    : Bus 60541	: V=1.0036685, theta=-0.090169 -> V=1.0, theta=0.0
% INFO    : Bus 60542	: V=0.9991937, theta=-0.946022 -> V=1.0, theta=0.0
% INFO    : Bus 60543	: V=0.9967381, theta=-1.166453 -> V=1.0, theta=0.0
% INFO    : Bus 60544	: V=1.0300007, theta=4.129879 -> V=1.0, theta=0.0
% INFO    : Bus 60545	: V=1.005845, theta=0.139252 -> V=1.0, theta=0.0
% INFO    : Bus 60546	: V=1.0052328, theta=0.079902 -> V=1.0, theta=0.0
% INFO    : Bus 60547	: V=0.9991186, theta=-0.964052 -> V=1.0, theta=0.0
% INFO    : Bus 60548	: V=0.9989031, theta=-0.977327 -> V=1.0, theta=0.0
% INFO    : Bus 60549	: V=0.9990364, theta=-0.973277 -> V=1.0, theta=0.0
% INFO    : Bus 60550	: V=1.0044074, theta=0.004017 -> V=1.0, theta=0.0
% INFO    : Bus 60551	: V=1.0200007, theta=2.649072 -> V=1.0, theta=0.0
% INFO    : Bus 60552	: V=1.0049771, theta=0.060693 -> V=1.0, theta=0.0
% INFO    : Bus 60553	: V=0.9856757, theta=-2.443345 -> V=1.0, theta=0.0
% INFO    : Bus 60554	: V=1.0016072, theta=-0.130623 -> V=1.0, theta=0.0
% INFO    : Bus 60555	: V=1.029846, theta=4.212523 -> V=1.0, theta=0.0
% INFO    : Bus 60556	: V=1.0047679, theta=0.136465 -> V=1.0, theta=0.0
% INFO    : Bus 60557	: V=1.0054149, theta=0.132194 -> V=1.0, theta=0.0
% INFO    : Bus 60558	: V=0.9951964, theta=-1.746537 -> V=1.0, theta=0.0
% INFO    : Bus 60559	: V=1.0017828, theta=-0.283875 -> V=1.0, theta=0.0
% INFO    : Bus 60560	: V=0.9988917, theta=-0.738791 -> V=1.0, theta=0.0
% INFO    : Bus 60561	: V=1.0001697, theta=-0.583733 -> V=1.0, theta=0.0
% INFO    : Bus 60562	: V=0.9979052, theta=-0.858289 -> V=1.0, theta=0.0
% INFO    : Bus 60563	: V=0.9948768, theta=-1.198664 -> V=1.0, theta=0.0
% INFO    : Bus 60564	: V=0.9953242, theta=-1.189349 -> V=1.0, theta=0.0
% INFO    : Bus 60565	: V=0.9961092, theta=-1.30416 -> V=1.0, theta=0.0
% INFO    : Bus 60566	: V=1.0042151, theta=0.179433 -> V=1.0, theta=0.0
% INFO    : Bus 60567	: V=0.9959094, theta=-1.680772 -> V=1.0, theta=0.0
% INFO    : Bus 60568	: V=1.0045715, theta=0.21145 -> V=1.0, theta=0.0
% INFO    : Bus 60569	: V=1.0049203, theta=0.246056 -> V=1.0, theta=0.0
% INFO    : Bus 60570	: V=1.0052655, theta=0.296617 -> V=1.0, theta=0.0
% INFO    : Bus 60571	: V=1.0052618, theta=0.293945 -> V=1.0, theta=0.0
% INFO    : Bus 60572	: V=1.0010516, theta=-0.161299 -> V=1.0, theta=0.0
% INFO    : Bus 60573	: V=1.0013886, theta=-0.15176 -> V=1.0, theta=0.0
% INFO    : Bus 60574	: V=0.997697, theta=-0.956602 -> V=1.0, theta=0.0
% INFO    : Bus 60575	: V=0.9975826, theta=-0.917158 -> V=1.0, theta=0.0
% INFO    : Bus 60576	: V=0.9990072, theta=-0.460683 -> V=1.0, theta=0.0
% INFO    : Bus 60577	: V=0.9998655, theta=-0.442015 -> V=1.0, theta=0.0
% INFO    : Bus 60578	: V=0.9985197, theta=-0.886979 -> V=1.0, theta=0.0
% INFO    : Bus 60579	: V=1.0053194, theta=0.313005 -> V=1.0, theta=0.0
% INFO    : Bus 60580	: V=1.0043601, theta=0.099602 -> V=1.0, theta=0.0
% INFO    : Bus 60581	: V=1.0115547, theta=1.711146 -> V=1.0, theta=0.0
% INFO    : Bus 60582	: V=1.0041269, theta=0.116547 -> V=1.0, theta=0.0
% INFO    : Bus 60583	: V=1.0037883, theta=0.106669 -> V=1.0, theta=0.0
% INFO    : Bus 60584	: V=1.0021735, theta=-0.125375 -> V=1.0, theta=0.0
% INFO    : Bus 60585	: V=1.0032869, theta=-0.035092 -> V=1.0, theta=0.0
% INFO    : Bus 60586	: V=1.0025072, theta=-0.059585 -> V=1.0, theta=0.0
% INFO    : Bus 60587	: V=1.0063414, theta=0.566862 -> V=1.0, theta=0.0
% INFO    : Bus 60588	: V=0.9988254, theta=-0.786465 -> V=1.0, theta=0.0
% INFO    : Bus 60589	: V=1.0025269, theta=-0.346274 -> V=1.0, theta=0.0
% INFO    : Bus 60590	: V=1.0068627, theta=0.610217 -> V=1.0, theta=0.0
% INFO    : Bus 60591	: V=1.0065079, theta=0.534571 -> V=1.0, theta=0.0
% INFO    : Bus 60592	: V=1.0040049, theta=0.134838 -> V=1.0, theta=0.0
% INFO    : Bus 60593	: V=1.0295786, theta=4.430612 -> V=1.0, theta=0.0
% INFO    : Bus 60594	: V=1.0077966, theta=0.769425 -> V=1.0, theta=0.0
% INFO    : Bus 60595	: V=0.996966, theta=-1.174065 -> V=1.0, theta=0.0
% INFO    : Bus 60596	: V=0.991643, theta=-1.715504 -> V=1.0, theta=0.0
% INFO    : Bus 60597	: V=0.9914296, theta=-1.736125 -> V=1.0, theta=0.0
% INFO    : Bus 60598	: V=0.9924382, theta=-1.696097 -> V=1.0, theta=0.0
% INFO    : Bus 60599	: V=0.9934339, theta=-1.674493 -> V=1.0, theta=0.0
% INFO    : Bus 60600	: V=1.0046502, theta=0.400257 -> V=1.0, theta=0.0
% INFO    : Bus 60601	: V=1.0069515, theta=0.771832 -> V=1.0, theta=0.0
% INFO    : Bus 60602	: V=1.0059683, theta=0.75156 -> V=1.0, theta=0.0
% INFO    : Bus 60603	: V=1.0079658, theta=0.913641 -> V=1.0, theta=0.0
% INFO    : Bus 60604	: V=1.0052307, theta=0.528231 -> V=1.0, theta=0.0
% INFO    : Bus 60605	: V=1.0066549, theta=0.717127 -> V=1.0, theta=0.0
% INFO    : Bus 60606	: V=1.0094798, theta=1.082887 -> V=1.0, theta=0.0
% INFO    : Bus 60607	: V=1.0096912, theta=1.09741 -> V=1.0, theta=0.0
% INFO    : Bus 60608	: V=0.9929272, theta=-1.649725 -> V=1.0, theta=0.0
% INFO    : Bus 60609	: V=0.9910668, theta=-1.699964 -> V=1.0, theta=0.0
% INFO    : Bus 60610	: V=1.0036524, theta=0.334933 -> V=1.0, theta=0.0
% INFO    : Bus 60611	: V=1.0031263, theta=0.323896 -> V=1.0, theta=0.0
% INFO    : Bus 60612	: V=1.0083148, theta=1.043048 -> V=1.0, theta=0.0
% INFO    : Bus 60613	: V=1.0291851, theta=4.819839 -> V=1.0, theta=0.0
% INFO    : Bus 60614	: V=1.0090497, theta=1.000045 -> V=1.0, theta=0.0
% INFO    : Bus 60615	: V=1.0196562, theta=2.706965 -> V=1.0, theta=0.0
% INFO    : Bus 60616	: V=1.0088082, theta=0.780447 -> V=1.0, theta=0.0
% INFO    : Bus 60617	: V=1.0082397, theta=0.686838 -> V=1.0, theta=0.0
% INFO    : Bus 60618	: V=1.0100007, theta=1.884123 -> V=1.0, theta=0.0
% INFO    : Bus 60619	: V=1.0080774, theta=1.017332 -> V=1.0, theta=0.0
% INFO    : Bus 60620	: V=0.9980107, theta=-0.824876 -> V=1.0, theta=0.0
% INFO    : Bus 60621	: V=0.9974545, theta=-1.023178 -> V=1.0, theta=0.0
% INFO    : Bus 60622	: V=0.9971345, theta=-0.84967 -> V=1.0, theta=0.0
% INFO    : Bus 60623	: V=0.9948257, theta=-1.083279 -> V=1.0, theta=0.0
% INFO    : Bus 60624	: V=1.0197355, theta=2.673901 -> V=1.0, theta=0.0
% INFO    : Bus 60625	: V=1.0091064, theta=0.955179 -> V=1.0, theta=0.0
% INFO    : Bus 60626	: V=1.0200007, theta=2.614504 -> V=1.0, theta=0.0
% INFO    : Bus 60627	: V=0.9958086, theta=-1.066155 -> V=1.0, theta=0.0
% INFO    : Bus 60628	: V=0.9954677, theta=-1.07595 -> V=1.0, theta=0.0
% INFO    : Bus 60629	: V=0.9939581, theta=-1.613335 -> V=1.0, theta=0.0
% INFO    : Bus 60630	: V=0.9925419, theta=-1.811338 -> V=1.0, theta=0.0
% INFO    : Bus 60631	: V=0.997259, theta=-0.932887 -> V=1.0, theta=0.0
% INFO    : Bus 60632	: V=0.9966533, theta=-0.984054 -> V=1.0, theta=0.0
% INFO    : Bus 60633	: V=0.9907434, theta=-1.921704 -> V=1.0, theta=0.0
% INFO    : Bus 60634	: V=0.9975272, theta=-0.892294 -> V=1.0, theta=0.0
% INFO    : Bus 60635	: V=0.9943524, theta=-1.724765 -> V=1.0, theta=0.0
% INFO    : Bus 60636	: V=0.9979541, theta=-0.878863 -> V=1.0, theta=0.0
% INFO    : Bus 60637	: V=0.9956033, theta=-1.577625 -> V=1.0, theta=0.0
% INFO    : Bus 60638	: V=0.9971826, theta=-1.380038 -> V=1.0, theta=0.0
% INFO    : Bus 60639	: V=0.9932531, theta=-2.029215 -> V=1.0, theta=0.0
% INFO    : Bus 60640	: V=0.9911581, theta=-2.238147 -> V=1.0, theta=0.0
% INFO    : Bus 60641	: V=0.9904966, theta=-2.199776 -> V=1.0, theta=0.0
% INFO    : Bus 60642	: V=0.9891172, theta=-2.473969 -> V=1.0, theta=0.0
% INFO    : Bus 60643	: V=0.9857964, theta=-2.682912 -> V=1.0, theta=0.0
% INFO    : Bus 60644	: V=0.9934754, theta=-1.256242 -> V=1.0, theta=0.0
% INFO    : Bus 60645	: V=0.9829874, theta=-2.952385 -> V=1.0, theta=0.0
% INFO    : Bus 60646	: V=0.9830591, theta=-2.896027 -> V=1.0, theta=0.0
% INFO    : Bus 60647	: V=0.982255, theta=-3.002896 -> V=1.0, theta=0.0
% INFO    : Bus 60648	: V=0.9822165, theta=-2.986201 -> V=1.0, theta=0.0
% INFO    : Bus 60649	: V=0.9862433, theta=-2.515297 -> V=1.0, theta=0.0
% INFO    : Bus 60650	: V=0.9816941, theta=-2.929406 -> V=1.0, theta=0.0
% INFO    : Bus 60651	: V=0.9783664, theta=-3.071264 -> V=1.0, theta=0.0
% INFO    : Bus 60652	: V=0.9836901, theta=-2.685084 -> V=1.0, theta=0.0
% INFO    : Bus 60653	: V=0.9770725, theta=-3.113374 -> V=1.0, theta=0.0
% INFO    : Bus 60654	: V=0.9833357, theta=-2.828005 -> V=1.0, theta=0.0
% INFO    : Bus 60655	: V=0.9864821, theta=-2.539627 -> V=1.0, theta=0.0
% INFO    : Bus 60656	: V=0.9870822, theta=-2.508333 -> V=1.0, theta=0.0
% INFO    : Bus 60657	: V=0.9884104, theta=-2.261499 -> V=1.0, theta=0.0
% INFO    : Bus 60658	: V=0.9814814, theta=-2.803093 -> V=1.0, theta=0.0
% INFO    : Bus 60659	: V=0.9826161, theta=-2.744888 -> V=1.0, theta=0.0
% INFO    : Bus 60660	: V=0.9844305, theta=-2.735557 -> V=1.0, theta=0.0
% INFO    : Bus 60661	: V=0.9866512, theta=-2.635182 -> V=1.0, theta=0.0
% INFO    : Bus 60662	: V=0.9839542, theta=-2.7135 -> V=1.0, theta=0.0
% INFO    : Bus 60663	: V=0.998242, theta=-0.575092 -> V=1.0, theta=0.0
% INFO    : Bus 60664	: V=0.9980187, theta=-0.569364 -> V=1.0, theta=0.0
% INFO    : Bus 60665	: V=0.9817617, theta=-2.975696 -> V=1.0, theta=0.0
% INFO    : Bus 60666	: V=0.9924235, theta=-1.707012 -> V=1.0, theta=0.0
% INFO    : Bus 60667	: V=0.9980797, theta=-0.219642 -> V=1.0, theta=0.0
% INFO    : Bus 60668	: V=0.994064, theta=-1.424481 -> V=1.0, theta=0.0
% INFO    : Bus 60669	: V=0.9944105, theta=-1.387041 -> V=1.0, theta=0.0
% INFO    : Bus 60670	: V=0.9939855, theta=-1.415072 -> V=1.0, theta=0.0
% INFO    : Bus 60671	: V=0.9936063, theta=-1.432131 -> V=1.0, theta=0.0
% INFO    : Bus 60672	: V=0.9979657, theta=-0.933231 -> V=1.0, theta=0.0
% INFO    : Bus 60673	: V=0.9956946, theta=-1.238401 -> V=1.0, theta=0.0
% INFO    : Bus 60674	: V=0.9997807, theta=-0.519199 -> V=1.0, theta=0.0
% INFO    : Bus 60675	: V=0.999111, theta=-0.537553 -> V=1.0, theta=0.0
% INFO    : Bus 60676	: V=1.0022287, theta=-0.264006 -> V=1.0, theta=0.0
% INFO    : Bus 60677	: V=1.0077847, theta=1.093055 -> V=1.0, theta=0.0
% INFO    : Bus 60678	: V=0.9985648, theta=-0.59748 -> V=1.0, theta=0.0
% INFO    : Bus 60679	: V=0.9989746, theta=-0.627351 -> V=1.0, theta=0.0
% INFO    : Bus 60680	: V=0.9995375, theta=-0.569688 -> V=1.0, theta=0.0
% INFO    : Bus 60681	: V=0.9969303, theta=-0.425912 -> V=1.0, theta=0.0
% INFO    : Bus 60682	: V=1.0039943, theta=0.666722 -> V=1.0, theta=0.0
% INFO    : Bus 60683	: V=1.0059835, theta=1.009984 -> V=1.0, theta=0.0
% INFO    : Bus 60684	: V=1.0083853, theta=1.495024 -> V=1.0, theta=0.0
% INFO    : Bus 60685	: V=0.994944, theta=-0.443811 -> V=1.0, theta=0.0
% INFO    : Bus 60686	: V=1.0026121, theta=0.484498 -> V=1.0, theta=0.0
% INFO    : Bus 60687	: V=0.9977839, theta=-0.652502 -> V=1.0, theta=0.0
% INFO    : Bus 60688	: V=1.0030298, theta=0.522506 -> V=1.0, theta=0.0
% INFO    : Bus 60689	: V=1.0008397, theta=0.20529 -> V=1.0, theta=0.0
% INFO    : Bus 60690	: V=0.995889, theta=-0.418726 -> V=1.0, theta=0.0
% INFO    : Bus 60691	: V=0.9964531, theta=-0.588191 -> V=1.0, theta=0.0
% INFO    : Bus 60692	: V=1.0022259, theta=0.323573 -> V=1.0, theta=0.0
% INFO    : Bus 60693	: V=0.9972488, theta=-0.367503 -> V=1.0, theta=0.0
% INFO    : Bus 60694	: V=1.0012485, theta=0.228652 -> V=1.0, theta=0.0
% INFO    : Bus 60695	: V=1.0008269, theta=0.189711 -> V=1.0, theta=0.0
% INFO    : Bus 60696	: V=0.9947018, theta=-1.285785 -> V=1.0, theta=0.0
% INFO    : Bus 60697	: V=0.9995466, theta=-0.133529 -> V=1.0, theta=0.0
% INFO    : Bus 60698	: V=1.0010187, theta=0.026504 -> V=1.0, theta=0.0
% INFO    : Bus 60699	: V=1.0021656, theta=0.184182 -> V=1.0, theta=0.0
% INFO    : Bus 60700	: V=1.004353, theta=0.624027 -> V=1.0, theta=0.0
% INFO    : Bus 60701	: V=1.0056984, theta=0.44236 -> V=1.0, theta=0.0
% INFO    : Bus 60702	: V=1.0003827, theta=0.117897 -> V=1.0, theta=0.0
% INFO    : Bus 60703	: V=1.0044808, theta=0.642922 -> V=1.0, theta=0.0
% INFO    : Bus 60704	: V=1.0037204, theta=0.622465 -> V=1.0, theta=0.0
% INFO    : Bus 60705	: V=1.0037351, theta=0.603587 -> V=1.0, theta=0.0
% INFO    : Bus 60706	: V=1.0020652, theta=0.499046 -> V=1.0, theta=0.0
% INFO    : Bus 60707	: V=1.0039248, theta=0.611985 -> V=1.0, theta=0.0
% INFO    : Bus 60708	: V=1.0043096, theta=0.631889 -> V=1.0, theta=0.0
% INFO    : Bus 60709	: V=1.0040377, theta=0.625878 -> V=1.0, theta=0.0
% INFO    : Bus 60710	: V=0.9933206, theta=-0.545213 -> V=1.0, theta=0.0
% INFO    : Bus 60711	: V=0.9896227, theta=-0.668697 -> V=1.0, theta=0.0
% INFO    : Bus 60712	: V=0.9963863, theta=-0.387504 -> V=1.0, theta=0.0
% INFO    : Bus 60713	: V=0.9972708, theta=-0.289382 -> V=1.0, theta=0.0
% INFO    : Bus 60714	: V=0.9980616, theta=-0.327633 -> V=1.0, theta=0.0
% INFO    : Bus 60715	: V=1.0057071, theta=0.721997 -> V=1.0, theta=0.0
% INFO    : Bus 60716	: V=0.998641, theta=-0.305355 -> V=1.0, theta=0.0
% INFO    : Bus 60717	: V=0.9975585, theta=-0.274307 -> V=1.0, theta=0.0
% INFO    : Bus 60718	: V=0.9964179, theta=-0.305496 -> V=1.0, theta=0.0
% INFO    : Bus 60719	: V=0.9968438, theta=-0.25977 -> V=1.0, theta=0.0
% INFO    : Bus 60720	: V=0.997531, theta=-0.200135 -> V=1.0, theta=0.0
% INFO    : Bus 60721	: V=0.9906951, theta=-2.021774 -> V=1.0, theta=0.0
% INFO    : Bus 60722	: V=0.9893646, theta=-2.104337 -> V=1.0, theta=0.0
% INFO    : Bus 60723	: V=0.9912906, theta=-2.059572 -> V=1.0, theta=0.0
% INFO    : Bus 60724	: V=0.9900559, theta=-2.088991 -> V=1.0, theta=0.0
% INFO    : Bus 60725	: V=0.9927914, theta=-1.975102 -> V=1.0, theta=0.0
% INFO    : Bus 60726	: V=0.9943103, theta=-1.836452 -> V=1.0, theta=0.0
% INFO    : Bus 60727	: V=1.000739, theta=-0.152479 -> V=1.0, theta=0.0
% INFO    : Bus 60728	: V=0.9992313, theta=-0.282816 -> V=1.0, theta=0.0
% INFO    : Bus 60729	: V=1.0122945, theta=1.898382 -> V=1.0, theta=0.0
% INFO    : Bus 60730	: V=1.0300007, theta=3.752067 -> V=1.0, theta=0.0
% INFO    : Bus 60731	: V=1.0066044, theta=0.042093 -> V=1.0, theta=0.0
% INFO    : Bus 60732	: V=1.0200007, theta=2.76149 -> V=1.0, theta=0.0
% INFO    : Bus 60733	: V=1.0063138, theta=0.79838 -> V=1.0, theta=0.0
% INFO    : Bus 60734	: V=0.996738, theta=-1.037394 -> V=1.0, theta=0.0
% INFO    : Bus 60735	: V=1.0052777, theta=0.779534 -> V=1.0, theta=0.0
% INFO    : Bus 60736	: V=1.0094501, theta=1.752704 -> V=1.0, theta=0.0
% INFO    : Bus 60737	: V=1.0075207, theta=0.699796 -> V=1.0, theta=0.0
% INFO    : Bus 60738	: V=1.0030503, theta=-0.128091 -> V=1.0, theta=0.0
% INFO    : Bus 60739	: V=1.0200007, theta=2.732018 -> V=1.0, theta=0.0
% INFO    : Bus 60740	: V=1.0100007, theta=1.948348 -> V=1.0, theta=0.0
% INFO    : Bus 60741	: V=1.0085142, theta=0.877141 -> V=1.0, theta=0.0
% INFO    : Bus 60742	: V=1.0027577, theta=-0.131906 -> V=1.0, theta=0.0
% INFO    : Bus 60743	: V=1.0072028, theta=0.657118 -> V=1.0, theta=0.0
% INFO    : Bus 60744	: V=1.002373, theta=-0.118334 -> V=1.0, theta=0.0
% INFO    : Bus 60745	: V=1.0068145, theta=0.512931 -> V=1.0, theta=0.0
% INFO    : Bus 60746	: V=0.9914928, theta=-1.626632 -> V=1.0, theta=0.0
% INFO    : Bus 60747	: V=0.9994561, theta=-0.968669 -> V=1.0, theta=0.0
% INFO    : Bus 60748	: V=1.0069572, theta=0.608899 -> V=1.0, theta=0.0
% INFO    : Bus 60749	: V=1.007296, theta=0.645905 -> V=1.0, theta=0.0
% INFO    : Bus 60750	: V=1.0085127, theta=0.839685 -> V=1.0, theta=0.0
% INFO    : Bus 60751	: V=1.0096666, theta=0.945573 -> V=1.0, theta=0.0
% INFO    : Bus 60752	: V=1.0113314, theta=1.403159 -> V=1.0, theta=0.0
% INFO    : Bus 60753	: V=1.0100007, theta=1.264492 -> V=1.0, theta=0.0
% INFO    : Bus 60754	: V=1.0100007, theta=1.345221 -> V=1.0, theta=0.0
% INFO    : Bus 60755	: V=1.0006962, theta=-0.60231 -> V=1.0, theta=0.0
% INFO    : Bus 60756	: V=0.9981632, theta=-0.656041 -> V=1.0, theta=0.0
% INFO    : Bus 60757	: V=0.994321, theta=-1.466756 -> V=1.0, theta=0.0
% INFO    : Bus 60758	: V=0.9958464, theta=-1.433447 -> V=1.0, theta=0.0
% INFO    : Bus 60759	: V=0.9975448, theta=-1.21102 -> V=1.0, theta=0.0
% INFO    : Bus 60760	: V=0.9945186, theta=-1.562239 -> V=1.0, theta=0.0
% INFO    : Bus 60761	: V=0.9962307, theta=-1.533553 -> V=1.0, theta=0.0
% INFO    : Bus 60762	: V=0.9960127, theta=-2.239105 -> V=1.0, theta=0.0
% INFO    : Bus 60763	: V=0.9968447, theta=-2.215942 -> V=1.0, theta=0.0
% INFO    : Bus 60764	: V=1.0056821, theta=-0.087246 -> V=1.0, theta=0.0
% INFO    : Bus 60765	: V=0.9981554, theta=-1.415553 -> V=1.0, theta=0.0
% INFO    : Bus 60766	: V=1.0058028, theta=-0.051848 -> V=1.0, theta=0.0
% INFO    : Bus 60767	: V=0.9926572, theta=-2.164725 -> V=1.0, theta=0.0
% INFO    : Bus 60768	: V=1.0050998, theta=-0.050137 -> V=1.0, theta=0.0
% INFO    : Bus 60769	: V=1.006176, theta=0.023403 -> V=1.0, theta=0.0
% INFO    : Bus 60770	: V=1.0300007, theta=3.405063 -> V=1.0, theta=0.0
% INFO    : Bus 60771	: V=1.008157, theta=0.584699 -> V=1.0, theta=0.0
% INFO    : Bus 60772	: V=0.9947593, theta=-1.571668 -> V=1.0, theta=0.0
% INFO    : Bus 60773	: V=1.0037988, theta=0.161111 -> V=1.0, theta=0.0
% INFO    : Bus 60774	: V=1.0025582, theta=0.13041 -> V=1.0, theta=0.0
% INFO    : Bus 60775	: V=0.9902572, theta=-2.063607 -> V=1.0, theta=0.0
% INFO    : Bus 60776	: V=0.9922927, theta=-2.102227 -> V=1.0, theta=0.0
% INFO    : Bus 60777	: V=0.9912197, theta=-2.145801 -> V=1.0, theta=0.0
% INFO    : Bus 60778	: V=0.9909776, theta=-2.238688 -> V=1.0, theta=0.0
% INFO    : Bus 60779	: V=0.9929428, theta=-2.184206 -> V=1.0, theta=0.0
% INFO    : Bus 60780	: V=0.9923038, theta=-2.198673 -> V=1.0, theta=0.0
% INFO    : Bus 60781	: V=0.9910774, theta=-1.861565 -> V=1.0, theta=0.0
% INFO    : Bus 60782	: V=1.0034375, theta=-0.289288 -> V=1.0, theta=0.0
% INFO    : Bus 60783	: V=0.9923244, theta=-1.767696 -> V=1.0, theta=0.0
% INFO    : Bus 60784	: V=0.9974079, theta=-1.417301 -> V=1.0, theta=0.0
% INFO    : Bus 60785	: V=0.9960473, theta=-1.53476 -> V=1.0, theta=0.0
% INFO    : Bus 60786	: V=1.0035223, theta=-0.354458 -> V=1.0, theta=0.0
% INFO    : Bus 60787	: V=1.0054345, theta=-0.033999 -> V=1.0, theta=0.0
% INFO    : Bus 60788	: V=0.9982819, theta=-1.450414 -> V=1.0, theta=0.0
% INFO    : Bus 60789	: V=0.998049, theta=-1.426072 -> V=1.0, theta=0.0
% INFO    : Bus 60790	: V=0.9985236, theta=-1.425136 -> V=1.0, theta=0.0
% INFO    : Bus 60791	: V=1.0052237, theta=-0.272313 -> V=1.0, theta=0.0
% INFO    : Bus 60792	: V=1.0000795, theta=-1.327219 -> V=1.0, theta=0.0
% INFO    : Bus 60793	: V=0.9994943, theta=-1.385277 -> V=1.0, theta=0.0
% INFO    : Bus 60794	: V=1.0036615, theta=-0.579893 -> V=1.0, theta=0.0
% INFO    : Bus 60795	: V=1.0049775, theta=-0.454415 -> V=1.0, theta=0.0
% INFO    : Bus 60796	: V=1.0045845, theta=-0.494162 -> V=1.0, theta=0.0
% INFO    : Bus 60797	: V=1.0039017, theta=-0.560649 -> V=1.0, theta=0.0
% INFO    : Bus 60798	: V=1.0043211, theta=-1.049292 -> V=1.0, theta=0.0
% INFO    : Bus 60799	: V=1.0055239, theta=-0.436377 -> V=1.0, theta=0.0
% INFO    : Bus 60800	: V=1.0058861, theta=-0.417289 -> V=1.0, theta=0.0
% INFO    : Bus 60801	: V=1.0049093, theta=-0.471374 -> V=1.0, theta=0.0
% INFO    : Bus 60802	: V=0.999962, theta=-1.180439 -> V=1.0, theta=0.0
% INFO    : Bus 60803	: V=1.005251, theta=-0.49379 -> V=1.0, theta=0.0
% INFO    : Bus 60804	: V=1.0053892, theta=-0.437627 -> V=1.0, theta=0.0
% INFO    : Bus 60805	: V=1.0046387, theta=-0.891573 -> V=1.0, theta=0.0
% INFO    : Bus 60806	: V=1.004331, theta=-0.571038 -> V=1.0, theta=0.0
% INFO    : Bus 60807	: V=0.9986576, theta=-1.279225 -> V=1.0, theta=0.0
% INFO    : Bus 60808	: V=0.996822, theta=-1.403368 -> V=1.0, theta=0.0
% INFO    : Bus 60809	: V=1.0033259, theta=-0.926772 -> V=1.0, theta=0.0
% INFO    : Bus 60810	: V=1.0026487, theta=-0.956177 -> V=1.0, theta=0.0
% INFO    : Bus 60811	: V=1.0100007, theta=0.433926 -> V=1.0, theta=0.0
% INFO    : Bus 60812	: V=0.9980601, theta=-1.470633 -> V=1.0, theta=0.0
% INFO    : Bus 60813	: V=0.9988149, theta=-1.336834 -> V=1.0, theta=0.0
% INFO    : Bus 60814	: V=1.0016567, theta=-0.964728 -> V=1.0, theta=0.0
% INFO    : Bus 60815	: V=1.0015847, theta=-0.979426 -> V=1.0, theta=0.0
% INFO    : Bus 60816	: V=1.001839, theta=-0.964815 -> V=1.0, theta=0.0
% INFO    : Bus 60817	: V=0.9961141, theta=-1.995141 -> V=1.0, theta=0.0
% INFO    : Bus 60818	: V=1.0020066, theta=-0.972607 -> V=1.0, theta=0.0
% INFO    : Bus 60819	: V=1.0013513, theta=-1.031882 -> V=1.0, theta=0.0
% INFO    : Bus 60820	: V=0.9932157, theta=-2.277891 -> V=1.0, theta=0.0
% INFO    : Bus 60821	: V=1.0004436, theta=-1.108821 -> V=1.0, theta=0.0
% INFO    : Bus 60822	: V=0.9854197, theta=-2.896283 -> V=1.0, theta=0.0
% INFO    : Bus 60823	: V=0.9909609, theta=-1.739227 -> V=1.0, theta=0.0
% INFO    : Bus 60824	: V=0.9952042, theta=-1.575553 -> V=1.0, theta=0.0
% INFO    : Bus 60825	: V=0.9951934, theta=-2.08318 -> V=1.0, theta=0.0
% INFO    : Bus 60826	: V=0.9806192, theta=-3.224179 -> V=1.0, theta=0.0
% INFO    : Bus 60827	: V=0.9774205, theta=-3.373074 -> V=1.0, theta=0.0
% INFO    : Bus 60828	: V=0.9754234, theta=-3.493083 -> V=1.0, theta=0.0
% INFO    : Bus 60829	: V=0.999976, theta=3.956351 -> V=1.0, theta=0.0
% INFO    : Bus 60830	: V=1.0200007, theta=7.655579 -> V=1.0, theta=0.0
% INFO    : Bus 60831	: V=0.9901188, theta=-1.686664 -> V=1.0, theta=0.0
% INFO    : Bus 60832	: V=0.9792415, theta=-2.093365 -> V=1.0, theta=0.0
% INFO    : Bus 60833	: V=0.9918652, theta=-1.323911 -> V=1.0, theta=0.0
% INFO    : Bus 60834	: V=0.9904893, theta=-1.524495 -> V=1.0, theta=0.0
% INFO    : Bus 60835	: V=0.9892321, theta=-1.846829 -> V=1.0, theta=0.0
% INFO    : Bus 60836	: V=0.9848889, theta=-1.997368 -> V=1.0, theta=0.0
% INFO    : Bus 60837	: V=0.9870453, theta=-1.958989 -> V=1.0, theta=0.0
% INFO    : Bus 60838	: V=0.9883738, theta=-1.932757 -> V=1.0, theta=0.0
% INFO    : Bus 60839	: V=0.9903995, theta=-1.706785 -> V=1.0, theta=0.0
% INFO    : Bus 60840	: V=1.002496, theta=1.165048 -> V=1.0, theta=0.0
% INFO    : Bus 60841	: V=1.0020853, theta=1.315054 -> V=1.0, theta=0.0
% INFO    : Bus 60842	: V=0.9940899, theta=-1.432659 -> V=1.0, theta=0.0
% INFO    : Bus 60843	: V=0.9924984, theta=-1.754232 -> V=1.0, theta=0.0
% INFO    : Bus 60844	: V=0.9915714, theta=-1.859343 -> V=1.0, theta=0.0
% INFO    : Bus 60845	: V=0.9908767, theta=-1.929658 -> V=1.0, theta=0.0
% INFO    : Bus 60846	: V=0.9925323, theta=-0.880245 -> V=1.0, theta=0.0
% INFO    : Bus 60847	: V=1.0045058, theta=2.655798 -> V=1.0, theta=0.0
% INFO    : Bus 60848	: V=0.9894216, theta=-1.712616 -> V=1.0, theta=0.0
% INFO    : Bus 60849	: V=0.9875389, theta=-1.774225 -> V=1.0, theta=0.0
% INFO    : Bus 60850	: V=0.987262, theta=-1.759443 -> V=1.0, theta=0.0
% INFO    : Bus 60851	: V=0.9923511, theta=-1.162263 -> V=1.0, theta=0.0
% INFO    : Bus 60852	: V=0.9984444, theta=1.744483 -> V=1.0, theta=0.0
% INFO    : Bus 60853	: V=0.9932631, theta=-1.137134 -> V=1.0, theta=0.0
% INFO    : Bus 60854	: V=0.9837172, theta=-1.31936 -> V=1.0, theta=0.0
% INFO    : Bus 60855	: V=1.0048122, theta=0.897788 -> V=1.0, theta=0.0
% INFO    : Bus 60856	: V=0.9908186, theta=-1.131676 -> V=1.0, theta=0.0
% INFO    : Bus 60857	: V=1.0200007, theta=3.104829 -> V=1.0, theta=0.0
% INFO    : Bus 60858	: V=1.0063231, theta=1.057086 -> V=1.0, theta=0.0
% INFO    : Bus 60859	: V=1.0195846, theta=3.418983 -> V=1.0, theta=0.0
% INFO    : Bus 60860	: V=1.0200007, theta=3.976275 -> V=1.0, theta=0.0
% INFO    : Bus 60861	: V=1.0110753, theta=2.256919 -> V=1.0, theta=0.0
% INFO    : Bus 60862	: V=1.0117083, theta=2.309895 -> V=1.0, theta=0.0
% INFO    : Bus 60863	: V=1.0063489, theta=1.106927 -> V=1.0, theta=0.0
% INFO    : Bus 60864	: V=1.0015229, theta=0.26551 -> V=1.0, theta=0.0
% INFO    : Bus 60865	: V=1.0003414, theta=0.125589 -> V=1.0, theta=0.0
% INFO    : Bus 60866	: V=0.9848752, theta=-2.360171 -> V=1.0, theta=0.0
% INFO    : Bus 60867	: V=0.9990635, theta=-0.137729 -> V=1.0, theta=0.0
% INFO    : Bus 60868	: V=0.9873032, theta=-1.926752 -> V=1.0, theta=0.0
% INFO    : Bus 60869	: V=1.0100007, theta=1.811365 -> V=1.0, theta=0.0
% INFO    : Bus 60870	: V=0.9989737, theta=0.011379 -> V=1.0, theta=0.0
% INFO    : Bus 60871	: V=1.0119058, theta=2.068739 -> V=1.0, theta=0.0
% INFO    : Bus 60872	: V=1.0133981, theta=2.279781 -> V=1.0, theta=0.0
% INFO    : Bus 60873	: V=1.0082213, theta=0.986205 -> V=1.0, theta=0.0
% INFO    : Bus 60874	: V=0.993912, theta=-0.727165 -> V=1.0, theta=0.0
% INFO    : Bus 60875	: V=0.9836465, theta=-2.652327 -> V=1.0, theta=0.0
% INFO    : Bus 60876	: V=0.9917793, theta=-1.377077 -> V=1.0, theta=0.0
% INFO    : Bus 60877	: V=0.99023, theta=-1.565761 -> V=1.0, theta=0.0
% INFO    : Bus 60878	: V=0.9944774, theta=-1.315358 -> V=1.0, theta=0.0
% INFO    : Bus 60879	: V=0.9953897, theta=-1.149029 -> V=1.0, theta=0.0
% INFO    : Bus 60880	: V=1.0002307, theta=0.040296 -> V=1.0, theta=0.0
% INFO    : Bus 60881	: V=0.9913208, theta=-1.52624 -> V=1.0, theta=0.0
% INFO    : Bus 60882	: V=0.9891677, theta=-1.58176 -> V=1.0, theta=0.0
% INFO    : Bus 60883	: V=1.0034111, theta=0.06694 -> V=1.0, theta=0.0
% INFO    : Bus 60884	: V=0.9998107, theta=0.035441 -> V=1.0, theta=0.0
% INFO    : Bus 60885	: V=0.9935499, theta=0.58012 -> V=1.0, theta=0.0
% INFO    : Bus 60886	: V=0.9838817, theta=-0.63646 -> V=1.0, theta=0.0
% INFO    : Bus 60887	: V=0.9947296, theta=1.809164 -> V=1.0, theta=0.0
% INFO    : Bus 60888	: V=1.0161329, theta=3.917099 -> V=1.0, theta=0.0
% INFO    : Bus 60889	: V=1.0200007, theta=4.716497 -> V=1.0, theta=0.0
% INFO    : Bus 60890	: V=1.0140663, theta=5.563102 -> V=1.0, theta=0.0
% INFO    : Bus 60891	: V=1.0200007, theta=5.053067 -> V=1.0, theta=0.0
% INFO    : Bus 60892	: V=1.0168598, theta=4.900957 -> V=1.0, theta=0.0
% INFO    : Bus 60893	: V=1.001264, theta=5.426522 -> V=1.0, theta=0.0
% INFO    : Bus 60894	: V=1.0207862, theta=4.241718 -> V=1.0, theta=0.0
% INFO    : Bus 60895	: V=1.0293189, theta=5.22632 -> V=1.0, theta=0.0
% INFO    : Bus 60896	: V=1.0199052, theta=4.203313 -> V=1.0, theta=0.0
% INFO    : Bus 60897	: V=1.0089395, theta=1.101262 -> V=1.0, theta=0.0
% INFO    : Bus 60898	: V=1.0080705, theta=1.075355 -> V=1.0, theta=0.0
% INFO    : Bus 60899	: V=1.0108247, theta=1.173575 -> V=1.0, theta=0.0
% INFO    : Bus 60900	: V=1.0200007, theta=4.371228 -> V=1.0, theta=0.0
% INFO    : Bus 60901	: V=1.0087778, theta=2.373556 -> V=1.0, theta=0.0
% INFO    : Bus 60902	: V=1.0067867, theta=2.324066 -> V=1.0, theta=0.0
% INFO    : Bus 60903	: V=1.0097989, theta=1.277195 -> V=1.0, theta=0.0
% INFO    : Bus 60904	: V=1.0097947, theta=1.205303 -> V=1.0, theta=0.0
% INFO    : Bus 60905	: V=1.02026, theta=4.348437 -> V=1.0, theta=0.0
% INFO    : Bus 60906	: V=1.0116929, theta=1.275939 -> V=1.0, theta=0.0
% INFO    : Bus 60907	: V=1.0293541, theta=5.476593 -> V=1.0, theta=0.0
% INFO    : Bus 60908	: V=0.9751933, theta=-3.827657 -> V=1.0, theta=0.0
% INFO    : Bus 60909	: V=0.9820366, theta=-3.658139 -> V=1.0, theta=0.0
% INFO    : Bus 60910	: V=0.9985843, theta=-1.428505 -> V=1.0, theta=0.0
% INFO    : Bus 60911	: V=0.9879232, theta=-2.688042 -> V=1.0, theta=0.0
% INFO    : Bus 60912	: V=1.0100007, theta=0.456206 -> V=1.0, theta=0.0
% INFO    : Bus 60913	: V=0.9975185, theta=-1.675175 -> V=1.0, theta=0.0
% INFO    : Bus 60914	: V=0.9870162, theta=-3.05371 -> V=1.0, theta=0.0
% INFO    : Bus 60915	: V=0.9907866, theta=-2.936313 -> V=1.0, theta=0.0
% INFO    : Bus 60916	: V=1.0143385, theta=2.608358 -> V=1.0, theta=0.0
% INFO    : Bus 60917	: V=1.0242131, theta=4.11229 -> V=1.0, theta=0.0
% INFO    : Bus 60918	: V=1.0293991, theta=4.573426 -> V=1.0, theta=0.0
% INFO    : Bus 60919	: V=1.0188618, theta=3.557017 -> V=1.0, theta=0.0
% INFO    : Bus 60920	: V=0.9905019, theta=-2.494029 -> V=1.0, theta=0.0
% INFO    : Bus 60921	: V=0.9829927, theta=-2.852542 -> V=1.0, theta=0.0
% INFO    : Bus 60922	: V=0.9873545, theta=-2.566517 -> V=1.0, theta=0.0
% INFO    : Bus 60923	: V=0.9807457, theta=-2.897846 -> V=1.0, theta=0.0
% INFO    : Bus 60924	: V=0.974995, theta=-3.106765 -> V=1.0, theta=0.0
% INFO    : Bus 60925	: V=0.9797299, theta=-3.001271 -> V=1.0, theta=0.0
% INFO    : Bus 60926	: V=1.0051721, theta=2.280808 -> V=1.0, theta=0.0
% INFO    : Bus 60927	: V=1.0211729, theta=3.611549 -> V=1.0, theta=0.0
% INFO    : Bus 60928	: V=1.0297463, theta=4.995217 -> V=1.0, theta=0.0
% INFO    : Bus 60929	: V=1.0298025, theta=4.904416 -> V=1.0, theta=0.0
% INFO    : Bus 60930	: V=1.0186531, theta=4.172525 -> V=1.0, theta=0.0
% INFO    : Bus 60931	: V=1.02968, theta=5.121436 -> V=1.0, theta=0.0
% INFO    : Bus 60932	: V=0.9859087, theta=-2.021687 -> V=1.0, theta=0.0
% INFO    : Bus 60933	: V=1.0071706, theta=0.245626 -> V=1.0, theta=0.0
% INFO    : Bus 60934	: V=1.0110124, theta=1.083525 -> V=1.0, theta=0.0
% INFO    : Bus 60935	: V=1.0103447, theta=0.913633 -> V=1.0, theta=0.0
% INFO    : Bus 60936	: V=1.0103227, theta=0.921497 -> V=1.0, theta=0.0
% INFO    : Bus 60937	: V=1.0113494, theta=1.159435 -> V=1.0, theta=0.0
% INFO    : Bus 60938	: V=1.0058185, theta=0.834293 -> V=1.0, theta=0.0
% INFO    : Bus 60939	: V=1.0093441, theta=0.700428 -> V=1.0, theta=0.0
% INFO    : Bus 60940	: V=1.0084104, theta=0.624769 -> V=1.0, theta=0.0
% INFO    : Bus 60941	: V=1.0090624, theta=0.627371 -> V=1.0, theta=0.0
% INFO    : Bus 60942	: V=1.0052763, theta=-0.141075 -> V=1.0, theta=0.0
% INFO    : Bus 60943	: V=1.0042722, theta=-0.284122 -> V=1.0, theta=0.0
% INFO    : Bus 60944	: V=1.0065011, theta=-0.016644 -> V=1.0, theta=0.0
% INFO    : Bus 60945	: V=1.0071204, theta=0.058203 -> V=1.0, theta=0.0
% INFO    : Bus 60946	: V=0.9903994, theta=-2.949695 -> V=1.0, theta=0.0
% INFO    : Bus 60947	: V=1.0008849, theta=-1.038825 -> V=1.0, theta=0.0
% INFO    : Bus 60948	: V=1.0073916, theta=9.864232 -> V=1.0, theta=0.0
% INFO    : Bus 60949	: V=1.0011542, theta=14.461083 -> V=1.0, theta=0.0
% INFO    : Bus 60950	: V=1.0126231, theta=17.883503 -> V=1.0, theta=0.0
% INFO    : Bus 60951	: V=1.0112015, theta=16.820816 -> V=1.0, theta=0.0
% INFO    : Bus 60952	: V=1.0109319, theta=16.669382 -> V=1.0, theta=0.0
% INFO    : Bus 60953	: V=1.0049506, theta=16.252817 -> V=1.0, theta=0.0
% INFO    : Bus 60954	: V=1.0109604, theta=16.572578 -> V=1.0, theta=0.0
% INFO    : Bus 60955	: V=1.0006311, theta=17.839479 -> V=1.0, theta=0.0
% INFO    : Bus 60956	: V=1.0116001, theta=19.157704 -> V=1.0, theta=0.0
% INFO    : Bus 60957	: V=1.0300007, theta=15.586778 -> V=1.0, theta=0.0
% INFO    : Bus 60958	: V=1.0079894, theta=10.588947 -> V=1.0, theta=0.0
% INFO    : Bus 60959	: V=1.0108884, theta=-0.539828 -> V=1.0, theta=0.0
% INFO    : Bus 60960	: V=1.0152272, theta=0.769407 -> V=1.0, theta=0.0
% INFO    : Bus 60961	: V=1.0193553, theta=2.301179 -> V=1.0, theta=0.0
% INFO    : Bus 60962	: V=1.0209394, theta=2.699856 -> V=1.0, theta=0.0
% INFO    : Bus 60963	: V=1.0194187, theta=2.492438 -> V=1.0, theta=0.0
% INFO    : Bus 60964	: V=1.0195592, theta=2.563275 -> V=1.0, theta=0.0
% INFO    : Bus 60965	: V=1.0200007, theta=3.671398 -> V=1.0, theta=0.0
% INFO    : Bus 60966	: V=1.0193609, theta=2.663932 -> V=1.0, theta=0.0
% INFO    : Bus 60967	: V=1.0144898, theta=1.031458 -> V=1.0, theta=0.0
% INFO    : Bus 60968	: V=1.0190495, theta=2.624249 -> V=1.0, theta=0.0
% INFO    : Bus 60969	: V=1.0095212, theta=1.568413 -> V=1.0, theta=0.0
% INFO    : Bus 60970	: V=1.0100007, theta=1.801104 -> V=1.0, theta=0.0
% INFO    : Bus 60971	: V=1.0193494, theta=3.161812 -> V=1.0, theta=0.0
% INFO    : Bus 60972	: V=1.0162019, theta=1.468203 -> V=1.0, theta=0.0
% INFO    : Bus 60973	: V=1.00303, theta=-0.531959 -> V=1.0, theta=0.0
% INFO    : Bus 60974	: V=1.0112146, theta=0.910238 -> V=1.0, theta=0.0
% INFO    : Bus 60975	: V=1.0142376, theta=1.915052 -> V=1.0, theta=0.0
% INFO    : Bus 60976	: V=1.017225, theta=1.856483 -> V=1.0, theta=0.0
% INFO    : Bus 60977	: V=1.0110483, theta=2.328761 -> V=1.0, theta=0.0
% INFO    : Bus 60978	: V=1.0076842, theta=1.450506 -> V=1.0, theta=0.0
% INFO    : Bus 60979	: V=1.0034867, theta=29.910986 -> V=1.0, theta=0.0
% INFO    : Bus 60980	: V=1.0123067, theta=31.008465 -> V=1.0, theta=0.0
% INFO    : Bus 60981	: V=1.0294885, theta=43.944194 -> V=1.0, theta=0.0
% INFO    : Bus 60982	: V=1.0100007, theta=32.504743 -> V=1.0, theta=0.0
% INFO    : Bus 60983	: V=1.0077545, theta=-1.286006 -> V=1.0, theta=0.0
% INFO    : Bus 60984	: V=1.0036955, theta=-1.895062 -> V=1.0, theta=0.0
% INFO    : Bus 60985	: V=1.002533, theta=-3.356277 -> V=1.0, theta=0.0
% INFO    : Bus 60986	: V=0.9834303, theta=-1.79596 -> V=1.0, theta=0.0
% INFO    : Bus 60987	: V=1.0050355, theta=-0.434374 -> V=1.0, theta=0.0
% INFO    : Bus 60988	: V=0.9986074, theta=-2.670742 -> V=1.0, theta=0.0
% INFO    : Bus 60989	: V=0.9988828, theta=-3.437175 -> V=1.0, theta=0.0
% INFO    : Bus 60990	: V=0.996981, theta=-3.640668 -> V=1.0, theta=0.0
% INFO    : Bus 60991	: V=1.0079567, theta=-2.913723 -> V=1.0, theta=0.0
% INFO    : Bus 60992	: V=0.9944138, theta=-3.696596 -> V=1.0, theta=0.0
% INFO    : Bus 60993	: V=0.992665, theta=-3.484881 -> V=1.0, theta=0.0
% INFO    : Bus 60994	: V=0.992456, theta=-3.368588 -> V=1.0, theta=0.0
% INFO    : Bus 60995	: V=0.9956424, theta=-3.078977 -> V=1.0, theta=0.0
% INFO    : Bus 60996	: V=0.9899918, theta=-4.135576 -> V=1.0, theta=0.0
% INFO    : Bus 60997	: V=1.018722, theta=35.720202 -> V=1.0, theta=0.0
% INFO    : Bus 60998	: V=1.005742, theta=25.257314 -> V=1.0, theta=0.0
% INFO    : Bus 60999	: V=0.9775707, theta=21.117077 -> V=1.0, theta=0.0
% INFO    : Bus 61000	: V=0.9650609, theta=19.660617 -> V=1.0, theta=0.0
% INFO    : Bus 61001	: V=1.0014433, theta=25.250974 -> V=1.0, theta=0.0
% INFO    : Bus 61002	: V=1.0087248, theta=27.644609 -> V=1.0, theta=0.0
% INFO    : Bus 61003	: V=1.0008494, theta=23.629608 -> V=1.0, theta=0.0
% INFO    : Bus 61004	: V=0.9945162, theta=21.217038 -> V=1.0, theta=0.0
% INFO    : Bus 61005	: V=0.9533265, theta=18.456947 -> V=1.0, theta=0.0
% INFO    : Bus 61006	: V=0.9746281, theta=19.716015 -> V=1.0, theta=0.0
% INFO    : Bus 61007	: V=1.0297745, theta=-2.112954 -> V=1.0, theta=0.0
% INFO    : Bus 61008	: V=1.0012887, theta=-6.04083 -> V=1.0, theta=0.0
% INFO    : Bus 61009	: V=0.9982149, theta=-2.530726 -> V=1.0, theta=0.0
% INFO    : Bus 61010	: V=0.9747238, theta=-8.329272 -> V=1.0, theta=0.0
% INFO    : Bus 61011	: V=0.9737268, theta=-8.358673 -> V=1.0, theta=0.0
% INFO    : Bus 61012	: V=0.9807785, theta=-7.862544 -> V=1.0, theta=0.0
% INFO    : Bus 61013	: V=0.9893461, theta=-7.11699 -> V=1.0, theta=0.0
% INFO    : Bus 61014	: V=1.0200006, theta=22.181202 -> V=1.0, theta=0.0
% INFO    : Bus 61015	: V=1.0063998, theta=21.390087 -> V=1.0, theta=0.0
% INFO    : Bus 61016	: V=1.0038028, theta=21.936429 -> V=1.0, theta=0.0
% INFO    : Bus 61017	: V=1.0044672, theta=22.296338 -> V=1.0, theta=0.0
% INFO    : Bus 61018	: V=0.993839, theta=21.80291 -> V=1.0, theta=0.0
% INFO    : Bus 61019	: V=1.0300007, theta=3.157253 -> V=1.0, theta=0.0
% INFO    : Bus 61020	: V=0.9933009, theta=-1.724859 -> V=1.0, theta=0.0
% INFO    : Bus 61021	: V=1.005862, theta=-0.411174 -> V=1.0, theta=0.0
% INFO    : Bus 61022	: V=1.0063802, theta=-0.364497 -> V=1.0, theta=0.0
% INFO    : Bus 61023	: V=1.0069229, theta=-0.315372 -> V=1.0, theta=0.0
% INFO    : Bus 61024	: V=1.0067392, theta=-0.35137 -> V=1.0, theta=0.0
% INFO    : Bus 61025	: V=1.006096, theta=-0.402803 -> V=1.0, theta=0.0
% INFO    : Bus 61026	: V=1.0051015, theta=-0.467565 -> V=1.0, theta=0.0
% INFO    : Bus 61027	: V=1.0055605, theta=-0.437741 -> V=1.0, theta=0.0
% INFO    : Bus 61028	: V=0.9987571, theta=-1.567602 -> V=1.0, theta=0.0
% INFO    : Bus 61029	: V=1.0023157, theta=-1.299749 -> V=1.0, theta=0.0
% INFO    : Bus 61030	: V=0.999142, theta=-1.553378 -> V=1.0, theta=0.0
% INFO    : Bus 61031	: V=1.0004273, theta=-1.51497 -> V=1.0, theta=0.0
% INFO    : Bus 61032	: V=1.0062686, theta=-0.401408 -> V=1.0, theta=0.0
% INFO    : Bus 61033	: V=1.0064847, theta=-0.384164 -> V=1.0, theta=0.0
% INFO    : Bus 61034	: V=1.0067482, theta=-0.35836 -> V=1.0, theta=0.0
% INFO    : Bus 61035	: V=1.0069607, theta=-0.335519 -> V=1.0, theta=0.0
% INFO    : Bus 61036	: V=1.0077428, theta=-0.244566 -> V=1.0, theta=0.0
% INFO    : Bus 61037	: V=1.0072733, theta=-0.297574 -> V=1.0, theta=0.0
% INFO    : Bus 61038	: V=1.0085276, theta=-0.137626 -> V=1.0, theta=0.0
% INFO    : Bus 61039	: V=1.0014464, theta=-1.355035 -> V=1.0, theta=0.0
% INFO    : Bus 61040	: V=1.0056094, theta=-0.666965 -> V=1.0, theta=0.0
% INFO    : Bus 61041	: V=1.0086391, theta=-0.131472 -> V=1.0, theta=0.0
% INFO    : Bus 61042	: V=1.006201, theta=-0.615306 -> V=1.0, theta=0.0
% INFO    : Bus 61043	: V=1.0046666, theta=-0.730799 -> V=1.0, theta=0.0
% INFO    : Bus 61044	: V=1.0045925, theta=-0.736485 -> V=1.0, theta=0.0
% INFO    : Bus 61045	: V=1.0080533, theta=-0.199429 -> V=1.0, theta=0.0
% INFO    : Bus 61046	: V=1.0066441, theta=-0.37693 -> V=1.0, theta=0.0
% INFO    : Bus 61047	: V=1.00714, theta=-0.249139 -> V=1.0, theta=0.0
% INFO    : Bus 61048	: V=1.0016005, theta=-1.502646 -> V=1.0, theta=0.0
% INFO    : Bus 61049	: V=1.0077641, theta=-0.241056 -> V=1.0, theta=0.0
% INFO    : Bus 61050	: V=1.0017817, theta=-1.479722 -> V=1.0, theta=0.0
% INFO    : Bus 61051	: V=1.0006442, theta=-1.528811 -> V=1.0, theta=0.0
% INFO    : Bus 61052	: V=1.0004744, theta=-1.540722 -> V=1.0, theta=0.0
% INFO    : Bus 61053	: V=1.0060356, theta=-0.409297 -> V=1.0, theta=0.0
% INFO    : Bus 61054	: V=1.0000105, theta=-1.582116 -> V=1.0, theta=0.0
% INFO    : Bus 61055	: V=1.0003889, theta=-1.533999 -> V=1.0, theta=0.0
% INFO    : Bus 61056	: V=1.0012891, theta=-1.576768 -> V=1.0, theta=0.0
% INFO    : Bus 61057	: V=0.9751601, theta=-1.342599 -> V=1.0, theta=0.0
% INFO    : Bus 61058	: V=0.9926337, theta=-2.354863 -> V=1.0, theta=0.0
% INFO    : Bus 61059	: V=0.9802757, theta=-2.938001 -> V=1.0, theta=0.0
% INFO    : Bus 61060	: V=0.9852462, theta=-3.171497 -> V=1.0, theta=0.0
% INFO    : Bus 61061	: V=0.9905113, theta=-2.81875 -> V=1.0, theta=0.0
% INFO    : Bus 61062	: V=0.9673093, theta=-3.897675 -> V=1.0, theta=0.0
% INFO    : Bus 61063	: V=0.9869456, theta=-2.707297 -> V=1.0, theta=0.0
% INFO    : Bus 61064	: V=0.9892815, theta=-2.599746 -> V=1.0, theta=0.0
% INFO    : Bus 61065	: V=0.9851433, theta=-2.745068 -> V=1.0, theta=0.0
% INFO    : Bus 61066	: V=0.9877047, theta=-2.61806 -> V=1.0, theta=0.0
% INFO    : Bus 61067	: V=0.98163, theta=-2.895717 -> V=1.0, theta=0.0
% INFO    : Bus 61068	: V=0.989963, theta=-2.574214 -> V=1.0, theta=0.0
% INFO    : Bus 61069	: V=0.9908499, theta=-2.565809 -> V=1.0, theta=0.0
% INFO    : Bus 61070	: V=0.9970914, theta=-1.840747 -> V=1.0, theta=0.0
% INFO    : Bus 61071	: V=0.9901202, theta=-2.517952 -> V=1.0, theta=0.0
% INFO    : Bus 61072	: V=1.0005309, theta=-1.153542 -> V=1.0, theta=0.0
% INFO    : Bus 61073	: V=0.9916855, theta=-2.369662 -> V=1.0, theta=0.0
% INFO    : Bus 61074	: V=1.0045185, theta=-0.816247 -> V=1.0, theta=0.0
% INFO    : Bus 61075	: V=0.9974036, theta=-2.18639 -> V=1.0, theta=0.0
% INFO    : Bus 61076	: V=1.0039503, theta=-0.893783 -> V=1.0, theta=0.0
% INFO    : Bus 61077	: V=1.0002402, theta=-1.709273 -> V=1.0, theta=0.0
% INFO    : Bus 61078	: V=1.0000704, theta=-1.684659 -> V=1.0, theta=0.0
% INFO    : Bus 61079	: V=1.0058989, theta=-0.968188 -> V=1.0, theta=0.0
% INFO    : Bus 61080	: V=1.0018616, theta=-1.208794 -> V=1.0, theta=0.0
% INFO    : Bus 61081	: V=1.0026226, theta=-1.174957 -> V=1.0, theta=0.0
% INFO    : Bus 61082	: V=0.994662, theta=-2.275209 -> V=1.0, theta=0.0
% INFO    : Bus 61083	: V=0.9930357, theta=-2.346549 -> V=1.0, theta=0.0
% INFO    : Bus 61084	: V=1.0003537, theta=-1.874067 -> V=1.0, theta=0.0
% INFO    : Bus 61085	: V=1.007027, theta=-0.926416 -> V=1.0, theta=0.0
% INFO    : Bus 61086	: V=1.008298, theta=-0.85921 -> V=1.0, theta=0.0
% INFO    : Bus 61087	: V=1.0007323, theta=-1.790818 -> V=1.0, theta=0.0
% INFO    : Bus 61088	: V=1.0074352, theta=-0.923005 -> V=1.0, theta=0.0
% INFO    : Bus 61089	: V=1.0073884, theta=-0.923643 -> V=1.0, theta=0.0
% INFO    : Bus 61090	: V=1.0029868, theta=-1.571937 -> V=1.0, theta=0.0
% INFO    : Bus 61091	: V=1.009895, theta=-0.778315 -> V=1.0, theta=0.0
% INFO    : Bus 61092	: V=1.0094833, theta=-0.764015 -> V=1.0, theta=0.0
% INFO    : Bus 61093	: V=1.0022448, theta=-1.61196 -> V=1.0, theta=0.0
% INFO    : Bus 61094	: V=1.0082353, theta=-0.906124 -> V=1.0, theta=0.0
% INFO    : Bus 61095	: V=1.0085618, theta=-0.887755 -> V=1.0, theta=0.0
% INFO    : Bus 61096	: V=1.0026882, theta=-2.069491 -> V=1.0, theta=0.0
% INFO    : Bus 61097	: V=1.0108253, theta=0.105784 -> V=1.0, theta=0.0
% INFO    : Bus 61098	: V=1.0024878, theta=-1.552871 -> V=1.0, theta=0.0
% INFO    : Bus 61099	: V=1.0021074, theta=-1.581875 -> V=1.0, theta=0.0
% INFO    : Bus 61100	: V=1.001761, theta=-1.636274 -> V=1.0, theta=0.0
% INFO    : Bus 61101	: V=1.0001766, theta=-1.572667 -> V=1.0, theta=0.0
% INFO    : Bus 61102	: V=1.0009539, theta=-1.488122 -> V=1.0, theta=0.0
% INFO    : Bus 61103	: V=1.0021858, theta=-1.510009 -> V=1.0, theta=0.0
% INFO    : Bus 61104	: V=1.0093686, theta=-0.054062 -> V=1.0, theta=0.0
% INFO    : Bus 61105	: V=1.002002, theta=-1.552763 -> V=1.0, theta=0.0
% INFO    : Bus 61106	: V=1.0019188, theta=-1.50509 -> V=1.0, theta=0.0
% INFO    : Bus 61107	: V=1.001991, theta=-1.561966 -> V=1.0, theta=0.0
% INFO    : Bus 61108	: V=1.0088359, theta=-0.099061 -> V=1.0, theta=0.0
% INFO    : Bus 61109	: V=1.0061697, theta=-0.726324 -> V=1.0, theta=0.0
% INFO    : Bus 61110	: V=1.0059297, theta=-0.622345 -> V=1.0, theta=0.0
% INFO    : Bus 61111	: V=1.022156, theta=2.086045 -> V=1.0, theta=0.0
% INFO    : Bus 61112	: V=1.0053611, theta=-0.782042 -> V=1.0, theta=0.0
% INFO    : Bus 61113	: V=1.004613, theta=-0.814818 -> V=1.0, theta=0.0
% INFO    : Bus 61114	: V=1.007086, theta=-0.604776 -> V=1.0, theta=0.0
% INFO    : Bus 61115	: V=1.0148843, theta=0.133896 -> V=1.0, theta=0.0
% INFO    : Bus 61116	: V=0.9966031, theta=-1.850852 -> V=1.0, theta=0.0
% INFO    : Bus 61117	: V=0.9987432, theta=-1.803527 -> V=1.0, theta=0.0
% INFO    : Bus 61118	: V=1.0055237, theta=-0.517213 -> V=1.0, theta=0.0
% INFO    : Bus 61119	: V=1.0088173, theta=-0.448754 -> V=1.0, theta=0.0
% INFO    : Bus 61120	: V=1.0082011, theta=-0.381837 -> V=1.0, theta=0.0
% INFO    : Bus 61121	: V=1.0072551, theta=-0.44158 -> V=1.0, theta=0.0
% INFO    : Bus 61122	: V=1.0068766, theta=-0.486786 -> V=1.0, theta=0.0
% INFO    : Bus 61123	: V=1.0065248, theta=-0.296431 -> V=1.0, theta=0.0
% INFO    : Bus 61124	: V=0.9946212, theta=-2.04147 -> V=1.0, theta=0.0
% INFO    : Bus 61125	: V=0.9957538, theta=-1.979528 -> V=1.0, theta=0.0
% INFO    : Bus 61126	: V=0.9930548, theta=-2.080106 -> V=1.0, theta=0.0
% INFO    : Bus 61127	: V=0.9942139, theta=-2.053905 -> V=1.0, theta=0.0
% INFO    : Bus 61128	: V=0.9947145, theta=-2.001658 -> V=1.0, theta=0.0
% INFO    : Bus 61129	: V=0.9996522, theta=-1.414255 -> V=1.0, theta=0.0
% INFO    : Bus 61130	: V=1.0008148, theta=-1.382328 -> V=1.0, theta=0.0
% INFO    : Bus 61131	: V=0.9980413, theta=-1.476102 -> V=1.0, theta=0.0
% INFO    : Bus 61132	: V=1.0044646, theta=-0.479681 -> V=1.0, theta=0.0
% INFO    : Bus 61133	: V=1.0041411, theta=-0.517937 -> V=1.0, theta=0.0
% INFO    : Bus 61134	: V=0.9993996, theta=-1.481411 -> V=1.0, theta=0.0
% INFO    : Bus 61135	: V=0.9987942, theta=-1.463308 -> V=1.0, theta=0.0
% INFO    : Bus 61136	: V=0.9986582, theta=-1.383636 -> V=1.0, theta=0.0
% INFO    : Bus 61137	: V=0.9975744, theta=-1.421464 -> V=1.0, theta=0.0
% INFO    : Bus 61138	: V=1.0046216, theta=-0.45145 -> V=1.0, theta=0.0
% INFO    : Bus 61139	: V=1.0052092, theta=-0.331223 -> V=1.0, theta=0.0
% INFO    : Bus 61140	: V=1.0048108, theta=-0.396801 -> V=1.0, theta=0.0
% INFO    : Bus 61141	: V=1.0043232, theta=-0.479534 -> V=1.0, theta=0.0
% INFO    : Bus 61142	: V=1.0062846, theta=-0.248295 -> V=1.0, theta=0.0
% INFO    : Bus 61143	: V=1.0041442, theta=-1.121531 -> V=1.0, theta=0.0
% INFO    : Bus 61144	: V=1.0058902, theta=-0.339373 -> V=1.0, theta=0.0
% INFO    : Bus 61145	: V=1.0110962, theta=0.115888 -> V=1.0, theta=0.0
% INFO    : Bus 61146	: V=1.0085816, theta=-0.382914 -> V=1.0, theta=0.0
% INFO    : Bus 61147	: V=1.0093532, theta=0.213379 -> V=1.0, theta=0.0
% INFO    : Bus 61148	: V=1.0138278, theta=0.358783 -> V=1.0, theta=0.0
% INFO    : Bus 61149	: V=1.0136276, theta=0.28511 -> V=1.0, theta=0.0
% INFO    : Bus 61150	: V=1.0300007, theta=2.952446 -> V=1.0, theta=0.0
% INFO    : Bus 61151	: V=1.0085699, theta=0.211798 -> V=1.0, theta=0.0
% INFO    : Bus 61152	: V=1.0076962, theta=-0.179484 -> V=1.0, theta=0.0
% INFO    : Bus 61153	: V=1.0021495, theta=-0.09389 -> V=1.0, theta=0.0
% INFO    : Bus 61154	: V=1.0178011, theta=0.405286 -> V=1.0, theta=0.0
% INFO    : Bus 61155	: V=0.9971564, theta=-2.181356 -> V=1.0, theta=0.0
% INFO    : Bus 61156	: V=1.0039519, theta=-1.099989 -> V=1.0, theta=0.0
% INFO    : Bus 61157	: V=1.0052386, theta=-0.87827 -> V=1.0, theta=0.0
% INFO    : Bus 61158	: V=1.0048191, theta=-1.526589 -> V=1.0, theta=0.0
% INFO    : Bus 61159	: V=1.0082965, theta=-0.75952 -> V=1.0, theta=0.0
% INFO    : Bus 61160	: V=1.0074375, theta=-0.717693 -> V=1.0, theta=0.0
% INFO    : Bus 61161	: V=1.0074078, theta=-0.449177 -> V=1.0, theta=0.0
% INFO    : Bus 61162	: V=1.0059991, theta=-0.828309 -> V=1.0, theta=0.0
% INFO    : Bus 61163	: V=1.0092012, theta=-0.283575 -> V=1.0, theta=0.0
% INFO    : Bus 61164	: V=0.9970899, theta=-2.038253 -> V=1.0, theta=0.0
% INFO    : Bus 61165	: V=1.0043635, theta=-1.633051 -> V=1.0, theta=0.0
% INFO    : Bus 61166	: V=1.0035445, theta=-1.097435 -> V=1.0, theta=0.0
% INFO    : Bus 61167	: V=0.9988951, theta=-2.144835 -> V=1.0, theta=0.0
% INFO    : Bus 61168	: V=1.0017191, theta=-1.723753 -> V=1.0, theta=0.0
% INFO    : Bus 61169	: V=1.0031596, theta=-1.696747 -> V=1.0, theta=0.0
% INFO    : Bus 61170	: V=1.0033988, theta=-1.655879 -> V=1.0, theta=0.0
% INFO    : Bus 61171	: V=0.993689, theta=-0.176278 -> V=1.0, theta=0.0
% INFO    : Bus 61172	: V=1.0001041, theta=-1.220607 -> V=1.0, theta=0.0
% INFO    : Bus 61173	: V=0.9943666, theta=-2.278325 -> V=1.0, theta=0.0
% INFO    : Bus 61174	: V=0.9980321, theta=-1.96916 -> V=1.0, theta=0.0
% INFO    : Bus 61175	: V=0.9949649, theta=-2.225993 -> V=1.0, theta=0.0
% INFO    : Bus 61176	: V=0.9956459, theta=-2.21944 -> V=1.0, theta=0.0
% INFO    : Bus 61177	: V=1.0008686, theta=-1.118412 -> V=1.0, theta=0.0
% INFO    : Bus 61178	: V=0.9940578, theta=-2.613752 -> V=1.0, theta=0.0
% INFO    : Bus 61179	: V=0.9922047, theta=-2.742181 -> V=1.0, theta=0.0
% INFO    : Bus 61180	: V=1.0000604, theta=-1.448591 -> V=1.0, theta=0.0
% INFO    : Bus 61181	: V=1.0100007, theta=0.575686 -> V=1.0, theta=0.0
% INFO    : Bus 61182	: V=1.002791, theta=-1.13242 -> V=1.0, theta=0.0
% INFO    : Bus 61183	: V=1.0006567, theta=-1.493762 -> V=1.0, theta=0.0
% INFO    : Bus 61184	: V=1.0123544, theta=0.705075 -> V=1.0, theta=0.0
% INFO    : Bus 61185	: V=1.006824, theta=-0.329695 -> V=1.0, theta=0.0
% INFO    : Bus 61186	: V=1.0077307, theta=-0.229888 -> V=1.0, theta=0.0
% INFO    : Bus 61187	: V=1.0065234, theta=-0.358521 -> V=1.0, theta=0.0
% INFO    : Bus 61188	: V=0.9956221, theta=-2.559657 -> V=1.0, theta=0.0
% INFO    : Bus 61189	: V=1.0014321, theta=-1.064595 -> V=1.0, theta=0.0
% INFO    : Bus 61190	: V=1.0004392, theta=-1.431873 -> V=1.0, theta=0.0
% INFO    : Bus 61191	: V=1.0060715, theta=2.49585 -> V=1.0, theta=0.0
% INFO    : Bus 61192	: V=0.9629614, theta=-0.366052 -> V=1.0, theta=0.0
% INFO    : Bus 61193	: V=0.9576746, theta=-0.48297 -> V=1.0, theta=0.0
% INFO    : Bus 61194	: V=0.9907517, theta=0.263753 -> V=1.0, theta=0.0
% INFO    : Bus 61195	: V=1.0009751, theta=0.582272 -> V=1.0, theta=0.0
% INFO    : Bus 61196	: V=1.0094114, theta=1.676296 -> V=1.0, theta=0.0
% INFO    : Bus 61197	: V=1.0014807, theta=0.625986 -> V=1.0, theta=0.0
% INFO    : Bus 61198	: V=1.0095849, theta=1.89163 -> V=1.0, theta=0.0
% INFO    : Bus 61199	: V=1.0096815, theta=1.959639 -> V=1.0, theta=0.0
% INFO    : Bus 61200	: V=1.0029713, theta=0.764419 -> V=1.0, theta=0.0
% INFO    : Bus 61201	: V=1.0094097, theta=1.587422 -> V=1.0, theta=0.0
% INFO    : Bus 61202	: V=1.0076448, theta=1.949552 -> V=1.0, theta=0.0
% INFO    : Bus 61203	: V=1.0046722, theta=3.03884 -> V=1.0, theta=0.0
% INFO    : Bus 61204	: V=1.0061308, theta=3.315022 -> V=1.0, theta=0.0
% INFO    : Bus 61205	: V=1.0085936, theta=4.115126 -> V=1.0, theta=0.0
% INFO    : Bus 61206	: V=1.0100007, theta=6.541969 -> V=1.0, theta=0.0
% INFO    : Bus 61207	: V=1.0041186, theta=5.131096 -> V=1.0, theta=0.0
% INFO    : Bus 61208	: V=1.0003364, theta=2.278911 -> V=1.0, theta=0.0
% INFO    : Bus 61209	: V=1.0046147, theta=3.000362 -> V=1.0, theta=0.0
% INFO    : Bus 61210	: V=1.0046381, theta=2.976976 -> V=1.0, theta=0.0
% INFO    : Bus 61211	: V=1.0042665, theta=2.964524 -> V=1.0, theta=0.0
% INFO    : Bus 61212	: V=0.9912752, theta=0.341351 -> V=1.0, theta=0.0
% INFO    : Bus 61213	: V=1.0025536, theta=2.322467 -> V=1.0, theta=0.0
% INFO    : Bus 61214	: V=1.0100007, theta=3.617134 -> V=1.0, theta=0.0
% INFO    : Bus 61215	: V=1.0094114, theta=1.768241 -> V=1.0, theta=0.0
% INFO    : Bus 61216	: V=1.0025788, theta=2.145502 -> V=1.0, theta=0.0
% INFO    : Bus 61217	: V=1.0059009, theta=3.184526 -> V=1.0, theta=0.0
% INFO    : Bus 61218	: V=1.0054782, theta=3.136256 -> V=1.0, theta=0.0
% INFO    : Bus 61219	: V=1.0052105, theta=2.628547 -> V=1.0, theta=0.0
% INFO    : Bus 61220	: V=1.0111794, theta=3.539579 -> V=1.0, theta=0.0
% INFO    : Bus 61221	: V=1.004123, theta=2.494023 -> V=1.0, theta=0.0
% INFO    : Bus 61222	: V=1.0029049, theta=2.415724 -> V=1.0, theta=0.0
% INFO    : Bus 61223	: V=1.0100007, theta=3.115701 -> V=1.0, theta=0.0
% INFO    : Bus 61224	: V=1.0065843, theta=2.137355 -> V=1.0, theta=0.0
% INFO    : Bus 61225	: V=1.0045133, theta=2.020864 -> V=1.0, theta=0.0
% INFO    : Bus 61226	: V=1.0177829, theta=5.144262 -> V=1.0, theta=0.0
% INFO    : Bus 61227	: V=1.0195174, theta=7.518675 -> V=1.0, theta=0.0
% INFO    : Bus 61228	: V=1.014674, theta=10.310261 -> V=1.0, theta=0.0
% INFO    : Bus 61229	: V=1.0180198, theta=8.202492 -> V=1.0, theta=0.0
% INFO    : Bus 61230	: V=0.9904201, theta=-1.600599 -> V=1.0, theta=0.0
% INFO    : Bus 61231	: V=0.9870546, theta=-2.032643 -> V=1.0, theta=0.0
% INFO    : Bus 61232	: V=0.988334, theta=-2.021497 -> V=1.0, theta=0.0
% INFO    : Bus 61233	: V=0.9921426, theta=-1.41711 -> V=1.0, theta=0.0
% INFO    : Bus 61234	: V=0.9926846, theta=-1.336836 -> V=1.0, theta=0.0
% INFO    : Bus 61235	: V=0.9921736, theta=-1.430079 -> V=1.0, theta=0.0
% INFO    : Bus 61236	: V=0.9983633, theta=-3.069949 -> V=1.0, theta=0.0
% INFO    : Bus 61237	: V=0.9941706, theta=-3.020991 -> V=1.0, theta=0.0
% INFO    : Bus 61238	: V=0.9917366, theta=-1.485848 -> V=1.0, theta=0.0
% INFO    : Bus 61239	: V=0.9871038, theta=-2.9448 -> V=1.0, theta=0.0
% INFO    : Bus 61240	: V=0.9915262, theta=-2.948967 -> V=1.0, theta=0.0
% INFO    : Bus 61241	: V=0.9839046, theta=-2.901421 -> V=1.0, theta=0.0
% INFO    : Bus 61242	: V=0.9907874, theta=-1.70757 -> V=1.0, theta=0.0
% INFO    : Bus 61243	: V=0.9909978, theta=-1.669966 -> V=1.0, theta=0.0
% INFO    : Bus 61244	: V=0.9911184, theta=-1.690721 -> V=1.0, theta=0.0
% INFO    : Bus 61245	: V=0.9854481, theta=-3.001256 -> V=1.0, theta=0.0
% INFO    : Bus 61246	: V=0.9848592, theta=-3.016632 -> V=1.0, theta=0.0
% INFO    : Bus 61247	: V=0.9819617, theta=-2.811707 -> V=1.0, theta=0.0
% INFO    : Bus 61248	: V=0.988722, theta=-1.441695 -> V=1.0, theta=0.0
% INFO    : Bus 61249	: V=0.987879, theta=-1.530008 -> V=1.0, theta=0.0
% INFO    : Bus 61250	: V=0.9856168, theta=-2.493574 -> V=1.0, theta=0.0
% INFO    : Bus 61251	: V=0.9867424, theta=-2.407676 -> V=1.0, theta=0.0
% INFO    : Bus 61252	: V=0.9818095, theta=-3.004279 -> V=1.0, theta=0.0
% INFO    : Bus 61253	: V=0.9775124, theta=-3.250965 -> V=1.0, theta=0.0
% INFO    : Bus 61254	: V=0.9791026, theta=-3.192094 -> V=1.0, theta=0.0
% INFO    : Bus 61255	: V=0.9846563, theta=-2.751539 -> V=1.0, theta=0.0
% INFO    : Bus 61256	: V=0.9816712, theta=-3.043685 -> V=1.0, theta=0.0
% INFO    : Bus 61257	: V=0.9822117, theta=-2.99299 -> V=1.0, theta=0.0
% INFO    : Bus 61258	: V=0.9830997, theta=-2.947144 -> V=1.0, theta=0.0
% INFO    : Bus 61259	: V=0.983776, theta=-2.900175 -> V=1.0, theta=0.0
% INFO    : Bus 61260	: V=0.9810766, theta=-3.288504 -> V=1.0, theta=0.0
% INFO    : Bus 61261	: V=0.9920998, theta=-1.619004 -> V=1.0, theta=0.0
% INFO    : Bus 61262	: V=1.0200007, theta=1.903902 -> V=1.0, theta=0.0
% INFO    : Bus 61263	: V=0.9851956, theta=-2.793968 -> V=1.0, theta=0.0
% INFO    : Bus 61264	: V=0.9845671, theta=-2.792768 -> V=1.0, theta=0.0
% INFO    : Bus 61265	: V=0.9861807, theta=-2.733645 -> V=1.0, theta=0.0
% INFO    : Bus 61266	: V=0.9812691, theta=-3.324152 -> V=1.0, theta=0.0
% INFO    : Bus 61267	: V=0.9913096, theta=-1.83131 -> V=1.0, theta=0.0
% INFO    : Bus 61268	: V=0.9832681, theta=-3.258717 -> V=1.0, theta=0.0
% INFO    : Bus 61269	: V=0.9918947, theta=-1.766415 -> V=1.0, theta=0.0
% INFO    : Bus 61270	: V=0.9926598, theta=-1.675658 -> V=1.0, theta=0.0
% INFO    : Bus 61271	: V=0.9908349, theta=-1.875793 -> V=1.0, theta=0.0
% INFO    : Bus 61272	: V=0.9790407, theta=-3.551571 -> V=1.0, theta=0.0
% INFO    : Bus 61273	: V=0.9866278, theta=-2.777573 -> V=1.0, theta=0.0
% INFO    : Bus 61274	: V=0.9865744, theta=-2.758989 -> V=1.0, theta=0.0
% INFO    : Bus 61275	: V=0.9871033, theta=-2.707712 -> V=1.0, theta=0.0
% INFO    : Bus 61276	: V=0.9934841, theta=-1.326674 -> V=1.0, theta=0.0
% INFO    : Bus 61277	: V=0.993875, theta=-1.293312 -> V=1.0, theta=0.0
% INFO    : Bus 61278	: V=0.9946558, theta=-1.223415 -> V=1.0, theta=0.0
% INFO    : Bus 61279	: V=0.9905797, theta=-1.879411 -> V=1.0, theta=0.0
% INFO    : Bus 61280	: V=0.9861465, theta=-2.652927 -> V=1.0, theta=0.0
% INFO    : Bus 61281	: V=0.9962205, theta=-1.043714 -> V=1.0, theta=0.0
% INFO    : Bus 61282	: V=0.9950247, theta=-1.178563 -> V=1.0, theta=0.0
% INFO    : Bus 61283	: V=0.9954802, theta=-1.11782 -> V=1.0, theta=0.0
% INFO    : Bus 61284	: V=0.9945836, theta=-1.218789 -> V=1.0, theta=0.0
% INFO    : Bus 61285	: V=0.9857087, theta=-2.807065 -> V=1.0, theta=0.0
% INFO    : Bus 61286	: V=0.993394, theta=-1.341817 -> V=1.0, theta=0.0
% INFO    : Bus 61287	: V=0.9844069, theta=-2.973104 -> V=1.0, theta=0.0
% INFO    : Bus 61288	: V=0.9857454, theta=-2.883066 -> V=1.0, theta=0.0
% INFO    : Bus 61289	: V=0.9849268, theta=-2.94932 -> V=1.0, theta=0.0
% INFO    : Bus 61290	: V=0.9850229, theta=-2.964803 -> V=1.0, theta=0.0
% INFO    : Bus 61291	: V=0.9839577, theta=-2.991775 -> V=1.0, theta=0.0
% INFO    : Bus 61292	: V=0.9806437, theta=-3.528504 -> V=1.0, theta=0.0
% INFO    : Bus 61293	: V=0.9803489, theta=-3.525327 -> V=1.0, theta=0.0
% INFO    : Bus 61294	: V=0.9791, theta=-3.558841 -> V=1.0, theta=0.0
% INFO    : Bus 61295	: V=0.9924397, theta=-1.425306 -> V=1.0, theta=0.0
% INFO    : Bus 61296	: V=0.9877276, theta=-2.129837 -> V=1.0, theta=0.0
% INFO    : Bus 61297	: V=0.9841137, theta=-2.856113 -> V=1.0, theta=0.0
% INFO    : Bus 61298	: V=0.9826644, theta=-2.845428 -> V=1.0, theta=0.0
% INFO    : Bus 61299	: V=0.9770315, theta=-3.209931 -> V=1.0, theta=0.0
% INFO    : Bus 61300	: V=0.9807776, theta=-3.09266 -> V=1.0, theta=0.0
% INFO    : Bus 61301	: V=0.9827186, theta=-2.962182 -> V=1.0, theta=0.0
% INFO    : Bus 61302	: V=0.9791909, theta=-2.935515 -> V=1.0, theta=0.0
% INFO    : Bus 61303	: V=0.9778284, theta=-3.221992 -> V=1.0, theta=0.0
% INFO    : Bus 61304	: V=0.9792453, theta=-3.148921 -> V=1.0, theta=0.0
% INFO    : Bus 61305	: V=0.9801809, theta=-3.079088 -> V=1.0, theta=0.0
% INFO    : Bus 61306	: V=0.9780501, theta=-3.180952 -> V=1.0, theta=0.0
% INFO    : Bus 61307	: V=0.9928054, theta=-0.849673 -> V=1.0, theta=0.0
% INFO    : Bus 61308	: V=0.985147, theta=-2.627287 -> V=1.0, theta=0.0
% INFO    : Bus 61309	: V=0.9774379, theta=-3.338229 -> V=1.0, theta=0.0
% INFO    : Bus 61310	: V=0.9779241, theta=-3.359796 -> V=1.0, theta=0.0
% INFO    : Bus 61311	: V=0.9847876, theta=-2.769825 -> V=1.0, theta=0.0
% INFO    : Bus 61312	: V=0.9803859, theta=-3.117156 -> V=1.0, theta=0.0
% INFO    : Bus 61313	: V=0.9794946, theta=-3.165018 -> V=1.0, theta=0.0
% INFO    : Bus 61314	: V=0.9790552, theta=-3.166746 -> V=1.0, theta=0.0
% INFO    : Bus 61315	: V=0.9794032, theta=-3.136735 -> V=1.0, theta=0.0
% INFO    : Bus 61316	: V=0.9934188, theta=-1.197151 -> V=1.0, theta=0.0
% INFO    : Bus 61317	: V=0.9943031, theta=-0.637825 -> V=1.0, theta=0.0
% INFO    : Bus 61318	: V=0.9817694, theta=-2.715042 -> V=1.0, theta=0.0
% INFO    : Bus 61319	: V=0.9936775, theta=-0.633351 -> V=1.0, theta=0.0
% INFO    : Bus 61320	: V=0.99423, theta=-0.404082 -> V=1.0, theta=0.0
% INFO    : Bus 61321	: V=0.9933539, theta=-0.164747 -> V=1.0, theta=0.0
% INFO    : Bus 61322	: V=0.9867121, theta=-2.523793 -> V=1.0, theta=0.0
% INFO    : Bus 61323	: V=0.9882454, theta=-2.303245 -> V=1.0, theta=0.0
% INFO    : Bus 61324	: V=0.9926619, theta=-0.87944 -> V=1.0, theta=0.0
% INFO    : Bus 61325	: V=1.0005937, theta=0.302271 -> V=1.0, theta=0.0
% INFO    : Bus 61326	: V=0.9979754, theta=-0.206381 -> V=1.0, theta=0.0
% INFO    : Bus 61327	: V=1.0036666, theta=1.001148 -> V=1.0, theta=0.0
% INFO    : Bus 61328	: V=1.0200007, theta=3.166193 -> V=1.0, theta=0.0
% INFO    : Bus 61329	: V=0.9879785, theta=-1.901647 -> V=1.0, theta=0.0
% INFO    : Bus 61330	: V=0.9882036, theta=-2.061191 -> V=1.0, theta=0.0
% INFO    : Bus 61331	: V=1.0100007, theta=1.832418 -> V=1.0, theta=0.0
% INFO    : Bus 61332	: V=0.9971612, theta=-0.099322 -> V=1.0, theta=0.0
% INFO    : Bus 61333	: V=0.9940143, theta=-0.67117 -> V=1.0, theta=0.0
% INFO    : Bus 61334	: V=0.9828702, theta=-2.498213 -> V=1.0, theta=0.0
% INFO    : Bus 61335	: V=0.9819463, theta=-2.515312 -> V=1.0, theta=0.0
% INFO    : Bus 61336	: V=0.995491, theta=-0.749434 -> V=1.0, theta=0.0
% INFO    : Bus 61337	: V=0.9909435, theta=-1.463365 -> V=1.0, theta=0.0
% INFO    : Bus 61338	: V=0.9928869, theta=-1.358155 -> V=1.0, theta=0.0
% INFO    : Bus 61339	: V=0.9902173, theta=-1.473319 -> V=1.0, theta=0.0
% INFO    : Bus 61340	: V=0.9969874, theta=-0.546081 -> V=1.0, theta=0.0
% INFO    : Bus 61341	: V=0.9978185, theta=-0.460016 -> V=1.0, theta=0.0
% INFO    : Bus 61342	: V=0.9976981, theta=-0.435661 -> V=1.0, theta=0.0
% INFO    : Bus 61343	: V=0.9925805, theta=-1.087082 -> V=1.0, theta=0.0
% INFO    : Bus 61344	: V=0.9957066, theta=-0.677715 -> V=1.0, theta=0.0
% INFO    : Bus 61345	: V=0.9909398, theta=-1.455091 -> V=1.0, theta=0.0
% INFO    : Bus 61346	: V=0.9916634, theta=-1.410891 -> V=1.0, theta=0.0
% INFO    : Bus 61347	: V=0.9942429, theta=-0.898446 -> V=1.0, theta=0.0
% INFO    : Bus 61348	: V=0.9970954, theta=-0.433902 -> V=1.0, theta=0.0
% INFO    : Bus 61349	: V=0.9786031, theta=-3.781799 -> V=1.0, theta=0.0
% INFO    : Bus 61350	: V=0.9917273, theta=-1.20629 -> V=1.0, theta=0.0
% INFO    : Bus 61351	: V=0.9913633, theta=-1.256374 -> V=1.0, theta=0.0
% INFO    : Bus 61352	: V=0.9835425, theta=-2.452037 -> V=1.0, theta=0.0
% INFO    : Bus 61353	: V=0.9923154, theta=-1.204707 -> V=1.0, theta=0.0
% INFO    : Bus 61354	: V=0.9930827, theta=-1.082617 -> V=1.0, theta=0.0
% INFO    : Bus 61355	: V=0.9915829, theta=-1.254359 -> V=1.0, theta=0.0
% INFO    : Bus 61356	: V=0.9852997, theta=-2.317467 -> V=1.0, theta=0.0
% INFO    : Bus 61357	: V=0.9910594, theta=-1.379088 -> V=1.0, theta=0.0
% INFO    : Bus 61358	: V=0.9922459, theta=-0.989657 -> V=1.0, theta=0.0
% INFO    : Bus 61359	: V=0.9952118, theta=-0.266992 -> V=1.0, theta=0.0
% INFO    : Bus 61360	: V=0.9937291, theta=-0.656729 -> V=1.0, theta=0.0
% INFO    : Bus 61361	: V=0.9975849, theta=0.256602 -> V=1.0, theta=0.0
% INFO    : Bus 61362	: V=0.9932623, theta=-0.846901 -> V=1.0, theta=0.0
% INFO    : Bus 61363	: V=0.9799814, theta=-2.082293 -> V=1.0, theta=0.0
% INFO    : Bus 61364	: V=0.9952338, theta=-0.653571 -> V=1.0, theta=0.0
% INFO    : Bus 61365	: V=0.9996611, theta=-0.050836 -> V=1.0, theta=0.0
% INFO    : Bus 61366	: V=1.0100007, theta=2.399086 -> V=1.0, theta=0.0
% INFO    : Bus 61367	: V=0.9937169, theta=-0.912087 -> V=1.0, theta=0.0
% INFO    : Bus 61368	: V=0.9929759, theta=-0.930817 -> V=1.0, theta=0.0
% INFO    : Bus 61369	: V=0.9923184, theta=-1.070028 -> V=1.0, theta=0.0
% INFO    : Bus 61370	: V=0.9966658, theta=2.838934 -> V=1.0, theta=0.0
% INFO    : Bus 61371	: V=0.9903773, theta=-1.44684 -> V=1.0, theta=0.0
% INFO    : Bus 61372	: V=0.9961451, theta=-1.049357 -> V=1.0, theta=0.0
% INFO    : Bus 61373	: V=1.0002706, theta=8.753656 -> V=1.0, theta=0.0
% INFO    : Bus 61374	: V=1.0100007, theta=6.236096 -> V=1.0, theta=0.0
% INFO    : Bus 61375	: V=1.0074862, theta=3.147037 -> V=1.0, theta=0.0
% INFO    : Bus 61376	: V=1.0100221, theta=4.23419 -> V=1.0, theta=0.0
% INFO    : Bus 61377	: V=0.9911588, theta=-1.298739 -> V=1.0, theta=0.0
% INFO    : Bus 61378	: V=0.989646, theta=-1.799499 -> V=1.0, theta=0.0
% INFO    : Bus 61379	: V=0.9912382, theta=-1.705241 -> V=1.0, theta=0.0
% INFO    : Bus 61380	: V=0.9985789, theta=17.151856 -> V=1.0, theta=0.0
% INFO    : Bus 61381	: V=1.0003817, theta=18.472619 -> V=1.0, theta=0.0
% INFO    : Bus 61382	: V=1.0075532, theta=19.337767 -> V=1.0, theta=0.0
% INFO    : Bus 61383	: V=1.0074754, theta=19.441709 -> V=1.0, theta=0.0
% INFO    : Bus 61384	: V=1.0074695, theta=19.526717 -> V=1.0, theta=0.0
% INFO    : Bus 61385	: V=1.0100006, theta=20.966091 -> V=1.0, theta=0.0
% INFO    : Bus 61386	: V=1.0103932, theta=21.219205 -> V=1.0, theta=0.0
% INFO    : Bus 61387	: V=1.0029735, theta=19.091985 -> V=1.0, theta=0.0
% INFO    : Bus 61388	: V=0.9992224, theta=18.550631 -> V=1.0, theta=0.0
% INFO    : Bus 61389	: V=1.0061196, theta=19.434576 -> V=1.0, theta=0.0
% INFO    : Bus 61390	: V=1.0001621, theta=18.556595 -> V=1.0, theta=0.0
% INFO    : Bus 61391	: V=0.9995692, theta=18.530092 -> V=1.0, theta=0.0
% INFO    : Bus 61392	: V=0.9990269, theta=18.518673 -> V=1.0, theta=0.0
% INFO    : Bus 61393	: V=0.9995511, theta=17.436114 -> V=1.0, theta=0.0
% INFO    : Bus 61394	: V=1.0086181, theta=19.162731 -> V=1.0, theta=0.0
% INFO    : Bus 61395	: V=0.9941214, theta=16.800677 -> V=1.0, theta=0.0
% INFO    : Bus 61396	: V=0.9957177, theta=18.289531 -> V=1.0, theta=0.0
% INFO    : Bus 61397	: V=1.0049214, theta=19.267905 -> V=1.0, theta=0.0
% INFO    : Bus 61398	: V=1.0015608, theta=18.476814 -> V=1.0, theta=0.0
% INFO    : Bus 61399	: V=0.9972842, theta=18.248099 -> V=1.0, theta=0.0
% INFO    : Bus 61400	: V=1.004149, theta=19.164366 -> V=1.0, theta=0.0
% INFO    : Bus 61401	: V=1.00403, theta=18.95828 -> V=1.0, theta=0.0
% INFO    : Bus 61402	: V=0.9948491, theta=16.816514 -> V=1.0, theta=0.0
% INFO    : Bus 61403	: V=0.9941318, theta=16.815156 -> V=1.0, theta=0.0
% INFO    : Bus 61404	: V=0.9949846, theta=16.836892 -> V=1.0, theta=0.0
% INFO    : Bus 61405	: V=0.9938823, theta=16.673215 -> V=1.0, theta=0.0
% INFO    : Bus 61406	: V=0.9921066, theta=18.02252 -> V=1.0, theta=0.0
% INFO    : Bus 61407	: V=0.9933609, theta=18.106784 -> V=1.0, theta=0.0
% INFO    : Bus 61408	: V=1.003341, theta=19.365975 -> V=1.0, theta=0.0
% INFO    : Bus 61409	: V=0.9978056, theta=18.268763 -> V=1.0, theta=0.0
% INFO    : Bus 61410	: V=0.9838392, theta=15.591505 -> V=1.0, theta=0.0
% INFO    : Bus 61411	: V=0.9947415, theta=18.292344 -> V=1.0, theta=0.0
% INFO    : Bus 61412	: V=0.99179, theta=18.013952 -> V=1.0, theta=0.0
% INFO    : Bus 61413	: V=0.9906739, theta=17.976701 -> V=1.0, theta=0.0
% INFO    : Bus 61414	: V=0.9842088, theta=15.600327 -> V=1.0, theta=0.0
% INFO    : Bus 61415	: V=0.9862045, theta=15.66059 -> V=1.0, theta=0.0
% INFO    : Bus 61416	: V=0.992969, theta=16.648774 -> V=1.0, theta=0.0
% INFO    : Bus 61417	: V=0.9913012, theta=16.587657 -> V=1.0, theta=0.0
% INFO    : Bus 61418	: V=0.9904608, theta=16.564692 -> V=1.0, theta=0.0
% INFO    : Bus 61419	: V=0.9852691, theta=15.727593 -> V=1.0, theta=0.0
% INFO    : Bus 61420	: V=1.0015088, theta=18.185279 -> V=1.0, theta=0.0
% INFO    : Bus 61421	: V=0.9880786, theta=15.783441 -> V=1.0, theta=0.0
% INFO    : Bus 61422	: V=0.986332, theta=15.750057 -> V=1.0, theta=0.0
% INFO    : Bus 61423	: V=1.0062928, theta=20.589032 -> V=1.0, theta=0.0
% INFO    : Bus 61424	: V=1.0050484, theta=21.712613 -> V=1.0, theta=0.0
% INFO    : Bus 61425	: V=0.9860372, theta=18.008685 -> V=1.0, theta=0.0
% INFO    : Bus 61426	: V=1.0043346, theta=22.300843 -> V=1.0, theta=0.0
% INFO    : Bus 61427	: V=1.0045045, theta=21.494259 -> V=1.0, theta=0.0
% INFO    : Bus 61428	: V=1.0046855, theta=22.877745 -> V=1.0, theta=0.0
% INFO    : Bus 61429	: V=1.0048816, theta=20.773742 -> V=1.0, theta=0.0
% INFO    : Bus 61430	: V=1.0015658, theta=20.304392 -> V=1.0, theta=0.0
% INFO    : Bus 61431	: V=1.0055813, theta=22.896405 -> V=1.0, theta=0.0
% INFO    : Bus 61432	: V=1.0063177, theta=19.84121 -> V=1.0, theta=0.0
% INFO    : Bus 61433	: V=1.0045539, theta=21.808845 -> V=1.0, theta=0.0
% INFO    : Bus 61434	: V=1.0006333, theta=18.88474 -> V=1.0, theta=0.0
% INFO    : Bus 61435	: V=1.0077724, theta=20.059656 -> V=1.0, theta=0.0
% INFO    : Bus 61436	: V=1.0148168, theta=22.07459 -> V=1.0, theta=0.0
% INFO    : Bus 61437	: V=1.0081961, theta=19.847261 -> V=1.0, theta=0.0
% INFO    : Bus 61438	: V=1.0021462, theta=18.568248 -> V=1.0, theta=0.0
% INFO    : Bus 61439	: V=1.0072172, theta=19.677184 -> V=1.0, theta=0.0
% INFO    : Bus 61440	: V=0.9993194, theta=18.442575 -> V=1.0, theta=0.0
% INFO    : Bus 61441	: V=1.0005817, theta=18.469843 -> V=1.0, theta=0.0
% INFO    : Bus 61442	: V=1.0027009, theta=18.585379 -> V=1.0, theta=0.0
% INFO    : Bus 61443	: V=1.0073504, theta=19.336899 -> V=1.0, theta=0.0
% INFO    : Bus 61444	: V=1.0004292, theta=18.447197 -> V=1.0, theta=0.0
% INFO    : Bus 61445	: V=1.0008649, theta=17.624368 -> V=1.0, theta=0.0
% INFO    : Bus 61446	: V=1.0100006, theta=19.662044 -> V=1.0, theta=0.0
% INFO    : Bus 61447	: V=1.0034002, theta=17.689762 -> V=1.0, theta=0.0
% INFO    : Bus 61448	: V=1.0099179, theta=18.923177 -> V=1.0, theta=0.0
% INFO    : Bus 61449	: V=1.0027844, theta=17.64547 -> V=1.0, theta=0.0
% INFO    : Bus 61450	: V=1.0099544, theta=19.78283 -> V=1.0, theta=0.0
% INFO    : Bus 61451	: V=1.0082807, theta=18.829434 -> V=1.0, theta=0.0
% INFO    : Bus 61452	: V=1.0095178, theta=18.924975 -> V=1.0, theta=0.0
% INFO    : Bus 61453	: V=1.0033741, theta=17.864882 -> V=1.0, theta=0.0
% INFO    : Bus 61454	: V=1.0114157, theta=19.019049 -> V=1.0, theta=0.0
% INFO    : Bus 61455	: V=1.0300006, theta=20.159772 -> V=1.0, theta=0.0
% INFO    : Bus 61456	: V=1.0092695, theta=18.395914 -> V=1.0, theta=0.0
% INFO    : Bus 61457	: V=1.0042213, theta=17.996056 -> V=1.0, theta=0.0
% INFO    : Bus 61458	: V=1.0028492, theta=17.895525 -> V=1.0, theta=0.0
% INFO    : Bus 61459	: V=1.0029443, theta=17.851991 -> V=1.0, theta=0.0
% INFO    : Bus 61460	: V=1.0026586, theta=17.849094 -> V=1.0, theta=0.0
% INFO    : Bus 61461	: V=1.0012859, theta=17.824431 -> V=1.0, theta=0.0
% INFO    : Bus 61462	: V=1.0026288, theta=17.858152 -> V=1.0, theta=0.0
% INFO    : Bus 61463	: V=1.0026309, theta=17.860236 -> V=1.0, theta=0.0
% INFO    : Bus 61464	: V=1.0031828, theta=17.895051 -> V=1.0, theta=0.0
% INFO    : Bus 61465	: V=1.0053244, theta=18.695729 -> V=1.0, theta=0.0
% INFO    : Bus 61466	: V=1.0059707, theta=18.643235 -> V=1.0, theta=0.0
% INFO    : Bus 61467	: V=1.0046101, theta=18.547751 -> V=1.0, theta=0.0
% INFO    : Bus 61468	: V=0.9917821, theta=16.914916 -> V=1.0, theta=0.0
% INFO    : Bus 61469	: V=0.9978696, theta=17.697085 -> V=1.0, theta=0.0
% INFO    : Bus 61470	: V=0.9851221, theta=16.367453 -> V=1.0, theta=0.0
% INFO    : Bus 61471	: V=1.0015082, theta=17.700963 -> V=1.0, theta=0.0
% INFO    : Bus 61472	: V=1.0031103, theta=18.229079 -> V=1.0, theta=0.0
% INFO    : Bus 61473	: V=0.9791878, theta=16.240075 -> V=1.0, theta=0.0
% INFO    : Bus 61474	: V=0.9982571, theta=19.00201 -> V=1.0, theta=0.0
% INFO    : Bus 61475	: V=1.0031788, theta=19.699185 -> V=1.0, theta=0.0
% INFO    : Bus 61476	: V=1.0025542, theta=20.604634 -> V=1.0, theta=0.0
% INFO    : Bus 61477	: V=1.0003194, theta=21.082319 -> V=1.0, theta=0.0
% INFO    : Bus 61478	: V=0.9858979, theta=18.990684 -> V=1.0, theta=0.0
% INFO    : Bus 61479	: V=0.9869638, theta=19.056352 -> V=1.0, theta=0.0
% INFO    : Bus 61480	: V=1.0009533, theta=21.849388 -> V=1.0, theta=0.0
% INFO    : Bus 61481	: V=0.9923311, theta=19.456062 -> V=1.0, theta=0.0
% INFO    : Bus 61482	: V=1.0060772, theta=18.539947 -> V=1.0, theta=0.0
% INFO    : Bus 61483	: V=1.0094578, theta=19.115819 -> V=1.0, theta=0.0
% INFO    : Bus 61484	: V=1.0047816, theta=18.788298 -> V=1.0, theta=0.0
% INFO    : Bus 61485	: V=1.0072581, theta=26.73762 -> V=1.0, theta=0.0
% INFO    : Bus 61486	: V=1.0087359, theta=22.06225 -> V=1.0, theta=0.0
% INFO    : Bus 61487	: V=0.9915005, theta=21.537743 -> V=1.0, theta=0.0
% INFO    : Bus 61488	: V=0.9913056, theta=21.439429 -> V=1.0, theta=0.0
% INFO    : Bus 61489	: V=1.0053221, theta=22.234201 -> V=1.0, theta=0.0
% INFO    : Bus 61490	: V=0.9837029, theta=20.971229 -> V=1.0, theta=0.0
% INFO    : Bus 61491	: V=0.9869463, theta=23.711912 -> V=1.0, theta=0.0
% INFO    : Bus 61492	: V=0.9895249, theta=23.771011 -> V=1.0, theta=0.0
% INFO    : Bus 61493	: V=0.9999709, theta=32.120943 -> V=1.0, theta=0.0
% INFO    : Bus 61494	: V=0.9983659, theta=28.31896 -> V=1.0, theta=0.0
% INFO    : Bus 61495	: V=1.0005032, theta=25.259568 -> V=1.0, theta=0.0
% INFO    : Bus 61496	: V=1.0100006, theta=25.41126 -> V=1.0, theta=0.0
% INFO    : Bus 61497	: V=0.9990569, theta=-0.88875 -> V=1.0, theta=0.0
% INFO    : Bus 61498	: V=0.9891943, theta=-2.290583 -> V=1.0, theta=0.0
% INFO    : Bus 61499	: V=0.9996423, theta=-0.832448 -> V=1.0, theta=0.0
% INFO    : Bus 61500	: V=0.9902298, theta=-2.181703 -> V=1.0, theta=0.0
% INFO    : Bus 61501	: V=0.9891575, theta=-2.868815 -> V=1.0, theta=0.0
% INFO    : Bus 61502	: V=0.9906442, theta=-2.829754 -> V=1.0, theta=0.0
% INFO    : Bus 61503	: V=0.9895695, theta=-2.931318 -> V=1.0, theta=0.0
% INFO    : Bus 61504	: V=0.9965508, theta=-1.884871 -> V=1.0, theta=0.0
% INFO    : Bus 61505	: V=1.0043871, theta=-0.087837 -> V=1.0, theta=0.0
% INFO    : Bus 61506	: V=0.9895189, theta=-2.7337 -> V=1.0, theta=0.0
% INFO    : Bus 61507	: V=0.9899108, theta=-2.699061 -> V=1.0, theta=0.0
% INFO    : Bus 61508	: V=0.9896837, theta=-2.681691 -> V=1.0, theta=0.0
% INFO    : Bus 61509	: V=0.9881953, theta=-3.058387 -> V=1.0, theta=0.0
% INFO    : Bus 61510	: V=1.0018834, theta=-0.600957 -> V=1.0, theta=0.0
% INFO    : Bus 61511	: V=1.0012773, theta=-0.66472 -> V=1.0, theta=0.0
% INFO    : Bus 61512	: V=0.9974205, theta=-1.939114 -> V=1.0, theta=0.0
% INFO    : Bus 61513	: V=1.0027547, theta=-0.516471 -> V=1.0, theta=0.0
% INFO    : Bus 61514	: V=1.0038778, theta=-0.467331 -> V=1.0, theta=0.0
% INFO    : Bus 61515	: V=0.9963931, theta=-1.973673 -> V=1.0, theta=0.0
% INFO    : Bus 61516	: V=0.9990979, theta=-1.565355 -> V=1.0, theta=0.0
% INFO    : Bus 61517	: V=1.0035259, theta=-0.412917 -> V=1.0, theta=0.0
% INFO    : Bus 61518	: V=1.0005026, theta=-1.337535 -> V=1.0, theta=0.0
% INFO    : Bus 61519	: V=1.0047886, theta=-0.228964 -> V=1.0, theta=0.0
% INFO    : Bus 61520	: V=0.9969459, theta=-1.709678 -> V=1.0, theta=0.0
% INFO    : Bus 61521	: V=1.0063047, theta=0.269562 -> V=1.0, theta=0.0
% INFO    : Bus 61522	: V=0.9883912, theta=-2.439109 -> V=1.0, theta=0.0
% INFO    : Bus 61523	: V=1.0096138, theta=0.892949 -> V=1.0, theta=0.0
% INFO    : Bus 61524	: V=0.9946924, theta=-2.264961 -> V=1.0, theta=0.0
% INFO    : Bus 61525	: V=0.9883413, theta=-3.709079 -> V=1.0, theta=0.0
% INFO    : Bus 61526	: V=0.9863133, theta=-3.207184 -> V=1.0, theta=0.0
% INFO    : Bus 61527	: V=0.9879102, theta=-2.648447 -> V=1.0, theta=0.0
% INFO    : Bus 61528	: V=0.9908102, theta=-2.428545 -> V=1.0, theta=0.0
% INFO    : Bus 61529	: V=0.9963479, theta=-2.126312 -> V=1.0, theta=0.0
% INFO    : Bus 61530	: V=0.991096, theta=-2.431334 -> V=1.0, theta=0.0
% INFO    : Bus 61531	: V=1.0016671, theta=-0.671248 -> V=1.0, theta=0.0
% INFO    : Bus 61532	: V=0.9933335, theta=-2.150263 -> V=1.0, theta=0.0
% INFO    : Bus 61533	: V=0.9910647, theta=-2.212485 -> V=1.0, theta=0.0
% INFO    : Bus 61534	: V=1.005094, theta=-0.374589 -> V=1.0, theta=0.0
% INFO    : Bus 61535	: V=1.0116772, theta=0.855439 -> V=1.0, theta=0.0
% INFO    : Bus 61536	: V=1.0105855, theta=0.650319 -> V=1.0, theta=0.0
% INFO    : Bus 61537	: V=1.0077212, theta=0.210165 -> V=1.0, theta=0.0
% INFO    : Bus 61538	: V=1.0053979, theta=0.583907 -> V=1.0, theta=0.0
% INFO    : Bus 61539	: V=0.9960525, theta=-0.312319 -> V=1.0, theta=0.0
% INFO    : Bus 61540	: V=1.0113988, theta=0.864481 -> V=1.0, theta=0.0
% INFO    : Bus 61541	: V=1.0131827, theta=1.588956 -> V=1.0, theta=0.0
% INFO    : Bus 61542	: V=1.0183024, theta=2.320637 -> V=1.0, theta=0.0
% INFO    : Bus 61543	: V=1.013407, theta=1.094658 -> V=1.0, theta=0.0
% INFO    : Bus 61544	: V=1.0162282, theta=1.1428 -> V=1.0, theta=0.0
% INFO    : Bus 61545	: V=1.0018894, theta=-1.234977 -> V=1.0, theta=0.0
% INFO    : Bus 61546	: V=1.0071477, theta=-3.330358 -> V=1.0, theta=0.0
% INFO    : Bus 61547	: V=1.0100006, theta=22.144886 -> V=1.0, theta=0.0
% INFO    : Bus 61548	: V=1.0100006, theta=20.921926 -> V=1.0, theta=0.0
% INFO    : Bus 61549	: V=1.0075672, theta=19.56664 -> V=1.0, theta=0.0
% INFO    : Bus 61550	: V=1.0046057, theta=18.34575 -> V=1.0, theta=0.0
% INFO    : Bus 61551	: V=1.0101274, theta=19.792514 -> V=1.0, theta=0.0
% INFO    : Bus 61552	: V=1.012713, theta=20.559372 -> V=1.0, theta=0.0
% INFO    : Bus 61553	: V=1.0151483, theta=20.079769 -> V=1.0, theta=0.0
% INFO    : Bus 61554	: V=1.0200006, theta=20.343623 -> V=1.0, theta=0.0
% INFO    : Bus 61555	: V=1.0200006, theta=20.295522 -> V=1.0, theta=0.0
% INFO    : Bus 61556	: V=1.0079162, theta=19.682669 -> V=1.0, theta=0.0
% INFO    : Bus 61557	: V=1.0105017, theta=19.798102 -> V=1.0, theta=0.0
% INFO    : Bus 61558	: V=1.0200006, theta=20.121413 -> V=1.0, theta=0.0
% INFO    : Bus 61559	: V=1.0049779, theta=3.381771 -> V=1.0, theta=0.0
% INFO    : Bus 61560	: V=1.0300007, theta=7.660087 -> V=1.0, theta=0.0
% INFO    : Bus 61561	: V=1.0113453, theta=3.817024 -> V=1.0, theta=0.0
% INFO    : Bus 61562	: V=1.010999, theta=3.790038 -> V=1.0, theta=0.0
% INFO    : Bus 61563	: V=1.0014897, theta=2.107224 -> V=1.0, theta=0.0
% INFO    : Bus 61564	: V=1.0104644, theta=3.73233 -> V=1.0, theta=0.0
% INFO    : Bus 61565	: V=1.010086, theta=3.698841 -> V=1.0, theta=0.0
% INFO    : Bus 61566	: V=0.9996872, theta=2.35031 -> V=1.0, theta=0.0
% INFO    : Bus 61567	: V=0.9988941, theta=2.32984 -> V=1.0, theta=0.0
% INFO    : Bus 61568	: V=0.9995323, theta=2.438045 -> V=1.0, theta=0.0
% INFO    : Bus 61569	: V=1.0074952, theta=3.387344 -> V=1.0, theta=0.0
% INFO    : Bus 61570	: V=1.0067504, theta=3.354447 -> V=1.0, theta=0.0
% INFO    : Bus 61571	: V=0.9991029, theta=2.021014 -> V=1.0, theta=0.0
% INFO    : Bus 61572	: V=1.0084139, theta=3.444627 -> V=1.0, theta=0.0
% INFO    : Bus 61573	: V=1.0096754, theta=3.630742 -> V=1.0, theta=0.0
% INFO    : Bus 61574	: V=1.0095621, theta=3.444505 -> V=1.0, theta=0.0
% INFO    : Bus 61575	: V=1.0093927, theta=3.541829 -> V=1.0, theta=0.0
% INFO    : Bus 61576	: V=1.0059148, theta=2.349139 -> V=1.0, theta=0.0
% INFO    : Bus 61577	: V=1.00031, theta=5.984889 -> V=1.0, theta=0.0
% INFO    : Bus 61578	: V=1.0079401, theta=3.906898 -> V=1.0, theta=0.0
% INFO    : Bus 61579	: V=0.9968115, theta=1.46178 -> V=1.0, theta=0.0
% INFO    : Bus 61580	: V=1.0075372, theta=3.815126 -> V=1.0, theta=0.0
% INFO    : Bus 61581	: V=1.0075249, theta=3.857983 -> V=1.0, theta=0.0
% INFO    : Bus 61582	: V=0.9828515, theta=-0.112993 -> V=1.0, theta=0.0
% INFO    : Bus 61583	: V=0.9785926, theta=-0.129819 -> V=1.0, theta=0.0
% INFO    : Bus 61584	: V=0.9912229, theta=0.225802 -> V=1.0, theta=0.0
% INFO    : Bus 61585	: V=1.0100007, theta=3.87504 -> V=1.0, theta=0.0
% INFO    : Bus 61586	: V=1.0035127, theta=1.585707 -> V=1.0, theta=0.0
% INFO    : Bus 61587	: V=1.0100804, theta=3.838204 -> V=1.0, theta=0.0
% INFO    : Bus 61588	: V=1.0084073, theta=3.776326 -> V=1.0, theta=0.0
% INFO    : Bus 61589	: V=1.0058289, theta=3.570218 -> V=1.0, theta=0.0
% INFO    : Bus 61590	: V=1.0100099, theta=3.053297 -> V=1.0, theta=0.0
% INFO    : Bus 61591	: V=0.9711789, theta=-0.442458 -> V=1.0, theta=0.0
% INFO    : Bus 61592	: V=1.0112297, theta=3.710814 -> V=1.0, theta=0.0
% INFO    : Bus 61593	: V=1.0200006, theta=20.831678 -> V=1.0, theta=0.0
% INFO    : Bus 61594	: V=1.0104152, theta=19.733535 -> V=1.0, theta=0.0
% INFO    : Bus 61595	: V=1.0100006, theta=20.327397 -> V=1.0, theta=0.0
% INFO    : Bus 61596	: V=1.0132391, theta=19.621836 -> V=1.0, theta=0.0
% INFO    : Bus 61597	: V=1.0100006, theta=20.235562 -> V=1.0, theta=0.0
% INFO    : Bus 61598	: V=1.0087651, theta=19.536603 -> V=1.0, theta=0.0
% INFO    : Bus 61599	: V=1.0041, theta=18.7886 -> V=1.0, theta=0.0
% INFO    : Bus 61600	: V=1.0101979, theta=19.973953 -> V=1.0, theta=0.0
% INFO    : Bus 61601	: V=0.9902832, theta=18.864711 -> V=1.0, theta=0.0
% INFO    : Bus 61602	: V=1.0219636, theta=22.962635 -> V=1.0, theta=0.0
% INFO    : Bus 61603	: V=1.0179657, theta=17.158335 -> V=1.0, theta=0.0
% INFO    : Bus 61604	: V=1.0196516, theta=17.258907 -> V=1.0, theta=0.0
% INFO    : Bus 61605	: V=1.0194569, theta=17.016027 -> V=1.0, theta=0.0
% INFO    : Bus 61606	: V=1.0085866, theta=15.664387 -> V=1.0, theta=0.0
% INFO    : Bus 61607	: V=1.0067903, theta=15.544713 -> V=1.0, theta=0.0
% INFO    : Bus 61608	: V=1.009091, theta=15.740086 -> V=1.0, theta=0.0
% INFO    : Bus 61609	: V=1.0096156, theta=15.838666 -> V=1.0, theta=0.0
% INFO    : Bus 61610	: V=1.0072553, theta=15.602228 -> V=1.0, theta=0.0
% INFO    : Bus 61611	: V=1.0193071, theta=16.615066 -> V=1.0, theta=0.0
% INFO    : Bus 61612	: V=1.0108216, theta=15.74134 -> V=1.0, theta=0.0
% INFO    : Bus 61613	: V=1.0063004, theta=15.5814 -> V=1.0, theta=0.0
% INFO    : Bus 61614	: V=1.0056053, theta=15.616173 -> V=1.0, theta=0.0
% INFO    : Bus 61615	: V=1.0072167, theta=15.696358 -> V=1.0, theta=0.0
% INFO    : Bus 61616	: V=1.0061016, theta=15.673499 -> V=1.0, theta=0.0
% INFO    : Bus 61617	: V=1.0146819, theta=16.74508 -> V=1.0, theta=0.0
% INFO    : Bus 61618	: V=1.0140995, theta=16.710615 -> V=1.0, theta=0.0
% INFO    : Bus 61619	: V=1.0200007, theta=17.483243 -> V=1.0, theta=0.0
% INFO    : Bus 61620	: V=1.0168745, theta=16.975478 -> V=1.0, theta=0.0
% INFO    : Bus 61621	: V=1.0083118, theta=15.95461 -> V=1.0, theta=0.0
% INFO    : Bus 61622	: V=1.0205688, theta=17.794745 -> V=1.0, theta=0.0
% INFO    : Bus 61623	: V=1.0300007, theta=20.780609 -> V=1.0, theta=0.0
% INFO    : Bus 61624	: V=1.0007883, theta=15.664649 -> V=1.0, theta=0.0
% INFO    : Bus 61625	: V=1.0057299, theta=18.675378 -> V=1.0, theta=0.0
% INFO    : Bus 61626	: V=1.0019096, theta=18.752381 -> V=1.0, theta=0.0
% INFO    : Bus 61627	: V=1.0020036, theta=18.810892 -> V=1.0, theta=0.0
% INFO    : Bus 61628	: V=1.0036626, theta=18.511561 -> V=1.0, theta=0.0
% INFO    : Bus 61629	: V=0.9981765, theta=17.578171 -> V=1.0, theta=0.0
% INFO    : Bus 61630	: V=1.0080156, theta=18.465269 -> V=1.0, theta=0.0
% INFO    : Bus 61631	: V=0.9949388, theta=17.33012 -> V=1.0, theta=0.0
% INFO    : Bus 61632	: V=1.0110833, theta=18.264539 -> V=1.0, theta=0.0
% INFO    : Bus 61633	: V=1.0053489, theta=19.454207 -> V=1.0, theta=0.0
% INFO    : Bus 61634	: V=1.0005456, theta=15.329799 -> V=1.0, theta=0.0
% INFO    : Bus 61635	: V=1.0079707, theta=15.525467 -> V=1.0, theta=0.0
% INFO    : Bus 61636	: V=1.0200007, theta=15.357374 -> V=1.0, theta=0.0
% INFO    : Bus 61637	: V=1.0200007, theta=13.330099 -> V=1.0, theta=0.0
% INFO    : Bus 61638	: V=1.0138155, theta=16.154044 -> V=1.0, theta=0.0
% INFO    : Bus 61639	: V=0.997005, theta=15.265292 -> V=1.0, theta=0.0
% INFO    : Bus 61640	: V=1.0140031, theta=16.691185 -> V=1.0, theta=0.0
% INFO    : Bus 61641	: V=1.0032456, theta=15.450666 -> V=1.0, theta=0.0
% INFO    : Bus 61642	: V=0.9920197, theta=14.641599 -> V=1.0, theta=0.0
% INFO    : Bus 61643	: V=1.0060317, theta=17.743618 -> V=1.0, theta=0.0
% INFO    : Bus 61644	: V=1.0075068, theta=14.931337 -> V=1.0, theta=0.0
% INFO    : Bus 61645	: V=0.990908, theta=15.161895 -> V=1.0, theta=0.0
% INFO    : Bus 61646	: V=1.0064418, theta=17.76862 -> V=1.0, theta=0.0
% INFO    : Bus 61647	: V=1.0069948, theta=17.82454 -> V=1.0, theta=0.0
% INFO    : Bus 61648	: V=1.0300003, theta=21.231643 -> V=1.0, theta=0.0
% INFO    : Bus 61649	: V=1.0211787, theta=20.947778 -> V=1.0, theta=0.0
% INFO    : Bus 61650	: V=1.0206266, theta=20.940838 -> V=1.0, theta=0.0
% INFO    : Bus 61651	: V=1.0201843, theta=20.949039 -> V=1.0, theta=0.0
% INFO    : Bus 61652	: V=1.0192265, theta=21.001947 -> V=1.0, theta=0.0
% INFO    : Bus 61653	: V=1.0177682, theta=20.548589 -> V=1.0, theta=0.0
% INFO    : Bus 61654	: V=1.0172277, theta=20.494105 -> V=1.0, theta=0.0
% INFO    : Bus 61655	: V=1.0173398, theta=20.505532 -> V=1.0, theta=0.0
% INFO    : Bus 61656	: V=1.0181976, theta=21.138877 -> V=1.0, theta=0.0
% INFO    : Bus 61657	: V=1.0134048, theta=22.797433 -> V=1.0, theta=0.0
% INFO    : Bus 61658	: V=1.0051475, theta=15.800587 -> V=1.0, theta=0.0
% INFO    : Bus 61659	: V=1.0173985, theta=15.706452 -> V=1.0, theta=0.0
% INFO    : Bus 61660	: V=1.0300005, theta=16.909881 -> V=1.0, theta=0.0
% INFO    : Bus 61661	: V=1.0027619, theta=26.107248 -> V=1.0, theta=0.0
% INFO    : Bus 61662	: V=1.0115557, theta=27.342087 -> V=1.0, theta=0.0
% INFO    : Bus 61663	: V=1.0161215, theta=26.890178 -> V=1.0, theta=0.0
% INFO    : Bus 61664	: V=0.9993858, theta=26.566157 -> V=1.0, theta=0.0
% INFO    : Bus 61665	: V=0.9913439, theta=25.583656 -> V=1.0, theta=0.0
% INFO    : Bus 61666	: V=0.9967072, theta=25.741284 -> V=1.0, theta=0.0
% INFO    : Bus 61667	: V=0.9988642, theta=24.266016 -> V=1.0, theta=0.0
% INFO    : Bus 61668	: V=1.0300004, theta=30.515002 -> V=1.0, theta=0.0
% INFO    : Bus 61669	: V=1.0103737, theta=27.581103 -> V=1.0, theta=0.0
% INFO    : Bus 61670	: V=0.9899775, theta=24.628918 -> V=1.0, theta=0.0
% INFO    : Bus 61671	: V=1.0136969, theta=25.706121 -> V=1.0, theta=0.0
% INFO    : Bus 61672	: V=1.009926, theta=28.913346 -> V=1.0, theta=0.0
% INFO    : Bus 61673	: V=1.0300004, theta=31.489648 -> V=1.0, theta=0.0
% INFO    : Bus 61674	: V=1.0200004, theta=31.281196 -> V=1.0, theta=0.0
% INFO    : Bus 61675	: V=1.0100004, theta=30.986974 -> V=1.0, theta=0.0
% INFO    : Bus 61676	: V=1.0200004, theta=30.409872 -> V=1.0, theta=0.0
% INFO    : Bus 61677	: V=1.0100005, theta=22.602653 -> V=1.0, theta=0.0
% INFO    : Bus 61678	: V=1.0140494, theta=25.28184 -> V=1.0, theta=0.0
% INFO    : Bus 61679	: V=1.0181862, theta=23.900401 -> V=1.0, theta=0.0
% INFO    : Bus 61680	: V=1.0172999, theta=23.609165 -> V=1.0, theta=0.0
% INFO    : Bus 61681	: V=1.0027873, theta=23.264277 -> V=1.0, theta=0.0
% INFO    : Bus 61682	: V=1.0214163, theta=14.838718 -> V=1.0, theta=0.0
% INFO    : Bus 61683	: V=1.0129412, theta=20.013953 -> V=1.0, theta=0.0
% INFO    : Bus 61684	: V=0.9713963, theta=19.14703 -> V=1.0, theta=0.0
% INFO    : Bus 61685	: V=1.0300004, theta=28.248054 -> V=1.0, theta=0.0
% INFO    : Bus 61686	: V=1.0115838, theta=23.97383 -> V=1.0, theta=0.0
% INFO    : Bus 61687	: V=1.0234435, theta=25.781812 -> V=1.0, theta=0.0
% INFO    : Bus 61688	: V=1.0086339, theta=23.529893 -> V=1.0, theta=0.0
% INFO    : Bus 61689	: V=0.9895082, theta=29.642132 -> V=1.0, theta=0.0
% INFO    : Bus 61690	: V=0.9860344, theta=27.738729 -> V=1.0, theta=0.0
% INFO    : Bus 61691	: V=0.9822123, theta=27.304356 -> V=1.0, theta=0.0
% INFO    : Bus 61692	: V=1.0300004, theta=34.008363 -> V=1.0, theta=0.0
% INFO    : Bus 61693	: V=0.9676789, theta=14.836835 -> V=1.0, theta=0.0
% INFO    : Bus 61694	: V=0.9650831, theta=15.71518 -> V=1.0, theta=0.0
% INFO    : Bus 61695	: V=1.0028564, theta=23.772745 -> V=1.0, theta=0.0
% INFO    : Bus 61696	: V=1.0045909, theta=22.60628 -> V=1.0, theta=0.0
% INFO    : Bus 61697	: V=1.0200004, theta=25.053528 -> V=1.0, theta=0.0
% INFO    : Bus 61698	: V=1.0056443, theta=22.464251 -> V=1.0, theta=0.0
% INFO    : Bus 61699	: V=1.0020101, theta=22.270528 -> V=1.0, theta=0.0
% INFO    : Bus 61700	: V=1.0067894, theta=23.009741 -> V=1.0, theta=0.0
% INFO    : Bus 61701	: V=0.9982866, theta=21.328833 -> V=1.0, theta=0.0
% INFO    : Bus 61702	: V=1.0067682, theta=23.052201 -> V=1.0, theta=0.0
% INFO    : Bus 61703	: V=1.0200004, theta=25.244225 -> V=1.0, theta=0.0
% INFO    : Bus 61704	: V=1.0057977, theta=22.769225 -> V=1.0, theta=0.0
% INFO    : Bus 61705	: V=1.0015509, theta=21.443499 -> V=1.0, theta=0.0
% INFO    : Bus 61706	: V=1.0094512, theta=23.170789 -> V=1.0, theta=0.0
% INFO    : Bus 61707	: V=1.0092369, theta=23.19931 -> V=1.0, theta=0.0
% INFO    : Bus 61708	: V=0.9937471, theta=20.716142 -> V=1.0, theta=0.0
% INFO    : Bus 61709	: V=0.9968177, theta=20.80503 -> V=1.0, theta=0.0
% INFO    : Bus 61710	: V=1.0060907, theta=23.09163 -> V=1.0, theta=0.0
% INFO    : Bus 61711	: V=0.9942346, theta=20.745408 -> V=1.0, theta=0.0
% INFO    : Bus 61712	: V=1.0055448, theta=23.214196 -> V=1.0, theta=0.0
% INFO    : Bus 61713	: V=0.9960739, theta=21.260132 -> V=1.0, theta=0.0
% INFO    : Bus 61714	: V=0.9902626, theta=24.585668 -> V=1.0, theta=0.0
% INFO    : Bus 61715	: V=1.0200004, theta=25.943875 -> V=1.0, theta=0.0
% INFO    : Bus 61716	: V=1.001976, theta=24.897765 -> V=1.0, theta=0.0
% INFO    : Bus 61717	: V=1.0044934, theta=22.743233 -> V=1.0, theta=0.0
% INFO    : Bus 61718	: V=1.0070533, theta=9.06373 -> V=1.0, theta=0.0
% INFO    : Bus 61719	: V=0.9736972, theta=7.579651 -> V=1.0, theta=0.0
% INFO    : Bus 61720	: V=1.0300004, theta=22.511275 -> V=1.0, theta=0.0
% INFO    : Bus 61721	: V=1.0163666, theta=18.910358 -> V=1.0, theta=0.0
% INFO    : Bus 61722	: V=0.9968577, theta=27.995077 -> V=1.0, theta=0.0
% INFO    : Bus 61723	: V=0.9969228, theta=28.038158 -> V=1.0, theta=0.0
% INFO    : Bus 61724	: V=0.9946047, theta=27.591175 -> V=1.0, theta=0.0
% INFO    : Bus 61725	: V=0.9972577, theta=28.098285 -> V=1.0, theta=0.0
% INFO    : Bus 61726	: V=0.9953228, theta=27.635405 -> V=1.0, theta=0.0
% INFO    : Bus 61727	: V=0.9969948, theta=28.011649 -> V=1.0, theta=0.0
% INFO    : Bus 61728	: V=0.9918784, theta=27.469266 -> V=1.0, theta=0.0
% INFO    : Bus 61729	: V=0.9971379, theta=27.946879 -> V=1.0, theta=0.0
% INFO    : Bus 61730	: V=0.9972029, theta=27.948745 -> V=1.0, theta=0.0
% INFO    : Bus 61731	: V=0.9970241, theta=27.963637 -> V=1.0, theta=0.0
% INFO    : Bus 61732	: V=1.0031864, theta=28.449469 -> V=1.0, theta=0.0
% INFO    : Bus 61733	: V=0.9960523, theta=27.518723 -> V=1.0, theta=0.0
% INFO    : Bus 61734	: V=0.997588, theta=27.946077 -> V=1.0, theta=0.0
% INFO    : Bus 61735	: V=1.0003293, theta=28.00363 -> V=1.0, theta=0.0
% INFO    : Bus 61736	: V=0.9976905, theta=28.220707 -> V=1.0, theta=0.0
% INFO    : Bus 61737	: V=0.9935164, theta=27.44168 -> V=1.0, theta=0.0
% INFO    : Bus 61738	: V=1.0021119, theta=28.343413 -> V=1.0, theta=0.0
% INFO    : Bus 61739	: V=0.9862076, theta=24.266871 -> V=1.0, theta=0.0
% INFO    : Bus 61740	: V=1.0213083, theta=28.423434 -> V=1.0, theta=0.0
% INFO    : Bus 61741	: V=1.009927, theta=12.771545 -> V=1.0, theta=0.0
% INFO    : Bus 61742	: V=1.0029815, theta=11.602319 -> V=1.0, theta=0.0
% INFO    : Bus 61743	: V=1.0196445, theta=11.052624 -> V=1.0, theta=0.0
% INFO    : Bus 61744	: V=0.9774077, theta=8.232992 -> V=1.0, theta=0.0
% INFO    : Bus 61745	: V=0.9765279, theta=8.108714 -> V=1.0, theta=0.0
% INFO    : Bus 61746	: V=1.0300004, theta=32.47332 -> V=1.0, theta=0.0
% INFO    : Bus 61747	: V=1.0085507, theta=30.806923 -> V=1.0, theta=0.0
% INFO    : Bus 61748	: V=1.0143246, theta=19.388211 -> V=1.0, theta=0.0
% INFO    : Bus 61749	: V=1.0104593, theta=18.365349 -> V=1.0, theta=0.0
% INFO    : Bus 61750	: V=1.0116623, theta=18.400082 -> V=1.0, theta=0.0
% INFO    : Bus 61751	: V=1.021692, theta=19.617467 -> V=1.0, theta=0.0
% INFO    : Bus 61752	: V=1.0300005, theta=21.087974 -> V=1.0, theta=0.0
% INFO    : Bus 61753	: V=1.0200005, theta=18.320793 -> V=1.0, theta=0.0
% INFO    : Bus 61754	: V=1.0100004, theta=20.23945 -> V=1.0, theta=0.0
% INFO    : Bus 61755	: V=1.0098694, theta=19.873332 -> V=1.0, theta=0.0
% INFO    : Bus 61756	: V=1.0300004, theta=23.533943 -> V=1.0, theta=0.0
% INFO    : Bus 61757	: V=1.0200004, theta=24.392402 -> V=1.0, theta=0.0
% INFO    : Bus 61758	: V=1.0200004, theta=24.33377 -> V=1.0, theta=0.0
% INFO    : Bus 61759	: V=1.0018007, theta=20.683995 -> V=1.0, theta=0.0
% INFO    : Bus 61760	: V=1.0036373, theta=23.678328 -> V=1.0, theta=0.0
% INFO    : Bus 61761	: V=0.9934295, theta=23.067842 -> V=1.0, theta=0.0
% INFO    : Bus 61762	: V=1.0037545, theta=23.616318 -> V=1.0, theta=0.0
% INFO    : Bus 61763	: V=0.9985683, theta=23.489679 -> V=1.0, theta=0.0
% INFO    : Bus 61764	: V=1.0200004, theta=24.21155 -> V=1.0, theta=0.0
% INFO    : Bus 61765	: V=1.0181343, theta=25.647242 -> V=1.0, theta=0.0
% INFO    : Bus 61766	: V=1.0200004, theta=24.359284 -> V=1.0, theta=0.0
% INFO    : Bus 61767	: V=1.0275056, theta=27.613633 -> V=1.0, theta=0.0
% INFO    : Bus 61768	: V=0.9696452, theta=1.851655 -> V=1.0, theta=0.0
% INFO    : Bus 61769	: V=1.0206547, theta=8.575158 -> V=1.0, theta=0.0
% INFO    : Bus 61770	: V=1.0196796, theta=7.886537 -> V=1.0, theta=0.0
% INFO    : Bus 61771	: V=1.0294894, theta=8.105448 -> V=1.0, theta=0.0
% INFO    : Bus 61772	: V=1.0204488, theta=20.820875 -> V=1.0, theta=0.0
% INFO    : Bus 61773	: V=1.0300004, theta=18.702659 -> V=1.0, theta=0.0
% INFO    : Bus 61774	: V=1.0095179, theta=15.732424 -> V=1.0, theta=0.0
% INFO    : Bus 61775	: V=0.9541205, theta=12.351898 -> V=1.0, theta=0.0
% INFO    : Bus 61776	: V=0.9824283, theta=14.41789 -> V=1.0, theta=0.0
% INFO    : Bus 61777	: V=0.9906256, theta=15.418814 -> V=1.0, theta=0.0
% INFO    : Bus 61778	: V=1.0100005, theta=28.014944 -> V=1.0, theta=0.0
% INFO    : Bus 61779	: V=1.0200004, theta=28.169376 -> V=1.0, theta=0.0
% INFO    : Bus 61780	: V=1.03, theta=11.770455 -> V=1.0, theta=0.0
% INFO    : Bus 61781	: V=1.0300002, theta=52.029311 -> V=1.0, theta=0.0
% INFO    : Bus 61782	: V=1.0374729, theta=30.48877 -> V=1.0, theta=0.0
% INFO    : Bus 61783	: V=1.02, theta=34.687817 -> V=1.0, theta=0.0
% INFO    : Bus 61784	: V=1.02, theta=8.194316 -> V=1.0, theta=0.0
% INFO    : Bus 61785	: V=1.0200002, theta=-17.90721 -> V=1.0, theta=0.0
% INFO    : Bus 61786	: V=1.01, theta=5.804401 -> V=1.0, theta=0.0
% INFO    : Bus 61787	: V=1.02, theta=11.323782 -> V=1.0, theta=0.0
% INFO    : Bus 61788	: V=1.02, theta=1.538698 -> V=1.0, theta=0.0
% INFO    : Bus 61789	: V=1.02, theta=11.253393 -> V=1.0, theta=0.0
% INFO    : Bus 61790	: V=1.020002, theta=11.251226 -> V=1.0, theta=0.0
% INFO    : Bus 61791	: V=1.02, theta=10.971956 -> V=1.0, theta=0.0
% INFO    : Bus 61792	: V=1.0200002, theta=-13.069667 -> V=1.0, theta=0.0
% INFO    : Bus 61793	: V=1.02, theta=8.324687 -> V=1.0, theta=0.0
% INFO    : Bus 61794	: V=1.03, theta=7.732459 -> V=1.0, theta=0.0
% INFO    : Bus 61795	: V=1.0176345, theta=-6.184477 -> V=1.0, theta=0.0
% INFO    : Bus 61796	: V=1.01, theta=-1.792992 -> V=1.0, theta=0.0
% INFO    : Bus 61797	: V=1.0200002, theta=48.72479 -> V=1.0, theta=0.0
% INFO    : Bus 61798	: V=1.01, theta=-2.194808 -> V=1.0, theta=0.0
% INFO    : Bus 61799	: V=1.02, theta=28.379551 -> V=1.0, theta=0.0
% INFO    : Bus 61800	: V=1.0154489, theta=-4.302174 -> V=1.0, theta=0.0
% INFO    : Bus 61801	: V=1.02, theta=3.668892 -> V=1.0, theta=0.0
% INFO    : Bus 61802	: V=0.9899773, theta=-9.263973 -> V=1.0, theta=0.0
% INFO    : Bus 61803	: V=1.01, theta=0.149509 -> V=1.0, theta=0.0
% INFO    : Bus 61804	: V=1.01, theta=21.100064 -> V=1.0, theta=0.0
% INFO    : Bus 61805	: V=1.01, theta=21.370927 -> V=1.0, theta=0.0
% INFO    : Bus 61806	: V=1.0008931, theta=-20.134045 -> V=1.0, theta=0.0
% INFO    : Bus 61807	: V=1.01, theta=1.56264 -> V=1.0, theta=0.0
% INFO    : Bus 61808	: V=1.0200002, theta=-13.161545 -> V=1.0, theta=0.0
% INFO    : Bus 61809	: V=1.01, theta=-3.786561 -> V=1.0, theta=0.0
% INFO    : Bus 61810	: V=1.02, theta=-1.650988 -> V=1.0, theta=0.0
% INFO    : Bus 61811	: V=1.02, theta=-3.569208 -> V=1.0, theta=0.0
% INFO    : Bus 61812	: V=1.0249813, theta=-20.280022 -> V=1.0, theta=0.0
% INFO    : Bus 61813	: V=0.9886175, theta=-2.339572 -> V=1.0, theta=0.0
% INFO    : Bus 61814	: V=0.998529, theta=3.891747 -> V=1.0, theta=0.0
% INFO    : Bus 61815	: V=1.01, theta=2.350951 -> V=1.0, theta=0.0
% INFO    : Bus 61816	: V=1.002719, theta=19.739871 -> V=1.0, theta=0.0
% INFO    : Bus 61817	: V=0.9917337, theta=-8.095438 -> V=1.0, theta=0.0
% INFO    : Bus 61818	: V=0.9766093, theta=-4.984876 -> V=1.0, theta=0.0
% INFO    : Bus 61819	: V=1.02, theta=-19.058337 -> V=1.0, theta=0.0
% INFO    : Bus 61820	: V=1.0200003, theta=28.058596 -> V=1.0, theta=0.0
% INFO    : Bus 61821	: V=1.0300003, theta=33.202613 -> V=1.0, theta=0.0
% INFO    : Bus 61822	: V=1.0200003, theta=29.749893 -> V=1.0, theta=0.0
% INFO    : Bus 61823	: V=1.0200004, theta=24.439395 -> V=1.0, theta=0.0
% INFO    : Bus 61824	: V=1.0200004, theta=23.790442 -> V=1.0, theta=0.0
% INFO    : Bus 61825	: V=1.0131903, theta=23.800175 -> V=1.0, theta=0.0
% INFO    : Bus 61826	: V=1.0100003, theta=38.373326 -> V=1.0, theta=0.0
% INFO    : Bus 61827	: V=1.0100003, theta=36.320389 -> V=1.0, theta=0.0
% INFO    : Bus 61828	: V=1.0190438, theta=10.735634 -> V=1.0, theta=0.0
% INFO    : Bus 61829	: V=1.0200003, theta=13.776709 -> V=1.0, theta=0.0
% INFO    : Bus 61830	: V=1.0100003, theta=14.141538 -> V=1.0, theta=0.0
% INFO    : Bus 61831	: V=1.0304137, theta=31.333944 -> V=1.0, theta=0.0
% INFO    : Bus 61832	: V=1.0200003, theta=16.534511 -> V=1.0, theta=0.0
% INFO    : Bus 61833	: V=1.0200003, theta=14.322314 -> V=1.0, theta=0.0
% INFO    : Bus 61834	: V=1.0100003, theta=26.017921 -> V=1.0, theta=0.0
% INFO    : Bus 61835	: V=1.0300003, theta=22.448173 -> V=1.0, theta=0.0
% INFO    : Bus 61836	: V=1.0288264, theta=20.215341 -> V=1.0, theta=0.0
% INFO    : Bus 61837	: V=1.0100003, theta=27.779142 -> V=1.0, theta=0.0
% INFO    : Bus 61838	: V=1.0200003, theta=13.51558 -> V=1.0, theta=0.0
% INFO    : Bus 61839	: V=1.0100003, theta=12.936755 -> V=1.0, theta=0.0
% INFO    : Bus 61840	: V=1.0100003, theta=12.96372 -> V=1.0, theta=0.0
% INFO    : Bus 61841	: V=1.0100002, theta=31.774253 -> V=1.0, theta=0.0
% INFO    : Bus 61842	: V=1.0100003, theta=22.805651 -> V=1.0, theta=0.0
% INFO    : Bus 61843	: V=1.0100003, theta=26.815522 -> V=1.0, theta=0.0
% INFO    : Bus 61844	: V=1.0100003, theta=25.8702 -> V=1.0, theta=0.0
% INFO    : Bus 61845	: V=1.0100003, theta=23.126184 -> V=1.0, theta=0.0
% INFO    : Bus 61846	: V=1.0100003, theta=11.537862 -> V=1.0, theta=0.0
% INFO    : Bus 61847	: V=1.0100003, theta=22.068056 -> V=1.0, theta=0.0
% INFO    : Bus 61848	: V=1.0062946, theta=8.690081 -> V=1.0, theta=0.0
% INFO    : Bus 61849	: V=1.0100003, theta=14.127141 -> V=1.0, theta=0.0
% INFO    : Bus 61850	: V=1.0100003, theta=27.187267 -> V=1.0, theta=0.0
% INFO    : Bus 61851	: V=1.0000003, theta=41.659542 -> V=1.0, theta=0.0
% INFO    : Bus 61852	: V=1.0000003, theta=15.656427 -> V=1.0, theta=0.0
% INFO    : Bus 61853	: V=1.0100003, theta=13.892181 -> V=1.0, theta=0.0
% INFO    : Bus 61854	: V=1.0166283, theta=26.546837 -> V=1.0, theta=0.0
% INFO    : Bus 61855	: V=1.0100003, theta=13.956338 -> V=1.0, theta=0.0
% INFO    : Bus 61856	: V=1.0100003, theta=16.73758 -> V=1.0, theta=0.0
% INFO    : Bus 61857	: V=1.0000003, theta=12.926025 -> V=1.0, theta=0.0
% INFO    : Bus 61858	: V=1.0100003, theta=24.107642 -> V=1.0, theta=0.0
% INFO    : Bus 61859	: V=1.0007656, theta=11.802408 -> V=1.0, theta=0.0
% INFO    : Bus 61860	: V=0.9990387, theta=8.465307 -> V=1.0, theta=0.0
% INFO    : Bus 61861	: V=1.0060406, theta=8.696198 -> V=1.0, theta=0.0
% INFO    : Bus 61862	: V=1.0000004, theta=12.507038 -> V=1.0, theta=0.0
% INFO    : Bus 61863	: V=1.0100003, theta=25.205304 -> V=1.0, theta=0.0
% INFO    : Bus 61864	: V=0.9970361, theta=13.878015 -> V=1.0, theta=0.0
% INFO    : Bus 61865	: V=1.0065846, theta=13.624029 -> V=1.0, theta=0.0
% INFO    : Bus 61866	: V=1.0000003, theta=41.259804 -> V=1.0, theta=0.0
% INFO    : Bus 61867	: V=1.0094144, theta=26.292197 -> V=1.0, theta=0.0
% INFO    : Bus 61868	: V=1.0200003, theta=16.236268 -> V=1.0, theta=0.0
% INFO    : Bus 61869	: V=1.006725, theta=19.879711 -> V=1.0, theta=0.0
% INFO    : Bus 61870	: V=0.9873704, theta=21.58099 -> V=1.0, theta=0.0
% INFO    : Bus 61871	: V=1.0056091, theta=26.852461 -> V=1.0, theta=0.0
% INFO    : Bus 61872	: V=1.0000003, theta=17.247261 -> V=1.0, theta=0.0
% INFO    : Bus 61873	: V=0.9891459, theta=15.964731 -> V=1.0, theta=0.0
% INFO    : Bus 61874	: V=0.9795373, theta=23.701762 -> V=1.0, theta=0.0
% INFO    : Bus 61875	: V=1.0000003, theta=21.21735 -> V=1.0, theta=0.0
% INFO    : Bus 61876	: V=1.0200003, theta=28.327427 -> V=1.0, theta=0.0
% INFO    : Bus 61877	: V=1.0009002, theta=24.989076 -> V=1.0, theta=0.0
% INFO    : Bus 61878	: V=1.0100003, theta=40.443041 -> V=1.0, theta=0.0
% INFO    : Bus 61879	: V=0.9958448, theta=9.122876 -> V=1.0, theta=0.0
% INFO    : Bus 61880	: V=1.0200001, theta=47.62656 -> V=1.0, theta=0.0
% INFO    : Bus 61881	: V=1.0100001, theta=21.961086 -> V=1.0, theta=0.0
% INFO    : Bus 61882	: V=1.0100001, theta=10.525877 -> V=1.0, theta=0.0
% INFO    : Bus 61883	: V=1.0200001, theta=4.639662 -> V=1.0, theta=0.0
% INFO    : Bus 61884	: V=1.0300001, theta=48.324164 -> V=1.0, theta=0.0
% INFO    : Bus 61885	: V=1.0321207, theta=3.382171 -> V=1.0, theta=0.0
% INFO    : Bus 61886	: V=1.0200001, theta=10.236573 -> V=1.0, theta=0.0
% INFO    : Bus 61887	: V=1.0100001, theta=5.849678 -> V=1.0, theta=0.0
% INFO    : Bus 61888	: V=1.0060503, theta=5.227827 -> V=1.0, theta=0.0
% INFO    : Bus 61889	: V=1.0100001, theta=3.156605 -> V=1.0, theta=0.0
% INFO    : Bus 61890	: V=1.0100001, theta=-0.471372 -> V=1.0, theta=0.0
% INFO    : Bus 61891	: V=1.0100001, theta=11.073999 -> V=1.0, theta=0.0
% INFO    : Bus 61892	: V=1.0200001, theta=0.798941 -> V=1.0, theta=0.0
% INFO    : Bus 61893	: V=1.0100001, theta=12.962566 -> V=1.0, theta=0.0
% INFO    : Bus 61894	: V=1.0100001, theta=3.027048 -> V=1.0, theta=0.0
% INFO    : Bus 61895	: V=1.0100001, theta=8.721979 -> V=1.0, theta=0.0
% INFO    : Bus 61896	: V=1.0100001, theta=1.696118 -> V=1.0, theta=0.0
% INFO    : Bus 61897	: V=1.01, theta=12.855959 -> V=1.0, theta=0.0
% INFO    : Bus 61898	: V=1.0000001, theta=7.008174 -> V=1.0, theta=0.0
% INFO    : Bus 61899	: V=0.9872392, theta=3.559336 -> V=1.0, theta=0.0
% INFO    : Bus 61900	: V=0.9936864, theta=3.827908 -> V=1.0, theta=0.0
% INFO    : Bus 61901	: V=1.0100001, theta=42.094721 -> V=1.0, theta=0.0
% INFO    : Bus 61902	: V=1.0100001, theta=11.982956 -> V=1.0, theta=0.0
% INFO    : Bus 61903	: V=1.0100002, theta=41.819367 -> V=1.0, theta=0.0
% INFO    : Bus 61904	: V=0.9943737, theta=37.749945 -> V=1.0, theta=0.0
% INFO    : Bus 61905	: V=1.0000001, theta=7.211819 -> V=1.0, theta=0.0
% INFO    : Bus 61906	: V=1.0100001, theta=42.242221 -> V=1.0, theta=0.0
% INFO    : Bus 61907	: V=0.9812688, theta=3.16534 -> V=1.0, theta=0.0
% INFO    : Bus 61908	: V=1.0100001, theta=13.828933 -> V=1.0, theta=0.0
% INFO    : Bus 61909	: V=1.0300002, theta=-22.784707 -> V=1.0, theta=0.0
% INFO    : Bus 61910	: V=1.0138225, theta=-14.551773 -> V=1.0, theta=0.0
% INFO    : Bus 61911	: V=1.0200004, theta=-5.564581 -> V=1.0, theta=0.0
% INFO    : Bus 61912	: V=1.0100004, theta=-16.652703 -> V=1.0, theta=0.0
% INFO    : Bus 61913	: V=1.0300003, theta=-14.298598 -> V=1.0, theta=0.0
% INFO    : Bus 61914	: V=1.0200003, theta=-13.738563 -> V=1.0, theta=0.0
% INFO    : Bus 61915	: V=1.0200003, theta=-15.709025 -> V=1.0, theta=0.0
% INFO    : Bus 61916	: V=1.0300003, theta=-16.068371 -> V=1.0, theta=0.0
% INFO    : Bus 61917	: V=1.0200003, theta=-14.854936 -> V=1.0, theta=0.0
% INFO    : Bus 61918	: V=1.0200003, theta=-12.976105 -> V=1.0, theta=0.0
% INFO    : Bus 61919	: V=1.0131333, theta=-67.367768 -> V=1.0, theta=0.0
% INFO    : Bus 61920	: V=1.0100004, theta=-69.976529 -> V=1.0, theta=0.0
% INFO    : Bus 61921	: V=1.0300003, theta=-11.758496 -> V=1.0, theta=0.0
% INFO    : Bus 61922	: V=1.0200003, theta=-13.559977 -> V=1.0, theta=0.0
% INFO    : Bus 61923	: V=1.0228504, theta=-14.552236 -> V=1.0, theta=0.0
% INFO    : Bus 61924	: V=1.0100003, theta=-14.173612 -> V=1.0, theta=0.0
% INFO    : Bus 61925	: V=1.0185083, theta=-15.074623 -> V=1.0, theta=0.0
% INFO    : Bus 61926	: V=1.0230683, theta=-14.535128 -> V=1.0, theta=0.0
% INFO    : Bus 61927	: V=1.0298472, theta=-68.311204 -> V=1.0, theta=0.0
% INFO    : Bus 61928	: V=0.993581, theta=-42.027689 -> V=1.0, theta=0.0
% INFO    : Bus 61929	: V=1.0196548, theta=-14.927217 -> V=1.0, theta=0.0
% INFO    : Bus 61930	: V=0.9874769, theta=-54.619377 -> V=1.0, theta=0.0
% INFO    : Bus 61931	: V=1.0100003, theta=-15.065739 -> V=1.0, theta=0.0
% INFO    : Bus 61932	: V=0.9942774, theta=-57.84185 -> V=1.0, theta=0.0
% INFO    : Bus 61933	: V=1.0000004, theta=-75.79024 -> V=1.0, theta=0.0
% INFO    : Bus 61934	: V=1.0000004, theta=-75.728626 -> V=1.0, theta=0.0
% INFO    : Bus 61935	: V=1.0031507, theta=-58.162173 -> V=1.0, theta=0.0
% INFO    : Bus 61936	: V=0.9992266, theta=-58.439938 -> V=1.0, theta=0.0
% INFO    : Bus 61937	: V=1.0300004, theta=-68.306455 -> V=1.0, theta=0.0
% INFO    : Bus 61938	: V=1.0120868, theta=-55.556056 -> V=1.0, theta=0.0
% INFO    : Bus 61939	: V=1.0000004, theta=-28.739486 -> V=1.0, theta=0.0
% INFO    : Bus 61940	: V=1.0046558, theta=-14.475228 -> V=1.0, theta=0.0
% INFO    : Bus 61941	: V=1.0100003, theta=-14.132445 -> V=1.0, theta=0.0
% INFO    : Bus 61942	: V=0.9435186, theta=-30.133058 -> V=1.0, theta=0.0
% INFO    : Bus 61943	: V=1.0000004, theta=-76.075442 -> V=1.0, theta=0.0
% INFO    : Bus 61944	: V=1.0300003, theta=23.166023 -> V=1.0, theta=0.0
% INFO    : Bus 61945	: V=1.0300003, theta=38.386867 -> V=1.0, theta=0.0
% INFO    : Bus 61946	: V=1.0100003, theta=37.631649 -> V=1.0, theta=0.0
% INFO    : Bus 61947	: V=1.0200003, theta=36.426844 -> V=1.0, theta=0.0
% INFO    : Bus 61948	: V=1.0100003, theta=26.409686 -> V=1.0, theta=0.0
% INFO    : Bus 61949	: V=1.0200004, theta=17.469068 -> V=1.0, theta=0.0
% INFO    : Bus 61950	: V=1.0300003, theta=22.235511 -> V=1.0, theta=0.0
% INFO    : Bus 61951	: V=1.0100003, theta=27.22685 -> V=1.0, theta=0.0
% INFO    : Bus 61952	: V=1.0200004, theta=11.202983 -> V=1.0, theta=0.0
% INFO    : Bus 61953	: V=1.0100004, theta=27.000949 -> V=1.0, theta=0.0
% INFO    : Bus 61954	: V=1.0100004, theta=10.749951 -> V=1.0, theta=0.0
% INFO    : Bus 61955	: V=1.0196792, theta=11.426885 -> V=1.0, theta=0.0
% INFO    : Bus 61956	: V=0.9953646, theta=9.754708 -> V=1.0, theta=0.0
% INFO    : Bus 61957	: V=0.9859613, theta=3.742376 -> V=1.0, theta=0.0
% INFO    : Bus 61958	: V=1.0100004, theta=10.523942 -> V=1.0, theta=0.0
% INFO    : Bus 61959	: V=1.0200003, theta=24.691694 -> V=1.0, theta=0.0
% INFO    : Bus 61960	: V=0.9752296, theta=-1.195388 -> V=1.0, theta=0.0
% INFO    : Bus 61961	: V=1.0047107, theta=17.524988 -> V=1.0, theta=0.0
% INFO    : Bus 61962	: V=1.0065355, theta=9.298868 -> V=1.0, theta=0.0
% INFO    : Bus 61963	: V=1.0033092, theta=36.975641 -> V=1.0, theta=0.0
% INFO    : Bus 61964	: V=1.0025132, theta=36.27636 -> V=1.0, theta=0.0
% INFO    : Bus 61965	: V=0.9953485, theta=26.406197 -> V=1.0, theta=0.0
% INFO    : Bus 61966	: V=0.9993808, theta=31.895189 -> V=1.0, theta=0.0
% INFO    : Bus 61967	: V=0.9998257, theta=30.22615 -> V=1.0, theta=0.0
% INFO    : Bus 61968	: V=0.9974862, theta=29.760736 -> V=1.0, theta=0.0
% INFO    : Bus 61969	: V=1.0030068, theta=30.919389 -> V=1.0, theta=0.0
% INFO    : Bus 61970	: V=0.9882672, theta=23.112665 -> V=1.0, theta=0.0
% INFO    : Bus 61971	: V=1.0043092, theta=24.863464 -> V=1.0, theta=0.0
% INFO    : Bus 61972	: V=0.9882007, theta=23.20562 -> V=1.0, theta=0.0
% INFO    : Bus 61973	: V=1.0041328, theta=22.435508 -> V=1.0, theta=0.0
% INFO    : Bus 61974	: V=1.0102421, theta=26.272206 -> V=1.0, theta=0.0
% INFO    : Bus 61975	: V=1.0191448, theta=29.057356 -> V=1.0, theta=0.0
% INFO    : Bus 61976	: V=1.030705, theta=31.102672 -> V=1.0, theta=0.0
% INFO    : Bus 61977	: V=1.02, theta=29.899072 -> V=1.0, theta=0.0
% INFO    : Bus 61978	: V=1.0029141, theta=20.777579 -> V=1.0, theta=0.0
% INFO    : Bus 61979	: V=1.0018576, theta=7.316854 -> V=1.0, theta=0.0
% INFO    : Bus 61980	: V=0.9867508, theta=2.986001 -> V=1.0, theta=0.0
% INFO    : Bus 61981	: V=0.9980423, theta=3.281638 -> V=1.0, theta=0.0
% INFO    : Bus 61982	: V=1.0103936, theta=4.616882 -> V=1.0, theta=0.0
% INFO    : Bus 61983	: V=0.9942708, theta=-1.922719 -> V=1.0, theta=0.0
% INFO    : Bus 61984	: V=0.9938086, theta=-1.426046 -> V=1.0, theta=0.0
% INFO    : Bus 61985	: V=0.9928035, theta=-3.975138 -> V=1.0, theta=0.0
% INFO    : Bus 61986	: V=0.9940567, theta=-0.135422 -> V=1.0, theta=0.0
% INFO    : Bus 61987	: V=0.9714903, theta=-2.799159 -> V=1.0, theta=0.0
% INFO    : Bus 61988	: V=0.9672539, theta=-4.735201 -> V=1.0, theta=0.0
% INFO    : Bus 61989	: V=0.9662984, theta=-5.15325 -> V=1.0, theta=0.0
% INFO    : Bus 61990	: V=0.9675859, theta=-5.22539 -> V=1.0, theta=0.0
% INFO    : Bus 61991	: V=0.9729759, theta=-5.142853 -> V=1.0, theta=0.0
% INFO    : Bus 61992	: V=0.9748752, theta=-5.065709 -> V=1.0, theta=0.0
% INFO    : Bus 61993	: V=0.9822604, theta=-2.596097 -> V=1.0, theta=0.0
% INFO    : Bus 61994	: V=0.9812572, theta=-1.539444 -> V=1.0, theta=0.0
% INFO    : Bus 61995	: V=0.9743892, theta=-4.06721 -> V=1.0, theta=0.0
% INFO    : Bus 61996	: V=0.9843526, theta=-3.777892 -> V=1.0, theta=0.0
% INFO    : Bus 61997	: V=0.9760286, theta=-4.196671 -> V=1.0, theta=0.0
% INFO    : Bus 61998	: V=0.959638, theta=-5.697012 -> V=1.0, theta=0.0
% INFO    : Bus 61999	: V=0.9643988, theta=-5.441627 -> V=1.0, theta=0.0
% INFO    : Bus 62000	: V=0.9726678, theta=-4.332142 -> V=1.0, theta=0.0
% INFO    : Bus 62001	: V=0.971708, theta=-4.364491 -> V=1.0, theta=0.0
% INFO    : Bus 62002	: V=0.9709074, theta=-4.426302 -> V=1.0, theta=0.0
% INFO    : Bus 62003	: V=0.965884, theta=-5.130788 -> V=1.0, theta=0.0
% INFO    : Bus 62004	: V=0.9731984, theta=-4.061549 -> V=1.0, theta=0.0
% INFO    : Bus 62005	: V=0.967048, theta=-4.97172 -> V=1.0, theta=0.0
% INFO    : Bus 62006	: V=0.9696314, theta=-4.508476 -> V=1.0, theta=0.0
% INFO    : Bus 62007	: V=0.9578531, theta=-5.989543 -> V=1.0, theta=0.0
% INFO    : Bus 62008	: V=0.9553592, theta=-6.087593 -> V=1.0, theta=0.0
% INFO    : Bus 62009	: V=0.969045, theta=-4.581735 -> V=1.0, theta=0.0
% INFO    : Bus 62010	: V=0.9503854, theta=-6.313494 -> V=1.0, theta=0.0
% INFO    : Bus 62011	: V=0.9766832, theta=2.727486 -> V=1.0, theta=0.0
% INFO    : Bus 62012	: V=0.9766081, theta=2.923692 -> V=1.0, theta=0.0
% INFO    : Bus 62013	: V=0.9807068, theta=2.172602 -> V=1.0, theta=0.0
% INFO    : Bus 62014	: V=0.9801307, theta=2.074712 -> V=1.0, theta=0.0
% INFO    : Bus 62015	: V=0.9733933, theta=4.308927 -> V=1.0, theta=0.0
% INFO    : Bus 62016	: V=0.9810942, theta=2.683883 -> V=1.0, theta=0.0
% INFO    : Bus 62017	: V=0.9805298, theta=2.345131 -> V=1.0, theta=0.0
% INFO    : Bus 62018	: V=0.9763933, theta=3.227029 -> V=1.0, theta=0.0
% INFO    : Bus 62019	: V=0.9760144, theta=2.598233 -> V=1.0, theta=0.0
% INFO    : Bus 62020	: V=0.9763996, theta=2.78779 -> V=1.0, theta=0.0
% INFO    : Bus 62021	: V=0.9809409, theta=1.472309 -> V=1.0, theta=0.0
% INFO    : Bus 62022	: V=0.9764801, theta=2.659027 -> V=1.0, theta=0.0
% INFO    : Bus 62023	: V=0.9803984, theta=1.868213 -> V=1.0, theta=0.0
% INFO    : Bus 62024	: V=0.9776174, theta=2.62346 -> V=1.0, theta=0.0
% INFO    : Bus 62025	: V=0.961553, theta=8.850455 -> V=1.0, theta=0.0
% INFO    : Bus 62026	: V=0.9892133, theta=18.076564 -> V=1.0, theta=0.0
% INFO    : Bus 62027	: V=0.981035, theta=-1.184466 -> V=1.0, theta=0.0
% INFO    : Bus 62028	: V=0.9790088, theta=-1.934988 -> V=1.0, theta=0.0
% INFO    : Bus 62029	: V=0.9638908, theta=34.109263 -> V=1.0, theta=0.0
% INFO    : Bus 62030	: V=1.0200002, theta=49.103556 -> V=1.0, theta=0.0
% INFO    : Bus 62031	: V=0.9750849, theta=1.883947 -> V=1.0, theta=0.0
% INFO    : Bus 62032	: V=0.9977933, theta=-4.648047 -> V=1.0, theta=0.0
% INFO    : Bus 62033	: V=1.0200002, theta=48.54138 -> V=1.0, theta=0.0
% INFO    : Bus 62034	: V=1.0100002, theta=48.01076 -> V=1.0, theta=0.0
% INFO    : Bus 62035	: V=0.9599894, theta=32.210637 -> V=1.0, theta=0.0
% INFO    : Bus 62036	: V=0.944147, theta=30.154887 -> V=1.0, theta=0.0
% INFO    : Bus 62037	: V=0.9549391, theta=21.801465 -> V=1.0, theta=0.0
% INFO    : Bus 62038	: V=0.9641967, theta=34.603028 -> V=1.0, theta=0.0
% INFO    : Bus 62039	: V=0.9618316, theta=5.713746 -> V=1.0, theta=0.0
% INFO    : Bus 62040	: V=0.9731695, theta=10.052257 -> V=1.0, theta=0.0
% INFO    : Bus 62041	: V=0.9713596, theta=6.92738 -> V=1.0, theta=0.0
% INFO    : Bus 62042	: V=0.9709017, theta=4.284923 -> V=1.0, theta=0.0
% INFO    : Bus 62043	: V=0.971586, theta=8.526598 -> V=1.0, theta=0.0
% INFO    : Bus 62044	: V=0.9770657, theta=6.653524 -> V=1.0, theta=0.0
% INFO    : Bus 62045	: V=0.9923765, theta=9.378403 -> V=1.0, theta=0.0
% INFO    : Bus 62046	: V=0.9998499, theta=5.029947 -> V=1.0, theta=0.0
% INFO    : Bus 62047	: V=0.996118, theta=2.889116 -> V=1.0, theta=0.0
% INFO    : Bus 62048	: V=0.9900222, theta=2.610791 -> V=1.0, theta=0.0
% INFO    : Bus 62049	: V=0.9930568, theta=6.118074 -> V=1.0, theta=0.0
% INFO    : Bus 62050	: V=0.9944309, theta=3.62907 -> V=1.0, theta=0.0
% INFO    : Bus 62051	: V=0.9924106, theta=2.391751 -> V=1.0, theta=0.0
% INFO    : Bus 62052	: V=0.9933417, theta=2.309652 -> V=1.0, theta=0.0
% INFO    : Bus 62053	: V=0.9842282, theta=13.422914 -> V=1.0, theta=0.0
% INFO    : Bus 62054	: V=0.9847076, theta=7.085088 -> V=1.0, theta=0.0
% INFO    : Bus 62055	: V=0.9701014, theta=4.251467 -> V=1.0, theta=0.0
% INFO    : Bus 62056	: V=0.9676933, theta=2.922773 -> V=1.0, theta=0.0
% INFO    : Bus 62057	: V=0.9761434, theta=4.524874 -> V=1.0, theta=0.0
% INFO    : Bus 62058	: V=0.9729006, theta=4.413526 -> V=1.0, theta=0.0
% INFO    : Bus 62059	: V=0.9822685, theta=5.667781 -> V=1.0, theta=0.0
% INFO    : Bus 62060	: V=0.9782872, theta=4.553407 -> V=1.0, theta=0.0
% INFO    : Bus 62061	: V=0.9838498, theta=4.40493 -> V=1.0, theta=0.0
% INFO    : Bus 62062	: V=0.9657003, theta=0.359101 -> V=1.0, theta=0.0
% INFO    : Bus 62063	: V=0.9811562, theta=6.790772 -> V=1.0, theta=0.0
% INFO    : Bus 62064	: V=0.9867446, theta=13.509145 -> V=1.0, theta=0.0
% INFO    : Bus 62065	: V=0.9827659, theta=8.446446 -> V=1.0, theta=0.0
% INFO    : Bus 62066	: V=0.9842634, theta=5.835833 -> V=1.0, theta=0.0
% INFO    : Bus 62067	: V=0.983223, theta=-10.683631 -> V=1.0, theta=0.0
% INFO    : Bus 62068	: V=0.9913242, theta=-17.732121 -> V=1.0, theta=0.0
% INFO    : Bus 62069	: V=0.9911522, theta=-15.808226 -> V=1.0, theta=0.0
% INFO    : Bus 62070	: V=0.9809283, theta=-15.952319 -> V=1.0, theta=0.0
% INFO    : Bus 62071	: V=0.9847266, theta=-18.571444 -> V=1.0, theta=0.0
% INFO    : Bus 62072	: V=0.9899128, theta=-19.875738 -> V=1.0, theta=0.0
% INFO    : Bus 62073	: V=0.9913089, theta=-18.553021 -> V=1.0, theta=0.0
% INFO    : Bus 62074	: V=0.9777648, theta=-19.464786 -> V=1.0, theta=0.0
% INFO    : Bus 62075	: V=0.9715366, theta=-1.61653 -> V=1.0, theta=0.0
% INFO    : Bus 62076	: V=0.9723806, theta=0.000632 -> V=1.0, theta=0.0
% INFO    : Bus 62077	: V=0.9582329, theta=-5.516339 -> V=1.0, theta=0.0
% INFO    : Bus 62078	: V=0.9568465, theta=-5.59311 -> V=1.0, theta=0.0
% INFO    : Bus 62079	: V=1.01, theta=0.981109 -> V=1.0, theta=0.0
% INFO    : Bus 62080	: V=0.9945305, theta=0.232171 -> V=1.0, theta=0.0
% INFO    : Bus 62081	: V=0.9992942, theta=0.413398 -> V=1.0, theta=0.0
% INFO    : Bus 62082	: V=0.9961736, theta=0.099761 -> V=1.0, theta=0.0
% INFO    : Bus 62083	: V=0.9938907, theta=0.282551 -> V=1.0, theta=0.0
% INFO    : Bus 62084	: V=0.9932341, theta=0.149693 -> V=1.0, theta=0.0
% INFO    : Bus 62085	: V=1.01, theta=3.972713 -> V=1.0, theta=0.0
% INFO    : Bus 62086	: V=1.0045002, theta=4.587322 -> V=1.0, theta=0.0
% INFO    : Bus 62087	: V=0.9892722, theta=0.985982 -> V=1.0, theta=0.0
% INFO    : Bus 62088	: V=0.9971006, theta=-1.213914 -> V=1.0, theta=0.0
% INFO    : Bus 62089	: V=0.99221, theta=-1.489416 -> V=1.0, theta=0.0
% INFO    : Bus 62090	: V=0.989758, theta=-1.05345 -> V=1.0, theta=0.0
% INFO    : Bus 62091	: V=0.9919047, theta=-0.681033 -> V=1.0, theta=0.0
% INFO    : Bus 62092	: V=0.9956038, theta=-0.013056 -> V=1.0, theta=0.0
% INFO    : Bus 62093	: V=0.994657, theta=-0.208496 -> V=1.0, theta=0.0
% INFO    : Bus 62094	: V=0.9973275, theta=0.24259 -> V=1.0, theta=0.0
% INFO    : Bus 62095	: V=0.9984104, theta=0.35799 -> V=1.0, theta=0.0
% INFO    : Bus 62096	: V=0.9969704, theta=0.411442 -> V=1.0, theta=0.0
% INFO    : Bus 62097	: V=0.9993435, theta=0.451901 -> V=1.0, theta=0.0
% INFO    : Bus 62098	: V=0.9997094, theta=0.488499 -> V=1.0, theta=0.0
% INFO    : Bus 62099	: V=0.9946308, theta=0.284126 -> V=1.0, theta=0.0
% INFO    : Bus 62100	: V=0.9950891, theta=0.012035 -> V=1.0, theta=0.0
% INFO    : Bus 62101	: V=0.9995735, theta=0.417703 -> V=1.0, theta=0.0
% INFO    : Bus 62102	: V=1.01, theta=9.285248 -> V=1.0, theta=0.0
% INFO    : Bus 62103	: V=1.02, theta=10.124778 -> V=1.0, theta=0.0
% INFO    : Bus 62104	: V=0.9979921, theta=2.39784 -> V=1.0, theta=0.0
% INFO    : Bus 62105	: V=1.0167987, theta=3.688716 -> V=1.0, theta=0.0
% INFO    : Bus 62106	: V=1.02, theta=8.449183 -> V=1.0, theta=0.0
% INFO    : Bus 62107	: V=1.03, theta=6.756214 -> V=1.0, theta=0.0
% INFO    : Bus 62108	: V=1.03, theta=6.622059 -> V=1.0, theta=0.0
% INFO    : Bus 62109	: V=1.0198229, theta=6.904545 -> V=1.0, theta=0.0
% INFO    : Bus 62110	: V=1.0217135, theta=5.701371 -> V=1.0, theta=0.0
% INFO    : Bus 62111	: V=1.0202544, theta=5.33611 -> V=1.0, theta=0.0
% INFO    : Bus 62112	: V=1.0215151, theta=6.34415 -> V=1.0, theta=0.0
% INFO    : Bus 62113	: V=0.9948539, theta=-0.026771 -> V=1.0, theta=0.0
% INFO    : Bus 62114	: V=0.9993883, theta=-0.151706 -> V=1.0, theta=0.0
% INFO    : Bus 62115	: V=1.0001445, theta=0.080559 -> V=1.0, theta=0.0
% INFO    : Bus 62116	: V=1.0002964, theta=-0.019735 -> V=1.0, theta=0.0
% INFO    : Bus 62117	: V=1.0011137, theta=0.08373 -> V=1.0, theta=0.0
% INFO    : Bus 62118	: V=0.997042, theta=-0.229241 -> V=1.0, theta=0.0
% INFO    : Bus 62119	: V=1.0113285, theta=3.073562 -> V=1.0, theta=0.0
% INFO    : Bus 62120	: V=1.009164, theta=1.992312 -> V=1.0, theta=0.0
% INFO    : Bus 62121	: V=1.005245, theta=1.158935 -> V=1.0, theta=0.0
% INFO    : Bus 62122	: V=1.0122196, theta=2.79076 -> V=1.0, theta=0.0
% INFO    : Bus 62123	: V=1.008803, theta=1.612868 -> V=1.0, theta=0.0
% INFO    : Bus 62124	: V=1.0093056, theta=1.868104 -> V=1.0, theta=0.0
% INFO    : Bus 62125	: V=1.0108145, theta=2.327935 -> V=1.0, theta=0.0
% INFO    : Bus 62126	: V=1.0199516, theta=4.393882 -> V=1.0, theta=0.0
% INFO    : Bus 62127	: V=1.02, theta=4.627469 -> V=1.0, theta=0.0
% INFO    : Bus 62128	: V=1.01, theta=2.95962 -> V=1.0, theta=0.0
% INFO    : Bus 62129	: V=1.0139702, theta=2.945336 -> V=1.0, theta=0.0
% INFO    : Bus 62130	: V=1.0104236, theta=2.252881 -> V=1.0, theta=0.0
% INFO    : Bus 62131	: V=1.0100871, theta=2.127861 -> V=1.0, theta=0.0
% INFO    : Bus 62132	: V=1.0126572, theta=3.131155 -> V=1.0, theta=0.0
% INFO    : Bus 62133	: V=1.02, theta=6.043274 -> V=1.0, theta=0.0
% INFO    : Bus 62134	: V=1.02, theta=5.809917 -> V=1.0, theta=0.0
% INFO    : Bus 62135	: V=0.9972699, theta=0.524737 -> V=1.0, theta=0.0
% INFO    : Bus 62136	: V=1.0004819, theta=0.578301 -> V=1.0, theta=0.0
% INFO    : Bus 62137	: V=0.9937637, theta=-0.063282 -> V=1.0, theta=0.0
% INFO    : Bus 62138	: V=1.0000636, theta=0.399715 -> V=1.0, theta=0.0
% INFO    : Bus 62139	: V=0.9946993, theta=-0.206941 -> V=1.0, theta=0.0
% INFO    : Bus 62140	: V=1.0027156, theta=0.871944 -> V=1.0, theta=0.0
% INFO    : Bus 62141	: V=1.005229, theta=1.14405 -> V=1.0, theta=0.0
% INFO    : Bus 62142	: V=0.9933224, theta=-0.145315 -> V=1.0, theta=0.0
% INFO    : Bus 62143	: V=1.0017599, theta=0.544976 -> V=1.0, theta=0.0
% INFO    : Bus 62144	: V=1.0008717, theta=0.396215 -> V=1.0, theta=0.0
% INFO    : Bus 62145	: V=1.0006913, theta=0.281388 -> V=1.0, theta=0.0
% INFO    : Bus 62146	: V=1.0053411, theta=1.48401 -> V=1.0, theta=0.0
% INFO    : Bus 62147	: V=1.0029026, theta=0.711408 -> V=1.0, theta=0.0
% INFO    : Bus 62148	: V=1.0099695, theta=2.282904 -> V=1.0, theta=0.0
% INFO    : Bus 62149	: V=1.0024448, theta=0.454479 -> V=1.0, theta=0.0
% INFO    : Bus 62150	: V=1.0014593, theta=0.201154 -> V=1.0, theta=0.0
% INFO    : Bus 62151	: V=1.0011085, theta=0.101981 -> V=1.0, theta=0.0
% INFO    : Bus 62152	: V=0.999505, theta=-0.331871 -> V=1.0, theta=0.0
% INFO    : Bus 62153	: V=1.0027021, theta=0.499666 -> V=1.0, theta=0.0
% INFO    : Bus 62154	: V=1.02, theta=3.770735 -> V=1.0, theta=0.0
% INFO    : Bus 62155	: V=1.02, theta=4.104295 -> V=1.0, theta=0.0
% INFO    : Bus 62156	: V=1.0069633, theta=1.506223 -> V=1.0, theta=0.0
% INFO    : Bus 62157	: V=1.0079201, theta=1.723249 -> V=1.0, theta=0.0
% INFO    : Bus 62158	: V=1.0095109, theta=1.918886 -> V=1.0, theta=0.0
% INFO    : Bus 62159	: V=1.019353, theta=5.077739 -> V=1.0, theta=0.0
% INFO    : Bus 62160	: V=1.009119, theta=2.057129 -> V=1.0, theta=0.0
% INFO    : Bus 62161	: V=1.0094349, theta=2.057584 -> V=1.0, theta=0.0
% INFO    : Bus 62162	: V=1.0130338, theta=2.723081 -> V=1.0, theta=0.0
% INFO    : Bus 62163	: V=0.9988517, theta=-0.433887 -> V=1.0, theta=0.0
% INFO    : Bus 62164	: V=0.9939512, theta=-1.286953 -> V=1.0, theta=0.0
% INFO    : Bus 62165	: V=0.9986714, theta=-0.347299 -> V=1.0, theta=0.0
% INFO    : Bus 62166	: V=0.9927189, theta=-1.580713 -> V=1.0, theta=0.0
% INFO    : Bus 62167	: V=0.993405, theta=-1.291694 -> V=1.0, theta=0.0
% INFO    : Bus 62168	: V=0.9949907, theta=-1.404677 -> V=1.0, theta=0.0
% INFO    : Bus 62169	: V=0.9858104, theta=-2.532272 -> V=1.0, theta=0.0
% INFO    : Bus 62170	: V=0.9956176, theta=-1.306173 -> V=1.0, theta=0.0
% INFO    : Bus 62171	: V=0.9942826, theta=-1.421946 -> V=1.0, theta=0.0
% INFO    : Bus 62172	: V=0.9947895, theta=-1.130186 -> V=1.0, theta=0.0
% INFO    : Bus 62173	: V=0.9961138, theta=-0.972408 -> V=1.0, theta=0.0
% INFO    : Bus 62174	: V=0.9953656, theta=-1.298227 -> V=1.0, theta=0.0
% INFO    : Bus 62175	: V=0.9964268, theta=-1.230272 -> V=1.0, theta=0.0
% INFO    : Bus 62176	: V=1.0013089, theta=0.052349 -> V=1.0, theta=0.0
% INFO    : Bus 62177	: V=1.0020276, theta=0.224112 -> V=1.0, theta=0.0
% INFO    : Bus 62178	: V=1.0015788, theta=0.050766 -> V=1.0, theta=0.0
% INFO    : Bus 62179	: V=0.9996072, theta=-0.401068 -> V=1.0, theta=0.0
% INFO    : Bus 62180	: V=1.0017713, theta=-0.106908 -> V=1.0, theta=0.0
% INFO    : Bus 62181	: V=1.0022899, theta=-0.563263 -> V=1.0, theta=0.0
% INFO    : Bus 62182	: V=1.0009374, theta=-0.652823 -> V=1.0, theta=0.0
% INFO    : Bus 62183	: V=1.0021004, theta=-0.24121 -> V=1.0, theta=0.0
% INFO    : Bus 62184	: V=0.9990743, theta=-0.935519 -> V=1.0, theta=0.0
% INFO    : Bus 62185	: V=1.0008856, theta=-0.743386 -> V=1.0, theta=0.0
% INFO    : Bus 62186	: V=1.0004005, theta=-0.443692 -> V=1.0, theta=0.0
% INFO    : Bus 62187	: V=0.9990984, theta=-0.602175 -> V=1.0, theta=0.0
% INFO    : Bus 62188	: V=1.0015409, theta=-0.745105 -> V=1.0, theta=0.0
% INFO    : Bus 62189	: V=1.0061756, theta=-0.304585 -> V=1.0, theta=0.0
% INFO    : Bus 62190	: V=1.0078159, theta=1.004251 -> V=1.0, theta=0.0
% INFO    : Bus 62191	: V=1.0074975, theta=0.783965 -> V=1.0, theta=0.0
% INFO    : Bus 62192	: V=1.0073826, theta=0.716751 -> V=1.0, theta=0.0
% INFO    : Bus 62193	: V=1.0078072, theta=0.93857 -> V=1.0, theta=0.0
% INFO    : Bus 62194	: V=1.0060096, theta=0.169972 -> V=1.0, theta=0.0
% INFO    : Bus 62195	: V=1.0081332, theta=1.270114 -> V=1.0, theta=0.0
% INFO    : Bus 62196	: V=1.0077943, theta=0.965386 -> V=1.0, theta=0.0
% INFO    : Bus 62197	: V=1.0085869, theta=1.14899 -> V=1.0, theta=0.0
% INFO    : Bus 62198	: V=1.008012, theta=0.903807 -> V=1.0, theta=0.0
% INFO    : Bus 62199	: V=1.0077438, theta=1.528747 -> V=1.0, theta=0.0
% INFO    : Bus 62200	: V=1.0079901, theta=1.540679 -> V=1.0, theta=0.0
% INFO    : Bus 62201	: V=1.0050172, theta=1.110376 -> V=1.0, theta=0.0
% INFO    : Bus 62202	: V=1.0105729, theta=2.232919 -> V=1.0, theta=0.0
% INFO    : Bus 62203	: V=1.0097964, theta=1.835068 -> V=1.0, theta=0.0
% INFO    : Bus 62204	: V=1.0090135, theta=1.47371 -> V=1.0, theta=0.0
% INFO    : Bus 62205	: V=1.0117306, theta=2.424741 -> V=1.0, theta=0.0
% INFO    : Bus 62206	: V=1.01, theta=2.707378 -> V=1.0, theta=0.0
% INFO    : Bus 62207	: V=1.01, theta=2.646798 -> V=1.0, theta=0.0
% INFO    : Bus 62208	: V=1.0082269, theta=0.972659 -> V=1.0, theta=0.0
% INFO    : Bus 62209	: V=1.0106073, theta=2.039502 -> V=1.0, theta=0.0
% INFO    : Bus 62210	: V=1.0100804, theta=1.963978 -> V=1.0, theta=0.0
% INFO    : Bus 62211	: V=1.0099747, theta=1.757064 -> V=1.0, theta=0.0
% INFO    : Bus 62212	: V=1.0093443, theta=1.759775 -> V=1.0, theta=0.0
% INFO    : Bus 62213	: V=1.0111175, theta=2.231984 -> V=1.0, theta=0.0
% INFO    : Bus 62214	: V=1.0125595, theta=2.59464 -> V=1.0, theta=0.0
% INFO    : Bus 62215	: V=1.0095416, theta=1.706636 -> V=1.0, theta=0.0
% INFO    : Bus 62216	: V=1.011156, theta=2.266262 -> V=1.0, theta=0.0
% INFO    : Bus 62217	: V=1.0118791, theta=2.466194 -> V=1.0, theta=0.0
% INFO    : Bus 62218	: V=1.01, theta=2.570761 -> V=1.0, theta=0.0
% INFO    : Bus 62219	: V=1.004104, theta=-0.510917 -> V=1.0, theta=0.0
% INFO    : Bus 62220	: V=1.0012476, theta=-0.803079 -> V=1.0, theta=0.0
% INFO    : Bus 62221	: V=1.0045037, theta=-0.518387 -> V=1.0, theta=0.0
% INFO    : Bus 62222	: V=0.999159, theta=-1.001215 -> V=1.0, theta=0.0
% INFO    : Bus 62223	: V=1.0026085, theta=-0.693198 -> V=1.0, theta=0.0
% INFO    : Bus 62224	: V=1.0056804, theta=-0.394172 -> V=1.0, theta=0.0
% INFO    : Bus 62225	: V=1.0067368, theta=-0.291595 -> V=1.0, theta=0.0
% INFO    : Bus 62226	: V=0.9977237, theta=-1.194853 -> V=1.0, theta=0.0
% INFO    : Bus 62227	: V=0.9975688, theta=-1.184206 -> V=1.0, theta=0.0
% INFO    : Bus 62228	: V=0.9983626, theta=-1.168066 -> V=1.0, theta=0.0
% INFO    : Bus 62229	: V=1.0010768, theta=-0.810561 -> V=1.0, theta=0.0
% INFO    : Bus 62230	: V=1.0042307, theta=-0.597628 -> V=1.0, theta=0.0
% INFO    : Bus 62231	: V=1.0069704, theta=0.320007 -> V=1.0, theta=0.0
% INFO    : Bus 62232	: V=1.0012415, theta=-0.52707 -> V=1.0, theta=0.0
% INFO    : Bus 62233	: V=1.0024889, theta=-0.455115 -> V=1.0, theta=0.0
% INFO    : Bus 62234	: V=1.0040319, theta=-0.449913 -> V=1.0, theta=0.0
% INFO    : Bus 62235	: V=1.0035991, theta=-0.357596 -> V=1.0, theta=0.0
% INFO    : Bus 62236	: V=1.0031425, theta=-0.089649 -> V=1.0, theta=0.0
% INFO    : Bus 62237	: V=1.0073807, theta=0.47548 -> V=1.0, theta=0.0
% INFO    : Bus 62238	: V=1.0073317, theta=0.528921 -> V=1.0, theta=0.0
% INFO    : Bus 62239	: V=1.0025948, theta=-0.619696 -> V=1.0, theta=0.0
% INFO    : Bus 62240	: V=1.0028678, theta=-0.574386 -> V=1.0, theta=0.0
% INFO    : Bus 62241	: V=1.0074254, theta=0.805044 -> V=1.0, theta=0.0
% INFO    : Bus 62242	: V=1.0070833, theta=0.637897 -> V=1.0, theta=0.0
% INFO    : Bus 62243	: V=1.0016229, theta=-0.499041 -> V=1.0, theta=0.0
% INFO    : Bus 62244	: V=1.0023227, theta=-0.178148 -> V=1.0, theta=0.0
% INFO    : Bus 62245	: V=1.0020628, theta=-0.300163 -> V=1.0, theta=0.0
% INFO    : Bus 62246	: V=1.0014452, theta=-0.719878 -> V=1.0, theta=0.0
% INFO    : Bus 62247	: V=1.0015267, theta=-0.674036 -> V=1.0, theta=0.0
% INFO    : Bus 62248	: V=0.9991219, theta=-1.015892 -> V=1.0, theta=0.0
% INFO    : Bus 62249	: V=0.9976791, theta=-1.132509 -> V=1.0, theta=0.0
% INFO    : Bus 62250	: V=0.9979643, theta=-1.115307 -> V=1.0, theta=0.0
% INFO    : Bus 62251	: V=0.9986251, theta=-1.057307 -> V=1.0, theta=0.0
% INFO    : Bus 62252	: V=1.0010118, theta=-0.453443 -> V=1.0, theta=0.0
% INFO    : Bus 62253	: V=1.0021981, theta=-0.546994 -> V=1.0, theta=0.0
% INFO    : Bus 62254	: V=1.0019751, theta=-0.541188 -> V=1.0, theta=0.0
% INFO    : Bus 62255	: V=1.0081471, theta=0.013921 -> V=1.0, theta=0.0
% INFO    : Bus 62256	: V=0.9736141, theta=-4.329245 -> V=1.0, theta=0.0
% INFO    : Bus 62257	: V=0.9725652, theta=-4.403394 -> V=1.0, theta=0.0
% INFO    : Bus 62258	: V=0.9719176, theta=-4.456286 -> V=1.0, theta=0.0
% INFO    : Bus 62259	: V=0.9820749, theta=-2.851788 -> V=1.0, theta=0.0
% INFO    : Bus 62260	: V=0.9781518, theta=-3.829475 -> V=1.0, theta=0.0
% INFO    : Bus 62261	: V=0.9807874, theta=-2.970228 -> V=1.0, theta=0.0
% INFO    : Bus 62262	: V=0.9748156, theta=-4.203663 -> V=1.0, theta=0.0
% INFO    : Bus 62263	: V=0.97254, theta=-4.425768 -> V=1.0, theta=0.0
% INFO    : Bus 62264	: V=0.9698894, theta=-4.610774 -> V=1.0, theta=0.0
% INFO    : Bus 62265	: V=0.9718222, theta=-4.482967 -> V=1.0, theta=0.0
% INFO    : Bus 62266	: V=0.9709641, theta=-4.537491 -> V=1.0, theta=0.0
% INFO    : Bus 62267	: V=0.9696295, theta=-4.600624 -> V=1.0, theta=0.0
% INFO    : Bus 62268	: V=0.969836, theta=-4.59018 -> V=1.0, theta=0.0
% INFO    : Bus 62269	: V=0.9707058, theta=-4.561226 -> V=1.0, theta=0.0
% INFO    : Bus 62270	: V=0.9762017, theta=-4.15222 -> V=1.0, theta=0.0
% INFO    : Bus 62271	: V=0.9749356, theta=-4.262114 -> V=1.0, theta=0.0
% INFO    : Bus 62272	: V=0.975656, theta=-4.160761 -> V=1.0, theta=0.0
% INFO    : Bus 62273	: V=0.9762491, theta=-4.015548 -> V=1.0, theta=0.0
% INFO    : Bus 62274	: V=0.9764421, theta=-4.024617 -> V=1.0, theta=0.0
% INFO    : Bus 62275	: V=0.9750379, theta=-4.213167 -> V=1.0, theta=0.0
% INFO    : Bus 62276	: V=0.9848537, theta=-2.571001 -> V=1.0, theta=0.0
% INFO    : Bus 62277	: V=0.9857367, theta=-2.482393 -> V=1.0, theta=0.0
% INFO    : Bus 62278	: V=0.9868632, theta=-2.130522 -> V=1.0, theta=0.0
% INFO    : Bus 62279	: V=0.9833093, theta=-3.208148 -> V=1.0, theta=0.0
% INFO    : Bus 62280	: V=0.9780475, theta=-3.88216 -> V=1.0, theta=0.0
% INFO    : Bus 62281	: V=0.9818333, theta=-3.306452 -> V=1.0, theta=0.0
% INFO    : Bus 62282	: V=0.9871692, theta=-2.133042 -> V=1.0, theta=0.0
% INFO    : Bus 62283	: V=0.9854781, theta=-2.65664 -> V=1.0, theta=0.0
% INFO    : Bus 62284	: V=0.9801899, theta=-3.531648 -> V=1.0, theta=0.0
% INFO    : Bus 62285	: V=0.9818765, theta=-3.345683 -> V=1.0, theta=0.0
% INFO    : Bus 62286	: V=0.9850336, theta=-3.021031 -> V=1.0, theta=0.0
% INFO    : Bus 62287	: V=0.9872426, theta=-2.78374 -> V=1.0, theta=0.0
% INFO    : Bus 62288	: V=0.9870514, theta=-2.340692 -> V=1.0, theta=0.0
% INFO    : Bus 62289	: V=0.9885711, theta=-2.167807 -> V=1.0, theta=0.0
% INFO    : Bus 62290	: V=0.9860691, theta=-2.652635 -> V=1.0, theta=0.0
% INFO    : Bus 62291	: V=0.9904621, theta=-1.830536 -> V=1.0, theta=0.0
% INFO    : Bus 62292	: V=0.9863844, theta=-2.601589 -> V=1.0, theta=0.0
% INFO    : Bus 62293	: V=0.9899544, theta=-2.260098 -> V=1.0, theta=0.0
% INFO    : Bus 62294	: V=0.9956022, theta=-1.337195 -> V=1.0, theta=0.0
% INFO    : Bus 62295	: V=0.9969423, theta=-1.217625 -> V=1.0, theta=0.0
% INFO    : Bus 62296	: V=0.9938301, theta=-1.473101 -> V=1.0, theta=0.0
% INFO    : Bus 62297	: V=0.9970811, theta=-1.367052 -> V=1.0, theta=0.0
% INFO    : Bus 62298	: V=0.9810381, theta=-3.449035 -> V=1.0, theta=0.0
% INFO    : Bus 62299	: V=0.9910387, theta=-2.187027 -> V=1.0, theta=0.0
% INFO    : Bus 62300	: V=0.99255, theta=-1.615649 -> V=1.0, theta=0.0
% INFO    : Bus 62301	: V=0.9940503, theta=-1.445922 -> V=1.0, theta=0.0
% INFO    : Bus 62302	: V=0.9933853, theta=-1.855032 -> V=1.0, theta=0.0
% INFO    : Bus 62303	: V=0.9923784, theta=-1.963008 -> V=1.0, theta=0.0
% INFO    : Bus 62304	: V=0.9915559, theta=-2.016109 -> V=1.0, theta=0.0
% INFO    : Bus 62305	: V=0.9926468, theta=-1.967673 -> V=1.0, theta=0.0
% INFO    : Bus 62306	: V=1.0004463, theta=-0.880483 -> V=1.0, theta=0.0
% INFO    : Bus 62307	: V=1.0000741, theta=-0.809738 -> V=1.0, theta=0.0
% INFO    : Bus 62308	: V=0.9977575, theta=-1.056983 -> V=1.0, theta=0.0
% INFO    : Bus 62309	: V=0.9997859, theta=-0.93722 -> V=1.0, theta=0.0
% INFO    : Bus 62310	: V=0.9908726, theta=-2.031892 -> V=1.0, theta=0.0
% INFO    : Bus 62311	: V=0.9892545, theta=-2.280743 -> V=1.0, theta=0.0
% INFO    : Bus 62312	: V=0.9977219, theta=-1.142708 -> V=1.0, theta=0.0
% INFO    : Bus 62313	: V=0.9884936, theta=-2.404994 -> V=1.0, theta=0.0
% INFO    : Bus 62314	: V=0.9881093, theta=-2.47548 -> V=1.0, theta=0.0
% INFO    : Bus 62315	: V=0.9925807, theta=-1.630041 -> V=1.0, theta=0.0
% INFO    : Bus 62316	: V=0.9894528, theta=-2.36357 -> V=1.0, theta=0.0
% INFO    : Bus 62317	: V=0.9930501, theta=-1.646577 -> V=1.0, theta=0.0
% INFO    : Bus 62318	: V=0.9895211, theta=-2.46334 -> V=1.0, theta=0.0
% INFO    : Bus 62319	: V=0.9907422, theta=-1.931647 -> V=1.0, theta=0.0
% INFO    : Bus 62320	: V=0.9905363, theta=-1.950657 -> V=1.0, theta=0.0
% INFO    : Bus 62321	: V=0.9887292, theta=-2.160825 -> V=1.0, theta=0.0
% INFO    : Bus 62322	: V=0.986652, theta=-2.387237 -> V=1.0, theta=0.0
% INFO    : Bus 62323	: V=0.9850829, theta=-2.561474 -> V=1.0, theta=0.0
% INFO    : Bus 62324	: V=0.9834097, theta=-2.724951 -> V=1.0, theta=0.0
% INFO    : Bus 62325	: V=0.9871776, theta=-2.674438 -> V=1.0, theta=0.0
% INFO    : Bus 62326	: V=0.9813606, theta=-3.064971 -> V=1.0, theta=0.0
% INFO    : Bus 62327	: V=0.9840648, theta=-2.891937 -> V=1.0, theta=0.0
% INFO    : Bus 62328	: V=0.9808987, theta=-3.501934 -> V=1.0, theta=0.0
% INFO    : Bus 62329	: V=0.9889386, theta=-2.585696 -> V=1.0, theta=0.0
% INFO    : Bus 62330	: V=0.9875637, theta=-2.781767 -> V=1.0, theta=0.0
% INFO    : Bus 62331	: V=0.9875156, theta=-2.636666 -> V=1.0, theta=0.0
% INFO    : Bus 62332	: V=0.9928328, theta=-1.666688 -> V=1.0, theta=0.0
% INFO    : Bus 62333	: V=0.9918921, theta=-2.221527 -> V=1.0, theta=0.0
% INFO    : Bus 62334	: V=0.9979355, theta=-1.118886 -> V=1.0, theta=0.0
% INFO    : Bus 62335	: V=0.9955575, theta=-1.363183 -> V=1.0, theta=0.0
% INFO    : Bus 62336	: V=0.9970425, theta=-1.194811 -> V=1.0, theta=0.0
% INFO    : Bus 62337	: V=0.9972472, theta=-1.295767 -> V=1.0, theta=0.0
% INFO    : Bus 62338	: V=0.9996553, theta=-0.964298 -> V=1.0, theta=0.0
% INFO    : Bus 62339	: V=1.0013445, theta=-0.805593 -> V=1.0, theta=0.0
% INFO    : Bus 62340	: V=1.000452, theta=-0.890363 -> V=1.0, theta=0.0
% INFO    : Bus 62341	: V=0.998056, theta=-1.178719 -> V=1.0, theta=0.0
% INFO    : Bus 62342	: V=0.9948099, theta=-1.894152 -> V=1.0, theta=0.0
% INFO    : Bus 62343	: V=0.9946563, theta=-1.906594 -> V=1.0, theta=0.0
% INFO    : Bus 62344	: V=0.9973838, theta=-1.141324 -> V=1.0, theta=0.0
% INFO    : Bus 62345	: V=0.9946681, theta=-1.905809 -> V=1.0, theta=0.0
% INFO    : Bus 62346	: V=0.9951472, theta=-1.382679 -> V=1.0, theta=0.0
% INFO    : Bus 62347	: V=0.990032, theta=-2.350441 -> V=1.0, theta=0.0
% INFO    : Bus 62348	: V=0.9888842, theta=-2.497323 -> V=1.0, theta=0.0
% INFO    : Bus 62349	: V=0.9937943, theta=-1.884115 -> V=1.0, theta=0.0
% INFO    : Bus 62350	: V=0.9904119, theta=-2.328611 -> V=1.0, theta=0.0
% INFO    : Bus 62351	: V=0.9927751, theta=-2.083437 -> V=1.0, theta=0.0
% INFO    : Bus 62352	: V=0.9914945, theta=-2.249981 -> V=1.0, theta=0.0
% INFO    : Bus 62353	: V=0.9965988, theta=-1.207833 -> V=1.0, theta=0.0
% INFO    : Bus 62354	: V=0.9954138, theta=-1.884057 -> V=1.0, theta=0.0
% INFO    : Bus 62355	: V=0.9955353, theta=-1.891934 -> V=1.0, theta=0.0
% INFO    : Bus 62356	: V=0.9983589, theta=-0.987808 -> V=1.0, theta=0.0
% INFO    : Bus 62357	: V=0.997901, theta=-1.045432 -> V=1.0, theta=0.0
% INFO    : Bus 62358	: V=0.9955136, theta=-1.828831 -> V=1.0, theta=0.0
% INFO    : Bus 62359	: V=0.9990525, theta=-1.049026 -> V=1.0, theta=0.0
% INFO    : Bus 62360	: V=0.999812, theta=-0.914945 -> V=1.0, theta=0.0
% INFO    : Bus 62361	: V=1.0028393, theta=-0.295267 -> V=1.0, theta=0.0
% INFO    : Bus 62362	: V=1.0007832, theta=-0.649142 -> V=1.0, theta=0.0
% INFO    : Bus 62363	: V=0.9998976, theta=-0.786572 -> V=1.0, theta=0.0
% INFO    : Bus 62364	: V=0.9994329, theta=-0.866985 -> V=1.0, theta=0.0
% INFO    : Bus 62365	: V=0.9992563, theta=-0.931938 -> V=1.0, theta=0.0
% INFO    : Bus 62366	: V=0.998675, theta=-0.994357 -> V=1.0, theta=0.0
% INFO    : Bus 62367	: V=0.9938744, theta=-2.049576 -> V=1.0, theta=0.0
% INFO    : Bus 62368	: V=0.9943848, theta=-1.845489 -> V=1.0, theta=0.0
% INFO    : Bus 62369	: V=0.9932139, theta=-2.143692 -> V=1.0, theta=0.0
% INFO    : Bus 62370	: V=0.9928758, theta=-2.22112 -> V=1.0, theta=0.0
% INFO    : Bus 62371	: V=0.9902197, theta=-2.439101 -> V=1.0, theta=0.0
% INFO    : Bus 62372	: V=0.9923587, theta=-3.010818 -> V=1.0, theta=0.0
% INFO    : Bus 62373	: V=0.9921517, theta=-2.261209 -> V=1.0, theta=0.0
% INFO    : Bus 62374	: V=0.9908483, theta=-2.471308 -> V=1.0, theta=0.0
% INFO    : Bus 62375	: V=0.9921474, theta=-2.354814 -> V=1.0, theta=0.0
% INFO    : Bus 62376	: V=0.9935989, theta=-2.011531 -> V=1.0, theta=0.0
% INFO    : Bus 62377	: V=0.9944994, theta=-1.881491 -> V=1.0, theta=0.0
% INFO    : Bus 62378	: V=0.9946246, theta=-2.012337 -> V=1.0, theta=0.0
% INFO    : Bus 62379	: V=0.9951281, theta=-1.780951 -> V=1.0, theta=0.0
% INFO    : Bus 62380	: V=0.9943326, theta=-1.985805 -> V=1.0, theta=0.0
% INFO    : Bus 62381	: V=0.9967068, theta=-1.55082 -> V=1.0, theta=0.0
% INFO    : Bus 62382	: V=0.9956986, theta=-1.847883 -> V=1.0, theta=0.0
% INFO    : Bus 62383	: V=0.9967308, theta=-1.693837 -> V=1.0, theta=0.0
% INFO    : Bus 62384	: V=0.9964278, theta=-1.714507 -> V=1.0, theta=0.0
% INFO    : Bus 62385	: V=0.9988578, theta=-1.284065 -> V=1.0, theta=0.0
% INFO    : Bus 62386	: V=0.9980727, theta=-1.417353 -> V=1.0, theta=0.0
% INFO    : Bus 62387	: V=0.9987564, theta=-1.342431 -> V=1.0, theta=0.0
% INFO    : Bus 62388	: V=0.999514, theta=-1.110273 -> V=1.0, theta=0.0
% INFO    : Bus 62389	: V=0.999896, theta=-1.09484 -> V=1.0, theta=0.0
% INFO    : Bus 62390	: V=1.02, theta=3.402292 -> V=1.0, theta=0.0
% INFO    : Bus 62391	: V=1.0015953, theta=-0.491537 -> V=1.0, theta=0.0
% INFO    : Bus 62392	: V=1.0026692, theta=-0.291632 -> V=1.0, theta=0.0
% INFO    : Bus 62393	: V=1.0033778, theta=-0.155809 -> V=1.0, theta=0.0
% INFO    : Bus 62394	: V=1.007318, theta=0.655997 -> V=1.0, theta=0.0
% INFO    : Bus 62395	: V=1.0072993, theta=0.613869 -> V=1.0, theta=0.0
% INFO    : Bus 62396	: V=1.0072905, theta=0.602296 -> V=1.0, theta=0.0
% INFO    : Bus 62397	: V=1.0073282, theta=0.589736 -> V=1.0, theta=0.0
% INFO    : Bus 62398	: V=1.0075709, theta=0.691635 -> V=1.0, theta=0.0
% INFO    : Bus 62399	: V=1.0076734, theta=0.786796 -> V=1.0, theta=0.0
% INFO    : Bus 62400	: V=1.0074571, theta=0.688088 -> V=1.0, theta=0.0
% INFO    : Bus 62401	: V=1.0049945, theta=0.045465 -> V=1.0, theta=0.0
% INFO    : Bus 62402	: V=1.0075339, theta=0.733695 -> V=1.0, theta=0.0
% INFO    : Bus 62403	: V=1.004589, theta=0.091818 -> V=1.0, theta=0.0
% INFO    : Bus 62404	: V=1.004972, theta=0.104874 -> V=1.0, theta=0.0
% INFO    : Bus 62405	: V=1.0038825, theta=0.007297 -> V=1.0, theta=0.0
% INFO    : Bus 62406	: V=1.0029678, theta=-0.246211 -> V=1.0, theta=0.0
% INFO    : Bus 62407	: V=1.0022738, theta=-0.351486 -> V=1.0, theta=0.0
% INFO    : Bus 62408	: V=1.0064606, theta=0.613513 -> V=1.0, theta=0.0
% INFO    : Bus 62409	: V=1.0005743, theta=-1.009246 -> V=1.0, theta=0.0
% INFO    : Bus 62410	: V=0.9996287, theta=-1.162485 -> V=1.0, theta=0.0
% INFO    : Bus 62411	: V=0.9970579, theta=-1.796225 -> V=1.0, theta=0.0
% INFO    : Bus 62412	: V=0.9988034, theta=-1.269681 -> V=1.0, theta=0.0
% INFO    : Bus 62413	: V=0.9978899, theta=-1.402458 -> V=1.0, theta=0.0
% INFO    : Bus 62414	: V=0.9971538, theta=-1.51369 -> V=1.0, theta=0.0
% INFO    : Bus 62415	: V=0.9953637, theta=-1.78397 -> V=1.0, theta=0.0
% INFO    : Bus 62416	: V=0.9959445, theta=-1.698594 -> V=1.0, theta=0.0
% INFO    : Bus 62417	: V=0.9946171, theta=-1.893189 -> V=1.0, theta=0.0
% INFO    : Bus 62418	: V=0.9941434, theta=-1.954466 -> V=1.0, theta=0.0
% INFO    : Bus 62419	: V=0.9922683, theta=-2.834238 -> V=1.0, theta=0.0
% INFO    : Bus 62420	: V=0.9927106, theta=-3.061546 -> V=1.0, theta=0.0
% INFO    : Bus 62421	: V=0.9936816, theta=-2.972974 -> V=1.0, theta=0.0
% INFO    : Bus 62422	: V=1.0008489, theta=-1.84343 -> V=1.0, theta=0.0
% INFO    : Bus 62423	: V=0.9961452, theta=-2.803052 -> V=1.0, theta=0.0
% INFO    : Bus 62424	: V=0.9955637, theta=-2.834844 -> V=1.0, theta=0.0
% INFO    : Bus 62425	: V=0.9936683, theta=-2.820007 -> V=1.0, theta=0.0
% INFO    : Bus 62426	: V=0.9941761, theta=-2.735121 -> V=1.0, theta=0.0
% INFO    : Bus 62427	: V=0.9942764, theta=-2.755803 -> V=1.0, theta=0.0
% INFO    : Bus 62428	: V=0.9980178, theta=-1.392717 -> V=1.0, theta=0.0
% INFO    : Bus 62429	: V=0.9960253, theta=-2.047032 -> V=1.0, theta=0.0
% INFO    : Bus 62430	: V=0.9981545, theta=-1.376738 -> V=1.0, theta=0.0
% INFO    : Bus 62431	: V=0.9983077, theta=-1.358709 -> V=1.0, theta=0.0
% INFO    : Bus 62432	: V=0.999062, theta=-1.242853 -> V=1.0, theta=0.0
% INFO    : Bus 62433	: V=1.0002399, theta=-1.090817 -> V=1.0, theta=0.0
% INFO    : Bus 62434	: V=1.0017125, theta=-0.875258 -> V=1.0, theta=0.0
% INFO    : Bus 62435	: V=1.0049819, theta=0.320559 -> V=1.0, theta=0.0
% INFO    : Bus 62436	: V=1.0064011, theta=0.564834 -> V=1.0, theta=0.0
% INFO    : Bus 62437	: V=1.0061934, theta=0.122994 -> V=1.0, theta=0.0
% INFO    : Bus 62438	: V=1.0076781, theta=0.868158 -> V=1.0, theta=0.0
% INFO    : Bus 62439	: V=1.007161, theta=0.775496 -> V=1.0, theta=0.0
% INFO    : Bus 62440	: V=1.0048093, theta=0.112072 -> V=1.0, theta=0.0
% INFO    : Bus 62441	: V=1.0053152, theta=0.166509 -> V=1.0, theta=0.0
% INFO    : Bus 62442	: V=1.0062903, theta=0.228219 -> V=1.0, theta=0.0
% INFO    : Bus 62443	: V=1.0048441, theta=0.248416 -> V=1.0, theta=0.0
% INFO    : Bus 62444	: V=1.0057072, theta=0.163824 -> V=1.0, theta=0.0
% INFO    : Bus 62445	: V=1.0088466, theta=0.948274 -> V=1.0, theta=0.0
% INFO    : Bus 62446	: V=1.0084179, theta=0.990152 -> V=1.0, theta=0.0
% INFO    : Bus 62447	: V=1.0085221, theta=0.942 -> V=1.0, theta=0.0
% INFO    : Bus 62448	: V=1.0082954, theta=0.946844 -> V=1.0, theta=0.0
% INFO    : Bus 62449	: V=1.0097058, theta=1.539102 -> V=1.0, theta=0.0
% INFO    : Bus 62450	: V=1.0089806, theta=1.541394 -> V=1.0, theta=0.0
% INFO    : Bus 62451	: V=1.03, theta=6.855073 -> V=1.0, theta=0.0
% INFO    : Bus 62452	: V=1.0086379, theta=1.284102 -> V=1.0, theta=0.0
% INFO    : Bus 62453	: V=1.0086554, theta=0.901014 -> V=1.0, theta=0.0
% INFO    : Bus 62454	: V=1.0033709, theta=-0.538512 -> V=1.0, theta=0.0
% INFO    : Bus 62455	: V=1.0087303, theta=0.87944 -> V=1.0, theta=0.0
% INFO    : Bus 62456	: V=1.0033847, theta=-0.576481 -> V=1.0, theta=0.0
% INFO    : Bus 62457	: V=1.0016762, theta=-0.958787 -> V=1.0, theta=0.0
% INFO    : Bus 62458	: V=1.0016215, theta=-1.085911 -> V=1.0, theta=0.0
% INFO    : Bus 62459	: V=0.9979423, theta=-1.684512 -> V=1.0, theta=0.0
% INFO    : Bus 62460	: V=1.0008601, theta=-1.298259 -> V=1.0, theta=0.0
% INFO    : Bus 62461	: V=0.9981237, theta=-1.732946 -> V=1.0, theta=0.0
% INFO    : Bus 62462	: V=1.0010769, theta=-1.232544 -> V=1.0, theta=0.0
% INFO    : Bus 62463	: V=1.0006374, theta=-1.454975 -> V=1.0, theta=0.0
% INFO    : Bus 62464	: V=1.0006412, theta=-1.579285 -> V=1.0, theta=0.0
% INFO    : Bus 62465	: V=0.9969507, theta=-2.031168 -> V=1.0, theta=0.0
% INFO    : Bus 62466	: V=1.0005152, theta=-1.62261 -> V=1.0, theta=0.0
% INFO    : Bus 62467	: V=0.9953654, theta=-2.660901 -> V=1.0, theta=0.0
% INFO    : Bus 62468	: V=1.0005956, theta=-1.657322 -> V=1.0, theta=0.0
% INFO    : Bus 62469	: V=0.9972964, theta=-2.720657 -> V=1.0, theta=0.0
% INFO    : Bus 62470	: V=1.0014922, theta=-1.726618 -> V=1.0, theta=0.0
% INFO    : Bus 62471	: V=0.9974207, theta=-2.318016 -> V=1.0, theta=0.0
% INFO    : Bus 62472	: V=0.9975715, theta=-1.863573 -> V=1.0, theta=0.0
% INFO    : Bus 62473	: V=1.0012979, theta=-1.21161 -> V=1.0, theta=0.0
% INFO    : Bus 62474	: V=1.0021559, theta=-1.059843 -> V=1.0, theta=0.0
% INFO    : Bus 62475	: V=0.9984414, theta=-1.749045 -> V=1.0, theta=0.0
% INFO    : Bus 62476	: V=1.0013811, theta=-0.999987 -> V=1.0, theta=0.0
% INFO    : Bus 62477	: V=1.0012494, theta=-1.016655 -> V=1.0, theta=0.0
% INFO    : Bus 62478	: V=1.0085315, theta=0.843627 -> V=1.0, theta=0.0
% INFO    : Bus 62479	: V=1.0084452, theta=0.835199 -> V=1.0, theta=0.0
% INFO    : Bus 62480	: V=1.0092718, theta=0.958197 -> V=1.0, theta=0.0
% INFO    : Bus 62481	: V=1.0104145, theta=1.150184 -> V=1.0, theta=0.0
% INFO    : Bus 62482	: V=1.0022798, theta=-1.379941 -> V=1.0, theta=0.0
% INFO    : Bus 62483	: V=1.0043385, theta=-1.009582 -> V=1.0, theta=0.0
% INFO    : Bus 62484	: V=1.0036611, theta=-1.052726 -> V=1.0, theta=0.0
% INFO    : Bus 62485	: V=0.9974763, theta=-2.428865 -> V=1.0, theta=0.0
% INFO    : Bus 62486	: V=1.0030002, theta=-1.314514 -> V=1.0, theta=0.0
% INFO    : Bus 62487	: V=1.0034487, theta=-1.177881 -> V=1.0, theta=0.0
% INFO    : Bus 62488	: V=1.0034355, theta=-1.195078 -> V=1.0, theta=0.0
% INFO    : Bus 62489	: V=1.005411, theta=-0.947857 -> V=1.0, theta=0.0
% INFO    : Bus 62490	: V=1.0050743, theta=-1.008017 -> V=1.0, theta=0.0
% INFO    : Bus 62491	: V=1.0029717, theta=-1.299047 -> V=1.0, theta=0.0
% INFO    : Bus 62492	: V=1.0053218, theta=-1.021072 -> V=1.0, theta=0.0
% INFO    : Bus 62493	: V=1.0028558, theta=-1.367957 -> V=1.0, theta=0.0
% INFO    : Bus 62494	: V=1.0027738, theta=-1.433934 -> V=1.0, theta=0.0
% INFO    : Bus 62495	: V=1.0025605, theta=-1.515756 -> V=1.0, theta=0.0
% INFO    : Bus 62496	: V=1.0041753, theta=-1.672819 -> V=1.0, theta=0.0
% INFO    : Bus 62497	: V=1.003055, theta=-1.600964 -> V=1.0, theta=0.0
% INFO    : Bus 62498	: V=1.0042318, theta=-1.594918 -> V=1.0, theta=0.0
% INFO    : Bus 62499	: V=1.0042141, theta=-1.717999 -> V=1.0, theta=0.0
% INFO    : Bus 62500	: V=0.9998256, theta=-1.999333 -> V=1.0, theta=0.0
% INFO    : Bus 62501	: V=1.0009463, theta=-1.829838 -> V=1.0, theta=0.0
% INFO    : Bus 62502	: V=0.9985531, theta=-1.903605 -> V=1.0, theta=0.0
% INFO    : Bus 62503	: V=0.9990128, theta=-1.888697 -> V=1.0, theta=0.0
% INFO    : Bus 62504	: V=1.0063679, theta=0.943479 -> V=1.0, theta=0.0
% INFO    : Bus 62505	: V=1.0022637, theta=-1.242685 -> V=1.0, theta=0.0
% INFO    : Bus 62506	: V=1.0012496, theta=-1.378488 -> V=1.0, theta=0.0
% INFO    : Bus 62507	: V=1.0002887, theta=-1.468477 -> V=1.0, theta=0.0
% INFO    : Bus 62508	: V=1.0023858, theta=-1.372202 -> V=1.0, theta=0.0
% INFO    : Bus 62509	: V=1.0024004, theta=-1.144069 -> V=1.0, theta=0.0
% INFO    : Bus 62510	: V=1.0013307, theta=-1.339716 -> V=1.0, theta=0.0
% INFO    : Bus 62511	: V=1.0011676, theta=-1.436039 -> V=1.0, theta=0.0
% INFO    : Bus 62512	: V=0.9998412, theta=-1.479815 -> V=1.0, theta=0.0
% INFO    : Bus 62513	: V=0.9987703, theta=-1.586242 -> V=1.0, theta=0.0
% INFO    : Bus 62514	: V=0.9984412, theta=-1.71325 -> V=1.0, theta=0.0
% INFO    : Bus 62515	: V=0.9976002, theta=-1.990599 -> V=1.0, theta=0.0
% INFO    : Bus 62516	: V=0.998105, theta=-2.036626 -> V=1.0, theta=0.0
% INFO    : Bus 62517	: V=1.0000699, theta=-2.218777 -> V=1.0, theta=0.0
% INFO    : Bus 62518	: V=1.0009231, theta=-2.709268 -> V=1.0, theta=0.0
% INFO    : Bus 62519	: V=1.0033046, theta=-2.017378 -> V=1.0, theta=0.0
% INFO    : Bus 62520	: V=1.0046894, theta=-1.843095 -> V=1.0, theta=0.0
% INFO    : Bus 62521	: V=0.9988975, theta=-2.792783 -> V=1.0, theta=0.0
% INFO    : Bus 62522	: V=1.0003403, theta=-2.844649 -> V=1.0, theta=0.0
% INFO    : Bus 62523	: V=0.997414, theta=-3.156489 -> V=1.0, theta=0.0
% INFO    : Bus 62524	: V=0.9931145, theta=-3.285809 -> V=1.0, theta=0.0
% INFO    : Bus 62525	: V=0.9926723, theta=-3.295803 -> V=1.0, theta=0.0
% INFO    : Bus 62526	: V=1.0010999, theta=-2.70668 -> V=1.0, theta=0.0
% INFO    : Bus 62527	: V=0.9997165, theta=-2.921201 -> V=1.0, theta=0.0
% INFO    : Bus 62528	: V=1.0022577, theta=-2.135559 -> V=1.0, theta=0.0
% INFO    : Bus 62529	: V=0.9981661, theta=-3.077391 -> V=1.0, theta=0.0
% INFO    : Bus 62530	: V=0.9976001, theta=-2.992951 -> V=1.0, theta=0.0
% INFO    : Bus 62531	: V=0.9921176, theta=-3.319509 -> V=1.0, theta=0.0
% INFO    : Bus 62532	: V=0.9971716, theta=-2.316783 -> V=1.0, theta=0.0
% INFO    : Bus 62533	: V=0.9945935, theta=-2.078468 -> V=1.0, theta=0.0
% INFO    : Bus 62534	: V=0.9971021, theta=-2.296985 -> V=1.0, theta=0.0
% INFO    : Bus 62535	: V=0.9920667, theta=-3.322534 -> V=1.0, theta=0.0
% INFO    : Bus 62536	: V=0.995331, theta=-1.90985 -> V=1.0, theta=0.0
% INFO    : Bus 62537	: V=0.9956364, theta=-1.93814 -> V=1.0, theta=0.0
% INFO    : Bus 62538	: V=0.9974775, theta=-1.867367 -> V=1.0, theta=0.0
% INFO    : Bus 62539	: V=0.996351, theta=-2.025435 -> V=1.0, theta=0.0
% INFO    : Bus 62540	: V=1.019939, theta=3.406717 -> V=1.0, theta=0.0
% INFO    : Bus 62541	: V=1.0041241, theta=0.162067 -> V=1.0, theta=0.0
% INFO    : Bus 62542	: V=0.9999589, theta=-1.217503 -> V=1.0, theta=0.0
% INFO    : Bus 62543	: V=0.9961951, theta=-1.834887 -> V=1.0, theta=0.0
% INFO    : Bus 62544	: V=1.0023159, theta=-1.366021 -> V=1.0, theta=0.0
% INFO    : Bus 62545	: V=1.02, theta=3.302817 -> V=1.0, theta=0.0
% INFO    : Bus 62546	: V=0.9793581, theta=-3.928167 -> V=1.0, theta=0.0
% INFO    : Bus 62547	: V=0.9737022, theta=-4.369587 -> V=1.0, theta=0.0
% INFO    : Bus 62548	: V=0.9771292, theta=-4.128393 -> V=1.0, theta=0.0
% INFO    : Bus 62549	: V=0.9717325, theta=-4.507857 -> V=1.0, theta=0.0
% INFO    : Bus 62550	: V=0.975386, theta=-4.186069 -> V=1.0, theta=0.0
% INFO    : Bus 62551	: V=0.978013, theta=-3.220625 -> V=1.0, theta=0.0
% INFO    : Bus 62552	: V=0.9851317, theta=-2.267658 -> V=1.0, theta=0.0
% INFO    : Bus 62553	: V=0.9756207, theta=-3.46707 -> V=1.0, theta=0.0
% INFO    : Bus 62554	: V=0.9857693, theta=-2.104232 -> V=1.0, theta=0.0
% INFO    : Bus 62555	: V=0.9857766, theta=-2.294901 -> V=1.0, theta=0.0
% INFO    : Bus 62556	: V=0.9614207, theta=-4.884058 -> V=1.0, theta=0.0
% INFO    : Bus 62557	: V=0.9712896, theta=-4.522609 -> V=1.0, theta=0.0
% INFO    : Bus 62558	: V=0.9646427, theta=-4.265198 -> V=1.0, theta=0.0
% INFO    : Bus 62559	: V=0.9799493, theta=-3.167847 -> V=1.0, theta=0.0
% INFO    : Bus 62560	: V=0.9768084, theta=-4.002253 -> V=1.0, theta=0.0
% INFO    : Bus 62561	: V=0.9704722, theta=-4.591644 -> V=1.0, theta=0.0
% INFO    : Bus 62562	: V=0.9691729, theta=-4.576049 -> V=1.0, theta=0.0
% INFO    : Bus 62563	: V=0.9771842, theta=-4.066552 -> V=1.0, theta=0.0
% INFO    : Bus 62564	: V=0.9786931, theta=-3.950303 -> V=1.0, theta=0.0
% INFO    : Bus 62565	: V=0.9695372, theta=-4.652907 -> V=1.0, theta=0.0
% INFO    : Bus 62566	: V=0.974594, theta=-4.366135 -> V=1.0, theta=0.0
% INFO    : Bus 62567	: V=0.9699436, theta=-4.57756 -> V=1.0, theta=0.0
% INFO    : Bus 62568	: V=0.9690129, theta=-4.683365 -> V=1.0, theta=0.0
% INFO    : Bus 62569	: V=0.9604957, theta=-5.164889 -> V=1.0, theta=0.0
% INFO    : Bus 62570	: V=0.9669702, theta=-4.798057 -> V=1.0, theta=0.0
% INFO    : Bus 62571	: V=0.9679768, theta=-4.764892 -> V=1.0, theta=0.0
% INFO    : Bus 62572	: V=0.9722133, theta=-2.546202 -> V=1.0, theta=0.0
% INFO    : Bus 62573	: V=0.9691354, theta=-4.629984 -> V=1.0, theta=0.0
% INFO    : Bus 62574	: V=0.9703804, theta=-4.591691 -> V=1.0, theta=0.0
% INFO    : Bus 62575	: V=0.9755186, theta=-3.168343 -> V=1.0, theta=0.0
% INFO    : Bus 62576	: V=0.9743599, theta=-3.036179 -> V=1.0, theta=0.0
% INFO    : Bus 62577	: V=0.9823419, theta=-2.537991 -> V=1.0, theta=0.0
% INFO    : Bus 62578	: V=0.9751608, theta=-3.928963 -> V=1.0, theta=0.0
% INFO    : Bus 62579	: V=0.9762378, theta=-3.216512 -> V=1.0, theta=0.0
% INFO    : Bus 62580	: V=0.9730479, theta=-2.798141 -> V=1.0, theta=0.0
% INFO    : Bus 62581	: V=0.9693287, theta=-4.638903 -> V=1.0, theta=0.0
% INFO    : Bus 62582	: V=0.9692767, theta=-4.672597 -> V=1.0, theta=0.0
% INFO    : Bus 62583	: V=0.980682, theta=-3.796447 -> V=1.0, theta=0.0
% INFO    : Bus 62584	: V=0.9803297, theta=-3.868998 -> V=1.0, theta=0.0
% INFO    : Bus 62585	: V=0.9826475, theta=-3.616003 -> V=1.0, theta=0.0
% INFO    : Bus 62586	: V=0.9818092, theta=-3.751056 -> V=1.0, theta=0.0
% INFO    : Bus 62587	: V=0.9842101, theta=-3.63705 -> V=1.0, theta=0.0
% INFO    : Bus 62588	: V=0.9838345, theta=-3.648417 -> V=1.0, theta=0.0
% INFO    : Bus 62589	: V=0.9859981, theta=-3.566443 -> V=1.0, theta=0.0
% INFO    : Bus 62590	: V=0.983846, theta=-3.626976 -> V=1.0, theta=0.0
% INFO    : Bus 62591	: V=0.9850256, theta=-3.61247 -> V=1.0, theta=0.0
% INFO    : Bus 62592	: V=0.9849599, theta=-3.593671 -> V=1.0, theta=0.0
% INFO    : Bus 62593	: V=0.9905026, theta=-3.254194 -> V=1.0, theta=0.0
% INFO    : Bus 62594	: V=0.9886226, theta=-3.378368 -> V=1.0, theta=0.0
% INFO    : Bus 62595	: V=0.9874926, theta=-3.440142 -> V=1.0, theta=0.0
% INFO    : Bus 62596	: V=0.9861904, theta=-3.587247 -> V=1.0, theta=0.0
% INFO    : Bus 62597	: V=0.9902393, theta=-3.484314 -> V=1.0, theta=0.0
% INFO    : Bus 62598	: V=0.9917879, theta=-3.438808 -> V=1.0, theta=0.0
% INFO    : Bus 62599	: V=0.9893563, theta=-3.433198 -> V=1.0, theta=0.0
% INFO    : Bus 62600	: V=0.9970589, theta=-2.194781 -> V=1.0, theta=0.0
% INFO    : Bus 62601	: V=0.9998081, theta=-2.054284 -> V=1.0, theta=0.0
% INFO    : Bus 62602	: V=0.9906818, theta=-3.438522 -> V=1.0, theta=0.0
% INFO    : Bus 62603	: V=0.9910297, theta=-3.476102 -> V=1.0, theta=0.0
% INFO    : Bus 62604	: V=1.0019135, theta=-2.220001 -> V=1.0, theta=0.0
% INFO    : Bus 62605	: V=1.0002693, theta=-2.022227 -> V=1.0, theta=0.0
% INFO    : Bus 62606	: V=1.0038001, theta=-1.837044 -> V=1.0, theta=0.0
% INFO    : Bus 62607	: V=1.0039427, theta=-1.678561 -> V=1.0, theta=0.0
% INFO    : Bus 62608	: V=1.0048105, theta=-1.626723 -> V=1.0, theta=0.0
% INFO    : Bus 62609	: V=1.0041639, theta=-1.803991 -> V=1.0, theta=0.0
% INFO    : Bus 62610	: V=1.0036813, theta=-1.995261 -> V=1.0, theta=0.0
% INFO    : Bus 62611	: V=1.0038021, theta=-2.055741 -> V=1.0, theta=0.0
% INFO    : Bus 62612	: V=1.0036326, theta=-1.977493 -> V=1.0, theta=0.0
% INFO    : Bus 62613	: V=1.0033123, theta=-2.804205 -> V=1.0, theta=0.0
% INFO    : Bus 62614	: V=1.0045232, theta=-2.743017 -> V=1.0, theta=0.0
% INFO    : Bus 62615	: V=1.0038852, theta=-2.760138 -> V=1.0, theta=0.0
% INFO    : Bus 62616	: V=1.0008402, theta=-2.775418 -> V=1.0, theta=0.0
% INFO    : Bus 62617	: V=1.0037138, theta=-2.009491 -> V=1.0, theta=0.0
% INFO    : Bus 62618	: V=1.0032227, theta=-2.084743 -> V=1.0, theta=0.0
% INFO    : Bus 62619	: V=1.0019605, theta=-2.926093 -> V=1.0, theta=0.0
% INFO    : Bus 62620	: V=1.0042412, theta=-1.898051 -> V=1.0, theta=0.0
% INFO    : Bus 62621	: V=1.0055652, theta=-1.686845 -> V=1.0, theta=0.0
% INFO    : Bus 62622	: V=1.0029688, theta=-2.266312 -> V=1.0, theta=0.0
% INFO    : Bus 62623	: V=1.03, theta=7.738889 -> V=1.0, theta=0.0
% INFO    : Bus 62624	: V=1.02, theta=2.783189 -> V=1.0, theta=0.0
% INFO    : Bus 62625	: V=1.003548, theta=-2.549164 -> V=1.0, theta=0.0
% INFO    : Bus 62626	: V=1.0055907, theta=-1.689321 -> V=1.0, theta=0.0
% INFO    : Bus 62627	: V=1.0081116, theta=-1.746543 -> V=1.0, theta=0.0
% INFO    : Bus 62628	: V=1.0014893, theta=-2.832731 -> V=1.0, theta=0.0
% INFO    : Bus 62629	: V=1.0000748, theta=-2.969851 -> V=1.0, theta=0.0
% INFO    : Bus 62630	: V=1.0094686, theta=-1.824163 -> V=1.0, theta=0.0
% INFO    : Bus 62631	: V=1.0007331, theta=-3.074539 -> V=1.0, theta=0.0
% INFO    : Bus 62632	: V=1.0018874, theta=-2.996952 -> V=1.0, theta=0.0
% INFO    : Bus 62633	: V=1.0097353, theta=-1.797226 -> V=1.0, theta=0.0
% INFO    : Bus 62634	: V=1.0077119, theta=-2.0283 -> V=1.0, theta=0.0
% INFO    : Bus 62635	: V=1.0012572, theta=-2.816869 -> V=1.0, theta=0.0
% INFO    : Bus 62636	: V=1.000983, theta=-2.738169 -> V=1.0, theta=0.0
% INFO    : Bus 62637	: V=1.0022904, theta=-2.668578 -> V=1.0, theta=0.0
% INFO    : Bus 62638	: V=1.0030192, theta=-2.627274 -> V=1.0, theta=0.0
% INFO    : Bus 62639	: V=1.0013926, theta=-1.880353 -> V=1.0, theta=0.0
% INFO    : Bus 62640	: V=1.001381, theta=-2.682956 -> V=1.0, theta=0.0
% INFO    : Bus 62641	: V=0.9905314, theta=-4.641538 -> V=1.0, theta=0.0
% INFO    : Bus 62642	: V=0.9853976, theta=-4.955236 -> V=1.0, theta=0.0
% INFO    : Bus 62643	: V=0.9887072, theta=-4.746014 -> V=1.0, theta=0.0
% INFO    : Bus 62644	: V=0.9895241, theta=-4.721047 -> V=1.0, theta=0.0
% INFO    : Bus 62645	: V=0.986887, theta=-4.775506 -> V=1.0, theta=0.0
% INFO    : Bus 62646	: V=0.9896584, theta=-4.63597 -> V=1.0, theta=0.0
% INFO    : Bus 62647	: V=0.9868558, theta=-4.775144 -> V=1.0, theta=0.0
% INFO    : Bus 62648	: V=0.9913094, theta=-4.504356 -> V=1.0, theta=0.0
% INFO    : Bus 62649	: V=0.9910531, theta=-4.563602 -> V=1.0, theta=0.0
% INFO    : Bus 62650	: V=0.9894628, theta=-4.631281 -> V=1.0, theta=0.0
% INFO    : Bus 62651	: V=0.9868617, theta=-4.785785 -> V=1.0, theta=0.0
% INFO    : Bus 62652	: V=0.9882508, theta=-4.801893 -> V=1.0, theta=0.0
% INFO    : Bus 62653	: V=0.982202, theta=-5.09576 -> V=1.0, theta=0.0
% INFO    : Bus 62654	: V=0.9825607, theta=-5.087801 -> V=1.0, theta=0.0
% INFO    : Bus 62655	: V=0.9876087, theta=-4.811163 -> V=1.0, theta=0.0
% INFO    : Bus 62656	: V=0.988495, theta=-4.797837 -> V=1.0, theta=0.0
% INFO    : Bus 62657	: V=0.9861688, theta=-4.930554 -> V=1.0, theta=0.0
% INFO    : Bus 62658	: V=0.9838465, theta=-5.051802 -> V=1.0, theta=0.0
% INFO    : Bus 62659	: V=0.9847656, theta=-5.013224 -> V=1.0, theta=0.0
% INFO    : Bus 62660	: V=0.9922639, theta=-4.511495 -> V=1.0, theta=0.0
% INFO    : Bus 62661	: V=0.989533, theta=-4.747655 -> V=1.0, theta=0.0
% INFO    : Bus 62662	: V=0.9864968, theta=-4.886911 -> V=1.0, theta=0.0
% INFO    : Bus 62663	: V=0.9857114, theta=-4.925275 -> V=1.0, theta=0.0
% INFO    : Bus 62664	: V=0.98982, theta=-4.361882 -> V=1.0, theta=0.0
% INFO    : Bus 62665	: V=0.9845292, theta=-4.685283 -> V=1.0, theta=0.0
% INFO    : Bus 62666	: V=0.9845403, theta=-4.748675 -> V=1.0, theta=0.0
% INFO    : Bus 62667	: V=0.9827938, theta=-4.950971 -> V=1.0, theta=0.0
% INFO    : Bus 62668	: V=0.9920019, theta=-4.179321 -> V=1.0, theta=0.0
% INFO    : Bus 62669	: V=0.9839, theta=-4.705971 -> V=1.0, theta=0.0
% INFO    : Bus 62670	: V=0.9911641, theta=-4.071519 -> V=1.0, theta=0.0
% INFO    : Bus 62671	: V=0.9913162, theta=-4.224305 -> V=1.0, theta=0.0
% INFO    : Bus 62672	: V=0.9912269, theta=-4.231194 -> V=1.0, theta=0.0
% INFO    : Bus 62673	: V=0.9881654, theta=-4.551047 -> V=1.0, theta=0.0
% INFO    : Bus 62674	: V=0.986223, theta=-4.68355 -> V=1.0, theta=0.0
% INFO    : Bus 62675	: V=0.9903678, theta=-4.344977 -> V=1.0, theta=0.0
% INFO    : Bus 62676	: V=0.989956, theta=-4.562807 -> V=1.0, theta=0.0
% INFO    : Bus 62677	: V=0.9887208, theta=-4.589952 -> V=1.0, theta=0.0
% INFO    : Bus 62678	: V=0.989219, theta=-4.702868 -> V=1.0, theta=0.0
% INFO    : Bus 62679	: V=0.9911733, theta=-4.497363 -> V=1.0, theta=0.0
% INFO    : Bus 62680	: V=0.9908082, theta=-4.599473 -> V=1.0, theta=0.0
% INFO    : Bus 62681	: V=0.9906327, theta=-4.50794 -> V=1.0, theta=0.0
% INFO    : Bus 62682	: V=0.991934, theta=-4.472009 -> V=1.0, theta=0.0
% INFO    : Bus 62683	: V=0.9890611, theta=-4.435475 -> V=1.0, theta=0.0
% INFO    : Bus 62684	: V=0.9917033, theta=-4.120671 -> V=1.0, theta=0.0
% INFO    : Bus 62685	: V=0.9904428, theta=-4.229751 -> V=1.0, theta=0.0
% INFO    : Bus 62686	: V=0.9981143, theta=-2.803375 -> V=1.0, theta=0.0
% INFO    : Bus 62687	: V=0.9978861, theta=-2.819547 -> V=1.0, theta=0.0
% INFO    : Bus 62688	: V=0.9943764, theta=-4.018652 -> V=1.0, theta=0.0
% INFO    : Bus 62689	: V=0.9983791, theta=-2.772193 -> V=1.0, theta=0.0
% INFO    : Bus 62690	: V=1.0000705, theta=-2.512669 -> V=1.0, theta=0.0
% INFO    : Bus 62691	: V=0.9994431, theta=-2.63933 -> V=1.0, theta=0.0
% INFO    : Bus 62692	: V=0.9999585, theta=-2.629661 -> V=1.0, theta=0.0
% INFO    : Bus 62693	: V=0.9988428, theta=-3.564687 -> V=1.0, theta=0.0
% INFO    : Bus 62694	: V=1.0166365, theta=-1.80667 -> V=1.0, theta=0.0
% INFO    : Bus 62695	: V=0.9983259, theta=-2.80519 -> V=1.0, theta=0.0
% INFO    : Bus 62696	: V=0.9915573, theta=-4.174307 -> V=1.0, theta=0.0
% INFO    : Bus 62697	: V=0.9910223, theta=-4.213902 -> V=1.0, theta=0.0
% INFO    : Bus 62698	: V=0.9899701, theta=-4.316551 -> V=1.0, theta=0.0
% INFO    : Bus 62699	: V=0.9906102, theta=-4.300249 -> V=1.0, theta=0.0
% INFO    : Bus 62700	: V=0.9888665, theta=-4.571098 -> V=1.0, theta=0.0
% INFO    : Bus 62701	: V=0.9883004, theta=-4.583632 -> V=1.0, theta=0.0
% INFO    : Bus 62702	: V=0.9920007, theta=-4.285937 -> V=1.0, theta=0.0
% INFO    : Bus 62703	: V=0.9911886, theta=-4.308748 -> V=1.0, theta=0.0
% INFO    : Bus 62704	: V=0.99229, theta=-4.095446 -> V=1.0, theta=0.0
% INFO    : Bus 62705	: V=0.9918013, theta=-4.147838 -> V=1.0, theta=0.0
% INFO    : Bus 62706	: V=0.9926299, theta=-3.997501 -> V=1.0, theta=0.0
% INFO    : Bus 62707	: V=0.9935464, theta=-3.967832 -> V=1.0, theta=0.0
% INFO    : Bus 62708	: V=0.9983351, theta=-3.540895 -> V=1.0, theta=0.0
% INFO    : Bus 62709	: V=0.9984135, theta=-3.481648 -> V=1.0, theta=0.0
% INFO    : Bus 62710	: V=1.0015434, theta=-2.420114 -> V=1.0, theta=0.0
% INFO    : Bus 62711	: V=0.9953895, theta=-3.783447 -> V=1.0, theta=0.0
% INFO    : Bus 62712	: V=0.9941877, theta=-3.821234 -> V=1.0, theta=0.0
% INFO    : Bus 62713	: V=0.9973918, theta=-3.581933 -> V=1.0, theta=0.0
% INFO    : Bus 62714	: V=0.998918, theta=-2.755761 -> V=1.0, theta=0.0
% INFO    : Bus 62715	: V=0.9999304, theta=-2.639391 -> V=1.0, theta=0.0
% INFO    : Bus 62716	: V=0.9996896, theta=-3.022072 -> V=1.0, theta=0.0
% INFO    : Bus 62717	: V=0.9956633, theta=-3.733979 -> V=1.0, theta=0.0
% INFO    : Bus 62718	: V=0.9968438, theta=-3.551045 -> V=1.0, theta=0.0
% INFO    : Bus 62719	: V=0.9982498, theta=-3.345434 -> V=1.0, theta=0.0
% INFO    : Bus 62720	: V=0.9994138, theta=-3.18537 -> V=1.0, theta=0.0
% INFO    : Bus 62721	: V=0.9991741, theta=-3.217339 -> V=1.0, theta=0.0
% INFO    : Bus 62722	: V=0.9979482, theta=-3.437357 -> V=1.0, theta=0.0
% INFO    : Bus 62723	: V=0.9965978, theta=-3.612219 -> V=1.0, theta=0.0
% INFO    : Bus 62724	: V=0.9958046, theta=-3.707826 -> V=1.0, theta=0.0
% INFO    : Bus 62725	: V=0.9994059, theta=-3.229371 -> V=1.0, theta=0.0
% INFO    : Bus 62726	: V=0.9970965, theta=-3.494049 -> V=1.0, theta=0.0
% INFO    : Bus 62727	: V=0.9952795, theta=-3.755627 -> V=1.0, theta=0.0
% INFO    : Bus 62728	: V=0.998752, theta=-3.348343 -> V=1.0, theta=0.0
% INFO    : Bus 62729	: V=0.9981441, theta=-3.384495 -> V=1.0, theta=0.0
% INFO    : Bus 62730	: V=0.9978157, theta=-2.862253 -> V=1.0, theta=0.0
% INFO    : Bus 62731	: V=0.9934406, theta=-4.225531 -> V=1.0, theta=0.0
% INFO    : Bus 62732	: V=0.9935958, theta=-3.845058 -> V=1.0, theta=0.0
% INFO    : Bus 62733	: V=0.9952911, theta=-3.947744 -> V=1.0, theta=0.0
% INFO    : Bus 62734	: V=1.0039531, theta=-2.424116 -> V=1.0, theta=0.0
% INFO    : Bus 62735	: V=0.9974984, theta=-3.788501 -> V=1.0, theta=0.0
% INFO    : Bus 62736	: V=0.9965323, theta=-3.843392 -> V=1.0, theta=0.0
% INFO    : Bus 62737	: V=1.0047804, theta=-2.515783 -> V=1.0, theta=0.0
% INFO    : Bus 62738	: V=1.0063413, theta=-2.634836 -> V=1.0, theta=0.0
% INFO    : Bus 62739	: V=0.9976268, theta=-3.786733 -> V=1.0, theta=0.0
% INFO    : Bus 62740	: V=0.9974072, theta=-3.821726 -> V=1.0, theta=0.0
% INFO    : Bus 62741	: V=1.0023921, theta=-2.967081 -> V=1.0, theta=0.0
% INFO    : Bus 62742	: V=0.990635, theta=-4.480321 -> V=1.0, theta=0.0
% INFO    : Bus 62743	: V=1.0037069, theta=-2.863742 -> V=1.0, theta=0.0
% INFO    : Bus 62744	: V=0.9960391, theta=-4.11079 -> V=1.0, theta=0.0
% INFO    : Bus 62745	: V=0.999068, theta=-3.740027 -> V=1.0, theta=0.0
% INFO    : Bus 62746	: V=0.9978487, theta=-3.985742 -> V=1.0, theta=0.0
% INFO    : Bus 62747	: V=0.997993, theta=-3.794387 -> V=1.0, theta=0.0
% INFO    : Bus 62748	: V=1.0078945, theta=-2.377999 -> V=1.0, theta=0.0
% INFO    : Bus 62749	: V=1.0017257, theta=-3.680954 -> V=1.0, theta=0.0
% INFO    : Bus 62750	: V=1.0089008, theta=-2.297434 -> V=1.0, theta=0.0
% INFO    : Bus 62751	: V=1.0039185, theta=-3.467943 -> V=1.0, theta=0.0
% INFO    : Bus 62752	: V=0.9926183, theta=-4.450259 -> V=1.0, theta=0.0
% INFO    : Bus 62753	: V=0.9960809, theta=-4.136114 -> V=1.0, theta=0.0
% INFO    : Bus 62754	: V=1.0070811, theta=-2.624576 -> V=1.0, theta=0.0
% INFO    : Bus 62755	: V=0.9946233, theta=-4.346304 -> V=1.0, theta=0.0
% INFO    : Bus 62756	: V=0.9934773, theta=-4.433775 -> V=1.0, theta=0.0
% INFO    : Bus 62757	: V=0.9921199, theta=-4.493472 -> V=1.0, theta=0.0
% INFO    : Bus 62758	: V=0.9972189, theta=-3.725353 -> V=1.0, theta=0.0
% INFO    : Bus 62759	: V=0.9884797, theta=-4.822648 -> V=1.0, theta=0.0
% INFO    : Bus 62760	: V=0.9965338, theta=-4.240331 -> V=1.0, theta=0.0
% INFO    : Bus 62761	: V=0.9971312, theta=-4.231834 -> V=1.0, theta=0.0
% INFO    : Bus 62762	: V=0.9987776, theta=-3.943231 -> V=1.0, theta=0.0
% INFO    : Bus 62763	: V=0.9993057, theta=-3.965206 -> V=1.0, theta=0.0
% INFO    : Bus 62764	: V=0.9979842, theta=-4.102716 -> V=1.0, theta=0.0
% INFO    : Bus 62765	: V=0.9999505, theta=-3.712927 -> V=1.0, theta=0.0
% INFO    : Bus 62766	: V=0.9931861, theta=-4.446144 -> V=1.0, theta=0.0
% INFO    : Bus 62767	: V=0.9900732, theta=-4.73229 -> V=1.0, theta=0.0
% INFO    : Bus 62768	: V=0.9918843, theta=-4.487899 -> V=1.0, theta=0.0
% INFO    : Bus 62769	: V=0.9908397, theta=-4.560548 -> V=1.0, theta=0.0
% INFO    : Bus 62770	: V=0.9897316, theta=-4.619232 -> V=1.0, theta=0.0
% INFO    : Bus 62771	: V=0.9872794, theta=-4.780706 -> V=1.0, theta=0.0
% INFO    : Bus 62772	: V=0.9911432, theta=-4.578024 -> V=1.0, theta=0.0
% INFO    : Bus 62773	: V=0.9978719, theta=-3.623634 -> V=1.0, theta=0.0
% INFO    : Bus 62774	: V=0.9915045, theta=-4.531252 -> V=1.0, theta=0.0
% INFO    : Bus 62775	: V=1.0022585, theta=-2.939982 -> V=1.0, theta=0.0
% INFO    : Bus 62776	: V=0.9935891, theta=-4.433954 -> V=1.0, theta=0.0
% INFO    : Bus 62777	: V=0.9936736, theta=-4.460658 -> V=1.0, theta=0.0
% INFO    : Bus 62778	: V=0.99665, theta=-4.121353 -> V=1.0, theta=0.0
% INFO    : Bus 62779	: V=0.9938218, theta=-4.373726 -> V=1.0, theta=0.0
% INFO    : Bus 62780	: V=0.9954281, theta=-4.174233 -> V=1.0, theta=0.0
% INFO    : Bus 62781	: V=0.9939315, theta=-4.386837 -> V=1.0, theta=0.0
% INFO    : Bus 62782	: V=0.9963112, theta=-4.36919 -> V=1.0, theta=0.0
% INFO    : Bus 62783	: V=1.0018081, theta=-3.116473 -> V=1.0, theta=0.0
% INFO    : Bus 62784	: V=0.9990447, theta=-3.472913 -> V=1.0, theta=0.0
% INFO    : Bus 62785	: V=0.9897933, theta=-4.76178 -> V=1.0, theta=0.0
% INFO    : Bus 62786	: V=0.9883932, theta=-4.806153 -> V=1.0, theta=0.0
% INFO    : Bus 62787	: V=0.9897782, theta=-4.671981 -> V=1.0, theta=0.0
% INFO    : Bus 62788	: V=0.9898943, theta=-4.522838 -> V=1.0, theta=0.0
% INFO    : Bus 62789	: V=0.9923729, theta=-3.988926 -> V=1.0, theta=0.0
% INFO    : Bus 62790	: V=0.9923484, theta=-4.029518 -> V=1.0, theta=0.0
% INFO    : Bus 62791	: V=0.9926049, theta=-4.048115 -> V=1.0, theta=0.0
% INFO    : Bus 62792	: V=0.9937978, theta=-3.971341 -> V=1.0, theta=0.0
% INFO    : Bus 62793	: V=0.9952054, theta=-3.861688 -> V=1.0, theta=0.0
% INFO    : Bus 62794	: V=0.9965369, theta=-3.667607 -> V=1.0, theta=0.0
% INFO    : Bus 62795	: V=0.99554, theta=-3.72255 -> V=1.0, theta=0.0
% INFO    : Bus 62796	: V=0.9923234, theta=-4.147037 -> V=1.0, theta=0.0
% INFO    : Bus 62797	: V=0.9962795, theta=-3.85257 -> V=1.0, theta=0.0
% INFO    : Bus 62798	: V=0.9944186, theta=-3.940469 -> V=1.0, theta=0.0
% INFO    : Bus 62799	: V=0.9818243, theta=-3.437116 -> V=1.0, theta=0.0
% INFO    : Bus 62800	: V=0.9688996, theta=-5.10194 -> V=1.0, theta=0.0
% INFO    : Bus 62801	: V=0.9696851, theta=-5.076595 -> V=1.0, theta=0.0
% INFO    : Bus 62802	: V=0.9779532, theta=-3.734447 -> V=1.0, theta=0.0
% INFO    : Bus 62803	: V=0.9686688, theta=-5.131731 -> V=1.0, theta=0.0
% INFO    : Bus 62804	: V=0.9681579, theta=-5.123601 -> V=1.0, theta=0.0
% INFO    : Bus 62805	: V=0.9701778, theta=-4.883633 -> V=1.0, theta=0.0
% INFO    : Bus 62806	: V=0.962208, theta=-5.506973 -> V=1.0, theta=0.0
% INFO    : Bus 62807	: V=0.9842098, theta=-2.520009 -> V=1.0, theta=0.0
% INFO    : Bus 62808	: V=0.9854828, theta=-2.355766 -> V=1.0, theta=0.0
% INFO    : Bus 62809	: V=0.9846419, theta=-2.432559 -> V=1.0, theta=0.0
% INFO    : Bus 62810	: V=0.9853889, theta=-2.364888 -> V=1.0, theta=0.0
% INFO    : Bus 62811	: V=0.9865211, theta=-2.065601 -> V=1.0, theta=0.0
% INFO    : Bus 62812	: V=0.9740303, theta=-4.344355 -> V=1.0, theta=0.0
% INFO    : Bus 62813	: V=0.9850397, theta=-2.261397 -> V=1.0, theta=0.0
% INFO    : Bus 62814	: V=0.9811551, theta=-3.423078 -> V=1.0, theta=0.0
% INFO    : Bus 62815	: V=0.9791061, theta=-3.539814 -> V=1.0, theta=0.0
% INFO    : Bus 62816	: V=0.9827106, theta=-3.221388 -> V=1.0, theta=0.0
% INFO    : Bus 62817	: V=0.983225, theta=-2.525308 -> V=1.0, theta=0.0
% INFO    : Bus 62818	: V=0.9822095, theta=-2.628119 -> V=1.0, theta=0.0
% INFO    : Bus 62819	: V=0.9732878, theta=-3.811772 -> V=1.0, theta=0.0
% INFO    : Bus 62820	: V=0.975499, theta=-3.749424 -> V=1.0, theta=0.0
% INFO    : Bus 62821	: V=0.9797217, theta=-2.941872 -> V=1.0, theta=0.0
% INFO    : Bus 62822	: V=0.9759422, theta=-3.348006 -> V=1.0, theta=0.0
% INFO    : Bus 62823	: V=0.9630485, theta=-5.265017 -> V=1.0, theta=0.0
% INFO    : Bus 62824	: V=0.9659847, theta=-5.124388 -> V=1.0, theta=0.0
% INFO    : Bus 62825	: V=0.9657834, theta=-5.135095 -> V=1.0, theta=0.0
% INFO    : Bus 62826	: V=0.9661882, theta=-5.131933 -> V=1.0, theta=0.0
% INFO    : Bus 62827	: V=0.9645645, theta=-5.198468 -> V=1.0, theta=0.0
% INFO    : Bus 62828	: V=0.9601453, theta=-5.303905 -> V=1.0, theta=0.0
% INFO    : Bus 62829	: V=0.9606692, theta=-5.285329 -> V=1.0, theta=0.0
% INFO    : Bus 62830	: V=0.9624233, theta=-5.263334 -> V=1.0, theta=0.0
% INFO    : Bus 62831	: V=0.9617631, theta=-5.276097 -> V=1.0, theta=0.0
% INFO    : Bus 62832	: V=0.9899751, theta=-1.131461 -> V=1.0, theta=0.0
% INFO    : Bus 62833	: V=0.9896151, theta=-1.327733 -> V=1.0, theta=0.0
% INFO    : Bus 62834	: V=0.9891931, theta=-1.543601 -> V=1.0, theta=0.0
% INFO    : Bus 62835	: V=0.9885966, theta=-1.812278 -> V=1.0, theta=0.0
% INFO    : Bus 62836	: V=0.9880127, theta=-1.989663 -> V=1.0, theta=0.0
% INFO    : Bus 62837	: V=0.9893918, theta=-1.692731 -> V=1.0, theta=0.0
% INFO    : Bus 62838	: V=0.9882216, theta=-1.851948 -> V=1.0, theta=0.0
% INFO    : Bus 62839	: V=0.9876563, theta=-2.207844 -> V=1.0, theta=0.0
% INFO    : Bus 62840	: V=0.982997, theta=-2.696648 -> V=1.0, theta=0.0
% INFO    : Bus 62841	: V=0.9850137, theta=-2.336178 -> V=1.0, theta=0.0
% INFO    : Bus 62842	: V=0.9812487, theta=-3.412838 -> V=1.0, theta=0.0
% INFO    : Bus 62843	: V=0.9794679, theta=-3.515168 -> V=1.0, theta=0.0
% INFO    : Bus 62844	: V=0.9801919, theta=-3.470872 -> V=1.0, theta=0.0
% INFO    : Bus 62845	: V=0.9831766, theta=-2.55769 -> V=1.0, theta=0.0
% INFO    : Bus 62846	: V=0.9793488, theta=-3.604211 -> V=1.0, theta=0.0
% INFO    : Bus 62847	: V=0.980759, theta=-2.856271 -> V=1.0, theta=0.0
% INFO    : Bus 62848	: V=0.9720695, theta=-4.512121 -> V=1.0, theta=0.0
% INFO    : Bus 62849	: V=0.9696253, theta=-4.740299 -> V=1.0, theta=0.0
% INFO    : Bus 62850	: V=0.9657285, theta=-5.011613 -> V=1.0, theta=0.0
% INFO    : Bus 62851	: V=0.9900307, theta=-1.08135 -> V=1.0, theta=0.0
% INFO    : Bus 62852	: V=0.9954822, theta=-0.815233 -> V=1.0, theta=0.0
% INFO    : Bus 62853	: V=0.9946029, theta=-0.964533 -> V=1.0, theta=0.0
% INFO    : Bus 62854	: V=0.9882823, theta=-1.883828 -> V=1.0, theta=0.0
% INFO    : Bus 62855	: V=0.9908377, theta=-1.537831 -> V=1.0, theta=0.0
% INFO    : Bus 62856	: V=0.9900207, theta=-1.656034 -> V=1.0, theta=0.0
% INFO    : Bus 62857	: V=0.9892699, theta=-1.749614 -> V=1.0, theta=0.0
% INFO    : Bus 62858	: V=0.9881092, theta=-1.932231 -> V=1.0, theta=0.0
% INFO    : Bus 62859	: V=0.9864101, theta=-2.1885 -> V=1.0, theta=0.0
% INFO    : Bus 62860	: V=0.9870279, theta=-2.113018 -> V=1.0, theta=0.0
% INFO    : Bus 62861	: V=0.986961, theta=-2.145834 -> V=1.0, theta=0.0
% INFO    : Bus 62862	: V=0.9858613, theta=-2.266992 -> V=1.0, theta=0.0
% INFO    : Bus 62863	: V=0.978153, theta=-3.609687 -> V=1.0, theta=0.0
% INFO    : Bus 62864	: V=0.9787136, theta=-3.608126 -> V=1.0, theta=0.0
% INFO    : Bus 62865	: V=0.978619, theta=-3.700054 -> V=1.0, theta=0.0
% INFO    : Bus 62866	: V=0.9739781, theta=-4.163725 -> V=1.0, theta=0.0
% INFO    : Bus 62867	: V=0.9755006, theta=-4.121416 -> V=1.0, theta=0.0
% INFO    : Bus 62868	: V=0.9796985, theta=-2.980371 -> V=1.0, theta=0.0
% INFO    : Bus 62869	: V=0.9738262, theta=-4.270116 -> V=1.0, theta=0.0
% INFO    : Bus 62870	: V=0.9732571, theta=-4.302781 -> V=1.0, theta=0.0
% INFO    : Bus 62871	: V=0.9716088, theta=-4.452816 -> V=1.0, theta=0.0
% INFO    : Bus 62872	: V=0.9966939, theta=-0.619145 -> V=1.0, theta=0.0
% INFO    : Bus 62873	: V=0.9938323, theta=-1.083081 -> V=1.0, theta=0.0
% INFO    : Bus 62874	: V=0.9929134, theta=-1.220106 -> V=1.0, theta=0.0
% INFO    : Bus 62875	: V=0.9918077, theta=-1.395997 -> V=1.0, theta=0.0
% INFO    : Bus 62876	: V=0.9869567, theta=-2.413844 -> V=1.0, theta=0.0
% INFO    : Bus 62877	: V=0.986272, theta=-2.522873 -> V=1.0, theta=0.0
% INFO    : Bus 62878	: V=0.9911398, theta=-1.767403 -> V=1.0, theta=0.0
% INFO    : Bus 62879	: V=0.9899005, theta=-1.897086 -> V=1.0, theta=0.0
% INFO    : Bus 62880	: V=0.9878704, theta=-2.074188 -> V=1.0, theta=0.0
% INFO    : Bus 62881	: V=0.9885601, theta=-2.017251 -> V=1.0, theta=0.0
% INFO    : Bus 62882	: V=0.9803448, theta=-3.482073 -> V=1.0, theta=0.0
% INFO    : Bus 62883	: V=0.9807559, theta=-3.465703 -> V=1.0, theta=0.0
% INFO    : Bus 62884	: V=0.9789818, theta=-3.542194 -> V=1.0, theta=0.0
% INFO    : Bus 62885	: V=0.9792154, theta=-3.565641 -> V=1.0, theta=0.0
% INFO    : Bus 62886	: V=0.9797297, theta=-3.514582 -> V=1.0, theta=0.0
% INFO    : Bus 62887	: V=0.985856, theta=-2.229282 -> V=1.0, theta=0.0
% INFO    : Bus 62888	: V=0.977655, theta=-3.796411 -> V=1.0, theta=0.0
% INFO    : Bus 62889	: V=0.9793312, theta=-3.608647 -> V=1.0, theta=0.0
% INFO    : Bus 62890	: V=0.9777614, theta=-3.822564 -> V=1.0, theta=0.0
% INFO    : Bus 62891	: V=0.9762536, theta=-4.03502 -> V=1.0, theta=0.0
% INFO    : Bus 62892	: V=0.9769353, theta=-3.962348 -> V=1.0, theta=0.0
% INFO    : Bus 62893	: V=0.9747045, theta=-4.229289 -> V=1.0, theta=0.0
% INFO    : Bus 62894	: V=0.9731992, theta=-4.33049 -> V=1.0, theta=0.0
% INFO    : Bus 62895	: V=0.9707495, theta=-4.491453 -> V=1.0, theta=0.0
% INFO    : Bus 62896	: V=0.9732612, theta=-4.409114 -> V=1.0, theta=0.0
% INFO    : Bus 62897	: V=0.970126, theta=-4.556084 -> V=1.0, theta=0.0
% INFO    : Bus 62898	: V=1.0156012, theta=4.113585 -> V=1.0, theta=0.0
% INFO    : Bus 62899	: V=0.9957222, theta=1.810173 -> V=1.0, theta=0.0
% INFO    : Bus 62900	: V=0.9956541, theta=7.415101 -> V=1.0, theta=0.0
% INFO    : Bus 62901	: V=1.0116155, theta=5.428432 -> V=1.0, theta=0.0
% INFO    : Bus 62902	: V=1.0147459, theta=3.826575 -> V=1.0, theta=0.0
% INFO    : Bus 62903	: V=1.0157591, theta=4.122442 -> V=1.0, theta=0.0
% INFO    : Bus 62904	: V=1.0008462, theta=-2.913483 -> V=1.0, theta=0.0
% INFO    : Bus 62905	: V=1.0072134, theta=-2.061334 -> V=1.0, theta=0.0
% INFO    : Bus 62906	: V=0.9982468, theta=-3.403487 -> V=1.0, theta=0.0
% INFO    : Bus 62907	: V=0.9978635, theta=-3.522325 -> V=1.0, theta=0.0
% INFO    : Bus 62908	: V=1.0034521, theta=-2.175717 -> V=1.0, theta=0.0
% INFO    : Bus 62909	: V=0.9993716, theta=-3.214965 -> V=1.0, theta=0.0
% INFO    : Bus 62910	: V=1.0001039, theta=-3.270817 -> V=1.0, theta=0.0
% INFO    : Bus 62911	: V=1.0058621, theta=-2.179715 -> V=1.0, theta=0.0
% INFO    : Bus 62912	: V=0.9979345, theta=-3.595187 -> V=1.0, theta=0.0
% INFO    : Bus 62913	: V=0.9983291, theta=-3.286243 -> V=1.0, theta=0.0
% INFO    : Bus 62914	: V=0.9985436, theta=-3.388506 -> V=1.0, theta=0.0
% INFO    : Bus 62915	: V=0.998412, theta=-3.487323 -> V=1.0, theta=0.0
% INFO    : Bus 62916	: V=1.0046368, theta=-2.525998 -> V=1.0, theta=0.0
% INFO    : Bus 62917	: V=0.9943265, theta=-3.987058 -> V=1.0, theta=0.0
% INFO    : Bus 62918	: V=0.9932529, theta=-4.036598 -> V=1.0, theta=0.0
% INFO    : Bus 62919	: V=0.9957604, theta=-4.07286 -> V=1.0, theta=0.0
% INFO    : Bus 62920	: V=0.9930678, theta=-4.155464 -> V=1.0, theta=0.0
% INFO    : Bus 62921	: V=0.9943693, theta=-4.126021 -> V=1.0, theta=0.0
% INFO    : Bus 62922	: V=0.9972761, theta=-3.641612 -> V=1.0, theta=0.0
% INFO    : Bus 62923	: V=0.9940461, theta=-3.972759 -> V=1.0, theta=0.0
% INFO    : Bus 62924	: V=0.9929104, theta=-4.046123 -> V=1.0, theta=0.0
% INFO    : Bus 62925	: V=0.993173, theta=-4.142199 -> V=1.0, theta=0.0
% INFO    : Bus 62926	: V=0.9943709, theta=-3.961489 -> V=1.0, theta=0.0
% INFO    : Bus 62927	: V=0.992823, theta=-4.090886 -> V=1.0, theta=0.0
% INFO    : Bus 62928	: V=1.0009824, theta=-2.684716 -> V=1.0, theta=0.0
% INFO    : Bus 62929	: V=0.9926431, theta=-4.321337 -> V=1.0, theta=0.0
% INFO    : Bus 62930	: V=0.9945638, theta=-3.973263 -> V=1.0, theta=0.0
% INFO    : Bus 62931	: V=0.9922125, theta=-4.07962 -> V=1.0, theta=0.0
% INFO    : Bus 62932	: V=0.991782, theta=-4.363891 -> V=1.0, theta=0.0
% INFO    : Bus 62933	: V=0.9943417, theta=-3.971723 -> V=1.0, theta=0.0
% INFO    : Bus 62934	: V=0.9922115, theta=-4.24798 -> V=1.0, theta=0.0
% INFO    : Bus 62935	: V=0.9921378, theta=-4.260147 -> V=1.0, theta=0.0
% INFO    : Bus 62936	: V=0.992657, theta=-4.24503 -> V=1.0, theta=0.0
% INFO    : Bus 62937	: V=0.9914761, theta=-4.357711 -> V=1.0, theta=0.0
% INFO    : Bus 62938	: V=0.9898435, theta=-4.532389 -> V=1.0, theta=0.0
% INFO    : Bus 62939	: V=0.9914394, theta=-4.277506 -> V=1.0, theta=0.0
% INFO    : Bus 62940	: V=0.9900383, theta=-4.508415 -> V=1.0, theta=0.0
% INFO    : Bus 62941	: V=0.9918833, theta=-4.260704 -> V=1.0, theta=0.0
% INFO    : Bus 62942	: V=0.9885467, theta=-4.593548 -> V=1.0, theta=0.0
% INFO    : Bus 62943	: V=0.9881339, theta=-4.624915 -> V=1.0, theta=0.0
% INFO    : Bus 62944	: V=0.9887253, theta=-4.597178 -> V=1.0, theta=0.0
% INFO    : Bus 62945	: V=0.9891687, theta=-4.583842 -> V=1.0, theta=0.0
% INFO    : Bus 62946	: V=0.9946334, theta=-3.966034 -> V=1.0, theta=0.0
% INFO    : Bus 62947	: V=0.9960427, theta=-3.901367 -> V=1.0, theta=0.0
% INFO    : Bus 62948	: V=0.9978532, theta=-3.808467 -> V=1.0, theta=0.0
% INFO    : Bus 62949	: V=1.0087328, theta=-2.299831 -> V=1.0, theta=0.0
% INFO    : Bus 62950	: V=1.0035138, theta=-3.521386 -> V=1.0, theta=0.0
% INFO    : Bus 62951	: V=1.0038413, theta=-3.472802 -> V=1.0, theta=0.0
% INFO    : Bus 62952	: V=1.0009927, theta=-3.733566 -> V=1.0, theta=0.0
% INFO    : Bus 62953	: V=0.996331, theta=-4.056198 -> V=1.0, theta=0.0
% INFO    : Bus 62954	: V=1.001453, theta=-3.621246 -> V=1.0, theta=0.0
% INFO    : Bus 62955	: V=1.0012489, theta=-3.684254 -> V=1.0, theta=0.0
% INFO    : Bus 62956	: V=0.9986585, theta=-3.850147 -> V=1.0, theta=0.0
% INFO    : Bus 62957	: V=0.9942202, theta=-4.221577 -> V=1.0, theta=0.0
% INFO    : Bus 62958	: V=1.0076803, theta=-2.180696 -> V=1.0, theta=0.0
% INFO    : Bus 62959	: V=1.0079559, theta=-2.371412 -> V=1.0, theta=0.0
% INFO    : Bus 62960	: V=0.9975022, theta=-3.939746 -> V=1.0, theta=0.0
% INFO    : Bus 62961	: V=0.9958547, theta=-4.09952 -> V=1.0, theta=0.0
% INFO    : Bus 62962	: V=0.9946968, theta=-4.138397 -> V=1.0, theta=0.0
% INFO    : Bus 62963	: V=0.997677, theta=-3.860523 -> V=1.0, theta=0.0
% INFO    : Bus 62964	: V=0.9909262, theta=-4.515628 -> V=1.0, theta=0.0
% INFO    : Bus 62965	: V=0.9940584, theta=-4.19142 -> V=1.0, theta=0.0
% INFO    : Bus 62966	: V=0.9927063, theta=-4.27869 -> V=1.0, theta=0.0
% INFO    : Bus 62967	: V=0.99201, theta=-4.2259 -> V=1.0, theta=0.0
% INFO    : Bus 62968	: V=0.9885896, theta=-4.687201 -> V=1.0, theta=0.0
% INFO    : Bus 62969	: V=0.9873919, theta=-4.713565 -> V=1.0, theta=0.0
% INFO    : Bus 62970	: V=0.991356, theta=-4.331802 -> V=1.0, theta=0.0
% INFO    : Bus 62971	: V=0.9900036, theta=-4.188638 -> V=1.0, theta=0.0
% INFO    : Bus 62972	: V=0.9888978, theta=-4.30233 -> V=1.0, theta=0.0
% INFO    : Bus 62973	: V=0.9867403, theta=-4.238397 -> V=1.0, theta=0.0
% INFO    : Bus 62974	: V=0.989137, theta=-4.122198 -> V=1.0, theta=0.0
% INFO    : Bus 62975	: V=0.9886253, theta=-4.117313 -> V=1.0, theta=0.0
% INFO    : Bus 62976	: V=0.9901396, theta=-3.9721 -> V=1.0, theta=0.0
% INFO    : Bus 62977	: V=0.9943389, theta=-4.186724 -> V=1.0, theta=0.0
% INFO    : Bus 62978	: V=0.9934242, theta=-4.214824 -> V=1.0, theta=0.0
% INFO    : Bus 62979	: V=0.9926029, theta=-4.238484 -> V=1.0, theta=0.0
% INFO    : Bus 62980	: V=1.0006352, theta=-2.648897 -> V=1.0, theta=0.0
% INFO    : Bus 62981	: V=0.9977203, theta=0.776602 -> V=1.0, theta=0.0
% INFO    : Bus 62982	: V=0.9960374, theta=-1.807411 -> V=1.0, theta=0.0
% INFO    : Bus 62983	: V=1.01, theta=0.665259 -> V=1.0, theta=0.0
% INFO    : Bus 62984	: V=0.9866852, theta=-1.482077 -> V=1.0, theta=0.0
% INFO    : Bus 62985	: V=0.9892358, theta=-2.623114 -> V=1.0, theta=0.0
% INFO    : Bus 62986	: V=1.0203628, theta=7.777551 -> V=1.0, theta=0.0
% INFO    : Bus 62987	: V=0.9988996, theta=-2.249411 -> V=1.0, theta=0.0
% INFO    : Bus 62988	: V=0.9988186, theta=-2.447716 -> V=1.0, theta=0.0
% INFO    : Bus 62989	: V=0.9916666, theta=-4.370715 -> V=1.0, theta=0.0
% INFO    : Bus 62990	: V=0.9756337, theta=-2.833923 -> V=1.0, theta=0.0
% INFO    : Bus 62991	: V=1.01996, theta=-11.033936 -> V=1.0, theta=0.0
% INFO    : Bus 62992	: V=1.0168916, theta=-18.681786 -> V=1.0, theta=0.0
% INFO    : Bus 62993	: V=0.9447482, theta=-2.808952 -> V=1.0, theta=0.0
% INFO    : Bus 62994	: V=1.0187371, theta=-13.521217 -> V=1.0, theta=0.0
% INFO    : Bus 62995	: V=1.0185071, theta=-13.054522 -> V=1.0, theta=0.0
% INFO    : Bus 62996	: V=1.005627, theta=-16.877362 -> V=1.0, theta=0.0
% INFO    : Bus 62997	: V=1.0159963, theta=-17.002382 -> V=1.0, theta=0.0
% INFO    : Bus 62998	: V=1.0152967, theta=-15.244758 -> V=1.0, theta=0.0
% INFO    : Bus 62999	: V=1.016682, theta=-14.493914 -> V=1.0, theta=0.0
% INFO    : Bus 63000	: V=1.0156075, theta=-15.076886 -> V=1.0, theta=0.0
% INFO    : Bus 63001	: V=1.0148443, theta=-15.243372 -> V=1.0, theta=0.0
% INFO    : Bus 63002	: V=1.0179746, theta=-19.351283 -> V=1.0, theta=0.0
% INFO    : Bus 63003	: V=1.025294, theta=-20.91359 -> V=1.0, theta=0.0
% INFO    : Bus 63004	: V=1.0200757, theta=-20.006292 -> V=1.0, theta=0.0
% INFO    : Bus 63005	: V=1.021005, theta=-19.662591 -> V=1.0, theta=0.0
% INFO    : Bus 63006	: V=1.0219783, theta=-20.210143 -> V=1.0, theta=0.0
% INFO    : Bus 63007	: V=1.0175216, theta=-20.711041 -> V=1.0, theta=0.0
% INFO    : Bus 63008	: V=1.0181932, theta=-20.696111 -> V=1.0, theta=0.0
% INFO    : Bus 63009	: V=1.0175947, theta=-20.71317 -> V=1.0, theta=0.0
% INFO    : Bus 63010	: V=1.0166401, theta=-19.585847 -> V=1.0, theta=0.0
% INFO    : Bus 63011	: V=1.0160251, theta=-19.604451 -> V=1.0, theta=0.0
% INFO    : Bus 63012	: V=1.0153468, theta=-18.18093 -> V=1.0, theta=0.0
% INFO    : Bus 63013	: V=1.0143693, theta=-19.808275 -> V=1.0, theta=0.0
% INFO    : Bus 63014	: V=1.0163715, theta=-19.245679 -> V=1.0, theta=0.0
% INFO    : Bus 63015	: V=1.0020526, theta=-18.768715 -> V=1.0, theta=0.0
% INFO    : Bus 63016	: V=0.9978354, theta=-18.862044 -> V=1.0, theta=0.0
% INFO    : Bus 63017	: V=0.9973771, theta=-18.874707 -> V=1.0, theta=0.0
% INFO    : Bus 63018	: V=0.9969837, theta=-18.862311 -> V=1.0, theta=0.0
% INFO    : Bus 63019	: V=0.9905331, theta=-19.733151 -> V=1.0, theta=0.0
% INFO    : Bus 63020	: V=0.9967736, theta=-18.841375 -> V=1.0, theta=0.0
% INFO    : Bus 63021	: V=0.9923669, theta=-19.689185 -> V=1.0, theta=0.0
% INFO    : Bus 63022	: V=0.9922507, theta=-19.661194 -> V=1.0, theta=0.0
% INFO    : Bus 63023	: V=0.9927837, theta=-19.577532 -> V=1.0, theta=0.0
% INFO    : Bus 63024	: V=0.996571, theta=-18.754894 -> V=1.0, theta=0.0
% INFO    : Bus 63025	: V=0.9941267, theta=-19.453589 -> V=1.0, theta=0.0
% INFO    : Bus 63026	: V=0.9942243, theta=-17.740785 -> V=1.0, theta=0.0
% INFO    : Bus 63027	: V=1.0110421, theta=-15.272549 -> V=1.0, theta=0.0
% INFO    : Bus 63028	: V=1.0143907, theta=-15.091791 -> V=1.0, theta=0.0
% INFO    : Bus 63029	: V=1.0150739, theta=-15.288966 -> V=1.0, theta=0.0
% INFO    : Bus 63030	: V=1.0200002, theta=-13.798702 -> V=1.0, theta=0.0
% INFO    : Bus 63031	: V=1.0100002, theta=-13.003379 -> V=1.0, theta=0.0
% INFO    : Bus 63032	: V=1.0150322, theta=-15.478853 -> V=1.0, theta=0.0
% INFO    : Bus 63033	: V=1.0188826, theta=-18.535596 -> V=1.0, theta=0.0
% INFO    : Bus 63034	: V=0.9897489, theta=28.231723 -> V=1.0, theta=0.0
% INFO    : Bus 63035	: V=0.9946339, theta=27.42387 -> V=1.0, theta=0.0
% INFO    : Bus 63036	: V=0.994067, theta=28.428012 -> V=1.0, theta=0.0
% INFO    : Bus 63037	: V=0.9781554, theta=29.430107 -> V=1.0, theta=0.0
% INFO    : Bus 63038	: V=0.9977418, theta=26.592202 -> V=1.0, theta=0.0
% INFO    : Bus 63039	: V=1.0029149, theta=23.497711 -> V=1.0, theta=0.0
% INFO    : Bus 63040	: V=1.0147704, theta=26.977642 -> V=1.0, theta=0.0
% INFO    : Bus 63041	: V=0.9818367, theta=15.623607 -> V=1.0, theta=0.0
% INFO    : Bus 63042	: V=0.9783385, theta=14.714499 -> V=1.0, theta=0.0
% INFO    : Bus 63043	: V=0.9701004, theta=14.492259 -> V=1.0, theta=0.0
% INFO    : Bus 63044	: V=1.0039233, theta=41.654446 -> V=1.0, theta=0.0
% INFO    : Bus 63045	: V=1.0026896, theta=39.626972 -> V=1.0, theta=0.0
% INFO    : Bus 63046	: V=1.0028364, theta=37.626165 -> V=1.0, theta=0.0
% INFO    : Bus 63047	: V=1.0092119, theta=23.415574 -> V=1.0, theta=0.0
% INFO    : Bus 63048	: V=1.0169487, theta=24.479316 -> V=1.0, theta=0.0
% INFO    : Bus 63049	: V=0.9888881, theta=20.040829 -> V=1.0, theta=0.0
% INFO    : Bus 63050	: V=1.0194396, theta=26.50905 -> V=1.0, theta=0.0
% INFO    : Bus 63051	: V=1.0020024, theta=21.595707 -> V=1.0, theta=0.0
% INFO    : Bus 63052	: V=0.99642, theta=18.601413 -> V=1.0, theta=0.0
% INFO    : Bus 63053	: V=0.9960526, theta=18.463543 -> V=1.0, theta=0.0
% INFO    : Bus 63054	: V=0.9969642, theta=18.756482 -> V=1.0, theta=0.0
% INFO    : Bus 63055	: V=1.0066688, theta=20.610813 -> V=1.0, theta=0.0
% INFO    : Bus 63056	: V=1.0099822, theta=21.118893 -> V=1.0, theta=0.0
% INFO    : Bus 63057	: V=0.9960366, theta=18.169561 -> V=1.0, theta=0.0
% INFO    : Bus 63058	: V=1.0017909, theta=19.782129 -> V=1.0, theta=0.0
% INFO    : Bus 63059	: V=0.9960476, theta=17.832137 -> V=1.0, theta=0.0
% INFO    : Bus 63060	: V=0.9966922, theta=18.314783 -> V=1.0, theta=0.0
% INFO    : Bus 63061	: V=0.9886669, theta=17.202546 -> V=1.0, theta=0.0
% INFO    : Bus 63062	: V=0.9977135, theta=18.984933 -> V=1.0, theta=0.0
% INFO    : Bus 63063	: V=0.9961595, theta=18.654486 -> V=1.0, theta=0.0
% INFO    : Bus 63064	: V=0.9970582, theta=18.561932 -> V=1.0, theta=0.0
% INFO    : Bus 63065	: V=0.9841179, theta=-10.288556 -> V=1.0, theta=0.0
% INFO    : Bus 63066	: V=0.9838684, theta=-10.314267 -> V=1.0, theta=0.0
% INFO    : Bus 63067	: V=0.9827595, theta=-10.307592 -> V=1.0, theta=0.0
% INFO    : Bus 63068	: V=0.9827473, theta=-10.321452 -> V=1.0, theta=0.0
% INFO    : Bus 63069	: V=0.9818673, theta=-10.451223 -> V=1.0, theta=0.0
% INFO    : Bus 63070	: V=0.991734, theta=-8.823498 -> V=1.0, theta=0.0
% INFO    : Bus 63071	: V=0.9828381, theta=-10.392582 -> V=1.0, theta=0.0
% INFO    : Bus 63072	: V=0.9836238, theta=-10.275534 -> V=1.0, theta=0.0
% INFO    : Bus 63073	: V=0.9915199, theta=-8.882627 -> V=1.0, theta=0.0
% INFO    : Bus 63074	: V=0.9851735, theta=-10.169487 -> V=1.0, theta=0.0
% INFO    : Bus 63075	: V=0.9836963, theta=-10.307595 -> V=1.0, theta=0.0
% INFO    : Bus 63076	: V=0.9843339, theta=-10.267868 -> V=1.0, theta=0.0
% INFO    : Bus 63077	: V=0.9832675, theta=-10.266092 -> V=1.0, theta=0.0
% INFO    : Bus 63078	: V=0.9894231, theta=-9.306284 -> V=1.0, theta=0.0
% INFO    : Bus 63079	: V=0.9804875, theta=-10.529013 -> V=1.0, theta=0.0
% INFO    : Bus 63080	: V=0.9805716, theta=-10.541902 -> V=1.0, theta=0.0
% INFO    : Bus 63081	: V=0.9808042, theta=-10.548137 -> V=1.0, theta=0.0
% INFO    : Bus 63082	: V=0.9816808, theta=-10.498382 -> V=1.0, theta=0.0
% INFO    : Bus 63083	: V=0.9779239, theta=-10.771585 -> V=1.0, theta=0.0
% INFO    : Bus 63084	: V=0.9803049, theta=-10.597711 -> V=1.0, theta=0.0
% INFO    : Bus 63085	: V=0.9816826, theta=-10.498475 -> V=1.0, theta=0.0
% INFO    : Bus 63086	: V=0.993145, theta=-8.697089 -> V=1.0, theta=0.0
% INFO    : Bus 63087	: V=0.994732, theta=-8.532566 -> V=1.0, theta=0.0
% INFO    : Bus 63088	: V=1.01, theta=-6.349184 -> V=1.0, theta=0.0
% INFO    : Bus 63089	: V=0.9973852, theta=-8.244845 -> V=1.0, theta=0.0
% INFO    : Bus 63090	: V=0.9922751, theta=-8.968779 -> V=1.0, theta=0.0
% INFO    : Bus 63091	: V=0.9931041, theta=-8.691825 -> V=1.0, theta=0.0
% INFO    : Bus 63092	: V=0.9952282, theta=-8.448408 -> V=1.0, theta=0.0
% INFO    : Bus 63093	: V=0.9857605, theta=-10.118106 -> V=1.0, theta=0.0
% INFO    : Bus 63094	: V=0.9849657, theta=-10.13861 -> V=1.0, theta=0.0
% INFO    : Bus 63095	: V=0.9864053, theta=-9.783075 -> V=1.0, theta=0.0
% INFO    : Bus 63096	: V=0.9868519, theta=-9.724849 -> V=1.0, theta=0.0
% INFO    : Bus 63097	: V=0.9981677, theta=-7.756535 -> V=1.0, theta=0.0
% INFO    : Bus 63098	: V=0.9779219, theta=-10.742417 -> V=1.0, theta=0.0
% INFO    : Bus 63099	: V=0.9789833, theta=-10.631052 -> V=1.0, theta=0.0
% INFO    : Bus 63100	: V=0.9796649, theta=-10.613686 -> V=1.0, theta=0.0
% INFO    : Bus 63101	: V=0.976734, theta=-10.776605 -> V=1.0, theta=0.0
% INFO    : Bus 63102	: V=0.9770631, theta=-10.825095 -> V=1.0, theta=0.0
% INFO    : Bus 63103	: V=0.9771677, theta=-10.771266 -> V=1.0, theta=0.0
% INFO    : Bus 63104	: V=0.9787165, theta=-10.707448 -> V=1.0, theta=0.0
% INFO    : Bus 63105	: V=0.978879, theta=-10.698653 -> V=1.0, theta=0.0
% INFO    : Bus 63106	: V=0.9793148, theta=-10.678077 -> V=1.0, theta=0.0
% INFO    : Bus 63107	: V=0.9802113, theta=-10.660676 -> V=1.0, theta=0.0
% INFO    : Bus 63108	: V=0.9784237, theta=-10.70769 -> V=1.0, theta=0.0
% INFO    : Bus 63109	: V=0.9787997, theta=-10.720709 -> V=1.0, theta=0.0
% INFO    : Bus 63110	: V=0.9790153, theta=-10.709418 -> V=1.0, theta=0.0
% INFO    : Bus 63111	: V=0.9804936, theta=-10.57801 -> V=1.0, theta=0.0
% INFO    : Bus 63112	: V=0.9794193, theta=-10.645404 -> V=1.0, theta=0.0
% INFO    : Bus 63113	: V=0.9787057, theta=-10.673358 -> V=1.0, theta=0.0
% INFO    : Bus 63114	: V=0.9903865, theta=-8.882443 -> V=1.0, theta=0.0
% INFO    : Bus 63115	: V=0.9802633, theta=-10.602627 -> V=1.0, theta=0.0
% INFO    : Bus 63116	: V=0.9823239, theta=-10.455237 -> V=1.0, theta=0.0
% INFO    : Bus 63117	: V=0.9844879, theta=-10.143388 -> V=1.0, theta=0.0
% INFO    : Bus 63118	: V=0.9903779, theta=-8.891714 -> V=1.0, theta=0.0
% INFO    : Bus 63119	: V=0.9826373, theta=-10.398463 -> V=1.0, theta=0.0
% INFO    : Bus 63120	: V=0.983546, theta=-10.351592 -> V=1.0, theta=0.0
% INFO    : Bus 63121	: V=0.9932135, theta=-8.62538 -> V=1.0, theta=0.0
% INFO    : Bus 63122	: V=0.9912413, theta=-8.807864 -> V=1.0, theta=0.0
% INFO    : Bus 63123	: V=0.9904325, theta=-9.440602 -> V=1.0, theta=0.0
% INFO    : Bus 63124	: V=0.9884621, theta=-9.650165 -> V=1.0, theta=0.0
% INFO    : Bus 63125	: V=0.9949005, theta=-8.143278 -> V=1.0, theta=0.0
% INFO    : Bus 63126	: V=0.9978171, theta=-8.036283 -> V=1.0, theta=0.0
% INFO    : Bus 63127	: V=0.9916586, theta=-9.169761 -> V=1.0, theta=0.0
% INFO    : Bus 63128	: V=0.9912157, theta=-9.222495 -> V=1.0, theta=0.0
% INFO    : Bus 63129	: V=0.9956003, theta=-8.777355 -> V=1.0, theta=0.0
% INFO    : Bus 63130	: V=0.9949998, theta=-8.790664 -> V=1.0, theta=0.0
% INFO    : Bus 63131	: V=0.995706, theta=-8.371245 -> V=1.0, theta=0.0
% INFO    : Bus 63132	: V=0.9965105, theta=-8.24509 -> V=1.0, theta=0.0
% INFO    : Bus 63133	: V=0.9951612, theta=-8.741883 -> V=1.0, theta=0.0
% INFO    : Bus 63134	: V=0.9900358, theta=-9.336676 -> V=1.0, theta=0.0
% INFO    : Bus 63135	: V=0.9897846, theta=-9.405382 -> V=1.0, theta=0.0
% INFO    : Bus 63136	: V=0.9859986, theta=-9.925215 -> V=1.0, theta=0.0
% INFO    : Bus 63137	: V=0.9835083, theta=-10.184836 -> V=1.0, theta=0.0
% INFO    : Bus 63138	: V=0.9897301, theta=-8.750304 -> V=1.0, theta=0.0
% INFO    : Bus 63139	: V=0.9884934, theta=-8.879233 -> V=1.0, theta=0.0
% INFO    : Bus 63140	: V=0.9754554, theta=-10.899696 -> V=1.0, theta=0.0
% INFO    : Bus 63141	: V=0.9809313, theta=-10.307338 -> V=1.0, theta=0.0
% INFO    : Bus 63142	: V=0.9847199, theta=-10.041101 -> V=1.0, theta=0.0
% INFO    : Bus 63143	: V=0.9796895, theta=-10.578192 -> V=1.0, theta=0.0
% INFO    : Bus 63144	: V=0.979229, theta=-10.570272 -> V=1.0, theta=0.0
% INFO    : Bus 63145	: V=0.9803228, theta=-10.531725 -> V=1.0, theta=0.0
% INFO    : Bus 63146	: V=0.9852118, theta=-9.982956 -> V=1.0, theta=0.0
% INFO    : Bus 63147	: V=0.9847117, theta=-9.997475 -> V=1.0, theta=0.0
% INFO    : Bus 63148	: V=0.9818848, theta=-10.212281 -> V=1.0, theta=0.0
% INFO    : Bus 63149	: V=0.9814894, theta=-10.224425 -> V=1.0, theta=0.0
% INFO    : Bus 63150	: V=0.9842205, theta=-10.056157 -> V=1.0, theta=0.0
% INFO    : Bus 63151	: V=0.9843357, theta=-10.057898 -> V=1.0, theta=0.0
% INFO    : Bus 63152	: V=0.9796699, theta=-10.457232 -> V=1.0, theta=0.0
% INFO    : Bus 63153	: V=0.9830193, theta=-10.027728 -> V=1.0, theta=0.0
% INFO    : Bus 63154	: V=0.9882624, theta=-8.893617 -> V=1.0, theta=0.0
% INFO    : Bus 63155	: V=0.9817149, theta=-10.084158 -> V=1.0, theta=0.0
% INFO    : Bus 63156	: V=0.979208, theta=-10.600385 -> V=1.0, theta=0.0
% INFO    : Bus 63157	: V=0.9785718, theta=-10.618386 -> V=1.0, theta=0.0
% INFO    : Bus 63158	: V=0.981737, theta=-10.137363 -> V=1.0, theta=0.0
% INFO    : Bus 63159	: V=0.9826176, theta=-10.204478 -> V=1.0, theta=0.0
% INFO    : Bus 63160	: V=0.9786916, theta=-10.214212 -> V=1.0, theta=0.0
% INFO    : Bus 63161	: V=0.9774745, theta=-10.351944 -> V=1.0, theta=0.0
% INFO    : Bus 63162	: V=0.9704669, theta=-10.582892 -> V=1.0, theta=0.0
% INFO    : Bus 63163	: V=0.9741312, theta=-10.943871 -> V=1.0, theta=0.0
% INFO    : Bus 63164	: V=0.9781238, theta=-10.227684 -> V=1.0, theta=0.0
% INFO    : Bus 63165	: V=0.9806309, theta=-10.168679 -> V=1.0, theta=0.0
% INFO    : Bus 63166	: V=0.9812559, theta=-10.228722 -> V=1.0, theta=0.0
% INFO    : Bus 63167	: V=0.9804064, theta=-10.261758 -> V=1.0, theta=0.0
% INFO    : Bus 63168	: V=0.9824808, theta=-10.209256 -> V=1.0, theta=0.0
% INFO    : Bus 63169	: V=0.9917313, theta=-6.135212 -> V=1.0, theta=0.0
% INFO    : Bus 63170	: V=0.9876795, theta=-8.47772 -> V=1.0, theta=0.0
% INFO    : Bus 63171	: V=0.9889812, theta=-8.744365 -> V=1.0, theta=0.0
% INFO    : Bus 63172	: V=0.992146, theta=-7.146819 -> V=1.0, theta=0.0
% INFO    : Bus 63173	: V=0.9887111, theta=-8.44507 -> V=1.0, theta=0.0
% INFO    : Bus 63174	: V=0.9878947, theta=-8.483133 -> V=1.0, theta=0.0
% INFO    : Bus 63175	: V=0.9811747, theta=-10.436349 -> V=1.0, theta=0.0
% INFO    : Bus 63176	: V=0.9902506, theta=-8.824791 -> V=1.0, theta=0.0
% INFO    : Bus 63177	: V=0.9812571, theta=-10.297799 -> V=1.0, theta=0.0
% INFO    : Bus 63178	: V=0.9820096, theta=-10.213502 -> V=1.0, theta=0.0
% INFO    : Bus 63179	: V=0.9801138, theta=-10.443529 -> V=1.0, theta=0.0
% INFO    : Bus 63180	: V=0.9796646, theta=-10.454893 -> V=1.0, theta=0.0
% INFO    : Bus 63181	: V=0.9950148, theta=-7.343567 -> V=1.0, theta=0.0
% INFO    : Bus 63182	: V=0.98792, theta=-8.504113 -> V=1.0, theta=0.0
% INFO    : Bus 63183	: V=0.9676463, theta=-8.777869 -> V=1.0, theta=0.0
% INFO    : Bus 63184	: V=0.9734048, theta=-7.807298 -> V=1.0, theta=0.0
% INFO    : Bus 63185	: V=0.9983316, theta=-8.56941 -> V=1.0, theta=0.0
% INFO    : Bus 63186	: V=1.0021336, theta=-8.085642 -> V=1.0, theta=0.0
% INFO    : Bus 63187	: V=1.0010532, theta=-7.472311 -> V=1.0, theta=0.0
% INFO    : Bus 63188	: V=0.9964804, theta=-7.88726 -> V=1.0, theta=0.0
% INFO    : Bus 63189	: V=1.0033079, theta=-7.625506 -> V=1.0, theta=0.0
% INFO    : Bus 63190	: V=1.0004672, theta=-8.126067 -> V=1.0, theta=0.0
% INFO    : Bus 63191	: V=1.0011785, theta=-8.332793 -> V=1.0, theta=0.0
% INFO    : Bus 63192	: V=0.973502, theta=-9.062594 -> V=1.0, theta=0.0
% INFO    : Bus 63193	: V=0.9784161, theta=-8.543786 -> V=1.0, theta=0.0
% INFO    : Bus 63194	: V=0.9958769, theta=-8.704767 -> V=1.0, theta=0.0
% INFO    : Bus 63195	: V=0.982425, theta=-8.97514 -> V=1.0, theta=0.0
% INFO    : Bus 63196	: V=0.9837322, theta=-9.904016 -> V=1.0, theta=0.0
% INFO    : Bus 63197	: V=0.9829951, theta=-10.042933 -> V=1.0, theta=0.0
% INFO    : Bus 63198	: V=0.9848243, theta=-9.869623 -> V=1.0, theta=0.0
% INFO    : Bus 63199	: V=0.9799811, theta=-9.871884 -> V=1.0, theta=0.0
% INFO    : Bus 63200	: V=0.9599023, theta=-9.689589 -> V=1.0, theta=0.0
% INFO    : Bus 63201	: V=0.987196, theta=-8.516431 -> V=1.0, theta=0.0
% INFO    : Bus 63202	: V=0.9802808, theta=-10.149966 -> V=1.0, theta=0.0
% INFO    : Bus 63203	: V=0.981771, theta=-10.105757 -> V=1.0, theta=0.0
% INFO    : Bus 63204	: V=0.9830248, theta=-10.004775 -> V=1.0, theta=0.0
% INFO    : Bus 63205	: V=0.9927875, theta=-8.183789 -> V=1.0, theta=0.0
% INFO    : Bus 63206	: V=0.9795041, theta=-8.507823 -> V=1.0, theta=0.0
% INFO    : Bus 63207	: V=0.976378, theta=-8.935932 -> V=1.0, theta=0.0
% INFO    : Bus 63208	: V=0.9902908, theta=-8.346973 -> V=1.0, theta=0.0
% INFO    : Bus 63209	: V=0.9871927, theta=-8.874847 -> V=1.0, theta=0.0
% INFO    : Bus 63210	: V=0.9785662, theta=-8.85545 -> V=1.0, theta=0.0
% INFO    : Bus 63211	: V=0.9909779, theta=-8.66624 -> V=1.0, theta=0.0
% INFO    : Bus 63212	: V=0.9822292, theta=-8.980102 -> V=1.0, theta=0.0
% INFO    : Bus 63213	: V=0.9877085, theta=-8.491151 -> V=1.0, theta=0.0
% INFO    : Bus 63214	: V=0.9835166, theta=-8.980267 -> V=1.0, theta=0.0
% INFO    : Bus 63215	: V=0.9806776, theta=-10.164366 -> V=1.0, theta=0.0
% INFO    : Bus 63216	: V=0.9741142, theta=-10.235766 -> V=1.0, theta=0.0
% INFO    : Bus 63217	: V=0.9778868, theta=-10.232521 -> V=1.0, theta=0.0
% INFO    : Bus 63218	: V=0.9835933, theta=-10.235719 -> V=1.0, theta=0.0
% INFO    : Bus 63219	: V=0.9824321, theta=-10.27115 -> V=1.0, theta=0.0
% INFO    : Bus 63220	: V=0.9836437, theta=-10.073984 -> V=1.0, theta=0.0
% INFO    : Bus 63221	: V=0.982066, theta=-10.298994 -> V=1.0, theta=0.0
% INFO    : Bus 63222	: V=0.9825808, theta=-10.299089 -> V=1.0, theta=0.0
% INFO    : Bus 63223	: V=0.9827375, theta=-10.360345 -> V=1.0, theta=0.0
% INFO    : Bus 63224	: V=0.9862712, theta=-9.471383 -> V=1.0, theta=0.0
% INFO    : Bus 63225	: V=1.0066485, theta=-6.02637 -> V=1.0, theta=0.0
% INFO    : Bus 63226	: V=0.9775964, theta=-10.087271 -> V=1.0, theta=0.0
% INFO    : Bus 63227	: V=0.9779254, theta=-10.277913 -> V=1.0, theta=0.0
% INFO    : Bus 63228	: V=0.997041, theta=-7.433358 -> V=1.0, theta=0.0
% INFO    : Bus 63229	: V=0.9864876, theta=-9.301741 -> V=1.0, theta=0.0
% INFO    : Bus 63230	: V=0.9988228, theta=-5.70343 -> V=1.0, theta=0.0
% INFO    : Bus 63231	: V=0.9935342, theta=-8.112888 -> V=1.0, theta=0.0
% INFO    : Bus 63232	: V=0.9969571, theta=-7.652109 -> V=1.0, theta=0.0
% INFO    : Bus 63233	: V=0.9895379, theta=-7.819998 -> V=1.0, theta=0.0
% INFO    : Bus 63234	: V=0.9959022, theta=-7.749672 -> V=1.0, theta=0.0
% INFO    : Bus 63235	: V=1.0037382, theta=-6.588325 -> V=1.0, theta=0.0
% INFO    : Bus 63236	: V=1.01, theta=-5.257965 -> V=1.0, theta=0.0
% INFO    : Bus 63237	: V=0.989062, theta=-9.194805 -> V=1.0, theta=0.0
% INFO    : Bus 63238	: V=0.9835891, theta=-10.067357 -> V=1.0, theta=0.0
% INFO    : Bus 63239	: V=0.9889016, theta=-9.079327 -> V=1.0, theta=0.0
% INFO    : Bus 63240	: V=0.9811169, theta=-10.478831 -> V=1.0, theta=0.0
% INFO    : Bus 63241	: V=0.9797917, theta=-10.614755 -> V=1.0, theta=0.0
% INFO    : Bus 63242	: V=0.9789947, theta=-10.672033 -> V=1.0, theta=0.0
% INFO    : Bus 63243	: V=0.983, theta=-10.130283 -> V=1.0, theta=0.0
% INFO    : Bus 63244	: V=0.9822992, theta=-10.148069 -> V=1.0, theta=0.0
% INFO    : Bus 63245	: V=0.9891924, theta=-9.007924 -> V=1.0, theta=0.0
% INFO    : Bus 63246	: V=0.9903092, theta=-8.567321 -> V=1.0, theta=0.0
% INFO    : Bus 63247	: V=0.9829826, theta=-9.958507 -> V=1.0, theta=0.0
% INFO    : Bus 63248	: V=0.9836473, theta=-9.945654 -> V=1.0, theta=0.0
% INFO    : Bus 63249	: V=0.9817617, theta=-10.229837 -> V=1.0, theta=0.0
% INFO    : Bus 63250	: V=0.9827326, theta=-10.131677 -> V=1.0, theta=0.0
% INFO    : Bus 63251	: V=0.9813559, theta=-10.354175 -> V=1.0, theta=0.0
% INFO    : Bus 63252	: V=0.9807937, theta=-9.788552 -> V=1.0, theta=0.0
% INFO    : Bus 63253	: V=0.980392, theta=-9.971557 -> V=1.0, theta=0.0
% INFO    : Bus 63254	: V=0.9881446, theta=-8.869412 -> V=1.0, theta=0.0
% INFO    : Bus 63255	: V=0.9808965, theta=-9.958428 -> V=1.0, theta=0.0
% INFO    : Bus 63256	: V=0.9889655, theta=-8.685579 -> V=1.0, theta=0.0
% INFO    : Bus 63257	: V=0.9890514, theta=-9.009445 -> V=1.0, theta=0.0
% INFO    : Bus 63258	: V=0.9847692, theta=-9.637321 -> V=1.0, theta=0.0
% INFO    : Bus 63259	: V=0.989105, theta=-8.967878 -> V=1.0, theta=0.0
% INFO    : Bus 63260	: V=0.9896829, theta=-8.890406 -> V=1.0, theta=0.0
% INFO    : Bus 63261	: V=0.986667, theta=-9.463273 -> V=1.0, theta=0.0
% INFO    : Bus 63262	: V=0.9896082, theta=-8.49402 -> V=1.0, theta=0.0
% INFO    : Bus 63263	: V=0.9853513, theta=-9.218719 -> V=1.0, theta=0.0
% INFO    : Bus 63264	: V=0.9839043, theta=-9.394825 -> V=1.0, theta=0.0
% INFO    : Bus 63265	: V=0.9818452, theta=-9.659395 -> V=1.0, theta=0.0
% INFO    : Bus 63266	: V=0.9861313, theta=-9.119496 -> V=1.0, theta=0.0
% INFO    : Bus 63267	: V=0.9800111, theta=-9.682036 -> V=1.0, theta=0.0
% INFO    : Bus 63268	: V=0.9793495, theta=-9.636625 -> V=1.0, theta=0.0
% INFO    : Bus 63269	: V=0.9898802, theta=-7.511538 -> V=1.0, theta=0.0
% INFO    : Bus 63270	: V=0.9906747, theta=-8.146298 -> V=1.0, theta=0.0
% INFO    : Bus 63271	: V=0.9750276, theta=-9.543721 -> V=1.0, theta=0.0
% INFO    : Bus 63272	: V=0.9781301, theta=-9.675278 -> V=1.0, theta=0.0
% INFO    : Bus 63273	: V=0.9843264, theta=-9.30661 -> V=1.0, theta=0.0
% INFO    : Bus 63274	: V=0.9741292, theta=-9.401869 -> V=1.0, theta=0.0
% INFO    : Bus 63275	: V=0.989683, theta=-8.5671 -> V=1.0, theta=0.0
% INFO    : Bus 63276	: V=0.9928833, theta=-8.221404 -> V=1.0, theta=0.0
% INFO    : Bus 63277	: V=0.9917565, theta=-8.389784 -> V=1.0, theta=0.0
% INFO    : Bus 63278	: V=0.990772, theta=-8.503025 -> V=1.0, theta=0.0
% INFO    : Bus 63279	: V=0.976321, theta=-10.874138 -> V=1.0, theta=0.0
% INFO    : Bus 63280	: V=0.9755491, theta=-10.801703 -> V=1.0, theta=0.0
% INFO    : Bus 63281	: V=0.9751471, theta=-10.860061 -> V=1.0, theta=0.0
% INFO    : Bus 63282	: V=0.9789618, theta=-10.318686 -> V=1.0, theta=0.0
% INFO    : Bus 63283	: V=0.977456, theta=-10.583021 -> V=1.0, theta=0.0
% INFO    : Bus 63284	: V=0.9643055, theta=-9.796932 -> V=1.0, theta=0.0
% INFO    : Bus 63285	: V=0.9614327, theta=-10.398751 -> V=1.0, theta=0.0
% INFO    : Bus 63286	: V=0.9744237, theta=-10.879255 -> V=1.0, theta=0.0
% INFO    : Bus 63287	: V=0.9745339, theta=-10.8946 -> V=1.0, theta=0.0
% INFO    : Bus 63288	: V=0.9718725, theta=-10.993986 -> V=1.0, theta=0.0
% INFO    : Bus 63289	: V=0.9754655, theta=-10.902955 -> V=1.0, theta=0.0
% INFO    : Bus 63290	: V=0.9768308, theta=-10.821348 -> V=1.0, theta=0.0
% INFO    : Bus 63291	: V=0.9753761, theta=-10.909742 -> V=1.0, theta=0.0
% INFO    : Bus 63292	: V=0.9740651, theta=-10.949297 -> V=1.0, theta=0.0
% INFO    : Bus 63293	: V=0.9760185, theta=-10.882713 -> V=1.0, theta=0.0
% INFO    : Bus 63294	: V=0.9815329, theta=-10.353857 -> V=1.0, theta=0.0
% INFO    : Bus 63295	: V=0.9772712, theta=-10.679618 -> V=1.0, theta=0.0
% INFO    : Bus 63296	: V=1.02, theta=-4.375833 -> V=1.0, theta=0.0
% INFO    : Bus 63297	: V=1.03, theta=-2.43907 -> V=1.0, theta=0.0
% INFO    : Bus 63298	: V=1.0015002, theta=-7.411228 -> V=1.0, theta=0.0
% INFO    : Bus 63299	: V=1.0191923, theta=7.042674 -> V=1.0, theta=0.0
% INFO    : Bus 63300	: V=0.9799348, theta=-10.14531 -> V=1.0, theta=0.0
% INFO    : Bus 63301	: V=0.9773572, theta=-2.113825 -> V=1.0, theta=0.0
% INFO    : Bus 63302	: V=1.0066293, theta=6.019325 -> V=1.0, theta=0.0
% INFO    : Bus 63303	: V=0.9654139, theta=-9.191839 -> V=1.0, theta=0.0
% INFO    : Bus 63304	: V=0.9775457, theta=-10.117593 -> V=1.0, theta=0.0
% INFO    : Bus 63305	: V=0.9771749, theta=-10.20946 -> V=1.0, theta=0.0
% INFO    : Bus 63306	: V=0.988437, theta=-0.06714 -> V=1.0, theta=0.0
% INFO    : Bus 63307	: V=0.9858556, theta=-4.401384 -> V=1.0, theta=0.0
% INFO    : Bus 63308	: V=0.9845724, theta=-4.178596 -> V=1.0, theta=0.0
% INFO    : Bus 63309	: V=0.9869624, theta=-4.098354 -> V=1.0, theta=0.0
% INFO    : Bus 63310	: V=0.9812231, theta=-3.902407 -> V=1.0, theta=0.0
% INFO    : Bus 63311	: V=0.9874437, theta=-3.114585 -> V=1.0, theta=0.0
% INFO    : Bus 63312	: V=0.989191, theta=-3.912488 -> V=1.0, theta=0.0
% INFO    : Bus 63313	: V=0.9911979, theta=-3.475511 -> V=1.0, theta=0.0
% INFO    : Bus 63314	: V=0.9905583, theta=-3.185315 -> V=1.0, theta=0.0
% INFO    : Bus 63315	: V=0.9889102, theta=-3.075605 -> V=1.0, theta=0.0
% INFO    : Bus 63316	: V=0.9972896, theta=-1.717433 -> V=1.0, theta=0.0
% INFO    : Bus 63317	: V=0.9962271, theta=-2.186133 -> V=1.0, theta=0.0
% INFO    : Bus 63318	: V=0.9892089, theta=-3.726686 -> V=1.0, theta=0.0
% INFO    : Bus 63319	: V=0.987532, theta=-4.685658 -> V=1.0, theta=0.0
% INFO    : Bus 63320	: V=0.9878167, theta=-4.728563 -> V=1.0, theta=0.0
% INFO    : Bus 63321	: V=0.9980313, theta=-3.860816 -> V=1.0, theta=0.0
% INFO    : Bus 63322	: V=0.9886775, theta=-4.405904 -> V=1.0, theta=0.0
% INFO    : Bus 63323	: V=0.9902159, theta=-3.81142 -> V=1.0, theta=0.0
% INFO    : Bus 63324	: V=0.9874016, theta=-4.760239 -> V=1.0, theta=0.0
% INFO    : Bus 63325	: V=0.9866871, theta=-4.867674 -> V=1.0, theta=0.0
% INFO    : Bus 63326	: V=0.9863878, theta=-4.812786 -> V=1.0, theta=0.0
% INFO    : Bus 63327	: V=0.9863187, theta=-4.63953 -> V=1.0, theta=0.0
% INFO    : Bus 63328	: V=0.9762552, theta=-5.295863 -> V=1.0, theta=0.0
% INFO    : Bus 63329	: V=0.9853997, theta=-4.907178 -> V=1.0, theta=0.0
% INFO    : Bus 63330	: V=0.9849899, theta=-4.784346 -> V=1.0, theta=0.0
% INFO    : Bus 63331	: V=0.9808652, theta=-4.960118 -> V=1.0, theta=0.0
% INFO    : Bus 63332	: V=0.9832457, theta=0.038373 -> V=1.0, theta=0.0
% INFO    : Bus 63333	: V=0.9658027, theta=-9.578345 -> V=1.0, theta=0.0
% INFO    : Bus 63334	: V=0.9660523, theta=-9.237803 -> V=1.0, theta=0.0
% INFO    : Bus 63335	: V=0.9612069, theta=-9.695569 -> V=1.0, theta=0.0
% INFO    : Bus 63336	: V=0.9918293, theta=-2.559969 -> V=1.0, theta=0.0
% INFO    : Bus 63337	: V=0.9955495, theta=-4.33113 -> V=1.0, theta=0.0
% INFO    : Bus 63338	: V=0.9799206, theta=-2.763547 -> V=1.0, theta=0.0
% INFO    : Bus 63339	: V=0.9891497, theta=-2.383444 -> V=1.0, theta=0.0
% INFO    : Bus 63340	: V=0.9927872, theta=-2.097171 -> V=1.0, theta=0.0
% INFO    : Bus 63341	: V=0.9993072, theta=-0.944227 -> V=1.0, theta=0.0
% INFO    : Bus 63342	: V=1.0066027, theta=0.514795 -> V=1.0, theta=0.0
% INFO    : Bus 63343	: V=1.009209, theta=0.797914 -> V=1.0, theta=0.0
% INFO    : Bus 63344	: V=1.0102077, theta=0.282833 -> V=1.0, theta=0.0
% INFO    : Bus 63345	: V=1.0066762, theta=0.075291 -> V=1.0, theta=0.0
% INFO    : Bus 63346	: V=1.0091423, theta=0.349082 -> V=1.0, theta=0.0
% INFO    : Bus 63347	: V=1.0092718, theta=0.184736 -> V=1.0, theta=0.0
% INFO    : Bus 63348	: V=1.0097679, theta=-0.030564 -> V=1.0, theta=0.0
% INFO    : Bus 63349	: V=1.0067726, theta=-0.456787 -> V=1.0, theta=0.0
% INFO    : Bus 63350	: V=1.0089312, theta=-0.108701 -> V=1.0, theta=0.0
% INFO    : Bus 63351	: V=1.0089196, theta=-0.223041 -> V=1.0, theta=0.0
% INFO    : Bus 63352	: V=1.008241, theta=-0.007985 -> V=1.0, theta=0.0
% INFO    : Bus 63353	: V=1.0070646, theta=-0.570416 -> V=1.0, theta=0.0
% INFO    : Bus 63354	: V=1.0081634, theta=-0.405222 -> V=1.0, theta=0.0
% INFO    : Bus 63355	: V=1.0089192, theta=0.065761 -> V=1.0, theta=0.0
% INFO    : Bus 63356	: V=1.0100046, theta=0.341816 -> V=1.0, theta=0.0
% INFO    : Bus 63357	: V=0.9983432, theta=1.110097 -> V=1.0, theta=0.0
% INFO    : Bus 63358	: V=0.9875255, theta=-1.924257 -> V=1.0, theta=0.0
% INFO    : Bus 63359	: V=0.9882605, theta=-1.905272 -> V=1.0, theta=0.0
% INFO    : Bus 63360	: V=0.9958872, theta=-0.102462 -> V=1.0, theta=0.0
% INFO    : Bus 63361	: V=0.986235, theta=-2.077768 -> V=1.0, theta=0.0
% INFO    : Bus 63362	: V=0.9867049, theta=-2.091965 -> V=1.0, theta=0.0
% INFO    : Bus 63363	: V=0.9880562, theta=-2.028484 -> V=1.0, theta=0.0
% INFO    : Bus 63364	: V=0.9864023, theta=-2.093199 -> V=1.0, theta=0.0
% INFO    : Bus 63365	: V=0.9856323, theta=-2.121106 -> V=1.0, theta=0.0
% INFO    : Bus 63366	: V=0.9836751, theta=-2.1697 -> V=1.0, theta=0.0
% INFO    : Bus 63367	: V=0.9870035, theta=-2.058009 -> V=1.0, theta=0.0
% INFO    : Bus 63368	: V=1.0037743, theta=-1.504037 -> V=1.0, theta=0.0
% INFO    : Bus 63369	: V=1.0072645, theta=-0.753977 -> V=1.0, theta=0.0
% INFO    : Bus 63370	: V=1.0069163, theta=-0.996905 -> V=1.0, theta=0.0
% INFO    : Bus 63371	: V=1.0068594, theta=-1.483298 -> V=1.0, theta=0.0
% INFO    : Bus 63372	: V=1.0027595, theta=-1.837567 -> V=1.0, theta=0.0
% INFO    : Bus 63373	: V=1.0009228, theta=-1.807841 -> V=1.0, theta=0.0
% INFO    : Bus 63374	: V=0.9995224, theta=-3.611175 -> V=1.0, theta=0.0
% INFO    : Bus 63375	: V=0.963123, theta=-5.855126 -> V=1.0, theta=0.0
% INFO    : Bus 63376	: V=0.9792935, theta=-1.196987 -> V=1.0, theta=0.0
% INFO    : Bus 63377	: V=0.960228, theta=-3.66359 -> V=1.0, theta=0.0
% INFO    : Bus 63378	: V=1.0054883, theta=-0.149143 -> V=1.0, theta=0.0
% INFO    : Bus 63379	: V=0.9845522, theta=-2.161866 -> V=1.0, theta=0.0
% INFO    : Bus 63380	: V=0.9872237, theta=-1.645058 -> V=1.0, theta=0.0
% INFO    : Bus 63381	: V=0.994884, theta=-4.132377 -> V=1.0, theta=0.0
% INFO    : Bus 63382	: V=0.9944641, theta=-7.339893 -> V=1.0, theta=0.0
% INFO    : Bus 63383	: V=1.0083947, theta=-5.505282 -> V=1.0, theta=0.0
% INFO    : Bus 63384	: V=1.0034262, theta=-4.217673 -> V=1.0, theta=0.0
% INFO    : Bus 63385	: V=0.9983601, theta=-6.896264 -> V=1.0, theta=0.0
% INFO    : Bus 63386	: V=1.0153236, theta=-4.319401 -> V=1.0, theta=0.0
% INFO    : Bus 63387	: V=1.0081392, theta=-4.85638 -> V=1.0, theta=0.0
% INFO    : Bus 63388	: V=1.0109811, theta=-4.883387 -> V=1.0, theta=0.0
% INFO    : Bus 63389	: V=1.0089863, theta=-4.950069 -> V=1.0, theta=0.0
% INFO    : Bus 63390	: V=1.0081689, theta=-4.992211 -> V=1.0, theta=0.0
% INFO    : Bus 63391	: V=0.9786891, theta=-7.781948 -> V=1.0, theta=0.0
% INFO    : Bus 63392	: V=0.9746274, theta=-9.647707 -> V=1.0, theta=0.0
% INFO    : Bus 63393	: V=0.9781162, theta=-8.282744 -> V=1.0, theta=0.0
% INFO    : Bus 63394	: V=0.9765541, theta=-9.283829 -> V=1.0, theta=0.0
% INFO    : Bus 63395	: V=0.9748702, theta=-8.779927 -> V=1.0, theta=0.0
% INFO    : Bus 63396	: V=0.9748232, theta=-8.749564 -> V=1.0, theta=0.0
% INFO    : Bus 63397	: V=0.978187, theta=-7.652413 -> V=1.0, theta=0.0
% INFO    : Bus 63398	: V=0.9823954, theta=-9.034624 -> V=1.0, theta=0.0
% INFO    : Bus 63399	: V=0.9814051, theta=-9.090575 -> V=1.0, theta=0.0
% INFO    : Bus 63400	: V=0.9783234, theta=-7.715036 -> V=1.0, theta=0.0
% INFO    : Bus 63401	: V=0.9804692, theta=-9.000366 -> V=1.0, theta=0.0
% INFO    : Bus 63402	: V=0.983396, theta=-8.963667 -> V=1.0, theta=0.0
% INFO    : Bus 63403	: V=0.9827747, theta=-9.055165 -> V=1.0, theta=0.0
% INFO    : Bus 63404	: V=0.980831, theta=-9.142152 -> V=1.0, theta=0.0
% INFO    : Bus 63405	: V=0.9777308, theta=-8.517387 -> V=1.0, theta=0.0
% INFO    : Bus 63406	: V=0.976004, theta=-8.5184 -> V=1.0, theta=0.0
% INFO    : Bus 63407	: V=0.9756675, theta=-8.669239 -> V=1.0, theta=0.0
% INFO    : Bus 63408	: V=0.9779703, theta=-7.755528 -> V=1.0, theta=0.0
% INFO    : Bus 63409	: V=0.978106, theta=-7.846787 -> V=1.0, theta=0.0
% INFO    : Bus 63410	: V=0.9791069, theta=-7.947978 -> V=1.0, theta=0.0
% INFO    : Bus 63411	: V=0.9786709, theta=-7.876206 -> V=1.0, theta=0.0
% INFO    : Bus 63412	: V=0.9798303, theta=-7.367923 -> V=1.0, theta=0.0
% INFO    : Bus 63413	: V=0.9852272, theta=-8.248591 -> V=1.0, theta=0.0
% INFO    : Bus 63414	: V=0.9922954, theta=-8.321107 -> V=1.0, theta=0.0
% INFO    : Bus 63415	: V=0.977224, theta=-6.285616 -> V=1.0, theta=0.0
% INFO    : Bus 63416	: V=0.9925494, theta=-4.071614 -> V=1.0, theta=0.0
% INFO    : Bus 63417	: V=0.9970701, theta=-4.489922 -> V=1.0, theta=0.0
% INFO    : Bus 63418	: V=0.9804327, theta=-4.576069 -> V=1.0, theta=0.0
% INFO    : Bus 63419	: V=0.9837422, theta=-4.651093 -> V=1.0, theta=0.0
% INFO    : Bus 63420	: V=0.9905595, theta=-8.477034 -> V=1.0, theta=0.0
% INFO    : Bus 63421	: V=0.9948147, theta=-7.534058 -> V=1.0, theta=0.0
% INFO    : Bus 63422	: V=0.9840311, theta=-3.877334 -> V=1.0, theta=0.0
% INFO    : Bus 63423	: V=0.9885116, theta=-4.05247 -> V=1.0, theta=0.0
% INFO    : Bus 63424	: V=0.9875809, theta=-2.447349 -> V=1.0, theta=0.0
% INFO    : Bus 63425	: V=0.9829364, theta=-2.424415 -> V=1.0, theta=0.0
% INFO    : Bus 63426	: V=0.9787179, theta=-3.202686 -> V=1.0, theta=0.0
% INFO    : Bus 63427	: V=0.9803111, theta=-6.765175 -> V=1.0, theta=0.0
% INFO    : Bus 63428	: V=0.9906228, theta=-6.63979 -> V=1.0, theta=0.0
% INFO    : Bus 63429	: V=0.9841617, theta=-4.213559 -> V=1.0, theta=0.0
% INFO    : Bus 63430	: V=0.9911386, theta=-6.29982 -> V=1.0, theta=0.0
% INFO    : Bus 63431	: V=0.988781, theta=-6.884203 -> V=1.0, theta=0.0
% INFO    : Bus 63432	: V=0.9859066, theta=-8.048361 -> V=1.0, theta=0.0
% INFO    : Bus 63433	: V=0.99999, theta=-19.970868 -> V=1.0, theta=0.0
% INFO    : Bus 63434	: V=1.0001997, theta=-20.031574 -> V=1.0, theta=0.0
% INFO    : Bus 63435	: V=0.9999187, theta=-20.125659 -> V=1.0, theta=0.0
% INFO    : Bus 63436	: V=1.0004194, theta=-20.068746 -> V=1.0, theta=0.0
% INFO    : Bus 63437	: V=1.003087, theta=-20.309017 -> V=1.0, theta=0.0
% INFO    : Bus 63438	: V=1.0022181, theta=-20.252558 -> V=1.0, theta=0.0
% INFO    : Bus 63439	: V=0.9997611, theta=-20.163311 -> V=1.0, theta=0.0
% INFO    : Bus 63440	: V=0.9987456, theta=-20.219914 -> V=1.0, theta=0.0
% INFO    : Bus 63441	: V=1.0015852, theta=-20.205127 -> V=1.0, theta=0.0
% INFO    : Bus 63442	: V=0.9981494, theta=-20.237296 -> V=1.0, theta=0.0
% INFO    : Bus 63443	: V=0.9998119, theta=-19.852669 -> V=1.0, theta=0.0
% INFO    : Bus 63444	: V=1.000663, theta=-19.886792 -> V=1.0, theta=0.0
% INFO    : Bus 63445	: V=0.998671, theta=-20.26743 -> V=1.0, theta=0.0
% INFO    : Bus 63446	: V=0.9991075, theta=-20.311595 -> V=1.0, theta=0.0
% INFO    : Bus 63447	: V=0.9997182, theta=-20.18556 -> V=1.0, theta=0.0
% INFO    : Bus 63448	: V=1.0006514, theta=-20.384846 -> V=1.0, theta=0.0
% INFO    : Bus 63449	: V=1.002484, theta=-19.937418 -> V=1.0, theta=0.0
% INFO    : Bus 63450	: V=0.9979588, theta=-20.267298 -> V=1.0, theta=0.0
% INFO    : Bus 63451	: V=0.999763, theta=-19.80598 -> V=1.0, theta=0.0
% INFO    : Bus 63452	: V=1.000363, theta=-19.84724 -> V=1.0, theta=0.0
% INFO    : Bus 63453	: V=1.0007945, theta=-19.876792 -> V=1.0, theta=0.0
% INFO    : Bus 63454	: V=1.0000732, theta=-19.801454 -> V=1.0, theta=0.0
% INFO    : Bus 63455	: V=0.9998104, theta=-19.72052 -> V=1.0, theta=0.0
% INFO    : Bus 63456	: V=0.9971079, theta=-19.794531 -> V=1.0, theta=0.0
% INFO    : Bus 63457	: V=0.9971772, theta=-19.741154 -> V=1.0, theta=0.0
% INFO    : Bus 63458	: V=0.9974405, theta=-19.515815 -> V=1.0, theta=0.0
% INFO    : Bus 63459	: V=0.9974424, theta=-19.944476 -> V=1.0, theta=0.0
% INFO    : Bus 63460	: V=0.9962531, theta=-20.178114 -> V=1.0, theta=0.0
% INFO    : Bus 63461	: V=0.9951882, theta=-20.185475 -> V=1.0, theta=0.0
% INFO    : Bus 63462	: V=1.017499, theta=-19.21053 -> V=1.0, theta=0.0
% INFO    : Bus 63463	: V=0.9984982, theta=-18.903552 -> V=1.0, theta=0.0
% INFO    : Bus 63464	: V=0.9984843, theta=-19.114005 -> V=1.0, theta=0.0
% INFO    : Bus 63465	: V=0.9984495, theta=-19.25432 -> V=1.0, theta=0.0
% INFO    : Bus 63466	: V=0.9980141, theta=-19.752572 -> V=1.0, theta=0.0
% INFO    : Bus 63467	: V=0.9980671, theta=-19.409901 -> V=1.0, theta=0.0
% INFO    : Bus 63468	: V=0.9964357, theta=-19.788622 -> V=1.0, theta=0.0
% INFO    : Bus 63469	: V=0.9955037, theta=-19.475103 -> V=1.0, theta=0.0
% INFO    : Bus 63470	: V=0.9947171, theta=-19.49389 -> V=1.0, theta=0.0
% INFO    : Bus 63471	: V=0.9970215, theta=-18.709339 -> V=1.0, theta=0.0
% INFO    : Bus 63472	: V=0.9942764, theta=-15.908924 -> V=1.0, theta=0.0
% INFO    : Bus 63473	: V=0.993296, theta=-11.822576 -> V=1.0, theta=0.0
% INFO    : Bus 63474	: V=0.9816192, theta=-23.565857 -> V=1.0, theta=0.0
% INFO    : Bus 63475	: V=0.9804779, theta=-23.594624 -> V=1.0, theta=0.0
% INFO    : Bus 63476	: V=0.9812841, theta=-23.529103 -> V=1.0, theta=0.0
% INFO    : Bus 63477	: V=0.9936547, theta=-21.188142 -> V=1.0, theta=0.0
% INFO    : Bus 63478	: V=0.9946204, theta=-21.153558 -> V=1.0, theta=0.0
% INFO    : Bus 63479	: V=0.9996996, theta=-20.132868 -> V=1.0, theta=0.0
% INFO    : Bus 63480	: V=0.9842699, theta=-23.346338 -> V=1.0, theta=0.0
% INFO    : Bus 63481	: V=0.9967741, theta=-19.803632 -> V=1.0, theta=0.0
% INFO    : Bus 63482	: V=0.986291, theta=-21.959169 -> V=1.0, theta=0.0
% INFO    : Bus 63483	: V=1.02, theta=0.480034 -> V=1.0, theta=0.0
% INFO    : Bus 63484	: V=0.9750594, theta=-13.465599 -> V=1.0, theta=0.0
% INFO    : Bus 63485	: V=0.9855977, theta=-21.996014 -> V=1.0, theta=0.0
% INFO    : Bus 63486	: V=0.9990101, theta=-19.61347 -> V=1.0, theta=0.0
% INFO    : Bus 63487	: V=0.9887474, theta=7.734827 -> V=1.0, theta=0.0
% INFO    : Bus 63488	: V=0.9889837, theta=7.841944 -> V=1.0, theta=0.0
% INFO    : Bus 63489	: V=0.9934378, theta=8.771755 -> V=1.0, theta=0.0
% INFO    : Bus 63490	: V=0.9884143, theta=7.819242 -> V=1.0, theta=0.0
% INFO    : Bus 63491	: V=0.9894143, theta=7.899835 -> V=1.0, theta=0.0
% INFO    : Bus 63492	: V=0.9980805, theta=9.521769 -> V=1.0, theta=0.0
% INFO    : Bus 63493	: V=0.9993466, theta=9.759026 -> V=1.0, theta=0.0
% INFO    : Bus 63494	: V=1.0200003, theta=15.32902 -> V=1.0, theta=0.0
% INFO    : Bus 63495	: V=1.0040353, theta=9.82818 -> V=1.0, theta=0.0
% INFO    : Bus 63496	: V=0.9970883, theta=10.301913 -> V=1.0, theta=0.0
% INFO    : Bus 63497	: V=0.9631327, theta=20.256028 -> V=1.0, theta=0.0
% INFO    : Bus 63498	: V=0.9857321, theta=8.874955 -> V=1.0, theta=0.0
% INFO    : Bus 63499	: V=0.986126, theta=8.977026 -> V=1.0, theta=0.0
% INFO    : Bus 63500	: V=0.9889665, theta=9.0572 -> V=1.0, theta=0.0
% INFO    : Bus 63501	: V=0.9940457, theta=10.116613 -> V=1.0, theta=0.0
% INFO    : Bus 63502	: V=1.007083, theta=11.589784 -> V=1.0, theta=0.0
% INFO    : Bus 63503	: V=0.9982378, theta=10.566102 -> V=1.0, theta=0.0
% INFO    : Bus 63504	: V=0.9944979, theta=10.55728 -> V=1.0, theta=0.0
% INFO    : Bus 63505	: V=0.9937835, theta=10.261506 -> V=1.0, theta=0.0
% INFO    : Bus 63506	: V=0.9933227, theta=9.969883 -> V=1.0, theta=0.0
% INFO    : Bus 63507	: V=0.9939056, theta=10.047717 -> V=1.0, theta=0.0
% INFO    : Bus 63508	: V=0.9944729, theta=10.165612 -> V=1.0, theta=0.0
% INFO    : Bus 63509	: V=1.0043638, theta=11.329162 -> V=1.0, theta=0.0
% INFO    : Bus 63510	: V=0.9969922, theta=10.100879 -> V=1.0, theta=0.0
% INFO    : Bus 63511	: V=0.9982662, theta=10.179829 -> V=1.0, theta=0.0
% INFO    : Bus 63512	: V=0.9967825, theta=10.060917 -> V=1.0, theta=0.0
% INFO    : Bus 63513	: V=0.9995924, theta=10.681948 -> V=1.0, theta=0.0
% INFO    : Bus 63514	: V=1.0109306, theta=12.377062 -> V=1.0, theta=0.0
% INFO    : Bus 63515	: V=0.9961073, theta=10.94548 -> V=1.0, theta=0.0
% INFO    : Bus 63516	: V=0.9978482, theta=11.018301 -> V=1.0, theta=0.0
% INFO    : Bus 63517	: V=0.9946795, theta=10.487442 -> V=1.0, theta=0.0
% INFO    : Bus 63518	: V=0.9927062, theta=10.276678 -> V=1.0, theta=0.0
% INFO    : Bus 63519	: V=0.9962387, theta=10.362766 -> V=1.0, theta=0.0
% INFO    : Bus 63520	: V=0.9955611, theta=10.284652 -> V=1.0, theta=0.0
% INFO    : Bus 63521	: V=0.9972656, theta=10.42333 -> V=1.0, theta=0.0
% INFO    : Bus 63522	: V=0.996553, theta=10.344186 -> V=1.0, theta=0.0
% INFO    : Bus 63523	: V=0.995244, theta=10.198108 -> V=1.0, theta=0.0
% INFO    : Bus 63524	: V=0.9957322, theta=10.081579 -> V=1.0, theta=0.0
% INFO    : Bus 63525	: V=0.9992061, theta=11.145764 -> V=1.0, theta=0.0
% INFO    : Bus 63526	: V=0.9992523, theta=11.154193 -> V=1.0, theta=0.0
% INFO    : Bus 63527	: V=0.9985824, theta=11.127821 -> V=1.0, theta=0.0
% INFO    : Bus 63528	: V=0.9999078, theta=11.18124 -> V=1.0, theta=0.0
% INFO    : Bus 63529	: V=0.9766864, theta=7.471934 -> V=1.0, theta=0.0
% INFO    : Bus 63530	: V=0.9792768, theta=7.659839 -> V=1.0, theta=0.0
% INFO    : Bus 63531	: V=0.9924826, theta=9.57044 -> V=1.0, theta=0.0
% INFO    : Bus 63532	: V=0.9851601, theta=8.035823 -> V=1.0, theta=0.0
% INFO    : Bus 63533	: V=0.9910815, theta=9.584875 -> V=1.0, theta=0.0
% INFO    : Bus 63534	: V=1.0100003, theta=11.83006 -> V=1.0, theta=0.0
% INFO    : Bus 63535	: V=0.9923849, theta=9.646285 -> V=1.0, theta=0.0
% INFO    : Bus 63536	: V=0.9925693, theta=9.639409 -> V=1.0, theta=0.0
% INFO    : Bus 63537	: V=0.9925182, theta=9.697418 -> V=1.0, theta=0.0
% INFO    : Bus 63538	: V=0.9928904, theta=9.897707 -> V=1.0, theta=0.0
% INFO    : Bus 63539	: V=0.9896113, theta=8.735168 -> V=1.0, theta=0.0
% INFO    : Bus 63540	: V=0.989994, theta=8.877615 -> V=1.0, theta=0.0
% INFO    : Bus 63541	: V=0.9922964, theta=9.880941 -> V=1.0, theta=0.0
% INFO    : Bus 63542	: V=0.9926404, theta=9.905145 -> V=1.0, theta=0.0
% INFO    : Bus 63543	: V=0.9930504, theta=9.864548 -> V=1.0, theta=0.0
% INFO    : Bus 63544	: V=0.9928493, theta=9.791721 -> V=1.0, theta=0.0
% INFO    : Bus 63545	: V=0.9851593, theta=8.849238 -> V=1.0, theta=0.0
% INFO    : Bus 63546	: V=0.9846242, theta=8.2863 -> V=1.0, theta=0.0
% INFO    : Bus 63547	: V=0.9851499, theta=8.314097 -> V=1.0, theta=0.0
% INFO    : Bus 63548	: V=0.9851668, theta=8.318303 -> V=1.0, theta=0.0
% INFO    : Bus 63549	: V=0.9846535, theta=8.3025 -> V=1.0, theta=0.0
% INFO    : Bus 63550	: V=0.9843005, theta=8.286365 -> V=1.0, theta=0.0
% INFO    : Bus 63551	: V=0.9853067, theta=8.863541 -> V=1.0, theta=0.0
% INFO    : Bus 63552	: V=0.9876778, theta=8.890447 -> V=1.0, theta=0.0
% INFO    : Bus 63553	: V=0.9874233, theta=8.926247 -> V=1.0, theta=0.0
% INFO    : Bus 63554	: V=0.9876948, theta=8.955563 -> V=1.0, theta=0.0
% INFO    : Bus 63555	: V=0.9857064, theta=8.955143 -> V=1.0, theta=0.0
% INFO    : Bus 63556	: V=0.9853756, theta=8.896731 -> V=1.0, theta=0.0
% INFO    : Bus 63557	: V=0.9853653, theta=8.9365 -> V=1.0, theta=0.0
% INFO    : Bus 63558	: V=0.9865987, theta=9.113895 -> V=1.0, theta=0.0
% INFO    : Bus 63559	: V=0.9867995, theta=9.026668 -> V=1.0, theta=0.0
% INFO    : Bus 63560	: V=0.9860483, theta=8.959691 -> V=1.0, theta=0.0
% INFO    : Bus 63561	: V=0.9884062, theta=9.149787 -> V=1.0, theta=0.0
% INFO    : Bus 63562	: V=0.9926637, theta=10.30854 -> V=1.0, theta=0.0
% INFO    : Bus 63563	: V=0.9925205, theta=10.247827 -> V=1.0, theta=0.0
% INFO    : Bus 63564	: V=0.9892651, theta=9.376505 -> V=1.0, theta=0.0
% INFO    : Bus 63565	: V=0.9880005, theta=9.187312 -> V=1.0, theta=0.0
% INFO    : Bus 63566	: V=0.9929679, theta=10.422846 -> V=1.0, theta=0.0
% INFO    : Bus 63567	: V=0.9861779, theta=8.997029 -> V=1.0, theta=0.0
% INFO    : Bus 63568	: V=0.9863272, theta=8.355317 -> V=1.0, theta=0.0
% INFO    : Bus 63569	: V=0.9926205, theta=9.865943 -> V=1.0, theta=0.0
% INFO    : Bus 63570	: V=0.9920617, theta=9.138605 -> V=1.0, theta=0.0
% INFO    : Bus 63571	: V=0.9927226, theta=10.1646 -> V=1.0, theta=0.0
% INFO    : Bus 63572	: V=0.9925172, theta=10.050393 -> V=1.0, theta=0.0
% INFO    : Bus 63573	: V=0.9924902, theta=9.927843 -> V=1.0, theta=0.0
% INFO    : Bus 63574	: V=0.9881726, theta=9.043459 -> V=1.0, theta=0.0
% INFO    : Bus 63575	: V=0.9886187, theta=9.033219 -> V=1.0, theta=0.0
% INFO    : Bus 63576	: V=0.9853855, theta=8.238317 -> V=1.0, theta=0.0
% INFO    : Bus 63577	: V=0.9856604, theta=7.523545 -> V=1.0, theta=0.0
% INFO    : Bus 63578	: V=1.0200003, theta=13.566143 -> V=1.0, theta=0.0
% INFO    : Bus 63579	: V=0.9962846, theta=10.703544 -> V=1.0, theta=0.0
% INFO    : Bus 63580	: V=0.9951419, theta=10.794568 -> V=1.0, theta=0.0
% INFO    : Bus 63581	: V=0.9875974, theta=9.147833 -> V=1.0, theta=0.0
% INFO    : Bus 63582	: V=0.9985403, theta=11.052215 -> V=1.0, theta=0.0
% INFO    : Bus 63583	: V=0.9969583, theta=9.991405 -> V=1.0, theta=0.0
% INFO    : Bus 63584	: V=0.9962661, theta=16.216104 -> V=1.0, theta=0.0
% INFO    : Bus 63585	: V=0.9985136, theta=17.165386 -> V=1.0, theta=0.0
% INFO    : Bus 63586	: V=0.9984455, theta=16.713582 -> V=1.0, theta=0.0
% INFO    : Bus 63587	: V=1.0027673, theta=17.214964 -> V=1.0, theta=0.0
% INFO    : Bus 63588	: V=0.9824606, theta=6.465808 -> V=1.0, theta=0.0
% INFO    : Bus 63589	: V=0.9829822, theta=6.534435 -> V=1.0, theta=0.0
% INFO    : Bus 63590	: V=1.0200003, theta=12.970215 -> V=1.0, theta=0.0
% INFO    : Bus 63591	: V=0.9973192, theta=8.254586 -> V=1.0, theta=0.0
% INFO    : Bus 63592	: V=0.9955735, theta=8.154334 -> V=1.0, theta=0.0
% INFO    : Bus 63593	: V=0.9942868, theta=8.806099 -> V=1.0, theta=0.0
% INFO    : Bus 63594	: V=0.9894929, theta=7.321644 -> V=1.0, theta=0.0
% INFO    : Bus 63595	: V=0.9928775, theta=8.652303 -> V=1.0, theta=0.0
% INFO    : Bus 63596	: V=0.9951044, theta=8.186461 -> V=1.0, theta=0.0
% INFO    : Bus 63597	: V=0.9955057, theta=8.326819 -> V=1.0, theta=0.0
% INFO    : Bus 63598	: V=0.9980173, theta=9.581577 -> V=1.0, theta=0.0
% INFO    : Bus 63599	: V=1.0200003, theta=12.93146 -> V=1.0, theta=0.0
% INFO    : Bus 63600	: V=0.9966633, theta=9.339753 -> V=1.0, theta=0.0
% INFO    : Bus 63601	: V=0.9872295, theta=7.642891 -> V=1.0, theta=0.0
% INFO    : Bus 63602	: V=0.9891769, theta=7.744343 -> V=1.0, theta=0.0
% INFO    : Bus 63603	: V=0.9875992, theta=7.636591 -> V=1.0, theta=0.0
% INFO    : Bus 63604	: V=0.9860777, theta=7.5351 -> V=1.0, theta=0.0
% INFO    : Bus 63605	: V=0.9834732, theta=7.299232 -> V=1.0, theta=0.0
% INFO    : Bus 63606	: V=0.9837934, theta=7.311189 -> V=1.0, theta=0.0
% INFO    : Bus 63607	: V=0.9925817, theta=8.889603 -> V=1.0, theta=0.0
% INFO    : Bus 63608	: V=0.9879852, theta=7.829336 -> V=1.0, theta=0.0
% INFO    : Bus 63609	: V=0.9939721, theta=9.027977 -> V=1.0, theta=0.0
% INFO    : Bus 63610	: V=0.9875968, theta=7.654231 -> V=1.0, theta=0.0
% INFO    : Bus 63611	: V=0.9958964, theta=9.33392 -> V=1.0, theta=0.0
% INFO    : Bus 63612	: V=0.9917565, theta=8.542021 -> V=1.0, theta=0.0
% INFO    : Bus 63613	: V=0.9877971, theta=7.177277 -> V=1.0, theta=0.0
% INFO    : Bus 63614	: V=1.0053867, theta=8.590656 -> V=1.0, theta=0.0
% INFO    : Bus 63615	: V=0.9880733, theta=6.68221 -> V=1.0, theta=0.0
% INFO    : Bus 63616	: V=1.0039565, theta=8.490521 -> V=1.0, theta=0.0
% INFO    : Bus 63617	: V=0.9872538, theta=6.595689 -> V=1.0, theta=0.0
% INFO    : Bus 63618	: V=0.9994929, theta=8.771372 -> V=1.0, theta=0.0
% INFO    : Bus 63619	: V=0.9869638, theta=6.989273 -> V=1.0, theta=0.0
% INFO    : Bus 63620	: V=0.987069, theta=7.009042 -> V=1.0, theta=0.0
% INFO    : Bus 63621	: V=0.986303, theta=7.097697 -> V=1.0, theta=0.0
% INFO    : Bus 63622	: V=0.9974496, theta=8.761309 -> V=1.0, theta=0.0
% INFO    : Bus 63623	: V=0.998102, theta=9.045871 -> V=1.0, theta=0.0
% INFO    : Bus 63624	: V=0.9953949, theta=8.323042 -> V=1.0, theta=0.0
% INFO    : Bus 63625	: V=0.9968211, theta=8.792224 -> V=1.0, theta=0.0
% INFO    : Bus 63626	: V=0.9949659, theta=9.023338 -> V=1.0, theta=0.0
% INFO    : Bus 63627	: V=0.9964178, theta=8.852683 -> V=1.0, theta=0.0
% INFO    : Bus 63628	: V=0.9847384, theta=6.924399 -> V=1.0, theta=0.0
% INFO    : Bus 63629	: V=0.9863522, theta=6.976675 -> V=1.0, theta=0.0
% INFO    : Bus 63630	: V=0.981956, theta=7.089739 -> V=1.0, theta=0.0
% INFO    : Bus 63631	: V=0.9803614, theta=6.932704 -> V=1.0, theta=0.0
% INFO    : Bus 63632	: V=0.98162, theta=7.205142 -> V=1.0, theta=0.0
% INFO    : Bus 63633	: V=0.9795122, theta=6.978349 -> V=1.0, theta=0.0
% INFO    : Bus 63634	: V=0.990772, theta=8.457054 -> V=1.0, theta=0.0
% INFO    : Bus 63635	: V=0.9819128, theta=6.94928 -> V=1.0, theta=0.0
% INFO    : Bus 63636	: V=0.9798782, theta=6.871458 -> V=1.0, theta=0.0
% INFO    : Bus 63637	: V=0.9792204, theta=6.698905 -> V=1.0, theta=0.0
% INFO    : Bus 63638	: V=0.9795074, theta=6.871988 -> V=1.0, theta=0.0
% INFO    : Bus 63639	: V=0.9803896, theta=6.70689 -> V=1.0, theta=0.0
% INFO    : Bus 63640	: V=0.9789113, theta=6.751501 -> V=1.0, theta=0.0
% INFO    : Bus 63641	: V=0.9830804, theta=8.365686 -> V=1.0, theta=0.0
% INFO    : Bus 63642	: V=0.980497, theta=6.832972 -> V=1.0, theta=0.0
% INFO    : Bus 63643	: V=0.9807236, theta=6.839076 -> V=1.0, theta=0.0
% INFO    : Bus 63644	: V=0.9578409, theta=19.73451 -> V=1.0, theta=0.0
% INFO    : Bus 63645	: V=0.9874787, theta=8.266369 -> V=1.0, theta=0.0
% INFO    : Bus 63646	: V=1.0100003, theta=10.33207 -> V=1.0, theta=0.0
% INFO    : Bus 63647	: V=1.001398, theta=9.347341 -> V=1.0, theta=0.0
% INFO    : Bus 63648	: V=0.9785603, theta=8.393498 -> V=1.0, theta=0.0
% INFO    : Bus 63649	: V=0.9773692, theta=7.12967 -> V=1.0, theta=0.0
% INFO    : Bus 63650	: V=0.9903697, theta=8.432455 -> V=1.0, theta=0.0
% INFO    : Bus 63651	: V=0.9880806, theta=7.715226 -> V=1.0, theta=0.0
% INFO    : Bus 63652	: V=0.9892018, theta=7.883279 -> V=1.0, theta=0.0
% INFO    : Bus 63653	: V=0.9925278, theta=8.698668 -> V=1.0, theta=0.0
% INFO    : Bus 63654	: V=0.9886092, theta=7.84031 -> V=1.0, theta=0.0
% INFO    : Bus 63655	: V=0.989193, theta=7.88506 -> V=1.0, theta=0.0
% INFO    : Bus 63656	: V=0.9944735, theta=9.040234 -> V=1.0, theta=0.0
% INFO    : Bus 63657	: V=0.9939231, theta=9.005985 -> V=1.0, theta=0.0
% INFO    : Bus 63658	: V=0.9858903, theta=7.24782 -> V=1.0, theta=0.0
% INFO    : Bus 63659	: V=0.9853555, theta=7.204555 -> V=1.0, theta=0.0
% INFO    : Bus 63660	: V=0.9821, theta=6.337102 -> V=1.0, theta=0.0
% INFO    : Bus 63661	: V=0.9848116, theta=7.166661 -> V=1.0, theta=0.0
% INFO    : Bus 63662	: V=0.9839992, theta=7.109074 -> V=1.0, theta=0.0
% INFO    : Bus 63663	: V=0.9830631, theta=7.066333 -> V=1.0, theta=0.0
% INFO    : Bus 63664	: V=0.9806651, theta=6.744777 -> V=1.0, theta=0.0
% INFO    : Bus 63665	: V=0.9899528, theta=8.815696 -> V=1.0, theta=0.0
% INFO    : Bus 63666	: V=0.981482, theta=6.897777 -> V=1.0, theta=0.0
% INFO    : Bus 63667	: V=0.9835495, theta=7.228537 -> V=1.0, theta=0.0
% INFO    : Bus 63668	: V=0.9843092, theta=7.278554 -> V=1.0, theta=0.0
% INFO    : Bus 63669	: V=0.9848373, theta=7.30121 -> V=1.0, theta=0.0
% INFO    : Bus 63670	: V=0.9854293, theta=7.341061 -> V=1.0, theta=0.0
% INFO    : Bus 63671	: V=0.9877828, theta=7.584548 -> V=1.0, theta=0.0
% INFO    : Bus 63672	: V=0.9873526, theta=7.705144 -> V=1.0, theta=0.0
% INFO    : Bus 63673	: V=0.9855555, theta=7.396957 -> V=1.0, theta=0.0
% INFO    : Bus 63674	: V=0.9865262, theta=7.503823 -> V=1.0, theta=0.0
% INFO    : Bus 63675	: V=0.9862603, theta=7.566939 -> V=1.0, theta=0.0
% INFO    : Bus 63676	: V=0.9808975, theta=6.881639 -> V=1.0, theta=0.0
% INFO    : Bus 63677	: V=0.9849065, theta=7.515128 -> V=1.0, theta=0.0
% INFO    : Bus 63678	: V=0.9807156, theta=6.83703 -> V=1.0, theta=0.0
% INFO    : Bus 63679	: V=0.9961721, theta=9.27533 -> V=1.0, theta=0.0
% INFO    : Bus 63680	: V=0.9894927, theta=7.842253 -> V=1.0, theta=0.0
% INFO    : Bus 63681	: V=0.9954233, theta=9.232214 -> V=1.0, theta=0.0
% INFO    : Bus 63682	: V=0.9945335, theta=9.106432 -> V=1.0, theta=0.0
% INFO    : Bus 63683	: V=0.9921142, theta=8.901655 -> V=1.0, theta=0.0
% INFO    : Bus 63684	: V=0.9914253, theta=8.850017 -> V=1.0, theta=0.0
% INFO    : Bus 63685	: V=0.9871239, theta=7.814429 -> V=1.0, theta=0.0
% INFO    : Bus 63686	: V=0.9866378, theta=7.804689 -> V=1.0, theta=0.0
% INFO    : Bus 63687	: V=0.9876313, theta=7.718758 -> V=1.0, theta=0.0
% INFO    : Bus 63688	: V=0.9859918, theta=7.626901 -> V=1.0, theta=0.0
% INFO    : Bus 63689	: V=0.9865175, theta=7.63773 -> V=1.0, theta=0.0
% INFO    : Bus 63690	: V=0.986228, theta=7.653244 -> V=1.0, theta=0.0
% INFO    : Bus 63691	: V=0.9935263, theta=8.69029 -> V=1.0, theta=0.0
% INFO    : Bus 63692	: V=0.9867161, theta=7.705666 -> V=1.0, theta=0.0
% INFO    : Bus 63693	: V=0.9906257, theta=8.5444 -> V=1.0, theta=0.0
% INFO    : Bus 63694	: V=0.9858725, theta=7.718663 -> V=1.0, theta=0.0
% INFO    : Bus 63695	: V=0.9907141, theta=8.475726 -> V=1.0, theta=0.0
% INFO    : Bus 63696	: V=0.9864012, theta=7.732839 -> V=1.0, theta=0.0
% INFO    : Bus 63697	: V=0.9808122, theta=6.808179 -> V=1.0, theta=0.0
% INFO    : Bus 63698	: V=0.9798359, theta=6.814877 -> V=1.0, theta=0.0
% INFO    : Bus 63699	: V=0.9801601, theta=6.768612 -> V=1.0, theta=0.0
% INFO    : Bus 63700	: V=0.9803179, theta=6.775463 -> V=1.0, theta=0.0
% INFO    : Bus 63701	: V=0.9798884, theta=6.776174 -> V=1.0, theta=0.0
% INFO    : Bus 63702	: V=0.9858687, theta=7.762404 -> V=1.0, theta=0.0
% INFO    : Bus 63703	: V=0.9881494, theta=8.292676 -> V=1.0, theta=0.0
% INFO    : Bus 63704	: V=0.9893552, theta=8.372961 -> V=1.0, theta=0.0
% INFO    : Bus 63705	: V=0.9869866, theta=7.876991 -> V=1.0, theta=0.0
% INFO    : Bus 63706	: V=0.9857852, theta=7.733686 -> V=1.0, theta=0.0
% INFO    : Bus 63707	: V=0.9862644, theta=8.188788 -> V=1.0, theta=0.0
% INFO    : Bus 63708	: V=0.9803125, theta=6.784702 -> V=1.0, theta=0.0
% INFO    : Bus 63709	: V=0.9857652, theta=7.879727 -> V=1.0, theta=0.0
% INFO    : Bus 63710	: V=0.9853741, theta=8.196422 -> V=1.0, theta=0.0
% INFO    : Bus 63711	: V=0.9849248, theta=8.211638 -> V=1.0, theta=0.0
% INFO    : Bus 63712	: V=0.9848139, theta=8.245707 -> V=1.0, theta=0.0
% INFO    : Bus 63713	: V=0.9850321, theta=7.8496 -> V=1.0, theta=0.0
% INFO    : Bus 63714	: V=0.9859854, theta=8.417616 -> V=1.0, theta=0.0
% INFO    : Bus 63715	: V=0.9858577, theta=8.293761 -> V=1.0, theta=0.0
% INFO    : Bus 63716	: V=0.9852874, theta=8.263205 -> V=1.0, theta=0.0
% INFO    : Bus 63717	: V=0.9856643, theta=7.86704 -> V=1.0, theta=0.0
% INFO    : Bus 63718	: V=0.9802756, theta=6.82228 -> V=1.0, theta=0.0
% INFO    : Bus 63719	: V=0.9861395, theta=7.806219 -> V=1.0, theta=0.0
% INFO    : Bus 63720	: V=0.9902231, theta=8.507898 -> V=1.0, theta=0.0
% INFO    : Bus 63721	: V=0.987402, theta=8.405959 -> V=1.0, theta=0.0
% INFO    : Bus 63722	: V=0.9855164, theta=7.955366 -> V=1.0, theta=0.0
% INFO    : Bus 63723	: V=0.9898421, theta=8.47531 -> V=1.0, theta=0.0
% INFO    : Bus 63724	: V=0.9844004, theta=8.242063 -> V=1.0, theta=0.0
% INFO    : Bus 63725	: V=0.9802336, theta=7.355166 -> V=1.0, theta=0.0
% INFO    : Bus 63726	: V=0.9789878, theta=7.286662 -> V=1.0, theta=0.0
% INFO    : Bus 63727	: V=0.9851059, theta=8.486267 -> V=1.0, theta=0.0
% INFO    : Bus 63728	: V=0.9764263, theta=7.102446 -> V=1.0, theta=0.0
% INFO    : Bus 63729	: V=0.9869983, theta=8.03132 -> V=1.0, theta=0.0
% INFO    : Bus 63730	: V=0.9810102, theta=6.76846 -> V=1.0, theta=0.0
% INFO    : Bus 63731	: V=0.9819914, theta=6.893148 -> V=1.0, theta=0.0
% INFO    : Bus 63732	: V=0.9811368, theta=6.791178 -> V=1.0, theta=0.0
% INFO    : Bus 63733	: V=0.9801937, theta=6.602211 -> V=1.0, theta=0.0
% INFO    : Bus 63734	: V=0.9796021, theta=6.56776 -> V=1.0, theta=0.0
% INFO    : Bus 63735	: V=0.9829372, theta=29.831714 -> V=1.0, theta=0.0
% INFO    : Bus 63736	: V=0.9856315, theta=27.485855 -> V=1.0, theta=0.0
% INFO    : Bus 63737	: V=0.9844754, theta=28.17593 -> V=1.0, theta=0.0
% INFO    : Bus 63738	: V=0.9894355, theta=25.072994 -> V=1.0, theta=0.0
% INFO    : Bus 63739	: V=0.9762036, theta=20.475127 -> V=1.0, theta=0.0
% INFO    : Bus 63740	: V=0.9976617, theta=21.837666 -> V=1.0, theta=0.0
% INFO    : Bus 63741	: V=1.0036976, theta=21.029035 -> V=1.0, theta=0.0
% INFO    : Bus 63742	: V=1.0067031, theta=13.653344 -> V=1.0, theta=0.0
% INFO    : Bus 63743	: V=1.0067826, theta=13.630555 -> V=1.0, theta=0.0
% INFO    : Bus 63744	: V=1.0084333, theta=13.760243 -> V=1.0, theta=0.0
% INFO    : Bus 63745	: V=1.006995, theta=13.6768 -> V=1.0, theta=0.0
% INFO    : Bus 63746	: V=1.0078157, theta=13.703977 -> V=1.0, theta=0.0
% INFO    : Bus 63747	: V=1.0061978, theta=13.66376 -> V=1.0, theta=0.0
% INFO    : Bus 63748	: V=1.0081928, theta=13.715678 -> V=1.0, theta=0.0
% INFO    : Bus 63749	: V=1.0300003, theta=18.68048 -> V=1.0, theta=0.0
% INFO    : Bus 63750	: V=1.0076239, theta=13.688607 -> V=1.0, theta=0.0
% INFO    : Bus 63751	: V=1.0066529, theta=13.622986 -> V=1.0, theta=0.0
% INFO    : Bus 63752	: V=1.0061236, theta=13.588149 -> V=1.0, theta=0.0
% INFO    : Bus 63753	: V=1.0094285, theta=14.001636 -> V=1.0, theta=0.0
% INFO    : Bus 63754	: V=1.0045649, theta=13.532216 -> V=1.0, theta=0.0
% INFO    : Bus 63755	: V=1.0061909, theta=13.567408 -> V=1.0, theta=0.0
% INFO    : Bus 63756	: V=1.0042444, theta=13.445659 -> V=1.0, theta=0.0
% INFO    : Bus 63757	: V=1.0052455, theta=13.465551 -> V=1.0, theta=0.0
% INFO    : Bus 63758	: V=1.0024218, theta=13.398951 -> V=1.0, theta=0.0
% INFO    : Bus 63759	: V=1.0068291, theta=13.584731 -> V=1.0, theta=0.0
% INFO    : Bus 63760	: V=1.0109548, theta=14.211954 -> V=1.0, theta=0.0
% INFO    : Bus 63761	: V=1.0061466, theta=13.566706 -> V=1.0, theta=0.0
% INFO    : Bus 63762	: V=1.0065129, theta=13.586721 -> V=1.0, theta=0.0
% INFO    : Bus 63763	: V=1.0065623, theta=13.574557 -> V=1.0, theta=0.0
% INFO    : Bus 63764	: V=0.9952955, theta=11.402691 -> V=1.0, theta=0.0
% INFO    : Bus 63765	: V=1.0052122, theta=13.29482 -> V=1.0, theta=0.0
% INFO    : Bus 63766	: V=1.0082217, theta=13.846387 -> V=1.0, theta=0.0
% INFO    : Bus 63767	: V=1.0030558, theta=13.023518 -> V=1.0, theta=0.0
% INFO    : Bus 63768	: V=0.9986281, theta=12.060156 -> V=1.0, theta=0.0
% INFO    : Bus 63769	: V=1.0079435, theta=13.805965 -> V=1.0, theta=0.0
% INFO    : Bus 63770	: V=1.0014675, theta=12.272527 -> V=1.0, theta=0.0
% INFO    : Bus 63771	: V=1.0023699, theta=12.685056 -> V=1.0, theta=0.0
% INFO    : Bus 63772	: V=1.0014186, theta=12.49542 -> V=1.0, theta=0.0
% INFO    : Bus 63773	: V=1.0014939, theta=12.50375 -> V=1.0, theta=0.0
% INFO    : Bus 63774	: V=1.0017567, theta=12.527635 -> V=1.0, theta=0.0
% INFO    : Bus 63775	: V=1.0045358, theta=13.112498 -> V=1.0, theta=0.0
% INFO    : Bus 63776	: V=1.0005072, theta=12.518433 -> V=1.0, theta=0.0
% INFO    : Bus 63777	: V=1.0039563, theta=13.04774 -> V=1.0, theta=0.0
% INFO    : Bus 63778	: V=1.0029314, theta=12.851054 -> V=1.0, theta=0.0
% INFO    : Bus 63779	: V=0.9968525, theta=12.169957 -> V=1.0, theta=0.0
% INFO    : Bus 63780	: V=0.9934121, theta=11.420108 -> V=1.0, theta=0.0
% INFO    : Bus 63781	: V=0.9975116, theta=11.845986 -> V=1.0, theta=0.0
% INFO    : Bus 63782	: V=0.9902776, theta=11.138769 -> V=1.0, theta=0.0
% INFO    : Bus 63783	: V=0.9900449, theta=11.053709 -> V=1.0, theta=0.0
% INFO    : Bus 63784	: V=0.9962334, theta=12.12812 -> V=1.0, theta=0.0
% INFO    : Bus 63785	: V=1.0013617, theta=12.587912 -> V=1.0, theta=0.0
% INFO    : Bus 63786	: V=0.9970758, theta=12.232765 -> V=1.0, theta=0.0
% INFO    : Bus 63787	: V=0.9974002, theta=12.268651 -> V=1.0, theta=0.0
% INFO    : Bus 63788	: V=0.9891568, theta=11.043625 -> V=1.0, theta=0.0
% INFO    : Bus 63789	: V=0.9877297, theta=10.996258 -> V=1.0, theta=0.0
% INFO    : Bus 63790	: V=0.9878145, theta=10.975367 -> V=1.0, theta=0.0
% INFO    : Bus 63791	: V=0.9883326, theta=10.993003 -> V=1.0, theta=0.0
% INFO    : Bus 63792	: V=0.987711, theta=10.983967 -> V=1.0, theta=0.0
% INFO    : Bus 63793	: V=0.9965948, theta=12.152397 -> V=1.0, theta=0.0
% INFO    : Bus 63794	: V=0.998067, theta=12.26236 -> V=1.0, theta=0.0
% INFO    : Bus 63795	: V=0.9869101, theta=10.910504 -> V=1.0, theta=0.0
% INFO    : Bus 63796	: V=0.9956146, theta=12.080393 -> V=1.0, theta=0.0
% INFO    : Bus 63797	: V=0.987586, theta=10.983393 -> V=1.0, theta=0.0
% INFO    : Bus 63798	: V=0.9862324, theta=10.894321 -> V=1.0, theta=0.0
% INFO    : Bus 63799	: V=0.9852979, theta=10.837881 -> V=1.0, theta=0.0
% INFO    : Bus 63800	: V=0.9946408, theta=11.609742 -> V=1.0, theta=0.0
% INFO    : Bus 63801	: V=0.9914321, theta=12.809564 -> V=1.0, theta=0.0
% INFO    : Bus 63802	: V=0.9924197, theta=13.146203 -> V=1.0, theta=0.0
% INFO    : Bus 63803	: V=0.9974067, theta=13.931456 -> V=1.0, theta=0.0
% INFO    : Bus 63804	: V=1.0040355, theta=12.805089 -> V=1.0, theta=0.0
% INFO    : Bus 63805	: V=1.001582, theta=12.55693 -> V=1.0, theta=0.0
% INFO    : Bus 63806	: V=0.9987607, theta=11.935755 -> V=1.0, theta=0.0
% INFO    : Bus 63807	: V=1.0000162, theta=12.215255 -> V=1.0, theta=0.0
% INFO    : Bus 63808	: V=0.9984754, theta=11.384112 -> V=1.0, theta=0.0
% INFO    : Bus 63809	: V=1.000894, theta=12.182536 -> V=1.0, theta=0.0
% INFO    : Bus 63810	: V=0.9965876, theta=11.254607 -> V=1.0, theta=0.0
% INFO    : Bus 63811	: V=0.9915984, theta=9.780313 -> V=1.0, theta=0.0
% INFO    : Bus 63812	: V=0.9957217, theta=11.044014 -> V=1.0, theta=0.0
% INFO    : Bus 63813	: V=0.9911665, theta=9.684571 -> V=1.0, theta=0.0
% INFO    : Bus 63814	: V=0.9938997, theta=10.816584 -> V=1.0, theta=0.0
% INFO    : Bus 63815	: V=0.9930435, theta=10.725381 -> V=1.0, theta=0.0
% INFO    : Bus 63816	: V=0.9951472, theta=10.941944 -> V=1.0, theta=0.0
% INFO    : Bus 63817	: V=0.9889688, theta=9.362429 -> V=1.0, theta=0.0
% INFO    : Bus 63818	: V=0.9943287, theta=10.819089 -> V=1.0, theta=0.0
% INFO    : Bus 63819	: V=0.9944443, theta=10.880676 -> V=1.0, theta=0.0
% INFO    : Bus 63820	: V=0.9957931, theta=11.027281 -> V=1.0, theta=0.0
% INFO    : Bus 63821	: V=0.9992948, theta=11.858176 -> V=1.0, theta=0.0
% INFO    : Bus 63822	: V=0.9990764, theta=12.015401 -> V=1.0, theta=0.0
% INFO    : Bus 63823	: V=0.997433, theta=11.480738 -> V=1.0, theta=0.0
% INFO    : Bus 63824	: V=1.0009013, theta=11.97031 -> V=1.0, theta=0.0
% INFO    : Bus 63825	: V=0.9883063, theta=17.504602 -> V=1.0, theta=0.0
% INFO    : Bus 63826	: V=0.9968795, theta=18.484226 -> V=1.0, theta=0.0
% INFO    : Bus 63827	: V=1.0005136, theta=19.227055 -> V=1.0, theta=0.0
% INFO    : Bus 63828	: V=1.0043568, theta=20.126815 -> V=1.0, theta=0.0
% INFO    : Bus 63829	: V=1.0067068, theta=20.206508 -> V=1.0, theta=0.0
% INFO    : Bus 63830	: V=1.0065106, theta=24.503674 -> V=1.0, theta=0.0
% INFO    : Bus 63831	: V=1.0081035, theta=14.91185 -> V=1.0, theta=0.0
% INFO    : Bus 63832	: V=1.0166202, theta=16.825033 -> V=1.0, theta=0.0
% INFO    : Bus 63833	: V=1.0225119, theta=17.36728 -> V=1.0, theta=0.0
% INFO    : Bus 63834	: V=0.9808973, theta=19.764579 -> V=1.0, theta=0.0
% INFO    : Bus 63835	: V=0.997765, theta=21.513528 -> V=1.0, theta=0.0
% INFO    : Bus 63836	: V=1.0004295, theta=15.944589 -> V=1.0, theta=0.0
% INFO    : Bus 63837	: V=0.997059, theta=13.592148 -> V=1.0, theta=0.0
% INFO    : Bus 63838	: V=0.9709742, theta=22.543283 -> V=1.0, theta=0.0
% INFO    : Bus 63839	: V=0.9635782, theta=14.890863 -> V=1.0, theta=0.0
% INFO    : Bus 63840	: V=0.9807487, theta=22.847744 -> V=1.0, theta=0.0
% INFO    : Bus 63841	: V=0.9680662, theta=22.802634 -> V=1.0, theta=0.0
% INFO    : Bus 63842	: V=0.9872482, theta=25.204712 -> V=1.0, theta=0.0
% INFO    : Bus 63843	: V=0.9615511, theta=22.549045 -> V=1.0, theta=0.0
% INFO    : Bus 63844	: V=0.9957986, theta=24.496856 -> V=1.0, theta=0.0
% INFO    : Bus 63845	: V=0.9694529, theta=23.074167 -> V=1.0, theta=0.0
% INFO    : Bus 63846	: V=0.9802147, theta=23.023503 -> V=1.0, theta=0.0
% INFO    : Bus 63847	: V=0.9925394, theta=9.094036 -> V=1.0, theta=0.0
% INFO    : Bus 63848	: V=0.9920962, theta=8.948334 -> V=1.0, theta=0.0
% INFO    : Bus 63849	: V=0.9861198, theta=7.458443 -> V=1.0, theta=0.0
% INFO    : Bus 63850	: V=0.9924102, theta=9.013897 -> V=1.0, theta=0.0
% INFO    : Bus 63851	: V=0.9927872, theta=8.973735 -> V=1.0, theta=0.0
% INFO    : Bus 63852	: V=0.9919286, theta=8.949376 -> V=1.0, theta=0.0
% INFO    : Bus 63853	: V=0.9862506, theta=7.447532 -> V=1.0, theta=0.0
% INFO    : Bus 63854	: V=0.9868869, theta=7.455792 -> V=1.0, theta=0.0
% INFO    : Bus 63855	: V=0.9894974, theta=7.293003 -> V=1.0, theta=0.0
% INFO    : Bus 63856	: V=0.9866279, theta=7.402116 -> V=1.0, theta=0.0
% INFO    : Bus 63857	: V=0.9867997, theta=7.340431 -> V=1.0, theta=0.0
% INFO    : Bus 63858	: V=0.9844503, theta=7.38346 -> V=1.0, theta=0.0
% INFO    : Bus 63859	: V=0.9891943, theta=7.179712 -> V=1.0, theta=0.0
% INFO    : Bus 63860	: V=0.9984763, theta=8.47044 -> V=1.0, theta=0.0
% INFO    : Bus 63861	: V=0.9828571, theta=7.078612 -> V=1.0, theta=0.0
% INFO    : Bus 63862	: V=0.98572, theta=6.912803 -> V=1.0, theta=0.0
% INFO    : Bus 63863	: V=0.9838586, theta=7.235228 -> V=1.0, theta=0.0
% INFO    : Bus 63864	: V=0.9874953, theta=7.027667 -> V=1.0, theta=0.0
% INFO    : Bus 63865	: V=0.9863667, theta=6.895495 -> V=1.0, theta=0.0
% INFO    : Bus 63866	: V=0.9854182, theta=7.43434 -> V=1.0, theta=0.0
% INFO    : Bus 63867	: V=0.9874801, theta=7.447218 -> V=1.0, theta=0.0
% INFO    : Bus 63868	: V=0.986175, theta=6.839983 -> V=1.0, theta=0.0
% INFO    : Bus 63869	: V=0.9860468, theta=6.694422 -> V=1.0, theta=0.0
% INFO    : Bus 63870	: V=1.0016513, theta=8.476741 -> V=1.0, theta=0.0
% INFO    : Bus 63871	: V=0.9867274, theta=6.798809 -> V=1.0, theta=0.0
% INFO    : Bus 63872	: V=1.0039775, theta=8.462555 -> V=1.0, theta=0.0
% INFO    : Bus 63873	: V=0.9928406, theta=8.783671 -> V=1.0, theta=0.0
% INFO    : Bus 63874	: V=0.9931801, theta=8.745241 -> V=1.0, theta=0.0
% INFO    : Bus 63875	: V=0.987251, theta=7.350581 -> V=1.0, theta=0.0
% INFO    : Bus 63876	: V=0.988715, theta=7.232588 -> V=1.0, theta=0.0
% INFO    : Bus 63877	: V=0.9875368, theta=7.051668 -> V=1.0, theta=0.0
% INFO    : Bus 63878	: V=0.9984594, theta=8.436979 -> V=1.0, theta=0.0
% INFO    : Bus 63879	: V=0.9874755, theta=7.284003 -> V=1.0, theta=0.0
% INFO    : Bus 63880	: V=0.9869419, theta=6.999266 -> V=1.0, theta=0.0
% INFO    : Bus 63881	: V=0.9992942, theta=8.429099 -> V=1.0, theta=0.0
% INFO    : Bus 63882	: V=0.9931595, theta=8.560872 -> V=1.0, theta=0.0
% INFO    : Bus 63883	: V=0.9925954, theta=8.490061 -> V=1.0, theta=0.0
% INFO    : Bus 63884	: V=0.9915259, theta=8.371421 -> V=1.0, theta=0.0
% INFO    : Bus 63885	: V=0.9891573, theta=7.328736 -> V=1.0, theta=0.0
% INFO    : Bus 63886	: V=0.9922468, theta=8.442957 -> V=1.0, theta=0.0
% INFO    : Bus 63887	: V=0.9867873, theta=6.977971 -> V=1.0, theta=0.0
% INFO    : Bus 63888	: V=0.9873663, theta=6.994258 -> V=1.0, theta=0.0
% INFO    : Bus 63889	: V=0.9874103, theta=7.024191 -> V=1.0, theta=0.0
% INFO    : Bus 63890	: V=0.9876979, theta=6.993879 -> V=1.0, theta=0.0
% INFO    : Bus 63891	: V=0.9886435, theta=6.955199 -> V=1.0, theta=0.0
% INFO    : Bus 63892	: V=0.9874001, theta=6.889274 -> V=1.0, theta=0.0
% INFO    : Bus 63893	: V=0.9856946, theta=6.703935 -> V=1.0, theta=0.0
% INFO    : Bus 63894	: V=0.9858932, theta=6.724444 -> V=1.0, theta=0.0
% INFO    : Bus 63895	: V=0.9866357, theta=6.5931 -> V=1.0, theta=0.0
% INFO    : Bus 63896	: V=0.9863573, theta=6.53569 -> V=1.0, theta=0.0
% INFO    : Bus 63897	: V=0.984922, theta=6.480545 -> V=1.0, theta=0.0
% INFO    : Bus 63898	: V=0.9848287, theta=6.428288 -> V=1.0, theta=0.0
% INFO    : Bus 63899	: V=0.9902282, theta=7.979831 -> V=1.0, theta=0.0
% INFO    : Bus 63900	: V=0.9920909, theta=8.422021 -> V=1.0, theta=0.0
% INFO    : Bus 63901	: V=0.9914597, theta=8.341055 -> V=1.0, theta=0.0
% INFO    : Bus 63902	: V=0.9874406, theta=7.053625 -> V=1.0, theta=0.0
% INFO    : Bus 63903	: V=0.9874701, theta=6.952098 -> V=1.0, theta=0.0
% INFO    : Bus 63904	: V=0.9912159, theta=8.322478 -> V=1.0, theta=0.0
% INFO    : Bus 63905	: V=0.9869172, theta=6.879441 -> V=1.0, theta=0.0
% INFO    : Bus 63906	: V=0.9857282, theta=6.679612 -> V=1.0, theta=0.0
% INFO    : Bus 63907	: V=1.0200003, theta=13.244664 -> V=1.0, theta=0.0
% INFO    : Bus 63908	: V=0.9938979, theta=8.646372 -> V=1.0, theta=0.0
% INFO    : Bus 63909	: V=0.994031, theta=8.702113 -> V=1.0, theta=0.0
% INFO    : Bus 63910	: V=0.9932109, theta=8.575298 -> V=1.0, theta=0.0
% INFO    : Bus 63911	: V=0.9923543, theta=8.468228 -> V=1.0, theta=0.0
% INFO    : Bus 63912	: V=0.9897428, theta=7.937584 -> V=1.0, theta=0.0
% INFO    : Bus 63913	: V=0.9916334, theta=8.376245 -> V=1.0, theta=0.0
% INFO    : Bus 63914	: V=0.990666, theta=8.256488 -> V=1.0, theta=0.0
% INFO    : Bus 63915	: V=0.9844433, theta=6.657201 -> V=1.0, theta=0.0
% INFO    : Bus 63916	: V=0.9824108, theta=6.372385 -> V=1.0, theta=0.0
% INFO    : Bus 63917	: V=0.9862663, theta=6.525844 -> V=1.0, theta=0.0
% INFO    : Bus 63918	: V=0.9817926, theta=6.315299 -> V=1.0, theta=0.0
% INFO    : Bus 63919	: V=0.9824642, theta=6.722004 -> V=1.0, theta=0.0
% INFO    : Bus 63920	: V=0.9834297, theta=6.419347 -> V=1.0, theta=0.0
% INFO    : Bus 63921	: V=0.9835108, theta=6.343572 -> V=1.0, theta=0.0
% INFO    : Bus 63922	: V=0.9939544, theta=8.699275 -> V=1.0, theta=0.0
% INFO    : Bus 63923	: V=0.9945526, theta=8.778117 -> V=1.0, theta=0.0
% INFO    : Bus 63924	: V=0.9883049, theta=7.633477 -> V=1.0, theta=0.0
% INFO    : Bus 63925	: V=0.9876741, theta=7.620751 -> V=1.0, theta=0.0
% INFO    : Bus 63926	: V=1.0100003, theta=11.221741 -> V=1.0, theta=0.0
% INFO    : Bus 63927	: V=0.9965887, theta=8.995388 -> V=1.0, theta=0.0
% INFO    : Bus 63928	: V=0.9855473, theta=7.166456 -> V=1.0, theta=0.0
% INFO    : Bus 63929	: V=0.9880255, theta=7.632866 -> V=1.0, theta=0.0
% INFO    : Bus 63930	: V=0.9865544, theta=7.240677 -> V=1.0, theta=0.0
% INFO    : Bus 63931	: V=0.9862106, theta=7.201578 -> V=1.0, theta=0.0
% INFO    : Bus 63932	: V=0.9836342, theta=6.676065 -> V=1.0, theta=0.0
% INFO    : Bus 63933	: V=0.9916872, theta=8.569547 -> V=1.0, theta=0.0
% INFO    : Bus 63934	: V=0.985003, theta=7.119044 -> V=1.0, theta=0.0
% INFO    : Bus 63935	: V=0.9877795, theta=7.640913 -> V=1.0, theta=0.0
% INFO    : Bus 63936	: V=0.9875602, theta=7.612542 -> V=1.0, theta=0.0
% INFO    : Bus 63937	: V=0.9889551, theta=8.25314 -> V=1.0, theta=0.0
% INFO    : Bus 63938	: V=0.9817778, theta=6.89275 -> V=1.0, theta=0.0
% INFO    : Bus 63939	: V=0.9823029, theta=6.96706 -> V=1.0, theta=0.0
% INFO    : Bus 63940	: V=0.9838014, theta=6.874646 -> V=1.0, theta=0.0
% INFO    : Bus 63941	: V=0.9793975, theta=6.801804 -> V=1.0, theta=0.0
% INFO    : Bus 63942	: V=0.980734, theta=6.831356 -> V=1.0, theta=0.0
% INFO    : Bus 63943	: V=0.9803688, theta=6.820729 -> V=1.0, theta=0.0
% INFO    : Bus 63944	: V=0.9805041, theta=6.911549 -> V=1.0, theta=0.0
% INFO    : Bus 63945	: V=0.9790124, theta=6.840782 -> V=1.0, theta=0.0
% INFO    : Bus 63946	: V=0.978864, theta=6.87294 -> V=1.0, theta=0.0
% INFO    : Bus 63947	: V=0.9824626, theta=6.570696 -> V=1.0, theta=0.0
% INFO    : Bus 63948	: V=0.9827463, theta=6.653933 -> V=1.0, theta=0.0
% INFO    : Bus 63949	: V=0.9818241, theta=6.398092 -> V=1.0, theta=0.0
% INFO    : Bus 63950	: V=0.9822513, theta=6.401782 -> V=1.0, theta=0.0
% INFO    : Bus 63951	: V=0.9811903, theta=6.469625 -> V=1.0, theta=0.0
% INFO    : Bus 63952	: V=0.982938, theta=6.357558 -> V=1.0, theta=0.0
% INFO    : Bus 63953	: V=0.9960762, theta=8.227642 -> V=1.0, theta=0.0
% INFO    : Bus 63954	: V=0.9950231, theta=8.145798 -> V=1.0, theta=0.0
% INFO    : Bus 63955	: V=0.9772964, theta=6.527076 -> V=1.0, theta=0.0
% INFO    : Bus 63956	: V=0.9778873, theta=6.539356 -> V=1.0, theta=0.0
% INFO    : Bus 63957	: V=0.9790162, theta=6.591306 -> V=1.0, theta=0.0
% INFO    : Bus 63958	: V=0.9794535, theta=6.608964 -> V=1.0, theta=0.0
% INFO    : Bus 63959	: V=0.9797299, theta=6.580633 -> V=1.0, theta=0.0
% INFO    : Bus 63960	: V=0.9803622, theta=6.54765 -> V=1.0, theta=0.0
% INFO    : Bus 63961	: V=0.9799629, theta=6.652239 -> V=1.0, theta=0.0
% INFO    : Bus 63962	: V=0.9799519, theta=6.642291 -> V=1.0, theta=0.0
% INFO    : Bus 63963	: V=0.9807879, theta=6.47052 -> V=1.0, theta=0.0
% INFO    : Bus 63964	: V=0.9808583, theta=6.755741 -> V=1.0, theta=0.0
% INFO    : Bus 63965	: V=0.9803511, theta=6.559437 -> V=1.0, theta=0.0
% INFO    : Bus 63966	: V=0.9844583, theta=7.067252 -> V=1.0, theta=0.0
% INFO    : Bus 63967	: V=0.9837083, theta=6.865478 -> V=1.0, theta=0.0
% INFO    : Bus 63968	: V=0.9876866, theta=8.099382 -> V=1.0, theta=0.0
% INFO    : Bus 63969	: V=1.0037441, theta=10.183144 -> V=1.0, theta=0.0
% INFO    : Bus 63970	: V=0.9938024, theta=8.385407 -> V=1.0, theta=0.0
% INFO    : Bus 63971	: V=0.9935771, theta=8.366197 -> V=1.0, theta=0.0
% INFO    : Bus 63972	: V=0.9919306, theta=8.244726 -> V=1.0, theta=0.0
% INFO    : Bus 63973	: V=0.9927505, theta=8.299191 -> V=1.0, theta=0.0
% INFO    : Bus 63974	: V=0.9918206, theta=8.258654 -> V=1.0, theta=0.0
% INFO    : Bus 63975	: V=0.9987673, theta=10.015175 -> V=1.0, theta=0.0
% INFO    : Bus 63976	: V=1.0021555, theta=10.254161 -> V=1.0, theta=0.0
% INFO    : Bus 63977	: V=1.0019037, theta=10.188506 -> V=1.0, theta=0.0
% INFO    : Bus 63978	: V=1.0023248, theta=10.091742 -> V=1.0, theta=0.0
% INFO    : Bus 63979	: V=0.9782319, theta=6.873383 -> V=1.0, theta=0.0
% INFO    : Bus 63980	: V=0.9773087, theta=6.839856 -> V=1.0, theta=0.0
% INFO    : Bus 63981	: V=0.995572, theta=8.218035 -> V=1.0, theta=0.0
% INFO    : Bus 63982	: V=0.9882523, theta=8.144219 -> V=1.0, theta=0.0
% INFO    : Bus 63983	: V=0.9855963, theta=7.939054 -> V=1.0, theta=0.0
% INFO    : Bus 63984	: V=0.9825298, theta=6.509152 -> V=1.0, theta=0.0
% INFO    : Bus 63985	: V=0.9927742, theta=9.237324 -> V=1.0, theta=0.0
% INFO    : Bus 63986	: V=0.9824018, theta=6.424449 -> V=1.0, theta=0.0
% INFO    : Bus 63987	: V=1.0025474, theta=8.927602 -> V=1.0, theta=0.0
% INFO    : Bus 63988	: V=0.9797485, theta=6.893776 -> V=1.0, theta=0.0
% INFO    : Bus 63989	: V=1.0042526, theta=10.70801 -> V=1.0, theta=0.0
% INFO    : Bus 63990	: V=1.0200003, theta=12.281683 -> V=1.0, theta=0.0
% INFO    : Bus 63991	: V=0.9911558, theta=34.417241 -> V=1.0, theta=0.0
% INFO    : Bus 63992	: V=0.9839646, theta=8.612142 -> V=1.0, theta=0.0
% INFO    : Bus 63993	: V=0.9829208, theta=8.841416 -> V=1.0, theta=0.0
% INFO    : Bus 63994	: V=0.9831924, theta=9.011732 -> V=1.0, theta=0.0
% INFO    : Bus 63995	: V=0.9836843, theta=9.215979 -> V=1.0, theta=0.0
% INFO    : Bus 63996	: V=0.983405, theta=9.47331 -> V=1.0, theta=0.0
% INFO    : Bus 63997	: V=0.9839897, theta=9.946011 -> V=1.0, theta=0.0
% INFO    : Bus 63998	: V=0.9800915, theta=8.635501 -> V=1.0, theta=0.0
% INFO    : Bus 63999	: V=0.9761608, theta=8.466953 -> V=1.0, theta=0.0
% INFO    : Bus 64000	: V=0.9832042, theta=8.593626 -> V=1.0, theta=0.0
% INFO    : Bus 64001	: V=0.9797287, theta=8.156228 -> V=1.0, theta=0.0
% INFO    : Bus 64002	: V=0.9850422, theta=9.301116 -> V=1.0, theta=0.0
% INFO    : Bus 64003	: V=0.9738318, theta=7.812952 -> V=1.0, theta=0.0
% INFO    : Bus 64004	: V=0.9839363, theta=8.964826 -> V=1.0, theta=0.0
% INFO    : Bus 64005	: V=0.982386, theta=8.754966 -> V=1.0, theta=0.0
% INFO    : Bus 64006	: V=0.977163, theta=7.798198 -> V=1.0, theta=0.0
% INFO    : Bus 64007	: V=0.9842146, theta=8.764682 -> V=1.0, theta=0.0
% INFO    : Bus 64008	: V=0.9897872, theta=10.262964 -> V=1.0, theta=0.0
% INFO    : Bus 64009	: V=0.9899974, theta=10.161707 -> V=1.0, theta=0.0
% INFO    : Bus 64010	: V=0.9869929, theta=7.820287 -> V=1.0, theta=0.0
% INFO    : Bus 64011	: V=0.9862138, theta=7.832391 -> V=1.0, theta=0.0
% INFO    : Bus 64012	: V=0.9855071, theta=7.815792 -> V=1.0, theta=0.0
% INFO    : Bus 64013	: V=0.9834438, theta=7.389034 -> V=1.0, theta=0.0
% INFO    : Bus 64014	: V=0.981737, theta=7.413541 -> V=1.0, theta=0.0
% INFO    : Bus 64015	: V=0.9810977, theta=7.435557 -> V=1.0, theta=0.0
% INFO    : Bus 64016	: V=0.9801209, theta=7.079245 -> V=1.0, theta=0.0
% INFO    : Bus 64017	: V=0.9809651, theta=7.480357 -> V=1.0, theta=0.0
% INFO    : Bus 64018	: V=0.9788751, theta=7.099911 -> V=1.0, theta=0.0
% INFO    : Bus 64019	: V=0.9886317, theta=9.988505 -> V=1.0, theta=0.0
% INFO    : Bus 64020	: V=0.987554, theta=9.120948 -> V=1.0, theta=0.0
% INFO    : Bus 64021	: V=0.9881164, theta=8.01132 -> V=1.0, theta=0.0
% INFO    : Bus 64022	: V=0.9816617, theta=8.457895 -> V=1.0, theta=0.0
% INFO    : Bus 64023	: V=0.9873386, theta=7.94244 -> V=1.0, theta=0.0
% INFO    : Bus 64024	: V=0.9867576, theta=9.681778 -> V=1.0, theta=0.0
% INFO    : Bus 64025	: V=0.9877436, theta=7.954123 -> V=1.0, theta=0.0
% INFO    : Bus 64026	: V=0.9870882, theta=7.910783 -> V=1.0, theta=0.0
% INFO    : Bus 64027	: V=0.9955918, theta=9.459738 -> V=1.0, theta=0.0
% INFO    : Bus 64028	: V=0.9957158, theta=9.418782 -> V=1.0, theta=0.0
% INFO    : Bus 64029	: V=0.9851175, theta=7.867005 -> V=1.0, theta=0.0
% INFO    : Bus 64030	: V=0.9864466, theta=7.886255 -> V=1.0, theta=0.0
% INFO    : Bus 64031	: V=0.985433, theta=9.509313 -> V=1.0, theta=0.0
% INFO    : Bus 64032	: V=0.9920617, theta=9.769107 -> V=1.0, theta=0.0
% INFO    : Bus 64033	: V=0.9827802, theta=7.74207 -> V=1.0, theta=0.0
% INFO    : Bus 64034	: V=0.9853584, theta=9.511313 -> V=1.0, theta=0.0
% INFO    : Bus 64035	: V=0.9810553, theta=7.225129 -> V=1.0, theta=0.0
% INFO    : Bus 64036	: V=0.9823784, theta=7.368254 -> V=1.0, theta=0.0
% INFO    : Bus 64037	: V=0.9815762, theta=7.559244 -> V=1.0, theta=0.0
% INFO    : Bus 64038	: V=0.9939151, theta=10.532109 -> V=1.0, theta=0.0
% INFO    : Bus 64039	: V=0.9926352, theta=10.530361 -> V=1.0, theta=0.0
% INFO    : Bus 64040	: V=0.985777, theta=7.959432 -> V=1.0, theta=0.0
% INFO    : Bus 64041	: V=0.9988307, theta=12.638363 -> V=1.0, theta=0.0
% INFO    : Bus 64042	: V=0.9853338, theta=11.198374 -> V=1.0, theta=0.0
% INFO    : Bus 64043	: V=0.9915191, theta=11.498579 -> V=1.0, theta=0.0
% INFO    : Bus 64044	: V=0.9889018, theta=9.152238 -> V=1.0, theta=0.0
% INFO    : Bus 64045	: V=0.9920571, theta=10.38003 -> V=1.0, theta=0.0
% INFO    : Bus 64046	: V=0.993556, theta=11.054093 -> V=1.0, theta=0.0
% INFO    : Bus 64047	: V=0.998646, theta=13.260676 -> V=1.0, theta=0.0
% INFO    : Bus 64048	: V=0.9926898, theta=11.254974 -> V=1.0, theta=0.0
% INFO    : Bus 64049	: V=0.9856521, theta=11.535127 -> V=1.0, theta=0.0
% INFO    : Bus 64050	: V=0.9891034, theta=12.503882 -> V=1.0, theta=0.0
% INFO    : Bus 64051	: V=0.9926886, theta=10.758901 -> V=1.0, theta=0.0
% INFO    : Bus 64052	: V=0.9883969, theta=10.64785 -> V=1.0, theta=0.0
% INFO    : Bus 64053	: V=0.9854492, theta=20.220943 -> V=1.0, theta=0.0
% INFO    : Bus 64054	: V=0.9974626, theta=21.833591 -> V=1.0, theta=0.0
% INFO    : Bus 64055	: V=0.9935365, theta=22.015188 -> V=1.0, theta=0.0
% INFO    : Bus 64056	: V=0.9953896, theta=21.985067 -> V=1.0, theta=0.0
% INFO    : Bus 64057	: V=0.974628, theta=17.625578 -> V=1.0, theta=0.0
% INFO    : Bus 64058	: V=0.9802063, theta=18.113997 -> V=1.0, theta=0.0
% INFO    : Bus 64059	: V=0.9830452, theta=18.890585 -> V=1.0, theta=0.0
% INFO    : Bus 64060	: V=0.9791407, theta=18.077754 -> V=1.0, theta=0.0
% INFO    : Bus 64061	: V=0.9811817, theta=17.661272 -> V=1.0, theta=0.0
% INFO    : Bus 64062	: V=0.9720201, theta=17.210307 -> V=1.0, theta=0.0
% INFO    : Bus 64063	: V=0.9977255, theta=18.143727 -> V=1.0, theta=0.0
% INFO    : Bus 64064	: V=0.9803769, theta=17.278165 -> V=1.0, theta=0.0
% INFO    : Bus 64065	: V=0.9803652, theta=16.930755 -> V=1.0, theta=0.0
% INFO    : Bus 64066	: V=0.9765312, theta=16.815373 -> V=1.0, theta=0.0
% INFO    : Bus 64067	: V=0.9959807, theta=18.845154 -> V=1.0, theta=0.0
% INFO    : Bus 64068	: V=0.9759284, theta=8.70744 -> V=1.0, theta=0.0
% INFO    : Bus 64069	: V=0.9855031, theta=13.8266 -> V=1.0, theta=0.0
% INFO    : Bus 64070	: V=0.9844007, theta=10.386849 -> V=1.0, theta=0.0
% INFO    : Bus 64071	: V=0.985618, theta=11.125774 -> V=1.0, theta=0.0
% INFO    : Bus 64072	: V=0.9871858, theta=11.890016 -> V=1.0, theta=0.0
% INFO    : Bus 64073	: V=0.9824925, theta=11.844339 -> V=1.0, theta=0.0
% INFO    : Bus 64074	: V=1.0029473, theta=16.191722 -> V=1.0, theta=0.0
% INFO    : Bus 64075	: V=0.9995611, theta=15.726859 -> V=1.0, theta=0.0
% INFO    : Bus 64076	: V=1.0018081, theta=16.035443 -> V=1.0, theta=0.0
% INFO    : Bus 64077	: V=0.9992366, theta=15.537792 -> V=1.0, theta=0.0
% INFO    : Bus 64078	: V=0.9993911, theta=15.578565 -> V=1.0, theta=0.0
% INFO    : Bus 64079	: V=1.0200003, theta=20.49272 -> V=1.0, theta=0.0
% INFO    : Bus 64080	: V=0.999319, theta=15.638081 -> V=1.0, theta=0.0
% INFO    : Bus 64081	: V=0.9994642, theta=15.646109 -> V=1.0, theta=0.0
% INFO    : Bus 64082	: V=0.9996507, theta=15.723322 -> V=1.0, theta=0.0
% INFO    : Bus 64083	: V=1.0035058, theta=16.42484 -> V=1.0, theta=0.0
% INFO    : Bus 64084	: V=1.0000352, theta=15.686821 -> V=1.0, theta=0.0
% INFO    : Bus 64085	: V=1.0003324, theta=15.675775 -> V=1.0, theta=0.0
% INFO    : Bus 64086	: V=1.0002733, theta=15.647927 -> V=1.0, theta=0.0
% INFO    : Bus 64087	: V=1.0001973, theta=15.608363 -> V=1.0, theta=0.0
% INFO    : Bus 64088	: V=0.9971093, theta=15.09455 -> V=1.0, theta=0.0
% INFO    : Bus 64089	: V=1.0086895, theta=16.399683 -> V=1.0, theta=0.0
% INFO    : Bus 64090	: V=0.9980126, theta=15.113436 -> V=1.0, theta=0.0
% INFO    : Bus 64091	: V=1.0036389, theta=15.814416 -> V=1.0, theta=0.0
% INFO    : Bus 64092	: V=1.0024272, theta=15.732799 -> V=1.0, theta=0.0
% INFO    : Bus 64093	: V=1.0007755, theta=15.687815 -> V=1.0, theta=0.0
% INFO    : Bus 64094	: V=1.0011859, theta=15.727311 -> V=1.0, theta=0.0
% INFO    : Bus 64095	: V=1.0020789, theta=15.798036 -> V=1.0, theta=0.0
% INFO    : Bus 64096	: V=1.003755, theta=16.53249 -> V=1.0, theta=0.0
% INFO    : Bus 64097	: V=1.0034069, theta=16.583196 -> V=1.0, theta=0.0
% INFO    : Bus 64098	: V=1.0044358, theta=16.642478 -> V=1.0, theta=0.0
% INFO    : Bus 64099	: V=1.0036859, theta=16.693397 -> V=1.0, theta=0.0
% INFO    : Bus 64100	: V=1.0041238, theta=15.890777 -> V=1.0, theta=0.0
% INFO    : Bus 64101	: V=1.0091706, theta=16.747004 -> V=1.0, theta=0.0
% INFO    : Bus 64102	: V=1.008923, theta=16.50856 -> V=1.0, theta=0.0
% INFO    : Bus 64103	: V=0.9992794, theta=15.493873 -> V=1.0, theta=0.0
% INFO    : Bus 64104	: V=1.0004801, theta=15.518245 -> V=1.0, theta=0.0
% INFO    : Bus 64105	: V=1.0070843, theta=16.841547 -> V=1.0, theta=0.0
% INFO    : Bus 64106	: V=1.006659, theta=17.001523 -> V=1.0, theta=0.0
% INFO    : Bus 64107	: V=1.0006074, theta=15.584811 -> V=1.0, theta=0.0
% INFO    : Bus 64108	: V=1.0093443, theta=16.681091 -> V=1.0, theta=0.0
% INFO    : Bus 64109	: V=0.999046, theta=15.557056 -> V=1.0, theta=0.0
% INFO    : Bus 64110	: V=1.0072722, theta=17.505346 -> V=1.0, theta=0.0
% INFO    : Bus 64111	: V=1.0002228, theta=15.65413 -> V=1.0, theta=0.0
% INFO    : Bus 64112	: V=1.0054637, theta=17.421288 -> V=1.0, theta=0.0
% INFO    : Bus 64113	: V=1.0017376, theta=16.013174 -> V=1.0, theta=0.0
% INFO    : Bus 64114	: V=1.0009223, theta=15.983213 -> V=1.0, theta=0.0
% INFO    : Bus 64115	: V=0.9956371, theta=15.266101 -> V=1.0, theta=0.0
% INFO    : Bus 64116	: V=1.0100003, theta=15.726521 -> V=1.0, theta=0.0
% INFO    : Bus 64117	: V=1.0010007, theta=15.27024 -> V=1.0, theta=0.0
% INFO    : Bus 64118	: V=1.0021329, theta=15.295922 -> V=1.0, theta=0.0
% INFO    : Bus 64119	: V=1.0036826, theta=15.47514 -> V=1.0, theta=0.0
% INFO    : Bus 64120	: V=1.002161, theta=15.30882 -> V=1.0, theta=0.0
% INFO    : Bus 64121	: V=1.0023254, theta=15.381383 -> V=1.0, theta=0.0
% INFO    : Bus 64122	: V=1.0136851, theta=17.252205 -> V=1.0, theta=0.0
% INFO    : Bus 64123	: V=1.0090734, theta=15.790279 -> V=1.0, theta=0.0
% INFO    : Bus 64124	: V=0.9935973, theta=13.868984 -> V=1.0, theta=0.0
% INFO    : Bus 64125	: V=0.994342, theta=16.326662 -> V=1.0, theta=0.0
% INFO    : Bus 64126	: V=1.0002695, theta=15.449085 -> V=1.0, theta=0.0
% INFO    : Bus 64127	: V=0.9991317, theta=15.256471 -> V=1.0, theta=0.0
% INFO    : Bus 64128	: V=0.999863, theta=18.184321 -> V=1.0, theta=0.0
% INFO    : Bus 64129	: V=1.0032309, theta=16.806688 -> V=1.0, theta=0.0
% INFO    : Bus 64130	: V=1.0054649, theta=16.996852 -> V=1.0, theta=0.0
% INFO    : Bus 64131	: V=1.0058533, theta=17.263398 -> V=1.0, theta=0.0
% INFO    : Bus 64132	: V=1.0019536, theta=17.114041 -> V=1.0, theta=0.0
% INFO    : Bus 64133	: V=1.0081532, theta=19.224985 -> V=1.0, theta=0.0
% INFO    : Bus 64134	: V=1.0068541, theta=17.494577 -> V=1.0, theta=0.0
% INFO    : Bus 64135	: V=1.007334, theta=17.538228 -> V=1.0, theta=0.0
% INFO    : Bus 64136	: V=1.001495, theta=24.423024 -> V=1.0, theta=0.0
% INFO    : Bus 64137	: V=1.0300003, theta=21.479856 -> V=1.0, theta=0.0
% INFO    : Bus 64138	: V=1.007544, theta=19.144001 -> V=1.0, theta=0.0
% INFO    : Bus 64139	: V=1.0087311, theta=19.643064 -> V=1.0, theta=0.0
% INFO    : Bus 64140	: V=1.0086056, theta=19.683969 -> V=1.0, theta=0.0
% INFO    : Bus 64141	: V=1.0059251, theta=19.187528 -> V=1.0, theta=0.0
% INFO    : Bus 64142	: V=1.0097707, theta=20.468856 -> V=1.0, theta=0.0
% INFO    : Bus 64143	: V=1.0009849, theta=19.037322 -> V=1.0, theta=0.0
% INFO    : Bus 64144	: V=1.0121126, theta=24.396669 -> V=1.0, theta=0.0
% INFO    : Bus 64145	: V=1.0025276, theta=18.584481 -> V=1.0, theta=0.0
% INFO    : Bus 64146	: V=0.9872265, theta=17.811967 -> V=1.0, theta=0.0
% INFO    : Bus 64147	: V=1.0051224, theta=18.948246 -> V=1.0, theta=0.0
% INFO    : Bus 64148	: V=0.9975904, theta=14.914434 -> V=1.0, theta=0.0
% INFO    : Bus 64149	: V=0.9935254, theta=14.6971 -> V=1.0, theta=0.0
% INFO    : Bus 64150	: V=0.9937744, theta=14.701633 -> V=1.0, theta=0.0
% INFO    : Bus 64151	: V=0.9971858, theta=15.775201 -> V=1.0, theta=0.0
% INFO    : Bus 64152	: V=0.9964993, theta=15.749477 -> V=1.0, theta=0.0
% INFO    : Bus 64153	: V=1.001059, theta=15.921399 -> V=1.0, theta=0.0
% INFO    : Bus 64154	: V=0.9994017, theta=15.899421 -> V=1.0, theta=0.0
% INFO    : Bus 64155	: V=0.9983288, theta=15.83363 -> V=1.0, theta=0.0
% INFO    : Bus 64156	: V=1.0002755, theta=16.364648 -> V=1.0, theta=0.0
% INFO    : Bus 64157	: V=0.9863465, theta=14.23952 -> V=1.0, theta=0.0
% INFO    : Bus 64158	: V=0.9915297, theta=14.769339 -> V=1.0, theta=0.0
% INFO    : Bus 64159	: V=0.993192, theta=14.883372 -> V=1.0, theta=0.0
% INFO    : Bus 64160	: V=0.9915126, theta=14.812209 -> V=1.0, theta=0.0
% INFO    : Bus 64161	: V=0.9892844, theta=14.62543 -> V=1.0, theta=0.0
% INFO    : Bus 64162	: V=0.9903691, theta=14.685717 -> V=1.0, theta=0.0
% INFO    : Bus 64163	: V=0.9918497, theta=14.79834 -> V=1.0, theta=0.0
% INFO    : Bus 64164	: V=0.9916166, theta=14.733785 -> V=1.0, theta=0.0
% INFO    : Bus 64165	: V=1.0057378, theta=16.841875 -> V=1.0, theta=0.0
% INFO    : Bus 64166	: V=1.0006676, theta=16.260018 -> V=1.0, theta=0.0
% INFO    : Bus 64167	: V=1.0062919, theta=17.006212 -> V=1.0, theta=0.0
% INFO    : Bus 64168	: V=1.0066041, theta=17.138148 -> V=1.0, theta=0.0
% INFO    : Bus 64169	: V=0.9932241, theta=14.880861 -> V=1.0, theta=0.0
% INFO    : Bus 64170	: V=0.9995156, theta=15.993215 -> V=1.0, theta=0.0
% INFO    : Bus 64171	: V=0.9948412, theta=15.01472 -> V=1.0, theta=0.0
% INFO    : Bus 64172	: V=0.9977063, theta=15.648056 -> V=1.0, theta=0.0
% INFO    : Bus 64173	: V=0.9999708, theta=16.135491 -> V=1.0, theta=0.0
% INFO    : Bus 64174	: V=0.9983326, theta=15.670526 -> V=1.0, theta=0.0
% INFO    : Bus 64175	: V=1.0009241, theta=16.372981 -> V=1.0, theta=0.0
% INFO    : Bus 64176	: V=1.0020983, theta=16.54779 -> V=1.0, theta=0.0
% INFO    : Bus 64177	: V=0.9997517, theta=16.227212 -> V=1.0, theta=0.0
% INFO    : Bus 64178	: V=1.0030366, theta=16.736136 -> V=1.0, theta=0.0
% INFO    : Bus 64179	: V=1.0041048, theta=16.917689 -> V=1.0, theta=0.0
% INFO    : Bus 64180	: V=1.000604, theta=16.276029 -> V=1.0, theta=0.0
% INFO    : Bus 64181	: V=1.002301, theta=16.46825 -> V=1.0, theta=0.0
% INFO    : Bus 64182	: V=1.001631, theta=16.453802 -> V=1.0, theta=0.0
% INFO    : Bus 64183	: V=1.0042828, theta=16.766633 -> V=1.0, theta=0.0
% INFO    : Bus 64184	: V=0.998588, theta=15.246931 -> V=1.0, theta=0.0
% INFO    : Bus 64185	: V=0.9996115, theta=15.329814 -> V=1.0, theta=0.0
% INFO    : Bus 64186	: V=0.9964069, theta=14.882492 -> V=1.0, theta=0.0
% INFO    : Bus 64187	: V=0.9899753, theta=14.348852 -> V=1.0, theta=0.0
% INFO    : Bus 64188	: V=0.9957272, theta=15.732649 -> V=1.0, theta=0.0
% INFO    : Bus 64189	: V=0.9901862, theta=14.365746 -> V=1.0, theta=0.0
% INFO    : Bus 64190	: V=0.9959108, theta=14.78465 -> V=1.0, theta=0.0
% INFO    : Bus 64191	: V=0.9900797, theta=14.368375 -> V=1.0, theta=0.0
% INFO    : Bus 64192	: V=0.9911646, theta=14.349083 -> V=1.0, theta=0.0
% INFO    : Bus 64193	: V=0.9955544, theta=14.55782 -> V=1.0, theta=0.0
% INFO    : Bus 64194	: V=0.9937367, theta=14.181009 -> V=1.0, theta=0.0
% INFO    : Bus 64195	: V=0.9876978, theta=13.713972 -> V=1.0, theta=0.0
% INFO    : Bus 64196	: V=0.9917265, theta=13.595478 -> V=1.0, theta=0.0
% INFO    : Bus 64197	: V=0.9861634, theta=14.06968 -> V=1.0, theta=0.0
% INFO    : Bus 64198	: V=0.994038, theta=15.853909 -> V=1.0, theta=0.0
% INFO    : Bus 64199	: V=0.9841974, theta=14.322224 -> V=1.0, theta=0.0
% INFO    : Bus 64200	: V=1.0027311, theta=15.809494 -> V=1.0, theta=0.0
% INFO    : Bus 64201	: V=0.9980955, theta=15.514262 -> V=1.0, theta=0.0
% INFO    : Bus 64202	: V=0.999692, theta=15.359917 -> V=1.0, theta=0.0
% INFO    : Bus 64203	: V=0.9997489, theta=15.516928 -> V=1.0, theta=0.0
% INFO    : Bus 64204	: V=0.9729813, theta=17.622996 -> V=1.0, theta=0.0
% INFO    : Bus 64205	: V=0.9881847, theta=17.502174 -> V=1.0, theta=0.0
% INFO    : Bus 64206	: V=0.9785681, theta=16.032031 -> V=1.0, theta=0.0
% INFO    : Bus 64207	: V=0.9861125, theta=16.541082 -> V=1.0, theta=0.0
% INFO    : Bus 64208	: V=0.9816009, theta=16.531152 -> V=1.0, theta=0.0
% INFO    : Bus 64209	: V=0.9876352, theta=16.166194 -> V=1.0, theta=0.0
% INFO    : Bus 64210	: V=0.9884736, theta=15.910737 -> V=1.0, theta=0.0
% INFO    : Bus 64211	: V=0.9945376, theta=17.394319 -> V=1.0, theta=0.0
% INFO    : Bus 64212	: V=0.9879588, theta=17.316925 -> V=1.0, theta=0.0
% INFO    : Bus 64213	: V=0.9902206, theta=17.38244 -> V=1.0, theta=0.0
% INFO    : Bus 64214	: V=0.9750563, theta=17.545914 -> V=1.0, theta=0.0
% INFO    : Bus 64215	: V=0.9889883, theta=15.960694 -> V=1.0, theta=0.0
% INFO    : Bus 64216	: V=0.9817951, theta=18.792871 -> V=1.0, theta=0.0
% INFO    : Bus 64217	: V=0.989452, theta=17.408956 -> V=1.0, theta=0.0
% INFO    : Bus 64218	: V=0.9801304, theta=21.782023 -> V=1.0, theta=0.0
% INFO    : Bus 64219	: V=0.9963037, theta=22.756358 -> V=1.0, theta=0.0
% INFO    : Bus 64220	: V=0.9922534, theta=21.649163 -> V=1.0, theta=0.0
% INFO    : Bus 64221	: V=0.9892109, theta=21.613782 -> V=1.0, theta=0.0
% INFO    : Bus 64222	: V=0.9953658, theta=22.156416 -> V=1.0, theta=0.0
% INFO    : Bus 64223	: V=0.9859847, theta=21.015455 -> V=1.0, theta=0.0
% INFO    : Bus 64224	: V=0.999795, theta=24.730547 -> V=1.0, theta=0.0
% INFO    : Bus 64225	: V=1.0030931, theta=24.207747 -> V=1.0, theta=0.0
% INFO    : Bus 64226	: V=1.0025619, theta=25.007568 -> V=1.0, theta=0.0
% INFO    : Bus 64227	: V=1.007261, theta=25.64012 -> V=1.0, theta=0.0
% INFO    : Bus 64228	: V=0.9768671, theta=22.074256 -> V=1.0, theta=0.0
% INFO    : Bus 64229	: V=1.0154116, theta=16.509663 -> V=1.0, theta=0.0
% INFO    : Bus 64230	: V=0.9904886, theta=15.123571 -> V=1.0, theta=0.0
% INFO    : Bus 64231	: V=0.9669488, theta=12.309839 -> V=1.0, theta=0.0
% INFO    : Bus 64232	: V=1.0026388, theta=15.965428 -> V=1.0, theta=0.0
% INFO    : Bus 64233	: V=1.0015349, theta=20.913651 -> V=1.0, theta=0.0
% INFO    : Bus 64234	: V=1.0037553, theta=21.897611 -> V=1.0, theta=0.0
% INFO    : Bus 64235	: V=0.9783826, theta=19.51338 -> V=1.0, theta=0.0
% INFO    : Bus 64236	: V=1.0055779, theta=23.857315 -> V=1.0, theta=0.0
% INFO    : Bus 64237	: V=0.9806716, theta=26.157731 -> V=1.0, theta=0.0
% INFO    : Bus 64238	: V=1.0128956, theta=20.892008 -> V=1.0, theta=0.0
% INFO    : Bus 64239	: V=1.0044349, theta=19.426454 -> V=1.0, theta=0.0
% INFO    : Bus 64240	: V=1.0193497, theta=25.413983 -> V=1.0, theta=0.0
% INFO    : Bus 64241	: V=0.9975053, theta=10.428269 -> V=1.0, theta=0.0
% INFO    : Bus 64242	: V=0.9959053, theta=10.258245 -> V=1.0, theta=0.0
% INFO    : Bus 64243	: V=1.0302514, theta=18.321159 -> V=1.0, theta=0.0
% INFO    : Bus 64244	: V=0.9919515, theta=9.601551 -> V=1.0, theta=0.0
% INFO    : Bus 64245	: V=0.9977709, theta=11.501139 -> V=1.0, theta=0.0
% INFO    : Bus 64246	: V=0.9945088, theta=10.78648 -> V=1.0, theta=0.0
% INFO    : Bus 64247	: V=0.9951126, theta=10.898073 -> V=1.0, theta=0.0
% INFO    : Bus 64248	: V=0.9966609, theta=11.198071 -> V=1.0, theta=0.0
% INFO    : Bus 64249	: V=0.9970536, theta=11.308415 -> V=1.0, theta=0.0
% INFO    : Bus 64250	: V=0.9911924, theta=9.454228 -> V=1.0, theta=0.0
% INFO    : Bus 64251	: V=0.9939846, theta=10.606646 -> V=1.0, theta=0.0
% INFO    : Bus 64252	: V=0.9931713, theta=10.340184 -> V=1.0, theta=0.0
% INFO    : Bus 64253	: V=0.9903397, theta=9.311563 -> V=1.0, theta=0.0
% INFO    : Bus 64254	: V=0.9908543, theta=9.391935 -> V=1.0, theta=0.0
% INFO    : Bus 64255	: V=0.9907773, theta=9.32713 -> V=1.0, theta=0.0
% INFO    : Bus 64256	: V=0.9959737, theta=9.95134 -> V=1.0, theta=0.0
% INFO    : Bus 64257	: V=1.0078903, theta=12.587444 -> V=1.0, theta=0.0
% INFO    : Bus 64258	: V=1.0039943, theta=11.701493 -> V=1.0, theta=0.0
% INFO    : Bus 64259	: V=1.0019108, theta=11.238981 -> V=1.0, theta=0.0
% INFO    : Bus 64260	: V=0.9960149, theta=9.861551 -> V=1.0, theta=0.0
% INFO    : Bus 64261	: V=0.995164, theta=9.778549 -> V=1.0, theta=0.0
% INFO    : Bus 64262	: V=0.99991, theta=10.827398 -> V=1.0, theta=0.0
% INFO    : Bus 64263	: V=0.9878391, theta=7.91385 -> V=1.0, theta=0.0
% INFO    : Bus 64264	: V=0.9942326, theta=10.811303 -> V=1.0, theta=0.0
% INFO    : Bus 64265	: V=0.9963549, theta=11.482016 -> V=1.0, theta=0.0
% INFO    : Bus 64266	: V=0.9971139, theta=12.266243 -> V=1.0, theta=0.0
% INFO    : Bus 64267	: V=0.9981886, theta=12.034967 -> V=1.0, theta=0.0
% INFO    : Bus 64268	: V=0.992508, theta=10.267592 -> V=1.0, theta=0.0
% INFO    : Bus 64269	: V=0.9898462, theta=10.574851 -> V=1.0, theta=0.0
% INFO    : Bus 64270	: V=1.0004351, theta=10.896302 -> V=1.0, theta=0.0
% INFO    : Bus 64271	: V=1.0200003, theta=15.430554 -> V=1.0, theta=0.0
% INFO    : Bus 64272	: V=0.9952301, theta=10.271857 -> V=1.0, theta=0.0
% INFO    : Bus 64273	: V=0.9910651, theta=9.056658 -> V=1.0, theta=0.0
% INFO    : Bus 64274	: V=0.9928448, theta=10.069474 -> V=1.0, theta=0.0
% INFO    : Bus 64275	: V=0.9926821, theta=9.530988 -> V=1.0, theta=0.0
% INFO    : Bus 64276	: V=0.9901028, theta=9.142571 -> V=1.0, theta=0.0
% INFO    : Bus 64277	: V=0.9892946, theta=8.975945 -> V=1.0, theta=0.0
% INFO    : Bus 64278	: V=0.9893593, theta=9.005385 -> V=1.0, theta=0.0
% INFO    : Bus 64279	: V=0.9903582, theta=8.969643 -> V=1.0, theta=0.0
% INFO    : Bus 64280	: V=0.9889255, theta=8.829842 -> V=1.0, theta=0.0
% INFO    : Bus 64281	: V=0.9941737, theta=9.879608 -> V=1.0, theta=0.0
% INFO    : Bus 64282	: V=0.9936217, theta=9.764961 -> V=1.0, theta=0.0
% INFO    : Bus 64283	: V=0.9942819, theta=9.682954 -> V=1.0, theta=0.0
% INFO    : Bus 64284	: V=0.9959169, theta=10.193519 -> V=1.0, theta=0.0
% INFO    : Bus 64285	: V=0.9877231, theta=8.621696 -> V=1.0, theta=0.0
% INFO    : Bus 64286	: V=0.9980727, theta=10.539372 -> V=1.0, theta=0.0
% INFO    : Bus 64287	: V=0.9968014, theta=10.342031 -> V=1.0, theta=0.0
% INFO    : Bus 64288	: V=0.9839772, theta=8.050777 -> V=1.0, theta=0.0
% INFO    : Bus 64289	: V=0.995535, theta=9.699446 -> V=1.0, theta=0.0
% INFO    : Bus 64290	: V=0.994753, theta=9.459758 -> V=1.0, theta=0.0
% INFO    : Bus 64291	: V=0.9864137, theta=8.400901 -> V=1.0, theta=0.0
% INFO    : Bus 64292	: V=0.9937289, theta=9.573621 -> V=1.0, theta=0.0
% INFO    : Bus 64293	: V=0.9938515, theta=9.103243 -> V=1.0, theta=0.0
% INFO    : Bus 64294	: V=0.9870182, theta=7.990778 -> V=1.0, theta=0.0
% INFO    : Bus 64295	: V=0.9860255, theta=7.920804 -> V=1.0, theta=0.0
% INFO    : Bus 64296	: V=0.9909427, theta=8.615178 -> V=1.0, theta=0.0
% INFO    : Bus 64297	: V=0.9903588, theta=8.594905 -> V=1.0, theta=0.0
% INFO    : Bus 64298	: V=0.9938576, theta=8.925461 -> V=1.0, theta=0.0
% INFO    : Bus 64299	: V=0.992849, theta=8.991215 -> V=1.0, theta=0.0
% INFO    : Bus 64300	: V=0.9853152, theta=7.882011 -> V=1.0, theta=0.0
% INFO    : Bus 64301	: V=0.9910193, theta=9.756736 -> V=1.0, theta=0.0
% INFO    : Bus 64302	: V=0.9915658, theta=9.629947 -> V=1.0, theta=0.0
% INFO    : Bus 64303	: V=0.983391, theta=7.675302 -> V=1.0, theta=0.0
% INFO    : Bus 64304	: V=0.9836534, theta=7.716107 -> V=1.0, theta=0.0
% INFO    : Bus 64305	: V=0.9903817, theta=9.508623 -> V=1.0, theta=0.0
% INFO    : Bus 64306	: V=0.9864722, theta=7.774602 -> V=1.0, theta=0.0
% INFO    : Bus 64307	: V=0.9850463, theta=7.601078 -> V=1.0, theta=0.0
% INFO    : Bus 64308	: V=0.9839608, theta=7.61109 -> V=1.0, theta=0.0
% INFO    : Bus 64309	: V=0.983292, theta=7.396935 -> V=1.0, theta=0.0
% INFO    : Bus 64310	: V=0.982683, theta=7.372348 -> V=1.0, theta=0.0
% INFO    : Bus 64311	: V=0.982475, theta=7.348773 -> V=1.0, theta=0.0
% INFO    : Bus 64312	: V=0.9897789, theta=9.462117 -> V=1.0, theta=0.0
% INFO    : Bus 64313	: V=0.9790674, theta=7.270821 -> V=1.0, theta=0.0
% INFO    : Bus 64314	: V=0.9829793, theta=7.893048 -> V=1.0, theta=0.0
% INFO    : Bus 64315	: V=0.9821541, theta=7.590007 -> V=1.0, theta=0.0
% INFO    : Bus 64316	: V=0.9811337, theta=7.476296 -> V=1.0, theta=0.0
% INFO    : Bus 64317	: V=0.9830446, theta=7.823688 -> V=1.0, theta=0.0
% INFO    : Bus 64318	: V=0.981904, theta=7.711814 -> V=1.0, theta=0.0
% INFO    : Bus 64319	: V=0.9858071, theta=8.777715 -> V=1.0, theta=0.0
% INFO    : Bus 64320	: V=0.9937495, theta=10.060368 -> V=1.0, theta=0.0
% INFO    : Bus 64321	: V=0.9892527, theta=9.450689 -> V=1.0, theta=0.0
% INFO    : Bus 64322	: V=0.9834354, theta=8.68772 -> V=1.0, theta=0.0
% INFO    : Bus 64323	: V=0.9812147, theta=7.691741 -> V=1.0, theta=0.0
% INFO    : Bus 64324	: V=0.9811274, theta=7.636183 -> V=1.0, theta=0.0
% INFO    : Bus 64325	: V=0.980057, theta=7.342158 -> V=1.0, theta=0.0
% INFO    : Bus 64326	: V=0.9801424, theta=7.318208 -> V=1.0, theta=0.0
% INFO    : Bus 64327	: V=0.9795132, theta=7.11899 -> V=1.0, theta=0.0
% INFO    : Bus 64328	: V=0.980423, theta=7.295123 -> V=1.0, theta=0.0
% INFO    : Bus 64329	: V=0.984739, theta=7.977326 -> V=1.0, theta=0.0
% INFO    : Bus 64330	: V=0.9903512, theta=9.626982 -> V=1.0, theta=0.0
% INFO    : Bus 64331	: V=0.9898618, theta=9.540568 -> V=1.0, theta=0.0
% INFO    : Bus 64332	: V=0.9825961, theta=7.38314 -> V=1.0, theta=0.0
% INFO    : Bus 64333	: V=0.9821377, theta=7.359192 -> V=1.0, theta=0.0
% INFO    : Bus 64334	: V=0.9894581, theta=9.42999 -> V=1.0, theta=0.0
% INFO    : Bus 64335	: V=0.9888975, theta=9.354114 -> V=1.0, theta=0.0
% INFO    : Bus 64336	: V=0.9773505, theta=6.853233 -> V=1.0, theta=0.0
% INFO    : Bus 64337	: V=0.9782089, theta=6.822955 -> V=1.0, theta=0.0
% INFO    : Bus 64338	: V=0.9830536, theta=8.455562 -> V=1.0, theta=0.0
% INFO    : Bus 64339	: V=0.9838715, theta=8.01915 -> V=1.0, theta=0.0
% INFO    : Bus 64340	: V=0.9937642, theta=9.875299 -> V=1.0, theta=0.0
% INFO    : Bus 64341	: V=0.9930444, theta=11.07406 -> V=1.0, theta=0.0
% INFO    : Bus 64342	: V=0.9907794, theta=10.525829 -> V=1.0, theta=0.0
% INFO    : Bus 64343	: V=0.9948604, theta=11.707201 -> V=1.0, theta=0.0
% INFO    : Bus 64344	: V=0.9916154, theta=11.376025 -> V=1.0, theta=0.0
% INFO    : Bus 64345	: V=0.9950708, theta=11.356259 -> V=1.0, theta=0.0
% INFO    : Bus 64346	: V=0.9943274, theta=11.010155 -> V=1.0, theta=0.0
% INFO    : Bus 64347	: V=0.9887776, theta=10.055753 -> V=1.0, theta=0.0
% INFO    : Bus 64348	: V=0.9935891, theta=10.311349 -> V=1.0, theta=0.0
% INFO    : Bus 64349	: V=0.9921856, theta=10.620798 -> V=1.0, theta=0.0
% INFO    : Bus 64350	: V=0.9971784, theta=12.013372 -> V=1.0, theta=0.0
% INFO    : Bus 64351	: V=0.9874467, theta=9.837631 -> V=1.0, theta=0.0
% INFO    : Bus 64352	: V=0.9867031, theta=8.135633 -> V=1.0, theta=0.0
% INFO    : Bus 64353	: V=0.98602, theta=8.016857 -> V=1.0, theta=0.0
% INFO    : Bus 64354	: V=0.9835603, theta=7.812225 -> V=1.0, theta=0.0
% INFO    : Bus 64355	: V=0.9876312, theta=9.865319 -> V=1.0, theta=0.0
% INFO    : Bus 64356	: V=0.9821022, theta=8.406522 -> V=1.0, theta=0.0
% INFO    : Bus 64357	: V=0.9859267, theta=8.293999 -> V=1.0, theta=0.0
% INFO    : Bus 64358	: V=0.9827199, theta=7.969936 -> V=1.0, theta=0.0
% INFO    : Bus 64359	: V=0.9832363, theta=7.982503 -> V=1.0, theta=0.0
% INFO    : Bus 64360	: V=0.9911968, theta=8.537377 -> V=1.0, theta=0.0
% INFO    : Bus 64361	: V=0.9974833, theta=9.585294 -> V=1.0, theta=0.0
% INFO    : Bus 64362	: V=0.9893271, theta=8.247851 -> V=1.0, theta=0.0
% INFO    : Bus 64363	: V=0.99682, theta=9.582641 -> V=1.0, theta=0.0
% INFO    : Bus 64364	: V=0.9847931, theta=8.091033 -> V=1.0, theta=0.0
% INFO    : Bus 64365	: V=0.9952031, theta=8.89481 -> V=1.0, theta=0.0
% INFO    : Bus 64366	: V=0.9845197, theta=7.847386 -> V=1.0, theta=0.0
% INFO    : Bus 64367	: V=0.9943477, theta=8.855187 -> V=1.0, theta=0.0
% INFO    : Bus 64368	: V=0.9820564, theta=7.834196 -> V=1.0, theta=0.0
% INFO    : Bus 64369	: V=0.9916043, theta=11.726235 -> V=1.0, theta=0.0
% INFO    : Bus 64370	: V=0.9832855, theta=7.871333 -> V=1.0, theta=0.0
% INFO    : Bus 64371	: V=0.9827117, theta=7.859588 -> V=1.0, theta=0.0
% INFO    : Bus 64372	: V=0.9848478, theta=7.869086 -> V=1.0, theta=0.0
% INFO    : Bus 64373	: V=0.9825859, theta=7.522501 -> V=1.0, theta=0.0
% INFO    : Bus 64374	: V=0.9948342, theta=10.858953 -> V=1.0, theta=0.0
% INFO    : Bus 64375	: V=0.9938353, theta=10.6094 -> V=1.0, theta=0.0
% INFO    : Bus 64376	: V=1.0040174, theta=12.164985 -> V=1.0, theta=0.0
% INFO    : Bus 64377	: V=0.9845488, theta=7.897343 -> V=1.0, theta=0.0
% INFO    : Bus 64378	: V=0.9823106, theta=7.514738 -> V=1.0, theta=0.0
% INFO    : Bus 64379	: V=0.9842718, theta=21.311388 -> V=1.0, theta=0.0
% INFO    : Bus 64380	: V=1.0150147, theta=26.254291 -> V=1.0, theta=0.0
% INFO    : Bus 64381	: V=1.0111842, theta=25.936678 -> V=1.0, theta=0.0
% INFO    : Bus 64382	: V=1.0078085, theta=24.991393 -> V=1.0, theta=0.0
% INFO    : Bus 64383	: V=1.0261433, theta=23.206981 -> V=1.0, theta=0.0
% INFO    : Bus 64384	: V=1.0367544, theta=25.593576 -> V=1.0, theta=0.0
% INFO    : Bus 64385	: V=0.9826076, theta=33.16373 -> V=1.0, theta=0.0
% INFO    : Bus 64386	: V=0.9812169, theta=38.51983 -> V=1.0, theta=0.0
% INFO    : Bus 64387	: V=0.9859888, theta=30.70868 -> V=1.0, theta=0.0
% INFO    : Bus 64388	: V=0.9844804, theta=33.124737 -> V=1.0, theta=0.0
% INFO    : Bus 64389	: V=0.9797561, theta=32.739929 -> V=1.0, theta=0.0
% INFO    : Bus 64390	: V=0.9861879, theta=30.53755 -> V=1.0, theta=0.0
% INFO    : Bus 64391	: V=0.9869043, theta=32.556507 -> V=1.0, theta=0.0
% INFO    : Bus 64392	: V=0.986759, theta=32.347936 -> V=1.0, theta=0.0
% INFO    : Bus 64393	: V=0.9872179, theta=32.782015 -> V=1.0, theta=0.0
% INFO    : Bus 64394	: V=0.9879851, theta=32.992438 -> V=1.0, theta=0.0
% INFO    : Bus 64395	: V=0.9912825, theta=14.458705 -> V=1.0, theta=0.0
% INFO    : Bus 64396	: V=0.990843, theta=14.445619 -> V=1.0, theta=0.0
% INFO    : Bus 64397	: V=0.990381, theta=14.437165 -> V=1.0, theta=0.0
% INFO    : Bus 64398	: V=1.0200004, theta=20.532792 -> V=1.0, theta=0.0
% INFO    : Bus 64399	: V=0.9935627, theta=14.816774 -> V=1.0, theta=0.0
% INFO    : Bus 64400	: V=0.9983335, theta=16.085763 -> V=1.0, theta=0.0
% INFO    : Bus 64401	: V=0.9927888, theta=14.636538 -> V=1.0, theta=0.0
% INFO    : Bus 64402	: V=0.9923819, theta=14.627052 -> V=1.0, theta=0.0
% INFO    : Bus 64403	: V=0.9979415, theta=16.026741 -> V=1.0, theta=0.0
% INFO    : Bus 64404	: V=0.9971135, theta=15.913493 -> V=1.0, theta=0.0
% INFO    : Bus 64405	: V=0.9912452, theta=14.432767 -> V=1.0, theta=0.0
% INFO    : Bus 64406	: V=0.9898608, theta=14.33517 -> V=1.0, theta=0.0
% INFO    : Bus 64407	: V=0.9902483, theta=14.347349 -> V=1.0, theta=0.0
% INFO    : Bus 64408	: V=0.9901094, theta=14.341461 -> V=1.0, theta=0.0
% INFO    : Bus 64409	: V=0.9895904, theta=14.192223 -> V=1.0, theta=0.0
% INFO    : Bus 64410	: V=0.9900051, theta=14.293063 -> V=1.0, theta=0.0
% INFO    : Bus 64411	: V=0.9889997, theta=14.058344 -> V=1.0, theta=0.0
% INFO    : Bus 64412	: V=0.9918847, theta=15.245337 -> V=1.0, theta=0.0
% INFO    : Bus 64413	: V=0.9881867, theta=13.815216 -> V=1.0, theta=0.0
% INFO    : Bus 64414	: V=0.9879032, theta=13.685249 -> V=1.0, theta=0.0
% INFO    : Bus 64415	: V=0.9846991, theta=12.751603 -> V=1.0, theta=0.0
% INFO    : Bus 64416	: V=0.9836711, theta=12.659594 -> V=1.0, theta=0.0
% INFO    : Bus 64417	: V=0.9959516, theta=15.749625 -> V=1.0, theta=0.0
% INFO    : Bus 64418	: V=0.9891075, theta=13.995013 -> V=1.0, theta=0.0
% INFO    : Bus 64419	: V=0.9948699, theta=15.617419 -> V=1.0, theta=0.0
% INFO    : Bus 64420	: V=0.9870085, theta=13.784702 -> V=1.0, theta=0.0
% INFO    : Bus 64421	: V=0.9925399, theta=14.476005 -> V=1.0, theta=0.0
% INFO    : Bus 64422	: V=0.9903231, theta=14.299336 -> V=1.0, theta=0.0
% INFO    : Bus 64423	: V=0.9918105, theta=14.035238 -> V=1.0, theta=0.0
% INFO    : Bus 64424	: V=0.9881202, theta=13.607349 -> V=1.0, theta=0.0
% INFO    : Bus 64425	: V=0.986375, theta=13.168032 -> V=1.0, theta=0.0
% INFO    : Bus 64426	: V=0.9920767, theta=14.710332 -> V=1.0, theta=0.0
% INFO    : Bus 64427	: V=0.993016, theta=14.667608 -> V=1.0, theta=0.0
% INFO    : Bus 64428	: V=0.9919429, theta=14.536971 -> V=1.0, theta=0.0
% INFO    : Bus 64429	: V=0.9958581, theta=16.06945 -> V=1.0, theta=0.0
% INFO    : Bus 64430	: V=0.9894359, theta=14.475405 -> V=1.0, theta=0.0
% INFO    : Bus 64431	: V=0.9972162, theta=16.832445 -> V=1.0, theta=0.0
% INFO    : Bus 64432	: V=0.9946502, theta=15.663795 -> V=1.0, theta=0.0
% INFO    : Bus 64433	: V=0.9923153, theta=15.306645 -> V=1.0, theta=0.0
% INFO    : Bus 64434	: V=0.98779, theta=13.59815 -> V=1.0, theta=0.0
% INFO    : Bus 64435	: V=0.99154, theta=15.188647 -> V=1.0, theta=0.0
% INFO    : Bus 64436	: V=0.9829635, theta=12.645241 -> V=1.0, theta=0.0
% INFO    : Bus 64437	: V=0.9869028, theta=13.581891 -> V=1.0, theta=0.0
% INFO    : Bus 64438	: V=0.9816118, theta=12.60257 -> V=1.0, theta=0.0
% INFO    : Bus 64439	: V=0.9966536, theta=12.205636 -> V=1.0, theta=0.0
% INFO    : Bus 64440	: V=0.983952, theta=10.894076 -> V=1.0, theta=0.0
% INFO    : Bus 64441	: V=0.9840737, theta=11.007631 -> V=1.0, theta=0.0
% INFO    : Bus 64442	: V=0.9832173, theta=12.719229 -> V=1.0, theta=0.0
% INFO    : Bus 64443	: V=1.0100003, theta=13.52056 -> V=1.0, theta=0.0
% INFO    : Bus 64444	: V=0.9827125, theta=10.896526 -> V=1.0, theta=0.0
% INFO    : Bus 64445	: V=0.9853907, theta=11.282517 -> V=1.0, theta=0.0
% INFO    : Bus 64446	: V=0.9844142, theta=11.113773 -> V=1.0, theta=0.0
% INFO    : Bus 64447	: V=0.9903208, theta=12.212869 -> V=1.0, theta=0.0
% INFO    : Bus 64448	: V=0.9860946, theta=12.289507 -> V=1.0, theta=0.0
% INFO    : Bus 64449	: V=0.9844038, theta=10.915499 -> V=1.0, theta=0.0
% INFO    : Bus 64450	: V=0.9843502, theta=10.992084 -> V=1.0, theta=0.0
% INFO    : Bus 64451	: V=0.9984118, theta=12.53636 -> V=1.0, theta=0.0
% INFO    : Bus 64452	: V=0.9845088, theta=10.821749 -> V=1.0, theta=0.0
% INFO    : Bus 64453	: V=0.9935387, theta=11.778291 -> V=1.0, theta=0.0
% INFO    : Bus 64454	: V=0.985168, theta=10.789006 -> V=1.0, theta=0.0
% INFO    : Bus 64455	: V=0.9976056, theta=11.850316 -> V=1.0, theta=0.0
% INFO    : Bus 64456	: V=0.9955828, theta=11.898195 -> V=1.0, theta=0.0
% INFO    : Bus 64457	: V=0.9910108, theta=14.790006 -> V=1.0, theta=0.0
% INFO    : Bus 64458	: V=1.0126099, theta=23.175125 -> V=1.0, theta=0.0
% INFO    : Bus 64459	: V=1.0143272, theta=23.706474 -> V=1.0, theta=0.0
% INFO    : Bus 64460	: V=0.9924592, theta=15.143009 -> V=1.0, theta=0.0
% INFO    : Bus 64461	: V=1.0008423, theta=18.492614 -> V=1.0, theta=0.0
% INFO    : Bus 64462	: V=1.0093863, theta=22.382878 -> V=1.0, theta=0.0
% INFO    : Bus 64463	: V=0.9799912, theta=10.48883 -> V=1.0, theta=0.0
% INFO    : Bus 64464	: V=0.9840312, theta=10.715581 -> V=1.0, theta=0.0
% INFO    : Bus 64465	: V=1.0001429, theta=12.829227 -> V=1.0, theta=0.0
% INFO    : Bus 64466	: V=0.9923727, theta=12.593417 -> V=1.0, theta=0.0
% INFO    : Bus 64467	: V=1.0001289, theta=12.812989 -> V=1.0, theta=0.0
% INFO    : Bus 64468	: V=1.0090845, theta=16.396946 -> V=1.0, theta=0.0
% INFO    : Bus 64469	: V=1.0037863, theta=11.849644 -> V=1.0, theta=0.0
% INFO    : Bus 64470	: V=1.0090479, theta=14.233558 -> V=1.0, theta=0.0
% INFO    : Bus 64471	: V=1.0048712, theta=11.89388 -> V=1.0, theta=0.0
% INFO    : Bus 64472	: V=1.0077076, theta=12.65439 -> V=1.0, theta=0.0
% INFO    : Bus 64473	: V=1.0023348, theta=13.954641 -> V=1.0, theta=0.0
% INFO    : Bus 64474	: V=1.00189, theta=23.737375 -> V=1.0, theta=0.0
% INFO    : Bus 64475	: V=0.9833991, theta=21.296734 -> V=1.0, theta=0.0
% INFO    : Bus 64476	: V=1.0095582, theta=39.133747 -> V=1.0, theta=0.0
% INFO    : Bus 64477	: V=0.9747703, theta=35.00603 -> V=1.0, theta=0.0
% INFO    : Bus 64478	: V=0.9920631, theta=37.519588 -> V=1.0, theta=0.0
% INFO    : Bus 64479	: V=0.9712142, theta=34.89629 -> V=1.0, theta=0.0
% INFO    : Bus 64480	: V=0.9830618, theta=34.393243 -> V=1.0, theta=0.0
% INFO    : Bus 64481	: V=0.9548358, theta=33.782708 -> V=1.0, theta=0.0
% INFO    : Bus 64482	: V=0.9583289, theta=21.994889 -> V=1.0, theta=0.0
% INFO    : Bus 64483	: V=0.9579807, theta=21.996622 -> V=1.0, theta=0.0
% INFO    : Bus 64484	: V=0.9619677, theta=23.277899 -> V=1.0, theta=0.0
% INFO    : Bus 64485	: V=0.9585348, theta=21.953558 -> V=1.0, theta=0.0
% INFO    : Bus 64486	: V=0.9583403, theta=21.952714 -> V=1.0, theta=0.0
% INFO    : Bus 64487	: V=0.9587105, theta=21.986411 -> V=1.0, theta=0.0
% INFO    : Bus 64488	: V=0.9663474, theta=23.319397 -> V=1.0, theta=0.0
% INFO    : Bus 64489	: V=0.9665959, theta=23.297373 -> V=1.0, theta=0.0
% INFO    : Bus 64490	: V=0.9633388, theta=23.42518 -> V=1.0, theta=0.0
% INFO    : Bus 64491	: V=0.9579561, theta=21.931909 -> V=1.0, theta=0.0
% INFO    : Bus 64492	: V=0.9584174, theta=21.88381 -> V=1.0, theta=0.0
% INFO    : Bus 64493	: V=0.9679046, theta=23.29716 -> V=1.0, theta=0.0
% INFO    : Bus 64494	: V=0.9687978, theta=23.312781 -> V=1.0, theta=0.0
% INFO    : Bus 64495	: V=0.96195, theta=22.28594 -> V=1.0, theta=0.0
% INFO    : Bus 64496	: V=0.9587382, theta=22.069153 -> V=1.0, theta=0.0
% INFO    : Bus 64497	: V=0.9617719, theta=22.305112 -> V=1.0, theta=0.0
% INFO    : Bus 64498	: V=0.9708552, theta=21.767485 -> V=1.0, theta=0.0
% INFO    : Bus 64499	: V=0.9659664, theta=23.661975 -> V=1.0, theta=0.0
% INFO    : Bus 64500	: V=0.9685078, theta=24.177024 -> V=1.0, theta=0.0
% INFO    : Bus 64501	: V=0.9854323, theta=21.356614 -> V=1.0, theta=0.0
% INFO    : Bus 64502	: V=0.947962, theta=17.417468 -> V=1.0, theta=0.0
% INFO    : Bus 64503	: V=0.9525739, theta=21.148963 -> V=1.0, theta=0.0
% INFO    : Bus 64504	: V=0.9601775, theta=22.123997 -> V=1.0, theta=0.0
% INFO    : Bus 64505	: V=0.970033, theta=23.344688 -> V=1.0, theta=0.0
% INFO    : Bus 64506	: V=0.9712024, theta=23.362235 -> V=1.0, theta=0.0
% INFO    : Bus 64507	: V=0.9612039, theta=22.237762 -> V=1.0, theta=0.0
% INFO    : Bus 64508	: V=0.9605082, theta=22.235419 -> V=1.0, theta=0.0
% INFO    : Bus 64509	: V=0.994666, theta=23.591039 -> V=1.0, theta=0.0
% INFO    : Bus 64510	: V=0.9915588, theta=27.942138 -> V=1.0, theta=0.0
% INFO    : Bus 64511	: V=0.9780246, theta=23.778419 -> V=1.0, theta=0.0
% INFO    : Bus 64512	: V=1.0128925, theta=30.01496 -> V=1.0, theta=0.0
% INFO    : Bus 64513	: V=1.0122602, theta=29.961029 -> V=1.0, theta=0.0
% INFO    : Bus 64514	: V=1.0133982, theta=30.052408 -> V=1.0, theta=0.0
% INFO    : Bus 64515	: V=0.9913787, theta=29.593701 -> V=1.0, theta=0.0
% INFO    : Bus 64516	: V=1.0071364, theta=39.848246 -> V=1.0, theta=0.0
% INFO    : Bus 64517	: V=0.9867478, theta=33.707366 -> V=1.0, theta=0.0
% INFO    : Bus 64518	: V=0.9932593, theta=34.323529 -> V=1.0, theta=0.0
% INFO    : Bus 64519	: V=1.0025768, theta=37.452864 -> V=1.0, theta=0.0
% INFO    : Bus 64520	: V=1.0035358, theta=38.179089 -> V=1.0, theta=0.0
% INFO    : Bus 64521	: V=0.9993343, theta=36.842136 -> V=1.0, theta=0.0
% INFO    : Bus 64522	: V=1.0031858, theta=38.215383 -> V=1.0, theta=0.0
% INFO    : Bus 64523	: V=1.0010355, theta=30.749429 -> V=1.0, theta=0.0
% INFO    : Bus 64524	: V=0.9935711, theta=26.958404 -> V=1.0, theta=0.0
% INFO    : Bus 64525	: V=1.0018332, theta=25.538464 -> V=1.0, theta=0.0
% INFO    : Bus 64526	: V=0.9901414, theta=25.931932 -> V=1.0, theta=0.0
% INFO    : Bus 64527	: V=0.9895565, theta=25.933893 -> V=1.0, theta=0.0
% INFO    : Bus 64528	: V=1.0051876, theta=25.552297 -> V=1.0, theta=0.0
% INFO    : Bus 64529	: V=0.9824424, theta=24.870232 -> V=1.0, theta=0.0
% INFO    : Bus 64530	: V=0.978614, theta=24.183541 -> V=1.0, theta=0.0
% INFO    : Bus 64531	: V=0.9897472, theta=25.994198 -> V=1.0, theta=0.0
% INFO    : Bus 64532	: V=0.9770228, theta=24.771111 -> V=1.0, theta=0.0
% INFO    : Bus 64533	: V=0.993033, theta=26.075199 -> V=1.0, theta=0.0
% INFO    : Bus 64534	: V=0.9856836, theta=22.960592 -> V=1.0, theta=0.0
% INFO    : Bus 64535	: V=0.9994831, theta=25.978279 -> V=1.0, theta=0.0
% INFO    : Bus 64536	: V=1.0092708, theta=27.857602 -> V=1.0, theta=0.0
% INFO    : Bus 64537	: V=1.0035039, theta=26.459069 -> V=1.0, theta=0.0
% INFO    : Bus 64538	: V=1.0006056, theta=24.227496 -> V=1.0, theta=0.0
% INFO    : Bus 64539	: V=1.0140494, theta=28.094408 -> V=1.0, theta=0.0
% INFO    : Bus 64540	: V=1.0117492, theta=28.12089 -> V=1.0, theta=0.0
% INFO    : Bus 64541	: V=0.9897882, theta=20.324041 -> V=1.0, theta=0.0
% INFO    : Bus 64542	: V=0.9852617, theta=17.873582 -> V=1.0, theta=0.0
% INFO    : Bus 64543	: V=0.9916344, theta=17.520727 -> V=1.0, theta=0.0
% INFO    : Bus 64544	: V=0.9829481, theta=17.091459 -> V=1.0, theta=0.0
% INFO    : Bus 64545	: V=0.9940439, theta=16.302302 -> V=1.0, theta=0.0
% INFO    : Bus 64546	: V=0.9841146, theta=17.769543 -> V=1.0, theta=0.0
% INFO    : Bus 64547	: V=0.9930412, theta=18.294651 -> V=1.0, theta=0.0
% INFO    : Bus 64548	: V=0.9936269, theta=26.885599 -> V=1.0, theta=0.0
% INFO    : Bus 64549	: V=1.008945, theta=15.560754 -> V=1.0, theta=0.0
% INFO    : Bus 64550	: V=0.9978006, theta=14.560705 -> V=1.0, theta=0.0
% INFO    : Bus 64551	: V=1.0179407, theta=20.955753 -> V=1.0, theta=0.0
% INFO    : Bus 64552	: V=1.0140759, theta=19.111099 -> V=1.0, theta=0.0
% INFO    : Bus 64553	: V=1.0045746, theta=18.399095 -> V=1.0, theta=0.0
% INFO    : Bus 64554	: V=0.9902535, theta=38.401698 -> V=1.0, theta=0.0
% INFO    : Bus 64555	: V=0.9675011, theta=35.983543 -> V=1.0, theta=0.0
% INFO    : Bus 64556	: V=0.992532, theta=22.239449 -> V=1.0, theta=0.0
% INFO    : Bus 64557	: V=0.9781488, theta=19.42128 -> V=1.0, theta=0.0
% INFO    : Bus 64558	: V=0.972146, theta=19.251439 -> V=1.0, theta=0.0
% INFO    : Bus 64559	: V=0.9832834, theta=19.776134 -> V=1.0, theta=0.0
% INFO    : Bus 64560	: V=0.9885141, theta=20.622716 -> V=1.0, theta=0.0
% INFO    : Bus 64561	: V=0.9996902, theta=22.650238 -> V=1.0, theta=0.0
% INFO    : Bus 64562	: V=0.9950497, theta=20.999906 -> V=1.0, theta=0.0
% INFO    : Bus 64563	: V=0.9818971, theta=20.084816 -> V=1.0, theta=0.0
% INFO    : Bus 64564	: V=1.0023902, theta=22.005923 -> V=1.0, theta=0.0
% INFO    : Bus 64565	: V=0.9967951, theta=24.39012 -> V=1.0, theta=0.0
% INFO    : Bus 64566	: V=0.9991846, theta=24.766777 -> V=1.0, theta=0.0
% INFO    : Bus 64567	: V=0.9991418, theta=24.767841 -> V=1.0, theta=0.0
% INFO    : Bus 64568	: V=0.9987726, theta=24.721399 -> V=1.0, theta=0.0
% INFO    : Bus 64569	: V=0.9982722, theta=24.659265 -> V=1.0, theta=0.0
% INFO    : Bus 64570	: V=0.999834, theta=24.8593 -> V=1.0, theta=0.0
% INFO    : Bus 64571	: V=1.0014431, theta=25.026591 -> V=1.0, theta=0.0
% INFO    : Bus 64572	: V=1.0015648, theta=25.128644 -> V=1.0, theta=0.0
% INFO    : Bus 64573	: V=1.0003368, theta=24.973283 -> V=1.0, theta=0.0
% INFO    : Bus 64574	: V=0.9984051, theta=24.717468 -> V=1.0, theta=0.0
% INFO    : Bus 64575	: V=0.998029, theta=24.707926 -> V=1.0, theta=0.0
% INFO    : Bus 64576	: V=1.0017336, theta=25.104936 -> V=1.0, theta=0.0
% INFO    : Bus 64577	: V=1.0021598, theta=25.113446 -> V=1.0, theta=0.0
% INFO    : Bus 64578	: V=1.0033069, theta=25.196483 -> V=1.0, theta=0.0
% INFO    : Bus 64579	: V=1.0020719, theta=24.97791 -> V=1.0, theta=0.0
% INFO    : Bus 64580	: V=1.0017816, theta=24.985785 -> V=1.0, theta=0.0
% INFO    : Bus 64581	: V=1.0022332, theta=24.945141 -> V=1.0, theta=0.0
% INFO    : Bus 64582	: V=1.008979, theta=26.409733 -> V=1.0, theta=0.0
% INFO    : Bus 64583	: V=1.0027686, theta=24.992642 -> V=1.0, theta=0.0
% INFO    : Bus 64584	: V=1.0027904, theta=24.984837 -> V=1.0, theta=0.0
% INFO    : Bus 64585	: V=1.0029717, theta=24.991579 -> V=1.0, theta=0.0
% INFO    : Bus 64586	: V=1.0037842, theta=25.041006 -> V=1.0, theta=0.0
% INFO    : Bus 64587	: V=1.009923, theta=26.58458 -> V=1.0, theta=0.0
% INFO    : Bus 64588	: V=1.0043083, theta=25.040004 -> V=1.0, theta=0.0
% INFO    : Bus 64589	: V=1.0036927, theta=24.994851 -> V=1.0, theta=0.0
% INFO    : Bus 64590	: V=1.0034185, theta=25.011495 -> V=1.0, theta=0.0
% INFO    : Bus 64591	: V=1.0096947, theta=26.509274 -> V=1.0, theta=0.0
% INFO    : Bus 64592	: V=1.0028872, theta=24.691649 -> V=1.0, theta=0.0
% INFO    : Bus 64593	: V=1.0022697, theta=24.546129 -> V=1.0, theta=0.0
% INFO    : Bus 64594	: V=1.0084878, theta=26.327896 -> V=1.0, theta=0.0
% INFO    : Bus 64595	: V=0.9965902, theta=21.590158 -> V=1.0, theta=0.0
% INFO    : Bus 64596	: V=0.9968543, theta=21.5909 -> V=1.0, theta=0.0
% INFO    : Bus 64597	: V=1.0015711, theta=24.65049 -> V=1.0, theta=0.0
% INFO    : Bus 64598	: V=1.0015929, theta=24.336091 -> V=1.0, theta=0.0
% INFO    : Bus 64599	: V=0.9999837, theta=24.788278 -> V=1.0, theta=0.0
% INFO    : Bus 64600	: V=0.9909548, theta=24.110468 -> V=1.0, theta=0.0
% INFO    : Bus 64601	: V=0.9876509, theta=21.796119 -> V=1.0, theta=0.0
% INFO    : Bus 64602	: V=0.9905649, theta=23.290189 -> V=1.0, theta=0.0
% INFO    : Bus 64603	: V=0.9920826, theta=23.473519 -> V=1.0, theta=0.0
% INFO    : Bus 64604	: V=0.9911741, theta=23.141399 -> V=1.0, theta=0.0
% INFO    : Bus 64605	: V=0.9925291, theta=23.485121 -> V=1.0, theta=0.0
% INFO    : Bus 64606	: V=0.9918983, theta=23.32198 -> V=1.0, theta=0.0
% INFO    : Bus 64607	: V=0.9935118, theta=23.529236 -> V=1.0, theta=0.0
% INFO    : Bus 64608	: V=0.9960497, theta=23.934142 -> V=1.0, theta=0.0
% INFO    : Bus 64609	: V=1.007157, theta=25.218792 -> V=1.0, theta=0.0
% INFO    : Bus 64610	: V=1.0116859, theta=26.98049 -> V=1.0, theta=0.0
% INFO    : Bus 64611	: V=0.9995335, theta=24.871943 -> V=1.0, theta=0.0
% INFO    : Bus 64612	: V=1.0118408, theta=26.929372 -> V=1.0, theta=0.0
% INFO    : Bus 64613	: V=1.0053492, theta=25.243055 -> V=1.0, theta=0.0
% INFO    : Bus 64614	: V=1.0085137, theta=26.082495 -> V=1.0, theta=0.0
% INFO    : Bus 64615	: V=1.0139026, theta=26.910598 -> V=1.0, theta=0.0
% INFO    : Bus 64616	: V=1.0051145, theta=23.371319 -> V=1.0, theta=0.0
% INFO    : Bus 64617	: V=1.0092957, theta=26.355615 -> V=1.0, theta=0.0
% INFO    : Bus 64618	: V=0.9976726, theta=23.924103 -> V=1.0, theta=0.0
% INFO    : Bus 64619	: V=1.0059395, theta=28.770376 -> V=1.0, theta=0.0
% INFO    : Bus 64620	: V=1.0067481, theta=31.78662 -> V=1.0, theta=0.0
% INFO    : Bus 64621	: V=0.9989269, theta=19.585339 -> V=1.0, theta=0.0
% INFO    : Bus 64622	: V=0.9890118, theta=19.472421 -> V=1.0, theta=0.0
% INFO    : Bus 64623	: V=0.9937963, theta=20.923995 -> V=1.0, theta=0.0
% INFO    : Bus 64624	: V=1.0086637, theta=27.049946 -> V=1.0, theta=0.0
% INFO    : Bus 64625	: V=1.0185591, theta=27.33742 -> V=1.0, theta=0.0
% INFO    : Bus 64626	: V=1.0110006, theta=25.742058 -> V=1.0, theta=0.0
% INFO    : Bus 64627	: V=0.9984651, theta=24.949408 -> V=1.0, theta=0.0
% INFO    : Bus 64628	: V=0.9927861, theta=24.829744 -> V=1.0, theta=0.0
% INFO    : Bus 64629	: V=0.9815361, theta=23.732523 -> V=1.0, theta=0.0
% INFO    : Bus 64630	: V=0.9874709, theta=24.007087 -> V=1.0, theta=0.0
% INFO    : Bus 64631	: V=0.9917473, theta=22.269139 -> V=1.0, theta=0.0
% INFO    : Bus 64632	: V=0.9716193, theta=17.40286 -> V=1.0, theta=0.0
% INFO    : Bus 64633	: V=0.9772262, theta=18.700253 -> V=1.0, theta=0.0
% INFO    : Bus 64634	: V=0.9889424, theta=28.981321 -> V=1.0, theta=0.0
% INFO    : Bus 64635	: V=0.9908529, theta=27.963216 -> V=1.0, theta=0.0
% INFO    : Bus 64636	: V=0.9901897, theta=27.409127 -> V=1.0, theta=0.0
% INFO    : Bus 64637	: V=0.9854053, theta=26.824041 -> V=1.0, theta=0.0
% INFO    : Bus 64638	: V=1.0032212, theta=33.367913 -> V=1.0, theta=0.0
% INFO    : Bus 64639	: V=0.9686928, theta=39.230694 -> V=1.0, theta=0.0
% INFO    : Bus 64640	: V=1.0107257, theta=18.801619 -> V=1.0, theta=0.0
% INFO    : Bus 64641	: V=1.0142068, theta=17.934848 -> V=1.0, theta=0.0
% INFO    : Bus 64642	: V=1.0158191, theta=20.298238 -> V=1.0, theta=0.0
% INFO    : Bus 64643	: V=1.0143721, theta=19.558785 -> V=1.0, theta=0.0
% INFO    : Bus 64644	: V=1.0141169, theta=18.789785 -> V=1.0, theta=0.0
% INFO    : Bus 64645	: V=1.0063468, theta=15.617274 -> V=1.0, theta=0.0
% INFO    : Bus 64646	: V=0.994695, theta=14.844244 -> V=1.0, theta=0.0
% INFO    : Bus 64647	: V=1.005538, theta=15.276921 -> V=1.0, theta=0.0
% INFO    : Bus 64648	: V=0.9976139, theta=15.368554 -> V=1.0, theta=0.0
% INFO    : Bus 64649	: V=1.0024308, theta=17.010423 -> V=1.0, theta=0.0
% INFO    : Bus 64650	: V=1.0015515, theta=17.249265 -> V=1.0, theta=0.0
% INFO    : Bus 64651	: V=0.9757958, theta=28.604003 -> V=1.0, theta=0.0
% INFO    : Bus 64652	: V=0.9911558, theta=29.805529 -> V=1.0, theta=0.0
% INFO    : Bus 64653	: V=0.9905759, theta=13.641089 -> V=1.0, theta=0.0
% INFO    : Bus 64654	: V=0.9898284, theta=13.624773 -> V=1.0, theta=0.0
% INFO    : Bus 64655	: V=0.986265, theta=13.812977 -> V=1.0, theta=0.0
% INFO    : Bus 64656	: V=0.9857248, theta=13.780885 -> V=1.0, theta=0.0
% INFO    : Bus 64657	: V=0.9871487, theta=15.350213 -> V=1.0, theta=0.0
% INFO    : Bus 64658	: V=0.9842222, theta=14.566631 -> V=1.0, theta=0.0
% INFO    : Bus 64659	: V=0.9876439, theta=15.225598 -> V=1.0, theta=0.0
% INFO    : Bus 64660	: V=0.988727, theta=15.014601 -> V=1.0, theta=0.0
% INFO    : Bus 64661	: V=0.9932357, theta=13.647246 -> V=1.0, theta=0.0
% INFO    : Bus 64662	: V=0.9854086, theta=16.08185 -> V=1.0, theta=0.0
% INFO    : Bus 64663	: V=0.9869413, theta=14.317452 -> V=1.0, theta=0.0
% INFO    : Bus 64664	: V=0.9862403, theta=16.390375 -> V=1.0, theta=0.0
% INFO    : Bus 64665	: V=0.9870293, theta=13.867401 -> V=1.0, theta=0.0
% INFO    : Bus 64666	: V=0.9844218, theta=13.612332 -> V=1.0, theta=0.0
% INFO    : Bus 64667	: V=0.9838032, theta=13.540677 -> V=1.0, theta=0.0
% INFO    : Bus 64668	: V=0.9855537, theta=13.763841 -> V=1.0, theta=0.0
% INFO    : Bus 64669	: V=0.9832474, theta=13.41425 -> V=1.0, theta=0.0
% INFO    : Bus 64670	: V=0.983251, theta=13.46226 -> V=1.0, theta=0.0
% INFO    : Bus 64671	: V=0.985823, theta=13.555599 -> V=1.0, theta=0.0
% INFO    : Bus 64672	: V=0.9854783, theta=13.532979 -> V=1.0, theta=0.0
% INFO    : Bus 64673	: V=0.9850931, theta=13.523217 -> V=1.0, theta=0.0
% INFO    : Bus 64674	: V=0.9885455, theta=14.705361 -> V=1.0, theta=0.0
% INFO    : Bus 64675	: V=0.9843992, theta=13.118957 -> V=1.0, theta=0.0
% INFO    : Bus 64676	: V=0.9843739, theta=13.106017 -> V=1.0, theta=0.0
% INFO    : Bus 64677	: V=0.9854359, theta=13.139159 -> V=1.0, theta=0.0
% INFO    : Bus 64678	: V=0.9848535, theta=13.125057 -> V=1.0, theta=0.0
% INFO    : Bus 64679	: V=0.9854531, theta=13.273038 -> V=1.0, theta=0.0
% INFO    : Bus 64680	: V=0.9856786, theta=13.431895 -> V=1.0, theta=0.0
% INFO    : Bus 64681	: V=0.9859285, theta=13.578285 -> V=1.0, theta=0.0
% INFO    : Bus 64682	: V=0.9859947, theta=13.373473 -> V=1.0, theta=0.0
% INFO    : Bus 64683	: V=0.9860821, theta=13.235746 -> V=1.0, theta=0.0
% INFO    : Bus 64684	: V=0.9867605, theta=13.631303 -> V=1.0, theta=0.0
% INFO    : Bus 64685	: V=0.9863897, theta=13.429868 -> V=1.0, theta=0.0
% INFO    : Bus 64686	: V=0.9886463, theta=14.372222 -> V=1.0, theta=0.0
% INFO    : Bus 64687	: V=0.9888214, theta=14.252767 -> V=1.0, theta=0.0
% INFO    : Bus 64688	: V=0.9885659, theta=14.521781 -> V=1.0, theta=0.0
% INFO    : Bus 64689	: V=1.0056095, theta=16.739552 -> V=1.0, theta=0.0
% INFO    : Bus 64690	: V=0.9807647, theta=13.886424 -> V=1.0, theta=0.0
% INFO    : Bus 64691	: V=0.9859052, theta=12.944511 -> V=1.0, theta=0.0
% INFO    : Bus 64692	: V=0.9933474, theta=12.704194 -> V=1.0, theta=0.0
% INFO    : Bus 64693	: V=1.0099801, theta=14.178602 -> V=1.0, theta=0.0
% INFO    : Bus 64694	: V=1.0099756, theta=13.888721 -> V=1.0, theta=0.0
% INFO    : Bus 64695	: V=0.9982153, theta=12.874756 -> V=1.0, theta=0.0
% INFO    : Bus 64696	: V=1.008259, theta=12.89173 -> V=1.0, theta=0.0
% INFO    : Bus 64697	: V=1.003224, theta=11.985011 -> V=1.0, theta=0.0
% INFO    : Bus 64698	: V=1.0066342, theta=12.718627 -> V=1.0, theta=0.0
% INFO    : Bus 64699	: V=1.0040041, theta=12.373031 -> V=1.0, theta=0.0
% INFO    : Bus 64700	: V=1.0034004, theta=11.863112 -> V=1.0, theta=0.0
% INFO    : Bus 64701	: V=1.002597, theta=12.605413 -> V=1.0, theta=0.0
% INFO    : Bus 64702	: V=0.9997722, theta=11.820566 -> V=1.0, theta=0.0
% INFO    : Bus 64703	: V=1.0038054, theta=12.739564 -> V=1.0, theta=0.0
% INFO    : Bus 64704	: V=1.0025871, theta=12.682002 -> V=1.0, theta=0.0
% INFO    : Bus 64705	: V=1.0054873, theta=12.934078 -> V=1.0, theta=0.0
% INFO    : Bus 64706	: V=1.0063946, theta=13.042867 -> V=1.0, theta=0.0
% INFO    : Bus 64707	: V=1.0067429, theta=13.063082 -> V=1.0, theta=0.0
% INFO    : Bus 64708	: V=1.0077204, theta=12.876976 -> V=1.0, theta=0.0
% INFO    : Bus 64709	: V=1.0113759, theta=13.059655 -> V=1.0, theta=0.0
% INFO    : Bus 64710	: V=1.0091731, theta=13.109895 -> V=1.0, theta=0.0
% INFO    : Bus 64711	: V=1.0018374, theta=12.324939 -> V=1.0, theta=0.0
% INFO    : Bus 64712	: V=1.0080235, theta=12.928771 -> V=1.0, theta=0.0
% INFO    : Bus 64713	: V=1.0187719, theta=15.98759 -> V=1.0, theta=0.0
% INFO    : Bus 64714	: V=1.0080148, theta=13.216321 -> V=1.0, theta=0.0
% INFO    : Bus 64715	: V=1.0078035, theta=13.170023 -> V=1.0, theta=0.0
% INFO    : Bus 64716	: V=0.9956782, theta=13.280568 -> V=1.0, theta=0.0
% INFO    : Bus 64717	: V=0.9841594, theta=12.523383 -> V=1.0, theta=0.0
% INFO    : Bus 64718	: V=0.9993893, theta=12.349645 -> V=1.0, theta=0.0
% INFO    : Bus 64719	: V=0.9892788, theta=13.981832 -> V=1.0, theta=0.0
% INFO    : Bus 64720	: V=0.9895559, theta=13.987163 -> V=1.0, theta=0.0
% INFO    : Bus 64721	: V=0.9895656, theta=14.036215 -> V=1.0, theta=0.0
% INFO    : Bus 64722	: V=0.9898972, theta=14.205583 -> V=1.0, theta=0.0
% INFO    : Bus 64723	: V=0.9905613, theta=14.46915 -> V=1.0, theta=0.0
% INFO    : Bus 64724	: V=0.9795806, theta=12.871309 -> V=1.0, theta=0.0
% INFO    : Bus 64725	: V=0.9903099, theta=13.883999 -> V=1.0, theta=0.0
% INFO    : Bus 64726	: V=0.9882095, theta=13.728197 -> V=1.0, theta=0.0
% INFO    : Bus 64727	: V=0.985593, theta=14.473952 -> V=1.0, theta=0.0
% INFO    : Bus 64728	: V=0.9813957, theta=24.212433 -> V=1.0, theta=0.0
% INFO    : Bus 64729	: V=1.0005289, theta=16.652952 -> V=1.0, theta=0.0
% INFO    : Bus 64730	: V=0.9933418, theta=26.360095 -> V=1.0, theta=0.0
% INFO    : Bus 64731	: V=0.9783263, theta=28.511619 -> V=1.0, theta=0.0
% INFO    : Bus 64732	: V=0.961328, theta=-49.630597 -> V=1.0, theta=0.0
% INFO    : Bus 64733	: V=0.9945618, theta=-58.836105 -> V=1.0, theta=0.0
% INFO    : Bus 64734	: V=0.9973835, theta=-58.233913 -> V=1.0, theta=0.0
% INFO    : Bus 64735	: V=0.9998765, theta=-59.636018 -> V=1.0, theta=0.0
% INFO    : Bus 64736	: V=0.9944965, theta=-54.919919 -> V=1.0, theta=0.0
% INFO    : Bus 64737	: V=0.9959481, theta=-58.5718 -> V=1.0, theta=0.0
% INFO    : Bus 64738	: V=1.0200004, theta=-59.700241 -> V=1.0, theta=0.0
% INFO    : Bus 64739	: V=0.9983459, theta=-16.927137 -> V=1.0, theta=0.0
% INFO    : Bus 64740	: V=0.9889053, theta=-18.310379 -> V=1.0, theta=0.0
% INFO    : Bus 64741	: V=0.9934392, theta=-17.614016 -> V=1.0, theta=0.0
% INFO    : Bus 64742	: V=0.9900085, theta=-18.1012 -> V=1.0, theta=0.0
% INFO    : Bus 64743	: V=0.9898756, theta=-18.13015 -> V=1.0, theta=0.0
% INFO    : Bus 64744	: V=0.9909156, theta=-18.010548 -> V=1.0, theta=0.0
% INFO    : Bus 64745	: V=0.9904267, theta=-18.058739 -> V=1.0, theta=0.0
% INFO    : Bus 64746	: V=0.9957278, theta=-17.309141 -> V=1.0, theta=0.0
% INFO    : Bus 64747	: V=0.9954071, theta=-17.387697 -> V=1.0, theta=0.0
% INFO    : Bus 64748	: V=0.9959093, theta=-17.379892 -> V=1.0, theta=0.0
% INFO    : Bus 64749	: V=0.9966891, theta=-17.275035 -> V=1.0, theta=0.0
% INFO    : Bus 64750	: V=0.9959808, theta=-17.34745 -> V=1.0, theta=0.0
% INFO    : Bus 64751	: V=0.9987705, theta=-16.920302 -> V=1.0, theta=0.0
% INFO    : Bus 64752	: V=1.0060734, theta=-15.922148 -> V=1.0, theta=0.0
% INFO    : Bus 64753	: V=0.9980017, theta=-17.189044 -> V=1.0, theta=0.0
% INFO    : Bus 64754	: V=0.9997216, theta=-16.863181 -> V=1.0, theta=0.0
% INFO    : Bus 64755	: V=1.006435, theta=-15.939488 -> V=1.0, theta=0.0
% INFO    : Bus 64756	: V=1.0088346, theta=-15.737842 -> V=1.0, theta=0.0
% INFO    : Bus 64757	: V=1.0069679, theta=-15.908172 -> V=1.0, theta=0.0
% INFO    : Bus 64758	: V=1.0068174, theta=-16.16695 -> V=1.0, theta=0.0
% INFO    : Bus 64759	: V=1.0075659, theta=-15.871646 -> V=1.0, theta=0.0
% INFO    : Bus 64760	: V=1.0151716, theta=-14.884005 -> V=1.0, theta=0.0
% INFO    : Bus 64761	: V=1.0053687, theta=-16.28678 -> V=1.0, theta=0.0
% INFO    : Bus 64762	: V=1.0004947, theta=-16.879393 -> V=1.0, theta=0.0
% INFO    : Bus 64763	: V=0.9999647, theta=-16.949624 -> V=1.0, theta=0.0
% INFO    : Bus 64764	: V=1.0011565, theta=-16.779751 -> V=1.0, theta=0.0
% INFO    : Bus 64765	: V=1.002202, theta=-16.689154 -> V=1.0, theta=0.0
% INFO    : Bus 64766	: V=1.0005836, theta=-16.790353 -> V=1.0, theta=0.0
% INFO    : Bus 64767	: V=1.000776, theta=-16.730313 -> V=1.0, theta=0.0
% INFO    : Bus 64768	: V=1.0017352, theta=-16.577435 -> V=1.0, theta=0.0
% INFO    : Bus 64769	: V=1.0024048, theta=-16.486888 -> V=1.0, theta=0.0
% INFO    : Bus 64770	: V=1.0026109, theta=-16.456673 -> V=1.0, theta=0.0
% INFO    : Bus 64771	: V=0.9988424, theta=-17.118356 -> V=1.0, theta=0.0
% INFO    : Bus 64772	: V=0.9970594, theta=-17.265978 -> V=1.0, theta=0.0
% INFO    : Bus 64773	: V=0.9977167, theta=-17.2321 -> V=1.0, theta=0.0
% INFO    : Bus 64774	: V=0.9970482, theta=-17.294321 -> V=1.0, theta=0.0
% INFO    : Bus 64775	: V=0.9961538, theta=-17.315174 -> V=1.0, theta=0.0
% INFO    : Bus 64776	: V=0.9975779, theta=-17.143579 -> V=1.0, theta=0.0
% INFO    : Bus 64777	: V=0.9924661, theta=-17.821347 -> V=1.0, theta=0.0
% INFO    : Bus 64778	: V=0.9930232, theta=-17.748336 -> V=1.0, theta=0.0
% INFO    : Bus 64779	: V=0.9961462, theta=-17.365682 -> V=1.0, theta=0.0
% INFO    : Bus 64780	: V=0.9965625, theta=-17.320608 -> V=1.0, theta=0.0
% INFO    : Bus 64781	: V=0.9986052, theta=-17.040512 -> V=1.0, theta=0.0
% INFO    : Bus 64782	: V=1.0014905, theta=-16.794671 -> V=1.0, theta=0.0
% INFO    : Bus 64783	: V=1.000839, theta=-16.836684 -> V=1.0, theta=0.0
% INFO    : Bus 64784	: V=1.0036889, theta=-16.5621 -> V=1.0, theta=0.0
% INFO    : Bus 64785	: V=1.0047179, theta=-16.432463 -> V=1.0, theta=0.0
% INFO    : Bus 64786	: V=1.0123202, theta=-15.351393 -> V=1.0, theta=0.0
% INFO    : Bus 64787	: V=1.004262, theta=-16.446447 -> V=1.0, theta=0.0
% INFO    : Bus 64788	: V=1.0056114, theta=-16.328718 -> V=1.0, theta=0.0
% INFO    : Bus 64789	: V=1.0056977, theta=-16.309651 -> V=1.0, theta=0.0
% INFO    : Bus 64790	: V=1.009927, theta=-15.688454 -> V=1.0, theta=0.0
% INFO    : Bus 64791	: V=1.0054955, theta=-16.322844 -> V=1.0, theta=0.0
% INFO    : Bus 64792	: V=1.0058112, theta=-16.289994 -> V=1.0, theta=0.0
% INFO    : Bus 64793	: V=1.002661, theta=-16.594779 -> V=1.0, theta=0.0
% INFO    : Bus 64794	: V=1.0019447, theta=-16.688847 -> V=1.0, theta=0.0
% INFO    : Bus 64795	: V=1.0030596, theta=-16.576769 -> V=1.0, theta=0.0
% INFO    : Bus 64796	: V=1.0042868, theta=-16.436965 -> V=1.0, theta=0.0
% INFO    : Bus 64797	: V=1.0052554, theta=-16.329667 -> V=1.0, theta=0.0
% INFO    : Bus 64798	: V=1.006285, theta=-15.860067 -> V=1.0, theta=0.0
% INFO    : Bus 64799	: V=1.0071211, theta=-15.768622 -> V=1.0, theta=0.0
% INFO    : Bus 64800	: V=1.0060845, theta=-16.21428 -> V=1.0, theta=0.0
% INFO    : Bus 64801	: V=1.0064561, theta=-16.194879 -> V=1.0, theta=0.0
% INFO    : Bus 64802	: V=1.0074519, theta=-16.052889 -> V=1.0, theta=0.0
% INFO    : Bus 64803	: V=1.0071565, theta=-16.057773 -> V=1.0, theta=0.0
% INFO    : Bus 64804	: V=1.0057239, theta=-16.219055 -> V=1.0, theta=0.0
% INFO    : Bus 64805	: V=1.0133505, theta=-15.029041 -> V=1.0, theta=0.0
% INFO    : Bus 64806	: V=1.0035123, theta=-16.515566 -> V=1.0, theta=0.0
% INFO    : Bus 64807	: V=1.0017649, theta=-16.70768 -> V=1.0, theta=0.0
% INFO    : Bus 64808	: V=1.0016615, theta=-16.719516 -> V=1.0, theta=0.0
% INFO    : Bus 64809	: V=0.9993108, theta=-17.012545 -> V=1.0, theta=0.0
% INFO    : Bus 64810	: V=0.9996426, theta=-16.994277 -> V=1.0, theta=0.0
% INFO    : Bus 64811	: V=0.9974991, theta=-17.223493 -> V=1.0, theta=0.0
% INFO    : Bus 64812	: V=0.9988735, theta=-17.026164 -> V=1.0, theta=0.0
% INFO    : Bus 64813	: V=0.9979315, theta=-17.137968 -> V=1.0, theta=0.0
% INFO    : Bus 64814	: V=0.9939606, theta=-17.733076 -> V=1.0, theta=0.0
% INFO    : Bus 64815	: V=0.998359, theta=-17.12649 -> V=1.0, theta=0.0
% INFO    : Bus 64816	: V=0.9940882, theta=-17.731818 -> V=1.0, theta=0.0
% INFO    : Bus 64817	: V=0.9961051, theta=-17.437011 -> V=1.0, theta=0.0
% INFO    : Bus 64818	: V=0.9956819, theta=-17.443263 -> V=1.0, theta=0.0
% INFO    : Bus 64819	: V=0.9974964, theta=-17.237806 -> V=1.0, theta=0.0
% INFO    : Bus 64820	: V=0.9984849, theta=-17.142057 -> V=1.0, theta=0.0
% INFO    : Bus 64821	: V=0.9975955, theta=-17.218584 -> V=1.0, theta=0.0
% INFO    : Bus 64822	: V=0.9981097, theta=-17.1778 -> V=1.0, theta=0.0
% INFO    : Bus 64823	: V=1.0052562, theta=-15.96447 -> V=1.0, theta=0.0
% INFO    : Bus 64824	: V=1.0009225, theta=-16.921319 -> V=1.0, theta=0.0
% INFO    : Bus 64825	: V=1.0057894, theta=-15.913665 -> V=1.0, theta=0.0
% INFO    : Bus 64826	: V=1.0000221, theta=-16.998014 -> V=1.0, theta=0.0
% INFO    : Bus 64827	: V=0.9989391, theta=-17.102002 -> V=1.0, theta=0.0
% INFO    : Bus 64828	: V=0.9979119, theta=-17.200911 -> V=1.0, theta=0.0
% INFO    : Bus 64829	: V=0.9977116, theta=-17.225245 -> V=1.0, theta=0.0
% INFO    : Bus 64830	: V=1.0008629, theta=-16.922728 -> V=1.0, theta=0.0
% INFO    : Bus 64831	: V=1.0003268, theta=-16.928915 -> V=1.0, theta=0.0
% INFO    : Bus 64832	: V=1.0005238, theta=-16.928983 -> V=1.0, theta=0.0
% INFO    : Bus 64833	: V=1.0060541, theta=-16.056142 -> V=1.0, theta=0.0
% INFO    : Bus 64834	: V=0.9965458, theta=-17.299298 -> V=1.0, theta=0.0
% INFO    : Bus 64835	: V=1.0025173, theta=-16.253911 -> V=1.0, theta=0.0
% INFO    : Bus 64836	: V=0.9998656, theta=-16.815405 -> V=1.0, theta=0.0
% INFO    : Bus 64837	: V=1.0082494, theta=-15.929668 -> V=1.0, theta=0.0
% INFO    : Bus 64838	: V=1.0118598, theta=-15.242211 -> V=1.0, theta=0.0
% INFO    : Bus 64839	: V=1.0080646, theta=-15.67341 -> V=1.0, theta=0.0
% INFO    : Bus 64840	: V=1.0069902, theta=-15.995057 -> V=1.0, theta=0.0
% INFO    : Bus 64841	: V=1.0093714, theta=-15.533581 -> V=1.0, theta=0.0
% INFO    : Bus 64842	: V=1.0102789, theta=-15.426328 -> V=1.0, theta=0.0
% INFO    : Bus 64843	: V=1.0081969, theta=-15.951366 -> V=1.0, theta=0.0
% INFO    : Bus 64844	: V=0.996752, theta=-17.247022 -> V=1.0, theta=0.0
% INFO    : Bus 64845	: V=0.9974797, theta=-17.050807 -> V=1.0, theta=0.0
% INFO    : Bus 64846	: V=1.0015695, theta=-16.297193 -> V=1.0, theta=0.0
% INFO    : Bus 64847	: V=0.9971216, theta=-17.241634 -> V=1.0, theta=0.0
% INFO    : Bus 64848	: V=0.9974867, theta=-17.179415 -> V=1.0, theta=0.0
% INFO    : Bus 64849	: V=0.998307, theta=-16.994825 -> V=1.0, theta=0.0
% INFO    : Bus 64850	: V=0.9987297, theta=-16.955457 -> V=1.0, theta=0.0
% INFO    : Bus 64851	: V=0.9989408, theta=-16.967466 -> V=1.0, theta=0.0
% INFO    : Bus 64852	: V=0.9983091, theta=-16.962423 -> V=1.0, theta=0.0
% INFO    : Bus 64853	: V=0.9965372, theta=-17.197977 -> V=1.0, theta=0.0
% INFO    : Bus 64854	: V=1.0021341, theta=-16.240501 -> V=1.0, theta=0.0
% INFO    : Bus 64855	: V=0.9994576, theta=-16.919144 -> V=1.0, theta=0.0
% INFO    : Bus 64856	: V=0.9985578, theta=-17.097203 -> V=1.0, theta=0.0
% INFO    : Bus 64857	: V=1.0046829, theta=-16.075043 -> V=1.0, theta=0.0
% INFO    : Bus 64858	: V=1.0043921, theta=-16.095357 -> V=1.0, theta=0.0
% INFO    : Bus 64859	: V=1.0007787, theta=-16.732351 -> V=1.0, theta=0.0
% INFO    : Bus 64860	: V=1.0003867, theta=-16.792211 -> V=1.0, theta=0.0
% INFO    : Bus 64861	: V=0.9968681, theta=-17.170604 -> V=1.0, theta=0.0
% INFO    : Bus 64862	: V=0.9977584, theta=-16.802214 -> V=1.0, theta=0.0
% INFO    : Bus 64863	: V=0.9896193, theta=-18.245926 -> V=1.0, theta=0.0
% INFO    : Bus 64864	: V=0.9928656, theta=-17.816916 -> V=1.0, theta=0.0
% INFO    : Bus 64865	: V=0.9922585, theta=-17.881471 -> V=1.0, theta=0.0
% INFO    : Bus 64866	: V=0.9938521, theta=-17.738331 -> V=1.0, theta=0.0
% INFO    : Bus 64867	: V=0.99417, theta=-17.786666 -> V=1.0, theta=0.0
% INFO    : Bus 64868	: V=0.9937967, theta=-17.815358 -> V=1.0, theta=0.0
% INFO    : Bus 64869	: V=0.993882, theta=-17.774115 -> V=1.0, theta=0.0
% INFO    : Bus 64870	: V=0.993642, theta=-17.80022 -> V=1.0, theta=0.0
% INFO    : Bus 64871	: V=0.9930386, theta=-17.811563 -> V=1.0, theta=0.0
% INFO    : Bus 64872	: V=0.9909669, theta=-18.067398 -> V=1.0, theta=0.0
% INFO    : Bus 64873	: V=0.9949995, theta=-17.5984 -> V=1.0, theta=0.0
% INFO    : Bus 64874	: V=0.9931835, theta=-17.8973 -> V=1.0, theta=0.0
% INFO    : Bus 64875	: V=0.9914967, theta=-18.069892 -> V=1.0, theta=0.0
% INFO    : Bus 64876	: V=0.9950882, theta=-17.685277 -> V=1.0, theta=0.0
% INFO    : Bus 64877	: V=0.9934206, theta=-17.822453 -> V=1.0, theta=0.0
% INFO    : Bus 64878	: V=0.9937125, theta=-17.849442 -> V=1.0, theta=0.0
% INFO    : Bus 64879	: V=0.9935238, theta=-17.827059 -> V=1.0, theta=0.0
% INFO    : Bus 64880	: V=0.9916819, theta=-18.053793 -> V=1.0, theta=0.0
% INFO    : Bus 64881	: V=0.9938264, theta=-17.712657 -> V=1.0, theta=0.0
% INFO    : Bus 64882	: V=0.9913514, theta=-18.059052 -> V=1.0, theta=0.0
% INFO    : Bus 64883	: V=0.9922397, theta=-17.983022 -> V=1.0, theta=0.0
% INFO    : Bus 64884	: V=0.998316, theta=-17.185203 -> V=1.0, theta=0.0
% INFO    : Bus 64885	: V=0.9991139, theta=-17.112702 -> V=1.0, theta=0.0
% INFO    : Bus 64886	: V=0.9922482, theta=-17.961575 -> V=1.0, theta=0.0
% INFO    : Bus 64887	: V=0.9964698, theta=-17.426225 -> V=1.0, theta=0.0
% INFO    : Bus 64888	: V=0.9948764, theta=-17.655853 -> V=1.0, theta=0.0
% INFO    : Bus 64889	: V=1.0100003, theta=-15.616899 -> V=1.0, theta=0.0
% INFO    : Bus 64890	: V=0.9944865, theta=-17.780875 -> V=1.0, theta=0.0
% INFO    : Bus 64891	: V=0.9975286, theta=-17.293877 -> V=1.0, theta=0.0
% INFO    : Bus 64892	: V=0.9977392, theta=-17.260205 -> V=1.0, theta=0.0
% INFO    : Bus 64893	: V=0.9973551, theta=-17.322375 -> V=1.0, theta=0.0
% INFO    : Bus 64894	: V=0.9979179, theta=-17.273037 -> V=1.0, theta=0.0
% INFO    : Bus 64895	: V=0.9986159, theta=-17.218144 -> V=1.0, theta=0.0
% INFO    : Bus 64896	: V=0.9957794, theta=-17.591966 -> V=1.0, theta=0.0
% INFO    : Bus 64897	: V=0.9926309, theta=-17.919314 -> V=1.0, theta=0.0
% INFO    : Bus 64898	: V=0.9943353, theta=-17.731406 -> V=1.0, theta=0.0
% INFO    : Bus 64899	: V=0.9951453, theta=-17.616157 -> V=1.0, theta=0.0
% INFO    : Bus 64900	: V=0.9957747, theta=-17.616373 -> V=1.0, theta=0.0
% INFO    : Bus 64901	: V=0.99679, theta=-17.601145 -> V=1.0, theta=0.0
% INFO    : Bus 64902	: V=0.9955444, theta=-17.607857 -> V=1.0, theta=0.0
% INFO    : Bus 64903	: V=0.9959364, theta=-17.585057 -> V=1.0, theta=0.0
% INFO    : Bus 64904	: V=0.9958302, theta=-17.592184 -> V=1.0, theta=0.0
% INFO    : Bus 64905	: V=0.9963647, theta=-17.559181 -> V=1.0, theta=0.0
% INFO    : Bus 64906	: V=0.9955511, theta=-17.577452 -> V=1.0, theta=0.0
% INFO    : Bus 64907	: V=0.9971794, theta=-17.516109 -> V=1.0, theta=0.0
% INFO    : Bus 64908	: V=0.9962796, theta=-17.414349 -> V=1.0, theta=0.0
% INFO    : Bus 64909	: V=0.9991751, theta=-17.080559 -> V=1.0, theta=0.0
% INFO    : Bus 64910	: V=0.998654, theta=-17.1433 -> V=1.0, theta=0.0
% INFO    : Bus 64911	: V=0.9885259, theta=-18.317636 -> V=1.0, theta=0.0
% INFO    : Bus 64912	: V=0.9913342, theta=-17.959871 -> V=1.0, theta=0.0
% INFO    : Bus 64913	: V=0.9914029, theta=-17.957388 -> V=1.0, theta=0.0
% INFO    : Bus 64914	: V=0.9915193, theta=-17.948342 -> V=1.0, theta=0.0
% INFO    : Bus 64915	: V=0.9917695, theta=-17.926199 -> V=1.0, theta=0.0
% INFO    : Bus 64916	: V=0.9884098, theta=-18.34161 -> V=1.0, theta=0.0
% INFO    : Bus 64917	: V=0.9879403, theta=-18.350524 -> V=1.0, theta=0.0
% INFO    : Bus 64918	: V=0.9887086, theta=-18.3282 -> V=1.0, theta=0.0
% INFO    : Bus 64919	: V=0.9861316, theta=-18.424312 -> V=1.0, theta=0.0
% INFO    : Bus 64920	: V=0.9859487, theta=-18.478405 -> V=1.0, theta=0.0
% INFO    : Bus 64921	: V=0.984148, theta=-18.837028 -> V=1.0, theta=0.0
% INFO    : Bus 64922	: V=0.9851066, theta=-18.672109 -> V=1.0, theta=0.0
% INFO    : Bus 64923	: V=0.9848842, theta=-18.723523 -> V=1.0, theta=0.0
% INFO    : Bus 64924	: V=0.9856326, theta=-18.613216 -> V=1.0, theta=0.0
% INFO    : Bus 64925	: V=0.9867892, theta=-18.538756 -> V=1.0, theta=0.0
% INFO    : Bus 64926	: V=0.986295, theta=-18.689255 -> V=1.0, theta=0.0
% INFO    : Bus 64927	: V=0.9912399, theta=-17.957237 -> V=1.0, theta=0.0
% INFO    : Bus 64928	: V=0.991528, theta=-17.933477 -> V=1.0, theta=0.0
% INFO    : Bus 64929	: V=0.9865258, theta=-19.157993 -> V=1.0, theta=0.0
% INFO    : Bus 64930	: V=0.986011, theta=-18.797729 -> V=1.0, theta=0.0
% INFO    : Bus 64931	: V=0.9865465, theta=-18.765003 -> V=1.0, theta=0.0
% INFO    : Bus 64932	: V=0.9849785, theta=-18.992047 -> V=1.0, theta=0.0
% INFO    : Bus 64933	: V=0.9877762, theta=-18.203498 -> V=1.0, theta=0.0
% INFO    : Bus 64934	: V=0.9871778, theta=-18.22522 -> V=1.0, theta=0.0
% INFO    : Bus 64935	: V=0.9876837, theta=-18.21528 -> V=1.0, theta=0.0
% INFO    : Bus 64936	: V=0.9859475, theta=-18.449103 -> V=1.0, theta=0.0
% INFO    : Bus 64937	: V=0.9852847, theta=-18.536322 -> V=1.0, theta=0.0
% INFO    : Bus 64938	: V=0.9879031, theta=-18.201667 -> V=1.0, theta=0.0
% INFO    : Bus 64939	: V=0.9884066, theta=-18.190756 -> V=1.0, theta=0.0
% INFO    : Bus 64940	: V=0.9879754, theta=-18.199947 -> V=1.0, theta=0.0
% INFO    : Bus 64941	: V=0.985776, theta=-18.325572 -> V=1.0, theta=0.0
% INFO    : Bus 64942	: V=0.9835994, theta=-18.796748 -> V=1.0, theta=0.0
% INFO    : Bus 64943	: V=0.9839647, theta=-18.788903 -> V=1.0, theta=0.0
% INFO    : Bus 64944	: V=0.9840795, theta=-18.793724 -> V=1.0, theta=0.0
% INFO    : Bus 64945	: V=0.9844099, theta=-18.734659 -> V=1.0, theta=0.0
% INFO    : Bus 64946	: V=0.9842707, theta=-18.751339 -> V=1.0, theta=0.0
% INFO    : Bus 64947	: V=0.9850274, theta=-18.593996 -> V=1.0, theta=0.0
% INFO    : Bus 64948	: V=0.9849639, theta=-18.615329 -> V=1.0, theta=0.0
% INFO    : Bus 64949	: V=0.9847273, theta=-18.670461 -> V=1.0, theta=0.0
% INFO    : Bus 64950	: V=0.9858796, theta=-18.507603 -> V=1.0, theta=0.0
% INFO    : Bus 64951	: V=0.985927, theta=-18.508915 -> V=1.0, theta=0.0
% INFO    : Bus 64952	: V=0.9866402, theta=-18.49207 -> V=1.0, theta=0.0
% INFO    : Bus 64953	: V=0.9863236, theta=-18.540759 -> V=1.0, theta=0.0
% INFO    : Bus 64954	: V=0.9848688, theta=-18.89828 -> V=1.0, theta=0.0
% INFO    : Bus 64955	: V=0.9864903, theta=-19.177565 -> V=1.0, theta=0.0
% INFO    : Bus 64956	: V=0.9848289, theta=-18.762348 -> V=1.0, theta=0.0
% INFO    : Bus 64957	: V=0.984814, theta=-18.784778 -> V=1.0, theta=0.0
% INFO    : Bus 64958	: V=0.9891524, theta=-18.546103 -> V=1.0, theta=0.0
% INFO    : Bus 64959	: V=0.9894409, theta=-18.527476 -> V=1.0, theta=0.0
% INFO    : Bus 64960	: V=0.9923057, theta=-17.867793 -> V=1.0, theta=0.0
% INFO    : Bus 64961	: V=0.9888113, theta=-18.578393 -> V=1.0, theta=0.0
% INFO    : Bus 64962	: V=0.9843703, theta=-18.864627 -> V=1.0, theta=0.0
% INFO    : Bus 64963	: V=0.9868692, theta=-18.3051 -> V=1.0, theta=0.0
% INFO    : Bus 64964	: V=0.9880103, theta=-18.209911 -> V=1.0, theta=0.0
% INFO    : Bus 64965	: V=0.9903155, theta=-17.940491 -> V=1.0, theta=0.0
% INFO    : Bus 64966	: V=0.9880365, theta=-18.179635 -> V=1.0, theta=0.0
% INFO    : Bus 64967	: V=0.9873986, theta=-18.262487 -> V=1.0, theta=0.0
% INFO    : Bus 64968	: V=0.9888458, theta=-18.097392 -> V=1.0, theta=0.0
% INFO    : Bus 64969	: V=0.9889246, theta=-18.075557 -> V=1.0, theta=0.0
% INFO    : Bus 64970	: V=0.9891501, theta=-17.9992 -> V=1.0, theta=0.0
% INFO    : Bus 64971	: V=0.9886516, theta=-18.091914 -> V=1.0, theta=0.0
% INFO    : Bus 64972	: V=0.9882581, theta=-18.099394 -> V=1.0, theta=0.0
% INFO    : Bus 64973	: V=0.9877274, theta=-18.133949 -> V=1.0, theta=0.0
% INFO    : Bus 64974	: V=0.9884598, theta=-18.18528 -> V=1.0, theta=0.0
% INFO    : Bus 64975	: V=0.987665, theta=-18.185086 -> V=1.0, theta=0.0
% INFO    : Bus 64976	: V=0.9881883, theta=-18.191181 -> V=1.0, theta=0.0
% INFO    : Bus 64977	: V=0.9954264, theta=-16.97554 -> V=1.0, theta=0.0
% INFO    : Bus 64978	: V=0.9885204, theta=-18.18485 -> V=1.0, theta=0.0
% INFO    : Bus 64979	: V=0.9875081, theta=-18.267886 -> V=1.0, theta=0.0
% INFO    : Bus 64980	: V=0.9888514, theta=-18.097285 -> V=1.0, theta=0.0
% INFO    : Bus 64981	: V=0.9870816, theta=-18.442034 -> V=1.0, theta=0.0
% INFO    : Bus 64982	: V=0.9884456, theta=-18.214918 -> V=1.0, theta=0.0
% INFO    : Bus 64983	: V=0.9891183, theta=-18.116088 -> V=1.0, theta=0.0
% INFO    : Bus 64984	: V=0.9880755, theta=-18.282495 -> V=1.0, theta=0.0
% INFO    : Bus 64985	: V=0.9886359, theta=-18.204782 -> V=1.0, theta=0.0
% INFO    : Bus 64986	: V=0.9893283, theta=-18.189392 -> V=1.0, theta=0.0
% INFO    : Bus 64987	: V=0.9903281, theta=-18.046403 -> V=1.0, theta=0.0
% INFO    : Bus 64988	: V=0.988067, theta=-18.333628 -> V=1.0, theta=0.0
% INFO    : Bus 64989	: V=0.9885956, theta=-18.268761 -> V=1.0, theta=0.0
% INFO    : Bus 64990	: V=0.9880664, theta=-18.336177 -> V=1.0, theta=0.0
% INFO    : Bus 64991	: V=0.9890733, theta=-18.203326 -> V=1.0, theta=0.0
% INFO    : Bus 64992	: V=0.9904715, theta=-18.009289 -> V=1.0, theta=0.0
% INFO    : Bus 64993	: V=0.9883977, theta=-18.323765 -> V=1.0, theta=0.0
% INFO    : Bus 64994	: V=0.9896085, theta=-18.188188 -> V=1.0, theta=0.0
% INFO    : Bus 64995	: V=0.9906865, theta=-18.013154 -> V=1.0, theta=0.0
% INFO    : Bus 64996	: V=0.9900822, theta=-18.07255 -> V=1.0, theta=0.0
% INFO    : Bus 64997	: V=0.9907688, theta=-17.99303 -> V=1.0, theta=0.0
% INFO    : Bus 64998	: V=0.9910089, theta=-17.922806 -> V=1.0, theta=0.0
% INFO    : Bus 64999	: V=0.9914018, theta=-17.914976 -> V=1.0, theta=0.0
% INFO    : Bus 65000	: V=0.9941909, theta=-17.622822 -> V=1.0, theta=0.0
% INFO    : Bus 65001	: V=0.9934516, theta=-17.724319 -> V=1.0, theta=0.0
% INFO    : Bus 65002	: V=0.9954684, theta=-17.402632 -> V=1.0, theta=0.0
% INFO    : Bus 65003	: V=1.0020351, theta=-16.229297 -> V=1.0, theta=0.0
% INFO    : Bus 65004	: V=0.9989777, theta=-16.588573 -> V=1.0, theta=0.0
% INFO    : Bus 65005	: V=0.9997874, theta=-16.522107 -> V=1.0, theta=0.0
% INFO    : Bus 65006	: V=0.9927647, theta=-17.763954 -> V=1.0, theta=0.0
% INFO    : Bus 65007	: V=0.9945277, theta=-17.553488 -> V=1.0, theta=0.0
% INFO    : Bus 65008	: V=1.0039545, theta=-16.063576 -> V=1.0, theta=0.0
% INFO    : Bus 65009	: V=0.9908156, theta=-18.066679 -> V=1.0, theta=0.0
% INFO    : Bus 65010	: V=0.99693, theta=-17.254637 -> V=1.0, theta=0.0
% INFO    : Bus 65011	: V=0.9898098, theta=-17.987147 -> V=1.0, theta=0.0
% INFO    : Bus 65012	: V=0.9903711, theta=-17.916412 -> V=1.0, theta=0.0
% INFO    : Bus 65013	: V=0.9913381, theta=-17.796166 -> V=1.0, theta=0.0
% INFO    : Bus 65014	: V=0.9897624, theta=-17.927078 -> V=1.0, theta=0.0
% INFO    : Bus 65015	: V=0.9945243, theta=-17.377584 -> V=1.0, theta=0.0
% INFO    : Bus 65016	: V=0.9968961, theta=-17.182002 -> V=1.0, theta=0.0
% INFO    : Bus 65017	: V=0.99278, theta=-17.400897 -> V=1.0, theta=0.0
% INFO    : Bus 65018	: V=0.9915699, theta=-17.444144 -> V=1.0, theta=0.0
% INFO    : Bus 65019	: V=1.0100003, theta=-14.563338 -> V=1.0, theta=0.0
% INFO    : Bus 65020	: V=0.993588, theta=-17.317214 -> V=1.0, theta=0.0
% INFO    : Bus 65021	: V=1.0036488, theta=-15.43639 -> V=1.0, theta=0.0
% INFO    : Bus 65022	: V=0.9900849, theta=-17.873396 -> V=1.0, theta=0.0
% INFO    : Bus 65023	: V=0.9909159, theta=-17.837907 -> V=1.0, theta=0.0
% INFO    : Bus 65024	: V=0.9927709, theta=-17.591018 -> V=1.0, theta=0.0
% INFO    : Bus 65025	: V=0.9924174, theta=-17.601491 -> V=1.0, theta=0.0
% INFO    : Bus 65026	: V=0.993698, theta=-17.566717 -> V=1.0, theta=0.0
% INFO    : Bus 65027	: V=0.9939843, theta=-17.52369 -> V=1.0, theta=0.0
% INFO    : Bus 65028	: V=0.9927468, theta=-17.595501 -> V=1.0, theta=0.0
% INFO    : Bus 65029	: V=0.9930196, theta=-17.546817 -> V=1.0, theta=0.0
% INFO    : Bus 65030	: V=0.9935464, theta=-17.41486 -> V=1.0, theta=0.0
% INFO    : Bus 65031	: V=0.9936358, theta=-17.432004 -> V=1.0, theta=0.0
% INFO    : Bus 65032	: V=0.9948169, theta=-17.376087 -> V=1.0, theta=0.0
% INFO    : Bus 65033	: V=0.9966322, theta=-17.359543 -> V=1.0, theta=0.0
% INFO    : Bus 65034	: V=0.9971145, theta=-17.233129 -> V=1.0, theta=0.0
% INFO    : Bus 65035	: V=1.0034154, theta=-16.140234 -> V=1.0, theta=0.0
% INFO    : Bus 65036	: V=0.9971007, theta=-17.246828 -> V=1.0, theta=0.0
% INFO    : Bus 65037	: V=0.9969221, theta=-17.257033 -> V=1.0, theta=0.0
% INFO    : Bus 65038	: V=0.9993654, theta=-16.926468 -> V=1.0, theta=0.0
% INFO    : Bus 65039	: V=0.9987888, theta=-16.952602 -> V=1.0, theta=0.0
% INFO    : Bus 65040	: V=0.9983307, theta=-16.963819 -> V=1.0, theta=0.0
% INFO    : Bus 65041	: V=1.0010205, theta=-16.659925 -> V=1.0, theta=0.0
% INFO    : Bus 65042	: V=1.0003425, theta=-16.684201 -> V=1.0, theta=0.0
% INFO    : Bus 65043	: V=0.9994531, theta=-16.75118 -> V=1.0, theta=0.0
% INFO    : Bus 65044	: V=1.0000867, theta=-16.71778 -> V=1.0, theta=0.0
% INFO    : Bus 65045	: V=0.9989103, theta=-16.770536 -> V=1.0, theta=0.0
% INFO    : Bus 65046	: V=0.9982674, theta=-16.850222 -> V=1.0, theta=0.0
% INFO    : Bus 65047	: V=0.9991122, theta=-16.732886 -> V=1.0, theta=0.0
% INFO    : Bus 65048	: V=1.0046354, theta=-15.974608 -> V=1.0, theta=0.0
% INFO    : Bus 65049	: V=0.9993721, theta=-16.628385 -> V=1.0, theta=0.0
% INFO    : Bus 65050	: V=1.0011391, theta=-16.412141 -> V=1.0, theta=0.0
% INFO    : Bus 65051	: V=1.0016171, theta=-16.517842 -> V=1.0, theta=0.0
% INFO    : Bus 65052	: V=1.0059975, theta=-15.966132 -> V=1.0, theta=0.0
% INFO    : Bus 65053	: V=1.0022045, theta=-16.503789 -> V=1.0, theta=0.0
% INFO    : Bus 65054	: V=1.0050095, theta=-16.016774 -> V=1.0, theta=0.0
% INFO    : Bus 65055	: V=1.0008219, theta=-16.518538 -> V=1.0, theta=0.0
% INFO    : Bus 65056	: V=0.9997773, theta=-16.593735 -> V=1.0, theta=0.0
% INFO    : Bus 65057	: V=0.9999955, theta=-16.546761 -> V=1.0, theta=0.0
% INFO    : Bus 65058	: V=1.0007615, theta=-16.482757 -> V=1.0, theta=0.0
% INFO    : Bus 65059	: V=1.0011148, theta=-16.522938 -> V=1.0, theta=0.0
% INFO    : Bus 65060	: V=1.0067145, theta=-16.003172 -> V=1.0, theta=0.0
% INFO    : Bus 65061	: V=1.0097994, theta=-15.929795 -> V=1.0, theta=0.0
% INFO    : Bus 65062	: V=1.0075475, theta=-16.097165 -> V=1.0, theta=0.0
% INFO    : Bus 65063	: V=1.010544, theta=-15.652865 -> V=1.0, theta=0.0
% INFO    : Bus 65064	: V=1.0044592, theta=-16.212944 -> V=1.0, theta=0.0
% INFO    : Bus 65065	: V=1.0033098, theta=-16.300119 -> V=1.0, theta=0.0
% INFO    : Bus 65066	: V=1.002852, theta=-16.299097 -> V=1.0, theta=0.0
% INFO    : Bus 65067	: V=1.0039626, theta=-15.982548 -> V=1.0, theta=0.0
% INFO    : Bus 65068	: V=1.0042888, theta=-15.975148 -> V=1.0, theta=0.0
% INFO    : Bus 65069	: V=1.0051581, theta=-16.033685 -> V=1.0, theta=0.0
% INFO    : Bus 65070	: V=1.0047557, theta=-16.208027 -> V=1.0, theta=0.0
% INFO    : Bus 65071	: V=1.0091862, theta=-15.756147 -> V=1.0, theta=0.0
% INFO    : Bus 65072	: V=1.0088257, theta=-15.950893 -> V=1.0, theta=0.0
% INFO    : Bus 65073	: V=1.0086282, theta=-16.030827 -> V=1.0, theta=0.0
% INFO    : Bus 65074	: V=1.011206, theta=-15.605287 -> V=1.0, theta=0.0
% INFO    : Bus 65075	: V=1.0222044, theta=-14.587477 -> V=1.0, theta=0.0
% INFO    : Bus 65076	: V=1.0066033, theta=-16.179382 -> V=1.0, theta=0.0
% INFO    : Bus 65077	: V=1.0068808, theta=-16.143504 -> V=1.0, theta=0.0
% INFO    : Bus 65078	: V=1.0063488, theta=-16.184248 -> V=1.0, theta=0.0
% INFO    : Bus 65079	: V=1.0139184, theta=-14.981242 -> V=1.0, theta=0.0
% INFO    : Bus 65080	: V=1.0137423, theta=-14.993859 -> V=1.0, theta=0.0
% INFO    : Bus 65081	: V=1.0092381, theta=-15.875006 -> V=1.0, theta=0.0
% INFO    : Bus 65082	: V=1.0112693, theta=-15.868314 -> V=1.0, theta=0.0
% INFO    : Bus 65083	: V=1.0076537, theta=-16.01857 -> V=1.0, theta=0.0
% INFO    : Bus 65084	: V=1.0097811, theta=-15.897503 -> V=1.0, theta=0.0
% INFO    : Bus 65085	: V=1.0083713, theta=-15.852882 -> V=1.0, theta=0.0
% INFO    : Bus 65086	: V=1.0087025, theta=-15.838261 -> V=1.0, theta=0.0
% INFO    : Bus 65087	: V=1.0162339, theta=-14.471575 -> V=1.0, theta=0.0
% INFO    : Bus 65088	: V=1.0055441, theta=-16.08287 -> V=1.0, theta=0.0
% INFO    : Bus 65089	: V=1.0064416, theta=-16.015146 -> V=1.0, theta=0.0
% INFO    : Bus 65090	: V=1.0058487, theta=-16.074252 -> V=1.0, theta=0.0
% INFO    : Bus 65091	: V=1.0200003, theta=-13.610433 -> V=1.0, theta=0.0
% INFO    : Bus 65092	: V=1.0051997, theta=-16.093104 -> V=1.0, theta=0.0
% INFO    : Bus 65093	: V=1.0048818, theta=-16.102539 -> V=1.0, theta=0.0
% INFO    : Bus 65094	: V=1.0047377, theta=-16.118824 -> V=1.0, theta=0.0
% INFO    : Bus 65095	: V=1.0095882, theta=-15.360276 -> V=1.0, theta=0.0
% INFO    : Bus 65096	: V=1.0098216, theta=-15.130248 -> V=1.0, theta=0.0
% INFO    : Bus 65097	: V=1.0027371, theta=-16.185723 -> V=1.0, theta=0.0
% INFO    : Bus 65098	: V=1.0030741, theta=-16.150967 -> V=1.0, theta=0.0
% INFO    : Bus 65099	: V=1.0035533, theta=-16.104528 -> V=1.0, theta=0.0
% INFO    : Bus 65100	: V=1.0047423, theta=-16.124316 -> V=1.0, theta=0.0
% INFO    : Bus 65101	: V=1.0046282, theta=-16.091759 -> V=1.0, theta=0.0
% INFO    : Bus 65102	: V=1.0033527, theta=-16.242255 -> V=1.0, theta=0.0
% INFO    : Bus 65103	: V=1.0038225, theta=-16.162378 -> V=1.0, theta=0.0
% INFO    : Bus 65104	: V=1.0040502, theta=-16.153749 -> V=1.0, theta=0.0
% INFO    : Bus 65105	: V=1.0023339, theta=-16.290851 -> V=1.0, theta=0.0
% INFO    : Bus 65106	: V=1.002165, theta=-16.292857 -> V=1.0, theta=0.0
% INFO    : Bus 65107	: V=1.0046548, theta=-15.976668 -> V=1.0, theta=0.0
% INFO    : Bus 65108	: V=1.0022689, theta=-16.319363 -> V=1.0, theta=0.0
% INFO    : Bus 65109	: V=1.0049532, theta=-15.942938 -> V=1.0, theta=0.0
% INFO    : Bus 65110	: V=1.0057009, theta=-15.641125 -> V=1.0, theta=0.0
% INFO    : Bus 65111	: V=1.0047326, theta=-15.67909 -> V=1.0, theta=0.0
% INFO    : Bus 65112	: V=1.0053448, theta=-15.902912 -> V=1.0, theta=0.0
% INFO    : Bus 65113	: V=1.0058538, theta=-15.849306 -> V=1.0, theta=0.0
% INFO    : Bus 65114	: V=1.0054425, theta=-15.647967 -> V=1.0, theta=0.0
% INFO    : Bus 65115	: V=1.0053877, theta=-15.645538 -> V=1.0, theta=0.0
% INFO    : Bus 65116	: V=1.0057988, theta=-15.584687 -> V=1.0, theta=0.0
% INFO    : Bus 65117	: V=1.0018291, theta=-16.582902 -> V=1.0, theta=0.0
% INFO    : Bus 65118	: V=1.0059769, theta=-15.966933 -> V=1.0, theta=0.0
% INFO    : Bus 65119	: V=1.0031798, theta=-16.509084 -> V=1.0, theta=0.0
% INFO    : Bus 65120	: V=1.0025235, theta=-16.337386 -> V=1.0, theta=0.0
% INFO    : Bus 65121	: V=1.0030405, theta=-16.29044 -> V=1.0, theta=0.0
% INFO    : Bus 65122	: V=1.0025713, theta=-16.406012 -> V=1.0, theta=0.0
% INFO    : Bus 65123	: V=1.0057125, theta=-15.961529 -> V=1.0, theta=0.0
% INFO    : Bus 65124	: V=1.0091653, theta=-15.158591 -> V=1.0, theta=0.0
% INFO    : Bus 65125	: V=1.0095674, theta=-15.115191 -> V=1.0, theta=0.0
% INFO    : Bus 65126	: V=1.0068815, theta=-15.743365 -> V=1.0, theta=0.0
% INFO    : Bus 65127	: V=1.0059898, theta=-15.836451 -> V=1.0, theta=0.0
% INFO    : Bus 65128	: V=1.0088957, theta=-15.200589 -> V=1.0, theta=0.0
% INFO    : Bus 65129	: V=1.0045057, theta=-15.69643 -> V=1.0, theta=0.0
% INFO    : Bus 65130	: V=1.005019, theta=-15.689147 -> V=1.0, theta=0.0
% INFO    : Bus 65131	: V=1.0108548, theta=-14.759019 -> V=1.0, theta=0.0
% INFO    : Bus 65132	: V=1.0050615, theta=-15.782388 -> V=1.0, theta=0.0
% INFO    : Bus 65133	: V=1.0052284, theta=-15.689671 -> V=1.0, theta=0.0
% INFO    : Bus 65134	: V=1.0046308, theta=-15.694627 -> V=1.0, theta=0.0
% INFO    : Bus 65135	: V=1.0044545, theta=-15.693705 -> V=1.0, theta=0.0
% INFO    : Bus 65136	: V=1.0060915, theta=-15.519317 -> V=1.0, theta=0.0
% INFO    : Bus 65137	: V=1.0036431, theta=-15.743226 -> V=1.0, theta=0.0
% INFO    : Bus 65138	: V=1.0019546, theta=-15.775468 -> V=1.0, theta=0.0
% INFO    : Bus 65139	: V=1.0048571, theta=-15.858791 -> V=1.0, theta=0.0
% INFO    : Bus 65140	: V=1.0014479, theta=-16.080956 -> V=1.0, theta=0.0
% INFO    : Bus 65141	: V=1.0055803, theta=-15.703769 -> V=1.0, theta=0.0
% INFO    : Bus 65142	: V=1.0065449, theta=-15.691333 -> V=1.0, theta=0.0
% INFO    : Bus 65143	: V=1.0125001, theta=-14.49347 -> V=1.0, theta=0.0
% INFO    : Bus 65144	: V=1.0142781, theta=-14.340317 -> V=1.0, theta=0.0
% INFO    : Bus 65145	: V=1.0098436, theta=-15.097046 -> V=1.0, theta=0.0
% INFO    : Bus 65146	: V=1.0094059, theta=-15.105789 -> V=1.0, theta=0.0
% INFO    : Bus 65147	: V=1.0203007, theta=-6.774989 -> V=1.0, theta=0.0
% INFO    : Bus 65148	: V=1.0200003, theta=-10.837174 -> V=1.0, theta=0.0
% INFO    : Bus 65149	: V=1.0281689, theta=-14.922789 -> V=1.0, theta=0.0
% INFO    : Bus 65150	: V=1.0200003, theta=-6.925457 -> V=1.0, theta=0.0
% INFO    : Bus 65151	: V=1.0200003, theta=-7.120337 -> V=1.0, theta=0.0
% INFO    : Bus 65152	: V=1.0222154, theta=-20.351168 -> V=1.0, theta=0.0
% INFO    : Bus 65153	: V=1.0272774, theta=-18.156354 -> V=1.0, theta=0.0
% INFO    : Bus 65154	: V=1.0179807, theta=-20.848197 -> V=1.0, theta=0.0
% INFO    : Bus 65155	: V=1.0151294, theta=-20.334157 -> V=1.0, theta=0.0
% INFO    : Bus 65156	: V=1.0100003, theta=-14.944966 -> V=1.0, theta=0.0
% INFO    : Bus 65157	: V=1.0015454, theta=-16.902107 -> V=1.0, theta=0.0
% INFO    : Bus 65158	: V=1.0100003, theta=-14.878104 -> V=1.0, theta=0.0
% INFO    : Bus 65159	: V=1.0070414, theta=-15.908281 -> V=1.0, theta=0.0
% INFO    : Bus 65160	: V=1.0073624, theta=-15.801506 -> V=1.0, theta=0.0
% INFO    : Bus 65161	: V=1.0080079, theta=-15.767475 -> V=1.0, theta=0.0
% INFO    : Bus 65162	: V=0.986799, theta=-18.791265 -> V=1.0, theta=0.0
% INFO    : Bus 65163	: V=0.9871569, theta=-18.717888 -> V=1.0, theta=0.0
% INFO    : Bus 65164	: V=0.9880334, theta=-18.623089 -> V=1.0, theta=0.0
% INFO    : Bus 65165	: V=0.9868551, theta=-18.698817 -> V=1.0, theta=0.0
% INFO    : Bus 65166	: V=0.9872789, theta=-18.688241 -> V=1.0, theta=0.0
% INFO    : Bus 65167	: V=0.9876613, theta=-18.665808 -> V=1.0, theta=0.0
% INFO    : Bus 65168	: V=0.9881227, theta=-18.629827 -> V=1.0, theta=0.0
% INFO    : Bus 65169	: V=0.9910701, theta=-18.204379 -> V=1.0, theta=0.0
% INFO    : Bus 65170	: V=0.9936452, theta=-17.789994 -> V=1.0, theta=0.0
% INFO    : Bus 65171	: V=0.9733459, theta=-25.646765 -> V=1.0, theta=0.0
% INFO    : Bus 65172	: V=0.9850678, theta=-18.98656 -> V=1.0, theta=0.0
% INFO    : Bus 65173	: V=0.982581, theta=-20.72031 -> V=1.0, theta=0.0
% INFO    : Bus 65174	: V=0.9865312, theta=-19.189873 -> V=1.0, theta=0.0
% INFO    : Bus 65175	: V=0.9934056, theta=-17.793926 -> V=1.0, theta=0.0
% INFO    : Bus 65176	: V=0.9932976, theta=-17.821771 -> V=1.0, theta=0.0
% INFO    : Bus 65177	: V=1.0006531, theta=-17.742481 -> V=1.0, theta=0.0
% INFO    : Bus 65178	: V=0.9988293, theta=-17.476273 -> V=1.0, theta=0.0
% INFO    : Bus 65179	: V=0.9994124, theta=-17.202185 -> V=1.0, theta=0.0
% INFO    : Bus 65180	: V=1.0005457, theta=-17.078103 -> V=1.0, theta=0.0
% INFO    : Bus 65181	: V=1.0145904, theta=-15.01547 -> V=1.0, theta=0.0
% INFO    : Bus 65182	: V=0.998199, theta=-17.394994 -> V=1.0, theta=0.0
% INFO    : Bus 65183	: V=1.0017821, theta=-16.898387 -> V=1.0, theta=0.0
% INFO    : Bus 65184	: V=0.9967277, theta=-17.264169 -> V=1.0, theta=0.0
% INFO    : Bus 65185	: V=0.9965621, theta=-17.315516 -> V=1.0, theta=0.0
% INFO    : Bus 65186	: V=0.9962216, theta=-17.325138 -> V=1.0, theta=0.0
% INFO    : Bus 65187	: V=0.9971819, theta=-17.21868 -> V=1.0, theta=0.0
% INFO    : Bus 65188	: V=0.9977979, theta=-17.172329 -> V=1.0, theta=0.0
% INFO    : Bus 65189	: V=0.999789, theta=-16.965686 -> V=1.0, theta=0.0
% INFO    : Bus 65190	: V=0.983655, theta=-19.1369 -> V=1.0, theta=0.0
% INFO    : Bus 65191	: V=0.9853493, theta=-18.9433 -> V=1.0, theta=0.0
% INFO    : Bus 65192	: V=0.9899635, theta=-18.140176 -> V=1.0, theta=0.0
% INFO    : Bus 65193	: V=0.985379, theta=-18.966949 -> V=1.0, theta=0.0
% INFO    : Bus 65194	: V=0.988911, theta=-18.578673 -> V=1.0, theta=0.0
% INFO    : Bus 65195	: V=0.9897999, theta=-18.415285 -> V=1.0, theta=0.0
% INFO    : Bus 65196	: V=0.9905178, theta=-18.126187 -> V=1.0, theta=0.0
% INFO    : Bus 65197	: V=0.9909927, theta=-18.110594 -> V=1.0, theta=0.0
% INFO    : Bus 65198	: V=0.9927076, theta=-17.92105 -> V=1.0, theta=0.0
% INFO    : Bus 65199	: V=0.9912319, theta=-18.100739 -> V=1.0, theta=0.0
% INFO    : Bus 65200	: V=0.9939021, theta=-17.77518 -> V=1.0, theta=0.0
% INFO    : Bus 65201	: V=0.9942207, theta=-17.737463 -> V=1.0, theta=0.0
% INFO    : Bus 65202	: V=0.9950633, theta=-17.652788 -> V=1.0, theta=0.0
% INFO    : Bus 65203	: V=0.9955059, theta=-17.588589 -> V=1.0, theta=0.0
% INFO    : Bus 65204	: V=0.9963383, theta=-17.496074 -> V=1.0, theta=0.0
% INFO    : Bus 65205	: V=0.9971188, theta=-17.448732 -> V=1.0, theta=0.0
% INFO    : Bus 65206	: V=0.9962858, theta=-17.644557 -> V=1.0, theta=0.0
% INFO    : Bus 65207	: V=0.9976319, theta=-16.366851 -> V=1.0, theta=0.0
% INFO    : Bus 65208	: V=1.0079459, theta=-5.38853 -> V=1.0, theta=0.0
% INFO    : Bus 65209	: V=1.0207613, theta=-7.392427 -> V=1.0, theta=0.0
% INFO    : Bus 65210	: V=1.0187337, theta=-6.414491 -> V=1.0, theta=0.0
% INFO    : Bus 65211	: V=1.0036147, theta=-15.519647 -> V=1.0, theta=0.0
% INFO    : Bus 65212	: V=1.0038463, theta=-15.808846 -> V=1.0, theta=0.0
% INFO    : Bus 65213	: V=0.9981629, theta=-16.19164 -> V=1.0, theta=0.0
% INFO    : Bus 65214	: V=1.0023152, theta=-16.277706 -> V=1.0, theta=0.0
% INFO    : Bus 65215	: V=1.0035149, theta=-15.941122 -> V=1.0, theta=0.0
% INFO    : Bus 65216	: V=1.0027688, theta=-15.974208 -> V=1.0, theta=0.0
% INFO    : Bus 65217	: V=1.0018276, theta=-16.041108 -> V=1.0, theta=0.0
% INFO    : Bus 65218	: V=1.0163879, theta=-14.31736 -> V=1.0, theta=0.0
% INFO    : Bus 65219	: V=0.9987499, theta=-17.108542 -> V=1.0, theta=0.0
% INFO    : Bus 65220	: V=1.0073019, theta=-16.00025 -> V=1.0, theta=0.0
% INFO    : Bus 65221	: V=1.005441, theta=-15.995797 -> V=1.0, theta=0.0
% INFO    : Bus 65222	: V=1.0027394, theta=-15.436094 -> V=1.0, theta=0.0
% INFO    : Bus 65223	: V=0.9778285, theta=-22.847186 -> V=1.0, theta=0.0
% INFO    : Bus 65224	: V=1.0199393, theta=-10.759178 -> V=1.0, theta=0.0
% INFO    : Bus 65225	: V=1.0046236, theta=-14.882312 -> V=1.0, theta=0.0
% INFO    : Bus 65226	: V=0.9774826, theta=-81.113608 -> V=1.0, theta=0.0
% INFO    : Bus 65227	: V=0.9784358, theta=-81.258184 -> V=1.0, theta=0.0
% INFO    : Bus 65228	: V=0.9760938, theta=-81.149849 -> V=1.0, theta=0.0
% INFO    : Bus 65229	: V=0.9829678, theta=-80.401185 -> V=1.0, theta=0.0
% INFO    : Bus 65230	: V=0.9844357, theta=-80.087573 -> V=1.0, theta=0.0
% INFO    : Bus 65231	: V=0.9792345, theta=-80.955427 -> V=1.0, theta=0.0
% INFO    : Bus 65232	: V=0.9855793, theta=-79.822476 -> V=1.0, theta=0.0
% INFO    : Bus 65233	: V=0.9843761, theta=-80.448159 -> V=1.0, theta=0.0
% INFO    : Bus 65234	: V=0.9846544, theta=-80.716897 -> V=1.0, theta=0.0
% INFO    : Bus 65235	: V=0.9881295, theta=-79.735972 -> V=1.0, theta=0.0
% INFO    : Bus 65236	: V=0.9902785, theta=-78.909967 -> V=1.0, theta=0.0
% INFO    : Bus 65237	: V=0.9896926, theta=-78.922155 -> V=1.0, theta=0.0
% INFO    : Bus 65238	: V=0.9918512, theta=-78.64916 -> V=1.0, theta=0.0
% INFO    : Bus 65239	: V=0.9934166, theta=-77.817161 -> V=1.0, theta=0.0
% INFO    : Bus 65240	: V=0.9793114, theta=-80.692319 -> V=1.0, theta=0.0
% INFO    : Bus 65241	: V=0.98142, theta=-79.494171 -> V=1.0, theta=0.0
% INFO    : Bus 65242	: V=0.9670732, theta=-20.255023 -> V=1.0, theta=0.0
% INFO    : Bus 65243	: V=0.9741853, theta=-30.246828 -> V=1.0, theta=0.0
% INFO    : Bus 65244	: V=0.9754399, theta=-29.888789 -> V=1.0, theta=0.0
% INFO    : Bus 65245	: V=0.9782956, theta=-29.080469 -> V=1.0, theta=0.0
% INFO    : Bus 65246	: V=0.9749731, theta=-30.15456 -> V=1.0, theta=0.0
% INFO    : Bus 65247	: V=0.9747162, theta=-30.195806 -> V=1.0, theta=0.0
% INFO    : Bus 65248	: V=0.9777844, theta=-29.672381 -> V=1.0, theta=0.0
% INFO    : Bus 65249	: V=0.9794716, theta=-31.301176 -> V=1.0, theta=0.0
% INFO    : Bus 65250	: V=0.9788995, theta=-28.988594 -> V=1.0, theta=0.0
% INFO    : Bus 65251	: V=0.9756945, theta=-29.486109 -> V=1.0, theta=0.0
% INFO    : Bus 65252	: V=0.9709778, theta=-27.997376 -> V=1.0, theta=0.0
% INFO    : Bus 65253	: V=0.9622073, theta=-11.540069 -> V=1.0, theta=0.0
% INFO    : Bus 65254	: V=0.9807147, theta=-25.736815 -> V=1.0, theta=0.0
% INFO    : Bus 65255	: V=0.9830926, theta=-34.335821 -> V=1.0, theta=0.0
% INFO    : Bus 65256	: V=0.9580173, theta=-64.840685 -> V=1.0, theta=0.0
% INFO    : Bus 65257	: V=1.0200003, theta=-37.679728 -> V=1.0, theta=0.0
% INFO    : Bus 65258	: V=1.0200004, theta=-9.717575 -> V=1.0, theta=0.0
% INFO    : Bus 65259	: V=0.9796101, theta=-18.679762 -> V=1.0, theta=0.0
% INFO    : Bus 65260	: V=0.9540696, theta=-24.73504 -> V=1.0, theta=0.0
% INFO    : Bus 65261	: V=0.9439864, theta=-25.986629 -> V=1.0, theta=0.0
% INFO    : Bus 65262	: V=0.945532, theta=-35.048264 -> V=1.0, theta=0.0
% INFO    : Bus 65263	: V=1.0300003, theta=-3.16731 -> V=1.0, theta=0.0
% INFO    : Bus 65264	: V=0.9753768, theta=-18.850153 -> V=1.0, theta=0.0
% INFO    : Bus 65265	: V=1.0071882, theta=-59.552025 -> V=1.0, theta=0.0
% INFO    : Bus 65266	: V=1.0089716, theta=-59.451945 -> V=1.0, theta=0.0
% INFO    : Bus 65267	: V=1.0300004, theta=-52.083216 -> V=1.0, theta=0.0
% INFO    : Bus 65268	: V=1.0072705, theta=-69.861961 -> V=1.0, theta=0.0
% INFO    : Bus 65269	: V=1.0069963, theta=-67.582481 -> V=1.0, theta=0.0
% INFO    : Bus 65270	: V=1.0213593, theta=-72.885638 -> V=1.0, theta=0.0
% INFO    : Bus 65271	: V=1.005213, theta=-74.249722 -> V=1.0, theta=0.0
% INFO    : Bus 65272	: V=0.999974, theta=-74.526029 -> V=1.0, theta=0.0
% INFO    : Bus 65273	: V=0.991368, theta=-78.055886 -> V=1.0, theta=0.0
% INFO    : Bus 65274	: V=1.0053083, theta=-70.943684 -> V=1.0, theta=0.0
% INFO    : Bus 65275	: V=1.0300004, theta=-76.175553 -> V=1.0, theta=0.0
% INFO    : Bus 65276	: V=1.0070711, theta=-74.872153 -> V=1.0, theta=0.0
% INFO    : Bus 65277	: V=0.9178697, theta=-47.443317 -> V=1.0, theta=0.0
% INFO    : Bus 65278	: V=0.936706, theta=-53.935257 -> V=1.0, theta=0.0
% INFO    : Bus 65279	: V=1.0200003, theta=-40.217088 -> V=1.0, theta=0.0
% INFO    : Bus 65280	: V=0.9757881, theta=-27.094046 -> V=1.0, theta=0.0
% INFO    : Bus 65281	: V=0.9580869, theta=-28.229574 -> V=1.0, theta=0.0
% INFO    : Bus 65282	: V=0.9547518, theta=-28.414368 -> V=1.0, theta=0.0
% INFO    : Bus 65283	: V=0.9594042, theta=-27.957242 -> V=1.0, theta=0.0
% INFO    : Bus 65284	: V=0.9567058, theta=-28.093748 -> V=1.0, theta=0.0
% INFO    : Bus 65285	: V=0.9537366, theta=-28.518422 -> V=1.0, theta=0.0
% INFO    : Bus 65286	: V=0.9752144, theta=-43.995729 -> V=1.0, theta=0.0
% INFO    : Bus 65287	: V=0.9364181, theta=-45.825612 -> V=1.0, theta=0.0
% INFO    : Bus 65288	: V=1.0304718, theta=-68.728765 -> V=1.0, theta=0.0
% INFO    : Bus 65289	: V=0.9783558, theta=-77.713902 -> V=1.0, theta=0.0
% INFO    : Bus 65290	: V=0.9861397, theta=-75.359371 -> V=1.0, theta=0.0
% INFO    : Bus 65291	: V=0.9826752, theta=-75.91299 -> V=1.0, theta=0.0
% INFO    : Bus 65292	: V=0.982024, theta=-75.947897 -> V=1.0, theta=0.0
% INFO    : Bus 65293	: V=0.9819227, theta=-75.940684 -> V=1.0, theta=0.0
% INFO    : Bus 65294	: V=0.98042, theta=-76.112174 -> V=1.0, theta=0.0
% INFO    : Bus 65295	: V=0.9864752, theta=-75.317946 -> V=1.0, theta=0.0
% INFO    : Bus 65296	: V=0.9825836, theta=-75.906847 -> V=1.0, theta=0.0
% INFO    : Bus 65297	: V=0.9881552, theta=-75.081664 -> V=1.0, theta=0.0
% INFO    : Bus 65298	: V=0.984048, theta=-75.848198 -> V=1.0, theta=0.0
% INFO    : Bus 65299	: V=0.9835374, theta=-75.879983 -> V=1.0, theta=0.0
% INFO    : Bus 65300	: V=0.9999578, theta=-75.876502 -> V=1.0, theta=0.0
% INFO    : Bus 65301	: V=1.0008448, theta=-76.038377 -> V=1.0, theta=0.0
% INFO    : Bus 65302	: V=0.9835017, theta=-75.772797 -> V=1.0, theta=0.0
% INFO    : Bus 65303	: V=0.9905002, theta=-77.050182 -> V=1.0, theta=0.0
% INFO    : Bus 65304	: V=0.9842274, theta=-75.631902 -> V=1.0, theta=0.0
% INFO    : Bus 65305	: V=0.9872926, theta=-75.21667 -> V=1.0, theta=0.0
% INFO    : Bus 65306	: V=0.9799236, theta=-76.124354 -> V=1.0, theta=0.0
% INFO    : Bus 65307	: V=0.9779226, theta=-76.199333 -> V=1.0, theta=0.0
% INFO    : Bus 65308	: V=0.9866115, theta=-75.303281 -> V=1.0, theta=0.0
% INFO    : Bus 65309	: V=0.9830455, theta=-77.154786 -> V=1.0, theta=0.0
% INFO    : Bus 65310	: V=0.9797752, theta=-77.61863 -> V=1.0, theta=0.0
% INFO    : Bus 65311	: V=0.9794838, theta=-76.143532 -> V=1.0, theta=0.0
% INFO    : Bus 65312	: V=0.9778584, theta=-77.798482 -> V=1.0, theta=0.0
% INFO    : Bus 65313	: V=0.9748739, theta=-77.267693 -> V=1.0, theta=0.0
% INFO    : Bus 65314	: V=0.9747895, theta=-77.279024 -> V=1.0, theta=0.0
% INFO    : Bus 65315	: V=0.9858024, theta=-75.379301 -> V=1.0, theta=0.0
% INFO    : Bus 65316	: V=0.978823, theta=-74.536986 -> V=1.0, theta=0.0
% INFO    : Bus 65317	: V=0.9877376, theta=-73.846887 -> V=1.0, theta=0.0
% INFO    : Bus 65318	: V=0.9788641, theta=-77.567485 -> V=1.0, theta=0.0
% INFO    : Bus 65319	: V=0.9854844, theta=-74.64383 -> V=1.0, theta=0.0
% INFO    : Bus 65320	: V=0.9892427, theta=-74.013817 -> V=1.0, theta=0.0
% INFO    : Bus 65321	: V=0.9824626, theta=-75.89955 -> V=1.0, theta=0.0
% INFO    : Bus 65322	: V=0.9899229, theta=-75.084649 -> V=1.0, theta=0.0
% INFO    : Bus 65323	: V=0.989063, theta=-75.305874 -> V=1.0, theta=0.0
% INFO    : Bus 65324	: V=0.9880294, theta=-75.418777 -> V=1.0, theta=0.0
% INFO    : Bus 65325	: V=0.987443, theta=-75.431703 -> V=1.0, theta=0.0
% INFO    : Bus 65326	: V=0.9834763, theta=-75.862022 -> V=1.0, theta=0.0
% INFO    : Bus 65327	: V=0.9897611, theta=-74.847514 -> V=1.0, theta=0.0
% INFO    : Bus 65328	: V=0.9890346, theta=-74.931118 -> V=1.0, theta=0.0
% INFO    : Bus 65329	: V=0.9889228, theta=-74.973885 -> V=1.0, theta=0.0
% INFO    : Bus 65330	: V=0.9926682, theta=-75.687826 -> V=1.0, theta=0.0
% INFO    : Bus 65331	: V=0.991483, theta=-75.708557 -> V=1.0, theta=0.0
% INFO    : Bus 65332	: V=0.9935271, theta=-75.641428 -> V=1.0, theta=0.0
% INFO    : Bus 65333	: V=0.9925007, theta=-75.662261 -> V=1.0, theta=0.0
% INFO    : Bus 65334	: V=0.9828239, theta=-75.905934 -> V=1.0, theta=0.0
% INFO    : Bus 65335	: V=0.9823569, theta=-75.917708 -> V=1.0, theta=0.0
% INFO    : Bus 65336	: V=0.9731051, theta=-78.594476 -> V=1.0, theta=0.0
% INFO    : Bus 65337	: V=0.9712815, theta=-78.925418 -> V=1.0, theta=0.0
% INFO    : Bus 65338	: V=0.9735631, theta=-77.350773 -> V=1.0, theta=0.0
% INFO    : Bus 65339	: V=0.9777363, theta=-77.837766 -> V=1.0, theta=0.0
% INFO    : Bus 65340	: V=0.9771471, theta=-77.912487 -> V=1.0, theta=0.0
% INFO    : Bus 65341	: V=0.9766191, theta=-77.922889 -> V=1.0, theta=0.0
% INFO    : Bus 65342	: V=0.9754666, theta=-78.243149 -> V=1.0, theta=0.0
% INFO    : Bus 65343	: V=0.9770962, theta=-77.874509 -> V=1.0, theta=0.0
% INFO    : Bus 65344	: V=0.9779384, theta=-77.856932 -> V=1.0, theta=0.0
% INFO    : Bus 65345	: V=0.9762108, theta=-77.931015 -> V=1.0, theta=0.0
% INFO    : Bus 65346	: V=0.9743442, theta=-77.330827 -> V=1.0, theta=0.0
% INFO    : Bus 65347	: V=0.9683295, theta=-78.070852 -> V=1.0, theta=0.0
% INFO    : Bus 65348	: V=0.9694856, theta=-75.57819 -> V=1.0, theta=0.0
% INFO    : Bus 65349	: V=0.9672652, theta=-78.218313 -> V=1.0, theta=0.0
% INFO    : Bus 65350	: V=0.9686082, theta=-78.905479 -> V=1.0, theta=0.0
% INFO    : Bus 65351	: V=0.9657891, theta=-79.014984 -> V=1.0, theta=0.0
% INFO    : Bus 65352	: V=0.9719337, theta=-75.227859 -> V=1.0, theta=0.0
% INFO    : Bus 65353	: V=0.9711731, theta=-75.238487 -> V=1.0, theta=0.0
% INFO    : Bus 65354	: V=0.9684574, theta=-75.598449 -> V=1.0, theta=0.0
% INFO    : Bus 65355	: V=0.9851047, theta=-73.667484 -> V=1.0, theta=0.0
% INFO    : Bus 65356	: V=0.9657857, theta=-78.28391 -> V=1.0, theta=0.0
% INFO    : Bus 65357	: V=0.9830301, theta=-73.604299 -> V=1.0, theta=0.0
% INFO    : Bus 65358	: V=0.9864277, theta=-73.625841 -> V=1.0, theta=0.0
% INFO    : Bus 65359	: V=0.9783703, theta=-74.457479 -> V=1.0, theta=0.0
% INFO    : Bus 65360	: V=0.9825656, theta=-74.376069 -> V=1.0, theta=0.0
% INFO    : Bus 65361	: V=0.9802689, theta=-74.237727 -> V=1.0, theta=0.0
% INFO    : Bus 65362	: V=0.979648, theta=-74.316606 -> V=1.0, theta=0.0
% INFO    : Bus 65363	: V=0.9783066, theta=-74.526776 -> V=1.0, theta=0.0
% INFO    : Bus 65364	: V=0.9819178, theta=-75.914045 -> V=1.0, theta=0.0
% INFO    : Bus 65365	: V=0.9806243, theta=-74.034589 -> V=1.0, theta=0.0
% INFO    : Bus 65366	: V=0.9825478, theta=-75.873531 -> V=1.0, theta=0.0
% INFO    : Bus 65367	: V=0.9914536, theta=-74.182364 -> V=1.0, theta=0.0
% INFO    : Bus 65368	: V=1.0213274, theta=-70.470396 -> V=1.0, theta=0.0
% INFO    : Bus 65369	: V=0.9803189, theta=-73.988141 -> V=1.0, theta=0.0
% INFO    : Bus 65370	: V=0.9934601, theta=-74.243091 -> V=1.0, theta=0.0
% INFO    : Bus 65371	: V=0.9806248, theta=-73.983518 -> V=1.0, theta=0.0
% INFO    : Bus 65372	: V=0.9824853, theta=-73.72766 -> V=1.0, theta=0.0
% INFO    : Bus 65373	: V=0.9814958, theta=-73.918047 -> V=1.0, theta=0.0
% INFO    : Bus 65374	: V=0.9994811, theta=-76.382335 -> V=1.0, theta=0.0
% INFO    : Bus 65375	: V=0.9984727, theta=-76.313989 -> V=1.0, theta=0.0
% INFO    : Bus 65376	: V=0.9927916, theta=-77.347011 -> V=1.0, theta=0.0
% INFO    : Bus 65377	: V=0.9859189, theta=-78.000978 -> V=1.0, theta=0.0
% INFO    : Bus 65378	: V=0.9862343, theta=-77.997001 -> V=1.0, theta=0.0
% INFO    : Bus 65379	: V=0.9855439, theta=-78.008431 -> V=1.0, theta=0.0
% INFO    : Bus 65380	: V=0.9890002, theta=-77.860799 -> V=1.0, theta=0.0
% INFO    : Bus 65381	: V=0.9215669, theta=-54.513583 -> V=1.0, theta=0.0
% INFO    : Bus 65382	: V=0.9817345, theta=-73.975382 -> V=1.0, theta=0.0
% INFO    : Bus 65383	: V=0.9876678, theta=-71.592858 -> V=1.0, theta=0.0
% INFO    : Bus 65384	: V=0.9800579, theta=-73.960548 -> V=1.0, theta=0.0
% INFO    : Bus 65385	: V=0.9796805, theta=-74.043432 -> V=1.0, theta=0.0
% INFO    : Bus 65386	: V=0.9863281, theta=-72.836244 -> V=1.0, theta=0.0
% INFO    : Bus 65387	: V=0.9788377, theta=-74.059099 -> V=1.0, theta=0.0
% INFO    : Bus 65388	: V=0.9864244, theta=-72.484505 -> V=1.0, theta=0.0
% INFO    : Bus 65389	: V=0.9826017, theta=-73.736167 -> V=1.0, theta=0.0
% INFO    : Bus 65390	: V=0.984716, theta=-73.386195 -> V=1.0, theta=0.0
% INFO    : Bus 65391	: V=0.9821892, theta=-72.225009 -> V=1.0, theta=0.0
% INFO    : Bus 65392	: V=0.9867177, theta=-72.136363 -> V=1.0, theta=0.0
% INFO    : Bus 65393	: V=0.9625435, theta=-66.944097 -> V=1.0, theta=0.0
% INFO    : Bus 65394	: V=0.9887227, theta=-75.059879 -> V=1.0, theta=0.0
% INFO    : Bus 65395	: V=0.9710049, theta=-76.777436 -> V=1.0, theta=0.0
% INFO    : Bus 65396	: V=0.9870057, theta=-78.674012 -> V=1.0, theta=0.0
% INFO    : Bus 65397	: V=0.962513, theta=-22.133489 -> V=1.0, theta=0.0
% INFO    : Bus 65398	: V=0.9305479, theta=-29.790291 -> V=1.0, theta=0.0
% INFO    : Bus 65399	: V=0.9459482, theta=-23.254898 -> V=1.0, theta=0.0
% INFO    : Bus 65400	: V=0.9926028, theta=-78.005061 -> V=1.0, theta=0.0
% INFO    : Bus 65401	: V=0.9988202, theta=-76.890266 -> V=1.0, theta=0.0
% INFO    : Bus 65402	: V=0.9968439, theta=-77.094202 -> V=1.0, theta=0.0
% INFO    : Bus 65403	: V=1.0100004, theta=-76.749531 -> V=1.0, theta=0.0
% INFO    : Bus 65404	: V=0.9947237, theta=-77.697894 -> V=1.0, theta=0.0
% INFO    : Bus 65405	: V=0.9943791, theta=-77.754618 -> V=1.0, theta=0.0
% INFO    : Bus 65406	: V=0.9991001, theta=-76.804452 -> V=1.0, theta=0.0
% INFO    : Bus 65407	: V=0.9933547, theta=-78.033841 -> V=1.0, theta=0.0
% INFO    : Bus 65408	: V=0.9930627, theta=-78.095936 -> V=1.0, theta=0.0
% INFO    : Bus 65409	: V=0.992785, theta=-78.228699 -> V=1.0, theta=0.0
% INFO    : Bus 65410	: V=1.0001704, theta=-76.71351 -> V=1.0, theta=0.0
% INFO    : Bus 65411	: V=1.0001455, theta=-76.707407 -> V=1.0, theta=0.0
% INFO    : Bus 65412	: V=1.0200004, theta=-73.827563 -> V=1.0, theta=0.0
% INFO    : Bus 65413	: V=0.9742532, theta=1.289709 -> V=1.0, theta=0.0
% INFO    : Bus 65414	: V=0.9751548, theta=1.31343 -> V=1.0, theta=0.0
% INFO    : Bus 65415	: V=0.9763608, theta=1.388583 -> V=1.0, theta=0.0
% INFO    : Bus 65416	: V=0.9768854, theta=1.40449 -> V=1.0, theta=0.0
% INFO    : Bus 65417	: V=0.9757068, theta=1.34666 -> V=1.0, theta=0.0
% INFO    : Bus 65418	: V=0.9796157, theta=1.671832 -> V=1.0, theta=0.0
% INFO    : Bus 65419	: V=0.976482, theta=1.400021 -> V=1.0, theta=0.0
% INFO    : Bus 65420	: V=0.9774227, theta=1.453078 -> V=1.0, theta=0.0
% INFO    : Bus 65421	: V=0.9779115, theta=1.552671 -> V=1.0, theta=0.0
% INFO    : Bus 65422	: V=0.9802175, theta=1.686222 -> V=1.0, theta=0.0
% INFO    : Bus 65423	: V=0.9878591, theta=3.316598 -> V=1.0, theta=0.0
% INFO    : Bus 65424	: V=0.9879816, theta=3.343493 -> V=1.0, theta=0.0
% INFO    : Bus 65425	: V=0.9882344, theta=3.377927 -> V=1.0, theta=0.0
% INFO    : Bus 65426	: V=0.9853116, theta=2.744578 -> V=1.0, theta=0.0
% INFO    : Bus 65427	: V=0.9766686, theta=1.517639 -> V=1.0, theta=0.0
% INFO    : Bus 65428	: V=0.9886, theta=3.431111 -> V=1.0, theta=0.0
% INFO    : Bus 65429	: V=0.9887106, theta=3.50069 -> V=1.0, theta=0.0
% INFO    : Bus 65430	: V=0.9891398, theta=3.51003 -> V=1.0, theta=0.0
% INFO    : Bus 65431	: V=0.9802145, theta=1.685715 -> V=1.0, theta=0.0
% INFO    : Bus 65432	: V=0.980847, theta=1.703353 -> V=1.0, theta=0.0
% INFO    : Bus 65433	: V=0.9786216, theta=1.572594 -> V=1.0, theta=0.0
% INFO    : Bus 65434	: V=0.9790926, theta=1.609596 -> V=1.0, theta=0.0
% INFO    : Bus 65435	: V=0.9814074, theta=1.741467 -> V=1.0, theta=0.0
% INFO    : Bus 65436	: V=0.9793916, theta=1.963338 -> V=1.0, theta=0.0
% INFO    : Bus 65437	: V=0.9846561, theta=2.444987 -> V=1.0, theta=0.0
% INFO    : Bus 65438	: V=0.9839847, theta=2.42474 -> V=1.0, theta=0.0
% INFO    : Bus 65439	: V=0.978819, theta=1.9449 -> V=1.0, theta=0.0
% INFO    : Bus 65440	: V=0.9873604, theta=2.819824 -> V=1.0, theta=0.0
% INFO    : Bus 65441	: V=0.9929826, theta=3.965708 -> V=1.0, theta=0.0
% INFO    : Bus 65442	: V=0.9932768, theta=3.996091 -> V=1.0, theta=0.0
% INFO    : Bus 65443	: V=0.9933917, theta=4.002721 -> V=1.0, theta=0.0
% INFO    : Bus 65444	: V=0.9937507, theta=4.03625 -> V=1.0, theta=0.0
% INFO    : Bus 65445	: V=0.9879, theta=2.933117 -> V=1.0, theta=0.0
% INFO    : Bus 65446	: V=0.99433, theta=4.098501 -> V=1.0, theta=0.0
% INFO    : Bus 65447	: V=0.9898479, theta=3.581814 -> V=1.0, theta=0.0
% INFO    : Bus 65448	: V=0.9912563, theta=3.744651 -> V=1.0, theta=0.0
% INFO    : Bus 65449	: V=0.9910126, theta=3.721527 -> V=1.0, theta=0.0
% INFO    : Bus 65450	: V=0.9798314, theta=1.680002 -> V=1.0, theta=0.0
% INFO    : Bus 65451	: V=0.9895557, theta=3.573977 -> V=1.0, theta=0.0
% INFO    : Bus 65452	: V=0.9808128, theta=1.74867 -> V=1.0, theta=0.0
% INFO    : Bus 65453	: V=0.9831798, theta=1.816671 -> V=1.0, theta=0.0
% INFO    : Bus 65454	: V=0.9818818, theta=1.922419 -> V=1.0, theta=0.0
% INFO    : Bus 65455	: V=0.9890529, theta=3.580186 -> V=1.0, theta=0.0
% INFO    : Bus 65456	: V=0.9905222, theta=3.75245 -> V=1.0, theta=0.0
% INFO    : Bus 65457	: V=0.99193, theta=3.926733 -> V=1.0, theta=0.0
% INFO    : Bus 65458	: V=0.9978305, theta=4.690098 -> V=1.0, theta=0.0
% INFO    : Bus 65459	: V=0.9919302, theta=3.817127 -> V=1.0, theta=0.0
% INFO    : Bus 65460	: V=0.9931697, theta=3.965705 -> V=1.0, theta=0.0
% INFO    : Bus 65461	: V=0.9926804, theta=3.907989 -> V=1.0, theta=0.0
% INFO    : Bus 65462	: V=0.9942679, theta=4.084953 -> V=1.0, theta=0.0
% INFO    : Bus 65463	: V=0.9900858, theta=3.277299 -> V=1.0, theta=0.0
% INFO    : Bus 65464	: V=1.0200001, theta=8.944204 -> V=1.0, theta=0.0
% INFO    : Bus 65465	: V=0.9983395, theta=4.484428 -> V=1.0, theta=0.0
% INFO    : Bus 65466	: V=0.9965457, theta=4.345108 -> V=1.0, theta=0.0
% INFO    : Bus 65467	: V=0.9955494, theta=4.234984 -> V=1.0, theta=0.0
% INFO    : Bus 65468	: V=0.9892584, theta=3.006677 -> V=1.0, theta=0.0
% INFO    : Bus 65469	: V=0.9943575, theta=4.102494 -> V=1.0, theta=0.0
% INFO    : Bus 65470	: V=0.9936023, theta=4.024964 -> V=1.0, theta=0.0
% INFO    : Bus 65471	: V=0.9944432, theta=4.114663 -> V=1.0, theta=0.0
% INFO    : Bus 65472	: V=0.9850279, theta=2.624158 -> V=1.0, theta=0.0
% INFO    : Bus 65473	: V=0.9961109, theta=4.303005 -> V=1.0, theta=0.0
% INFO    : Bus 65474	: V=0.9816535, theta=1.595447 -> V=1.0, theta=0.0
% INFO    : Bus 65475	: V=0.9882351, theta=2.833736 -> V=1.0, theta=0.0
% INFO    : Bus 65476	: V=0.9845806, theta=2.691186 -> V=1.0, theta=0.0
% INFO    : Bus 65477	: V=0.9857633, theta=2.754745 -> V=1.0, theta=0.0
% INFO    : Bus 65478	: V=0.9793078, theta=1.402245 -> V=1.0, theta=0.0
% INFO    : Bus 65479	: V=0.9802341, theta=1.473333 -> V=1.0, theta=0.0
% INFO    : Bus 65480	: V=0.9918931, theta=3.860659 -> V=1.0, theta=0.0
% INFO    : Bus 65481	: V=0.9909723, theta=3.769538 -> V=1.0, theta=0.0
% INFO    : Bus 65482	: V=0.9801256, theta=1.473898 -> V=1.0, theta=0.0
% INFO    : Bus 65483	: V=0.97889, theta=1.43881 -> V=1.0, theta=0.0
% INFO    : Bus 65484	: V=0.978545, theta=1.435346 -> V=1.0, theta=0.0
% INFO    : Bus 65485	: V=0.9794463, theta=1.898441 -> V=1.0, theta=0.0
% INFO    : Bus 65486	: V=0.9801392, theta=1.931109 -> V=1.0, theta=0.0
% INFO    : Bus 65487	: V=0.9913533, theta=3.801642 -> V=1.0, theta=0.0
% INFO    : Bus 65488	: V=0.9920373, theta=3.734278 -> V=1.0, theta=0.0
% INFO    : Bus 65489	: V=0.9753656, theta=1.419463 -> V=1.0, theta=0.0
% INFO    : Bus 65490	: V=0.9886124, theta=3.520182 -> V=1.0, theta=0.0
% INFO    : Bus 65491	: V=0.9805818, theta=2.031991 -> V=1.0, theta=0.0
% INFO    : Bus 65492	: V=0.9892867, theta=3.450392 -> V=1.0, theta=0.0
% INFO    : Bus 65493	: V=0.9800569, theta=2.005518 -> V=1.0, theta=0.0
% INFO    : Bus 65494	: V=0.9838361, theta=2.310982 -> V=1.0, theta=0.0
% INFO    : Bus 65495	: V=0.9874532, theta=3.268325 -> V=1.0, theta=0.0
% INFO    : Bus 65496	: V=0.9878847, theta=3.311033 -> V=1.0, theta=0.0
% INFO    : Bus 65497	: V=0.9812063, theta=1.969533 -> V=1.0, theta=0.0
% INFO    : Bus 65498	: V=0.9744287, theta=1.102381 -> V=1.0, theta=0.0
% INFO    : Bus 65499	: V=0.9881811, theta=3.004339 -> V=1.0, theta=0.0
% INFO    : Bus 65500	: V=0.9906455, theta=3.594969 -> V=1.0, theta=0.0
% INFO    : Bus 65501	: V=0.9845191, theta=2.422492 -> V=1.0, theta=0.0
% INFO    : Bus 65502	: V=0.9854306, theta=2.46674 -> V=1.0, theta=0.0
% INFO    : Bus 65503	: V=0.9804821, theta=1.943434 -> V=1.0, theta=0.0
% INFO    : Bus 65504	: V=0.9820439, theta=2.022649 -> V=1.0, theta=0.0
% INFO    : Bus 65505	: V=0.9831166, theta=2.226709 -> V=1.0, theta=0.0
% INFO    : Bus 65506	: V=0.9842906, theta=2.263735 -> V=1.0, theta=0.0
% INFO    : Bus 65507	: V=0.9838816, theta=2.686261 -> V=1.0, theta=0.0
% INFO    : Bus 65508	: V=0.9859122, theta=2.805728 -> V=1.0, theta=0.0
% INFO    : Bus 65509	: V=0.9815284, theta=2.125181 -> V=1.0, theta=0.0
% INFO    : Bus 65510	: V=0.9920204, theta=3.746273 -> V=1.0, theta=0.0
% INFO    : Bus 65511	: V=1.0200001, theta=9.454789 -> V=1.0, theta=0.0
% INFO    : Bus 65512	: V=0.980549, theta=1.939641 -> V=1.0, theta=0.0
% INFO    : Bus 65513	: V=0.9810675, theta=1.95713 -> V=1.0, theta=0.0
% INFO    : Bus 65514	: V=0.9788328, theta=1.415997 -> V=1.0, theta=0.0
% INFO    : Bus 65515	: V=0.9777712, theta=1.171655 -> V=1.0, theta=0.0
% INFO    : Bus 65516	: V=0.975146, theta=1.105919 -> V=1.0, theta=0.0
% INFO    : Bus 65517	: V=0.980627, theta=1.323021 -> V=1.0, theta=0.0
% INFO    : Bus 65518	: V=0.9928357, theta=3.264913 -> V=1.0, theta=0.0
% INFO    : Bus 65519	: V=1.0300001, theta=13.324182 -> V=1.0, theta=0.0
% INFO    : Bus 65520	: V=0.9970306, theta=4.505038 -> V=1.0, theta=0.0
% INFO    : Bus 65521	: V=0.9893172, theta=2.954337 -> V=1.0, theta=0.0
% INFO    : Bus 65522	: V=0.9905894, theta=4.044961 -> V=1.0, theta=0.0
% INFO    : Bus 65523	: V=1.0001762, theta=4.798566 -> V=1.0, theta=0.0
% INFO    : Bus 65524	: V=0.9958074, theta=4.036321 -> V=1.0, theta=0.0
% INFO    : Bus 65525	: V=0.997714, theta=4.315887 -> V=1.0, theta=0.0
% INFO    : Bus 65526	: V=1.0015562, theta=4.982369 -> V=1.0, theta=0.0
% INFO    : Bus 65527	: V=1.0035965, theta=5.280552 -> V=1.0, theta=0.0
% INFO    : Bus 65528	: V=0.9850215, theta=2.831945 -> V=1.0, theta=0.0
% INFO    : Bus 65529	: V=0.9861761, theta=2.937501 -> V=1.0, theta=0.0
% INFO    : Bus 65530	: V=0.9971366, theta=4.176089 -> V=1.0, theta=0.0
% INFO    : Bus 65531	: V=0.9744427, theta=1.775051 -> V=1.0, theta=0.0
% INFO    : Bus 65532	: V=0.9753491, theta=1.908506 -> V=1.0, theta=0.0
% INFO    : Bus 65533	: V=0.9799859, theta=3.076585 -> V=1.0, theta=0.0
% INFO    : Bus 65534	: V=0.9739837, theta=1.329509 -> V=1.0, theta=0.0
% INFO    : Bus 65535	: V=0.981198, theta=3.10752 -> V=1.0, theta=0.0
% INFO    : Bus 65536	: V=0.9824316, theta=3.24414 -> V=1.0, theta=0.0
% INFO    : Bus 65537	: V=0.9830138, theta=3.309511 -> V=1.0, theta=0.0
% INFO    : Bus 65538	: V=0.9846596, theta=3.493101 -> V=1.0, theta=0.0
% INFO    : Bus 65539	: V=0.9838291, theta=3.401228 -> V=1.0, theta=0.0
% INFO    : Bus 65540	: V=0.9790225, theta=1.552494 -> V=1.0, theta=0.0
% INFO    : Bus 65541	: V=0.978715, theta=1.472263 -> V=1.0, theta=0.0
% INFO    : Bus 65542	: V=0.9829514, theta=2.476073 -> V=1.0, theta=0.0
% INFO    : Bus 65543	: V=0.9902574, theta=4.066509 -> V=1.0, theta=0.0
% INFO    : Bus 65544	: V=0.9903405, theta=4.056425 -> V=1.0, theta=0.0
% INFO    : Bus 65545	: V=0.9854395, theta=2.91699 -> V=1.0, theta=0.0
% INFO    : Bus 65546	: V=0.9894618, theta=3.094579 -> V=1.0, theta=0.0
% INFO    : Bus 65547	: V=0.9919061, theta=3.313802 -> V=1.0, theta=0.0
% INFO    : Bus 65548	: V=0.9822296, theta=2.45143 -> V=1.0, theta=0.0
% INFO    : Bus 65549	: V=0.9833341, theta=2.53632 -> V=1.0, theta=0.0
% INFO    : Bus 65550	: V=0.9912767, theta=4.243455 -> V=1.0, theta=0.0
% INFO    : Bus 65551	: V=0.987228, theta=3.777645 -> V=1.0, theta=0.0
% INFO    : Bus 65552	: V=0.9856691, theta=2.847826 -> V=1.0, theta=0.0
% INFO    : Bus 65553	: V=0.9910338, theta=4.698485 -> V=1.0, theta=0.0
% INFO    : Bus 65554	: V=0.979762, theta=3.091672 -> V=1.0, theta=0.0
% INFO    : Bus 65555	: V=0.9709978, theta=1.608673 -> V=1.0, theta=0.0
% INFO    : Bus 65556	: V=0.9720281, theta=1.633491 -> V=1.0, theta=0.0
% INFO    : Bus 65557	: V=0.9713957, theta=1.648103 -> V=1.0, theta=0.0
% INFO    : Bus 65558	: V=0.9830779, theta=2.615742 -> V=1.0, theta=0.0
% INFO    : Bus 65559	: V=0.9848793, theta=2.800349 -> V=1.0, theta=0.0
% INFO    : Bus 65560	: V=0.9803455, theta=3.064857 -> V=1.0, theta=0.0
% INFO    : Bus 65561	: V=0.9749522, theta=1.792871 -> V=1.0, theta=0.0
% INFO    : Bus 65562	: V=0.9755457, theta=1.834164 -> V=1.0, theta=0.0
% INFO    : Bus 65563	: V=0.9825455, theta=2.648567 -> V=1.0, theta=0.0
% INFO    : Bus 65564	: V=0.9912139, theta=6.851291 -> V=1.0, theta=0.0
% INFO    : Bus 65565	: V=1.002884, theta=5.21243 -> V=1.0, theta=0.0
% INFO    : Bus 65566	: V=1.0116676, theta=19.627412 -> V=1.0, theta=0.0
% INFO    : Bus 65567	: V=0.9743673, theta=-6.325419 -> V=1.0, theta=0.0
% INFO    : Bus 65568	: V=0.9740325, theta=-6.258791 -> V=1.0, theta=0.0
% INFO    : Bus 65569	: V=0.9726363, theta=-6.451889 -> V=1.0, theta=0.0
% INFO    : Bus 65570	: V=0.9687306, theta=-6.575168 -> V=1.0, theta=0.0
% INFO    : Bus 65571	: V=0.9752817, theta=-6.214917 -> V=1.0, theta=0.0
% INFO    : Bus 65572	: V=0.9854623, theta=-4.588684 -> V=1.0, theta=0.0
% INFO    : Bus 65573	: V=0.9853988, theta=-4.594204 -> V=1.0, theta=0.0
% INFO    : Bus 65574	: V=0.9762067, theta=-6.109813 -> V=1.0, theta=0.0
% INFO    : Bus 65575	: V=0.9722157, theta=-6.312486 -> V=1.0, theta=0.0
% INFO    : Bus 65576	: V=0.971007, theta=-6.561317 -> V=1.0, theta=0.0
% INFO    : Bus 65577	: V=0.9713932, theta=-6.547036 -> V=1.0, theta=0.0
% INFO    : Bus 65578	: V=0.9838201, theta=-4.877543 -> V=1.0, theta=0.0
% INFO    : Bus 65579	: V=0.9973875, theta=-3.841964 -> V=1.0, theta=0.0
% INFO    : Bus 65580	: V=0.9834094, theta=-5.366662 -> V=1.0, theta=0.0
% INFO    : Bus 65581	: V=0.9855335, theta=-4.056272 -> V=1.0, theta=0.0
% INFO    : Bus 65582	: V=0.9938108, theta=-2.129348 -> V=1.0, theta=0.0
% INFO    : Bus 65583	: V=0.9960125, theta=12.106298 -> V=1.0, theta=0.0
% INFO    : Bus 65584	: V=0.9878328, theta=21.069053 -> V=1.0, theta=0.0
% INFO    : Bus 65585	: V=0.9945546, theta=9.228155 -> V=1.0, theta=0.0
% INFO    : Bus 65586	: V=0.9981683, theta=16.716415 -> V=1.0, theta=0.0
% INFO    : Bus 65587	: V=0.9985752, theta=17.032106 -> V=1.0, theta=0.0
% INFO    : Bus 65588	: V=0.9995755, theta=17.540314 -> V=1.0, theta=0.0
% INFO    : Bus 65589	: V=0.9816658, theta=20.411274 -> V=1.0, theta=0.0
% INFO    : Bus 65590	: V=0.9963374, theta=9.020002 -> V=1.0, theta=0.0
% INFO    : Bus 65591	: V=1.0137112, theta=12.135501 -> V=1.0, theta=0.0
% INFO    : Bus 65592	: V=1.0006246, theta=9.748702 -> V=1.0, theta=0.0
% INFO    : Bus 65593	: V=0.9484535, theta=-1.227513 -> V=1.0, theta=0.0
% INFO    : Bus 65594	: V=0.9465939, theta=-1.277488 -> V=1.0, theta=0.0
% INFO    : Bus 65595	: V=0.947559, theta=-1.251859 -> V=1.0, theta=0.0
% INFO    : Bus 65596	: V=0.9497544, theta=-1.001179 -> V=1.0, theta=0.0
% INFO    : Bus 65597	: V=0.9529802, theta=-0.663927 -> V=1.0, theta=0.0
% INFO    : Bus 65598	: V=0.9512445, theta=-0.700514 -> V=1.0, theta=0.0
% INFO    : Bus 65599	: V=0.9534952, theta=-0.668643 -> V=1.0, theta=0.0
% INFO    : Bus 65600	: V=0.9628126, theta=0.875185 -> V=1.0, theta=0.0
% INFO    : Bus 65601	: V=0.978929, theta=3.933628 -> V=1.0, theta=0.0
% INFO    : Bus 65602	: V=0.9668567, theta=2.689449 -> V=1.0, theta=0.0
% INFO    : Bus 65603	: V=0.9650541, theta=1.065641 -> V=1.0, theta=0.0
% INFO    : Bus 65604	: V=0.9677037, theta=1.780185 -> V=1.0, theta=0.0
% INFO    : Bus 65605	: V=1.009979, theta=11.02095 -> V=1.0, theta=0.0
% INFO    : Bus 65606	: V=0.9709518, theta=-1.742616 -> V=1.0, theta=0.0
% INFO    : Bus 65607	: V=0.9769599, theta=-1.104012 -> V=1.0, theta=0.0
% INFO    : Bus 65608	: V=0.9759592, theta=-1.281144 -> V=1.0, theta=0.0
% INFO    : Bus 65609	: V=0.982697, theta=0.999787 -> V=1.0, theta=0.0
% INFO    : Bus 65610	: V=0.9791535, theta=-0.60711 -> V=1.0, theta=0.0
% INFO    : Bus 65611	: V=0.9750837, theta=-1.383058 -> V=1.0, theta=0.0
% INFO    : Bus 65612	: V=0.9724731, theta=-1.693139 -> V=1.0, theta=0.0
% INFO    : Bus 65613	: V=0.9709672, theta=-1.763192 -> V=1.0, theta=0.0
% INFO    : Bus 65614	: V=0.9756348, theta=-1.330029 -> V=1.0, theta=0.0
% INFO    : Bus 65615	: V=0.974169, theta=-1.506309 -> V=1.0, theta=0.0
% INFO    : Bus 65616	: V=0.9701588, theta=-1.815548 -> V=1.0, theta=0.0
% INFO    : Bus 65617	: V=0.9751102, theta=-1.573958 -> V=1.0, theta=0.0
% INFO    : Bus 65618	: V=0.981234, theta=-0.499186 -> V=1.0, theta=0.0
% INFO    : Bus 65619	: V=0.982598, theta=-0.447423 -> V=1.0, theta=0.0
% INFO    : Bus 65620	: V=0.9780978, theta=-1.248482 -> V=1.0, theta=0.0
% INFO    : Bus 65621	: V=0.9819095, theta=-1.211586 -> V=1.0, theta=0.0
% INFO    : Bus 65622	: V=0.9869496, theta=-0.204032 -> V=1.0, theta=0.0
% INFO    : Bus 65623	: V=0.9589801, theta=-2.85719 -> V=1.0, theta=0.0
% INFO    : Bus 65624	: V=0.9688368, theta=-1.855389 -> V=1.0, theta=0.0
% INFO    : Bus 65625	: V=0.9747787, theta=-1.477944 -> V=1.0, theta=0.0
% INFO    : Bus 65626	: V=0.967831, theta=-1.869748 -> V=1.0, theta=0.0
% INFO    : Bus 65627	: V=0.9706037, theta=-1.611746 -> V=1.0, theta=0.0
% INFO    : Bus 65628	: V=0.9709042, theta=-2.314338 -> V=1.0, theta=0.0
% INFO    : Bus 65629	: V=0.9663208, theta=-3.297342 -> V=1.0, theta=0.0
% INFO    : Bus 65630	: V=0.9742529, theta=-1.602547 -> V=1.0, theta=0.0
% INFO    : Bus 65631	: V=0.9460556, theta=-4.38113 -> V=1.0, theta=0.0
% INFO    : Bus 65632	: V=0.9718437, theta=0.488864 -> V=1.0, theta=0.0
% INFO    : Bus 65633	: V=0.9551707, theta=-3.116479 -> V=1.0, theta=0.0
% INFO    : Bus 65634	: V=0.9975411, theta=0.507176 -> V=1.0, theta=0.0
% INFO    : Bus 65635	: V=0.9920929, theta=1.349283 -> V=1.0, theta=0.0
% INFO    : Bus 65636	: V=0.9987702, theta=0.260572 -> V=1.0, theta=0.0
% INFO    : Bus 65637	: V=1.0010992, theta=1.057903 -> V=1.0, theta=0.0
% INFO    : Bus 65638	: V=1.0073158, theta=1.164859 -> V=1.0, theta=0.0
% INFO    : Bus 65639	: V=1.0066769, theta=1.093337 -> V=1.0, theta=0.0
% INFO    : Bus 65640	: V=1.0075116, theta=1.500186 -> V=1.0, theta=0.0
% INFO    : Bus 65641	: V=0.9885126, theta=-0.190793 -> V=1.0, theta=0.0
% INFO    : Bus 65642	: V=0.9927348, theta=0.011462 -> V=1.0, theta=0.0
% INFO    : Bus 65643	: V=0.9751546, theta=-1.764137 -> V=1.0, theta=0.0
% INFO    : Bus 65644	: V=0.9913972, theta=-0.317092 -> V=1.0, theta=0.0
% INFO    : Bus 65645	: V=0.9903839, theta=-0.389197 -> V=1.0, theta=0.0
% INFO    : Bus 65646	: V=0.9637271, theta=-4.613869 -> V=1.0, theta=0.0
% INFO    : Bus 65647	: V=0.9777499, theta=-3.981832 -> V=1.0, theta=0.0
% INFO    : Bus 65648	: V=0.9802484, theta=-3.597377 -> V=1.0, theta=0.0
% INFO    : Bus 65649	: V=0.9785407, theta=-3.859925 -> V=1.0, theta=0.0
% INFO    : Bus 65650	: V=0.9725537, theta=-4.280219 -> V=1.0, theta=0.0
% INFO    : Bus 65651	: V=0.9766504, theta=-3.910352 -> V=1.0, theta=0.0
% INFO    : Bus 65652	: V=0.9766252, theta=-4.169185 -> V=1.0, theta=0.0
% INFO    : Bus 65653	: V=0.9773304, theta=-3.836716 -> V=1.0, theta=0.0
% INFO    : Bus 65654	: V=1.0200001, theta=1.644958 -> V=1.0, theta=0.0
% INFO    : Bus 65655	: V=0.966075, theta=-4.155252 -> V=1.0, theta=0.0
% INFO    : Bus 65656	: V=1.0200001, theta=2.833917 -> V=1.0, theta=0.0
% INFO    : Bus 65657	: V=1.0200001, theta=2.7294 -> V=1.0, theta=0.0
% INFO    : Bus 65658	: V=1.0106752, theta=0.743427 -> V=1.0, theta=0.0
% INFO    : Bus 65659	: V=0.9750766, theta=5.160265 -> V=1.0, theta=0.0
% INFO    : Bus 65660	: V=0.9843492, theta=5.402058 -> V=1.0, theta=0.0
% INFO    : Bus 65661	: V=0.9874341, theta=5.588972 -> V=1.0, theta=0.0
% INFO    : Bus 65662	: V=0.9895474, theta=5.795743 -> V=1.0, theta=0.0
% INFO    : Bus 65663	: V=0.9814188, theta=5.327431 -> V=1.0, theta=0.0
% INFO    : Bus 65664	: V=1.0137406, theta=8.513432 -> V=1.0, theta=0.0
% INFO    : Bus 65665	: V=0.9851917, theta=5.429353 -> V=1.0, theta=0.0
% INFO    : Bus 65666	: V=1.0094323, theta=10.742446 -> V=1.0, theta=0.0
% INFO    : Bus 65667	: V=1.0074118, theta=12.171093 -> V=1.0, theta=0.0
% INFO    : Bus 65668	: V=1.017052, theta=9.939486 -> V=1.0, theta=0.0
% INFO    : Bus 65669	: V=1.0023251, theta=8.885756 -> V=1.0, theta=0.0
% INFO    : Bus 65670	: V=1.0081433, theta=11.677361 -> V=1.0, theta=0.0
% INFO    : Bus 65671	: V=0.9793551, theta=-2.449569 -> V=1.0, theta=0.0
% INFO    : Bus 65672	: V=0.9779732, theta=-2.568151 -> V=1.0, theta=0.0
% INFO    : Bus 65673	: V=0.9774874, theta=-2.559935 -> V=1.0, theta=0.0
% INFO    : Bus 65674	: V=0.9764432, theta=-2.595398 -> V=1.0, theta=0.0
% INFO    : Bus 65675	: V=0.976294, theta=-2.263382 -> V=1.0, theta=0.0
% INFO    : Bus 65676	: V=0.9781772, theta=-2.201168 -> V=1.0, theta=0.0
% INFO    : Bus 65677	: V=0.9796874, theta=-2.158434 -> V=1.0, theta=0.0
% INFO    : Bus 65678	: V=0.9949953, theta=1.315374 -> V=1.0, theta=0.0
% INFO    : Bus 65679	: V=0.9751843, theta=-2.29351 -> V=1.0, theta=0.0
% INFO    : Bus 65680	: V=1.0053474, theta=2.561585 -> V=1.0, theta=0.0
% INFO    : Bus 65681	: V=0.9782611, theta=-2.202681 -> V=1.0, theta=0.0
% INFO    : Bus 65682	: V=0.9766539, theta=-2.247018 -> V=1.0, theta=0.0
% INFO    : Bus 65683	: V=0.9745833, theta=-0.758999 -> V=1.0, theta=0.0
% INFO    : Bus 65684	: V=0.9806082, theta=-2.096924 -> V=1.0, theta=0.0
% INFO    : Bus 65685	: V=0.9986215, theta=0.730563 -> V=1.0, theta=0.0
% INFO    : Bus 65686	: V=0.9973589, theta=0.463386 -> V=1.0, theta=0.0
% INFO    : Bus 65687	: V=0.9979661, theta=0.596263 -> V=1.0, theta=0.0
% INFO    : Bus 65688	: V=0.9905993, theta=-1.052945 -> V=1.0, theta=0.0
% INFO    : Bus 65689	: V=0.9963273, theta=-0.262301 -> V=1.0, theta=0.0
% INFO    : Bus 65690	: V=0.9771645, theta=-4.508459 -> V=1.0, theta=0.0
% INFO    : Bus 65691	: V=0.9806198, theta=-5.031666 -> V=1.0, theta=0.0
% INFO    : Bus 65692	: V=0.978534, theta=-4.993699 -> V=1.0, theta=0.0
% INFO    : Bus 65693	: V=0.9736754, theta=-6.256142 -> V=1.0, theta=0.0
% INFO    : Bus 65694	: V=0.9760205, theta=3.696832 -> V=1.0, theta=0.0
% INFO    : Bus 65695	: V=0.9783709, theta=3.998497 -> V=1.0, theta=0.0
% INFO    : Bus 65696	: V=1.0200001, theta=15.729861 -> V=1.0, theta=0.0
% INFO    : Bus 65697	: V=0.9830424, theta=4.850153 -> V=1.0, theta=0.0
% INFO    : Bus 65698	: V=1.0129601, theta=7.998378 -> V=1.0, theta=0.0
% INFO    : Bus 65699	: V=1.0123252, theta=8.899087 -> V=1.0, theta=0.0
% INFO    : Bus 65700	: V=1.0147476, theta=8.486943 -> V=1.0, theta=0.0
% INFO    : Bus 65701	: V=0.9917686, theta=3.966284 -> V=1.0, theta=0.0
% INFO    : Bus 65702	: V=1.0140195, theta=8.990293 -> V=1.0, theta=0.0
% INFO    : Bus 65703	: V=1.0159573, theta=8.517264 -> V=1.0, theta=0.0
% INFO    : Bus 65704	: V=1.0032964, theta=23.933982 -> V=1.0, theta=0.0
% INFO    : Bus 65705	: V=1.0013652, theta=23.499229 -> V=1.0, theta=0.0
% INFO    : Bus 65706	: V=0.9749209, theta=19.086087 -> V=1.0, theta=0.0
% INFO    : Bus 65707	: V=0.9846816, theta=20.590718 -> V=1.0, theta=0.0
% INFO    : Bus 65708	: V=0.9809745, theta=23.413645 -> V=1.0, theta=0.0
% INFO    : Bus 65709	: V=0.9882301, theta=24.937632 -> V=1.0, theta=0.0
% INFO    : Bus 65710	: V=0.9832269, theta=21.168689 -> V=1.0, theta=0.0
% INFO    : Bus 65711	: V=0.9876382, theta=21.616679 -> V=1.0, theta=0.0
% INFO    : Bus 65712	: V=0.9797898, theta=16.658208 -> V=1.0, theta=0.0
% INFO    : Bus 65713	: V=0.9826145, theta=21.322895 -> V=1.0, theta=0.0
% INFO    : Bus 65714	: V=0.9812894, theta=21.612359 -> V=1.0, theta=0.0
% INFO    : Bus 65715	: V=0.9817667, theta=21.102798 -> V=1.0, theta=0.0
% INFO    : Bus 65716	: V=0.9815212, theta=21.003059 -> V=1.0, theta=0.0
% INFO    : Bus 65717	: V=0.9800631, theta=20.911246 -> V=1.0, theta=0.0
% INFO    : Bus 65718	: V=0.9907273, theta=21.92658 -> V=1.0, theta=0.0
% INFO    : Bus 65719	: V=1.0081932, theta=21.394497 -> V=1.0, theta=0.0
% INFO    : Bus 65720	: V=1.0021362, theta=21.861452 -> V=1.0, theta=0.0
% INFO    : Bus 65721	: V=0.9866156, theta=3.918735 -> V=1.0, theta=0.0
% INFO    : Bus 65722	: V=0.9617682, theta=-11.753501 -> V=1.0, theta=0.0
% INFO    : Bus 65723	: V=0.9617375, theta=-11.712395 -> V=1.0, theta=0.0
% INFO    : Bus 65724	: V=0.9614122, theta=-11.620741 -> V=1.0, theta=0.0
% INFO    : Bus 65725	: V=0.9608324, theta=-11.499024 -> V=1.0, theta=0.0
% INFO    : Bus 65726	: V=0.961783, theta=-11.631749 -> V=1.0, theta=0.0
% INFO    : Bus 65727	: V=0.9606061, theta=-11.460681 -> V=1.0, theta=0.0
% INFO    : Bus 65728	: V=0.9614924, theta=-11.432773 -> V=1.0, theta=0.0
% INFO    : Bus 65729	: V=0.9635318, theta=-10.946747 -> V=1.0, theta=0.0
% INFO    : Bus 65730	: V=0.9611874, theta=-11.09393 -> V=1.0, theta=0.0
% INFO    : Bus 65731	: V=0.9645781, theta=-5.87153 -> V=1.0, theta=0.0
% INFO    : Bus 65732	: V=0.9643346, theta=-7.673314 -> V=1.0, theta=0.0
% INFO    : Bus 65733	: V=0.9605689, theta=-11.274298 -> V=1.0, theta=0.0
% INFO    : Bus 65734	: V=0.9513642, theta=-12.751275 -> V=1.0, theta=0.0
% INFO    : Bus 65735	: V=0.9651862, theta=-10.151853 -> V=1.0, theta=0.0
% INFO    : Bus 65736	: V=0.9688691, theta=-6.068752 -> V=1.0, theta=0.0
% INFO    : Bus 65737	: V=0.971663, theta=-8.667964 -> V=1.0, theta=0.0
% INFO    : Bus 65738	: V=0.9826836, theta=8.832772 -> V=1.0, theta=0.0
% INFO    : Bus 65739	: V=0.9868947, theta=8.9471 -> V=1.0, theta=0.0
% INFO    : Bus 65740	: V=1.0073966, theta=11.691037 -> V=1.0, theta=0.0
% INFO    : Bus 65741	: V=0.958372, theta=-1.386306 -> V=1.0, theta=0.0
% INFO    : Bus 65742	: V=0.9660129, theta=1.6673 -> V=1.0, theta=0.0
% INFO    : Bus 65743	: V=0.9657873, theta=1.302735 -> V=1.0, theta=0.0
% INFO    : Bus 65744	: V=0.9485917, theta=20.852989 -> V=1.0, theta=0.0
% INFO    : Bus 65745	: V=0.9515518, theta=29.640273 -> V=1.0, theta=0.0
% INFO    : Bus 65746	: V=0.9651042, theta=0.835739 -> V=1.0, theta=0.0
% INFO    : Bus 65747	: V=0.9697554, theta=1.626166 -> V=1.0, theta=0.0
% INFO    : Bus 65748	: V=0.9723442, theta=34.19403 -> V=1.0, theta=0.0
% INFO    : Bus 65749	: V=0.9624181, theta=0.847848 -> V=1.0, theta=0.0
% INFO    : Bus 65750	: V=0.9567198, theta=-2.281583 -> V=1.0, theta=0.0
% INFO    : Bus 65751	: V=0.9544626, theta=-2.358619 -> V=1.0, theta=0.0
% INFO    : Bus 65752	: V=0.9575157, theta=-2.265799 -> V=1.0, theta=0.0
% INFO    : Bus 65753	: V=0.9829335, theta=-2.041205 -> V=1.0, theta=0.0
% INFO    : Bus 65754	: V=0.9780488, theta=-0.38745 -> V=1.0, theta=0.0
% INFO    : Bus 65755	: V=0.9780683, theta=2.380057 -> V=1.0, theta=0.0
% INFO    : Bus 65756	: V=0.9843713, theta=3.22812 -> V=1.0, theta=0.0
% INFO    : Bus 65757	: V=0.9832275, theta=3.151125 -> V=1.0, theta=0.0
% INFO    : Bus 65758	: V=0.9751675, theta=2.239541 -> V=1.0, theta=0.0
% INFO    : Bus 65759	: V=0.9810192, theta=3.044155 -> V=1.0, theta=0.0
% INFO    : Bus 65760	: V=0.9757537, theta=2.25546 -> V=1.0, theta=0.0
% INFO    : Bus 65761	: V=0.9781753, theta=3.464321 -> V=1.0, theta=0.0
% INFO    : Bus 65762	: V=0.9774003, theta=3.703999 -> V=1.0, theta=0.0
% INFO    : Bus 65763	: V=0.9810064, theta=3.091965 -> V=1.0, theta=0.0
% INFO    : Bus 65764	: V=0.9762371, theta=2.287309 -> V=1.0, theta=0.0
% INFO    : Bus 65765	: V=0.9821661, theta=3.088562 -> V=1.0, theta=0.0
% INFO    : Bus 65766	: V=0.9711115, theta=2.43337 -> V=1.0, theta=0.0
% INFO    : Bus 65767	: V=0.9744807, theta=2.75651 -> V=1.0, theta=0.0
% INFO    : Bus 65768	: V=0.9797846, theta=3.189183 -> V=1.0, theta=0.0
% INFO    : Bus 65769	: V=0.9744281, theta=1.942954 -> V=1.0, theta=0.0
% INFO    : Bus 65770	: V=0.9763651, theta=3.205726 -> V=1.0, theta=0.0
% INFO    : Bus 65771	: V=0.9763672, theta=4.085807 -> V=1.0, theta=0.0
% INFO    : Bus 65772	: V=0.9740347, theta=5.187001 -> V=1.0, theta=0.0
% INFO    : Bus 65773	: V=0.9661179, theta=11.104687 -> V=1.0, theta=0.0
% INFO    : Bus 65774	: V=0.968529, theta=5.732742 -> V=1.0, theta=0.0
% INFO    : Bus 65775	: V=0.9822338, theta=2.298809 -> V=1.0, theta=0.0
% INFO    : Bus 65776	: V=0.9716245, theta=5.524967 -> V=1.0, theta=0.0
% INFO    : Bus 65777	: V=0.9703293, theta=4.536013 -> V=1.0, theta=0.0
% INFO    : Bus 65778	: V=0.9771211, theta=2.362396 -> V=1.0, theta=0.0
% INFO    : Bus 65779	: V=0.9673666, theta=7.837216 -> V=1.0, theta=0.0
% INFO    : Bus 65780	: V=0.9841106, theta=3.645688 -> V=1.0, theta=0.0
% INFO    : Bus 65781	: V=0.9576478, theta=19.182676 -> V=1.0, theta=0.0
% INFO    : Bus 65782	: V=1.0099229, theta=42.162554 -> V=1.0, theta=0.0
% INFO    : Bus 65783	: V=1.007441, theta=41.557461 -> V=1.0, theta=0.0
% INFO    : Bus 65784	: V=1.0088063, theta=41.792198 -> V=1.0, theta=0.0
% INFO    : Bus 65785	: V=1.0091028, theta=41.859457 -> V=1.0, theta=0.0
% INFO    : Bus 65786	: V=1.0108757, theta=42.162643 -> V=1.0, theta=0.0
% INFO    : Bus 65787	: V=1.0118268, theta=42.438707 -> V=1.0, theta=0.0
% INFO    : Bus 65788	: V=1.0098284, theta=41.566861 -> V=1.0, theta=0.0
% INFO    : Bus 65789	: V=1.0131761, theta=42.707501 -> V=1.0, theta=0.0
% INFO    : Bus 65790	: V=1.0110556, theta=42.356033 -> V=1.0, theta=0.0
% INFO    : Bus 65791	: V=1.0300001, theta=45.760961 -> V=1.0, theta=0.0
% INFO    : Bus 65792	: V=1.0200001, theta=47.601977 -> V=1.0, theta=0.0
% INFO    : Bus 65793	: V=1.0200001, theta=46.164528 -> V=1.0, theta=0.0
% INFO    : Bus 65794	: V=1.009055, theta=41.940832 -> V=1.0, theta=0.0
% INFO    : Bus 65795	: V=1.0026417, theta=40.684937 -> V=1.0, theta=0.0
% INFO    : Bus 65796	: V=0.9968346, theta=39.13454 -> V=1.0, theta=0.0
% INFO    : Bus 65797	: V=0.9976276, theta=39.451597 -> V=1.0, theta=0.0
% INFO    : Bus 65798	: V=0.9955282, theta=39.211866 -> V=1.0, theta=0.0
% INFO    : Bus 65799	: V=0.999769, theta=39.860395 -> V=1.0, theta=0.0
% INFO    : Bus 65800	: V=1.0028291, theta=40.589497 -> V=1.0, theta=0.0
% INFO    : Bus 65801	: V=1.00017, theta=39.48277 -> V=1.0, theta=0.0
% INFO    : Bus 65802	: V=1.0094649, theta=41.793804 -> V=1.0, theta=0.0
% INFO    : Bus 65803	: V=0.9872003, theta=36.187703 -> V=1.0, theta=0.0
% INFO    : Bus 65804	: V=1.0092053, theta=41.799186 -> V=1.0, theta=0.0
% INFO    : Bus 65805	: V=1.0016893, theta=40.174203 -> V=1.0, theta=0.0
% INFO    : Bus 65806	: V=1.0040016, theta=40.501943 -> V=1.0, theta=0.0
% INFO    : Bus 65807	: V=1.0134037, theta=42.209261 -> V=1.0, theta=0.0
% INFO    : Bus 65808	: V=1.0151087, theta=42.853723 -> V=1.0, theta=0.0
% INFO    : Bus 65809	: V=1.0124312, theta=43.076524 -> V=1.0, theta=0.0
% INFO    : Bus 65810	: V=0.982318, theta=34.662817 -> V=1.0, theta=0.0
% INFO    : Bus 65811	: V=0.9997723, theta=40.621129 -> V=1.0, theta=0.0
% INFO    : Bus 65812	: V=0.9761363, theta=28.602418 -> V=1.0, theta=0.0
% INFO    : Bus 65813	: V=0.9647075, theta=31.03766 -> V=1.0, theta=0.0
% INFO    : Bus 65814	: V=1.0048419, theta=41.552897 -> V=1.0, theta=0.0
% INFO    : Bus 65815	: V=0.9778763, theta=3.069381 -> V=1.0, theta=0.0
% INFO    : Bus 65816	: V=0.9791604, theta=3.145779 -> V=1.0, theta=0.0
% INFO    : Bus 65817	: V=0.9794104, theta=3.060225 -> V=1.0, theta=0.0
% INFO    : Bus 65818	: V=1.0152208, theta=10.313326 -> V=1.0, theta=0.0
% INFO    : Bus 65819	: V=0.9786047, theta=2.908924 -> V=1.0, theta=0.0
% INFO    : Bus 65820	: V=0.9999945, theta=10.447963 -> V=1.0, theta=0.0
% INFO    : Bus 65821	: V=0.9782156, theta=3.076243 -> V=1.0, theta=0.0
% INFO    : Bus 65822	: V=0.9642128, theta=0.316356 -> V=1.0, theta=0.0
% INFO    : Bus 65823	: V=0.9661029, theta=0.48395 -> V=1.0, theta=0.0
% INFO    : Bus 65824	: V=0.9671983, theta=0.524412 -> V=1.0, theta=0.0
% INFO    : Bus 65825	: V=0.966297, theta=0.430205 -> V=1.0, theta=0.0
% INFO    : Bus 65826	: V=0.9651133, theta=0.359938 -> V=1.0, theta=0.0
% INFO    : Bus 65827	: V=0.9681378, theta=1.613336 -> V=1.0, theta=0.0
% INFO    : Bus 65828	: V=0.9684987, theta=1.668651 -> V=1.0, theta=0.0
% INFO    : Bus 65829	: V=0.9640793, theta=0.211582 -> V=1.0, theta=0.0
% INFO    : Bus 65830	: V=0.9648125, theta=0.239958 -> V=1.0, theta=0.0
% INFO    : Bus 65831	: V=0.9662338, theta=0.403535 -> V=1.0, theta=0.0
% INFO    : Bus 65832	: V=0.9679686, theta=1.590418 -> V=1.0, theta=0.0
% INFO    : Bus 65833	: V=0.9627074, theta=0.093587 -> V=1.0, theta=0.0
% INFO    : Bus 65834	: V=0.9649911, theta=0.225594 -> V=1.0, theta=0.0
% INFO    : Bus 65835	: V=0.9635816, theta=0.146163 -> V=1.0, theta=0.0
% INFO    : Bus 65836	: V=0.966835, theta=0.363204 -> V=1.0, theta=0.0
% INFO    : Bus 65837	: V=0.9648888, theta=0.197118 -> V=1.0, theta=0.0
% INFO    : Bus 65838	: V=0.9683163, theta=1.615764 -> V=1.0, theta=0.0
% INFO    : Bus 65839	: V=0.9667201, theta=0.398148 -> V=1.0, theta=0.0
% INFO    : Bus 65840	: V=0.9656227, theta=0.483457 -> V=1.0, theta=0.0
% INFO    : Bus 65841	: V=0.9675598, theta=0.816129 -> V=1.0, theta=0.0
% INFO    : Bus 65842	: V=0.9672209, theta=0.80602 -> V=1.0, theta=0.0
% INFO    : Bus 65843	: V=0.9669588, theta=0.539715 -> V=1.0, theta=0.0
% INFO    : Bus 65844	: V=0.9665031, theta=0.680981 -> V=1.0, theta=0.0
% INFO    : Bus 65845	: V=0.9658532, theta=0.651849 -> V=1.0, theta=0.0
% INFO    : Bus 65846	: V=0.9613559, theta=-0.590948 -> V=1.0, theta=0.0
% INFO    : Bus 65847	: V=0.963517, theta=1.148147 -> V=1.0, theta=0.0
% INFO    : Bus 65848	: V=0.9762827, theta=3.660075 -> V=1.0, theta=0.0
% INFO    : Bus 65849	: V=0.9709476, theta=2.19638 -> V=1.0, theta=0.0
% INFO    : Bus 65850	: V=0.9582886, theta=0.314653 -> V=1.0, theta=0.0
% INFO    : Bus 65851	: V=0.968524, theta=-0.204627 -> V=1.0, theta=0.0
% INFO    : Bus 65852	: V=0.9769908, theta=0.43477 -> V=1.0, theta=0.0
% INFO    : Bus 65853	: V=0.9773575, theta=0.85158 -> V=1.0, theta=0.0
% INFO    : Bus 65854	: V=0.9700835, theta=0.413732 -> V=1.0, theta=0.0
% INFO    : Bus 65855	: V=0.966142, theta=0.504458 -> V=1.0, theta=0.0
% INFO    : Bus 65856	: V=0.9661242, theta=0.335657 -> V=1.0, theta=0.0
% INFO    : Bus 65857	: V=0.963167, theta=0.129996 -> V=1.0, theta=0.0
% INFO    : Bus 65858	: V=0.9619235, theta=-0.080586 -> V=1.0, theta=0.0
% INFO    : Bus 65859	: V=0.9626028, theta=0.2519 -> V=1.0, theta=0.0
% INFO    : Bus 65860	: V=0.9649608, theta=0.059627 -> V=1.0, theta=0.0
% INFO    : Bus 65861	: V=0.9637015, theta=-0.44208 -> V=1.0, theta=0.0
% INFO    : Bus 65862	: V=0.9648558, theta=-0.427588 -> V=1.0, theta=0.0
% INFO    : Bus 65863	: V=0.9635102, theta=-0.362136 -> V=1.0, theta=0.0
% INFO    : Bus 65864	: V=0.9576538, theta=-0.268344 -> V=1.0, theta=0.0
% INFO    : Bus 65865	: V=0.9700092, theta=2.722576 -> V=1.0, theta=0.0
% INFO    : Bus 65866	: V=0.9758925, theta=2.593306 -> V=1.0, theta=0.0
% INFO    : Bus 65867	: V=0.9735108, theta=2.963828 -> V=1.0, theta=0.0
% INFO    : Bus 65868	: V=0.9663123, theta=1.297077 -> V=1.0, theta=0.0
% INFO    : Bus 65869	: V=0.9701859, theta=1.506336 -> V=1.0, theta=0.0
% INFO    : Bus 65870	: V=0.9669362, theta=0.974581 -> V=1.0, theta=0.0
% INFO    : Bus 65871	: V=0.9651774, theta=0.618211 -> V=1.0, theta=0.0
% INFO    : Bus 65872	: V=1.0017367, theta=6.652708 -> V=1.0, theta=0.0
% INFO    : Bus 65873	: V=0.9987528, theta=6.365876 -> V=1.0, theta=0.0
% INFO    : Bus 65874	: V=0.9764566, theta=5.802739 -> V=1.0, theta=0.0
% INFO    : Bus 65875	: V=1.0196897, theta=8.211541 -> V=1.0, theta=0.0
% INFO    : Bus 65876	: V=1.0015677, theta=10.052519 -> V=1.0, theta=0.0
% INFO    : Bus 65877	: V=0.9967183, theta=2.392592 -> V=1.0, theta=0.0
% INFO    : Bus 65878	: V=1.0119448, theta=9.083617 -> V=1.0, theta=0.0
% INFO    : Bus 65879	: V=1.0085111, theta=5.870817 -> V=1.0, theta=0.0
% INFO    : Bus 65880	: V=1.0064024, theta=5.329616 -> V=1.0, theta=0.0
% INFO    : Bus 65881	: V=0.9993099, theta=4.735521 -> V=1.0, theta=0.0
% INFO    : Bus 65882	: V=0.9700549, theta=2.710211 -> V=1.0, theta=0.0
% INFO    : Bus 65883	: V=0.988679, theta=7.048558 -> V=1.0, theta=0.0
% INFO    : Bus 65884	: V=0.993922, theta=9.381434 -> V=1.0, theta=0.0
% INFO    : Bus 65885	: V=0.958963, theta=12.698156 -> V=1.0, theta=0.0
% INFO    : Bus 65886	: V=0.9789911, theta=4.010804 -> V=1.0, theta=0.0
% INFO    : Bus 65887	: V=0.9718786, theta=2.721642 -> V=1.0, theta=0.0
% INFO    : Bus 65888	: V=0.9765432, theta=0.630365 -> V=1.0, theta=0.0
% INFO    : Bus 65889	: V=0.9877611, theta=1.86732 -> V=1.0, theta=0.0
% INFO    : Bus 65890	: V=0.9933915, theta=1.507562 -> V=1.0, theta=0.0
% INFO    : Bus 65891	: V=1.0041042, theta=1.478467 -> V=1.0, theta=0.0
% INFO    : Bus 65892	: V=1.0124309, theta=10.017047 -> V=1.0, theta=0.0
% INFO    : Bus 65893	: V=0.9981203, theta=4.89218 -> V=1.0, theta=0.0
% INFO    : Bus 65894	: V=0.9931941, theta=4.367057 -> V=1.0, theta=0.0
% INFO    : Bus 65895	: V=1.0031081, theta=5.260889 -> V=1.0, theta=0.0
% INFO    : Bus 65896	: V=1.0028882, theta=5.223857 -> V=1.0, theta=0.0
% INFO    : Bus 65897	: V=0.9889647, theta=4.13868 -> V=1.0, theta=0.0
% INFO    : Bus 65898	: V=0.9841732, theta=3.906845 -> V=1.0, theta=0.0
% INFO    : Bus 65899	: V=1.0045921, theta=5.406151 -> V=1.0, theta=0.0
% INFO    : Bus 65900	: V=0.9985116, theta=4.90824 -> V=1.0, theta=0.0
% INFO    : Bus 65901	: V=1.0042212, theta=5.524859 -> V=1.0, theta=0.0
% INFO    : Bus 65902	: V=1.004464, theta=5.47371 -> V=1.0, theta=0.0
% INFO    : Bus 65903	: V=1.0048599, theta=5.446618 -> V=1.0, theta=0.0
% INFO    : Bus 65904	: V=1.0068472, theta=5.566661 -> V=1.0, theta=0.0
% INFO    : Bus 65905	: V=1.007981, theta=5.65203 -> V=1.0, theta=0.0
% INFO    : Bus 65906	: V=1.0057571, theta=5.262208 -> V=1.0, theta=0.0
% INFO    : Bus 65907	: V=1.0082479, theta=5.664047 -> V=1.0, theta=0.0
% INFO    : Bus 65908	: V=0.9968504, theta=5.083285 -> V=1.0, theta=0.0
% INFO    : Bus 65909	: V=0.9923942, theta=5.797933 -> V=1.0, theta=0.0
% INFO    : Bus 65910	: V=0.9931632, theta=5.085068 -> V=1.0, theta=0.0
% INFO    : Bus 65911	: V=1.0114181, theta=27.36946 -> V=1.0, theta=0.0
% INFO    : Bus 65912	: V=0.9687065, theta=19.882615 -> V=1.0, theta=0.0
% INFO    : Bus 65913	: V=0.9567818, theta=-5.98511 -> V=1.0, theta=0.0
% INFO    : Bus 65914	: V=0.9626858, theta=-2.09402 -> V=1.0, theta=0.0
% INFO    : Bus 65915	: V=0.9618075, theta=-0.299488 -> V=1.0, theta=0.0
% INFO    : Bus 65916	: V=0.9637225, theta=-0.216638 -> V=1.0, theta=0.0
% INFO    : Bus 65917	: V=0.9744512, theta=1.109253 -> V=1.0, theta=0.0
% INFO    : Bus 65918	: V=0.9700035, theta=0.627677 -> V=1.0, theta=0.0
% INFO    : Bus 65919	: V=0.967837, theta=0.415286 -> V=1.0, theta=0.0
% INFO    : Bus 65920	: V=0.9716953, theta=0.857919 -> V=1.0, theta=0.0
% INFO    : Bus 65921	: V=0.9708849, theta=0.837824 -> V=1.0, theta=0.0
% INFO    : Bus 65922	: V=0.9773626, theta=2.340317 -> V=1.0, theta=0.0
% INFO    : Bus 65923	: V=0.9730338, theta=1.048954 -> V=1.0, theta=0.0
% INFO    : Bus 65924	: V=0.9768908, theta=-0.61886 -> V=1.0, theta=0.0
% INFO    : Bus 65925	: V=0.9709436, theta=-1.334176 -> V=1.0, theta=0.0
% INFO    : Bus 65926	: V=0.9558211, theta=-3.010446 -> V=1.0, theta=0.0
% INFO    : Bus 65927	: V=0.9578776, theta=-2.792474 -> V=1.0, theta=0.0
% INFO    : Bus 65928	: V=0.9600658, theta=-0.607417 -> V=1.0, theta=0.0
% INFO    : Bus 65929	: V=0.9525949, theta=-2.465242 -> V=1.0, theta=0.0
% INFO    : Bus 65930	: V=0.9512939, theta=-2.522019 -> V=1.0, theta=0.0
% INFO    : Bus 65931	: V=0.9566193, theta=-2.285136 -> V=1.0, theta=0.0
% INFO    : Bus 65932	: V=0.9576859, theta=-0.574343 -> V=1.0, theta=0.0
% INFO    : Bus 65933	: V=0.9571881, theta=-0.648351 -> V=1.0, theta=0.0
% INFO    : Bus 65934	: V=0.9534114, theta=-2.366123 -> V=1.0, theta=0.0
% INFO    : Bus 65935	: V=0.9520917, theta=-2.429504 -> V=1.0, theta=0.0
% INFO    : Bus 65936	: V=0.9530289, theta=-2.382554 -> V=1.0, theta=0.0
% INFO    : Bus 65937	: V=0.9547092, theta=-2.009021 -> V=1.0, theta=0.0
% INFO    : Bus 65938	: V=0.955148, theta=-1.913293 -> V=1.0, theta=0.0
% INFO    : Bus 65939	: V=0.9541996, theta=-2.02078 -> V=1.0, theta=0.0
% INFO    : Bus 65940	: V=0.9541235, theta=-2.071907 -> V=1.0, theta=0.0
% INFO    : Bus 65941	: V=0.959636, theta=-0.147187 -> V=1.0, theta=0.0
% INFO    : Bus 65942	: V=0.9560729, theta=-1.754668 -> V=1.0, theta=0.0
% INFO    : Bus 65943	: V=0.9624125, theta=0.46422 -> V=1.0, theta=0.0
% INFO    : Bus 65944	: V=0.9619016, theta=0.342367 -> V=1.0, theta=0.0
% INFO    : Bus 65945	: V=0.9512228, theta=-1.553173 -> V=1.0, theta=0.0
% INFO    : Bus 65946	: V=0.9546415, theta=-1.154777 -> V=1.0, theta=0.0
% INFO    : Bus 65947	: V=0.9618253, theta=0.264673 -> V=1.0, theta=0.0
% INFO    : Bus 65948	: V=0.9593655, theta=-0.528626 -> V=1.0, theta=0.0
% INFO    : Bus 65949	: V=0.9608606, theta=0.077245 -> V=1.0, theta=0.0
% INFO    : Bus 65950	: V=0.9942056, theta=26.908217 -> V=1.0, theta=0.0
% INFO    : Bus 65951	: V=0.9943334, theta=27.038151 -> V=1.0, theta=0.0
% INFO    : Bus 65952	: V=0.9976201, theta=27.115964 -> V=1.0, theta=0.0
% INFO    : Bus 65953	: V=1.0107677, theta=27.710625 -> V=1.0, theta=0.0
% INFO    : Bus 65954	: V=1.0041323, theta=27.755207 -> V=1.0, theta=0.0
% INFO    : Bus 65955	: V=1.0088353, theta=27.396859 -> V=1.0, theta=0.0
% INFO    : Bus 65956	: V=0.9922017, theta=5.648069 -> V=1.0, theta=0.0
% INFO    : Bus 65957	: V=0.995862, theta=5.122804 -> V=1.0, theta=0.0
% INFO    : Bus 65958	: V=0.9904373, theta=5.021437 -> V=1.0, theta=0.0
% INFO    : Bus 65959	: V=1.0200004, theta=8.101072 -> V=1.0, theta=0.0
% INFO    : Bus 65960	: V=0.9959137, theta=4.911102 -> V=1.0, theta=0.0
% INFO    : Bus 65961	: V=0.9979339, theta=5.674856 -> V=1.0, theta=0.0
% INFO    : Bus 65962	: V=0.9947443, theta=4.798026 -> V=1.0, theta=0.0
% INFO    : Bus 65963	: V=0.9938224, theta=4.789159 -> V=1.0, theta=0.0
% INFO    : Bus 65964	: V=0.9981389, theta=5.865928 -> V=1.0, theta=0.0
% INFO    : Bus 65965	: V=0.9875563, theta=4.24849 -> V=1.0, theta=0.0
% INFO    : Bus 65966	: V=0.9905176, theta=4.518682 -> V=1.0, theta=0.0
% INFO    : Bus 65967	: V=0.9895177, theta=4.400091 -> V=1.0, theta=0.0
% INFO    : Bus 65968	: V=0.9922376, theta=4.669037 -> V=1.0, theta=0.0
% INFO    : Bus 65969	: V=0.9925629, theta=4.724883 -> V=1.0, theta=0.0
% INFO    : Bus 65970	: V=0.9917546, theta=4.592839 -> V=1.0, theta=0.0
% INFO    : Bus 65971	: V=0.9976557, theta=5.261064 -> V=1.0, theta=0.0
% INFO    : Bus 65972	: V=1.0004117, theta=5.561482 -> V=1.0, theta=0.0
% INFO    : Bus 65973	: V=0.9935333, theta=4.773824 -> V=1.0, theta=0.0
% INFO    : Bus 65974	: V=0.9931691, theta=4.994956 -> V=1.0, theta=0.0
% INFO    : Bus 65975	: V=0.99374, theta=5.346521 -> V=1.0, theta=0.0
% INFO    : Bus 65976	: V=0.9941936, theta=5.882399 -> V=1.0, theta=0.0
% INFO    : Bus 65977	: V=0.9924984, theta=4.83551 -> V=1.0, theta=0.0
% INFO    : Bus 65978	: V=0.9925324, theta=4.794043 -> V=1.0, theta=0.0
% INFO    : Bus 65979	: V=0.9953401, theta=5.998594 -> V=1.0, theta=0.0
% INFO    : Bus 65980	: V=0.9956877, theta=6.1058 -> V=1.0, theta=0.0
% INFO    : Bus 65981	: V=0.9952337, theta=5.885637 -> V=1.0, theta=0.0
% INFO    : Bus 65982	: V=0.9934072, theta=5.453369 -> V=1.0, theta=0.0
% INFO    : Bus 65983	: V=0.9940932, theta=5.34577 -> V=1.0, theta=0.0
% INFO    : Bus 65984	: V=0.9931535, theta=5.945893 -> V=1.0, theta=0.0
% INFO    : Bus 65985	: V=0.9962053, theta=6.254357 -> V=1.0, theta=0.0
% INFO    : Bus 65986	: V=0.9957062, theta=5.744493 -> V=1.0, theta=0.0
% INFO    : Bus 65987	: V=0.9971697, theta=6.468281 -> V=1.0, theta=0.0
% INFO    : Bus 65988	: V=1.0000038, theta=6.982703 -> V=1.0, theta=0.0
% INFO    : Bus 65989	: V=0.9965573, theta=5.920651 -> V=1.0, theta=0.0
% INFO    : Bus 65990	: V=0.9962693, theta=6.621626 -> V=1.0, theta=0.0
% INFO    : Bus 65991	: V=0.9993213, theta=7.18063 -> V=1.0, theta=0.0
% INFO    : Bus 65992	: V=1.0047479, theta=7.854322 -> V=1.0, theta=0.0
% INFO    : Bus 65993	: V=1.004489, theta=8.4743 -> V=1.0, theta=0.0
% INFO    : Bus 65994	: V=1.0061801, theta=8.222641 -> V=1.0, theta=0.0
% INFO    : Bus 65995	: V=1.0003302, theta=8.530162 -> V=1.0, theta=0.0
% INFO    : Bus 65996	: V=1.0132822, theta=9.836993 -> V=1.0, theta=0.0
% INFO    : Bus 65997	: V=1.0096912, theta=9.030587 -> V=1.0, theta=0.0
% INFO    : Bus 65998	: V=1.0126686, theta=9.536863 -> V=1.0, theta=0.0
% INFO    : Bus 65999	: V=1.0057255, theta=8.500079 -> V=1.0, theta=0.0
% INFO    : Bus 66000	: V=1.0074762, theta=8.535548 -> V=1.0, theta=0.0
% INFO    : Bus 66001	: V=1.0083379, theta=8.718233 -> V=1.0, theta=0.0
% INFO    : Bus 66002	: V=1.0048623, theta=8.429788 -> V=1.0, theta=0.0
% INFO    : Bus 66003	: V=1.0063301, theta=8.599538 -> V=1.0, theta=0.0
% INFO    : Bus 66004	: V=1.0094706, theta=8.953842 -> V=1.0, theta=0.0
% INFO    : Bus 66005	: V=1.0108238, theta=9.205343 -> V=1.0, theta=0.0
% INFO    : Bus 66006	: V=1.0300004, theta=13.336681 -> V=1.0, theta=0.0
% INFO    : Bus 66007	: V=1.0116195, theta=9.614722 -> V=1.0, theta=0.0
% INFO    : Bus 66008	: V=1.011244, theta=9.15924 -> V=1.0, theta=0.0
% INFO    : Bus 66009	: V=0.996654, theta=6.372494 -> V=1.0, theta=0.0
% INFO    : Bus 66010	: V=0.9964129, theta=25.068785 -> V=1.0, theta=0.0
% INFO    : Bus 66011	: V=0.9715609, theta=24.727145 -> V=1.0, theta=0.0
% INFO    : Bus 66012	: V=0.9941301, theta=27.656985 -> V=1.0, theta=0.0
% INFO    : Bus 66013	: V=1.0106083, theta=30.472535 -> V=1.0, theta=0.0
% INFO    : Bus 66014	: V=1.0152533, theta=33.326581 -> V=1.0, theta=0.0
% INFO    : Bus 66015	: V=1.025894, theta=36.623294 -> V=1.0, theta=0.0
% INFO    : Bus 66016	: V=1.0200003, theta=30.020141 -> V=1.0, theta=0.0
% INFO    : Bus 66017	: V=1.0165577, theta=38.361607 -> V=1.0, theta=0.0
% INFO    : Bus 66018	: V=1.0373024, theta=37.839191 -> V=1.0, theta=0.0
% INFO    : Bus 66019	: V=0.9780577, theta=31.651018 -> V=1.0, theta=0.0
% INFO    : Bus 66020	: V=0.9982775, theta=22.79823 -> V=1.0, theta=0.0
% INFO    : Bus 66021	: V=1.006436, theta=21.779435 -> V=1.0, theta=0.0
% INFO    : Bus 66022	: V=1.0020116, theta=-1.189 -> V=1.0, theta=0.0
% INFO    : Bus 66023	: V=0.9814284, theta=16.887825 -> V=1.0, theta=0.0
% INFO    : Bus 66024	: V=0.9855838, theta=18.554671 -> V=1.0, theta=0.0
% INFO    : Bus 66025	: V=0.9780618, theta=15.843518 -> V=1.0, theta=0.0
% INFO    : Bus 66026	: V=0.9830033, theta=17.328947 -> V=1.0, theta=0.0
% INFO    : Bus 66027	: V=0.9731248, theta=14.17896 -> V=1.0, theta=0.0
% INFO    : Bus 66028	: V=1.0181116, theta=22.609987 -> V=1.0, theta=0.0
% INFO    : Bus 66029	: V=1.0100003, theta=21.791331 -> V=1.0, theta=0.0
% INFO    : Bus 66030	: V=1.0089409, theta=41.75069 -> V=1.0, theta=0.0
% INFO    : Bus 66031	: V=0.9509964, theta=22.91925 -> V=1.0, theta=0.0
% INFO    : Bus 66032	: V=1.0214233, theta=22.594577 -> V=1.0, theta=0.0
% INFO    : Bus 66033	: V=1.0117822, theta=25.963799 -> V=1.0, theta=0.0
% INFO    : Bus 66034	: V=1.0149707, theta=24.337458 -> V=1.0, theta=0.0
% INFO    : Bus 66035	: V=0.9755735, theta=6.466796 -> V=1.0, theta=0.0
% INFO    : Bus 66036	: V=0.9924612, theta=9.062641 -> V=1.0, theta=0.0
% INFO    : Bus 66037	: V=1.0054394, theta=31.614586 -> V=1.0, theta=0.0
% INFO    : Bus 66038	: V=0.954926, theta=2.467244 -> V=1.0, theta=0.0
% INFO    : Bus 66039	: V=1.0095184, theta=9.577147 -> V=1.0, theta=0.0
% INFO    : Bus 66040	: V=1.0126647, theta=9.789746 -> V=1.0, theta=0.0
% INFO    : Bus 66041	: V=1.0082968, theta=9.157245 -> V=1.0, theta=0.0
% INFO    : Bus 66042	: V=1.0067478, theta=9.107797 -> V=1.0, theta=0.0
% INFO    : Bus 66043	: V=1.0071464, theta=9.115465 -> V=1.0, theta=0.0
% INFO    : Bus 66044	: V=1.0101257, theta=9.693587 -> V=1.0, theta=0.0
% INFO    : Bus 66045	: V=1.0200004, theta=11.177169 -> V=1.0, theta=0.0
% INFO    : Bus 66046	: V=1.0084063, theta=9.52203 -> V=1.0, theta=0.0
% INFO    : Bus 66047	: V=1.0077955, theta=9.494464 -> V=1.0, theta=0.0
% INFO    : Bus 66048	: V=1.0032701, theta=8.999588 -> V=1.0, theta=0.0
% INFO    : Bus 66049	: V=1.0029266, theta=8.99274 -> V=1.0, theta=0.0
% INFO    : Bus 66050	: V=1.0022743, theta=8.932093 -> V=1.0, theta=0.0
% INFO    : Bus 66051	: V=1.0022362, theta=8.973759 -> V=1.0, theta=0.0
% INFO    : Bus 66052	: V=0.9931238, theta=8.435953 -> V=1.0, theta=0.0
% INFO    : Bus 66053	: V=0.9980393, theta=8.754763 -> V=1.0, theta=0.0
% INFO    : Bus 66054	: V=0.998709, theta=8.780882 -> V=1.0, theta=0.0
% INFO    : Bus 66055	: V=0.9998789, theta=8.809761 -> V=1.0, theta=0.0
% INFO    : Bus 66056	: V=0.9992468, theta=8.820516 -> V=1.0, theta=0.0
% INFO    : Bus 66057	: V=1.0003613, theta=8.825676 -> V=1.0, theta=0.0
% INFO    : Bus 66058	: V=1.0000626, theta=8.85524 -> V=1.0, theta=0.0
% INFO    : Bus 66059	: V=1.0010548, theta=8.858533 -> V=1.0, theta=0.0
% INFO    : Bus 66060	: V=1.0010281, theta=8.907009 -> V=1.0, theta=0.0
% INFO    : Bus 66061	: V=1.0079595, theta=9.523604 -> V=1.0, theta=0.0
% INFO    : Bus 66062	: V=1.0091925, theta=9.650454 -> V=1.0, theta=0.0
% INFO    : Bus 66063	: V=1.0089354, theta=9.669552 -> V=1.0, theta=0.0
% INFO    : Bus 66064	: V=1.0098443, theta=9.724193 -> V=1.0, theta=0.0
% INFO    : Bus 66065	: V=1.0200004, theta=11.307236 -> V=1.0, theta=0.0
% INFO    : Bus 66066	: V=1.0069251, theta=9.564318 -> V=1.0, theta=0.0
% INFO    : Bus 66067	: V=1.0048598, theta=9.434944 -> V=1.0, theta=0.0
% INFO    : Bus 66068	: V=1.0011973, theta=8.925854 -> V=1.0, theta=0.0
% INFO    : Bus 66069	: V=0.9991197, theta=8.883546 -> V=1.0, theta=0.0
% INFO    : Bus 66070	: V=0.9998641, theta=8.908535 -> V=1.0, theta=0.0
% INFO    : Bus 66071	: V=0.9964311, theta=8.837932 -> V=1.0, theta=0.0
% INFO    : Bus 66072	: V=0.9970847, theta=8.822199 -> V=1.0, theta=0.0
% INFO    : Bus 66073	: V=0.9975417, theta=8.79426 -> V=1.0, theta=0.0
% INFO    : Bus 66074	: V=0.9955523, theta=8.724912 -> V=1.0, theta=0.0
% INFO    : Bus 66075	: V=0.9959479, theta=8.817859 -> V=1.0, theta=0.0
% INFO    : Bus 66076	: V=0.9950947, theta=8.826052 -> V=1.0, theta=0.0
% INFO    : Bus 66077	: V=0.9924769, theta=8.65478 -> V=1.0, theta=0.0
% INFO    : Bus 66078	: V=0.9929704, theta=8.672142 -> V=1.0, theta=0.0
% INFO    : Bus 66079	: V=0.9941448, theta=8.689011 -> V=1.0, theta=0.0
% INFO    : Bus 66080	: V=0.9916401, theta=8.573322 -> V=1.0, theta=0.0
% INFO    : Bus 66081	: V=0.9918246, theta=8.705557 -> V=1.0, theta=0.0
% INFO    : Bus 66082	: V=0.9914934, theta=8.738957 -> V=1.0, theta=0.0
% INFO    : Bus 66083	: V=0.9937885, theta=8.87254 -> V=1.0, theta=0.0
% INFO    : Bus 66084	: V=0.9913818, theta=9.706973 -> V=1.0, theta=0.0
% INFO    : Bus 66085	: V=0.995458, theta=8.915708 -> V=1.0, theta=0.0
% INFO    : Bus 66086	: V=0.9815526, theta=11.561591 -> V=1.0, theta=0.0
% INFO    : Bus 66087	: V=0.9846201, theta=8.999794 -> V=1.0, theta=0.0
% INFO    : Bus 66088	: V=0.9759903, theta=11.381044 -> V=1.0, theta=0.0
% INFO    : Bus 66089	: V=0.9910221, theta=8.810745 -> V=1.0, theta=0.0
% INFO    : Bus 66090	: V=0.9921984, theta=8.921826 -> V=1.0, theta=0.0
% INFO    : Bus 66091	: V=0.9922266, theta=8.989764 -> V=1.0, theta=0.0
% INFO    : Bus 66092	: V=0.9906423, theta=9.874288 -> V=1.0, theta=0.0
% INFO    : Bus 66093	: V=0.9910702, theta=8.910035 -> V=1.0, theta=0.0
% INFO    : Bus 66094	: V=0.9910067, theta=9.032943 -> V=1.0, theta=0.0
% INFO    : Bus 66095	: V=0.9920441, theta=9.054225 -> V=1.0, theta=0.0
% INFO    : Bus 66096	: V=0.990682, theta=9.945703 -> V=1.0, theta=0.0
% INFO    : Bus 66097	: V=0.9908064, theta=10.045635 -> V=1.0, theta=0.0
% INFO    : Bus 66098	: V=0.9910504, theta=10.178824 -> V=1.0, theta=0.0
% INFO    : Bus 66099	: V=0.9913587, theta=10.232845 -> V=1.0, theta=0.0
% INFO    : Bus 66100	: V=0.9913224, theta=10.523259 -> V=1.0, theta=0.0
% INFO    : Bus 66101	: V=0.9889478, theta=9.080058 -> V=1.0, theta=0.0
% INFO    : Bus 66102	: V=0.9918681, theta=9.357846 -> V=1.0, theta=0.0
% INFO    : Bus 66103	: V=0.9921887, theta=10.175042 -> V=1.0, theta=0.0
% INFO    : Bus 66104	: V=0.9923264, theta=10.197953 -> V=1.0, theta=0.0
% INFO    : Bus 66105	: V=0.9897497, theta=9.633791 -> V=1.0, theta=0.0
% INFO    : Bus 66106	: V=0.9913922, theta=10.656464 -> V=1.0, theta=0.0
% INFO    : Bus 66107	: V=0.9916686, theta=10.831369 -> V=1.0, theta=0.0
% INFO    : Bus 66108	: V=0.9913567, theta=10.63167 -> V=1.0, theta=0.0
% INFO    : Bus 66109	: V=0.9914456, theta=10.728803 -> V=1.0, theta=0.0
% INFO    : Bus 66110	: V=0.9951995, theta=8.961161 -> V=1.0, theta=0.0
% INFO    : Bus 66111	: V=1.0007985, theta=9.320296 -> V=1.0, theta=0.0
% INFO    : Bus 66112	: V=0.9976349, theta=9.476796 -> V=1.0, theta=0.0
% INFO    : Bus 66113	: V=0.9936987, theta=9.14204 -> V=1.0, theta=0.0
% INFO    : Bus 66114	: V=0.9931715, theta=9.107274 -> V=1.0, theta=0.0
% INFO    : Bus 66115	: V=0.9922272, theta=9.660598 -> V=1.0, theta=0.0
% INFO    : Bus 66116	: V=0.9924133, theta=8.909894 -> V=1.0, theta=0.0
% INFO    : Bus 66117	: V=0.9924729, theta=9.046578 -> V=1.0, theta=0.0
% INFO    : Bus 66118	: V=0.9937505, theta=9.69909 -> V=1.0, theta=0.0
% INFO    : Bus 66119	: V=0.9917661, theta=9.254046 -> V=1.0, theta=0.0
% INFO    : Bus 66120	: V=0.9937544, theta=9.238763 -> V=1.0, theta=0.0
% INFO    : Bus 66121	: V=0.9951532, theta=9.73746 -> V=1.0, theta=0.0
% INFO    : Bus 66122	: V=0.9906227, theta=9.147971 -> V=1.0, theta=0.0
% INFO    : Bus 66123	: V=0.994648, theta=9.808843 -> V=1.0, theta=0.0
% INFO    : Bus 66124	: V=0.9917274, theta=9.160682 -> V=1.0, theta=0.0
% INFO    : Bus 66125	: V=0.9937528, theta=9.991239 -> V=1.0, theta=0.0
% INFO    : Bus 66126	: V=0.9901263, theta=9.126504 -> V=1.0, theta=0.0
% INFO    : Bus 66127	: V=0.9934935, theta=10.125513 -> V=1.0, theta=0.0
% INFO    : Bus 66128	: V=0.990166, theta=9.737306 -> V=1.0, theta=0.0
% INFO    : Bus 66129	: V=0.995595, theta=10.302636 -> V=1.0, theta=0.0
% INFO    : Bus 66130	: V=0.9945074, theta=10.255647 -> V=1.0, theta=0.0
% INFO    : Bus 66131	: V=0.9939034, theta=10.212439 -> V=1.0, theta=0.0
% INFO    : Bus 66132	: V=0.9892974, theta=9.652062 -> V=1.0, theta=0.0
% INFO    : Bus 66133	: V=0.9941134, theta=10.271095 -> V=1.0, theta=0.0
% INFO    : Bus 66134	: V=0.9882618, theta=10.051754 -> V=1.0, theta=0.0
% INFO    : Bus 66135	: V=0.9889645, theta=9.818661 -> V=1.0, theta=0.0
% INFO    : Bus 66136	: V=0.9892808, theta=9.933716 -> V=1.0, theta=0.0
% INFO    : Bus 66137	: V=0.992, theta=10.996488 -> V=1.0, theta=0.0
% INFO    : Bus 66138	: V=0.9933736, theta=10.341488 -> V=1.0, theta=0.0
% INFO    : Bus 66139	: V=0.9898341, theta=9.74148 -> V=1.0, theta=0.0
% INFO    : Bus 66140	: V=0.9933654, theta=10.687725 -> V=1.0, theta=0.0
% INFO    : Bus 66141	: V=0.9933353, theta=10.97835 -> V=1.0, theta=0.0
% INFO    : Bus 66142	: V=0.991604, theta=10.81267 -> V=1.0, theta=0.0
% INFO    : Bus 66143	: V=0.9913996, theta=10.101765 -> V=1.0, theta=0.0
% INFO    : Bus 66144	: V=0.992374, theta=11.117412 -> V=1.0, theta=0.0
% INFO    : Bus 66145	: V=0.9927691, theta=11.233107 -> V=1.0, theta=0.0
% INFO    : Bus 66146	: V=0.992619, theta=10.244934 -> V=1.0, theta=0.0
% INFO    : Bus 66147	: V=0.9902223, theta=9.926383 -> V=1.0, theta=0.0
% INFO    : Bus 66148	: V=0.9933347, theta=10.501758 -> V=1.0, theta=0.0
% INFO    : Bus 66149	: V=0.9919602, theta=11.546454 -> V=1.0, theta=0.0
% INFO    : Bus 66150	: V=0.9924073, theta=11.761418 -> V=1.0, theta=0.0
% INFO    : Bus 66151	: V=0.9905913, theta=11.383074 -> V=1.0, theta=0.0
% INFO    : Bus 66152	: V=0.987886, theta=10.245882 -> V=1.0, theta=0.0
% INFO    : Bus 66153	: V=0.9892021, theta=10.601504 -> V=1.0, theta=0.0
% INFO    : Bus 66154	: V=0.9933927, theta=11.390648 -> V=1.0, theta=0.0
% INFO    : Bus 66155	: V=0.9930366, theta=12.088665 -> V=1.0, theta=0.0
% INFO    : Bus 66156	: V=0.9931922, theta=12.017936 -> V=1.0, theta=0.0
% INFO    : Bus 66157	: V=0.9898223, theta=10.865912 -> V=1.0, theta=0.0
% INFO    : Bus 66158	: V=0.9911364, theta=11.519533 -> V=1.0, theta=0.0
% INFO    : Bus 66159	: V=0.9931867, theta=12.007666 -> V=1.0, theta=0.0
% INFO    : Bus 66160	: V=0.9940958, theta=12.283074 -> V=1.0, theta=0.0
% INFO    : Bus 66161	: V=0.9913264, theta=12.049786 -> V=1.0, theta=0.0
% INFO    : Bus 66162	: V=0.9870353, theta=10.374158 -> V=1.0, theta=0.0
% INFO    : Bus 66163	: V=0.9907994, theta=10.860695 -> V=1.0, theta=0.0
% INFO    : Bus 66164	: V=0.9983413, theta=10.119993 -> V=1.0, theta=0.0
% INFO    : Bus 66165	: V=0.9982604, theta=9.707178 -> V=1.0, theta=0.0
% INFO    : Bus 66166	: V=0.9987276, theta=10.183314 -> V=1.0, theta=0.0
% INFO    : Bus 66167	: V=0.9984387, theta=10.219618 -> V=1.0, theta=0.0
% INFO    : Bus 66168	: V=0.9987345, theta=10.291769 -> V=1.0, theta=0.0
% INFO    : Bus 66169	: V=0.99876, theta=10.129622 -> V=1.0, theta=0.0
% INFO    : Bus 66170	: V=0.9986986, theta=10.327282 -> V=1.0, theta=0.0
% INFO    : Bus 66171	: V=0.9936269, theta=9.954143 -> V=1.0, theta=0.0
% INFO    : Bus 66172	: V=0.9971683, theta=10.369851 -> V=1.0, theta=0.0
% INFO    : Bus 66173	: V=0.9939279, theta=9.961702 -> V=1.0, theta=0.0
% INFO    : Bus 66174	: V=1.0122262, theta=13.394292 -> V=1.0, theta=0.0
% INFO    : Bus 66175	: V=0.9975046, theta=10.338236 -> V=1.0, theta=0.0
% INFO    : Bus 66176	: V=0.9947388, theta=9.960869 -> V=1.0, theta=0.0
% INFO    : Bus 66177	: V=0.9916626, theta=10.000474 -> V=1.0, theta=0.0
% INFO    : Bus 66178	: V=0.9885049, theta=10.364216 -> V=1.0, theta=0.0
% INFO    : Bus 66179	: V=0.9894011, theta=10.121031 -> V=1.0, theta=0.0
% INFO    : Bus 66180	: V=0.994175, theta=10.568945 -> V=1.0, theta=0.0
% INFO    : Bus 66181	: V=0.9886436, theta=11.06084 -> V=1.0, theta=0.0
% INFO    : Bus 66182	: V=0.9938312, theta=10.688718 -> V=1.0, theta=0.0
% INFO    : Bus 66183	: V=0.9892917, theta=11.031722 -> V=1.0, theta=0.0
% INFO    : Bus 66184	: V=0.9870389, theta=10.304013 -> V=1.0, theta=0.0
% INFO    : Bus 66185	: V=0.9949431, theta=10.406426 -> V=1.0, theta=0.0
% INFO    : Bus 66186	: V=0.9984223, theta=10.340563 -> V=1.0, theta=0.0
% INFO    : Bus 66187	: V=0.9956946, theta=9.976209 -> V=1.0, theta=0.0
% INFO    : Bus 66188	: V=1.0011854, theta=10.491876 -> V=1.0, theta=0.0
% INFO    : Bus 66189	: V=0.9933314, theta=10.885702 -> V=1.0, theta=0.0
% INFO    : Bus 66190	: V=0.9978641, theta=10.287908 -> V=1.0, theta=0.0
% INFO    : Bus 66191	: V=1.0051737, theta=9.476451 -> V=1.0, theta=0.0
% INFO    : Bus 66192	: V=0.9972159, theta=9.21354 -> V=1.0, theta=0.0
% INFO    : Bus 66193	: V=1.0041559, theta=9.472656 -> V=1.0, theta=0.0
% INFO    : Bus 66194	: V=1.0039743, theta=9.584142 -> V=1.0, theta=0.0
% INFO    : Bus 66195	: V=1.0042901, theta=9.700198 -> V=1.0, theta=0.0
% INFO    : Bus 66196	: V=0.9988902, theta=9.214996 -> V=1.0, theta=0.0
% INFO    : Bus 66197	: V=1.0046736, theta=9.754029 -> V=1.0, theta=0.0
% INFO    : Bus 66198	: V=1.0010491, theta=9.587672 -> V=1.0, theta=0.0
% INFO    : Bus 66199	: V=1.0069853, theta=10.18368 -> V=1.0, theta=0.0
% INFO    : Bus 66200	: V=1.0065741, theta=10.143632 -> V=1.0, theta=0.0
% INFO    : Bus 66201	: V=1.0050187, theta=9.900814 -> V=1.0, theta=0.0
% INFO    : Bus 66202	: V=1.0046108, theta=9.795562 -> V=1.0, theta=0.0
% INFO    : Bus 66203	: V=1.003933, theta=9.829226 -> V=1.0, theta=0.0
% INFO    : Bus 66204	: V=1.0062752, theta=10.10948 -> V=1.0, theta=0.0
% INFO    : Bus 66205	: V=1.0051598, theta=10.044517 -> V=1.0, theta=0.0
% INFO    : Bus 66206	: V=0.9962272, theta=9.183084 -> V=1.0, theta=0.0
% INFO    : Bus 66207	: V=1.0000414, theta=9.741671 -> V=1.0, theta=0.0
% INFO    : Bus 66208	: V=0.9993592, theta=9.667687 -> V=1.0, theta=0.0
% INFO    : Bus 66209	: V=0.9986711, theta=9.593759 -> V=1.0, theta=0.0
% INFO    : Bus 66210	: V=0.9967158, theta=9.353683 -> V=1.0, theta=0.0
% INFO    : Bus 66211	: V=0.9932143, theta=9.1369 -> V=1.0, theta=0.0
% INFO    : Bus 66212	: V=0.9939967, theta=9.207305 -> V=1.0, theta=0.0
% INFO    : Bus 66213	: V=1.0009353, theta=9.839484 -> V=1.0, theta=0.0
% INFO    : Bus 66214	: V=0.999766, theta=9.537491 -> V=1.0, theta=0.0
% INFO    : Bus 66215	: V=0.9983993, theta=9.983333 -> V=1.0, theta=0.0
% INFO    : Bus 66216	: V=0.9984409, theta=10.046967 -> V=1.0, theta=0.0
% INFO    : Bus 66217	: V=1.0200004, theta=11.458398 -> V=1.0, theta=0.0
% INFO    : Bus 66218	: V=1.0033452, theta=9.879779 -> V=1.0, theta=0.0
% INFO    : Bus 66219	: V=1.000274, theta=9.617033 -> V=1.0, theta=0.0
% INFO    : Bus 66220	: V=0.9996351, theta=9.589358 -> V=1.0, theta=0.0
% INFO    : Bus 66221	: V=0.9985582, theta=10.016034 -> V=1.0, theta=0.0
% INFO    : Bus 66222	: V=0.9990121, theta=10.012735 -> V=1.0, theta=0.0
% INFO    : Bus 66223	: V=0.999634, theta=9.598275 -> V=1.0, theta=0.0
% INFO    : Bus 66224	: V=0.9991476, theta=9.621702 -> V=1.0, theta=0.0
% INFO    : Bus 66225	: V=1.0034425, theta=9.958894 -> V=1.0, theta=0.0
% INFO    : Bus 66226	: V=1.0023428, theta=9.905551 -> V=1.0, theta=0.0
% INFO    : Bus 66227	: V=1.0071633, theta=10.243724 -> V=1.0, theta=0.0
% INFO    : Bus 66228	: V=1.0077138, theta=10.325456 -> V=1.0, theta=0.0
% INFO    : Bus 66229	: V=1.0014019, theta=9.736536 -> V=1.0, theta=0.0
% INFO    : Bus 66230	: V=0.9996378, theta=9.596286 -> V=1.0, theta=0.0
% INFO    : Bus 66231	: V=0.9994279, theta=9.59056 -> V=1.0, theta=0.0
% INFO    : Bus 66232	: V=1.003766, theta=9.79393 -> V=1.0, theta=0.0
% INFO    : Bus 66233	: V=1.0083638, theta=10.416829 -> V=1.0, theta=0.0
% INFO    : Bus 66234	: V=1.0009822, theta=9.630719 -> V=1.0, theta=0.0
% INFO    : Bus 66235	: V=1.0019235, theta=9.569485 -> V=1.0, theta=0.0
% INFO    : Bus 66236	: V=1.0025916, theta=9.5928 -> V=1.0, theta=0.0
% INFO    : Bus 66237	: V=1.0076191, theta=10.251058 -> V=1.0, theta=0.0
% INFO    : Bus 66238	: V=1.003774, theta=9.25319 -> V=1.0, theta=0.0
% INFO    : Bus 66239	: V=1.0100004, theta=10.964776 -> V=1.0, theta=0.0
% INFO    : Bus 66240	: V=1.0068587, theta=9.435356 -> V=1.0, theta=0.0
% INFO    : Bus 66241	: V=0.9943505, theta=8.844103 -> V=1.0, theta=0.0
% INFO    : Bus 66242	: V=0.9967763, theta=10.357048 -> V=1.0, theta=0.0
% INFO    : Bus 66243	: V=0.9973932, theta=10.243392 -> V=1.0, theta=0.0
% INFO    : Bus 66244	: V=1.0200004, theta=11.427889 -> V=1.0, theta=0.0
% INFO    : Bus 66245	: V=0.9898757, theta=11.089059 -> V=1.0, theta=0.0
% INFO    : Bus 66246	: V=1.0114239, theta=9.642853 -> V=1.0, theta=0.0
% INFO    : Bus 66247	: V=1.0070798, theta=9.170773 -> V=1.0, theta=0.0
% INFO    : Bus 66248	: V=0.9936553, theta=11.344766 -> V=1.0, theta=0.0
% INFO    : Bus 66249	: V=0.9962885, theta=10.242962 -> V=1.0, theta=0.0
% INFO    : Bus 66250	: V=1.0064808, theta=9.194994 -> V=1.0, theta=0.0
% INFO    : Bus 66251	: V=0.9736492, theta=34.06537 -> V=1.0, theta=0.0
% INFO    : Bus 66252	: V=0.9841604, theta=40.139504 -> V=1.0, theta=0.0
% INFO    : Bus 66253	: V=1.0031459, theta=36.257053 -> V=1.0, theta=0.0
% INFO    : Bus 66254	: V=1.0100002, theta=40.82737 -> V=1.0, theta=0.0
% INFO    : Bus 66255	: V=1.0031218, theta=28.287974 -> V=1.0, theta=0.0
% INFO    : Bus 66256	: V=1.0131131, theta=25.324056 -> V=1.0, theta=0.0
% INFO    : Bus 66257	: V=1.0028568, theta=26.139737 -> V=1.0, theta=0.0
% INFO    : Bus 66258	: V=1.0156668, theta=27.773194 -> V=1.0, theta=0.0
% INFO    : Bus 66259	: V=1.0200003, theta=29.9942 -> V=1.0, theta=0.0
% INFO    : Bus 66260	: V=1.0152473, theta=28.541018 -> V=1.0, theta=0.0
% INFO    : Bus 66261	: V=1.0120534, theta=28.050059 -> V=1.0, theta=0.0
% INFO    : Bus 66262	: V=1.0022114, theta=27.099558 -> V=1.0, theta=0.0
% INFO    : Bus 66263	: V=1.0093721, theta=27.896121 -> V=1.0, theta=0.0
% INFO    : Bus 66264	: V=1.0076941, theta=28.884718 -> V=1.0, theta=0.0
% INFO    : Bus 66265	: V=0.9712348, theta=8.73387 -> V=1.0, theta=0.0
% INFO    : Bus 66266	: V=0.9699629, theta=10.504708 -> V=1.0, theta=0.0
% INFO    : Bus 66267	: V=0.9741289, theta=11.551383 -> V=1.0, theta=0.0
% INFO    : Bus 66268	: V=0.9737511, theta=11.178501 -> V=1.0, theta=0.0
% INFO    : Bus 66269	: V=0.9767856, theta=16.85443 -> V=1.0, theta=0.0
% INFO    : Bus 66270	: V=0.9846044, theta=10.568119 -> V=1.0, theta=0.0
% INFO    : Bus 66271	: V=0.9838887, theta=10.813047 -> V=1.0, theta=0.0
% INFO    : Bus 66272	: V=0.9836162, theta=11.151567 -> V=1.0, theta=0.0
% INFO    : Bus 66273	: V=0.97914, theta=11.017512 -> V=1.0, theta=0.0
% INFO    : Bus 66274	: V=0.9833899, theta=11.505594 -> V=1.0, theta=0.0
% INFO    : Bus 66275	: V=0.9764865, theta=11.305728 -> V=1.0, theta=0.0
% INFO    : Bus 66276	: V=0.9846678, theta=12.434388 -> V=1.0, theta=0.0
% INFO    : Bus 66277	: V=0.983312, theta=12.064486 -> V=1.0, theta=0.0
% INFO    : Bus 66278	: V=1.0300003, theta=13.534931 -> V=1.0, theta=0.0
% INFO    : Bus 66279	: V=1.0100004, theta=11.285873 -> V=1.0, theta=0.0
% INFO    : Bus 66280	: V=1.0126648, theta=11.217719 -> V=1.0, theta=0.0
% INFO    : Bus 66281	: V=1.0200003, theta=12.290079 -> V=1.0, theta=0.0
% INFO    : Bus 66282	: V=1.0200004, theta=12.165861 -> V=1.0, theta=0.0
% INFO    : Bus 66283	: V=1.0059186, theta=10.06136 -> V=1.0, theta=0.0
% INFO    : Bus 66284	: V=1.0200004, theta=12.052032 -> V=1.0, theta=0.0
% INFO    : Bus 66285	: V=1.0116148, theta=11.132479 -> V=1.0, theta=0.0
% INFO    : Bus 66286	: V=1.0041152, theta=9.82993 -> V=1.0, theta=0.0
% INFO    : Bus 66287	: V=1.0057849, theta=9.946697 -> V=1.0, theta=0.0
% INFO    : Bus 66288	: V=1.0135683, theta=11.066006 -> V=1.0, theta=0.0
% INFO    : Bus 66289	: V=1.0083196, theta=32.779926 -> V=1.0, theta=0.0
% INFO    : Bus 66290	: V=0.9915648, theta=31.163624 -> V=1.0, theta=0.0
% INFO    : Bus 66291	: V=0.9724043, theta=26.103392 -> V=1.0, theta=0.0
% INFO    : Bus 66292	: V=0.9949889, theta=28.657991 -> V=1.0, theta=0.0
% INFO    : Bus 66293	: V=0.9862928, theta=29.900855 -> V=1.0, theta=0.0
% INFO    : Bus 66294	: V=0.9855548, theta=29.949269 -> V=1.0, theta=0.0
% INFO    : Bus 66295	: V=0.9994902, theta=13.706353 -> V=1.0, theta=0.0
% INFO    : Bus 66296	: V=0.9982921, theta=13.029278 -> V=1.0, theta=0.0
% INFO    : Bus 66297	: V=0.9997279, theta=13.735685 -> V=1.0, theta=0.0
% INFO    : Bus 66298	: V=1.0000217, theta=13.769973 -> V=1.0, theta=0.0
% INFO    : Bus 66299	: V=1.0012279, theta=14.138063 -> V=1.0, theta=0.0
% INFO    : Bus 66300	: V=1.0018163, theta=14.096858 -> V=1.0, theta=0.0
% INFO    : Bus 66301	: V=0.9994135, theta=13.651609 -> V=1.0, theta=0.0
% INFO    : Bus 66302	: V=0.9999817, theta=13.47932 -> V=1.0, theta=0.0
% INFO    : Bus 66303	: V=1.0003358, theta=13.703881 -> V=1.0, theta=0.0
% INFO    : Bus 66304	: V=1.002598, theta=14.942954 -> V=1.0, theta=0.0
% INFO    : Bus 66305	: V=1.0030518, theta=15.378245 -> V=1.0, theta=0.0
% INFO    : Bus 66306	: V=1.0026593, theta=15.205741 -> V=1.0, theta=0.0
% INFO    : Bus 66307	: V=1.0034543, theta=15.497729 -> V=1.0, theta=0.0
% INFO    : Bus 66308	: V=1.0025401, theta=14.545283 -> V=1.0, theta=0.0
% INFO    : Bus 66309	: V=1.0023702, theta=14.427652 -> V=1.0, theta=0.0
% INFO    : Bus 66310	: V=1.0100004, theta=16.443427 -> V=1.0, theta=0.0
% INFO    : Bus 66311	: V=1.003242, theta=15.472236 -> V=1.0, theta=0.0
% INFO    : Bus 66312	: V=1.003861, theta=15.675118 -> V=1.0, theta=0.0
% INFO    : Bus 66313	: V=1.0045112, theta=16.111281 -> V=1.0, theta=0.0
% INFO    : Bus 66314	: V=1.0040665, theta=15.861008 -> V=1.0, theta=0.0
% INFO    : Bus 66315	: V=1.0038907, theta=15.775271 -> V=1.0, theta=0.0
% INFO    : Bus 66316	: V=1.0041946, theta=15.849723 -> V=1.0, theta=0.0
% INFO    : Bus 66317	: V=1.0027943, theta=15.951216 -> V=1.0, theta=0.0
% INFO    : Bus 66318	: V=1.002451, theta=15.942985 -> V=1.0, theta=0.0
% INFO    : Bus 66319	: V=1.0026707, theta=15.947717 -> V=1.0, theta=0.0
% INFO    : Bus 66320	: V=1.0043554, theta=15.967858 -> V=1.0, theta=0.0
% INFO    : Bus 66321	: V=1.0046179, theta=16.058157 -> V=1.0, theta=0.0
% INFO    : Bus 66322	: V=1.0050212, theta=16.295191 -> V=1.0, theta=0.0
% INFO    : Bus 66323	: V=1.0052842, theta=16.378536 -> V=1.0, theta=0.0
% INFO    : Bus 66324	: V=1.005512, theta=16.431101 -> V=1.0, theta=0.0
% INFO    : Bus 66325	: V=1.0057443, theta=16.490759 -> V=1.0, theta=0.0
% INFO    : Bus 66326	: V=1.0030247, theta=16.013527 -> V=1.0, theta=0.0
% INFO    : Bus 66327	: V=1.0058286, theta=16.462675 -> V=1.0, theta=0.0
% INFO    : Bus 66328	: V=1.0052954, theta=16.352231 -> V=1.0, theta=0.0
% INFO    : Bus 66329	: V=1.0049879, theta=16.208932 -> V=1.0, theta=0.0
% INFO    : Bus 66330	: V=1.0058738, theta=16.467807 -> V=1.0, theta=0.0
% INFO    : Bus 66331	: V=1.0064746, theta=16.585977 -> V=1.0, theta=0.0
% INFO    : Bus 66332	: V=1.0064582, theta=16.6047 -> V=1.0, theta=0.0
% INFO    : Bus 66333	: V=1.0060488, theta=16.283099 -> V=1.0, theta=0.0
% INFO    : Bus 66334	: V=1.0068732, theta=16.70234 -> V=1.0, theta=0.0
% INFO    : Bus 66335	: V=1.0062966, theta=16.61613 -> V=1.0, theta=0.0
% INFO    : Bus 66336	: V=1.0075443, theta=16.857965 -> V=1.0, theta=0.0
% INFO    : Bus 66337	: V=1.0023085, theta=16.055487 -> V=1.0, theta=0.0
% INFO    : Bus 66338	: V=1.0044636, theta=16.216085 -> V=1.0, theta=0.0
% INFO    : Bus 66339	: V=1.0048401, theta=16.303968 -> V=1.0, theta=0.0
% INFO    : Bus 66340	: V=1.007976, theta=17.021508 -> V=1.0, theta=0.0
% INFO    : Bus 66341	: V=1.0083614, theta=17.100183 -> V=1.0, theta=0.0
% INFO    : Bus 66342	: V=1.0044323, theta=16.294746 -> V=1.0, theta=0.0
% INFO    : Bus 66343	: V=1.0052085, theta=16.916766 -> V=1.0, theta=0.0
% INFO    : Bus 66344	: V=1.0060654, theta=16.940898 -> V=1.0, theta=0.0
% INFO    : Bus 66345	: V=1.0087296, theta=17.172296 -> V=1.0, theta=0.0
% INFO    : Bus 66346	: V=1.0089284, theta=17.211639 -> V=1.0, theta=0.0
% INFO    : Bus 66347	: V=1.006071, theta=16.800054 -> V=1.0, theta=0.0
% INFO    : Bus 66348	: V=1.0087443, theta=17.180882 -> V=1.0, theta=0.0
% INFO    : Bus 66349	: V=1.0086399, theta=17.086462 -> V=1.0, theta=0.0
% INFO    : Bus 66350	: V=1.0075438, theta=16.835007 -> V=1.0, theta=0.0
% INFO    : Bus 66351	: V=1.0067366, theta=16.526486 -> V=1.0, theta=0.0
% INFO    : Bus 66352	: V=1.0100004, theta=16.771202 -> V=1.0, theta=0.0
% INFO    : Bus 66353	: V=1.0063193, theta=16.291046 -> V=1.0, theta=0.0
% INFO    : Bus 66354	: V=1.0068266, theta=16.402795 -> V=1.0, theta=0.0
% INFO    : Bus 66355	: V=1.0076829, theta=16.655439 -> V=1.0, theta=0.0
% INFO    : Bus 66356	: V=1.0087189, theta=17.021638 -> V=1.0, theta=0.0
% INFO    : Bus 66357	: V=1.0077044, theta=16.731226 -> V=1.0, theta=0.0
% INFO    : Bus 66358	: V=1.0190209, theta=18.912114 -> V=1.0, theta=0.0
% INFO    : Bus 66359	: V=1.0073351, theta=16.763882 -> V=1.0, theta=0.0
% INFO    : Bus 66360	: V=1.005906, theta=17.056834 -> V=1.0, theta=0.0
% INFO    : Bus 66361	: V=1.0043331, theta=17.278851 -> V=1.0, theta=0.0
% INFO    : Bus 66362	: V=1.0200003, theta=19.353907 -> V=1.0, theta=0.0
% INFO    : Bus 66363	: V=1.0076996, theta=17.592448 -> V=1.0, theta=0.0
% INFO    : Bus 66364	: V=1.0062027, theta=17.818173 -> V=1.0, theta=0.0
% INFO    : Bus 66365	: V=1.0067576, theta=17.763537 -> V=1.0, theta=0.0
% INFO    : Bus 66366	: V=1.0068634, theta=17.717256 -> V=1.0, theta=0.0
% INFO    : Bus 66367	: V=1.0035247, theta=17.51032 -> V=1.0, theta=0.0
% INFO    : Bus 66368	: V=1.003787, theta=17.593677 -> V=1.0, theta=0.0
% INFO    : Bus 66369	: V=1.0037146, theta=17.688074 -> V=1.0, theta=0.0
% INFO    : Bus 66370	: V=1.0035038, theta=17.508199 -> V=1.0, theta=0.0
% INFO    : Bus 66371	: V=1.0031931, theta=17.578768 -> V=1.0, theta=0.0
% INFO    : Bus 66372	: V=1.0009581, theta=17.466658 -> V=1.0, theta=0.0
% INFO    : Bus 66373	: V=1.0047523, theta=18.15517 -> V=1.0, theta=0.0
% INFO    : Bus 66374	: V=1.0012066, theta=17.498057 -> V=1.0, theta=0.0
% INFO    : Bus 66375	: V=1.0012088, theta=17.538667 -> V=1.0, theta=0.0
% INFO    : Bus 66376	: V=1.0004071, theta=17.51001 -> V=1.0, theta=0.0
% INFO    : Bus 66377	: V=1.0065149, theta=18.47663 -> V=1.0, theta=0.0
% INFO    : Bus 66378	: V=1.007532, theta=18.618264 -> V=1.0, theta=0.0
% INFO    : Bus 66379	: V=1.0094431, theta=18.673546 -> V=1.0, theta=0.0
% INFO    : Bus 66380	: V=1.0003347, theta=13.300098 -> V=1.0, theta=0.0
% INFO    : Bus 66381	: V=0.9977112, theta=12.649023 -> V=1.0, theta=0.0
% INFO    : Bus 66382	: V=0.9968756, theta=12.428465 -> V=1.0, theta=0.0
% INFO    : Bus 66383	: V=0.9924934, theta=12.195559 -> V=1.0, theta=0.0
% INFO    : Bus 66384	: V=1.0025591, theta=12.932321 -> V=1.0, theta=0.0
% INFO    : Bus 66385	: V=0.9942101, theta=12.312894 -> V=1.0, theta=0.0
% INFO    : Bus 66386	: V=0.9935878, theta=12.368225 -> V=1.0, theta=0.0
% INFO    : Bus 66387	: V=0.9962617, theta=12.721551 -> V=1.0, theta=0.0
% INFO    : Bus 66388	: V=0.9942336, theta=12.632987 -> V=1.0, theta=0.0
% INFO    : Bus 66389	: V=1.0045616, theta=14.558227 -> V=1.0, theta=0.0
% INFO    : Bus 66390	: V=1.0028664, theta=14.519477 -> V=1.0, theta=0.0
% INFO    : Bus 66391	: V=0.9973018, theta=13.183081 -> V=1.0, theta=0.0
% INFO    : Bus 66392	: V=0.9969179, theta=13.441356 -> V=1.0, theta=0.0
% INFO    : Bus 66393	: V=1.0006813, theta=14.099649 -> V=1.0, theta=0.0
% INFO    : Bus 66394	: V=0.9936046, theta=12.896303 -> V=1.0, theta=0.0
% INFO    : Bus 66395	: V=0.9932362, theta=12.186277 -> V=1.0, theta=0.0
% INFO    : Bus 66396	: V=0.9997847, theta=13.64813 -> V=1.0, theta=0.0
% INFO    : Bus 66397	: V=0.9970673, theta=12.927776 -> V=1.0, theta=0.0
% INFO    : Bus 66398	: V=1.0025453, theta=14.399253 -> V=1.0, theta=0.0
% INFO    : Bus 66399	: V=0.9972611, theta=13.019701 -> V=1.0, theta=0.0
% INFO    : Bus 66400	: V=0.9935009, theta=12.317067 -> V=1.0, theta=0.0
% INFO    : Bus 66401	: V=0.9983766, theta=13.35076 -> V=1.0, theta=0.0
% INFO    : Bus 66402	: V=0.9990536, theta=13.573809 -> V=1.0, theta=0.0
% INFO    : Bus 66403	: V=0.998745, theta=13.755786 -> V=1.0, theta=0.0
% INFO    : Bus 66404	: V=1.0049671, theta=18.274154 -> V=1.0, theta=0.0
% INFO    : Bus 66405	: V=1.0051549, theta=18.116413 -> V=1.0, theta=0.0
% INFO    : Bus 66406	: V=1.0048441, theta=18.463614 -> V=1.0, theta=0.0
% INFO    : Bus 66407	: V=1.0017499, theta=17.59296 -> V=1.0, theta=0.0
% INFO    : Bus 66408	: V=1.001929, theta=17.613905 -> V=1.0, theta=0.0
% INFO    : Bus 66409	: V=1.0051857, theta=18.240517 -> V=1.0, theta=0.0
% INFO    : Bus 66410	: V=1.0041891, theta=17.867307 -> V=1.0, theta=0.0
% INFO    : Bus 66411	: V=1.0027913, theta=17.753272 -> V=1.0, theta=0.0
% INFO    : Bus 66412	: V=1.014197, theta=19.78712 -> V=1.0, theta=0.0
% INFO    : Bus 66413	: V=1.0093258, theta=18.878856 -> V=1.0, theta=0.0
% INFO    : Bus 66414	: V=1.0026984, theta=18.034757 -> V=1.0, theta=0.0
% INFO    : Bus 66415	: V=1.0081482, theta=17.895877 -> V=1.0, theta=0.0
% INFO    : Bus 66416	: V=1.008577, theta=18.448077 -> V=1.0, theta=0.0
% INFO    : Bus 66417	: V=1.0116411, theta=19.203585 -> V=1.0, theta=0.0
% INFO    : Bus 66418	: V=1.0089817, theta=18.335787 -> V=1.0, theta=0.0
% INFO    : Bus 66419	: V=1.0159874, theta=20.143079 -> V=1.0, theta=0.0
% INFO    : Bus 66420	: V=1.0005267, theta=13.950497 -> V=1.0, theta=0.0
% INFO    : Bus 66421	: V=1.0034991, theta=19.489289 -> V=1.0, theta=0.0
% INFO    : Bus 66422	: V=0.9947177, theta=11.78177 -> V=1.0, theta=0.0
% INFO    : Bus 66423	: V=0.995018, theta=20.093493 -> V=1.0, theta=0.0
% INFO    : Bus 66424	: V=0.9876821, theta=12.634336 -> V=1.0, theta=0.0
% INFO    : Bus 66425	: V=0.9890785, theta=14.720464 -> V=1.0, theta=0.0
% INFO    : Bus 66426	: V=0.9894996, theta=13.58986 -> V=1.0, theta=0.0
% INFO    : Bus 66427	: V=0.9662186, theta=11.540877 -> V=1.0, theta=0.0
% INFO    : Bus 66428	: V=0.9685647, theta=1.100016 -> V=1.0, theta=0.0
% INFO    : Bus 66429	: V=0.9646687, theta=0.171861 -> V=1.0, theta=0.0
% INFO    : Bus 66430	: V=0.9790136, theta=1.404545 -> V=1.0, theta=0.0
% INFO    : Bus 66431	: V=0.9856094, theta=1.479747 -> V=1.0, theta=0.0
% INFO    : Bus 66432	: V=0.9881542, theta=1.219196 -> V=1.0, theta=0.0
% INFO    : Bus 66433	: V=0.9846235, theta=1.825853 -> V=1.0, theta=0.0
% INFO    : Bus 66434	: V=0.9803238, theta=3.043307 -> V=1.0, theta=0.0
% INFO    : Bus 66435	: V=0.9764843, theta=2.237904 -> V=1.0, theta=0.0
% INFO    : Bus 66436	: V=0.9720697, theta=7.848062 -> V=1.0, theta=0.0
% INFO    : Bus 66437	: V=0.9748169, theta=6.751605 -> V=1.0, theta=0.0
% INFO    : Bus 66438	: V=0.9681799, theta=9.99104 -> V=1.0, theta=0.0
% INFO    : Bus 66439	: V=0.9859938, theta=3.716382 -> V=1.0, theta=0.0
% INFO    : Bus 66440	: V=0.9814234, theta=8.155838 -> V=1.0, theta=0.0
% INFO    : Bus 66441	: V=0.9840213, theta=2.67139 -> V=1.0, theta=0.0
% INFO    : Bus 66442	: V=0.9894428, theta=1.791461 -> V=1.0, theta=0.0
% INFO    : Bus 66443	: V=1.0000765, theta=-1.152019 -> V=1.0, theta=0.0
% INFO    : Bus 66444	: V=0.9913875, theta=0.505671 -> V=1.0, theta=0.0
% INFO    : Bus 66445	: V=0.9835499, theta=2.738055 -> V=1.0, theta=0.0
% INFO    : Bus 66446	: V=0.9776099, theta=1.605611 -> V=1.0, theta=0.0
% INFO    : Bus 66447	: V=0.9837423, theta=2.692702 -> V=1.0, theta=0.0
% INFO    : Bus 66448	: V=1.0205709, theta=37.541394 -> V=1.0, theta=0.0
% INFO    : Bus 66449	: V=0.987717, theta=3.726141 -> V=1.0, theta=0.0
% INFO    : Bus 66450	: V=0.9872505, theta=3.669151 -> V=1.0, theta=0.0
% INFO    : Bus 66451	: V=0.9857313, theta=3.486947 -> V=1.0, theta=0.0
% INFO    : Bus 66452	: V=0.9852732, theta=3.411559 -> V=1.0, theta=0.0
% INFO    : Bus 66453	: V=0.9985171, theta=5.264782 -> V=1.0, theta=0.0
% INFO    : Bus 66454	: V=0.9993143, theta=5.328215 -> V=1.0, theta=0.0
% INFO    : Bus 66455	: V=0.9905191, theta=3.921154 -> V=1.0, theta=0.0
% INFO    : Bus 66456	: V=0.9894279, theta=3.830506 -> V=1.0, theta=0.0
% INFO    : Bus 66457	: V=0.9931656, theta=4.202866 -> V=1.0, theta=0.0
% INFO    : Bus 66458	: V=0.9937219, theta=4.215932 -> V=1.0, theta=0.0
% INFO    : Bus 66459	: V=0.9939958, theta=4.233078 -> V=1.0, theta=0.0
% INFO    : Bus 66460	: V=0.9992186, theta=5.305869 -> V=1.0, theta=0.0
% INFO    : Bus 66461	: V=0.9996563, theta=5.335777 -> V=1.0, theta=0.0
% INFO    : Bus 66462	: V=0.9977321, theta=4.901054 -> V=1.0, theta=0.0
% INFO    : Bus 66463	: V=0.9991601, theta=5.332321 -> V=1.0, theta=0.0
% INFO    : Bus 66464	: V=0.993264, theta=4.305522 -> V=1.0, theta=0.0
% INFO    : Bus 66465	: V=0.9984593, theta=5.387989 -> V=1.0, theta=0.0
% INFO    : Bus 66466	: V=0.9986474, theta=5.354086 -> V=1.0, theta=0.0
% INFO    : Bus 66467	: V=0.9988762, theta=5.337625 -> V=1.0, theta=0.0
% INFO    : Bus 66468	: V=0.9942167, theta=4.30279 -> V=1.0, theta=0.0
% INFO    : Bus 66469	: V=1.0200004, theta=7.699805 -> V=1.0, theta=0.0
% INFO    : Bus 66470	: V=0.992837, theta=4.694715 -> V=1.0, theta=0.0
% INFO    : Bus 66471	: V=0.9816596, theta=3.309656 -> V=1.0, theta=0.0
% INFO    : Bus 66472	: V=0.9854387, theta=3.21831 -> V=1.0, theta=0.0
% INFO    : Bus 66473	: V=0.9852204, theta=3.250321 -> V=1.0, theta=0.0
% INFO    : Bus 66474	: V=0.9851125, theta=3.317089 -> V=1.0, theta=0.0
% INFO    : Bus 66475	: V=0.9838511, theta=3.301638 -> V=1.0, theta=0.0
% INFO    : Bus 66476	: V=0.9884876, theta=3.445198 -> V=1.0, theta=0.0
% INFO    : Bus 66477	: V=0.9934881, theta=4.112573 -> V=1.0, theta=0.0
% INFO    : Bus 66478	: V=1.0200004, theta=7.351525 -> V=1.0, theta=0.0
% INFO    : Bus 66479	: V=0.992937, theta=4.48991 -> V=1.0, theta=0.0
% INFO    : Bus 66480	: V=0.9966162, theta=4.692209 -> V=1.0, theta=0.0
% INFO    : Bus 66481	: V=0.9914278, theta=4.67241 -> V=1.0, theta=0.0
% INFO    : Bus 66482	: V=0.9945692, theta=4.621084 -> V=1.0, theta=0.0
% INFO    : Bus 66483	: V=1.0003209, theta=5.476744 -> V=1.0, theta=0.0
% INFO    : Bus 66484	: V=0.9995498, theta=5.489109 -> V=1.0, theta=0.0
% INFO    : Bus 66485	: V=0.9990392, theta=5.516399 -> V=1.0, theta=0.0
% INFO    : Bus 66486	: V=0.9986503, theta=5.565147 -> V=1.0, theta=0.0
% INFO    : Bus 66487	: V=0.9966605, theta=4.82711 -> V=1.0, theta=0.0
% INFO    : Bus 66488	: V=1.0005888, theta=5.487459 -> V=1.0, theta=0.0
% INFO    : Bus 66489	: V=0.9974991, theta=4.901729 -> V=1.0, theta=0.0
% INFO    : Bus 66490	: V=0.9997278, theta=5.460386 -> V=1.0, theta=0.0
% INFO    : Bus 66491	: V=0.9995998, theta=5.475034 -> V=1.0, theta=0.0
% INFO    : Bus 66492	: V=0.9955013, theta=4.825388 -> V=1.0, theta=0.0
% INFO    : Bus 66493	: V=0.9966755, theta=4.85247 -> V=1.0, theta=0.0
% INFO    : Bus 66494	: V=0.9944156, theta=4.749186 -> V=1.0, theta=0.0
% INFO    : Bus 66495	: V=0.99554, theta=4.785208 -> V=1.0, theta=0.0
% INFO    : Bus 66496	: V=0.9948857, theta=4.72485 -> V=1.0, theta=0.0
% INFO    : Bus 66497	: V=0.9912365, theta=4.904134 -> V=1.0, theta=0.0
% INFO    : Bus 66498	: V=0.9984007, theta=5.591176 -> V=1.0, theta=0.0
% INFO    : Bus 66499	: V=1.0300003, theta=-73.174658 -> V=1.0, theta=0.0
% INFO    : Bus 66500	: V=1.0300002, theta=-62.968602 -> V=1.0, theta=0.0
% INFO    : Bus 66501	: V=1.0300003, theta=-81.933628 -> V=1.0, theta=0.0
% INFO    : Bus 66502	: V=1.0100002, theta=-64.021248 -> V=1.0, theta=0.0
% INFO    : Bus 66503	: V=1.0200004, theta=-103.605835 -> V=1.0, theta=0.0
% INFO    : Bus 66504	: V=1.0300004, theta=-80.513283 -> V=1.0, theta=0.0
% INFO    : Bus 66505	: V=1.0138625, theta=-80.72029 -> V=1.0, theta=0.0
% INFO    : Bus 66506	: V=1.0128954, theta=-69.470008 -> V=1.0, theta=0.0
% INFO    : Bus 66507	: V=1.0283711, theta=-104.931234 -> V=1.0, theta=0.0
% INFO    : Bus 66508	: V=1.0300004, theta=-103.3491 -> V=1.0, theta=0.0
% INFO    : Bus 66509	: V=1.0300003, theta=-72.203583 -> V=1.0, theta=0.0
% INFO    : Bus 66510	: V=1.0066675, theta=-105.142751 -> V=1.0, theta=0.0
% INFO    : Bus 66511	: V=1.0300004, theta=-98.800633 -> V=1.0, theta=0.0
% INFO    : Bus 66512	: V=1.0080542, theta=-74.400303 -> V=1.0, theta=0.0
% INFO    : Bus 66513	: V=1.0200004, theta=-92.783936 -> V=1.0, theta=0.0
% INFO    : Bus 66514	: V=1.0300004, theta=-103.529244 -> V=1.0, theta=0.0
% INFO    : Bus 66515	: V=1.0200004, theta=-103.61502 -> V=1.0, theta=0.0
% INFO    : Bus 66516	: V=1.0211539, theta=-108.208889 -> V=1.0, theta=0.0
% INFO    : Bus 66517	: V=1.0100004, theta=-83.182825 -> V=1.0, theta=0.0
% INFO    : Bus 66518	: V=1.0200003, theta=-72.406637 -> V=1.0, theta=0.0
% INFO    : Bus 66519	: V=1.0200004, theta=-103.628994 -> V=1.0, theta=0.0
% INFO    : Bus 66520	: V=1.026349, theta=-60.555766 -> V=1.0, theta=0.0
% INFO    : Bus 66521	: V=1.0100003, theta=-82.626757 -> V=1.0, theta=0.0
% INFO    : Bus 66522	: V=1.0354125, theta=-71.617436 -> V=1.0, theta=0.0
% INFO    : Bus 66523	: V=1.0286907, theta=-82.375308 -> V=1.0, theta=0.0
% INFO    : Bus 66524	: V=1.0246791, theta=-22.893764 -> V=1.0, theta=0.0
% INFO    : Bus 66525	: V=1.0369024, theta=-83.792977 -> V=1.0, theta=0.0
% INFO    : Bus 66526	: V=1.0200003, theta=-61.000411 -> V=1.0, theta=0.0
% INFO    : Bus 66527	: V=1.0200004, theta=-96.168359 -> V=1.0, theta=0.0
% INFO    : Bus 66528	: V=1.0300003, theta=-77.136314 -> V=1.0, theta=0.0
% INFO    : Bus 66529	: V=1.0200807, theta=-72.037051 -> V=1.0, theta=0.0
% INFO    : Bus 66530	: V=1.0200002, theta=-60.729851 -> V=1.0, theta=0.0
% INFO    : Bus 66531	: V=1.0300002, theta=-61.612098 -> V=1.0, theta=0.0
% INFO    : Bus 66532	: V=1.0199902, theta=-80.112283 -> V=1.0, theta=0.0
% INFO    : Bus 66533	: V=1.0335093, theta=-78.393467 -> V=1.0, theta=0.0
% INFO    : Bus 66534	: V=1.0200004, theta=-89.981908 -> V=1.0, theta=0.0
% INFO    : Bus 66535	: V=1.0097958, theta=-74.539315 -> V=1.0, theta=0.0
% INFO    : Bus 66536	: V=1.0100005, theta=-66.377917 -> V=1.0, theta=0.0
% INFO    : Bus 66537	: V=1.0100004, theta=-103.260296 -> V=1.0, theta=0.0
% INFO    : Bus 66538	: V=1.0200004, theta=-102.6034 -> V=1.0, theta=0.0
% INFO    : Bus 66539	: V=1.0100004, theta=-102.129879 -> V=1.0, theta=0.0
% INFO    : Bus 66540	: V=1.0171465, theta=-72.694938 -> V=1.0, theta=0.0
% INFO    : Bus 66541	: V=1.0100004, theta=-86.684553 -> V=1.0, theta=0.0
% INFO    : Bus 66542	: V=1.0197148, theta=-83.49717 -> V=1.0, theta=0.0
% INFO    : Bus 66543	: V=1.0100003, theta=-66.209427 -> V=1.0, theta=0.0
% INFO    : Bus 66544	: V=1.0129922, theta=-81.345868 -> V=1.0, theta=0.0
% INFO    : Bus 66545	: V=1.0136655, theta=-89.42914 -> V=1.0, theta=0.0
% INFO    : Bus 66546	: V=1.0236535, theta=-95.791676 -> V=1.0, theta=0.0
% INFO    : Bus 66547	: V=1.0100004, theta=-99.611165 -> V=1.0, theta=0.0
% INFO    : Bus 66548	: V=1.0100005, theta=-78.944446 -> V=1.0, theta=0.0
% INFO    : Bus 66549	: V=1.0200004, theta=-81.472565 -> V=1.0, theta=0.0
% INFO    : Bus 66550	: V=1.0414191, theta=-58.834079 -> V=1.0, theta=0.0
% INFO    : Bus 66551	: V=1.0342937, theta=-89.180095 -> V=1.0, theta=0.0
% INFO    : Bus 66552	: V=1.0199321, theta=-78.009287 -> V=1.0, theta=0.0
% INFO    : Bus 66553	: V=1.0100005, theta=-67.230339 -> V=1.0, theta=0.0
% INFO    : Bus 66554	: V=1.0094897, theta=-84.063803 -> V=1.0, theta=0.0
% INFO    : Bus 66555	: V=1.0100004, theta=-105.31063 -> V=1.0, theta=0.0
% INFO    : Bus 66556	: V=1.0000004, theta=-98.575005 -> V=1.0, theta=0.0
% INFO    : Bus 66557	: V=1.0100003, theta=-52.283574 -> V=1.0, theta=0.0
% INFO    : Bus 66558	: V=1.0100003, theta=-52.506423 -> V=1.0, theta=0.0
% INFO    : Bus 66559	: V=1.0183964, theta=-88.838887 -> V=1.0, theta=0.0
% INFO    : Bus 66560	: V=1.011599, theta=-73.069595 -> V=1.0, theta=0.0
% INFO    : Bus 66561	: V=1.0087753, theta=-105.298357 -> V=1.0, theta=0.0
% INFO    : Bus 66562	: V=1.0224304, theta=-29.304929 -> V=1.0, theta=0.0
% INFO    : Bus 66563	: V=1.0019784, theta=-82.98892 -> V=1.0, theta=0.0
% INFO    : Bus 66564	: V=1.0122886, theta=-86.153535 -> V=1.0, theta=0.0
% INFO    : Bus 66565	: V=1.0196101, theta=-77.597167 -> V=1.0, theta=0.0
% INFO    : Bus 66566	: V=1.0200003, theta=-56.09962 -> V=1.0, theta=0.0
% INFO    : Bus 66567	: V=1.018142, theta=-106.189275 -> V=1.0, theta=0.0
% INFO    : Bus 66568	: V=1.0100005, theta=-68.030798 -> V=1.0, theta=0.0
% INFO    : Bus 66569	: V=1.0149387, theta=-78.438144 -> V=1.0, theta=0.0
% INFO    : Bus 66570	: V=1.0101035, theta=-94.834685 -> V=1.0, theta=0.0
% INFO    : Bus 66571	: V=1.0100004, theta=-86.270958 -> V=1.0, theta=0.0
% INFO    : Bus 66572	: V=1.0000001, theta=-29.076796 -> V=1.0, theta=0.0
% INFO    : Bus 66573	: V=1.0100004, theta=-87.12404 -> V=1.0, theta=0.0
% INFO    : Bus 66574	: V=1.0100004, theta=-86.443925 -> V=1.0, theta=0.0
% INFO    : Bus 66575	: V=1.0100004, theta=-92.048692 -> V=1.0, theta=0.0
% INFO    : Bus 66576	: V=1.011249, theta=-86.258306 -> V=1.0, theta=0.0
% INFO    : Bus 66577	: V=1.0100005, theta=-71.399458 -> V=1.0, theta=0.0
% INFO    : Bus 66578	: V=1.0032695, theta=-98.404315 -> V=1.0, theta=0.0
% INFO    : Bus 66579	: V=1.0100003, theta=-66.070752 -> V=1.0, theta=0.0
% INFO    : Bus 66580	: V=1.0123325, theta=-82.128874 -> V=1.0, theta=0.0
% INFO    : Bus 66581	: V=1.0203997, theta=-73.691164 -> V=1.0, theta=0.0
% INFO    : Bus 66582	: V=1.0204617, theta=-73.677929 -> V=1.0, theta=0.0
% INFO    : Bus 66583	: V=1.0100004, theta=-109.329906 -> V=1.0, theta=0.0
% INFO    : Bus 66584	: V=1.0048385, theta=-83.094424 -> V=1.0, theta=0.0
% INFO    : Bus 66585	: V=1.0108373, theta=-61.27057 -> V=1.0, theta=0.0
% INFO    : Bus 66586	: V=1.0000004, theta=-90.07563 -> V=1.0, theta=0.0
% INFO    : Bus 66587	: V=1.0100004, theta=-100.359743 -> V=1.0, theta=0.0
% INFO    : Bus 66588	: V=1.0100005, theta=-82.99169 -> V=1.0, theta=0.0
% INFO    : Bus 66589	: V=1.0112145, theta=-106.544155 -> V=1.0, theta=0.0
% INFO    : Bus 66590	: V=1.0090708, theta=-72.263609 -> V=1.0, theta=0.0
% INFO    : Bus 66591	: V=1.0336409, theta=-89.203801 -> V=1.0, theta=0.0
% INFO    : Bus 66592	: V=1.0100004, theta=-83.176655 -> V=1.0, theta=0.0
% INFO    : Bus 66593	: V=1.0099178, theta=-84.284579 -> V=1.0, theta=0.0
% INFO    : Bus 66594	: V=1.0048289, theta=-95.917955 -> V=1.0, theta=0.0
% INFO    : Bus 66595	: V=1.0149383, theta=-29.175274 -> V=1.0, theta=0.0
% INFO    : Bus 66596	: V=1.0100005, theta=-80.893697 -> V=1.0, theta=0.0
% INFO    : Bus 66597	: V=1.0082858, theta=-77.78553 -> V=1.0, theta=0.0
% INFO    : Bus 66598	: V=1.0149551, theta=-104.814747 -> V=1.0, theta=0.0
% INFO    : Bus 66599	: V=1.0158763, theta=-76.74459 -> V=1.0, theta=0.0
% INFO    : Bus 66600	: V=1.0000004, theta=-91.74296 -> V=1.0, theta=0.0
% INFO    : Bus 66601	: V=1.0154556, theta=-54.248344 -> V=1.0, theta=0.0
% INFO    : Bus 66602	: V=1.0012046, theta=-107.12148 -> V=1.0, theta=0.0
% INFO    : Bus 66603	: V=1.0099564, theta=-82.638582 -> V=1.0, theta=0.0
% INFO    : Bus 66604	: V=1.0124376, theta=-103.064355 -> V=1.0, theta=0.0
% INFO    : Bus 66605	: V=1.0338757, theta=-89.192064 -> V=1.0, theta=0.0
% INFO    : Bus 66606	: V=1.0000002, theta=-60.221705 -> V=1.0, theta=0.0
% INFO    : Bus 66607	: V=1.011952, theta=-64.815517 -> V=1.0, theta=0.0
% INFO    : Bus 66608	: V=1.0028947, theta=-105.970213 -> V=1.0, theta=0.0
% INFO    : Bus 66609	: V=1.0020156, theta=-90.857762 -> V=1.0, theta=0.0
% INFO    : Bus 66610	: V=0.9800001, theta=-34.908314 -> V=1.0, theta=0.0
% INFO    : Bus 66611	: V=0.9935362, theta=-89.056883 -> V=1.0, theta=0.0
% INFO    : Bus 66612	: V=1.0105677, theta=-81.726065 -> V=1.0, theta=0.0
% INFO    : Bus 66613	: V=1.0234364, theta=-67.296076 -> V=1.0, theta=0.0
% INFO    : Bus 66614	: V=1.0097919, theta=-71.04641 -> V=1.0, theta=0.0
% INFO    : Bus 66615	: V=1.0100005, theta=-86.570232 -> V=1.0, theta=0.0
% INFO    : Bus 66616	: V=1.0000002, theta=-63.008455 -> V=1.0, theta=0.0
% INFO    : Bus 66617	: V=1.0138651, theta=-61.806963 -> V=1.0, theta=0.0
% INFO    : Bus 66618	: V=1.0003238, theta=-80.148696 -> V=1.0, theta=0.0
% INFO    : Bus 66619	: V=1.0022292, theta=-29.56462 -> V=1.0, theta=0.0
% INFO    : Bus 66620	: V=1.0084566, theta=-82.551947 -> V=1.0, theta=0.0
% INFO    : Bus 66621	: V=1.0100005, theta=-77.405589 -> V=1.0, theta=0.0
% INFO    : Bus 66622	: V=1.0008066, theta=-78.053942 -> V=1.0, theta=0.0
% INFO    : Bus 66623	: V=1.0300003, theta=-79.314632 -> V=1.0, theta=0.0
% INFO    : Bus 66624	: V=0.9931478, theta=-80.953558 -> V=1.0, theta=0.0
% INFO    : Bus 66625	: V=1.0076409, theta=-47.404377 -> V=1.0, theta=0.0
% INFO    : Bus 66626	: V=1.0022043, theta=-110.693991 -> V=1.0, theta=0.0
% INFO    : Bus 66627	: V=1.0154048, theta=-61.93321 -> V=1.0, theta=0.0
% INFO    : Bus 66628	: V=1.0158516, theta=-84.488922 -> V=1.0, theta=0.0
% INFO    : Bus 66629	: V=1.0098365, theta=-85.341477 -> V=1.0, theta=0.0
% INFO    : Bus 66630	: V=1.0105199, theta=-86.114476 -> V=1.0, theta=0.0
% INFO    : Bus 66631	: V=1.0100004, theta=-87.192822 -> V=1.0, theta=0.0
% INFO    : Bus 66632	: V=1.0100004, theta=-90.064404 -> V=1.0, theta=0.0
% INFO    : Bus 66633	: V=1.0100004, theta=-88.451126 -> V=1.0, theta=0.0
% INFO    : Bus 66634	: V=1.0081925, theta=-105.195579 -> V=1.0, theta=0.0
% INFO    : Bus 66635	: V=1.0000005, theta=-73.63572 -> V=1.0, theta=0.0
% INFO    : Bus 66636	: V=1.0100004, theta=-88.696522 -> V=1.0, theta=0.0
% INFO    : Bus 66637	: V=0.9972966, theta=-105.059941 -> V=1.0, theta=0.0
% INFO    : Bus 66638	: V=1.0000001, theta=-27.084617 -> V=1.0, theta=0.0
% INFO    : Bus 66639	: V=1.0008982, theta=-88.078355 -> V=1.0, theta=0.0
% INFO    : Bus 66640	: V=1.0200004, theta=-104.030665 -> V=1.0, theta=0.0
% INFO    : Bus 66641	: V=1.0047528, theta=-62.14486 -> V=1.0, theta=0.0
% INFO    : Bus 66642	: V=0.9951324, theta=-111.057534 -> V=1.0, theta=0.0
% INFO    : Bus 66643	: V=1.0100005, theta=-68.367714 -> V=1.0, theta=0.0
% INFO    : Bus 66644	: V=1.0200005, theta=-68.510865 -> V=1.0, theta=0.0
% INFO    : Bus 66645	: V=1.0065895, theta=-62.008563 -> V=1.0, theta=0.0
% INFO    : Bus 66646	: V=1.0087698, theta=-86.182816 -> V=1.0, theta=0.0
% INFO    : Bus 66647	: V=1.0000004, theta=-100.402292 -> V=1.0, theta=0.0
% INFO    : Bus 66648	: V=1.0099354, theta=-82.642453 -> V=1.0, theta=0.0
% INFO    : Bus 66649	: V=1.0032745, theta=-104.880836 -> V=1.0, theta=0.0
% INFO    : Bus 66650	: V=1.0019445, theta=-80.702249 -> V=1.0, theta=0.0
% INFO    : Bus 66651	: V=1.0108116, theta=-108.708161 -> V=1.0, theta=0.0
% INFO    : Bus 66652	: V=0.9988526, theta=-69.059423 -> V=1.0, theta=0.0
% INFO    : Bus 66653	: V=1.0127215, theta=-53.878997 -> V=1.0, theta=0.0
% INFO    : Bus 66654	: V=1.0351098, theta=-52.331384 -> V=1.0, theta=0.0
% INFO    : Bus 66655	: V=1.0081478, theta=-61.260326 -> V=1.0, theta=0.0
% INFO    : Bus 66656	: V=1.0166245, theta=-90.511697 -> V=1.0, theta=0.0
% INFO    : Bus 66657	: V=1.0088331, theta=-62.346749 -> V=1.0, theta=0.0
% INFO    : Bus 66658	: V=1.0100004, theta=-99.208803 -> V=1.0, theta=0.0
% INFO    : Bus 66659	: V=1.006019, theta=-70.525759 -> V=1.0, theta=0.0
% INFO    : Bus 66660	: V=0.993167, theta=-71.08183 -> V=1.0, theta=0.0
% INFO    : Bus 66661	: V=0.9955369, theta=-75.985449 -> V=1.0, theta=0.0
% INFO    : Bus 66662	: V=1.0012174, theta=-79.577109 -> V=1.0, theta=0.0
% INFO    : Bus 66663	: V=1.026052, theta=-101.041989 -> V=1.0, theta=0.0
% INFO    : Bus 66664	: V=1.0069671, theta=-106.187506 -> V=1.0, theta=0.0
% INFO    : Bus 66665	: V=1.0112264, theta=-90.745664 -> V=1.0, theta=0.0
% INFO    : Bus 66666	: V=1.0000004, theta=-105.188831 -> V=1.0, theta=0.0
% INFO    : Bus 66667	: V=1.0016489, theta=-83.514548 -> V=1.0, theta=0.0
% INFO    : Bus 66668	: V=1.0100003, theta=-81.975922 -> V=1.0, theta=0.0
% INFO    : Bus 66669	: V=1.0135354, theta=-88.351785 -> V=1.0, theta=0.0
% INFO    : Bus 66670	: V=0.9930088, theta=-73.508987 -> V=1.0, theta=0.0
% INFO    : Bus 66671	: V=1.0094401, theta=-61.698156 -> V=1.0, theta=0.0
% INFO    : Bus 66672	: V=1.0112324, theta=-90.744474 -> V=1.0, theta=0.0
% INFO    : Bus 66673	: V=1.0000004, theta=-86.767488 -> V=1.0, theta=0.0
% INFO    : Bus 66674	: V=1.0088349, theta=-62.342853 -> V=1.0, theta=0.0
% INFO    : Bus 66675	: V=1.0100004, theta=-85.034997 -> V=1.0, theta=0.0
% INFO    : Bus 66676	: V=1.0131439, theta=-84.850149 -> V=1.0, theta=0.0
% INFO    : Bus 66677	: V=1.0022859, theta=-83.858203 -> V=1.0, theta=0.0
% INFO    : Bus 66678	: V=1.0014618, theta=-60.354489 -> V=1.0, theta=0.0
% INFO    : Bus 66679	: V=1.0000008, theta=-27.233462 -> V=1.0, theta=0.0
% INFO    : Bus 66680	: V=1.0001144, theta=-89.743189 -> V=1.0, theta=0.0
% INFO    : Bus 66681	: V=1.0113946, theta=-90.748686 -> V=1.0, theta=0.0
% INFO    : Bus 66682	: V=0.9876722, theta=-71.170999 -> V=1.0, theta=0.0
% INFO    : Bus 66683	: V=1.0000004, theta=-103.091341 -> V=1.0, theta=0.0
% INFO    : Bus 66684	: V=1.0185472, theta=-102.555225 -> V=1.0, theta=0.0
% INFO    : Bus 66685	: V=1.0113669, theta=-102.723823 -> V=1.0, theta=0.0
% INFO    : Bus 66686	: V=1.0100005, theta=-91.115699 -> V=1.0, theta=0.0
% INFO    : Bus 66687	: V=1.0075591, theta=-103.983578 -> V=1.0, theta=0.0
% INFO    : Bus 66688	: V=1.011637, theta=-104.321869 -> V=1.0, theta=0.0
% INFO    : Bus 66689	: V=1.0053306, theta=-89.907607 -> V=1.0, theta=0.0
% INFO    : Bus 66690	: V=0.9965945, theta=-85.950439 -> V=1.0, theta=0.0
% INFO    : Bus 66691	: V=1.0309649, theta=-77.460942 -> V=1.0, theta=0.0
% INFO    : Bus 66692	: V=1.006099, theta=-88.893084 -> V=1.0, theta=0.0
% INFO    : Bus 66693	: V=1.0000003, theta=-75.615023 -> V=1.0, theta=0.0
% INFO    : Bus 66694	: V=1.0000003, theta=-75.272623 -> V=1.0, theta=0.0
% INFO    : Bus 66695	: V=1.0185289, theta=-73.584171 -> V=1.0, theta=0.0
% INFO    : Bus 66696	: V=0.9983219, theta=-105.172482 -> V=1.0, theta=0.0
% INFO    : Bus 66697	: V=1.020834, theta=-72.863372 -> V=1.0, theta=0.0
% INFO    : Bus 66698	: V=1.0093689, theta=-109.14867 -> V=1.0, theta=0.0
% INFO    : Bus 66699	: V=1.0087548, theta=-105.295714 -> V=1.0, theta=0.0
% INFO    : Bus 66700	: V=1.018906, theta=-53.515935 -> V=1.0, theta=0.0
% INFO    : Bus 66701	: V=1.0094489, theta=-65.271275 -> V=1.0, theta=0.0
% INFO    : Bus 66702	: V=1.0113911, theta=-64.905477 -> V=1.0, theta=0.0
% INFO    : Bus 66703	: V=1.0078255, theta=-89.616966 -> V=1.0, theta=0.0
% INFO    : Bus 66704	: V=1.0140254, theta=-61.821791 -> V=1.0, theta=0.0
% INFO    : Bus 66705	: V=0.9922173, theta=-63.14222 -> V=1.0, theta=0.0
% INFO    : Bus 66706	: V=1.0166761, theta=-53.643541 -> V=1.0, theta=0.0
% INFO    : Bus 66707	: V=1.0028208, theta=-83.845512 -> V=1.0, theta=0.0
% INFO    : Bus 66708	: V=1.0000003, theta=-75.651085 -> V=1.0, theta=0.0
% INFO    : Bus 66709	: V=1.001258, theta=-80.334284 -> V=1.0, theta=0.0
% INFO    : Bus 66710	: V=1.007895, theta=-96.09321 -> V=1.0, theta=0.0
% INFO    : Bus 66711	: V=1.0100005, theta=-86.217759 -> V=1.0, theta=0.0
% INFO    : Bus 66712	: V=1.0197352, theta=-57.018005 -> V=1.0, theta=0.0
% INFO    : Bus 66713	: V=0.9874363, theta=-64.371117 -> V=1.0, theta=0.0
% INFO    : Bus 66714	: V=1.004057, theta=-67.556231 -> V=1.0, theta=0.0
% INFO    : Bus 66715	: V=1.0100005, theta=-77.012259 -> V=1.0, theta=0.0
% INFO    : Bus 66716	: V=1.0186363, theta=-74.086059 -> V=1.0, theta=0.0
% INFO    : Bus 66717	: V=1.0091513, theta=-105.492533 -> V=1.0, theta=0.0
% INFO    : Bus 66718	: V=1.005339, theta=-105.568782 -> V=1.0, theta=0.0
% INFO    : Bus 66719	: V=1.0198683, theta=-56.689307 -> V=1.0, theta=0.0
% INFO    : Bus 66720	: V=1.0000005, theta=-67.553193 -> V=1.0, theta=0.0
% INFO    : Bus 66721	: V=1.0234337, theta=-73.468671 -> V=1.0, theta=0.0
% INFO    : Bus 66722	: V=1.0111077, theta=-73.134242 -> V=1.0, theta=0.0
% INFO    : Bus 66723	: V=1.0139222, theta=-84.393228 -> V=1.0, theta=0.0
% INFO    : Bus 66724	: V=0.9999531, theta=-73.311125 -> V=1.0, theta=0.0
% INFO    : Bus 66725	: V=1.0200003, theta=-73.294122 -> V=1.0, theta=0.0
% INFO    : Bus 66726	: V=1.0000004, theta=-84.41935 -> V=1.0, theta=0.0
% INFO    : Bus 66727	: V=1.0002723, theta=-80.126386 -> V=1.0, theta=0.0
% INFO    : Bus 66728	: V=0.9982871, theta=-85.091649 -> V=1.0, theta=0.0
% INFO    : Bus 66729	: V=0.9850863, theta=-81.836459 -> V=1.0, theta=0.0
% INFO    : Bus 66730	: V=1.0218439, theta=-84.086271 -> V=1.0, theta=0.0
% INFO    : Bus 66731	: V=1.0133656, theta=-86.084886 -> V=1.0, theta=0.0
% INFO    : Bus 66732	: V=1.0000004, theta=-105.835182 -> V=1.0, theta=0.0
% INFO    : Bus 66733	: V=0.9974325, theta=-76.498387 -> V=1.0, theta=0.0
% INFO    : Bus 66734	: V=0.9994753, theta=-77.095354 -> V=1.0, theta=0.0
% INFO    : Bus 66735	: V=0.9999553, theta=-77.4235 -> V=1.0, theta=0.0
% INFO    : Bus 66736	: V=1.01763, theta=-78.67756 -> V=1.0, theta=0.0
% INFO    : Bus 66737	: V=1.0135145, theta=-82.775556 -> V=1.0, theta=0.0
% INFO    : Bus 66738	: V=1.0100004, theta=-102.1691 -> V=1.0, theta=0.0
% INFO    : Bus 66739	: V=1.0100004, theta=-90.336409 -> V=1.0, theta=0.0
% INFO    : Bus 66740	: V=0.985663, theta=-90.833944 -> V=1.0, theta=0.0
% INFO    : Bus 66741	: V=1.0000005, theta=-75.682664 -> V=1.0, theta=0.0
% INFO    : Bus 66742	: V=1.0024557, theta=-29.94206 -> V=1.0, theta=0.0
% INFO    : Bus 66743	: V=1.0005453, theta=-27.210851 -> V=1.0, theta=0.0
% INFO    : Bus 66744	: V=1.0022609, theta=-29.707146 -> V=1.0, theta=0.0
% INFO    : Bus 66745	: V=1.0066098, theta=-58.485362 -> V=1.0, theta=0.0
% INFO    : Bus 66746	: V=1.0000003, theta=-56.676002 -> V=1.0, theta=0.0
% INFO    : Bus 66747	: V=1.0100005, theta=-67.448413 -> V=1.0, theta=0.0
% INFO    : Bus 66748	: V=1.0021088, theta=-83.224924 -> V=1.0, theta=0.0
% INFO    : Bus 66749	: V=1.0235974, theta=-53.305954 -> V=1.0, theta=0.0
% INFO    : Bus 66750	: V=1.0100004, theta=-101.415036 -> V=1.0, theta=0.0
% INFO    : Bus 66751	: V=0.9999839, theta=-56.432792 -> V=1.0, theta=0.0
% INFO    : Bus 66752	: V=1.0000003, theta=-56.508501 -> V=1.0, theta=0.0
% INFO    : Bus 66753	: V=0.9999619, theta=-56.614587 -> V=1.0, theta=0.0
% INFO    : Bus 66754	: V=1.0100004, theta=-85.1111 -> V=1.0, theta=0.0
% INFO    : Bus 66755	: V=0.9990853, theta=-70.631948 -> V=1.0, theta=0.0
% INFO    : Bus 66756	: V=1.0151724, theta=-85.732098 -> V=1.0, theta=0.0
% INFO    : Bus 66757	: V=1.0021867, theta=-20.7104 -> V=1.0, theta=0.0
% INFO    : Bus 66758	: V=1.0019883, theta=-63.028696 -> V=1.0, theta=0.0
% INFO    : Bus 66759	: V=1.0128531, theta=-82.004322 -> V=1.0, theta=0.0
% INFO    : Bus 66760	: V=1.0097305, theta=-64.833624 -> V=1.0, theta=0.0
% INFO    : Bus 66761	: V=1.0121682, theta=-84.141528 -> V=1.0, theta=0.0
% INFO    : Bus 66762	: V=1.0000005, theta=-72.369283 -> V=1.0, theta=0.0
% INFO    : Bus 66763	: V=1.0153042, theta=-96.975606 -> V=1.0, theta=0.0
% INFO    : Bus 66764	: V=1.0017828, theta=-109.963284 -> V=1.0, theta=0.0
% INFO    : Bus 66765	: V=1.0018357, theta=-109.716443 -> V=1.0, theta=0.0
% INFO    : Bus 66766	: V=1.0200005, theta=-68.881154 -> V=1.0, theta=0.0
% INFO    : Bus 66767	: V=1.0003134, theta=-79.182394 -> V=1.0, theta=0.0
% INFO    : Bus 66768	: V=1.0139991, theta=-72.713662 -> V=1.0, theta=0.0
% INFO    : Bus 66769	: V=1.0010073, theta=-83.752187 -> V=1.0, theta=0.0
% INFO    : Bus 66770	: V=1.0004498, theta=-78.807789 -> V=1.0, theta=0.0
% INFO    : Bus 66771	: V=1.006692, theta=-84.341551 -> V=1.0, theta=0.0
% INFO    : Bus 66772	: V=1.0094078, theta=-68.31194 -> V=1.0, theta=0.0
% INFO    : Bus 66773	: V=1.0155664, theta=-54.211747 -> V=1.0, theta=0.0
% INFO    : Bus 66774	: V=1.0006106, theta=-75.15987 -> V=1.0, theta=0.0
% INFO    : Bus 66775	: V=1.0001525, theta=-79.132588 -> V=1.0, theta=0.0
% INFO    : Bus 66776	: V=1.0000004, theta=-89.220198 -> V=1.0, theta=0.0
% INFO    : Bus 66777	: V=1.0024808, theta=-29.62012 -> V=1.0, theta=0.0
% INFO    : Bus 66778	: V=1.0050627, theta=-81.164602 -> V=1.0, theta=0.0
% INFO    : Bus 66779	: V=1.0075242, theta=-77.931952 -> V=1.0, theta=0.0
% INFO    : Bus 66780	: V=1.0071993, theta=-65.612537 -> V=1.0, theta=0.0
% INFO    : Bus 66781	: V=1.0107738, theta=-84.254185 -> V=1.0, theta=0.0
% INFO    : Bus 66782	: V=0.9989043, theta=-17.722657 -> V=1.0, theta=0.0
% INFO    : Bus 66783	: V=1.0212818, theta=-55.966732 -> V=1.0, theta=0.0
% INFO    : Bus 66784	: V=0.9988435, theta=-56.595062 -> V=1.0, theta=0.0
% INFO    : Bus 66785	: V=0.9947715, theta=-56.577198 -> V=1.0, theta=0.0
% INFO    : Bus 66786	: V=1.0000003, theta=-79.0503 -> V=1.0, theta=0.0
% INFO    : Bus 66787	: V=1.0021198, theta=-69.873314 -> V=1.0, theta=0.0
% INFO    : Bus 66788	: V=1.0052384, theta=-69.292479 -> V=1.0, theta=0.0
% INFO    : Bus 66789	: V=1.0124079, theta=-54.062114 -> V=1.0, theta=0.0
% INFO    : Bus 66790	: V=1.004511, theta=-64.547245 -> V=1.0, theta=0.0
% INFO    : Bus 66791	: V=1.0000004, theta=-88.495773 -> V=1.0, theta=0.0
% INFO    : Bus 66792	: V=1.0100003, theta=-70.961558 -> V=1.0, theta=0.0
% INFO    : Bus 66793	: V=1.0027463, theta=-83.849953 -> V=1.0, theta=0.0
% INFO    : Bus 66794	: V=1.012417, theta=-82.1235 -> V=1.0, theta=0.0
% INFO    : Bus 66795	: V=1.0000005, theta=-89.186007 -> V=1.0, theta=0.0
% INFO    : Bus 66796	: V=1.00968, theta=-109.268989 -> V=1.0, theta=0.0
% INFO    : Bus 66797	: V=1.0077479, theta=-81.38663 -> V=1.0, theta=0.0
% INFO    : Bus 66798	: V=1.0001768, theta=-63.183508 -> V=1.0, theta=0.0
% INFO    : Bus 66799	: V=0.9982208, theta=-91.035508 -> V=1.0, theta=0.0
% INFO    : Bus 66800	: V=1.0039304, theta=-100.15375 -> V=1.0, theta=0.0
% INFO    : Bus 66801	: V=1.0054453, theta=-92.30539 -> V=1.0, theta=0.0
% INFO    : Bus 66802	: V=1.0039654, theta=-96.332946 -> V=1.0, theta=0.0
% INFO    : Bus 66803	: V=1.0000003, theta=-75.633856 -> V=1.0, theta=0.0
% INFO    : Bus 66804	: V=1.0119307, theta=-25.856836 -> V=1.0, theta=0.0
% INFO    : Bus 66805	: V=1.0058508, theta=-109.580093 -> V=1.0, theta=0.0
% INFO    : Bus 66806	: V=1.0015899, theta=-104.523037 -> V=1.0, theta=0.0
% INFO    : Bus 66807	: V=1.0076622, theta=-96.491083 -> V=1.0, theta=0.0
% INFO    : Bus 66808	: V=1.0027661, theta=-89.086749 -> V=1.0, theta=0.0
% INFO    : Bus 66809	: V=1.0023835, theta=-106.421894 -> V=1.0, theta=0.0
% INFO    : Bus 66810	: V=1.0086498, theta=-69.673693 -> V=1.0, theta=0.0
% INFO    : Bus 66811	: V=1.0000005, theta=-59.368148 -> V=1.0, theta=0.0
% INFO    : Bus 66812	: V=1.0031624, theta=-110.072453 -> V=1.0, theta=0.0
% INFO    : Bus 66813	: V=1.0004247, theta=-80.986879 -> V=1.0, theta=0.0
% INFO    : Bus 66814	: V=1.0100005, theta=-67.355609 -> V=1.0, theta=0.0
% INFO    : Bus 66815	: V=1.0100021, theta=-66.378618 -> V=1.0, theta=0.0
% INFO    : Bus 66816	: V=1.0073633, theta=-73.323342 -> V=1.0, theta=0.0
% INFO    : Bus 66817	: V=0.9980428, theta=-64.506442 -> V=1.0, theta=0.0
% INFO    : Bus 66818	: V=1.0000004, theta=-90.889202 -> V=1.0, theta=0.0
% INFO    : Bus 66819	: V=1.0000004, theta=-83.97296 -> V=1.0, theta=0.0
% INFO    : Bus 66820	: V=1.0096089, theta=-104.420115 -> V=1.0, theta=0.0
% INFO    : Bus 66821	: V=0.9966066, theta=-80.403483 -> V=1.0, theta=0.0
% INFO    : Bus 66822	: V=1.0101053, theta=-86.372758 -> V=1.0, theta=0.0
% INFO    : Bus 66823	: V=1.0000353, theta=-78.594284 -> V=1.0, theta=0.0
% INFO    : Bus 66824	: V=1.0032907, theta=-101.07617 -> V=1.0, theta=0.0
% INFO    : Bus 66825	: V=1.0117362, theta=-70.304128 -> V=1.0, theta=0.0
% INFO    : Bus 66826	: V=1.0101212, theta=-105.481195 -> V=1.0, theta=0.0
% INFO    : Bus 66827	: V=1.0180119, theta=-29.137913 -> V=1.0, theta=0.0
% INFO    : Bus 66828	: V=1.0000003, theta=-74.046833 -> V=1.0, theta=0.0
% INFO    : Bus 66829	: V=1.0000003, theta=-74.105293 -> V=1.0, theta=0.0
% INFO    : Bus 66830	: V=1.0100003, theta=-74.778075 -> V=1.0, theta=0.0
% INFO    : Bus 66831	: V=1.0058795, theta=-89.910998 -> V=1.0, theta=0.0
% INFO    : Bus 66832	: V=1.0000003, theta=-75.342315 -> V=1.0, theta=0.0
% INFO    : Bus 66833	: V=1.0143563, theta=-25.710557 -> V=1.0, theta=0.0
% INFO    : Bus 66834	: V=1.0100004, theta=-102.641339 -> V=1.0, theta=0.0
% INFO    : Bus 66835	: V=1.0000004, theta=-107.078156 -> V=1.0, theta=0.0
% INFO    : Bus 66836	: V=1.0105417, theta=-105.337216 -> V=1.0, theta=0.0
% INFO    : Bus 66837	: V=1.0000003, theta=-75.668244 -> V=1.0, theta=0.0
% INFO    : Bus 66838	: V=1.0054174, theta=-70.631937 -> V=1.0, theta=0.0
% INFO    : Bus 66839	: V=1.0100004, theta=-75.979861 -> V=1.0, theta=0.0
% INFO    : Bus 66840	: V=0.9976795, theta=-98.261866 -> V=1.0, theta=0.0
% INFO    : Bus 66841	: V=1.0119464, theta=-73.553438 -> V=1.0, theta=0.0
% INFO    : Bus 66842	: V=1.0076944, theta=-49.277557 -> V=1.0, theta=0.0
% INFO    : Bus 66843	: V=1.0102622, theta=-70.659434 -> V=1.0, theta=0.0
% INFO    : Bus 66844	: V=1.0100003, theta=-82.67143 -> V=1.0, theta=0.0
% INFO    : Bus 66845	: V=1.0067401, theta=-107.124848 -> V=1.0, theta=0.0
% INFO    : Bus 66846	: V=1.0225323, theta=-54.05581 -> V=1.0, theta=0.0
% INFO    : Bus 66847	: V=1.0340993, theta=-52.435306 -> V=1.0, theta=0.0
% INFO    : Bus 66848	: V=1.0027295, theta=-89.093594 -> V=1.0, theta=0.0
% INFO    : Bus 66849	: V=1.0095495, theta=-80.746004 -> V=1.0, theta=0.0
% INFO    : Bus 66850	: V=1.0000003, theta=-69.042722 -> V=1.0, theta=0.0
% INFO    : Bus 66851	: V=1.0000003, theta=-68.927943 -> V=1.0, theta=0.0
% INFO    : Bus 66852	: V=1.0105573, theta=-106.659619 -> V=1.0, theta=0.0
% INFO    : Bus 66853	: V=1.021555, theta=-53.353431 -> V=1.0, theta=0.0
% INFO    : Bus 66854	: V=1.0154927, theta=-25.52628 -> V=1.0, theta=0.0
% INFO    : Bus 66855	: V=1.0000003, theta=-69.085999 -> V=1.0, theta=0.0
% INFO    : Bus 66856	: V=1.0000003, theta=-70.669468 -> V=1.0, theta=0.0
% INFO    : Bus 66857	: V=0.9957003, theta=-76.786903 -> V=1.0, theta=0.0
% INFO    : Bus 66858	: V=1.0151174, theta=-29.567864 -> V=1.0, theta=0.0
% INFO    : Bus 66859	: V=0.9906661, theta=-24.015873 -> V=1.0, theta=0.0
% INFO    : Bus 66860	: V=1.0058905, theta=-66.998664 -> V=1.0, theta=0.0
% INFO    : Bus 66861	: V=0.9701004, theta=-84.195916 -> V=1.0, theta=0.0
% INFO    : Bus 66862	: V=1.0000004, theta=-86.825661 -> V=1.0, theta=0.0
% INFO    : Bus 66863	: V=1.0000005, theta=-59.21897 -> V=1.0, theta=0.0
% INFO    : Bus 66864	: V=1.0000001, theta=-27.38546 -> V=1.0, theta=0.0
% INFO    : Bus 66865	: V=1.0071185, theta=-66.701465 -> V=1.0, theta=0.0
% INFO    : Bus 66866	: V=0.983713, theta=-58.746669 -> V=1.0, theta=0.0
% INFO    : Bus 66867	: V=1.010331, theta=-68.498626 -> V=1.0, theta=0.0
% INFO    : Bus 66868	: V=1.0288202, theta=-53.82035 -> V=1.0, theta=0.0
% INFO    : Bus 66869	: V=1.007041, theta=-109.457288 -> V=1.0, theta=0.0
% INFO    : Bus 66870	: V=1.0077472, theta=-109.518424 -> V=1.0, theta=0.0
% INFO    : Bus 66871	: V=1.0077389, theta=-109.874359 -> V=1.0, theta=0.0
% INFO    : Bus 66872	: V=1.0081145, theta=-109.472674 -> V=1.0, theta=0.0
% INFO    : Bus 66873	: V=1.0084504, theta=-109.419014 -> V=1.0, theta=0.0
% INFO    : Bus 66874	: V=1.008628, theta=-109.307093 -> V=1.0, theta=0.0
% INFO    : Bus 66875	: V=1.0086992, theta=-109.30419 -> V=1.0, theta=0.0
% INFO    : Bus 66876	: V=1.0092762, theta=-109.282725 -> V=1.0, theta=0.0
% INFO    : Bus 66877	: V=1.0091584, theta=-109.287514 -> V=1.0, theta=0.0
% INFO    : Bus 66878	: V=1.0074438, theta=-110.13491 -> V=1.0, theta=0.0
% INFO    : Bus 66879	: V=1.0073487, theta=-110.148912 -> V=1.0, theta=0.0
% INFO    : Bus 66880	: V=1.0073005, theta=-110.135756 -> V=1.0, theta=0.0
% INFO    : Bus 66881	: V=1.0068187, theta=-110.214754 -> V=1.0, theta=0.0
% INFO    : Bus 66882	: V=1.0072448, theta=-110.191576 -> V=1.0, theta=0.0
% INFO    : Bus 66883	: V=1.0070572, theta=-110.200073 -> V=1.0, theta=0.0
% INFO    : Bus 66884	: V=1.0072812, theta=-110.231245 -> V=1.0, theta=0.0
% INFO    : Bus 66885	: V=1.0084373, theta=-109.244669 -> V=1.0, theta=0.0
% INFO    : Bus 66886	: V=1.0084475, theta=-109.276725 -> V=1.0, theta=0.0
% INFO    : Bus 66887	: V=1.0095636, theta=-109.2174 -> V=1.0, theta=0.0
% INFO    : Bus 66888	: V=1.0076839, theta=-110.20073 -> V=1.0, theta=0.0
% INFO    : Bus 66889	: V=1.0094781, theta=-109.168614 -> V=1.0, theta=0.0
% INFO    : Bus 66890	: V=1.0097823, theta=-109.277665 -> V=1.0, theta=0.0
% INFO    : Bus 66891	: V=1.0071565, theta=-110.29082 -> V=1.0, theta=0.0
% INFO    : Bus 66892	: V=1.0071087, theta=-110.320177 -> V=1.0, theta=0.0
% INFO    : Bus 66893	: V=1.0071328, theta=-110.336096 -> V=1.0, theta=0.0
% INFO    : Bus 66894	: V=1.007276, theta=-110.320551 -> V=1.0, theta=0.0
% INFO    : Bus 66895	: V=1.0097851, theta=-109.277786 -> V=1.0, theta=0.0
% INFO    : Bus 66896	: V=1.0070101, theta=-110.345763 -> V=1.0, theta=0.0
% INFO    : Bus 66897	: V=1.0069469, theta=-110.360122 -> V=1.0, theta=0.0
% INFO    : Bus 66898	: V=1.0066773, theta=-110.225644 -> V=1.0, theta=0.0
% INFO    : Bus 66899	: V=1.0066104, theta=-110.228667 -> V=1.0, theta=0.0
% INFO    : Bus 66900	: V=1.0066836, theta=-110.262125 -> V=1.0, theta=0.0
% INFO    : Bus 66901	: V=1.0065664, theta=-110.267435 -> V=1.0, theta=0.0
% INFO    : Bus 66902	: V=1.0068036, theta=-110.312861 -> V=1.0, theta=0.0
% INFO    : Bus 66903	: V=1.0061531, theta=-110.279188 -> V=1.0, theta=0.0
% INFO    : Bus 66904	: V=1.0067061, theta=-110.195585 -> V=1.0, theta=0.0
% INFO    : Bus 66905	: V=1.0067223, theta=-110.202171 -> V=1.0, theta=0.0
% INFO    : Bus 66906	: V=1.0072282, theta=-110.111284 -> V=1.0, theta=0.0
% INFO    : Bus 66907	: V=1.0069293, theta=-110.161421 -> V=1.0, theta=0.0
% INFO    : Bus 66908	: V=1.0068426, theta=-109.895427 -> V=1.0, theta=0.0
% INFO    : Bus 66909	: V=1.006773, theta=-109.725471 -> V=1.0, theta=0.0
% INFO    : Bus 66910	: V=1.0060848, theta=-109.57577 -> V=1.0, theta=0.0
% INFO    : Bus 66911	: V=1.0063113, theta=-110.019157 -> V=1.0, theta=0.0
% INFO    : Bus 66912	: V=1.0062514, theta=-109.958044 -> V=1.0, theta=0.0
% INFO    : Bus 66913	: V=1.006068, theta=-110.123479 -> V=1.0, theta=0.0
% INFO    : Bus 66914	: V=1.0060577, theta=-110.300665 -> V=1.0, theta=0.0
% INFO    : Bus 66915	: V=1.005891, theta=-110.318752 -> V=1.0, theta=0.0
% INFO    : Bus 66916	: V=1.0058351, theta=-110.326527 -> V=1.0, theta=0.0
% INFO    : Bus 66917	: V=1.0058423, theta=-110.324708 -> V=1.0, theta=0.0
% INFO    : Bus 66918	: V=1.0059368, theta=-110.309276 -> V=1.0, theta=0.0
% INFO    : Bus 66919	: V=1.0066963, theta=-110.378417 -> V=1.0, theta=0.0
% INFO    : Bus 66920	: V=1.0068151, theta=-110.365028 -> V=1.0, theta=0.0
% INFO    : Bus 66921	: V=1.0070499, theta=-110.444949 -> V=1.0, theta=0.0
% INFO    : Bus 66922	: V=1.0071962, theta=-110.439536 -> V=1.0, theta=0.0
% INFO    : Bus 66923	: V=1.0076339, theta=-110.435853 -> V=1.0, theta=0.0
% INFO    : Bus 66924	: V=1.00705, theta=-110.44495 -> V=1.0, theta=0.0
% INFO    : Bus 66925	: V=1.0066575, theta=-110.422237 -> V=1.0, theta=0.0
% INFO    : Bus 66926	: V=1.0064415, theta=-110.452957 -> V=1.0, theta=0.0
% INFO    : Bus 66927	: V=1.0062862, theta=-110.458708 -> V=1.0, theta=0.0
% INFO    : Bus 66928	: V=1.0069017, theta=-110.500218 -> V=1.0, theta=0.0
% INFO    : Bus 66929	: V=1.0069852, theta=-110.482048 -> V=1.0, theta=0.0
% INFO    : Bus 66930	: V=1.0085007, theta=-110.422194 -> V=1.0, theta=0.0
% INFO    : Bus 66931	: V=1.0061726, theta=-109.663644 -> V=1.0, theta=0.0
% INFO    : Bus 66932	: V=1.0068572, theta=-110.51148 -> V=1.0, theta=0.0
% INFO    : Bus 66933	: V=1.0070752, theta=-110.514319 -> V=1.0, theta=0.0
% INFO    : Bus 66934	: V=1.0064806, theta=-110.510239 -> V=1.0, theta=0.0
% INFO    : Bus 66935	: V=1.0062976, theta=-110.476735 -> V=1.0, theta=0.0
% INFO    : Bus 66936	: V=1.0061414, theta=-110.500093 -> V=1.0, theta=0.0
% INFO    : Bus 66937	: V=1.0059224, theta=-110.460457 -> V=1.0, theta=0.0
% INFO    : Bus 66938	: V=1.0057156, theta=-110.468839 -> V=1.0, theta=0.0
% INFO    : Bus 66939	: V=1.0059609, theta=-110.387605 -> V=1.0, theta=0.0
% INFO    : Bus 66940	: V=1.0056028, theta=-110.404484 -> V=1.0, theta=0.0
% INFO    : Bus 66941	: V=1.0054902, theta=-110.443413 -> V=1.0, theta=0.0
% INFO    : Bus 66942	: V=1.0054828, theta=-110.492167 -> V=1.0, theta=0.0
% INFO    : Bus 66943	: V=1.0061068, theta=-110.529655 -> V=1.0, theta=0.0
% INFO    : Bus 66944	: V=1.005868, theta=-110.548662 -> V=1.0, theta=0.0
% INFO    : Bus 66945	: V=1.0067252, theta=-110.531162 -> V=1.0, theta=0.0
% INFO    : Bus 66946	: V=1.0056807, theta=-109.870513 -> V=1.0, theta=0.0
% INFO    : Bus 66947	: V=1.0052756, theta=-110.582904 -> V=1.0, theta=0.0
% INFO    : Bus 66948	: V=1.0048638, theta=-110.599208 -> V=1.0, theta=0.0
% INFO    : Bus 66949	: V=1.0055326, theta=-110.571292 -> V=1.0, theta=0.0
% INFO    : Bus 66950	: V=1.004958, theta=-110.562726 -> V=1.0, theta=0.0
% INFO    : Bus 66951	: V=1.0051351, theta=-110.523496 -> V=1.0, theta=0.0
% INFO    : Bus 66952	: V=1.0053313, theta=-110.449882 -> V=1.0, theta=0.0
% INFO    : Bus 66953	: V=1.0058015, theta=-110.314987 -> V=1.0, theta=0.0
% INFO    : Bus 66954	: V=1.0047243, theta=-109.649259 -> V=1.0, theta=0.0
% INFO    : Bus 66955	: V=1.0050546, theta=-109.695413 -> V=1.0, theta=0.0
% INFO    : Bus 66956	: V=1.0048085, theta=-110.519695 -> V=1.0, theta=0.0
% INFO    : Bus 66957	: V=1.0044156, theta=-110.590638 -> V=1.0, theta=0.0
% INFO    : Bus 66958	: V=1.0041272, theta=-110.64648 -> V=1.0, theta=0.0
% INFO    : Bus 66959	: V=1.0042845, theta=-110.646797 -> V=1.0, theta=0.0
% INFO    : Bus 66960	: V=1.0044861, theta=-110.632832 -> V=1.0, theta=0.0
% INFO    : Bus 66961	: V=1.0049698, theta=-110.628577 -> V=1.0, theta=0.0
% INFO    : Bus 66962	: V=1.0050531, theta=-110.094399 -> V=1.0, theta=0.0
% INFO    : Bus 66963	: V=1.0055251, theta=-110.278634 -> V=1.0, theta=0.0
% INFO    : Bus 66964	: V=1.003473, theta=-110.775397 -> V=1.0, theta=0.0
% INFO    : Bus 66965	: V=1.0035981, theta=-110.770302 -> V=1.0, theta=0.0
% INFO    : Bus 66966	: V=1.0045146, theta=-110.271512 -> V=1.0, theta=0.0
% INFO    : Bus 66967	: V=1.0047266, theta=-110.2042 -> V=1.0, theta=0.0
% INFO    : Bus 66968	: V=1.0048969, theta=-110.148231 -> V=1.0, theta=0.0
% INFO    : Bus 66969	: V=1.0038268, theta=-110.697135 -> V=1.0, theta=0.0
% INFO    : Bus 66970	: V=1.003538, theta=-110.71485 -> V=1.0, theta=0.0
% INFO    : Bus 66971	: V=1.0043915, theta=-110.577242 -> V=1.0, theta=0.0
% INFO    : Bus 66972	: V=1.0043453, theta=-110.482143 -> V=1.0, theta=0.0
% INFO    : Bus 66973	: V=1.0037288, theta=-110.244215 -> V=1.0, theta=0.0
% INFO    : Bus 66974	: V=1.0040331, theta=-110.626405 -> V=1.0, theta=0.0
% INFO    : Bus 66975	: V=1.0039352, theta=-110.630037 -> V=1.0, theta=0.0
% INFO    : Bus 66976	: V=1.0036816, theta=-110.7079 -> V=1.0, theta=0.0
% INFO    : Bus 66977	: V=1.0036065, theta=-110.709172 -> V=1.0, theta=0.0
% INFO    : Bus 66978	: V=1.0094863, theta=-109.165993 -> V=1.0, theta=0.0
% INFO    : Bus 66979	: V=1.0097717, theta=-108.638819 -> V=1.0, theta=0.0
% INFO    : Bus 66980	: V=1.0099393, theta=-108.632052 -> V=1.0, theta=0.0
% INFO    : Bus 66981	: V=1.0097405, theta=-107.709896 -> V=1.0, theta=0.0
% INFO    : Bus 66982	: V=1.0100178, theta=-108.662324 -> V=1.0, theta=0.0
% INFO    : Bus 66983	: V=1.0095995, theta=-108.840791 -> V=1.0, theta=0.0
% INFO    : Bus 66984	: V=1.0100814, theta=-108.81911 -> V=1.0, theta=0.0
% INFO    : Bus 66985	: V=1.0099045, theta=-108.992216 -> V=1.0, theta=0.0
% INFO    : Bus 66986	: V=1.0101706, theta=-108.926027 -> V=1.0, theta=0.0
% INFO    : Bus 66987	: V=1.0100959, theta=-108.872758 -> V=1.0, theta=0.0
% INFO    : Bus 66988	: V=1.0103138, theta=-109.039604 -> V=1.0, theta=0.0
% INFO    : Bus 66989	: V=1.0096263, theta=-109.083495 -> V=1.0, theta=0.0
% INFO    : Bus 66990	: V=1.009447, theta=-109.155382 -> V=1.0, theta=0.0
% INFO    : Bus 66991	: V=1.0104994, theta=-109.11993 -> V=1.0, theta=0.0
% INFO    : Bus 66992	: V=1.0103645, theta=-108.968794 -> V=1.0, theta=0.0
% INFO    : Bus 66993	: V=1.0105189, theta=-108.961768 -> V=1.0, theta=0.0
% INFO    : Bus 66994	: V=1.0100004, theta=-106.58688 -> V=1.0, theta=0.0
% INFO    : Bus 66995	: V=1.0104217, theta=-108.746662 -> V=1.0, theta=0.0
% INFO    : Bus 66996	: V=1.0105218, theta=-109.035125 -> V=1.0, theta=0.0
% INFO    : Bus 66997	: V=1.010597, theta=-109.124227 -> V=1.0, theta=0.0
% INFO    : Bus 66998	: V=1.0107365, theta=-109.191531 -> V=1.0, theta=0.0
% INFO    : Bus 66999	: V=1.0093471, theta=-109.212507 -> V=1.0, theta=0.0
% INFO    : Bus 67000	: V=1.0093564, theta=-109.253259 -> V=1.0, theta=0.0
% INFO    : Bus 67001	: V=1.0090884, theta=-109.26535 -> V=1.0, theta=0.0
% INFO    : Bus 67002	: V=1.0091072, theta=-109.383335 -> V=1.0, theta=0.0
% INFO    : Bus 67003	: V=1.0106967, theta=-109.334645 -> V=1.0, theta=0.0
% INFO    : Bus 67004	: V=1.0100047, theta=-109.042016 -> V=1.0, theta=0.0
% INFO    : Bus 67005	: V=1.0103041, theta=-109.029672 -> V=1.0, theta=0.0
% INFO    : Bus 67006	: V=1.0104468, theta=-108.891228 -> V=1.0, theta=0.0
% INFO    : Bus 67007	: V=1.0098766, theta=-109.182181 -> V=1.0, theta=0.0
% INFO    : Bus 67008	: V=1.0094965, theta=-109.258311 -> V=1.0, theta=0.0
% INFO    : Bus 67009	: V=1.0090034, theta=-109.375429 -> V=1.0, theta=0.0
% INFO    : Bus 67010	: V=1.0086729, theta=-109.487364 -> V=1.0, theta=0.0
% INFO    : Bus 67011	: V=1.0089016, theta=-109.431924 -> V=1.0, theta=0.0
% INFO    : Bus 67012	: V=1.0080647, theta=-109.476582 -> V=1.0, theta=0.0
% INFO    : Bus 67013	: V=1.0074481, theta=-109.567626 -> V=1.0, theta=0.0
% INFO    : Bus 67014	: V=1.0086861, theta=-109.384712 -> V=1.0, theta=0.0
% INFO    : Bus 67015	: V=1.0084657, theta=-109.495009 -> V=1.0, theta=0.0
% INFO    : Bus 67016	: V=1.0090192, theta=-109.332147 -> V=1.0, theta=0.0
% INFO    : Bus 67017	: V=1.0095168, theta=-109.23733 -> V=1.0, theta=0.0
% INFO    : Bus 67018	: V=1.0088152, theta=-109.328028 -> V=1.0, theta=0.0
% INFO    : Bus 67019	: V=1.0089749, theta=-109.321578 -> V=1.0, theta=0.0
% INFO    : Bus 67020	: V=1.0094886, theta=-108.775028 -> V=1.0, theta=0.0
% INFO    : Bus 67021	: V=1.0092721, theta=-108.920105 -> V=1.0, theta=0.0
% INFO    : Bus 67022	: V=1.0064384, theta=-110.052738 -> V=1.0, theta=0.0
% INFO    : Bus 67023	: V=1.0069016, theta=-110.073221 -> V=1.0, theta=0.0
% INFO    : Bus 67024	: V=1.0067293, theta=-110.500662 -> V=1.0, theta=0.0
% INFO    : Bus 67025	: V=1.0077917, theta=-110.457118 -> V=1.0, theta=0.0
% INFO    : Bus 67026	: V=1.0071087, theta=-110.358199 -> V=1.0, theta=0.0
% INFO    : Bus 67027	: V=1.0062738, theta=-109.919823 -> V=1.0, theta=0.0
% INFO    : Bus 67028	: V=1.0065778, theta=-109.908584 -> V=1.0, theta=0.0
% INFO    : Bus 67029	: V=1.0071601, theta=-110.335108 -> V=1.0, theta=0.0
% INFO    : Bus 67030	: V=1.0073438, theta=-110.297594 -> V=1.0, theta=0.0
% INFO    : Bus 67031	: V=1.0072797, theta=-110.477787 -> V=1.0, theta=0.0
% INFO    : Bus 67032	: V=1.0065407, theta=-110.508276 -> V=1.0, theta=0.0
% INFO    : Bus 67033	: V=1.0070695, theta=-110.051709 -> V=1.0, theta=0.0
% INFO    : Bus 67034	: V=1.0063221, theta=-110.160721 -> V=1.0, theta=0.0
% INFO    : Bus 67035	: V=1.0065679, theta=-110.126337 -> V=1.0, theta=0.0
% INFO    : Bus 67036	: V=1.0073746, theta=-110.343784 -> V=1.0, theta=0.0
% INFO    : Bus 67037	: V=1.0076653, theta=-109.941265 -> V=1.0, theta=0.0
% INFO    : Bus 67038	: V=1.0070519, theta=-110.097063 -> V=1.0, theta=0.0
% INFO    : Bus 67039	: V=1.0057824, theta=-109.692178 -> V=1.0, theta=0.0
% INFO    : Bus 67040	: V=0.9995946, theta=-110.547423 -> V=1.0, theta=0.0
% INFO    : Bus 67041	: V=1.0021371, theta=-110.025504 -> V=1.0, theta=0.0
% INFO    : Bus 67042	: V=0.9999841, theta=-110.981107 -> V=1.0, theta=0.0
% INFO    : Bus 67043	: V=1.0005501, theta=-110.982745 -> V=1.0, theta=0.0
% INFO    : Bus 67044	: V=1.0010189, theta=-110.972716 -> V=1.0, theta=0.0
% INFO    : Bus 67045	: V=1.0010788, theta=-111.10425 -> V=1.0, theta=0.0
% INFO    : Bus 67046	: V=1.0005882, theta=-111.172769 -> V=1.0, theta=0.0
% INFO    : Bus 67047	: V=0.9998257, theta=-111.260208 -> V=1.0, theta=0.0
% INFO    : Bus 67048	: V=0.9996097, theta=-111.176355 -> V=1.0, theta=0.0
% INFO    : Bus 67049	: V=1.000058, theta=-111.250705 -> V=1.0, theta=0.0
% INFO    : Bus 67050	: V=0.999854, theta=-111.246205 -> V=1.0, theta=0.0
% INFO    : Bus 67051	: V=0.9998965, theta=-111.262407 -> V=1.0, theta=0.0
% INFO    : Bus 67052	: V=0.9998963, theta=-111.252294 -> V=1.0, theta=0.0
% INFO    : Bus 67053	: V=1.0033667, theta=-110.695655 -> V=1.0, theta=0.0
% INFO    : Bus 67054	: V=1.0033326, theta=-110.721652 -> V=1.0, theta=0.0
% INFO    : Bus 67055	: V=1.0035559, theta=-110.726323 -> V=1.0, theta=0.0
% INFO    : Bus 67056	: V=1.0049369, theta=-110.308251 -> V=1.0, theta=0.0
% INFO    : Bus 67057	: V=1.0021754, theta=-110.913294 -> V=1.0, theta=0.0
% INFO    : Bus 67058	: V=1.0033898, theta=-110.807453 -> V=1.0, theta=0.0
% INFO    : Bus 67059	: V=1.0026932, theta=-110.861136 -> V=1.0, theta=0.0
% INFO    : Bus 67060	: V=1.0030908, theta=-110.772722 -> V=1.0, theta=0.0
% INFO    : Bus 67061	: V=1.0031282, theta=-110.394071 -> V=1.0, theta=0.0
% INFO    : Bus 67062	: V=1.0022649, theta=-110.935299 -> V=1.0, theta=0.0
% INFO    : Bus 67063	: V=1.0029246, theta=-110.466579 -> V=1.0, theta=0.0
% INFO    : Bus 67064	: V=1.003078, theta=-110.42989 -> V=1.0, theta=0.0
% INFO    : Bus 67065	: V=1.0025562, theta=-110.916556 -> V=1.0, theta=0.0
% INFO    : Bus 67066	: V=1.0017872, theta=-111.067894 -> V=1.0, theta=0.0
% INFO    : Bus 67067	: V=1.0012267, theta=-111.099463 -> V=1.0, theta=0.0
% INFO    : Bus 67068	: V=1.0014985, theta=-111.114866 -> V=1.0, theta=0.0
% INFO    : Bus 67069	: V=1.001248, theta=-111.144489 -> V=1.0, theta=0.0
% INFO    : Bus 67070	: V=1.0011592, theta=-111.152973 -> V=1.0, theta=0.0
% INFO    : Bus 67071	: V=1.0027062, theta=-110.505608 -> V=1.0, theta=0.0
% INFO    : Bus 67072	: V=1.0028676, theta=-110.475393 -> V=1.0, theta=0.0
% INFO    : Bus 67073	: V=1.0009046, theta=-111.11193 -> V=1.0, theta=0.0
% INFO    : Bus 67074	: V=1.0013553, theta=-111.091655 -> V=1.0, theta=0.0
% INFO    : Bus 67075	: V=1.0017438, theta=-111.056023 -> V=1.0, theta=0.0
% INFO    : Bus 67076	: V=0.9942653, theta=-110.057645 -> V=1.0, theta=0.0
% INFO    : Bus 67077	: V=0.9998997, theta=-110.718656 -> V=1.0, theta=0.0
% INFO    : Bus 67078	: V=0.9989362, theta=-111.204076 -> V=1.0, theta=0.0
% INFO    : Bus 67079	: V=1.000152, theta=-111.253073 -> V=1.0, theta=0.0
% INFO    : Bus 67080	: V=1.0005629, theta=-111.219941 -> V=1.0, theta=0.0
% INFO    : Bus 67081	: V=1.0005464, theta=-111.23626 -> V=1.0, theta=0.0
% INFO    : Bus 67082	: V=1.0008522, theta=-111.196335 -> V=1.0, theta=0.0
% INFO    : Bus 67083	: V=1.0012904, theta=-111.131179 -> V=1.0, theta=0.0
% INFO    : Bus 67084	: V=1.0017871, theta=-111.056026 -> V=1.0, theta=0.0
% INFO    : Bus 67085	: V=1.0009155, theta=-111.071181 -> V=1.0, theta=0.0
% INFO    : Bus 67086	: V=1.0011502, theta=-111.142124 -> V=1.0, theta=0.0
% INFO    : Bus 67087	: V=1.0012593, theta=-111.106487 -> V=1.0, theta=0.0
% INFO    : Bus 67088	: V=1.0015847, theta=-111.040796 -> V=1.0, theta=0.0
% INFO    : Bus 67089	: V=1.002248, theta=-110.640082 -> V=1.0, theta=0.0
% INFO    : Bus 67090	: V=1.0009053, theta=-111.150641 -> V=1.0, theta=0.0
% INFO    : Bus 67091	: V=1.0007023, theta=-111.228031 -> V=1.0, theta=0.0
% INFO    : Bus 67092	: V=1.0014718, theta=-111.067232 -> V=1.0, theta=0.0
% INFO    : Bus 67093	: V=1.002962, theta=-110.298825 -> V=1.0, theta=0.0
% INFO    : Bus 67094	: V=1.0018839, theta=-111.113412 -> V=1.0, theta=0.0
% INFO    : Bus 67095	: V=1.0022412, theta=-111.055119 -> V=1.0, theta=0.0
% INFO    : Bus 67096	: V=1.0023156, theta=-110.892127 -> V=1.0, theta=0.0
% INFO    : Bus 67097	: V=1.0017107, theta=-111.023264 -> V=1.0, theta=0.0
% INFO    : Bus 67098	: V=1.0023363, theta=-110.624902 -> V=1.0, theta=0.0
% INFO    : Bus 67099	: V=1.0023079, theta=-110.644011 -> V=1.0, theta=0.0
% INFO    : Bus 67100	: V=1.0300004, theta=-105.465874 -> V=1.0, theta=0.0
% INFO    : Bus 67101	: V=1.0024214, theta=-110.71219 -> V=1.0, theta=0.0
% INFO    : Bus 67102	: V=1.0023211, theta=-110.956387 -> V=1.0, theta=0.0
% INFO    : Bus 67103	: V=1.0026234, theta=-110.817892 -> V=1.0, theta=0.0
% INFO    : Bus 67104	: V=1.0027604, theta=-110.837336 -> V=1.0, theta=0.0
% INFO    : Bus 67105	: V=1.0029665, theta=-110.846744 -> V=1.0, theta=0.0
% INFO    : Bus 67106	: V=1.0007846, theta=-110.687782 -> V=1.0, theta=0.0
% INFO    : Bus 67107	: V=1.0029833, theta=-110.25005 -> V=1.0, theta=0.0
% INFO    : Bus 67108	: V=1.0029261, theta=-110.267705 -> V=1.0, theta=0.0
% INFO    : Bus 67109	: V=1.0029031, theta=-110.287945 -> V=1.0, theta=0.0
% INFO    : Bus 67110	: V=1.0028107, theta=-110.911162 -> V=1.0, theta=0.0
% INFO    : Bus 67111	: V=0.9940776, theta=-110.538155 -> V=1.0, theta=0.0
% INFO    : Bus 67112	: V=0.9944646, theta=-110.536736 -> V=1.0, theta=0.0
% INFO    : Bus 67113	: V=1.000591, theta=-110.686819 -> V=1.0, theta=0.0
% INFO    : Bus 67114	: V=1.0100004, theta=-109.147079 -> V=1.0, theta=0.0
% INFO    : Bus 67115	: V=1.0031553, theta=-110.199814 -> V=1.0, theta=0.0
% INFO    : Bus 67116	: V=1.001336, theta=-110.703435 -> V=1.0, theta=0.0
% INFO    : Bus 67117	: V=1.0002032, theta=-110.672602 -> V=1.0, theta=0.0
% INFO    : Bus 67118	: V=0.9944923, theta=-110.176139 -> V=1.0, theta=0.0
% INFO    : Bus 67119	: V=0.9945655, theta=-110.301544 -> V=1.0, theta=0.0
% INFO    : Bus 67120	: V=1.0100004, theta=-109.251391 -> V=1.0, theta=0.0
% INFO    : Bus 67121	: V=1.0015301, theta=-109.969166 -> V=1.0, theta=0.0
% INFO    : Bus 67122	: V=0.9970826, theta=-110.316139 -> V=1.0, theta=0.0
% INFO    : Bus 67123	: V=0.9972761, theta=-110.31998 -> V=1.0, theta=0.0
% INFO    : Bus 67124	: V=0.995505, theta=-110.241847 -> V=1.0, theta=0.0
% INFO    : Bus 67125	: V=0.9948178, theta=-110.275155 -> V=1.0, theta=0.0
% INFO    : Bus 67126	: V=1.0023442, theta=-109.959233 -> V=1.0, theta=0.0
% INFO    : Bus 67127	: V=0.9971385, theta=-110.314682 -> V=1.0, theta=0.0
% INFO    : Bus 67128	: V=0.9965275, theta=-110.541516 -> V=1.0, theta=0.0
% INFO    : Bus 67129	: V=0.996734, theta=-110.316271 -> V=1.0, theta=0.0
% INFO    : Bus 67130	: V=0.9995969, theta=-109.899791 -> V=1.0, theta=0.0
% INFO    : Bus 67131	: V=0.993604, theta=-110.299431 -> V=1.0, theta=0.0
% INFO    : Bus 67132	: V=0.9914575, theta=-110.35025 -> V=1.0, theta=0.0
% INFO    : Bus 67133	: V=0.9991639, theta=-109.877356 -> V=1.0, theta=0.0
% INFO    : Bus 67134	: V=0.9929313, theta=-110.320036 -> V=1.0, theta=0.0
% INFO    : Bus 67135	: V=0.9921822, theta=-110.434087 -> V=1.0, theta=0.0
% INFO    : Bus 67136	: V=0.9984205, theta=-109.990438 -> V=1.0, theta=0.0
% INFO    : Bus 67137	: V=0.995226, theta=-110.259503 -> V=1.0, theta=0.0
% INFO    : Bus 67138	: V=0.9971874, theta=-110.320978 -> V=1.0, theta=0.0
% INFO    : Bus 67139	: V=1.0106822, theta=-109.013767 -> V=1.0, theta=0.0
% INFO    : Bus 67140	: V=0.9991115, theta=-110.002632 -> V=1.0, theta=0.0
% INFO    : Bus 67141	: V=0.9971921, theta=-110.318751 -> V=1.0, theta=0.0
% INFO    : Bus 67142	: V=0.9983003, theta=-110.013462 -> V=1.0, theta=0.0
% INFO    : Bus 67143	: V=0.994449, theta=-110.27129 -> V=1.0, theta=0.0
% INFO    : Bus 67144	: V=0.9979993, theta=-109.994455 -> V=1.0, theta=0.0
% INFO    : Bus 67145	: V=0.9978677, theta=-109.994705 -> V=1.0, theta=0.0
% INFO    : Bus 67146	: V=0.9976653, theta=-109.990495 -> V=1.0, theta=0.0
% INFO    : Bus 67147	: V=0.9888261, theta=-110.550367 -> V=1.0, theta=0.0
% INFO    : Bus 67148	: V=0.9945606, theta=-110.310873 -> V=1.0, theta=0.0
% INFO    : Bus 67149	: V=0.9904617, theta=-110.441307 -> V=1.0, theta=0.0
% INFO    : Bus 67150	: V=0.999172, theta=-109.845639 -> V=1.0, theta=0.0
% INFO    : Bus 67151	: V=0.9994593, theta=-109.807954 -> V=1.0, theta=0.0
% INFO    : Bus 67152	: V=0.9924085, theta=-110.403321 -> V=1.0, theta=0.0
% INFO    : Bus 67153	: V=0.9912731, theta=-110.419777 -> V=1.0, theta=0.0
% INFO    : Bus 67154	: V=1.0003366, theta=-109.593224 -> V=1.0, theta=0.0
% INFO    : Bus 67155	: V=1.0004734, theta=-109.690642 -> V=1.0, theta=0.0
% INFO    : Bus 67156	: V=1.0089582, theta=-109.467293 -> V=1.0, theta=0.0
% INFO    : Bus 67157	: V=0.9989589, theta=-109.905123 -> V=1.0, theta=0.0
% INFO    : Bus 67158	: V=0.9968883, theta=-110.248106 -> V=1.0, theta=0.0
% INFO    : Bus 67159	: V=0.9982304, theta=-109.936669 -> V=1.0, theta=0.0
% INFO    : Bus 67160	: V=0.9981882, theta=-109.936605 -> V=1.0, theta=0.0
% INFO    : Bus 67161	: V=0.9978822, theta=-109.963197 -> V=1.0, theta=0.0
% INFO    : Bus 67162	: V=0.9977458, theta=-109.978503 -> V=1.0, theta=0.0
% INFO    : Bus 67163	: V=0.9820217, theta=-110.967942 -> V=1.0, theta=0.0
% INFO    : Bus 67164	: V=0.98948, theta=-110.474399 -> V=1.0, theta=0.0
% INFO    : Bus 67165	: V=0.9877283, theta=-110.525418 -> V=1.0, theta=0.0
% INFO    : Bus 67166	: V=0.9995407, theta=-109.884787 -> V=1.0, theta=0.0
% INFO    : Bus 67167	: V=0.9993224, theta=-109.882305 -> V=1.0, theta=0.0
% INFO    : Bus 67168	: V=1.0100004, theta=-109.463844 -> V=1.0, theta=0.0
% INFO    : Bus 67169	: V=1.0006893, theta=-110.090681 -> V=1.0, theta=0.0
% INFO    : Bus 67170	: V=1.0094996, theta=-109.472116 -> V=1.0, theta=0.0
% INFO    : Bus 67171	: V=1.0100004, theta=-109.472462 -> V=1.0, theta=0.0
% INFO    : Bus 67172	: V=1.0043428, theta=-109.600686 -> V=1.0, theta=0.0
% INFO    : Bus 67173	: V=1.0087565, theta=-109.368314 -> V=1.0, theta=0.0
% INFO    : Bus 67174	: V=1.0092315, theta=-109.427373 -> V=1.0, theta=0.0
% INFO    : Bus 67175	: V=1.0042511, theta=-109.626632 -> V=1.0, theta=0.0
% INFO    : Bus 67176	: V=0.9969227, theta=-110.057297 -> V=1.0, theta=0.0
% INFO    : Bus 67177	: V=0.9869932, theta=-110.920574 -> V=1.0, theta=0.0
% INFO    : Bus 67178	: V=0.9862115, theta=-110.93418 -> V=1.0, theta=0.0
% INFO    : Bus 67179	: V=0.9814185, theta=-111.224702 -> V=1.0, theta=0.0
% INFO    : Bus 67180	: V=0.9825686, theta=-110.919403 -> V=1.0, theta=0.0
% INFO    : Bus 67181	: V=0.9964519, theta=-110.049295 -> V=1.0, theta=0.0
% INFO    : Bus 67182	: V=0.9966156, theta=-110.026904 -> V=1.0, theta=0.0
% INFO    : Bus 67183	: V=0.9974858, theta=-109.962607 -> V=1.0, theta=0.0
% INFO    : Bus 67184	: V=0.9978637, theta=-109.449792 -> V=1.0, theta=0.0
% INFO    : Bus 67185	: V=0.9988408, theta=-109.383793 -> V=1.0, theta=0.0
% INFO    : Bus 67186	: V=0.9994582, theta=-109.350202 -> V=1.0, theta=0.0
% INFO    : Bus 67187	: V=1.000958, theta=-108.553683 -> V=1.0, theta=0.0
% INFO    : Bus 67188	: V=1.0006383, theta=-108.607171 -> V=1.0, theta=0.0
% INFO    : Bus 67189	: V=0.9991863, theta=-109.606784 -> V=1.0, theta=0.0
% INFO    : Bus 67190	: V=0.9983142, theta=-109.640041 -> V=1.0, theta=0.0
% INFO    : Bus 67191	: V=0.9952395, theta=-109.842675 -> V=1.0, theta=0.0
% INFO    : Bus 67192	: V=0.9973152, theta=-109.593963 -> V=1.0, theta=0.0
% INFO    : Bus 67193	: V=1.0006707, theta=-108.667386 -> V=1.0, theta=0.0
% INFO    : Bus 67194	: V=1.000022, theta=-108.836423 -> V=1.0, theta=0.0
% INFO    : Bus 67195	: V=0.9999234, theta=-108.851958 -> V=1.0, theta=0.0
% INFO    : Bus 67196	: V=0.9968517, theta=-109.614963 -> V=1.0, theta=0.0
% INFO    : Bus 67197	: V=0.9998452, theta=-108.935233 -> V=1.0, theta=0.0
% INFO    : Bus 67198	: V=0.9938247, theta=-109.932371 -> V=1.0, theta=0.0
% INFO    : Bus 67199	: V=0.9996201, theta=-109.297611 -> V=1.0, theta=0.0
% INFO    : Bus 67200	: V=1.0011555, theta=-109.054895 -> V=1.0, theta=0.0
% INFO    : Bus 67201	: V=1.0003006, theta=-108.756061 -> V=1.0, theta=0.0
% INFO    : Bus 67202	: V=1.0001274, theta=-109.252648 -> V=1.0, theta=0.0
% INFO    : Bus 67203	: V=0.999549, theta=-109.324326 -> V=1.0, theta=0.0
% INFO    : Bus 67204	: V=0.9992232, theta=-109.340251 -> V=1.0, theta=0.0
% INFO    : Bus 67205	: V=1.0003651, theta=-109.199926 -> V=1.0, theta=0.0
% INFO    : Bus 67206	: V=1.0008792, theta=-109.052059 -> V=1.0, theta=0.0
% INFO    : Bus 67207	: V=1.0009236, theta=-107.476677 -> V=1.0, theta=0.0
% INFO    : Bus 67208	: V=1.0047128, theta=-106.908447 -> V=1.0, theta=0.0
% INFO    : Bus 67209	: V=1.0020136, theta=-108.735655 -> V=1.0, theta=0.0
% INFO    : Bus 67210	: V=1.0088666, theta=-107.482315 -> V=1.0, theta=0.0
% INFO    : Bus 67211	: V=1.0025208, theta=-107.105483 -> V=1.0, theta=0.0
% INFO    : Bus 67212	: V=1.0014715, theta=-108.722037 -> V=1.0, theta=0.0
% INFO    : Bus 67213	: V=1.0039345, theta=-107.834772 -> V=1.0, theta=0.0
% INFO    : Bus 67214	: V=1.0035594, theta=-108.144956 -> V=1.0, theta=0.0
% INFO    : Bus 67215	: V=1.0034616, theta=-108.292514 -> V=1.0, theta=0.0
% INFO    : Bus 67216	: V=1.0057926, theta=-108.033474 -> V=1.0, theta=0.0
% INFO    : Bus 67217	: V=1.0054642, theta=-107.781398 -> V=1.0, theta=0.0
% INFO    : Bus 67218	: V=1.0084957, theta=-106.962293 -> V=1.0, theta=0.0
% INFO    : Bus 67219	: V=1.0091359, theta=-107.511326 -> V=1.0, theta=0.0
% INFO    : Bus 67220	: V=1.0088869, theta=-107.512073 -> V=1.0, theta=0.0
% INFO    : Bus 67221	: V=1.0041692, theta=-108.394633 -> V=1.0, theta=0.0
% INFO    : Bus 67222	: V=1.0032073, theta=-108.54241 -> V=1.0, theta=0.0
% INFO    : Bus 67223	: V=1.0029558, theta=-108.552708 -> V=1.0, theta=0.0
% INFO    : Bus 67224	: V=1.0019601, theta=-108.83292 -> V=1.0, theta=0.0
% INFO    : Bus 67225	: V=1.0023796, theta=-108.721929 -> V=1.0, theta=0.0
% INFO    : Bus 67226	: V=1.0095737, theta=-109.220463 -> V=1.0, theta=0.0
% INFO    : Bus 67227	: V=1.0097433, theta=-109.275928 -> V=1.0, theta=0.0
% INFO    : Bus 67228	: V=1.0135769, theta=-110.174715 -> V=1.0, theta=0.0
% INFO    : Bus 67229	: V=0.992681, theta=-82.028069 -> V=1.0, theta=0.0
% INFO    : Bus 67230	: V=0.9979634, theta=-90.34671 -> V=1.0, theta=0.0
% INFO    : Bus 67231	: V=0.9969937, theta=-88.482585 -> V=1.0, theta=0.0
% INFO    : Bus 67232	: V=0.9890521, theta=-94.273399 -> V=1.0, theta=0.0
% INFO    : Bus 67233	: V=0.9911676, theta=-96.757654 -> V=1.0, theta=0.0
% INFO    : Bus 67234	: V=0.9896783, theta=-97.459218 -> V=1.0, theta=0.0
% INFO    : Bus 67235	: V=0.9920807, theta=-97.940348 -> V=1.0, theta=0.0
% INFO    : Bus 67236	: V=0.9997459, theta=-95.233765 -> V=1.0, theta=0.0
% INFO    : Bus 67237	: V=0.9983045, theta=-94.138618 -> V=1.0, theta=0.0
% INFO    : Bus 67238	: V=0.9993772, theta=-96.558246 -> V=1.0, theta=0.0
% INFO    : Bus 67239	: V=1.0117325, theta=-85.800843 -> V=1.0, theta=0.0
% INFO    : Bus 67240	: V=1.0118413, theta=-85.857056 -> V=1.0, theta=0.0
% INFO    : Bus 67241	: V=1.012269, theta=-85.918404 -> V=1.0, theta=0.0
% INFO    : Bus 67242	: V=1.0115688, theta=-85.945925 -> V=1.0, theta=0.0
% INFO    : Bus 67243	: V=1.0122527, theta=-85.927983 -> V=1.0, theta=0.0
% INFO    : Bus 67244	: V=1.0123239, theta=-85.918094 -> V=1.0, theta=0.0
% INFO    : Bus 67245	: V=1.0127532, theta=-85.655831 -> V=1.0, theta=0.0
% INFO    : Bus 67246	: V=1.0123398, theta=-85.847161 -> V=1.0, theta=0.0
% INFO    : Bus 67247	: V=1.0110493, theta=-85.919307 -> V=1.0, theta=0.0
% INFO    : Bus 67248	: V=1.01207, theta=-86.0134 -> V=1.0, theta=0.0
% INFO    : Bus 67249	: V=1.0120034, theta=-86.00903 -> V=1.0, theta=0.0
% INFO    : Bus 67250	: V=1.0126053, theta=-85.972215 -> V=1.0, theta=0.0
% INFO    : Bus 67251	: V=1.0122991, theta=-85.99704 -> V=1.0, theta=0.0
% INFO    : Bus 67252	: V=1.0118096, theta=-84.996267 -> V=1.0, theta=0.0
% INFO    : Bus 67253	: V=1.0117449, theta=-85.738298 -> V=1.0, theta=0.0
% INFO    : Bus 67254	: V=1.0115666, theta=-85.431248 -> V=1.0, theta=0.0
% INFO    : Bus 67255	: V=1.0124482, theta=-84.858945 -> V=1.0, theta=0.0
% INFO    : Bus 67256	: V=1.0120531, theta=-85.609788 -> V=1.0, theta=0.0
% INFO    : Bus 67257	: V=1.0120374, theta=-85.907613 -> V=1.0, theta=0.0
% INFO    : Bus 67258	: V=1.0120188, theta=-85.993484 -> V=1.0, theta=0.0
% INFO    : Bus 67259	: V=1.0135597, theta=-85.894072 -> V=1.0, theta=0.0
% INFO    : Bus 67260	: V=1.012253, theta=-84.915653 -> V=1.0, theta=0.0
% INFO    : Bus 67261	: V=1.0139659, theta=-85.126601 -> V=1.0, theta=0.0
% INFO    : Bus 67262	: V=1.0156451, theta=-85.774329 -> V=1.0, theta=0.0
% INFO    : Bus 67263	: V=1.0117666, theta=-82.343106 -> V=1.0, theta=0.0
% INFO    : Bus 67264	: V=1.0093967, theta=-84.125893 -> V=1.0, theta=0.0
% INFO    : Bus 67265	: V=1.0102848, theta=-84.089758 -> V=1.0, theta=0.0
% INFO    : Bus 67266	: V=1.0033308, theta=-79.439058 -> V=1.0, theta=0.0
% INFO    : Bus 67267	: V=1.0083188, theta=-84.413557 -> V=1.0, theta=0.0
% INFO    : Bus 67268	: V=1.0068022, theta=-84.47557 -> V=1.0, theta=0.0
% INFO    : Bus 67269	: V=1.006941, theta=-84.390652 -> V=1.0, theta=0.0
% INFO    : Bus 67270	: V=1.0098219, theta=-84.283088 -> V=1.0, theta=0.0
% INFO    : Bus 67271	: V=1.0112108, theta=-84.966155 -> V=1.0, theta=0.0
% INFO    : Bus 67272	: V=1.0127019, theta=-84.100431 -> V=1.0, theta=0.0
% INFO    : Bus 67273	: V=1.0107079, theta=-84.516122 -> V=1.0, theta=0.0
% INFO    : Bus 67274	: V=1.01462, theta=-83.895493 -> V=1.0, theta=0.0
% INFO    : Bus 67275	: V=1.015653, theta=-83.745126 -> V=1.0, theta=0.0
% INFO    : Bus 67276	: V=1.0164256, theta=-83.71545 -> V=1.0, theta=0.0
% INFO    : Bus 67277	: V=1.0149147, theta=-84.244072 -> V=1.0, theta=0.0
% INFO    : Bus 67278	: V=1.0117653, theta=-84.998338 -> V=1.0, theta=0.0
% INFO    : Bus 67279	: V=1.0117243, theta=-84.47592 -> V=1.0, theta=0.0
% INFO    : Bus 67280	: V=1.0144256, theta=-84.438713 -> V=1.0, theta=0.0
% INFO    : Bus 67281	: V=1.0138434, theta=-84.861494 -> V=1.0, theta=0.0
% INFO    : Bus 67282	: V=1.0138991, theta=-84.414742 -> V=1.0, theta=0.0
% INFO    : Bus 67283	: V=1.0106326, theta=-85.724366 -> V=1.0, theta=0.0
% INFO    : Bus 67284	: V=1.0100957, theta=-86.315256 -> V=1.0, theta=0.0
% INFO    : Bus 67285	: V=1.0085284, theta=-87.404416 -> V=1.0, theta=0.0
% INFO    : Bus 67286	: V=1.0112156, theta=-86.778476 -> V=1.0, theta=0.0
% INFO    : Bus 67287	: V=1.0067425, theta=-87.354862 -> V=1.0, theta=0.0
% INFO    : Bus 67288	: V=1.0178184, theta=-85.977267 -> V=1.0, theta=0.0
% INFO    : Bus 67289	: V=1.0130204, theta=-84.390056 -> V=1.0, theta=0.0
% INFO    : Bus 67290	: V=0.9973436, theta=-99.518914 -> V=1.0, theta=0.0
% INFO    : Bus 67291	: V=1.0065827, theta=-95.427624 -> V=1.0, theta=0.0
% INFO    : Bus 67292	: V=1.0051449, theta=-96.051879 -> V=1.0, theta=0.0
% INFO    : Bus 67293	: V=0.9913574, theta=-99.239399 -> V=1.0, theta=0.0
% INFO    : Bus 67294	: V=0.9946902, theta=-98.412757 -> V=1.0, theta=0.0
% INFO    : Bus 67295	: V=0.9999597, theta=-96.459687 -> V=1.0, theta=0.0
% INFO    : Bus 67296	: V=0.9948384, theta=-90.883328 -> V=1.0, theta=0.0
% INFO    : Bus 67297	: V=1.0051254, theta=-95.22413 -> V=1.0, theta=0.0
% INFO    : Bus 67298	: V=1.0035774, theta=-95.238235 -> V=1.0, theta=0.0
% INFO    : Bus 67299	: V=0.9994321, theta=-88.531191 -> V=1.0, theta=0.0
% INFO    : Bus 67300	: V=0.9950439, theta=-91.861333 -> V=1.0, theta=0.0
% INFO    : Bus 67301	: V=0.9966325, theta=-88.881758 -> V=1.0, theta=0.0
% INFO    : Bus 67302	: V=1.0142808, theta=-88.305599 -> V=1.0, theta=0.0
% INFO    : Bus 67303	: V=1.0193177, theta=-84.991886 -> V=1.0, theta=0.0
% INFO    : Bus 67304	: V=1.0002681, theta=-88.186572 -> V=1.0, theta=0.0
% INFO    : Bus 67305	: V=1.0036171, theta=-104.464853 -> V=1.0, theta=0.0
% INFO    : Bus 67306	: V=1.0023307, theta=-104.76794 -> V=1.0, theta=0.0
% INFO    : Bus 67307	: V=1.0044695, theta=-104.708329 -> V=1.0, theta=0.0
% INFO    : Bus 67308	: V=1.002022, theta=-104.713286 -> V=1.0, theta=0.0
% INFO    : Bus 67309	: V=1.0029773, theta=-104.667529 -> V=1.0, theta=0.0
% INFO    : Bus 67310	: V=0.9965098, theta=-105.526492 -> V=1.0, theta=0.0
% INFO    : Bus 67311	: V=1.0002639, theta=-104.772285 -> V=1.0, theta=0.0
% INFO    : Bus 67312	: V=0.9929783, theta=-105.909309 -> V=1.0, theta=0.0
% INFO    : Bus 67313	: V=0.9932711, theta=-105.991881 -> V=1.0, theta=0.0
% INFO    : Bus 67314	: V=1.0092481, theta=-104.969311 -> V=1.0, theta=0.0
% INFO    : Bus 67315	: V=0.992434, theta=-106.017693 -> V=1.0, theta=0.0
% INFO    : Bus 67316	: V=0.9935435, theta=-106.077992 -> V=1.0, theta=0.0
% INFO    : Bus 67317	: V=0.9914301, theta=-106.055482 -> V=1.0, theta=0.0
% INFO    : Bus 67318	: V=0.9908077, theta=-106.081065 -> V=1.0, theta=0.0
% INFO    : Bus 67319	: V=0.9892508, theta=-106.088963 -> V=1.0, theta=0.0
% INFO    : Bus 67320	: V=1.0006331, theta=-106.084807 -> V=1.0, theta=0.0
% INFO    : Bus 67321	: V=0.984405, theta=-106.279106 -> V=1.0, theta=0.0
% INFO    : Bus 67322	: V=0.9835272, theta=-106.292263 -> V=1.0, theta=0.0
% INFO    : Bus 67323	: V=0.9873737, theta=-106.194247 -> V=1.0, theta=0.0
% INFO    : Bus 67324	: V=1.012429, theta=-104.306111 -> V=1.0, theta=0.0
% INFO    : Bus 67325	: V=1.0123222, theta=-104.501198 -> V=1.0, theta=0.0
% INFO    : Bus 67326	: V=1.0120046, theta=-104.394455 -> V=1.0, theta=0.0
% INFO    : Bus 67327	: V=1.0126033, theta=-104.40341 -> V=1.0, theta=0.0
% INFO    : Bus 67328	: V=1.0099883, theta=-104.551133 -> V=1.0, theta=0.0
% INFO    : Bus 67329	: V=1.0118941, theta=-104.447421 -> V=1.0, theta=0.0
% INFO    : Bus 67330	: V=1.0163082, theta=-104.633763 -> V=1.0, theta=0.0
% INFO    : Bus 67331	: V=1.0109398, theta=-104.511195 -> V=1.0, theta=0.0
% INFO    : Bus 67332	: V=1.0102845, theta=-104.548761 -> V=1.0, theta=0.0
% INFO    : Bus 67333	: V=1.0105028, theta=-104.549129 -> V=1.0, theta=0.0
% INFO    : Bus 67334	: V=1.0035751, theta=-105.039391 -> V=1.0, theta=0.0
% INFO    : Bus 67335	: V=0.9997995, theta=-105.320233 -> V=1.0, theta=0.0
% INFO    : Bus 67336	: V=1.0129419, theta=-104.290135 -> V=1.0, theta=0.0
% INFO    : Bus 67337	: V=1.0194599, theta=-103.714884 -> V=1.0, theta=0.0
% INFO    : Bus 67338	: V=1.012495, theta=-104.586564 -> V=1.0, theta=0.0
% INFO    : Bus 67339	: V=1.0118615, theta=-104.458874 -> V=1.0, theta=0.0
% INFO    : Bus 67340	: V=1.0076249, theta=-104.802382 -> V=1.0, theta=0.0
% INFO    : Bus 67341	: V=1.0061701, theta=-104.860983 -> V=1.0, theta=0.0
% INFO    : Bus 67342	: V=1.005252, theta=-104.837375 -> V=1.0, theta=0.0
% INFO    : Bus 67343	: V=1.0103665, theta=-104.917553 -> V=1.0, theta=0.0
% INFO    : Bus 67344	: V=1.0086448, theta=-105.230526 -> V=1.0, theta=0.0
% INFO    : Bus 67345	: V=1.0072951, theta=-105.247696 -> V=1.0, theta=0.0
% INFO    : Bus 67346	: V=1.0065005, theta=-105.049947 -> V=1.0, theta=0.0
% INFO    : Bus 67347	: V=1.0116749, theta=-104.753694 -> V=1.0, theta=0.0
% INFO    : Bus 67348	: V=1.0031272, theta=-105.453727 -> V=1.0, theta=0.0
% INFO    : Bus 67349	: V=1.010362, theta=-104.94509 -> V=1.0, theta=0.0
% INFO    : Bus 67350	: V=1.0111135, theta=-104.650812 -> V=1.0, theta=0.0
% INFO    : Bus 67351	: V=1.030332, theta=-103.482219 -> V=1.0, theta=0.0
% INFO    : Bus 67352	: V=1.0052841, theta=-105.552137 -> V=1.0, theta=0.0
% INFO    : Bus 67353	: V=1.0048579, theta=-106.208149 -> V=1.0, theta=0.0
% INFO    : Bus 67354	: V=1.0054209, theta=-105.52298 -> V=1.0, theta=0.0
% INFO    : Bus 67355	: V=1.0038371, theta=-106.50132 -> V=1.0, theta=0.0
% INFO    : Bus 67356	: V=1.0053666, theta=-105.639747 -> V=1.0, theta=0.0
% INFO    : Bus 67357	: V=1.0032649, theta=-106.626657 -> V=1.0, theta=0.0
% INFO    : Bus 67358	: V=1.0065093, theta=-105.745985 -> V=1.0, theta=0.0
% INFO    : Bus 67359	: V=1.0030522, theta=-106.698516 -> V=1.0, theta=0.0
% INFO    : Bus 67360	: V=1.001989, theta=-106.929348 -> V=1.0, theta=0.0
% INFO    : Bus 67361	: V=1.0023109, theta=-107.018907 -> V=1.0, theta=0.0
% INFO    : Bus 67362	: V=1.0060215, theta=-105.933129 -> V=1.0, theta=0.0
% INFO    : Bus 67363	: V=1.0051775, theta=-106.251806 -> V=1.0, theta=0.0
% INFO    : Bus 67364	: V=1.0038587, theta=-107.09826 -> V=1.0, theta=0.0
% INFO    : Bus 67365	: V=0.9937705, theta=-107.267548 -> V=1.0, theta=0.0
% INFO    : Bus 67366	: V=0.9935975, theta=-107.201701 -> V=1.0, theta=0.0
% INFO    : Bus 67367	: V=1.0041853, theta=-106.654018 -> V=1.0, theta=0.0
% INFO    : Bus 67368	: V=0.9984604, theta=-107.179814 -> V=1.0, theta=0.0
% INFO    : Bus 67369	: V=1.0100004, theta=-105.222471 -> V=1.0, theta=0.0
% INFO    : Bus 67370	: V=1.0064805, theta=-105.682823 -> V=1.0, theta=0.0
% INFO    : Bus 67371	: V=1.0029863, theta=-106.044066 -> V=1.0, theta=0.0
% INFO    : Bus 67372	: V=1.0019249, theta=-106.102103 -> V=1.0, theta=0.0
% INFO    : Bus 67373	: V=0.9967102, theta=-106.831584 -> V=1.0, theta=0.0
% INFO    : Bus 67374	: V=1.0002619, theta=-106.237675 -> V=1.0, theta=0.0
% INFO    : Bus 67375	: V=1.0041989, theta=-106.861507 -> V=1.0, theta=0.0
% INFO    : Bus 67376	: V=1.0045746, theta=-106.84748 -> V=1.0, theta=0.0
% INFO    : Bus 67377	: V=1.0064403, theta=-105.503126 -> V=1.0, theta=0.0
% INFO    : Bus 67378	: V=0.9988293, theta=-106.678986 -> V=1.0, theta=0.0
% INFO    : Bus 67379	: V=1.0057244, theta=-105.566625 -> V=1.0, theta=0.0
% INFO    : Bus 67380	: V=0.9995736, theta=-106.808109 -> V=1.0, theta=0.0
% INFO    : Bus 67381	: V=1.000125, theta=-108.554871 -> V=1.0, theta=0.0
% INFO    : Bus 67382	: V=0.9959877, theta=-106.912056 -> V=1.0, theta=0.0
% INFO    : Bus 67383	: V=0.9956022, theta=-106.989396 -> V=1.0, theta=0.0
% INFO    : Bus 67384	: V=0.9949648, theta=-107.037387 -> V=1.0, theta=0.0
% INFO    : Bus 67385	: V=0.9945843, theta=-107.037215 -> V=1.0, theta=0.0
% INFO    : Bus 67386	: V=0.9941017, theta=-107.089819 -> V=1.0, theta=0.0
% INFO    : Bus 67387	: V=0.9969475, theta=-106.835897 -> V=1.0, theta=0.0
% INFO    : Bus 67388	: V=0.9953947, theta=-106.959333 -> V=1.0, theta=0.0
% INFO    : Bus 67389	: V=0.999944, theta=-107.225492 -> V=1.0, theta=0.0
% INFO    : Bus 67390	: V=0.9933541, theta=-107.093509 -> V=1.0, theta=0.0
% INFO    : Bus 67391	: V=0.9930645, theta=-107.096304 -> V=1.0, theta=0.0
% INFO    : Bus 67392	: V=0.9988348, theta=-107.465783 -> V=1.0, theta=0.0
% INFO    : Bus 67393	: V=1.0002317, theta=-108.023726 -> V=1.0, theta=0.0
% INFO    : Bus 67394	: V=1.0006124, theta=-108.009517 -> V=1.0, theta=0.0
% INFO    : Bus 67395	: V=1.0001466, theta=-107.594045 -> V=1.0, theta=0.0
% INFO    : Bus 67396	: V=0.9998048, theta=-107.706295 -> V=1.0, theta=0.0
% INFO    : Bus 67397	: V=1.0015656, theta=-108.558844 -> V=1.0, theta=0.0
% INFO    : Bus 67398	: V=1.0041019, theta=-107.084106 -> V=1.0, theta=0.0
% INFO    : Bus 67399	: V=1.0038319, theta=-106.855264 -> V=1.0, theta=0.0
% INFO    : Bus 67400	: V=1.0013208, theta=-108.610705 -> V=1.0, theta=0.0
% INFO    : Bus 67401	: V=1.0032949, theta=-108.727099 -> V=1.0, theta=0.0
% INFO    : Bus 67402	: V=1.0013226, theta=-108.428351 -> V=1.0, theta=0.0
% INFO    : Bus 67403	: V=1.0009118, theta=-108.254634 -> V=1.0, theta=0.0
% INFO    : Bus 67404	: V=0.9997181, theta=-108.10002 -> V=1.0, theta=0.0
% INFO    : Bus 67405	: V=0.9977862, theta=-109.512222 -> V=1.0, theta=0.0
% INFO    : Bus 67406	: V=0.9977187, theta=-109.540142 -> V=1.0, theta=0.0
% INFO    : Bus 67407	: V=0.997369, theta=-109.52788 -> V=1.0, theta=0.0
% INFO    : Bus 67408	: V=0.9991789, theta=-108.900573 -> V=1.0, theta=0.0
% INFO    : Bus 67409	: V=0.9978268, theta=-109.449126 -> V=1.0, theta=0.0
% INFO    : Bus 67410	: V=0.9977921, theta=-109.545762 -> V=1.0, theta=0.0
% INFO    : Bus 67411	: V=0.9966192, theta=-109.589904 -> V=1.0, theta=0.0
% INFO    : Bus 67412	: V=0.9991708, theta=-108.730882 -> V=1.0, theta=0.0
% INFO    : Bus 67413	: V=0.9992741, theta=-107.703468 -> V=1.0, theta=0.0
% INFO    : Bus 67414	: V=0.9962938, theta=-109.623996 -> V=1.0, theta=0.0
% INFO    : Bus 67415	: V=0.9979355, theta=-109.165652 -> V=1.0, theta=0.0
% INFO    : Bus 67416	: V=0.9983801, theta=-109.148603 -> V=1.0, theta=0.0
% INFO    : Bus 67417	: V=0.9988772, theta=-109.190687 -> V=1.0, theta=0.0
% INFO    : Bus 67418	: V=0.9990278, theta=-108.987733 -> V=1.0, theta=0.0
% INFO    : Bus 67419	: V=0.9992021, theta=-108.121382 -> V=1.0, theta=0.0
% INFO    : Bus 67420	: V=1.0017869, theta=-107.050622 -> V=1.0, theta=0.0
% INFO    : Bus 67421	: V=1.0008534, theta=-107.27687 -> V=1.0, theta=0.0
% INFO    : Bus 67422	: V=0.9993271, theta=-108.176034 -> V=1.0, theta=0.0
% INFO    : Bus 67423	: V=0.9999626, theta=-107.581803 -> V=1.0, theta=0.0
% INFO    : Bus 67424	: V=1.002748, theta=-107.684614 -> V=1.0, theta=0.0
% INFO    : Bus 67425	: V=1.0038839, theta=-108.304049 -> V=1.0, theta=0.0
% INFO    : Bus 67426	: V=1.0049168, theta=-107.726033 -> V=1.0, theta=0.0
% INFO    : Bus 67427	: V=1.0045122, theta=-108.70429 -> V=1.0, theta=0.0
% INFO    : Bus 67428	: V=0.9995851, theta=-108.758208 -> V=1.0, theta=0.0
% INFO    : Bus 67429	: V=1.0035367, theta=-108.818134 -> V=1.0, theta=0.0
% INFO    : Bus 67430	: V=0.9998256, theta=-108.662563 -> V=1.0, theta=0.0
% INFO    : Bus 67431	: V=1.0040637, theta=-108.896911 -> V=1.0, theta=0.0
% INFO    : Bus 67432	: V=0.9980865, theta=-108.734824 -> V=1.0, theta=0.0
% INFO    : Bus 67433	: V=0.9968656, theta=-108.781214 -> V=1.0, theta=0.0
% INFO    : Bus 67434	: V=1.0047145, theta=-108.449312 -> V=1.0, theta=0.0
% INFO    : Bus 67435	: V=1.0046854, theta=-108.856923 -> V=1.0, theta=0.0
% INFO    : Bus 67436	: V=1.0053209, theta=-109.298814 -> V=1.0, theta=0.0
% INFO    : Bus 67437	: V=1.0048497, theta=-109.011571 -> V=1.0, theta=0.0
% INFO    : Bus 67438	: V=1.0058458, theta=-109.403901 -> V=1.0, theta=0.0
% INFO    : Bus 67439	: V=1.0045571, theta=-109.26887 -> V=1.0, theta=0.0
% INFO    : Bus 67440	: V=0.9928307, theta=-106.396581 -> V=1.0, theta=0.0
% INFO    : Bus 67441	: V=0.9950311, theta=-106.305041 -> V=1.0, theta=0.0
% INFO    : Bus 67442	: V=1.0018937, theta=-105.050413 -> V=1.0, theta=0.0
% INFO    : Bus 67443	: V=0.9974337, theta=-105.46624 -> V=1.0, theta=0.0
% INFO    : Bus 67444	: V=0.998344, theta=-105.400379 -> V=1.0, theta=0.0
% INFO    : Bus 67445	: V=1.0049097, theta=-106.218547 -> V=1.0, theta=0.0
% INFO    : Bus 67446	: V=0.9993666, theta=-109.127301 -> V=1.0, theta=0.0
% INFO    : Bus 67447	: V=0.9989085, theta=-109.34605 -> V=1.0, theta=0.0
% INFO    : Bus 67448	: V=0.9985202, theta=-109.401573 -> V=1.0, theta=0.0
% INFO    : Bus 67449	: V=0.9977394, theta=-109.3903 -> V=1.0, theta=0.0
% INFO    : Bus 67450	: V=0.9983654, theta=-109.421508 -> V=1.0, theta=0.0
% INFO    : Bus 67451	: V=1.0007325, theta=-105.878919 -> V=1.0, theta=0.0
% INFO    : Bus 67452	: V=1.002676, theta=-107.108277 -> V=1.0, theta=0.0
% INFO    : Bus 67453	: V=1.0011898, theta=-107.436189 -> V=1.0, theta=0.0
% INFO    : Bus 67454	: V=1.0077724, theta=-105.484107 -> V=1.0, theta=0.0
% INFO    : Bus 67455	: V=1.0044939, theta=-106.309872 -> V=1.0, theta=0.0
% INFO    : Bus 67456	: V=1.0025953, theta=-106.312244 -> V=1.0, theta=0.0
% INFO    : Bus 67457	: V=1.0018865, theta=-107.157913 -> V=1.0, theta=0.0
% INFO    : Bus 67458	: V=1.0060215, theta=-105.297821 -> V=1.0, theta=0.0
% INFO    : Bus 67459	: V=1.0078783, theta=-105.210329 -> V=1.0, theta=0.0
% INFO    : Bus 67460	: V=1.0064063, theta=-107.036815 -> V=1.0, theta=0.0
% INFO    : Bus 67461	: V=1.0064677, theta=-106.953639 -> V=1.0, theta=0.0
% INFO    : Bus 67462	: V=1.0050099, theta=-106.766244 -> V=1.0, theta=0.0
% INFO    : Bus 67463	: V=1.0055882, theta=-106.724311 -> V=1.0, theta=0.0
% INFO    : Bus 67464	: V=1.0044808, theta=-107.050305 -> V=1.0, theta=0.0
% INFO    : Bus 67465	: V=1.0034864, theta=-106.706324 -> V=1.0, theta=0.0
% INFO    : Bus 67466	: V=1.0040942, theta=-106.824244 -> V=1.0, theta=0.0
% INFO    : Bus 67467	: V=1.0049246, theta=-107.148101 -> V=1.0, theta=0.0
% INFO    : Bus 67468	: V=1.0052797, theta=-107.346097 -> V=1.0, theta=0.0
% INFO    : Bus 67469	: V=1.0043223, theta=-107.170611 -> V=1.0, theta=0.0
% INFO    : Bus 67470	: V=1.0066818, theta=-107.768821 -> V=1.0, theta=0.0
% INFO    : Bus 67471	: V=1.0099312, theta=-107.010127 -> V=1.0, theta=0.0
% INFO    : Bus 67472	: V=1.005795, theta=-107.120221 -> V=1.0, theta=0.0
% INFO    : Bus 67473	: V=1.0064205, theta=-107.108199 -> V=1.0, theta=0.0
% INFO    : Bus 67474	: V=1.01065, theta=-106.632933 -> V=1.0, theta=0.0
% INFO    : Bus 67475	: V=1.0065256, theta=-107.15038 -> V=1.0, theta=0.0
% INFO    : Bus 67476	: V=1.0082528, theta=-107.009501 -> V=1.0, theta=0.0
% INFO    : Bus 67477	: V=1.009075, theta=-106.925998 -> V=1.0, theta=0.0
% INFO    : Bus 67478	: V=1.0065763, theta=-107.174197 -> V=1.0, theta=0.0
% INFO    : Bus 67479	: V=1.0067215, theta=-107.180222 -> V=1.0, theta=0.0
% INFO    : Bus 67480	: V=1.0102055, theta=-106.807472 -> V=1.0, theta=0.0
% INFO    : Bus 67481	: V=1.0099983, theta=-106.827846 -> V=1.0, theta=0.0
% INFO    : Bus 67482	: V=1.0075237, theta=-107.15921 -> V=1.0, theta=0.0
% INFO    : Bus 67483	: V=1.0070525, theta=-107.17833 -> V=1.0, theta=0.0
% INFO    : Bus 67484	: V=1.0101061, theta=-107.003619 -> V=1.0, theta=0.0
% INFO    : Bus 67485	: V=1.0102329, theta=-106.940286 -> V=1.0, theta=0.0
% INFO    : Bus 67486	: V=1.0096386, theta=-106.83033 -> V=1.0, theta=0.0
% INFO    : Bus 67487	: V=1.010493, theta=-106.795873 -> V=1.0, theta=0.0
% INFO    : Bus 67488	: V=1.0106786, theta=-106.832635 -> V=1.0, theta=0.0
% INFO    : Bus 67489	: V=1.0110803, theta=-106.721522 -> V=1.0, theta=0.0
% INFO    : Bus 67490	: V=1.0113995, theta=-106.412586 -> V=1.0, theta=0.0
% INFO    : Bus 67491	: V=1.0118653, theta=-106.383518 -> V=1.0, theta=0.0
% INFO    : Bus 67492	: V=1.0295378, theta=-103.12809 -> V=1.0, theta=0.0
% INFO    : Bus 67493	: V=1.0114024, theta=-106.410054 -> V=1.0, theta=0.0
% INFO    : Bus 67494	: V=1.0104729, theta=-107.045801 -> V=1.0, theta=0.0
% INFO    : Bus 67495	: V=1.010293, theta=-106.927699 -> V=1.0, theta=0.0
% INFO    : Bus 67496	: V=1.0086701, theta=-108.275033 -> V=1.0, theta=0.0
% INFO    : Bus 67497	: V=1.009204, theta=-108.446019 -> V=1.0, theta=0.0
% INFO    : Bus 67498	: V=1.0099455, theta=-107.082239 -> V=1.0, theta=0.0
% INFO    : Bus 67499	: V=1.0096805, theta=-107.209159 -> V=1.0, theta=0.0
% INFO    : Bus 67500	: V=1.0098385, theta=-107.134351 -> V=1.0, theta=0.0
% INFO    : Bus 67501	: V=1.0098919, theta=-107.406676 -> V=1.0, theta=0.0
% INFO    : Bus 67502	: V=1.009701, theta=-107.537303 -> V=1.0, theta=0.0
% INFO    : Bus 67503	: V=1.0095561, theta=-107.669963 -> V=1.0, theta=0.0
% INFO    : Bus 67504	: V=1.0098608, theta=-108.610383 -> V=1.0, theta=0.0
% INFO    : Bus 67505	: V=1.0095728, theta=-107.769357 -> V=1.0, theta=0.0
% INFO    : Bus 67506	: V=1.0103072, theta=-108.583213 -> V=1.0, theta=0.0
% INFO    : Bus 67507	: V=1.0098212, theta=-108.659639 -> V=1.0, theta=0.0
% INFO    : Bus 67508	: V=1.0098819, theta=-108.709681 -> V=1.0, theta=0.0
% INFO    : Bus 67509	: V=1.0097329, theta=-108.715735 -> V=1.0, theta=0.0
% INFO    : Bus 67510	: V=1.0070445, theta=-107.252559 -> V=1.0, theta=0.0
% INFO    : Bus 67511	: V=1.0068011, theta=-105.228754 -> V=1.0, theta=0.0
% INFO    : Bus 67512	: V=0.9901352, theta=-59.504398 -> V=1.0, theta=0.0
% INFO    : Bus 67513	: V=0.9926587, theta=-58.986451 -> V=1.0, theta=0.0
% INFO    : Bus 67514	: V=0.9908185, theta=-59.452663 -> V=1.0, theta=0.0
% INFO    : Bus 67515	: V=0.9909718, theta=-59.177165 -> V=1.0, theta=0.0
% INFO    : Bus 67516	: V=0.9906113, theta=-58.747696 -> V=1.0, theta=0.0
% INFO    : Bus 67517	: V=0.9956079, theta=-61.867089 -> V=1.0, theta=0.0
% INFO    : Bus 67518	: V=0.9961084, theta=-62.012515 -> V=1.0, theta=0.0
% INFO    : Bus 67519	: V=0.9907996, theta=-81.249738 -> V=1.0, theta=0.0
% INFO    : Bus 67520	: V=0.985962, theta=-81.479724 -> V=1.0, theta=0.0
% INFO    : Bus 67521	: V=0.9855448, theta=-81.487852 -> V=1.0, theta=0.0
% INFO    : Bus 67522	: V=0.9862992, theta=-81.863976 -> V=1.0, theta=0.0
% INFO    : Bus 67523	: V=0.9926662, theta=-81.836389 -> V=1.0, theta=0.0
% INFO    : Bus 67524	: V=0.9873439, theta=-82.469242 -> V=1.0, theta=0.0
% INFO    : Bus 67525	: V=0.9865468, theta=-81.464159 -> V=1.0, theta=0.0
% INFO    : Bus 67526	: V=0.9926168, theta=-81.896446 -> V=1.0, theta=0.0
% INFO    : Bus 67527	: V=0.9989132, theta=-92.812611 -> V=1.0, theta=0.0
% INFO    : Bus 67528	: V=0.9934307, theta=-92.788326 -> V=1.0, theta=0.0
% INFO    : Bus 67529	: V=1.0003391, theta=-84.366607 -> V=1.0, theta=0.0
% INFO    : Bus 67530	: V=1.0033006, theta=-95.69336 -> V=1.0, theta=0.0
% INFO    : Bus 67531	: V=0.9964303, theta=-95.37354 -> V=1.0, theta=0.0
% INFO    : Bus 67532	: V=1.0050167, theta=-95.562151 -> V=1.0, theta=0.0
% INFO    : Bus 67533	: V=1.0052249, theta=-95.096817 -> V=1.0, theta=0.0
% INFO    : Bus 67534	: V=1.0051231, theta=-94.500854 -> V=1.0, theta=0.0
% INFO    : Bus 67535	: V=1.0027022, theta=-93.968516 -> V=1.0, theta=0.0
% INFO    : Bus 67536	: V=1.0055534, theta=-92.680267 -> V=1.0, theta=0.0
% INFO    : Bus 67537	: V=1.0036285, theta=-92.672163 -> V=1.0, theta=0.0
% INFO    : Bus 67538	: V=1.0052603, theta=-94.264232 -> V=1.0, theta=0.0
% INFO    : Bus 67539	: V=1.0051031, theta=-93.576624 -> V=1.0, theta=0.0
% INFO    : Bus 67540	: V=1.0048608, theta=-93.878783 -> V=1.0, theta=0.0
% INFO    : Bus 67541	: V=1.0054498, theta=-93.327937 -> V=1.0, theta=0.0
% INFO    : Bus 67542	: V=1.0045963, theta=-91.71652 -> V=1.0, theta=0.0
% INFO    : Bus 67543	: V=1.0063371, theta=-91.132518 -> V=1.0, theta=0.0
% INFO    : Bus 67544	: V=1.0076759, theta=-90.488079 -> V=1.0, theta=0.0
% INFO    : Bus 67545	: V=1.0136283, theta=-90.286711 -> V=1.0, theta=0.0
% INFO    : Bus 67546	: V=1.0059566, theta=-90.123581 -> V=1.0, theta=0.0
% INFO    : Bus 67547	: V=0.9982761, theta=-87.975969 -> V=1.0, theta=0.0
% INFO    : Bus 67548	: V=0.9998966, theta=-86.637783 -> V=1.0, theta=0.0
% INFO    : Bus 67549	: V=0.9969747, theta=-88.767881 -> V=1.0, theta=0.0
% INFO    : Bus 67550	: V=0.9972274, theta=-88.908768 -> V=1.0, theta=0.0
% INFO    : Bus 67551	: V=0.9987537, theta=-86.659515 -> V=1.0, theta=0.0
% INFO    : Bus 67552	: V=0.9976419, theta=-87.272307 -> V=1.0, theta=0.0
% INFO    : Bus 67553	: V=1.000549, theta=-90.837744 -> V=1.0, theta=0.0
% INFO    : Bus 67554	: V=1.0012178, theta=-92.78592 -> V=1.0, theta=0.0
% INFO    : Bus 67555	: V=0.9984173, theta=-90.084612 -> V=1.0, theta=0.0
% INFO    : Bus 67556	: V=0.9858657, theta=-81.474823 -> V=1.0, theta=0.0
% INFO    : Bus 67557	: V=1.0044765, theta=-95.701579 -> V=1.0, theta=0.0
% INFO    : Bus 67558	: V=1.0048912, theta=-94.793354 -> V=1.0, theta=0.0
% INFO    : Bus 67559	: V=0.9947061, theta=-85.841815 -> V=1.0, theta=0.0
% INFO    : Bus 67560	: V=0.988874, theta=-82.51116 -> V=1.0, theta=0.0
% INFO    : Bus 67561	: V=0.9915539, theta=-93.148954 -> V=1.0, theta=0.0
% INFO    : Bus 67562	: V=0.9919881, theta=-93.033827 -> V=1.0, theta=0.0
% INFO    : Bus 67563	: V=0.9922122, theta=-92.938109 -> V=1.0, theta=0.0
% INFO    : Bus 67564	: V=0.997021, theta=-91.109498 -> V=1.0, theta=0.0
% INFO    : Bus 67565	: V=0.9928288, theta=-92.874028 -> V=1.0, theta=0.0
% INFO    : Bus 67566	: V=0.992991, theta=-92.867929 -> V=1.0, theta=0.0
% INFO    : Bus 67567	: V=0.9918615, theta=-93.124708 -> V=1.0, theta=0.0
% INFO    : Bus 67568	: V=0.9866986, theta=-93.698919 -> V=1.0, theta=0.0
% INFO    : Bus 67569	: V=0.9914357, theta=-92.927252 -> V=1.0, theta=0.0
% INFO    : Bus 67570	: V=0.9917698, theta=-92.792738 -> V=1.0, theta=0.0
% INFO    : Bus 67571	: V=0.9923875, theta=-92.831142 -> V=1.0, theta=0.0
% INFO    : Bus 67572	: V=0.9910261, theta=-92.712481 -> V=1.0, theta=0.0
% INFO    : Bus 67573	: V=0.9969664, theta=-91.073994 -> V=1.0, theta=0.0
% INFO    : Bus 67574	: V=1.0001835, theta=-89.95856 -> V=1.0, theta=0.0
% INFO    : Bus 67575	: V=0.9975398, theta=-91.044757 -> V=1.0, theta=0.0
% INFO    : Bus 67576	: V=0.9953548, theta=-92.328381 -> V=1.0, theta=0.0
% INFO    : Bus 67577	: V=0.996117, theta=-92.253727 -> V=1.0, theta=0.0
% INFO    : Bus 67578	: V=0.9957304, theta=-92.146964 -> V=1.0, theta=0.0
% INFO    : Bus 67579	: V=0.993781, theta=-92.711256 -> V=1.0, theta=0.0
% INFO    : Bus 67580	: V=0.9936314, theta=-92.71814 -> V=1.0, theta=0.0
% INFO    : Bus 67581	: V=0.9924038, theta=-92.807096 -> V=1.0, theta=0.0
% INFO    : Bus 67582	: V=0.9959924, theta=-92.083143 -> V=1.0, theta=0.0
% INFO    : Bus 67583	: V=0.9907083, theta=-92.808944 -> V=1.0, theta=0.0
% INFO    : Bus 67584	: V=0.9912082, theta=-92.645299 -> V=1.0, theta=0.0
% INFO    : Bus 67585	: V=0.9936219, theta=-92.338922 -> V=1.0, theta=0.0
% INFO    : Bus 67586	: V=0.9946407, theta=-92.2466 -> V=1.0, theta=0.0
% INFO    : Bus 67587	: V=0.9980473, theta=-91.047941 -> V=1.0, theta=0.0
% INFO    : Bus 67588	: V=0.9963859, theta=-91.627326 -> V=1.0, theta=0.0
% INFO    : Bus 67589	: V=0.9925192, theta=-91.91297 -> V=1.0, theta=0.0
% INFO    : Bus 67590	: V=0.9909042, theta=-92.371724 -> V=1.0, theta=0.0
% INFO    : Bus 67591	: V=0.9888424, theta=-93.035882 -> V=1.0, theta=0.0
% INFO    : Bus 67592	: V=0.9877121, theta=-93.59494 -> V=1.0, theta=0.0
% INFO    : Bus 67593	: V=0.9887028, theta=-93.446683 -> V=1.0, theta=0.0
% INFO    : Bus 67594	: V=0.9898282, theta=-93.326492 -> V=1.0, theta=0.0
% INFO    : Bus 67595	: V=0.9914661, theta=-93.109211 -> V=1.0, theta=0.0
% INFO    : Bus 67596	: V=0.9893008, theta=-93.340331 -> V=1.0, theta=0.0
% INFO    : Bus 67597	: V=0.9919575, theta=-93.000769 -> V=1.0, theta=0.0
% INFO    : Bus 67598	: V=0.9924284, theta=-92.971185 -> V=1.0, theta=0.0
% INFO    : Bus 67599	: V=0.9932772, theta=-92.824266 -> V=1.0, theta=0.0
% INFO    : Bus 67600	: V=0.9940739, theta=-92.665221 -> V=1.0, theta=0.0
% INFO    : Bus 67601	: V=0.9944226, theta=-92.380767 -> V=1.0, theta=0.0
% INFO    : Bus 67602	: V=0.9948471, theta=-92.364873 -> V=1.0, theta=0.0
% INFO    : Bus 67603	: V=0.9917292, theta=-93.012788 -> V=1.0, theta=0.0
% INFO    : Bus 67604	: V=0.9933157, theta=-92.765537 -> V=1.0, theta=0.0
% INFO    : Bus 67605	: V=0.9926474, theta=-92.797034 -> V=1.0, theta=0.0
% INFO    : Bus 67606	: V=0.9921629, theta=-92.820041 -> V=1.0, theta=0.0
% INFO    : Bus 67607	: V=0.9918547, theta=-92.833366 -> V=1.0, theta=0.0
% INFO    : Bus 67608	: V=0.9919973, theta=-92.828556 -> V=1.0, theta=0.0
% INFO    : Bus 67609	: V=0.9913837, theta=-92.832348 -> V=1.0, theta=0.0
% INFO    : Bus 67610	: V=0.9912039, theta=-92.840635 -> V=1.0, theta=0.0
% INFO    : Bus 67611	: V=0.9865617, theta=-93.491228 -> V=1.0, theta=0.0
% INFO    : Bus 67612	: V=0.9860087, theta=-93.514057 -> V=1.0, theta=0.0
% INFO    : Bus 67613	: V=0.9927008, theta=-91.674671 -> V=1.0, theta=0.0
% INFO    : Bus 67614	: V=0.9892935, theta=-93.177313 -> V=1.0, theta=0.0
% INFO    : Bus 67615	: V=0.9901714, theta=-93.124345 -> V=1.0, theta=0.0
% INFO    : Bus 67616	: V=0.9902141, theta=-93.298405 -> V=1.0, theta=0.0
% INFO    : Bus 67617	: V=0.9908873, theta=-93.196634 -> V=1.0, theta=0.0
% INFO    : Bus 67618	: V=0.9883883, theta=-93.426559 -> V=1.0, theta=0.0
% INFO    : Bus 67619	: V=0.9898516, theta=-93.344642 -> V=1.0, theta=0.0
% INFO    : Bus 67620	: V=0.9892261, theta=-93.407171 -> V=1.0, theta=0.0
% INFO    : Bus 67621	: V=0.9849097, theta=-93.828105 -> V=1.0, theta=0.0
% INFO    : Bus 67622	: V=0.985204, theta=-93.814498 -> V=1.0, theta=0.0
% INFO    : Bus 67623	: V=0.9850707, theta=-93.814644 -> V=1.0, theta=0.0
% INFO    : Bus 67624	: V=0.9823176, theta=-94.074049 -> V=1.0, theta=0.0
% INFO    : Bus 67625	: V=0.9821534, theta=-94.212352 -> V=1.0, theta=0.0
% INFO    : Bus 67626	: V=0.986131, theta=-93.69705 -> V=1.0, theta=0.0
% INFO    : Bus 67627	: V=0.9852118, theta=-93.756391 -> V=1.0, theta=0.0
% INFO    : Bus 67628	: V=0.9826955, theta=-94.111479 -> V=1.0, theta=0.0
% INFO    : Bus 67629	: V=0.9833864, theta=-94.033192 -> V=1.0, theta=0.0
% INFO    : Bus 67630	: V=1.0025647, theta=-91.843562 -> V=1.0, theta=0.0
% INFO    : Bus 67631	: V=0.9968683, theta=-92.361248 -> V=1.0, theta=0.0
% INFO    : Bus 67632	: V=0.9938562, theta=-92.619543 -> V=1.0, theta=0.0
% INFO    : Bus 67633	: V=0.9883958, theta=-93.899537 -> V=1.0, theta=0.0
% INFO    : Bus 67634	: V=0.9833399, theta=-94.117677 -> V=1.0, theta=0.0
% INFO    : Bus 67635	: V=0.9814195, theta=-94.328817 -> V=1.0, theta=0.0
% INFO    : Bus 67636	: V=0.9837769, theta=-94.215181 -> V=1.0, theta=0.0
% INFO    : Bus 67637	: V=0.9831177, theta=-94.247378 -> V=1.0, theta=0.0
% INFO    : Bus 67638	: V=0.9824479, theta=-94.327485 -> V=1.0, theta=0.0
% INFO    : Bus 67639	: V=0.9818744, theta=-94.338605 -> V=1.0, theta=0.0
% INFO    : Bus 67640	: V=0.983926, theta=-94.095366 -> V=1.0, theta=0.0
% INFO    : Bus 67641	: V=0.98422, theta=-94.083074 -> V=1.0, theta=0.0
% INFO    : Bus 67642	: V=0.9821752, theta=-94.408185 -> V=1.0, theta=0.0
% INFO    : Bus 67643	: V=0.9820388, theta=-94.461555 -> V=1.0, theta=0.0
% INFO    : Bus 67644	: V=0.9859429, theta=-93.887338 -> V=1.0, theta=0.0
% INFO    : Bus 67645	: V=0.9858499, theta=-93.867447 -> V=1.0, theta=0.0
% INFO    : Bus 67646	: V=0.9849122, theta=-93.889869 -> V=1.0, theta=0.0
% INFO    : Bus 67647	: V=0.9912354, theta=-91.842971 -> V=1.0, theta=0.0
% INFO    : Bus 67648	: V=0.9904481, theta=-93.156407 -> V=1.0, theta=0.0
% INFO    : Bus 67649	: V=0.9896691, theta=-93.237446 -> V=1.0, theta=0.0
% INFO    : Bus 67650	: V=0.9889603, theta=-93.235928 -> V=1.0, theta=0.0
% INFO    : Bus 67651	: V=0.9904151, theta=-91.978039 -> V=1.0, theta=0.0
% INFO    : Bus 67652	: V=0.9869453, theta=-93.686956 -> V=1.0, theta=0.0
% INFO    : Bus 67653	: V=0.9886705, theta=-93.45639 -> V=1.0, theta=0.0
% INFO    : Bus 67654	: V=0.9872628, theta=-93.627461 -> V=1.0, theta=0.0
% INFO    : Bus 67655	: V=0.9862765, theta=-93.752221 -> V=1.0, theta=0.0
% INFO    : Bus 67656	: V=0.9841127, theta=-93.973785 -> V=1.0, theta=0.0
% INFO    : Bus 67657	: V=0.9861476, theta=-93.71302 -> V=1.0, theta=0.0
% INFO    : Bus 67658	: V=0.9836251, theta=-94.026421 -> V=1.0, theta=0.0
% INFO    : Bus 67659	: V=0.9839058, theta=-93.966002 -> V=1.0, theta=0.0
% INFO    : Bus 67660	: V=0.9843507, theta=-93.907765 -> V=1.0, theta=0.0
% INFO    : Bus 67661	: V=0.9863891, theta=-93.687622 -> V=1.0, theta=0.0
% INFO    : Bus 67662	: V=0.985778, theta=-93.749102 -> V=1.0, theta=0.0
% INFO    : Bus 67663	: V=0.9872011, theta=-93.591774 -> V=1.0, theta=0.0
% INFO    : Bus 67664	: V=0.9862889, theta=-93.691448 -> V=1.0, theta=0.0
% INFO    : Bus 67665	: V=0.9865103, theta=-93.697833 -> V=1.0, theta=0.0
% INFO    : Bus 67666	: V=0.9879628, theta=-93.482149 -> V=1.0, theta=0.0
% INFO    : Bus 67667	: V=0.9888984, theta=-93.226291 -> V=1.0, theta=0.0
% INFO    : Bus 67668	: V=0.9896284, theta=-93.322463 -> V=1.0, theta=0.0
% INFO    : Bus 67669	: V=0.9865325, theta=-93.593391 -> V=1.0, theta=0.0
% INFO    : Bus 67670	: V=0.9870377, theta=-93.57432 -> V=1.0, theta=0.0
% INFO    : Bus 67671	: V=0.9873739, theta=-93.561997 -> V=1.0, theta=0.0
% INFO    : Bus 67672	: V=0.9890693, theta=-93.255743 -> V=1.0, theta=0.0
% INFO    : Bus 67673	: V=0.9889553, theta=-93.248068 -> V=1.0, theta=0.0
% INFO    : Bus 67674	: V=0.9879385, theta=-93.521777 -> V=1.0, theta=0.0
% INFO    : Bus 67675	: V=0.9888892, theta=-93.446926 -> V=1.0, theta=0.0
% INFO    : Bus 67676	: V=0.9891677, theta=-93.381497 -> V=1.0, theta=0.0
% INFO    : Bus 67677	: V=0.9912099, theta=-91.823976 -> V=1.0, theta=0.0
% INFO    : Bus 67678	: V=0.989464, theta=-93.246407 -> V=1.0, theta=0.0
% INFO    : Bus 67679	: V=0.9885019, theta=-93.450408 -> V=1.0, theta=0.0
% INFO    : Bus 67680	: V=0.9878963, theta=-93.55186 -> V=1.0, theta=0.0
% INFO    : Bus 67681	: V=0.9920944, theta=-91.908756 -> V=1.0, theta=0.0
% INFO    : Bus 67682	: V=0.9934825, theta=-91.723191 -> V=1.0, theta=0.0
% INFO    : Bus 67683	: V=0.9925458, theta=-91.764446 -> V=1.0, theta=0.0
% INFO    : Bus 67684	: V=0.9906269, theta=-93.077346 -> V=1.0, theta=0.0
% INFO    : Bus 67685	: V=0.9918929, theta=-91.817719 -> V=1.0, theta=0.0
% INFO    : Bus 67686	: V=0.99135, theta=-91.836263 -> V=1.0, theta=0.0
% INFO    : Bus 67687	: V=0.9910778, theta=-91.864661 -> V=1.0, theta=0.0
% INFO    : Bus 67688	: V=0.9905972, theta=-93.090847 -> V=1.0, theta=0.0
% INFO    : Bus 67689	: V=0.9911619, theta=-92.99293 -> V=1.0, theta=0.0
% INFO    : Bus 67690	: V=0.990473, theta=-93.09212 -> V=1.0, theta=0.0
% INFO    : Bus 67691	: V=1.0100004, theta=-88.487384 -> V=1.0, theta=0.0
% INFO    : Bus 67692	: V=0.9914532, theta=-93.046229 -> V=1.0, theta=0.0
% INFO    : Bus 67693	: V=0.9921767, theta=-92.814486 -> V=1.0, theta=0.0
% INFO    : Bus 67694	: V=0.9895383, theta=-93.135595 -> V=1.0, theta=0.0
% INFO    : Bus 67695	: V=0.98991, theta=-93.11998 -> V=1.0, theta=0.0
% INFO    : Bus 67696	: V=0.9960062, theta=-91.297411 -> V=1.0, theta=0.0
% INFO    : Bus 67697	: V=0.9915561, theta=-93.005317 -> V=1.0, theta=0.0
% INFO    : Bus 67698	: V=0.9917596, theta=-92.86683 -> V=1.0, theta=0.0
% INFO    : Bus 67699	: V=0.9883474, theta=-93.365158 -> V=1.0, theta=0.0
% INFO    : Bus 67700	: V=0.9894415, theta=-93.287035 -> V=1.0, theta=0.0
% INFO    : Bus 67701	: V=0.9885327, theta=-93.340816 -> V=1.0, theta=0.0
% INFO    : Bus 67702	: V=0.9875622, theta=-93.395515 -> V=1.0, theta=0.0
% INFO    : Bus 67703	: V=0.9870902, theta=-93.437075 -> V=1.0, theta=0.0
% INFO    : Bus 67704	: V=0.9891315, theta=-93.276625 -> V=1.0, theta=0.0
% INFO    : Bus 67705	: V=0.9884075, theta=-93.352302 -> V=1.0, theta=0.0
% INFO    : Bus 67706	: V=0.9884198, theta=-93.265917 -> V=1.0, theta=0.0
% INFO    : Bus 67707	: V=0.9881489, theta=-93.36132 -> V=1.0, theta=0.0
% INFO    : Bus 67708	: V=0.987108, theta=-93.517147 -> V=1.0, theta=0.0
% INFO    : Bus 67709	: V=0.9864022, theta=-93.543951 -> V=1.0, theta=0.0
% INFO    : Bus 67710	: V=0.9879577, theta=-93.419696 -> V=1.0, theta=0.0
% INFO    : Bus 67711	: V=0.9888038, theta=-93.122061 -> V=1.0, theta=0.0
% INFO    : Bus 67712	: V=0.9921239, theta=-92.402656 -> V=1.0, theta=0.0
% INFO    : Bus 67713	: V=0.9928088, theta=-92.357168 -> V=1.0, theta=0.0
% INFO    : Bus 67714	: V=0.9980983, theta=-91.640208 -> V=1.0, theta=0.0
% INFO    : Bus 67715	: V=0.9881373, theta=-93.362586 -> V=1.0, theta=0.0
% INFO    : Bus 67716	: V=0.9867999, theta=-93.419959 -> V=1.0, theta=0.0
% INFO    : Bus 67717	: V=0.9863289, theta=-93.441929 -> V=1.0, theta=0.0
% INFO    : Bus 67718	: V=0.9897577, theta=-92.910675 -> V=1.0, theta=0.0
% INFO    : Bus 67719	: V=0.9958304, theta=-92.120041 -> V=1.0, theta=0.0
% INFO    : Bus 67720	: V=1.0005315, theta=-91.869841 -> V=1.0, theta=0.0
% INFO    : Bus 67721	: V=1.0025707, theta=-92.066311 -> V=1.0, theta=0.0
% INFO    : Bus 67722	: V=0.9978137, theta=-91.733607 -> V=1.0, theta=0.0
% INFO    : Bus 67723	: V=0.9955155, theta=-89.455055 -> V=1.0, theta=0.0
% INFO    : Bus 67724	: V=1.0093019, theta=-82.154923 -> V=1.0, theta=0.0
% INFO    : Bus 67725	: V=1.0033392, theta=-83.893204 -> V=1.0, theta=0.0
% INFO    : Bus 67726	: V=1.0150572, theta=-87.619703 -> V=1.0, theta=0.0
% INFO    : Bus 67727	: V=1.0100004, theta=-86.532716 -> V=1.0, theta=0.0
% INFO    : Bus 67728	: V=0.9827302, theta=-91.162276 -> V=1.0, theta=0.0
% INFO    : Bus 67729	: V=0.9806615, theta=-91.242457 -> V=1.0, theta=0.0
% INFO    : Bus 67730	: V=0.9914842, theta=-89.786151 -> V=1.0, theta=0.0
% INFO    : Bus 67731	: V=0.9850504, theta=-90.776479 -> V=1.0, theta=0.0
% INFO    : Bus 67732	: V=0.9857933, theta=-90.748154 -> V=1.0, theta=0.0
% INFO    : Bus 67733	: V=0.9855007, theta=-90.892363 -> V=1.0, theta=0.0
% INFO    : Bus 67734	: V=0.9860932, theta=-91.140052 -> V=1.0, theta=0.0
% INFO    : Bus 67735	: V=0.9942978, theta=-91.661045 -> V=1.0, theta=0.0
% INFO    : Bus 67736	: V=0.9792364, theta=-91.929586 -> V=1.0, theta=0.0
% INFO    : Bus 67737	: V=0.9768306, theta=-91.933489 -> V=1.0, theta=0.0
% INFO    : Bus 67738	: V=0.9804753, theta=-91.925425 -> V=1.0, theta=0.0
% INFO    : Bus 67739	: V=0.9814807, theta=-91.620747 -> V=1.0, theta=0.0
% INFO    : Bus 67740	: V=0.9908141, theta=-90.157299 -> V=1.0, theta=0.0
% INFO    : Bus 67741	: V=0.9838794, theta=-90.973928 -> V=1.0, theta=0.0
% INFO    : Bus 67742	: V=0.9809982, theta=-91.884337 -> V=1.0, theta=0.0
% INFO    : Bus 67743	: V=0.9786998, theta=-91.880834 -> V=1.0, theta=0.0
% INFO    : Bus 67744	: V=0.9779313, theta=-90.639111 -> V=1.0, theta=0.0
% INFO    : Bus 67745	: V=0.9890121, theta=-88.960517 -> V=1.0, theta=0.0
% INFO    : Bus 67746	: V=0.9780337, theta=-90.514768 -> V=1.0, theta=0.0
% INFO    : Bus 67747	: V=0.9972728, theta=-85.4256 -> V=1.0, theta=0.0
% INFO    : Bus 67748	: V=0.9983787, theta=-87.435358 -> V=1.0, theta=0.0
% INFO    : Bus 67749	: V=0.9905185, theta=-85.541704 -> V=1.0, theta=0.0
% INFO    : Bus 67750	: V=0.98583, theta=-86.033565 -> V=1.0, theta=0.0
% INFO    : Bus 67751	: V=0.9853318, theta=-86.044811 -> V=1.0, theta=0.0
% INFO    : Bus 67752	: V=0.9838371, theta=-85.990882 -> V=1.0, theta=0.0
% INFO    : Bus 67753	: V=1.0038984, theta=-89.150976 -> V=1.0, theta=0.0
% INFO    : Bus 67754	: V=1.001908, theta=-93.238088 -> V=1.0, theta=0.0
% INFO    : Bus 67755	: V=1.0319305, theta=-90.447705 -> V=1.0, theta=0.0
% INFO    : Bus 67756	: V=1.0037267, theta=-95.43059 -> V=1.0, theta=0.0
% INFO    : Bus 67757	: V=0.99128, theta=-95.546478 -> V=1.0, theta=0.0
% INFO    : Bus 67758	: V=0.9881131, theta=-91.328678 -> V=1.0, theta=0.0
% INFO    : Bus 67759	: V=0.9908333, theta=-91.515644 -> V=1.0, theta=0.0
% INFO    : Bus 67760	: V=1.0162065, theta=-84.499327 -> V=1.0, theta=0.0
% INFO    : Bus 67761	: V=1.0172004, theta=-83.999343 -> V=1.0, theta=0.0
% INFO    : Bus 67762	: V=1.0191518, theta=-84.16131 -> V=1.0, theta=0.0
% INFO    : Bus 67763	: V=1.0346458, theta=-82.195473 -> V=1.0, theta=0.0
% INFO    : Bus 67764	: V=1.0156033, theta=-84.501601 -> V=1.0, theta=0.0
% INFO    : Bus 67765	: V=1.0181396, theta=-84.780828 -> V=1.0, theta=0.0
% INFO    : Bus 67766	: V=1.0067444, theta=-67.476025 -> V=1.0, theta=0.0
% INFO    : Bus 67767	: V=1.0078758, theta=-66.268028 -> V=1.0, theta=0.0
% INFO    : Bus 67768	: V=1.0080482, theta=-67.339547 -> V=1.0, theta=0.0
% INFO    : Bus 67769	: V=1.0095794, theta=-66.896967 -> V=1.0, theta=0.0
% INFO    : Bus 67770	: V=1.0069263, theta=-67.014457 -> V=1.0, theta=0.0
% INFO    : Bus 67771	: V=1.0065516, theta=-67.144101 -> V=1.0, theta=0.0
% INFO    : Bus 67772	: V=1.0067518, theta=-67.631752 -> V=1.0, theta=0.0
% INFO    : Bus 67773	: V=1.0040321, theta=-67.937488 -> V=1.0, theta=0.0
% INFO    : Bus 67774	: V=0.9999936, theta=-68.272767 -> V=1.0, theta=0.0
% INFO    : Bus 67775	: V=1.0041413, theta=-68.099714 -> V=1.0, theta=0.0
% INFO    : Bus 67776	: V=1.0045335, theta=-67.924784 -> V=1.0, theta=0.0
% INFO    : Bus 67777	: V=1.0081141, theta=-69.85315 -> V=1.0, theta=0.0
% INFO    : Bus 67778	: V=1.0049414, theta=-67.662628 -> V=1.0, theta=0.0
% INFO    : Bus 67779	: V=1.0074154, theta=-69.457919 -> V=1.0, theta=0.0
% INFO    : Bus 67780	: V=0.9990539, theta=-65.923545 -> V=1.0, theta=0.0
% INFO    : Bus 67781	: V=1.0027679, theta=-68.472904 -> V=1.0, theta=0.0
% INFO    : Bus 67782	: V=1.0054208, theta=-67.392919 -> V=1.0, theta=0.0
% INFO    : Bus 67783	: V=1.0049277, theta=-66.08114 -> V=1.0, theta=0.0
% INFO    : Bus 67784	: V=1.0057985, theta=-67.449313 -> V=1.0, theta=0.0
% INFO    : Bus 67785	: V=1.0095329, theta=-68.305797 -> V=1.0, theta=0.0
% INFO    : Bus 67786	: V=1.00882, theta=-68.001628 -> V=1.0, theta=0.0
% INFO    : Bus 67787	: V=1.0036245, theta=-69.569951 -> V=1.0, theta=0.0
% INFO    : Bus 67788	: V=1.0004587, theta=-70.507036 -> V=1.0, theta=0.0
% INFO    : Bus 67789	: V=1.0037097, theta=-72.294515 -> V=1.0, theta=0.0
% INFO    : Bus 67790	: V=1.0004366, theta=-71.015063 -> V=1.0, theta=0.0
% INFO    : Bus 67791	: V=1.0007579, theta=-72.434016 -> V=1.0, theta=0.0
% INFO    : Bus 67792	: V=0.9987113, theta=-72.528453 -> V=1.0, theta=0.0
% INFO    : Bus 67793	: V=1.0020681, theta=-75.424226 -> V=1.0, theta=0.0
% INFO    : Bus 67794	: V=1.0054239, theta=-74.51763 -> V=1.0, theta=0.0
% INFO    : Bus 67795	: V=1.0042062, theta=-68.832371 -> V=1.0, theta=0.0
% INFO    : Bus 67796	: V=0.9990974, theta=-30.478794 -> V=1.0, theta=0.0
% INFO    : Bus 67797	: V=1.0018558, theta=-29.915867 -> V=1.0, theta=0.0
% INFO    : Bus 67798	: V=1.0075173, theta=-27.882603 -> V=1.0, theta=0.0
% INFO    : Bus 67799	: V=1.0181137, theta=-28.802716 -> V=1.0, theta=0.0
% INFO    : Bus 67800	: V=1.0187523, theta=-28.732933 -> V=1.0, theta=0.0
% INFO    : Bus 67801	: V=1.0189524, theta=-28.647678 -> V=1.0, theta=0.0
% INFO    : Bus 67802	: V=1.0226202, theta=-28.672511 -> V=1.0, theta=0.0
% INFO    : Bus 67803	: V=1.0197841, theta=-28.789667 -> V=1.0, theta=0.0
% INFO    : Bus 67804	: V=1.0134753, theta=-26.012004 -> V=1.0, theta=0.0
% INFO    : Bus 67805	: V=1.0078715, theta=-27.703699 -> V=1.0, theta=0.0
% INFO    : Bus 67806	: V=1.0192779, theta=-29.391916 -> V=1.0, theta=0.0
% INFO    : Bus 67807	: V=1.0007975, theta=-31.005605 -> V=1.0, theta=0.0
% INFO    : Bus 67808	: V=1.0195942, theta=-29.468495 -> V=1.0, theta=0.0
% INFO    : Bus 67809	: V=1.0085189, theta=-30.727473 -> V=1.0, theta=0.0
% INFO    : Bus 67810	: V=1.0082196, theta=-29.498203 -> V=1.0, theta=0.0
% INFO    : Bus 67811	: V=1.0083594, theta=-30.352236 -> V=1.0, theta=0.0
% INFO    : Bus 67812	: V=1.0080791, theta=-30.601031 -> V=1.0, theta=0.0
% INFO    : Bus 67813	: V=1.007121, theta=-30.46179 -> V=1.0, theta=0.0
% INFO    : Bus 67814	: V=1.0065556, theta=-30.318083 -> V=1.0, theta=0.0
% INFO    : Bus 67815	: V=1.0048157, theta=-30.363402 -> V=1.0, theta=0.0
% INFO    : Bus 67816	: V=1.0053166, theta=-30.358436 -> V=1.0, theta=0.0
% INFO    : Bus 67817	: V=1.0068565, theta=-30.128892 -> V=1.0, theta=0.0
% INFO    : Bus 67818	: V=0.9899185, theta=-29.609017 -> V=1.0, theta=0.0
% INFO    : Bus 67819	: V=0.9852504, theta=-29.779366 -> V=1.0, theta=0.0
% INFO    : Bus 67820	: V=0.9840214, theta=-29.804578 -> V=1.0, theta=0.0
% INFO    : Bus 67821	: V=0.9857344, theta=-29.772418 -> V=1.0, theta=0.0
% INFO    : Bus 67822	: V=0.9839551, theta=-29.776931 -> V=1.0, theta=0.0
% INFO    : Bus 67823	: V=0.9741699, theta=-40.55092 -> V=1.0, theta=0.0
% INFO    : Bus 67824	: V=0.9952764, theta=-34.885856 -> V=1.0, theta=0.0
% INFO    : Bus 67825	: V=0.9754967, theta=-26.025636 -> V=1.0, theta=0.0
% INFO    : Bus 67826	: V=0.9979787, theta=-20.226301 -> V=1.0, theta=0.0
% INFO    : Bus 67827	: V=0.9560899, theta=-65.841778 -> V=1.0, theta=0.0
% INFO    : Bus 67828	: V=0.9768161, theta=-74.868623 -> V=1.0, theta=0.0
% INFO    : Bus 67829	: V=0.9676375, theta=-71.858943 -> V=1.0, theta=0.0
% INFO    : Bus 67830	: V=0.9684263, theta=-71.848159 -> V=1.0, theta=0.0
% INFO    : Bus 67831	: V=0.965537, theta=-61.209564 -> V=1.0, theta=0.0
% INFO    : Bus 67832	: V=0.9972963, theta=-52.511409 -> V=1.0, theta=0.0
% INFO    : Bus 67833	: V=0.9927095, theta=-75.848598 -> V=1.0, theta=0.0
% INFO    : Bus 67834	: V=1.0092255, theta=-75.212579 -> V=1.0, theta=0.0
% INFO    : Bus 67835	: V=0.9996395, theta=-75.95021 -> V=1.0, theta=0.0
% INFO    : Bus 67836	: V=0.9990637, theta=-75.934422 -> V=1.0, theta=0.0
% INFO    : Bus 67837	: V=1.0021276, theta=-76.05472 -> V=1.0, theta=0.0
% INFO    : Bus 67838	: V=0.9849475, theta=-76.298002 -> V=1.0, theta=0.0
% INFO    : Bus 67839	: V=0.9884601, theta=-76.228369 -> V=1.0, theta=0.0
% INFO    : Bus 67840	: V=0.9871724, theta=-76.340109 -> V=1.0, theta=0.0
% INFO    : Bus 67841	: V=0.9884074, theta=-76.606847 -> V=1.0, theta=0.0
% INFO    : Bus 67842	: V=1.0300003, theta=-76.885141 -> V=1.0, theta=0.0
% INFO    : Bus 67843	: V=0.9968007, theta=-76.039836 -> V=1.0, theta=0.0
% INFO    : Bus 67844	: V=1.0043095, theta=-75.815908 -> V=1.0, theta=0.0
% INFO    : Bus 67845	: V=1.000766, theta=-75.835196 -> V=1.0, theta=0.0
% INFO    : Bus 67846	: V=0.9998976, theta=-75.864486 -> V=1.0, theta=0.0
% INFO    : Bus 67847	: V=0.999447, theta=-75.875336 -> V=1.0, theta=0.0
% INFO    : Bus 67848	: V=0.993811, theta=-75.983237 -> V=1.0, theta=0.0
% INFO    : Bus 67849	: V=0.9932828, theta=-76.045735 -> V=1.0, theta=0.0
% INFO    : Bus 67850	: V=0.9954319, theta=-76.001493 -> V=1.0, theta=0.0
% INFO    : Bus 67851	: V=0.9934878, theta=-75.90786 -> V=1.0, theta=0.0
% INFO    : Bus 67852	: V=0.999173, theta=-75.869304 -> V=1.0, theta=0.0
% INFO    : Bus 67853	: V=0.9969714, theta=-75.950242 -> V=1.0, theta=0.0
% INFO    : Bus 67854	: V=1.0016432, theta=-75.773352 -> V=1.0, theta=0.0
% INFO    : Bus 67855	: V=0.995096, theta=-75.321077 -> V=1.0, theta=0.0
% INFO    : Bus 67856	: V=0.992622, theta=-75.826165 -> V=1.0, theta=0.0
% INFO    : Bus 67857	: V=0.9904809, theta=-75.994305 -> V=1.0, theta=0.0
% INFO    : Bus 67858	: V=0.9928566, theta=-76.046001 -> V=1.0, theta=0.0
% INFO    : Bus 67859	: V=0.9946388, theta=-76.001202 -> V=1.0, theta=0.0
% INFO    : Bus 67860	: V=0.9935267, theta=-76.135785 -> V=1.0, theta=0.0
% INFO    : Bus 67861	: V=0.9945293, theta=-76.125428 -> V=1.0, theta=0.0
% INFO    : Bus 67862	: V=0.9957478, theta=-75.996277 -> V=1.0, theta=0.0
% INFO    : Bus 67863	: V=0.9935484, theta=-76.189279 -> V=1.0, theta=0.0
% INFO    : Bus 67864	: V=1.0105209, theta=-74.773458 -> V=1.0, theta=0.0
% INFO    : Bus 67865	: V=1.0016316, theta=-76.098036 -> V=1.0, theta=0.0
% INFO    : Bus 67866	: V=0.9883678, theta=-76.629718 -> V=1.0, theta=0.0
% INFO    : Bus 67867	: V=0.9976175, theta=-76.359498 -> V=1.0, theta=0.0
% INFO    : Bus 67868	: V=0.9905894, theta=-76.526933 -> V=1.0, theta=0.0
% INFO    : Bus 67869	: V=0.9925301, theta=-76.422111 -> V=1.0, theta=0.0
% INFO    : Bus 67870	: V=1.0001218, theta=-76.054738 -> V=1.0, theta=0.0
% INFO    : Bus 67871	: V=0.9910976, theta=-76.405702 -> V=1.0, theta=0.0
% INFO    : Bus 67872	: V=0.9918748, theta=-76.327358 -> V=1.0, theta=0.0
% INFO    : Bus 67873	: V=0.9890553, theta=-76.093634 -> V=1.0, theta=0.0
% INFO    : Bus 67874	: V=0.9924277, theta=-76.227507 -> V=1.0, theta=0.0
% INFO    : Bus 67875	: V=0.9871635, theta=-76.404904 -> V=1.0, theta=0.0
% INFO    : Bus 67876	: V=0.9870396, theta=-76.620746 -> V=1.0, theta=0.0
% INFO    : Bus 67877	: V=0.9985996, theta=-76.105359 -> V=1.0, theta=0.0
% INFO    : Bus 67878	: V=0.9910265, theta=-76.441962 -> V=1.0, theta=0.0
% INFO    : Bus 67879	: V=0.98674, theta=-76.698289 -> V=1.0, theta=0.0
% INFO    : Bus 67880	: V=0.9822771, theta=-77.019577 -> V=1.0, theta=0.0
% INFO    : Bus 67881	: V=0.986162, theta=-76.706654 -> V=1.0, theta=0.0
% INFO    : Bus 67882	: V=0.9789839, theta=-77.107364 -> V=1.0, theta=0.0
% INFO    : Bus 67883	: V=0.9813185, theta=-77.017203 -> V=1.0, theta=0.0
% INFO    : Bus 67884	: V=0.9878917, theta=-76.677308 -> V=1.0, theta=0.0
% INFO    : Bus 67885	: V=0.995233, theta=-76.355882 -> V=1.0, theta=0.0
% INFO    : Bus 67886	: V=0.9946442, theta=-76.349546 -> V=1.0, theta=0.0
% INFO    : Bus 67887	: V=0.994145, theta=-76.335809 -> V=1.0, theta=0.0
% INFO    : Bus 67888	: V=0.9825361, theta=-77.036849 -> V=1.0, theta=0.0
% INFO    : Bus 67889	: V=0.9816302, theta=-77.070113 -> V=1.0, theta=0.0
% INFO    : Bus 67890	: V=0.9800371, theta=-77.088957 -> V=1.0, theta=0.0
% INFO    : Bus 67891	: V=0.9806361, theta=-77.090104 -> V=1.0, theta=0.0
% INFO    : Bus 67892	: V=0.9713147, theta=-77.599795 -> V=1.0, theta=0.0
% INFO    : Bus 67893	: V=0.9727469, theta=-77.58745 -> V=1.0, theta=0.0
% INFO    : Bus 67894	: V=0.9872174, theta=-76.731035 -> V=1.0, theta=0.0
% INFO    : Bus 67895	: V=0.9972912, theta=-76.14923 -> V=1.0, theta=0.0
% INFO    : Bus 67896	: V=0.9851378, theta=-76.783936 -> V=1.0, theta=0.0
% INFO    : Bus 67897	: V=0.9938399, theta=-76.304419 -> V=1.0, theta=0.0
% INFO    : Bus 67898	: V=0.9943958, theta=-76.257218 -> V=1.0, theta=0.0
% INFO    : Bus 67899	: V=0.9938038, theta=-76.279073 -> V=1.0, theta=0.0
% INFO    : Bus 67900	: V=0.9856503, theta=-76.878753 -> V=1.0, theta=0.0
% INFO    : Bus 67901	: V=0.9963744, theta=-76.171566 -> V=1.0, theta=0.0
% INFO    : Bus 67902	: V=0.9955755, theta=-76.18474 -> V=1.0, theta=0.0
% INFO    : Bus 67903	: V=0.9734907, theta=-77.582968 -> V=1.0, theta=0.0
% INFO    : Bus 67904	: V=0.9940622, theta=-76.257574 -> V=1.0, theta=0.0
% INFO    : Bus 67905	: V=0.9956288, theta=-76.163731 -> V=1.0, theta=0.0
% INFO    : Bus 67906	: V=0.9860054, theta=-76.392928 -> V=1.0, theta=0.0
% INFO    : Bus 67907	: V=0.9968047, theta=-75.812006 -> V=1.0, theta=0.0
% INFO    : Bus 67908	: V=0.9830402, theta=-76.9486 -> V=1.0, theta=0.0
% INFO    : Bus 67909	: V=0.9943874, theta=-76.118716 -> V=1.0, theta=0.0
% INFO    : Bus 67910	: V=1.0280928, theta=-74.451582 -> V=1.0, theta=0.0
% INFO    : Bus 67911	: V=1.0147138, theta=-73.623447 -> V=1.0, theta=0.0
% INFO    : Bus 67912	: V=1.0165775, theta=-77.103712 -> V=1.0, theta=0.0
% INFO    : Bus 67913	: V=1.0121409, theta=-76.246167 -> V=1.0, theta=0.0
% INFO    : Bus 67914	: V=1.0206082, theta=-73.444475 -> V=1.0, theta=0.0
% INFO    : Bus 67915	: V=1.02019, theta=-72.973584 -> V=1.0, theta=0.0
% INFO    : Bus 67916	: V=1.0207726, theta=-73.619317 -> V=1.0, theta=0.0
% INFO    : Bus 67917	: V=1.004281, theta=-75.473429 -> V=1.0, theta=0.0
% INFO    : Bus 67918	: V=0.9776269, theta=-76.893461 -> V=1.0, theta=0.0
% INFO    : Bus 67919	: V=0.978663, theta=-76.733521 -> V=1.0, theta=0.0
% INFO    : Bus 67920	: V=0.9819767, theta=-76.508631 -> V=1.0, theta=0.0
% INFO    : Bus 67921	: V=0.9839902, theta=-76.479546 -> V=1.0, theta=0.0
% INFO    : Bus 67922	: V=0.9838542, theta=-76.812711 -> V=1.0, theta=0.0
% INFO    : Bus 67923	: V=0.9853901, theta=-76.753053 -> V=1.0, theta=0.0
% INFO    : Bus 67924	: V=0.9711118, theta=-76.84978 -> V=1.0, theta=0.0
% INFO    : Bus 67925	: V=0.9820862, theta=-76.836868 -> V=1.0, theta=0.0
% INFO    : Bus 67926	: V=0.9826468, theta=-76.828316 -> V=1.0, theta=0.0
% INFO    : Bus 67927	: V=0.9840121, theta=-76.663398 -> V=1.0, theta=0.0
% INFO    : Bus 67928	: V=0.9846489, theta=-76.502637 -> V=1.0, theta=0.0
% INFO    : Bus 67929	: V=0.9901467, theta=-76.573651 -> V=1.0, theta=0.0
% INFO    : Bus 67930	: V=0.9816364, theta=-76.878211 -> V=1.0, theta=0.0
% INFO    : Bus 67931	: V=0.9809195, theta=-76.995253 -> V=1.0, theta=0.0
% INFO    : Bus 67932	: V=0.9819542, theta=-77.0067 -> V=1.0, theta=0.0
% INFO    : Bus 67933	: V=0.9994935, theta=-76.593332 -> V=1.0, theta=0.0
% INFO    : Bus 67934	: V=0.9975303, theta=-77.648418 -> V=1.0, theta=0.0
% INFO    : Bus 67935	: V=0.9930549, theta=-77.634623 -> V=1.0, theta=0.0
% INFO    : Bus 67936	: V=0.9975751, theta=-77.862071 -> V=1.0, theta=0.0
% INFO    : Bus 67937	: V=0.9977533, theta=-77.971056 -> V=1.0, theta=0.0
% INFO    : Bus 67938	: V=0.9978792, theta=-77.178192 -> V=1.0, theta=0.0
% INFO    : Bus 67939	: V=0.9869275, theta=-81.189612 -> V=1.0, theta=0.0
% INFO    : Bus 67940	: V=0.9855913, theta=-81.275044 -> V=1.0, theta=0.0
% INFO    : Bus 67941	: V=0.9989338, theta=-79.724151 -> V=1.0, theta=0.0
% INFO    : Bus 67942	: V=0.9978195, theta=-79.759435 -> V=1.0, theta=0.0
% INFO    : Bus 67943	: V=0.9949194, theta=-80.660055 -> V=1.0, theta=0.0
% INFO    : Bus 67944	: V=0.9933385, theta=-81.196579 -> V=1.0, theta=0.0
% INFO    : Bus 67945	: V=0.9914523, theta=-81.60425 -> V=1.0, theta=0.0
% INFO    : Bus 67946	: V=0.9920698, theta=-81.421746 -> V=1.0, theta=0.0
% INFO    : Bus 67947	: V=0.9949811, theta=-80.825933 -> V=1.0, theta=0.0
% INFO    : Bus 67948	: V=0.9929861, theta=-81.215992 -> V=1.0, theta=0.0
% INFO    : Bus 67949	: V=1.0103285, theta=-75.303295 -> V=1.0, theta=0.0
% INFO    : Bus 67950	: V=1.0049909, theta=-73.331082 -> V=1.0, theta=0.0
% INFO    : Bus 67951	: V=1.0048619, theta=-66.918224 -> V=1.0, theta=0.0
% INFO    : Bus 67952	: V=1.0042898, theta=-66.485241 -> V=1.0, theta=0.0
% INFO    : Bus 67953	: V=0.9932778, theta=-71.820801 -> V=1.0, theta=0.0
% INFO    : Bus 67954	: V=0.9590888, theta=-60.096576 -> V=1.0, theta=0.0
% INFO    : Bus 67955	: V=0.9624681, theta=-61.353632 -> V=1.0, theta=0.0
% INFO    : Bus 67956	: V=0.962621, theta=-61.351996 -> V=1.0, theta=0.0
% INFO    : Bus 67957	: V=0.9645375, theta=-61.275481 -> V=1.0, theta=0.0
% INFO    : Bus 67958	: V=0.9681998, theta=-59.822842 -> V=1.0, theta=0.0
% INFO    : Bus 67959	: V=0.9741741, theta=-63.38178 -> V=1.0, theta=0.0
% INFO    : Bus 67960	: V=0.9974548, theta=-72.876379 -> V=1.0, theta=0.0
% INFO    : Bus 67961	: V=0.9873986, theta=-65.344179 -> V=1.0, theta=0.0
% INFO    : Bus 67962	: V=0.9889288, theta=-65.501645 -> V=1.0, theta=0.0
% INFO    : Bus 67963	: V=0.9980015, theta=-58.507857 -> V=1.0, theta=0.0
% INFO    : Bus 67964	: V=0.9879764, theta=-65.845929 -> V=1.0, theta=0.0
% INFO    : Bus 67965	: V=0.9955103, theta=-74.630587 -> V=1.0, theta=0.0
% INFO    : Bus 67966	: V=0.9936928, theta=-74.705401 -> V=1.0, theta=0.0
% INFO    : Bus 67967	: V=1.0085433, theta=-69.608519 -> V=1.0, theta=0.0
% INFO    : Bus 67968	: V=0.9901741, theta=-72.159757 -> V=1.0, theta=0.0
% INFO    : Bus 67969	: V=0.9981306, theta=-70.762485 -> V=1.0, theta=0.0
% INFO    : Bus 67970	: V=1.0007913, theta=-67.901988 -> V=1.0, theta=0.0
% INFO    : Bus 67971	: V=0.9935675, theta=-71.316023 -> V=1.0, theta=0.0
% INFO    : Bus 67972	: V=0.9924911, theta=-72.779122 -> V=1.0, theta=0.0
% INFO    : Bus 67973	: V=0.9957799, theta=-72.344868 -> V=1.0, theta=0.0
% INFO    : Bus 67974	: V=1.0002716, theta=-70.310487 -> V=1.0, theta=0.0
% INFO    : Bus 67975	: V=1.0081598, theta=-75.365204 -> V=1.0, theta=0.0
% INFO    : Bus 67976	: V=1.0115057, theta=-75.818872 -> V=1.0, theta=0.0
% INFO    : Bus 67977	: V=0.9802417, theta=-75.782879 -> V=1.0, theta=0.0
% INFO    : Bus 67978	: V=0.9769219, theta=-75.522865 -> V=1.0, theta=0.0
% INFO    : Bus 67979	: V=0.9787781, theta=-75.507509 -> V=1.0, theta=0.0
% INFO    : Bus 67980	: V=0.9942136, theta=-76.117754 -> V=1.0, theta=0.0
% INFO    : Bus 67981	: V=0.9947461, theta=-76.062194 -> V=1.0, theta=0.0
% INFO    : Bus 67982	: V=0.9914515, theta=-76.026485 -> V=1.0, theta=0.0
% INFO    : Bus 67983	: V=0.9875429, theta=-63.905565 -> V=1.0, theta=0.0
% INFO    : Bus 67984	: V=0.9800329, theta=-91.205395 -> V=1.0, theta=0.0
% INFO    : Bus 67985	: V=0.9781043, theta=-90.335083 -> V=1.0, theta=0.0
% INFO    : Bus 67986	: V=1.0074056, theta=-87.948264 -> V=1.0, theta=0.0
% INFO    : Bus 67987	: V=0.983665, theta=-89.214988 -> V=1.0, theta=0.0
% INFO    : Bus 67988	: V=0.9798513, theta=-90.147023 -> V=1.0, theta=0.0
% INFO    : Bus 67989	: V=0.9808914, theta=-89.701029 -> V=1.0, theta=0.0
% INFO    : Bus 67990	: V=0.9788334, theta=-89.728219 -> V=1.0, theta=0.0
% INFO    : Bus 67991	: V=0.978968, theta=-90.848879 -> V=1.0, theta=0.0
% INFO    : Bus 67992	: V=0.9810517, theta=-91.495619 -> V=1.0, theta=0.0
% INFO    : Bus 67993	: V=0.9815113, theta=-91.470703 -> V=1.0, theta=0.0
% INFO    : Bus 67994	: V=0.9819078, theta=-91.435804 -> V=1.0, theta=0.0
% INFO    : Bus 67995	: V=0.9826751, theta=-91.28609 -> V=1.0, theta=0.0
% INFO    : Bus 67996	: V=0.9834768, theta=-91.255281 -> V=1.0, theta=0.0
% INFO    : Bus 67997	: V=0.9821191, theta=-91.348353 -> V=1.0, theta=0.0
% INFO    : Bus 67998	: V=0.9789458, theta=-91.396321 -> V=1.0, theta=0.0
% INFO    : Bus 67999	: V=0.978039, theta=-91.481623 -> V=1.0, theta=0.0
% INFO    : Bus 68000	: V=0.9770306, theta=-91.52372 -> V=1.0, theta=0.0
% INFO    : Bus 68001	: V=0.9875262, theta=-91.038807 -> V=1.0, theta=0.0
% INFO    : Bus 68002	: V=0.9996436, theta=-88.925414 -> V=1.0, theta=0.0
% INFO    : Bus 68003	: V=0.9742281, theta=-91.910218 -> V=1.0, theta=0.0
% INFO    : Bus 68004	: V=0.9700601, theta=-92.082603 -> V=1.0, theta=0.0
% INFO    : Bus 68005	: V=0.9692918, theta=-92.172049 -> V=1.0, theta=0.0
% INFO    : Bus 68006	: V=0.9684196, theta=-92.208738 -> V=1.0, theta=0.0
% INFO    : Bus 68007	: V=0.9654331, theta=-91.203884 -> V=1.0, theta=0.0
% INFO    : Bus 68008	: V=0.9673533, theta=-91.9502 -> V=1.0, theta=0.0
% INFO    : Bus 68009	: V=0.9793766, theta=-84.323858 -> V=1.0, theta=0.0
% INFO    : Bus 68010	: V=0.9732812, theta=-84.164396 -> V=1.0, theta=0.0
% INFO    : Bus 68011	: V=1.005316, theta=-86.795784 -> V=1.0, theta=0.0
% INFO    : Bus 68012	: V=0.9977683, theta=-87.975198 -> V=1.0, theta=0.0
% INFO    : Bus 68013	: V=1.0069331, theta=-86.926972 -> V=1.0, theta=0.0
% INFO    : Bus 68014	: V=1.0105764, theta=-86.858419 -> V=1.0, theta=0.0
% INFO    : Bus 68015	: V=1.0072247, theta=-87.369383 -> V=1.0, theta=0.0
% INFO    : Bus 68016	: V=1.0070652, theta=-89.410131 -> V=1.0, theta=0.0
% INFO    : Bus 68017	: V=1.0037682, theta=-89.371273 -> V=1.0, theta=0.0
% INFO    : Bus 68018	: V=1.0036842, theta=-89.80552 -> V=1.0, theta=0.0
% INFO    : Bus 68019	: V=1.0046036, theta=-89.336768 -> V=1.0, theta=0.0
% INFO    : Bus 68020	: V=1.0051756, theta=-89.313238 -> V=1.0, theta=0.0
% INFO    : Bus 68021	: V=1.0001881, theta=-89.506213 -> V=1.0, theta=0.0
% INFO    : Bus 68022	: V=0.9999818, theta=-88.078482 -> V=1.0, theta=0.0
% INFO    : Bus 68023	: V=1.0102246, theta=-86.326766 -> V=1.0, theta=0.0
% INFO    : Bus 68024	: V=1.0011292, theta=-90.6965 -> V=1.0, theta=0.0
% INFO    : Bus 68025	: V=0.9993969, theta=-91.625327 -> V=1.0, theta=0.0
% INFO    : Bus 68026	: V=1.003023, theta=-72.358266 -> V=1.0, theta=0.0
% INFO    : Bus 68027	: V=1.0078686, theta=-74.417954 -> V=1.0, theta=0.0
% INFO    : Bus 68028	: V=1.0008425, theta=-77.239789 -> V=1.0, theta=0.0
% INFO    : Bus 68029	: V=1.000821, theta=-76.980542 -> V=1.0, theta=0.0
% INFO    : Bus 68030	: V=1.0067163, theta=-77.016807 -> V=1.0, theta=0.0
% INFO    : Bus 68031	: V=1.0053267, theta=-76.503665 -> V=1.0, theta=0.0
% INFO    : Bus 68032	: V=0.9919322, theta=-76.023066 -> V=1.0, theta=0.0
% INFO    : Bus 68033	: V=0.9973585, theta=-77.404631 -> V=1.0, theta=0.0
% INFO    : Bus 68034	: V=1.0012414, theta=-76.690762 -> V=1.0, theta=0.0
% INFO    : Bus 68035	: V=1.0095216, theta=-83.792412 -> V=1.0, theta=0.0
% INFO    : Bus 68036	: V=1.0092664, theta=-83.80302 -> V=1.0, theta=0.0
% INFO    : Bus 68037	: V=1.0081864, theta=-83.309104 -> V=1.0, theta=0.0
% INFO    : Bus 68038	: V=1.0093125, theta=-83.772179 -> V=1.0, theta=0.0
% INFO    : Bus 68039	: V=1.0078274, theta=-83.308198 -> V=1.0, theta=0.0
% INFO    : Bus 68040	: V=1.0096686, theta=-83.72611 -> V=1.0, theta=0.0
% INFO    : Bus 68041	: V=1.011561, theta=-83.588443 -> V=1.0, theta=0.0
% INFO    : Bus 68042	: V=1.0113103, theta=-83.57655 -> V=1.0, theta=0.0
% INFO    : Bus 68043	: V=1.0113663, theta=-83.56038 -> V=1.0, theta=0.0
% INFO    : Bus 68044	: V=1.0164532, theta=-83.408145 -> V=1.0, theta=0.0
% INFO    : Bus 68045	: V=1.0087543, theta=-83.260774 -> V=1.0, theta=0.0
% INFO    : Bus 68046	: V=1.0085638, theta=-83.291395 -> V=1.0, theta=0.0
% INFO    : Bus 68047	: V=1.0092417, theta=-83.175515 -> V=1.0, theta=0.0
% INFO    : Bus 68048	: V=1.0076978, theta=-82.950329 -> V=1.0, theta=0.0
% INFO    : Bus 68049	: V=1.0092423, theta=-83.844214 -> V=1.0, theta=0.0
% INFO    : Bus 68050	: V=1.0118541, theta=-83.36331 -> V=1.0, theta=0.0
% INFO    : Bus 68051	: V=1.012298, theta=-83.415731 -> V=1.0, theta=0.0
% INFO    : Bus 68052	: V=1.0127778, theta=-83.415386 -> V=1.0, theta=0.0
% INFO    : Bus 68053	: V=1.0103784, theta=-83.198854 -> V=1.0, theta=0.0
% INFO    : Bus 68054	: V=1.0117306, theta=-83.353095 -> V=1.0, theta=0.0
% INFO    : Bus 68055	: V=1.0120234, theta=-83.410876 -> V=1.0, theta=0.0
% INFO    : Bus 68056	: V=1.0104013, theta=-83.059873 -> V=1.0, theta=0.0
% INFO    : Bus 68057	: V=1.0115552, theta=-83.453714 -> V=1.0, theta=0.0
% INFO    : Bus 68058	: V=1.0142865, theta=-82.989347 -> V=1.0, theta=0.0
% INFO    : Bus 68059	: V=1.0136248, theta=-82.953216 -> V=1.0, theta=0.0
% INFO    : Bus 68060	: V=1.0119567, theta=-83.452628 -> V=1.0, theta=0.0
% INFO    : Bus 68061	: V=1.0138904, theta=-82.961542 -> V=1.0, theta=0.0
% INFO    : Bus 68062	: V=1.0120627, theta=-83.56912 -> V=1.0, theta=0.0
% INFO    : Bus 68063	: V=1.0122765, theta=-83.518698 -> V=1.0, theta=0.0
% INFO    : Bus 68064	: V=1.0144149, theta=-82.974553 -> V=1.0, theta=0.0
% INFO    : Bus 68065	: V=1.0147523, theta=-82.996642 -> V=1.0, theta=0.0
% INFO    : Bus 68066	: V=1.0281145, theta=-82.401571 -> V=1.0, theta=0.0
% INFO    : Bus 68067	: V=1.0153686, theta=-82.998476 -> V=1.0, theta=0.0
% INFO    : Bus 68068	: V=1.014502, theta=-83.532198 -> V=1.0, theta=0.0
% INFO    : Bus 68069	: V=1.0135954, theta=-83.58066 -> V=1.0, theta=0.0
% INFO    : Bus 68070	: V=1.0126893, theta=-83.614855 -> V=1.0, theta=0.0
% INFO    : Bus 68071	: V=1.0108959, theta=-83.086948 -> V=1.0, theta=0.0
% INFO    : Bus 68072	: V=1.0104691, theta=-83.151895 -> V=1.0, theta=0.0
% INFO    : Bus 68073	: V=1.0103836, theta=-83.199874 -> V=1.0, theta=0.0
% INFO    : Bus 68074	: V=1.0107784, theta=-82.987749 -> V=1.0, theta=0.0
% INFO    : Bus 68075	: V=1.0109882, theta=-82.94729 -> V=1.0, theta=0.0
% INFO    : Bus 68076	: V=1.0111319, theta=-82.920865 -> V=1.0, theta=0.0
% INFO    : Bus 68077	: V=1.0114508, theta=-82.859164 -> V=1.0, theta=0.0
% INFO    : Bus 68078	: V=1.0115827, theta=-82.72616 -> V=1.0, theta=0.0
% INFO    : Bus 68079	: V=1.0113196, theta=-82.598138 -> V=1.0, theta=0.0
% INFO    : Bus 68080	: V=1.0114775, theta=-82.811218 -> V=1.0, theta=0.0
% INFO    : Bus 68081	: V=1.0115142, theta=-82.781778 -> V=1.0, theta=0.0
% INFO    : Bus 68082	: V=1.0111039, theta=-82.404189 -> V=1.0, theta=0.0
% INFO    : Bus 68083	: V=1.0119178, theta=-82.728391 -> V=1.0, theta=0.0
% INFO    : Bus 68084	: V=1.0071896, theta=-82.957528 -> V=1.0, theta=0.0
% INFO    : Bus 68085	: V=1.0092108, theta=-83.260622 -> V=1.0, theta=0.0
% INFO    : Bus 68086	: V=1.0067005, theta=-83.535909 -> V=1.0, theta=0.0
% INFO    : Bus 68087	: V=1.006938, theta=-83.526149 -> V=1.0, theta=0.0
% INFO    : Bus 68088	: V=1.0059277, theta=-83.613464 -> V=1.0, theta=0.0
% INFO    : Bus 68089	: V=1.0075916, theta=-83.446915 -> V=1.0, theta=0.0
% INFO    : Bus 68090	: V=1.0073155, theta=-83.622821 -> V=1.0, theta=0.0
% INFO    : Bus 68091	: V=1.0106226, theta=-83.185637 -> V=1.0, theta=0.0
% INFO    : Bus 68092	: V=1.0104646, theta=-83.191475 -> V=1.0, theta=0.0
% INFO    : Bus 68093	: V=1.0116977, theta=-82.848129 -> V=1.0, theta=0.0
% INFO    : Bus 68094	: V=1.0119534, theta=-82.834456 -> V=1.0, theta=0.0
% INFO    : Bus 68095	: V=1.0041999, theta=-83.727622 -> V=1.0, theta=0.0
% INFO    : Bus 68096	: V=1.0033576, theta=-83.71657 -> V=1.0, theta=0.0
% INFO    : Bus 68097	: V=1.0047301, theta=-83.698065 -> V=1.0, theta=0.0
% INFO    : Bus 68098	: V=1.0045781, theta=-83.704318 -> V=1.0, theta=0.0
% INFO    : Bus 68099	: V=1.0029211, theta=-83.699281 -> V=1.0, theta=0.0
% INFO    : Bus 68100	: V=1.0023811, theta=-83.637761 -> V=1.0, theta=0.0
% INFO    : Bus 68101	: V=1.009208, theta=-83.637339 -> V=1.0, theta=0.0
% INFO    : Bus 68102	: V=1.0083549, theta=-83.675681 -> V=1.0, theta=0.0
% INFO    : Bus 68103	: V=1.0076751, theta=-83.711916 -> V=1.0, theta=0.0
% INFO    : Bus 68104	: V=1.0091061, theta=-83.705833 -> V=1.0, theta=0.0
% INFO    : Bus 68105	: V=1.0131354, theta=-82.930128 -> V=1.0, theta=0.0
% INFO    : Bus 68106	: V=1.0094718, theta=-83.719216 -> V=1.0, theta=0.0
% INFO    : Bus 68107	: V=1.0086122, theta=-83.798208 -> V=1.0, theta=0.0
% INFO    : Bus 68108	: V=1.0084537, theta=-83.77629 -> V=1.0, theta=0.0
% INFO    : Bus 68109	: V=1.0074727, theta=-83.795699 -> V=1.0, theta=0.0
% INFO    : Bus 68110	: V=1.0074387, theta=-83.865131 -> V=1.0, theta=0.0
% INFO    : Bus 68111	: V=1.0062824, theta=-83.666183 -> V=1.0, theta=0.0
% INFO    : Bus 68112	: V=1.0068135, theta=-83.646363 -> V=1.0, theta=0.0
% INFO    : Bus 68113	: V=1.0068858, theta=-83.715477 -> V=1.0, theta=0.0
% INFO    : Bus 68114	: V=1.0044373, theta=-83.796364 -> V=1.0, theta=0.0
% INFO    : Bus 68115	: V=1.004526, theta=-83.909604 -> V=1.0, theta=0.0
% INFO    : Bus 68116	: V=1.0041552, theta=-83.769971 -> V=1.0, theta=0.0
% INFO    : Bus 68117	: V=1.0064139, theta=-83.752256 -> V=1.0, theta=0.0
% INFO    : Bus 68118	: V=1.0060335, theta=-83.769454 -> V=1.0, theta=0.0
% INFO    : Bus 68119	: V=1.0074157, theta=-83.777162 -> V=1.0, theta=0.0
% INFO    : Bus 68120	: V=1.0031672, theta=-83.682637 -> V=1.0, theta=0.0
% INFO    : Bus 68121	: V=1.006021, theta=-83.585415 -> V=1.0, theta=0.0
% INFO    : Bus 68122	: V=1.0009762, theta=-83.82674 -> V=1.0, theta=0.0
% INFO    : Bus 68123	: V=1.0019997, theta=-83.782141 -> V=1.0, theta=0.0
% INFO    : Bus 68124	: V=1.0017279, theta=-83.794309 -> V=1.0, theta=0.0
% INFO    : Bus 68125	: V=0.9978525, theta=-84.06951 -> V=1.0, theta=0.0
% INFO    : Bus 68126	: V=1.0035386, theta=-84.014644 -> V=1.0, theta=0.0
% INFO    : Bus 68127	: V=1.0046773, theta=-83.938872 -> V=1.0, theta=0.0
% INFO    : Bus 68128	: V=1.0052001, theta=-83.877106 -> V=1.0, theta=0.0
% INFO    : Bus 68129	: V=0.9979628, theta=-84.021431 -> V=1.0, theta=0.0
% INFO    : Bus 68130	: V=1.0019775, theta=-83.812192 -> V=1.0, theta=0.0
% INFO    : Bus 68131	: V=1.0060906, theta=-83.817897 -> V=1.0, theta=0.0
% INFO    : Bus 68132	: V=1.0300003, theta=-81.046176 -> V=1.0, theta=0.0
% INFO    : Bus 68133	: V=1.0038721, theta=-83.694313 -> V=1.0, theta=0.0
% INFO    : Bus 68134	: V=1.0063931, theta=-83.585213 -> V=1.0, theta=0.0
% INFO    : Bus 68135	: V=1.0066316, theta=-83.726047 -> V=1.0, theta=0.0
% INFO    : Bus 68136	: V=1.0118503, theta=-82.817265 -> V=1.0, theta=0.0
% INFO    : Bus 68137	: V=1.0106352, theta=-82.861831 -> V=1.0, theta=0.0
% INFO    : Bus 68138	: V=1.0059435, theta=-84.043187 -> V=1.0, theta=0.0
% INFO    : Bus 68139	: V=1.0051051, theta=-83.994016 -> V=1.0, theta=0.0
% INFO    : Bus 68140	: V=1.0054283, theta=-84.01829 -> V=1.0, theta=0.0
% INFO    : Bus 68141	: V=1.0052864, theta=-84.006336 -> V=1.0, theta=0.0
% INFO    : Bus 68142	: V=1.0051305, theta=-84.099835 -> V=1.0, theta=0.0
% INFO    : Bus 68143	: V=1.0056492, theta=-83.914245 -> V=1.0, theta=0.0
% INFO    : Bus 68144	: V=1.0047575, theta=-84.170109 -> V=1.0, theta=0.0
% INFO    : Bus 68145	: V=1.0048296, theta=-84.19731 -> V=1.0, theta=0.0
% INFO    : Bus 68146	: V=1.0048703, theta=-84.151711 -> V=1.0, theta=0.0
% INFO    : Bus 68147	: V=1.0044822, theta=-84.1826 -> V=1.0, theta=0.0
% INFO    : Bus 68148	: V=1.0084229, theta=-83.948859 -> V=1.0, theta=0.0
% INFO    : Bus 68149	: V=1.0089359, theta=-83.814064 -> V=1.0, theta=0.0
% INFO    : Bus 68150	: V=1.0079054, theta=-83.957293 -> V=1.0, theta=0.0
% INFO    : Bus 68151	: V=1.0074563, theta=-83.956485 -> V=1.0, theta=0.0
% INFO    : Bus 68152	: V=1.0062161, theta=-84.054542 -> V=1.0, theta=0.0
% INFO    : Bus 68153	: V=1.0064973, theta=-84.044085 -> V=1.0, theta=0.0
% INFO    : Bus 68154	: V=1.0071505, theta=-84.038117 -> V=1.0, theta=0.0
% INFO    : Bus 68155	: V=1.0078556, theta=-84.018653 -> V=1.0, theta=0.0
% INFO    : Bus 68156	: V=1.0084525, theta=-83.981389 -> V=1.0, theta=0.0
% INFO    : Bus 68157	: V=1.0084198, theta=-83.988406 -> V=1.0, theta=0.0
% INFO    : Bus 68158	: V=1.0085002, theta=-83.992335 -> V=1.0, theta=0.0
% INFO    : Bus 68159	: V=1.0086215, theta=-83.964663 -> V=1.0, theta=0.0
% INFO    : Bus 68160	: V=1.0087801, theta=-83.990612 -> V=1.0, theta=0.0
% INFO    : Bus 68161	: V=1.008968, theta=-83.983673 -> V=1.0, theta=0.0
% INFO    : Bus 68162	: V=1.0132512, theta=-83.644921 -> V=1.0, theta=0.0
% INFO    : Bus 68163	: V=1.0116751, theta=-83.649522 -> V=1.0, theta=0.0
% INFO    : Bus 68164	: V=1.0100304, theta=-83.770071 -> V=1.0, theta=0.0
% INFO    : Bus 68165	: V=1.010021, theta=-83.717226 -> V=1.0, theta=0.0
% INFO    : Bus 68166	: V=1.0093884, theta=-83.82167 -> V=1.0, theta=0.0
% INFO    : Bus 68167	: V=1.0089057, theta=-83.912174 -> V=1.0, theta=0.0
% INFO    : Bus 68168	: V=1.0089907, theta=-83.911868 -> V=1.0, theta=0.0
% INFO    : Bus 68169	: V=1.0093676, theta=-83.865323 -> V=1.0, theta=0.0
% INFO    : Bus 68170	: V=1.0093603, theta=-83.847884 -> V=1.0, theta=0.0
% INFO    : Bus 68171	: V=1.0106523, theta=-83.759662 -> V=1.0, theta=0.0
% INFO    : Bus 68172	: V=1.0103255, theta=-83.944307 -> V=1.0, theta=0.0
% INFO    : Bus 68173	: V=1.0113474, theta=-83.739763 -> V=1.0, theta=0.0
% INFO    : Bus 68174	: V=1.0103862, theta=-83.88432 -> V=1.0, theta=0.0
% INFO    : Bus 68175	: V=1.0090197, theta=-83.97333 -> V=1.0, theta=0.0
% INFO    : Bus 68176	: V=1.0092848, theta=-83.99974 -> V=1.0, theta=0.0
% INFO    : Bus 68177	: V=1.0094055, theta=-84.004817 -> V=1.0, theta=0.0
% INFO    : Bus 68178	: V=1.0083181, theta=-83.963668 -> V=1.0, theta=0.0
% INFO    : Bus 68179	: V=1.0097325, theta=-83.962595 -> V=1.0, theta=0.0
% INFO    : Bus 68180	: V=1.008382, theta=-83.961303 -> V=1.0, theta=0.0
% INFO    : Bus 68181	: V=1.00923, theta=-83.988028 -> V=1.0, theta=0.0
% INFO    : Bus 68182	: V=1.009117, theta=-83.99259 -> V=1.0, theta=0.0
% INFO    : Bus 68183	: V=1.008788, theta=-83.944874 -> V=1.0, theta=0.0
% INFO    : Bus 68184	: V=1.0094931, theta=-84.00216 -> V=1.0, theta=0.0
% INFO    : Bus 68185	: V=1.0098901, theta=-83.974513 -> V=1.0, theta=0.0
% INFO    : Bus 68186	: V=1.0145056, theta=-83.190712 -> V=1.0, theta=0.0
% INFO    : Bus 68187	: V=1.0110231, theta=-83.877796 -> V=1.0, theta=0.0
% INFO    : Bus 68188	: V=1.0108197, theta=-83.680986 -> V=1.0, theta=0.0
% INFO    : Bus 68189	: V=1.0275507, theta=-82.394089 -> V=1.0, theta=0.0
% INFO    : Bus 68190	: V=1.0169223, theta=-83.39335 -> V=1.0, theta=0.0
% INFO    : Bus 68191	: V=1.0149608, theta=-83.138922 -> V=1.0, theta=0.0
% INFO    : Bus 68192	: V=1.0154288, theta=-83.101936 -> V=1.0, theta=0.0
% INFO    : Bus 68193	: V=1.0105965, theta=-83.901363 -> V=1.0, theta=0.0
% INFO    : Bus 68194	: V=1.0105206, theta=-83.808808 -> V=1.0, theta=0.0
% INFO    : Bus 68195	: V=1.0107638, theta=-83.752552 -> V=1.0, theta=0.0
% INFO    : Bus 68196	: V=1.014391, theta=-83.150037 -> V=1.0, theta=0.0
% INFO    : Bus 68197	: V=1.0104914, theta=-83.935284 -> V=1.0, theta=0.0
% INFO    : Bus 68198	: V=1.0105787, theta=-83.687509 -> V=1.0, theta=0.0
% INFO    : Bus 68199	: V=1.0104997, theta=-83.690431 -> V=1.0, theta=0.0
% INFO    : Bus 68200	: V=1.0110135, theta=-83.673794 -> V=1.0, theta=0.0
% INFO    : Bus 68201	: V=1.0119835, theta=-83.593696 -> V=1.0, theta=0.0
% INFO    : Bus 68202	: V=1.0103985, theta=-83.715806 -> V=1.0, theta=0.0
% INFO    : Bus 68203	: V=1.010259, theta=-83.7057 -> V=1.0, theta=0.0
% INFO    : Bus 68204	: V=1.0131904, theta=-83.158891 -> V=1.0, theta=0.0
% INFO    : Bus 68205	: V=1.0103173, theta=-83.681294 -> V=1.0, theta=0.0
% INFO    : Bus 68206	: V=1.0094774, theta=-83.638762 -> V=1.0, theta=0.0
% INFO    : Bus 68207	: V=1.0093225, theta=-83.603688 -> V=1.0, theta=0.0
% INFO    : Bus 68208	: V=1.0100779, theta=-83.720127 -> V=1.0, theta=0.0
% INFO    : Bus 68209	: V=1.0114374, theta=-83.31148 -> V=1.0, theta=0.0
% INFO    : Bus 68210	: V=1.0117079, theta=-83.27896 -> V=1.0, theta=0.0
% INFO    : Bus 68211	: V=1.0100914, theta=-83.665843 -> V=1.0, theta=0.0
% INFO    : Bus 68212	: V=1.0112615, theta=-83.333529 -> V=1.0, theta=0.0
% INFO    : Bus 68213	: V=1.0094032, theta=-83.98905 -> V=1.0, theta=0.0
% INFO    : Bus 68214	: V=1.0098766, theta=-83.972372 -> V=1.0, theta=0.0
% INFO    : Bus 68215	: V=1.0088234, theta=-84.015076 -> V=1.0, theta=0.0
% INFO    : Bus 68216	: V=1.008826, theta=-84.009264 -> V=1.0, theta=0.0
% INFO    : Bus 68217	: V=1.0087752, theta=-84.029503 -> V=1.0, theta=0.0
% INFO    : Bus 68218	: V=1.0082584, theta=-84.026117 -> V=1.0, theta=0.0
% INFO    : Bus 68219	: V=1.0076023, theta=-83.92474 -> V=1.0, theta=0.0
% INFO    : Bus 68220	: V=1.0081704, theta=-83.991498 -> V=1.0, theta=0.0
% INFO    : Bus 68221	: V=1.0072733, theta=-83.939518 -> V=1.0, theta=0.0
% INFO    : Bus 68222	: V=1.0077234, theta=-83.844203 -> V=1.0, theta=0.0
% INFO    : Bus 68223	: V=1.009404, theta=-83.747363 -> V=1.0, theta=0.0
% INFO    : Bus 68224	: V=1.008116, theta=-83.765323 -> V=1.0, theta=0.0
% INFO    : Bus 68225	: V=1.0066794, theta=-83.844375 -> V=1.0, theta=0.0
% INFO    : Bus 68226	: V=1.0095226, theta=-83.412538 -> V=1.0, theta=0.0
% INFO    : Bus 68227	: V=1.0094743, theta=-83.424344 -> V=1.0, theta=0.0
% INFO    : Bus 68228	: V=1.0094816, theta=-83.422345 -> V=1.0, theta=0.0
% INFO    : Bus 68229	: V=1.0094933, theta=-83.4193 -> V=1.0, theta=0.0
% INFO    : Bus 68230	: V=1.0105466, theta=-83.348468 -> V=1.0, theta=0.0
% INFO    : Bus 68231	: V=1.0092059, theta=-83.65539 -> V=1.0, theta=0.0
% INFO    : Bus 68232	: V=1.0096107, theta=-83.39855 -> V=1.0, theta=0.0
% INFO    : Bus 68233	: V=1.0090885, theta=-83.568153 -> V=1.0, theta=0.0
% INFO    : Bus 68234	: V=1.0073298, theta=-83.934851 -> V=1.0, theta=0.0
% INFO    : Bus 68235	: V=1.0082958, theta=-83.938881 -> V=1.0, theta=0.0
% INFO    : Bus 68236	: V=1.0063659, theta=-83.628092 -> V=1.0, theta=0.0
% INFO    : Bus 68237	: V=1.0061932, theta=-83.619311 -> V=1.0, theta=0.0
% INFO    : Bus 68238	: V=1.0073257, theta=-83.846456 -> V=1.0, theta=0.0
% INFO    : Bus 68239	: V=1.0072303, theta=-83.839842 -> V=1.0, theta=0.0
% INFO    : Bus 68240	: V=1.0072528, theta=-83.818132 -> V=1.0, theta=0.0
% INFO    : Bus 68241	: V=1.0076706, theta=-83.772347 -> V=1.0, theta=0.0
% INFO    : Bus 68242	: V=1.0089028, theta=-83.631857 -> V=1.0, theta=0.0
% INFO    : Bus 68243	: V=1.0090152, theta=-83.415762 -> V=1.0, theta=0.0
% INFO    : Bus 68244	: V=1.0079853, theta=-83.720174 -> V=1.0, theta=0.0
% INFO    : Bus 68245	: V=1.0074719, theta=-83.727367 -> V=1.0, theta=0.0
% INFO    : Bus 68246	: V=1.0085652, theta=-83.427446 -> V=1.0, theta=0.0
% INFO    : Bus 68247	: V=1.0072252, theta=-83.73853 -> V=1.0, theta=0.0
% INFO    : Bus 68248	: V=1.0079442, theta=-83.440099 -> V=1.0, theta=0.0
% INFO    : Bus 68249	: V=1.0090766, theta=-84.046185 -> V=1.0, theta=0.0
% INFO    : Bus 68250	: V=1.0094548, theta=-84.005722 -> V=1.0, theta=0.0
% INFO    : Bus 68251	: V=1.0089714, theta=-84.031408 -> V=1.0, theta=0.0
% INFO    : Bus 68252	: V=1.0127784, theta=-83.380262 -> V=1.0, theta=0.0
% INFO    : Bus 68253	: V=1.0092167, theta=-84.046807 -> V=1.0, theta=0.0
% INFO    : Bus 68254	: V=1.0097807, theta=-83.955944 -> V=1.0, theta=0.0
% INFO    : Bus 68255	: V=1.0151031, theta=-82.949698 -> V=1.0, theta=0.0
% INFO    : Bus 68256	: V=1.0124241, theta=-83.420656 -> V=1.0, theta=0.0
% INFO    : Bus 68257	: V=1.0092941, theta=-84.063185 -> V=1.0, theta=0.0
% INFO    : Bus 68258	: V=1.0097616, theta=-84.041145 -> V=1.0, theta=0.0
% INFO    : Bus 68259	: V=1.0086465, theta=-84.095281 -> V=1.0, theta=0.0
% INFO    : Bus 68260	: V=1.0092098, theta=-84.064112 -> V=1.0, theta=0.0
% INFO    : Bus 68261	: V=1.0091601, theta=-84.05819 -> V=1.0, theta=0.0
% INFO    : Bus 68262	: V=1.0093941, theta=-84.056483 -> V=1.0, theta=0.0
% INFO    : Bus 68263	: V=1.0086948, theta=-84.090392 -> V=1.0, theta=0.0
% INFO    : Bus 68264	: V=1.0091094, theta=-84.065382 -> V=1.0, theta=0.0
% INFO    : Bus 68265	: V=1.0090426, theta=-84.061286 -> V=1.0, theta=0.0
% INFO    : Bus 68266	: V=1.009053, theta=-84.053935 -> V=1.0, theta=0.0
% INFO    : Bus 68267	: V=1.0083562, theta=-84.093095 -> V=1.0, theta=0.0
% INFO    : Bus 68268	: V=1.0088149, theta=-84.035495 -> V=1.0, theta=0.0
% INFO    : Bus 68269	: V=1.0080388, theta=-84.067067 -> V=1.0, theta=0.0
% INFO    : Bus 68270	: V=1.0081655, theta=-84.080568 -> V=1.0, theta=0.0
% INFO    : Bus 68271	: V=1.0083749, theta=-84.061284 -> V=1.0, theta=0.0
% INFO    : Bus 68272	: V=1.0078597, theta=-84.074333 -> V=1.0, theta=0.0
% INFO    : Bus 68273	: V=1.0089459, theta=-83.496051 -> V=1.0, theta=0.0
% INFO    : Bus 68274	: V=1.0087969, theta=-84.03116 -> V=1.0, theta=0.0
% INFO    : Bus 68275	: V=1.0173232, theta=-82.89813 -> V=1.0, theta=0.0
% INFO    : Bus 68276	: V=1.0088801, theta=-83.870991 -> V=1.0, theta=0.0
% INFO    : Bus 68277	: V=1.0083853, theta=-83.947288 -> V=1.0, theta=0.0
% INFO    : Bus 68278	: V=1.00824, theta=-83.948864 -> V=1.0, theta=0.0
% INFO    : Bus 68279	: V=1.0082255, theta=-83.868717 -> V=1.0, theta=0.0
% INFO    : Bus 68280	: V=1.0090866, theta=-83.783419 -> V=1.0, theta=0.0
% INFO    : Bus 68281	: V=1.0084333, theta=-83.527434 -> V=1.0, theta=0.0
% INFO    : Bus 68282	: V=1.0074446, theta=-83.855399 -> V=1.0, theta=0.0
% INFO    : Bus 68283	: V=1.0059614, theta=-83.866617 -> V=1.0, theta=0.0
% INFO    : Bus 68284	: V=1.0050452, theta=-84.215787 -> V=1.0, theta=0.0
% INFO    : Bus 68285	: V=1.0049357, theta=-84.251936 -> V=1.0, theta=0.0
% INFO    : Bus 68286	: V=1.0051502, theta=-84.206756 -> V=1.0, theta=0.0
% INFO    : Bus 68287	: V=1.0056412, theta=-84.208506 -> V=1.0, theta=0.0
% INFO    : Bus 68288	: V=1.0058756, theta=-83.899477 -> V=1.0, theta=0.0
% INFO    : Bus 68289	: V=1.0061659, theta=-83.815993 -> V=1.0, theta=0.0
% INFO    : Bus 68290	: V=1.0048609, theta=-84.183224 -> V=1.0, theta=0.0
% INFO    : Bus 68291	: V=1.0049266, theta=-84.20222 -> V=1.0, theta=0.0
% INFO    : Bus 68292	: V=1.0057758, theta=-83.935004 -> V=1.0, theta=0.0
% INFO    : Bus 68293	: V=1.0070772, theta=-84.197258 -> V=1.0, theta=0.0
% INFO    : Bus 68294	: V=1.0070649, theta=-84.155862 -> V=1.0, theta=0.0
% INFO    : Bus 68295	: V=1.0066564, theta=-84.21434 -> V=1.0, theta=0.0
% INFO    : Bus 68296	: V=1.0080524, theta=-84.122654 -> V=1.0, theta=0.0
% INFO    : Bus 68297	: V=1.0081326, theta=-84.151404 -> V=1.0, theta=0.0
% INFO    : Bus 68298	: V=1.0055969, theta=-83.972727 -> V=1.0, theta=0.0
% INFO    : Bus 68299	: V=1.0045199, theta=-84.202288 -> V=1.0, theta=0.0
% INFO    : Bus 68300	: V=1.0048842, theta=-83.899707 -> V=1.0, theta=0.0
% INFO    : Bus 68301	: V=1.0056444, theta=-83.964614 -> V=1.0, theta=0.0
% INFO    : Bus 68302	: V=1.006231, theta=-84.178277 -> V=1.0, theta=0.0
% INFO    : Bus 68303	: V=1.0050528, theta=-83.889754 -> V=1.0, theta=0.0
% INFO    : Bus 68304	: V=1.0047737, theta=-83.906244 -> V=1.0, theta=0.0
% INFO    : Bus 68305	: V=1.0038579, theta=-84.167683 -> V=1.0, theta=0.0
% INFO    : Bus 68306	: V=1.0040108, theta=-84.169206 -> V=1.0, theta=0.0
% INFO    : Bus 68307	: V=1.0050261, theta=-84.14166 -> V=1.0, theta=0.0
% INFO    : Bus 68308	: V=1.0061332, theta=-83.757351 -> V=1.0, theta=0.0
% INFO    : Bus 68309	: V=1.0059173, theta=-83.79303 -> V=1.0, theta=0.0
% INFO    : Bus 68310	: V=1.0056047, theta=-83.759681 -> V=1.0, theta=0.0
% INFO    : Bus 68311	: V=1.0013156, theta=-84.266931 -> V=1.0, theta=0.0
% INFO    : Bus 68312	: V=1.0017506, theta=-84.249115 -> V=1.0, theta=0.0
% INFO    : Bus 68313	: V=1.003476, theta=-84.09083 -> V=1.0, theta=0.0
% INFO    : Bus 68314	: V=1.0041092, theta=-84.012658 -> V=1.0, theta=0.0
% INFO    : Bus 68315	: V=1.0036894, theta=-84.081127 -> V=1.0, theta=0.0
% INFO    : Bus 68316	: V=0.9995913, theta=-84.226933 -> V=1.0, theta=0.0
% INFO    : Bus 68317	: V=1.0004074, theta=-84.276325 -> V=1.0, theta=0.0
% INFO    : Bus 68318	: V=0.999978, theta=-84.295925 -> V=1.0, theta=0.0
% INFO    : Bus 68319	: V=0.9986064, theta=-84.151964 -> V=1.0, theta=0.0
% INFO    : Bus 68320	: V=1.0032167, theta=-84.201663 -> V=1.0, theta=0.0
% INFO    : Bus 68321	: V=1.003857, theta=-84.133454 -> V=1.0, theta=0.0
% INFO    : Bus 68322	: V=1.0030326, theta=-84.180834 -> V=1.0, theta=0.0
% INFO    : Bus 68323	: V=1.004399, theta=-84.16415 -> V=1.0, theta=0.0
% INFO    : Bus 68324	: V=1.0056079, theta=-83.836191 -> V=1.0, theta=0.0
% INFO    : Bus 68325	: V=1.0053305, theta=-83.86413 -> V=1.0, theta=0.0
% INFO    : Bus 68326	: V=1.0040807, theta=-84.220535 -> V=1.0, theta=0.0
% INFO    : Bus 68327	: V=1.0043799, theta=-83.820282 -> V=1.0, theta=0.0
% INFO    : Bus 68328	: V=1.0036061, theta=-84.204925 -> V=1.0, theta=0.0
% INFO    : Bus 68329	: V=1.0035769, theta=-84.215014 -> V=1.0, theta=0.0
% INFO    : Bus 68330	: V=1.0009252, theta=-84.316056 -> V=1.0, theta=0.0
% INFO    : Bus 68331	: V=1.0016356, theta=-84.283714 -> V=1.0, theta=0.0
% INFO    : Bus 68332	: V=1.002872, theta=-84.254704 -> V=1.0, theta=0.0
% INFO    : Bus 68333	: V=1.0041255, theta=-83.809299 -> V=1.0, theta=0.0
% INFO    : Bus 68334	: V=1.0004964, theta=-84.337053 -> V=1.0, theta=0.0
% INFO    : Bus 68335	: V=0.9997938, theta=-84.396933 -> V=1.0, theta=0.0
% INFO    : Bus 68336	: V=0.9993269, theta=-84.469719 -> V=1.0, theta=0.0
% INFO    : Bus 68337	: V=1.0027352, theta=-84.254537 -> V=1.0, theta=0.0
% INFO    : Bus 68338	: V=1.0035403, theta=-84.220443 -> V=1.0, theta=0.0
% INFO    : Bus 68339	: V=1.0015911, theta=-84.303595 -> V=1.0, theta=0.0
% INFO    : Bus 68340	: V=1.0008143, theta=-84.331807 -> V=1.0, theta=0.0
% INFO    : Bus 68341	: V=0.9991415, theta=-84.518354 -> V=1.0, theta=0.0
% INFO    : Bus 68342	: V=1.0023244, theta=-84.273673 -> V=1.0, theta=0.0
% INFO    : Bus 68343	: V=1.0041965, theta=-83.719039 -> V=1.0, theta=0.0
% INFO    : Bus 68344	: V=1.0039051, theta=-83.847996 -> V=1.0, theta=0.0
% INFO    : Bus 68345	: V=1.003941, theta=-83.855772 -> V=1.0, theta=0.0
% INFO    : Bus 68346	: V=1.0029679, theta=-84.053076 -> V=1.0, theta=0.0
% INFO    : Bus 68347	: V=1.0028683, theta=-84.153513 -> V=1.0, theta=0.0
% INFO    : Bus 68348	: V=1.0055267, theta=-84.169515 -> V=1.0, theta=0.0
% INFO    : Bus 68349	: V=1.0046451, theta=-83.897075 -> V=1.0, theta=0.0
% INFO    : Bus 68350	: V=1.0036685, theta=-84.234217 -> V=1.0, theta=0.0
% INFO    : Bus 68351	: V=1.004686, theta=-83.904999 -> V=1.0, theta=0.0
% INFO    : Bus 68352	: V=1.0046602, theta=-83.903068 -> V=1.0, theta=0.0
% INFO    : Bus 68353	: V=1.0046055, theta=-84.163477 -> V=1.0, theta=0.0
% INFO    : Bus 68354	: V=1.0034352, theta=-84.234471 -> V=1.0, theta=0.0
% INFO    : Bus 68355	: V=1.0049339, theta=-84.160705 -> V=1.0, theta=0.0
% INFO    : Bus 68356	: V=1.0046249, theta=-83.88554 -> V=1.0, theta=0.0
% INFO    : Bus 68357	: V=1.0046192, theta=-83.87543 -> V=1.0, theta=0.0
% INFO    : Bus 68358	: V=1.0046294, theta=-83.851038 -> V=1.0, theta=0.0
% INFO    : Bus 68359	: V=1.0046606, theta=-83.800844 -> V=1.0, theta=0.0
% INFO    : Bus 68360	: V=1.0041653, theta=-83.747335 -> V=1.0, theta=0.0
% INFO    : Bus 68361	: V=1.0039758, theta=-83.786636 -> V=1.0, theta=0.0
% INFO    : Bus 68362	: V=1.0038883, theta=-83.808598 -> V=1.0, theta=0.0
% INFO    : Bus 68363	: V=1.0038538, theta=-83.827169 -> V=1.0, theta=0.0
% INFO    : Bus 68364	: V=1.0065373, theta=-83.625601 -> V=1.0, theta=0.0
% INFO    : Bus 68365	: V=1.0063742, theta=-83.649808 -> V=1.0, theta=0.0
% INFO    : Bus 68366	: V=1.006101, theta=-83.689746 -> V=1.0, theta=0.0
% INFO    : Bus 68367	: V=1.0063553, theta=-83.862052 -> V=1.0, theta=0.0
% INFO    : Bus 68368	: V=1.0055852, theta=-83.745524 -> V=1.0, theta=0.0
% INFO    : Bus 68369	: V=1.0067815, theta=-83.860405 -> V=1.0, theta=0.0
% INFO    : Bus 68370	: V=1.0058532, theta=-83.720055 -> V=1.0, theta=0.0
% INFO    : Bus 68371	: V=1.0052167, theta=-83.770309 -> V=1.0, theta=0.0
% INFO    : Bus 68372	: V=1.0051501, theta=-83.992383 -> V=1.0, theta=0.0
% INFO    : Bus 68373	: V=1.0063597, theta=-83.89221 -> V=1.0, theta=0.0
% INFO    : Bus 68374	: V=1.0059968, theta=-83.87973 -> V=1.0, theta=0.0
% INFO    : Bus 68375	: V=1.0071624, theta=-83.45389 -> V=1.0, theta=0.0
% INFO    : Bus 68376	: V=1.0060495, theta=-83.856992 -> V=1.0, theta=0.0
% INFO    : Bus 68377	: V=1.0067012, theta=-83.827847 -> V=1.0, theta=0.0
% INFO    : Bus 68378	: V=1.0060051, theta=-83.602503 -> V=1.0, theta=0.0
% INFO    : Bus 68379	: V=1.0059082, theta=-83.589607 -> V=1.0, theta=0.0
% INFO    : Bus 68380	: V=1.0056859, theta=-83.54879 -> V=1.0, theta=0.0
% INFO    : Bus 68381	: V=1.0058662, theta=-83.86071 -> V=1.0, theta=0.0
% INFO    : Bus 68382	: V=1.0057707, theta=-83.861464 -> V=1.0, theta=0.0
% INFO    : Bus 68383	: V=1.0045518, theta=-83.841748 -> V=1.0, theta=0.0
% INFO    : Bus 68384	: V=1.0055185, theta=-83.511515 -> V=1.0, theta=0.0
% INFO    : Bus 68385	: V=1.0060106, theta=-83.817002 -> V=1.0, theta=0.0
% INFO    : Bus 68386	: V=1.0056596, theta=-83.875609 -> V=1.0, theta=0.0
% INFO    : Bus 68387	: V=1.0033681, theta=-83.720288 -> V=1.0, theta=0.0
% INFO    : Bus 68388	: V=1.0047363, theta=-83.683664 -> V=1.0, theta=0.0
% INFO    : Bus 68389	: V=1.0039488, theta=-83.696712 -> V=1.0, theta=0.0
% INFO    : Bus 68390	: V=1.0034866, theta=-83.715623 -> V=1.0, theta=0.0
% INFO    : Bus 68391	: V=1.0068893, theta=-83.090364 -> V=1.0, theta=0.0
% INFO    : Bus 68392	: V=1.0028467, theta=-83.530552 -> V=1.0, theta=0.0
% INFO    : Bus 68393	: V=1.0023763, theta=-83.552073 -> V=1.0, theta=0.0
% INFO    : Bus 68394	: V=1.0022772, theta=-83.556127 -> V=1.0, theta=0.0
% INFO    : Bus 68395	: V=1.0030243, theta=-83.543569 -> V=1.0, theta=0.0
% INFO    : Bus 68396	: V=1.0036221, theta=-83.621304 -> V=1.0, theta=0.0
% INFO    : Bus 68397	: V=1.0039051, theta=-83.628662 -> V=1.0, theta=0.0
% INFO    : Bus 68398	: V=1.0038773, theta=-83.609674 -> V=1.0, theta=0.0
% INFO    : Bus 68399	: V=1.0042046, theta=-83.60657 -> V=1.0, theta=0.0
% INFO    : Bus 68400	: V=1.0043914, theta=-83.619237 -> V=1.0, theta=0.0
% INFO    : Bus 68401	: V=1.0039988, theta=-83.588598 -> V=1.0, theta=0.0
% INFO    : Bus 68402	: V=1.0038326, theta=-83.562932 -> V=1.0, theta=0.0
% INFO    : Bus 68403	: V=1.003394, theta=-83.544497 -> V=1.0, theta=0.0
% INFO    : Bus 68404	: V=1.0031908, theta=-83.546579 -> V=1.0, theta=0.0
% INFO    : Bus 68405	: V=1.0034303, theta=-83.432759 -> V=1.0, theta=0.0
% INFO    : Bus 68406	: V=1.0032773, theta=-83.368064 -> V=1.0, theta=0.0
% INFO    : Bus 68407	: V=1.0037839, theta=-83.534078 -> V=1.0, theta=0.0
% INFO    : Bus 68408	: V=1.0036911, theta=-83.537847 -> V=1.0, theta=0.0
% INFO    : Bus 68409	: V=1.0047777, theta=-83.558534 -> V=1.0, theta=0.0
% INFO    : Bus 68410	: V=1.0065455, theta=-83.552327 -> V=1.0, theta=0.0
% INFO    : Bus 68411	: V=1.0041221, theta=-83.72347 -> V=1.0, theta=0.0
% INFO    : Bus 68412	: V=1.0059883, theta=-83.592929 -> V=1.0, theta=0.0
% INFO    : Bus 68413	: V=1.0058367, theta=-83.517834 -> V=1.0, theta=0.0
% INFO    : Bus 68414	: V=1.0054088, theta=-83.4846 -> V=1.0, theta=0.0
% INFO    : Bus 68415	: V=1.0050771, theta=-83.668794 -> V=1.0, theta=0.0
% INFO    : Bus 68416	: V=1.0045429, theta=-83.616251 -> V=1.0, theta=0.0
% INFO    : Bus 68417	: V=1.0046974, theta=-83.614162 -> V=1.0, theta=0.0
% INFO    : Bus 68418	: V=1.0048811, theta=-83.610566 -> V=1.0, theta=0.0
% INFO    : Bus 68419	: V=1.0059955, theta=-83.61774 -> V=1.0, theta=0.0
% INFO    : Bus 68420	: V=1.005096, theta=-83.615479 -> V=1.0, theta=0.0
% INFO    : Bus 68421	: V=1.0069043, theta=-83.092532 -> V=1.0, theta=0.0
% INFO    : Bus 68422	: V=1.0067545, theta=-83.109375 -> V=1.0, theta=0.0
% INFO    : Bus 68423	: V=1.005715, theta=-83.603993 -> V=1.0, theta=0.0
% INFO    : Bus 68424	: V=1.0056739, theta=-83.697961 -> V=1.0, theta=0.0
% INFO    : Bus 68425	: V=1.0043508, theta=-83.713994 -> V=1.0, theta=0.0
% INFO    : Bus 68426	: V=1.0042246, theta=-83.765167 -> V=1.0, theta=0.0
% INFO    : Bus 68427	: V=1.0039853, theta=-83.774089 -> V=1.0, theta=0.0
% INFO    : Bus 68428	: V=1.0078306, theta=-82.939394 -> V=1.0, theta=0.0
% INFO    : Bus 68429	: V=1.0027042, theta=-83.883241 -> V=1.0, theta=0.0
% INFO    : Bus 68430	: V=1.0032266, theta=-83.856992 -> V=1.0, theta=0.0
% INFO    : Bus 68431	: V=1.0058769, theta=-83.688758 -> V=1.0, theta=0.0
% INFO    : Bus 68432	: V=1.0028945, theta=-83.864501 -> V=1.0, theta=0.0
% INFO    : Bus 68433	: V=1.003374, theta=-83.850255 -> V=1.0, theta=0.0
% INFO    : Bus 68434	: V=1.0022447, theta=-83.885744 -> V=1.0, theta=0.0
% INFO    : Bus 68435	: V=1.0031609, theta=-83.858102 -> V=1.0, theta=0.0
% INFO    : Bus 68436	: V=1.0033832, theta=-83.842168 -> V=1.0, theta=0.0
% INFO    : Bus 68437	: V=1.0054434, theta=-83.36583 -> V=1.0, theta=0.0
% INFO    : Bus 68438	: V=1.0047366, theta=-83.366437 -> V=1.0, theta=0.0
% INFO    : Bus 68439	: V=1.0038256, theta=-83.816689 -> V=1.0, theta=0.0
% INFO    : Bus 68440	: V=1.0059694, theta=-83.416386 -> V=1.0, theta=0.0
% INFO    : Bus 68441	: V=1.0034408, theta=-83.851072 -> V=1.0, theta=0.0
% INFO    : Bus 68442	: V=1.0033623, theta=-83.402671 -> V=1.0, theta=0.0
% INFO    : Bus 68443	: V=1.0031691, theta=-83.357891 -> V=1.0, theta=0.0
% INFO    : Bus 68444	: V=1.0034978, theta=-83.828342 -> V=1.0, theta=0.0
% INFO    : Bus 68445	: V=1.0035463, theta=-83.826375 -> V=1.0, theta=0.0
% INFO    : Bus 68446	: V=1.0032531, theta=-83.373754 -> V=1.0, theta=0.0
% INFO    : Bus 68447	: V=1.003331, theta=-83.837976 -> V=1.0, theta=0.0
% INFO    : Bus 68448	: V=1.0034107, theta=-83.837275 -> V=1.0, theta=0.0
% INFO    : Bus 68449	: V=1.0032727, theta=-83.850884 -> V=1.0, theta=0.0
% INFO    : Bus 68450	: V=1.0031769, theta=-83.849825 -> V=1.0, theta=0.0
% INFO    : Bus 68451	: V=1.002801, theta=-83.867313 -> V=1.0, theta=0.0
% INFO    : Bus 68452	: V=1.002951, theta=-83.863485 -> V=1.0, theta=0.0
% INFO    : Bus 68453	: V=1.0030334, theta=-83.856677 -> V=1.0, theta=0.0
% INFO    : Bus 68454	: V=1.0025442, theta=-83.876683 -> V=1.0, theta=0.0
% INFO    : Bus 68455	: V=1.0032792, theta=-83.845709 -> V=1.0, theta=0.0
% INFO    : Bus 68456	: V=1.0028137, theta=-83.842367 -> V=1.0, theta=0.0
% INFO    : Bus 68457	: V=1.002888, theta=-83.840067 -> V=1.0, theta=0.0
% INFO    : Bus 68458	: V=1.0024081, theta=-83.873146 -> V=1.0, theta=0.0
% INFO    : Bus 68459	: V=1.0042422, theta=-83.371379 -> V=1.0, theta=0.0
% INFO    : Bus 68460	: V=1.0043177, theta=-83.363698 -> V=1.0, theta=0.0
% INFO    : Bus 68461	: V=1.0023365, theta=-83.881227 -> V=1.0, theta=0.0
% INFO    : Bus 68462	: V=1.0021346, theta=-83.874674 -> V=1.0, theta=0.0
% INFO    : Bus 68463	: V=1.0024059, theta=-83.879749 -> V=1.0, theta=0.0
% INFO    : Bus 68464	: V=1.0020341, theta=-83.895318 -> V=1.0, theta=0.0
% INFO    : Bus 68465	: V=1.0021222, theta=-83.891315 -> V=1.0, theta=0.0
% INFO    : Bus 68466	: V=1.0020649, theta=-83.857005 -> V=1.0, theta=0.0
% INFO    : Bus 68467	: V=1.0021421, theta=-83.870546 -> V=1.0, theta=0.0
% INFO    : Bus 68468	: V=1.0018452, theta=-83.867217 -> V=1.0, theta=0.0
% INFO    : Bus 68469	: V=1.0018419, theta=-83.851244 -> V=1.0, theta=0.0
% INFO    : Bus 68470	: V=1.0018199, theta=-83.879941 -> V=1.0, theta=0.0
% INFO    : Bus 68471	: V=1.0022136, theta=-83.849089 -> V=1.0, theta=0.0
% INFO    : Bus 68472	: V=1.0019657, theta=-83.879204 -> V=1.0, theta=0.0
% INFO    : Bus 68473	: V=1.0025798, theta=-83.844453 -> V=1.0, theta=0.0
% INFO    : Bus 68474	: V=1.0023415, theta=-83.849393 -> V=1.0, theta=0.0
% INFO    : Bus 68475	: V=1.0034197, theta=-83.318369 -> V=1.0, theta=0.0
% INFO    : Bus 68476	: V=1.003425, theta=-83.309064 -> V=1.0, theta=0.0
% INFO    : Bus 68477	: V=1.0035418, theta=-83.320337 -> V=1.0, theta=0.0
% INFO    : Bus 68478	: V=1.0034122, theta=-83.313136 -> V=1.0, theta=0.0
% INFO    : Bus 68479	: V=1.0029226, theta=-83.718044 -> V=1.0, theta=0.0
% INFO    : Bus 68480	: V=1.0017345, theta=-83.735396 -> V=1.0, theta=0.0
% INFO    : Bus 68481	: V=1.0029382, theta=-83.747587 -> V=1.0, theta=0.0
% INFO    : Bus 68482	: V=1.0034952, theta=-83.27796 -> V=1.0, theta=0.0
% INFO    : Bus 68483	: V=1.0026304, theta=-83.792569 -> V=1.0, theta=0.0
% INFO    : Bus 68484	: V=1.0024857, theta=-83.803623 -> V=1.0, theta=0.0
% INFO    : Bus 68485	: V=1.0023933, theta=-83.809403 -> V=1.0, theta=0.0
% INFO    : Bus 68486	: V=1.0021356, theta=-83.809649 -> V=1.0, theta=0.0
% INFO    : Bus 68487	: V=1.0020288, theta=-83.795165 -> V=1.0, theta=0.0
% INFO    : Bus 68488	: V=1.0019893, theta=-83.824985 -> V=1.0, theta=0.0
% INFO    : Bus 68489	: V=1.0037667, theta=-83.840947 -> V=1.0, theta=0.0
% INFO    : Bus 68490	: V=1.0041181, theta=-83.848577 -> V=1.0, theta=0.0
% INFO    : Bus 68491	: V=1.0040391, theta=-83.446503 -> V=1.0, theta=0.0
% INFO    : Bus 68492	: V=1.0042702, theta=-83.872463 -> V=1.0, theta=0.0
% INFO    : Bus 68493	: V=1.0001955, theta=-83.876683 -> V=1.0, theta=0.0
% INFO    : Bus 68494	: V=1.0003388, theta=-83.870816 -> V=1.0, theta=0.0
% INFO    : Bus 68495	: V=1.0029541, theta=-83.417822 -> V=1.0, theta=0.0
% INFO    : Bus 68496	: V=1.0028255, theta=-83.80244 -> V=1.0, theta=0.0
% INFO    : Bus 68497	: V=1.0028878, theta=-83.8764 -> V=1.0, theta=0.0
% INFO    : Bus 68498	: V=1.0025715, theta=-83.876294 -> V=1.0, theta=0.0
% INFO    : Bus 68499	: V=1.0024493, theta=-83.867709 -> V=1.0, theta=0.0
% INFO    : Bus 68500	: V=1.0022146, theta=-83.839904 -> V=1.0, theta=0.0
% INFO    : Bus 68501	: V=1.0021929, theta=-83.806372 -> V=1.0, theta=0.0
% INFO    : Bus 68502	: V=1.002165, theta=-83.744811 -> V=1.0, theta=0.0
% INFO    : Bus 68503	: V=1.0021749, theta=-83.67472 -> V=1.0, theta=0.0
% INFO    : Bus 68504	: V=1.0021404, theta=-83.631007 -> V=1.0, theta=0.0
% INFO    : Bus 68505	: V=1.0019288, theta=-83.742563 -> V=1.0, theta=0.0
% INFO    : Bus 68506	: V=1.0021067, theta=-83.785073 -> V=1.0, theta=0.0
% INFO    : Bus 68507	: V=1.0020765, theta=-83.736554 -> V=1.0, theta=0.0
% INFO    : Bus 68508	: V=1.0020094, theta=-83.832219 -> V=1.0, theta=0.0
% INFO    : Bus 68509	: V=1.0020375, theta=-83.814835 -> V=1.0, theta=0.0
% INFO    : Bus 68510	: V=1.0020249, theta=-83.806644 -> V=1.0, theta=0.0
% INFO    : Bus 68511	: V=1.0048609, theta=-83.605157 -> V=1.0, theta=0.0
% INFO    : Bus 68512	: V=1.0014347, theta=-83.83674 -> V=1.0, theta=0.0
% INFO    : Bus 68513	: V=1.0038849, theta=-83.779036 -> V=1.0, theta=0.0
% INFO    : Bus 68514	: V=1.0015939, theta=-83.83081 -> V=1.0, theta=0.0
% INFO    : Bus 68515	: V=1.0020445, theta=-83.571963 -> V=1.0, theta=0.0
% INFO    : Bus 68516	: V=1.0020018, theta=-83.363544 -> V=1.0, theta=0.0
% INFO    : Bus 68517	: V=1.0019587, theta=-83.307226 -> V=1.0, theta=0.0
% INFO    : Bus 68518	: V=1.005294, theta=-83.345696 -> V=1.0, theta=0.0
% INFO    : Bus 68519	: V=1.0051202, theta=-83.298363 -> V=1.0, theta=0.0
% INFO    : Bus 68520	: V=1.0050116, theta=-83.055354 -> V=1.0, theta=0.0
% INFO    : Bus 68521	: V=1.003028, theta=-83.056297 -> V=1.0, theta=0.0
% INFO    : Bus 68522	: V=1.0052642, theta=-83.292522 -> V=1.0, theta=0.0
% INFO    : Bus 68523	: V=1.0052888, theta=-83.433724 -> V=1.0, theta=0.0
% INFO    : Bus 68524	: V=1.0055599, theta=-83.423611 -> V=1.0, theta=0.0
% INFO    : Bus 68525	: V=1.0039397, theta=-83.060542 -> V=1.0, theta=0.0
% INFO    : Bus 68526	: V=1.0032938, theta=-83.045505 -> V=1.0, theta=0.0
% INFO    : Bus 68527	: V=1.003631, theta=-83.022842 -> V=1.0, theta=0.0
% INFO    : Bus 68528	: V=1.003057, theta=-83.181657 -> V=1.0, theta=0.0
% INFO    : Bus 68529	: V=1.002515, theta=-83.111942 -> V=1.0, theta=0.0
% INFO    : Bus 68530	: V=1.0030497, theta=-83.111576 -> V=1.0, theta=0.0
% INFO    : Bus 68531	: V=1.0036877, theta=-83.155801 -> V=1.0, theta=0.0
% INFO    : Bus 68532	: V=1.0030815, theta=-83.262014 -> V=1.0, theta=0.0
% INFO    : Bus 68533	: V=1.0045956, theta=-83.05975 -> V=1.0, theta=0.0
% INFO    : Bus 68534	: V=1.0049474, theta=-82.86343 -> V=1.0, theta=0.0
% INFO    : Bus 68535	: V=1.0030524, theta=-83.032532 -> V=1.0, theta=0.0
% INFO    : Bus 68536	: V=1.0030888, theta=-83.054907 -> V=1.0, theta=0.0
% INFO    : Bus 68537	: V=1.0033109, theta=-82.940314 -> V=1.0, theta=0.0
% INFO    : Bus 68538	: V=1.0059633, theta=-82.921234 -> V=1.0, theta=0.0
% INFO    : Bus 68539	: V=1.0034258, theta=-82.936018 -> V=1.0, theta=0.0
% INFO    : Bus 68540	: V=1.005552, theta=-82.948764 -> V=1.0, theta=0.0
% INFO    : Bus 68541	: V=1.0054914, theta=-82.556407 -> V=1.0, theta=0.0
% INFO    : Bus 68542	: V=1.0055582, theta=-82.495483 -> V=1.0, theta=0.0
% INFO    : Bus 68543	: V=1.0037478, theta=-82.950636 -> V=1.0, theta=0.0
% INFO    : Bus 68544	: V=1.0044903, theta=-82.774273 -> V=1.0, theta=0.0
% INFO    : Bus 68545	: V=1.0051148, theta=-82.611006 -> V=1.0, theta=0.0
% INFO    : Bus 68546	: V=1.0056373, theta=-82.445362 -> V=1.0, theta=0.0
% INFO    : Bus 68547	: V=1.0057066, theta=-82.407051 -> V=1.0, theta=0.0
% INFO    : Bus 68548	: V=1.0056947, theta=-82.324787 -> V=1.0, theta=0.0
% INFO    : Bus 68549	: V=1.0061581, theta=-82.187334 -> V=1.0, theta=0.0
% INFO    : Bus 68550	: V=1.0062772, theta=-82.275601 -> V=1.0, theta=0.0
% INFO    : Bus 68551	: V=1.007095, theta=-82.095749 -> V=1.0, theta=0.0
% INFO    : Bus 68552	: V=1.0059448, theta=-82.368144 -> V=1.0, theta=0.0
% INFO    : Bus 68553	: V=1.0060966, theta=-82.37228 -> V=1.0, theta=0.0
% INFO    : Bus 68554	: V=1.0056688, theta=-82.48373 -> V=1.0, theta=0.0
% INFO    : Bus 68555	: V=1.0055847, theta=-82.487142 -> V=1.0, theta=0.0
% INFO    : Bus 68556	: V=1.0065457, theta=-82.301766 -> V=1.0, theta=0.0
% INFO    : Bus 68557	: V=1.0071736, theta=-82.158913 -> V=1.0, theta=0.0
% INFO    : Bus 68558	: V=1.0072086, theta=-82.091523 -> V=1.0, theta=0.0
% INFO    : Bus 68559	: V=1.0075525, theta=-81.962821 -> V=1.0, theta=0.0
% INFO    : Bus 68560	: V=1.007025, theta=-82.098983 -> V=1.0, theta=0.0
% INFO    : Bus 68561	: V=1.0057749, theta=-81.883506 -> V=1.0, theta=0.0
% INFO    : Bus 68562	: V=1.0077294, theta=-82.056901 -> V=1.0, theta=0.0
% INFO    : Bus 68563	: V=1.0300003, theta=-77.547993 -> V=1.0, theta=0.0
% INFO    : Bus 68564	: V=1.0022194, theta=-83.22652 -> V=1.0, theta=0.0
% INFO    : Bus 68565	: V=1.0033535, theta=-83.107574 -> V=1.0, theta=0.0
% INFO    : Bus 68566	: V=1.0107907, theta=-80.411504 -> V=1.0, theta=0.0
% INFO    : Bus 68567	: V=1.004884, theta=-82.667233 -> V=1.0, theta=0.0
% INFO    : Bus 68568	: V=1.0067265, theta=-82.282547 -> V=1.0, theta=0.0
% INFO    : Bus 68569	: V=1.0043877, theta=-83.034417 -> V=1.0, theta=0.0
% INFO    : Bus 68570	: V=1.0049399, theta=-82.837751 -> V=1.0, theta=0.0
% INFO    : Bus 68571	: V=1.0020326, theta=-83.260439 -> V=1.0, theta=0.0
% INFO    : Bus 68572	: V=1.0025407, theta=-83.182864 -> V=1.0, theta=0.0
% INFO    : Bus 68573	: V=1.0023027, theta=-83.192521 -> V=1.0, theta=0.0
% INFO    : Bus 68574	: V=1.0032553, theta=-83.246599 -> V=1.0, theta=0.0
% INFO    : Bus 68575	: V=1.0037748, theta=-83.162517 -> V=1.0, theta=0.0
% INFO    : Bus 68576	: V=1.0022623, theta=-83.265219 -> V=1.0, theta=0.0
% INFO    : Bus 68577	: V=1.0025507, theta=-83.326409 -> V=1.0, theta=0.0
% INFO    : Bus 68578	: V=1.0027784, theta=-83.302635 -> V=1.0, theta=0.0
% INFO    : Bus 68579	: V=1.0039804, theta=-82.497064 -> V=1.0, theta=0.0
% INFO    : Bus 68580	: V=1.0028317, theta=-83.31516 -> V=1.0, theta=0.0
% INFO    : Bus 68581	: V=1.002195, theta=-83.435316 -> V=1.0, theta=0.0
% INFO    : Bus 68582	: V=1.0024348, theta=-83.512197 -> V=1.0, theta=0.0
% INFO    : Bus 68583	: V=1.0023686, theta=-83.484275 -> V=1.0, theta=0.0
% INFO    : Bus 68584	: V=1.0035005, theta=-83.717628 -> V=1.0, theta=0.0
% INFO    : Bus 68585	: V=1.0033784, theta=-83.722178 -> V=1.0, theta=0.0
% INFO    : Bus 68586	: V=1.0024836, theta=-83.702937 -> V=1.0, theta=0.0
% INFO    : Bus 68587	: V=1.0022129, theta=-83.71657 -> V=1.0, theta=0.0
% INFO    : Bus 68588	: V=1.0018722, theta=-83.740458 -> V=1.0, theta=0.0
% INFO    : Bus 68589	: V=1.0020197, theta=-83.724278 -> V=1.0, theta=0.0
% INFO    : Bus 68590	: V=1.0027251, theta=-83.700712 -> V=1.0, theta=0.0
% INFO    : Bus 68591	: V=1.0031188, theta=-83.70927 -> V=1.0, theta=0.0
% INFO    : Bus 68592	: V=1.0040828, theta=-83.702274 -> V=1.0, theta=0.0
% INFO    : Bus 68593	: V=1.0034472, theta=-83.71236 -> V=1.0, theta=0.0
% INFO    : Bus 68594	: V=1.003419, theta=-83.637969 -> V=1.0, theta=0.0
% INFO    : Bus 68595	: V=1.0041636, theta=-83.699001 -> V=1.0, theta=0.0
% INFO    : Bus 68596	: V=1.0040763, theta=-83.702539 -> V=1.0, theta=0.0
% INFO    : Bus 68597	: V=1.0030313, theta=-83.566067 -> V=1.0, theta=0.0
% INFO    : Bus 68598	: V=1.0026502, theta=-83.5556 -> V=1.0, theta=0.0
% INFO    : Bus 68599	: V=1.0025325, theta=-83.535198 -> V=1.0, theta=0.0
% INFO    : Bus 68600	: V=1.0025306, theta=-83.561029 -> V=1.0, theta=0.0
% INFO    : Bus 68601	: V=1.0028334, theta=-83.574103 -> V=1.0, theta=0.0
% INFO    : Bus 68602	: V=1.0029758, theta=-83.634528 -> V=1.0, theta=0.0
% INFO    : Bus 68603	: V=1.0033176, theta=-83.583769 -> V=1.0, theta=0.0
% INFO    : Bus 68604	: V=1.0033559, theta=-83.61056 -> V=1.0, theta=0.0
% INFO    : Bus 68605	: V=1.0030093, theta=-83.5564 -> V=1.0, theta=0.0
% INFO    : Bus 68606	: V=1.0032381, theta=-83.538458 -> V=1.0, theta=0.0
% INFO    : Bus 68607	: V=1.0030766, theta=-83.550343 -> V=1.0, theta=0.0
% INFO    : Bus 68608	: V=1.0031574, theta=-83.541737 -> V=1.0, theta=0.0
% INFO    : Bus 68609	: V=1.0036141, theta=-82.635714 -> V=1.0, theta=0.0
% INFO    : Bus 68610	: V=1.0030863, theta=-83.244663 -> V=1.0, theta=0.0
% INFO    : Bus 68611	: V=1.0022839, theta=-83.684393 -> V=1.0, theta=0.0
% INFO    : Bus 68612	: V=1.0018681, theta=-83.74817 -> V=1.0, theta=0.0
% INFO    : Bus 68613	: V=1.0019382, theta=-83.751825 -> V=1.0, theta=0.0
% INFO    : Bus 68614	: V=1.0018862, theta=-83.655909 -> V=1.0, theta=0.0
% INFO    : Bus 68615	: V=1.0019615, theta=-83.777179 -> V=1.0, theta=0.0
% INFO    : Bus 68616	: V=1.0018506, theta=-83.657225 -> V=1.0, theta=0.0
% INFO    : Bus 68617	: V=1.0017982, theta=-83.757518 -> V=1.0, theta=0.0
% INFO    : Bus 68618	: V=1.0021016, theta=-83.642421 -> V=1.0, theta=0.0
% INFO    : Bus 68619	: V=1.0019719, theta=-83.652715 -> V=1.0, theta=0.0
% INFO    : Bus 68620	: V=1.0032521, theta=-83.206246 -> V=1.0, theta=0.0
% INFO    : Bus 68621	: V=1.0026508, theta=-83.597635 -> V=1.0, theta=0.0
% INFO    : Bus 68622	: V=1.0024587, theta=-83.614776 -> V=1.0, theta=0.0
% INFO    : Bus 68623	: V=1.0027104, theta=-83.600228 -> V=1.0, theta=0.0
% INFO    : Bus 68624	: V=1.0026103, theta=-83.620758 -> V=1.0, theta=0.0
% INFO    : Bus 68625	: V=1.0021481, theta=-83.651555 -> V=1.0, theta=0.0
% INFO    : Bus 68626	: V=1.0022839, theta=-83.635782 -> V=1.0, theta=0.0
% INFO    : Bus 68627	: V=1.0021995, theta=-83.657059 -> V=1.0, theta=0.0
% INFO    : Bus 68628	: V=1.0022112, theta=-83.673719 -> V=1.0, theta=0.0
% INFO    : Bus 68629	: V=1.0021937, theta=-83.666971 -> V=1.0, theta=0.0
% INFO    : Bus 68630	: V=1.0021035, theta=-83.691112 -> V=1.0, theta=0.0
% INFO    : Bus 68631	: V=1.0025032, theta=-83.6407 -> V=1.0, theta=0.0
% INFO    : Bus 68632	: V=1.0029246, theta=-83.58842 -> V=1.0, theta=0.0
% INFO    : Bus 68633	: V=1.0026926, theta=-83.643798 -> V=1.0, theta=0.0
% INFO    : Bus 68634	: V=1.0028268, theta=-83.623507 -> V=1.0, theta=0.0
% INFO    : Bus 68635	: V=1.0026454, theta=-83.642835 -> V=1.0, theta=0.0
% INFO    : Bus 68636	: V=1.0026149, theta=-83.638261 -> V=1.0, theta=0.0
% INFO    : Bus 68637	: V=1.0027661, theta=-83.616992 -> V=1.0, theta=0.0
% INFO    : Bus 68638	: V=1.0027957, theta=-83.607539 -> V=1.0, theta=0.0
% INFO    : Bus 68639	: V=1.0028784, theta=-83.627385 -> V=1.0, theta=0.0
% INFO    : Bus 68640	: V=1.0027824, theta=-83.624256 -> V=1.0, theta=0.0
% INFO    : Bus 68641	: V=1.002722, theta=-83.602614 -> V=1.0, theta=0.0
% INFO    : Bus 68642	: V=1.002771, theta=-83.600624 -> V=1.0, theta=0.0
% INFO    : Bus 68643	: V=1.0030465, theta=-83.078496 -> V=1.0, theta=0.0
% INFO    : Bus 68644	: V=1.0030068, theta=-83.053744 -> V=1.0, theta=0.0
% INFO    : Bus 68645	: V=1.0031748, theta=-83.531248 -> V=1.0, theta=0.0
% INFO    : Bus 68646	: V=1.0029151, theta=-83.186015 -> V=1.0, theta=0.0
% INFO    : Bus 68647	: V=1.0028626, theta=-83.131938 -> V=1.0, theta=0.0
% INFO    : Bus 68648	: V=1.0030186, theta=-83.504646 -> V=1.0, theta=0.0
% INFO    : Bus 68649	: V=1.0029647, theta=-83.033633 -> V=1.0, theta=0.0
% INFO    : Bus 68650	: V=1.0027233, theta=-83.541266 -> V=1.0, theta=0.0
% INFO    : Bus 68651	: V=1.0028075, theta=-83.509239 -> V=1.0, theta=0.0
% INFO    : Bus 68652	: V=1.0028315, theta=-83.513789 -> V=1.0, theta=0.0
% INFO    : Bus 68653	: V=1.0029008, theta=-83.511801 -> V=1.0, theta=0.0
% INFO    : Bus 68654	: V=1.0029984, theta=-83.559871 -> V=1.0, theta=0.0
% INFO    : Bus 68655	: V=1.0030285, theta=-83.506607 -> V=1.0, theta=0.0
% INFO    : Bus 68656	: V=1.0025974, theta=-83.704462 -> V=1.0, theta=0.0
% INFO    : Bus 68657	: V=1.0033107, theta=-83.289625 -> V=1.0, theta=0.0
% INFO    : Bus 68658	: V=1.0019796, theta=-83.719279 -> V=1.0, theta=0.0
% INFO    : Bus 68659	: V=1.0025257, theta=-83.388535 -> V=1.0, theta=0.0
% INFO    : Bus 68660	: V=1.0021611, theta=-83.658807 -> V=1.0, theta=0.0
% INFO    : Bus 68661	: V=1.0025733, theta=-83.380716 -> V=1.0, theta=0.0
% INFO    : Bus 68662	: V=1.0028616, theta=-83.409109 -> V=1.0, theta=0.0
% INFO    : Bus 68663	: V=1.0023864, theta=-83.678954 -> V=1.0, theta=0.0
% INFO    : Bus 68664	: V=1.0016119, theta=-83.753124 -> V=1.0, theta=0.0
% INFO    : Bus 68665	: V=1.00106, theta=-83.801683 -> V=1.0, theta=0.0
% INFO    : Bus 68666	: V=1.0012251, theta=-83.795521 -> V=1.0, theta=0.0
% INFO    : Bus 68667	: V=1.0025498, theta=-83.384591 -> V=1.0, theta=0.0
% INFO    : Bus 68668	: V=1.0019666, theta=-83.666719 -> V=1.0, theta=0.0
% INFO    : Bus 68669	: V=1.0027259, theta=-83.54752 -> V=1.0, theta=0.0
% INFO    : Bus 68670	: V=1.0025349, theta=-83.601476 -> V=1.0, theta=0.0
% INFO    : Bus 68671	: V=1.0026098, theta=-83.37292 -> V=1.0, theta=0.0
% INFO    : Bus 68672	: V=1.0028224, theta=-83.359288 -> V=1.0, theta=0.0
% INFO    : Bus 68673	: V=1.001529, theta=-83.77163 -> V=1.0, theta=0.0
% INFO    : Bus 68674	: V=1.0027954, theta=-83.340698 -> V=1.0, theta=0.0
% INFO    : Bus 68675	: V=1.001461, theta=-83.726489 -> V=1.0, theta=0.0
% INFO    : Bus 68676	: V=1.0026864, theta=-83.357471 -> V=1.0, theta=0.0
% INFO    : Bus 68677	: V=1.0016441, theta=-83.754169 -> V=1.0, theta=0.0
% INFO    : Bus 68678	: V=1.0029349, theta=-83.321902 -> V=1.0, theta=0.0
% INFO    : Bus 68679	: V=1.0015545, theta=-83.659788 -> V=1.0, theta=0.0
% INFO    : Bus 68680	: V=1.0023968, theta=-83.295189 -> V=1.0, theta=0.0
% INFO    : Bus 68681	: V=1.0030407, theta=-83.453632 -> V=1.0, theta=0.0
% INFO    : Bus 68682	: V=1.0028802, theta=-83.026525 -> V=1.0, theta=0.0
% INFO    : Bus 68683	: V=1.0023571, theta=-83.25806 -> V=1.0, theta=0.0
% INFO    : Bus 68684	: V=1.0028156, theta=-83.460671 -> V=1.0, theta=0.0
% INFO    : Bus 68685	: V=1.0018305, theta=-83.634058 -> V=1.0, theta=0.0
% INFO    : Bus 68686	: V=1.0019685, theta=-83.607148 -> V=1.0, theta=0.0
% INFO    : Bus 68687	: V=1.0021048, theta=-83.608144 -> V=1.0, theta=0.0
% INFO    : Bus 68688	: V=1.0023282, theta=-83.224086 -> V=1.0, theta=0.0
% INFO    : Bus 68689	: V=1.0026693, theta=-83.41917 -> V=1.0, theta=0.0
% INFO    : Bus 68690	: V=1.0026299, theta=-83.422369 -> V=1.0, theta=0.0
% INFO    : Bus 68691	: V=1.0028605, theta=-82.979838 -> V=1.0, theta=0.0
% INFO    : Bus 68692	: V=1.0028425, theta=-82.938125 -> V=1.0, theta=0.0
% INFO    : Bus 68693	: V=1.0028292, theta=-82.893637 -> V=1.0, theta=0.0
% INFO    : Bus 68694	: V=1.0027772, theta=-82.916513 -> V=1.0, theta=0.0
% INFO    : Bus 68695	: V=1.0029214, theta=-83.320785 -> V=1.0, theta=0.0
% INFO    : Bus 68696	: V=1.0024912, theta=-83.094296 -> V=1.0, theta=0.0
% INFO    : Bus 68697	: V=1.002427, theta=-83.495298 -> V=1.0, theta=0.0
% INFO    : Bus 68698	: V=1.0023461, theta=-83.537576 -> V=1.0, theta=0.0
% INFO    : Bus 68699	: V=1.0023308, theta=-83.562768 -> V=1.0, theta=0.0
% INFO    : Bus 68700	: V=1.0021937, theta=-83.603348 -> V=1.0, theta=0.0
% INFO    : Bus 68701	: V=1.0024237, theta=-83.158396 -> V=1.0, theta=0.0
% INFO    : Bus 68702	: V=1.0035376, theta=-83.12306 -> V=1.0, theta=0.0
% INFO    : Bus 68703	: V=1.0030859, theta=-83.461745 -> V=1.0, theta=0.0
% INFO    : Bus 68704	: V=1.0033317, theta=-82.629384 -> V=1.0, theta=0.0
% INFO    : Bus 68705	: V=1.002656, theta=-83.514879 -> V=1.0, theta=0.0
% INFO    : Bus 68706	: V=1.0029366, theta=-83.297327 -> V=1.0, theta=0.0
% INFO    : Bus 68707	: V=1.0027306, theta=-83.347628 -> V=1.0, theta=0.0
% INFO    : Bus 68708	: V=1.0028977, theta=-83.449851 -> V=1.0, theta=0.0
% INFO    : Bus 68709	: V=1.0029543, theta=-83.006922 -> V=1.0, theta=0.0
% INFO    : Bus 68710	: V=1.0028886, theta=-83.278393 -> V=1.0, theta=0.0
% INFO    : Bus 68711	: V=1.0027383, theta=-83.329673 -> V=1.0, theta=0.0
% INFO    : Bus 68712	: V=1.0027987, theta=-83.301257 -> V=1.0, theta=0.0
% INFO    : Bus 68713	: V=1.0029543, theta=-83.277635 -> V=1.0, theta=0.0
% INFO    : Bus 68714	: V=1.0033543, theta=-82.609099 -> V=1.0, theta=0.0
% INFO    : Bus 68715	: V=1.0024321, theta=-83.230198 -> V=1.0, theta=0.0
% INFO    : Bus 68716	: V=1.0025643, theta=-83.224175 -> V=1.0, theta=0.0
% INFO    : Bus 68717	: V=1.0026966, theta=-83.219605 -> V=1.0, theta=0.0
% INFO    : Bus 68718	: V=1.0028045, theta=-83.215211 -> V=1.0, theta=0.0
% INFO    : Bus 68719	: V=1.0031161, theta=-83.216359 -> V=1.0, theta=0.0
% INFO    : Bus 68720	: V=1.002838, theta=-82.77583 -> V=1.0, theta=0.0
% INFO    : Bus 68721	: V=1.0031434, theta=-83.255563 -> V=1.0, theta=0.0
% INFO    : Bus 68722	: V=1.0029785, theta=-83.278463 -> V=1.0, theta=0.0
% INFO    : Bus 68723	: V=1.0029221, theta=-82.696773 -> V=1.0, theta=0.0
% INFO    : Bus 68724	: V=1.0029213, theta=-83.225151 -> V=1.0, theta=0.0
% INFO    : Bus 68725	: V=1.002926, theta=-83.018805 -> V=1.0, theta=0.0
% INFO    : Bus 68726	: V=1.0029481, theta=-83.235627 -> V=1.0, theta=0.0
% INFO    : Bus 68727	: V=1.0032104, theta=-83.147712 -> V=1.0, theta=0.0
% INFO    : Bus 68728	: V=1.0030678, theta=-83.393018 -> V=1.0, theta=0.0
% INFO    : Bus 68729	: V=1.0030915, theta=-83.391472 -> V=1.0, theta=0.0
% INFO    : Bus 68730	: V=1.0031486, theta=-83.38935 -> V=1.0, theta=0.0
% INFO    : Bus 68731	: V=1.0030213, theta=-83.31015 -> V=1.0, theta=0.0
% INFO    : Bus 68732	: V=1.0031499, theta=-83.244269 -> V=1.0, theta=0.0
% INFO    : Bus 68733	: V=1.0031017, theta=-83.023988 -> V=1.0, theta=0.0
% INFO    : Bus 68734	: V=1.003055, theta=-83.055441 -> V=1.0, theta=0.0
% INFO    : Bus 68735	: V=1.0049919, theta=-82.180067 -> V=1.0, theta=0.0
% INFO    : Bus 68736	: V=1.0042023, theta=-82.899182 -> V=1.0, theta=0.0
% INFO    : Bus 68737	: V=1.0029965, theta=-83.057169 -> V=1.0, theta=0.0
% INFO    : Bus 68738	: V=1.0035924, theta=-82.932003 -> V=1.0, theta=0.0
% INFO    : Bus 68739	: V=1.0043368, theta=-82.308634 -> V=1.0, theta=0.0
% INFO    : Bus 68740	: V=1.0039133, theta=-82.84289 -> V=1.0, theta=0.0
% INFO    : Bus 68741	: V=1.0040397, theta=-82.78659 -> V=1.0, theta=0.0
% INFO    : Bus 68742	: V=1.0045059, theta=-82.461101 -> V=1.0, theta=0.0
% INFO    : Bus 68743	: V=1.0042064, theta=-82.720821 -> V=1.0, theta=0.0
% INFO    : Bus 68744	: V=1.0043095, theta=-82.662797 -> V=1.0, theta=0.0
% INFO    : Bus 68745	: V=1.003925, theta=-82.859383 -> V=1.0, theta=0.0
% INFO    : Bus 68746	: V=1.0039653, theta=-82.798984 -> V=1.0, theta=0.0
% INFO    : Bus 68747	: V=1.0032004, theta=-82.799323 -> V=1.0, theta=0.0
% INFO    : Bus 68748	: V=1.0033734, theta=-82.79228 -> V=1.0, theta=0.0
% INFO    : Bus 68749	: V=1.0036655, theta=-82.76938 -> V=1.0, theta=0.0
% INFO    : Bus 68750	: V=1.0040245, theta=-82.727189 -> V=1.0, theta=0.0
% INFO    : Bus 68751	: V=1.0045129, theta=-82.576499 -> V=1.0, theta=0.0
% INFO    : Bus 68752	: V=1.0046811, theta=-82.526638 -> V=1.0, theta=0.0
% INFO    : Bus 68753	: V=1.0050044, theta=-82.442565 -> V=1.0, theta=0.0
% INFO    : Bus 68754	: V=1.0039757, theta=-81.652065 -> V=1.0, theta=0.0
% INFO    : Bus 68755	: V=1.0050305, theta=-82.425116 -> V=1.0, theta=0.0
% INFO    : Bus 68756	: V=1.0047478, theta=-82.528594 -> V=1.0, theta=0.0
% INFO    : Bus 68757	: V=1.0032155, theta=-82.57363 -> V=1.0, theta=0.0
% INFO    : Bus 68758	: V=1.0032996, theta=-82.172635 -> V=1.0, theta=0.0
% INFO    : Bus 68759	: V=1.0035842, theta=-82.007636 -> V=1.0, theta=0.0
% INFO    : Bus 68760	: V=1.0036768, theta=-82.415093 -> V=1.0, theta=0.0
% INFO    : Bus 68761	: V=1.0031344, theta=-83.035626 -> V=1.0, theta=0.0
% INFO    : Bus 68762	: V=1.0030764, theta=-82.969023 -> V=1.0, theta=0.0
% INFO    : Bus 68763	: V=1.0031782, theta=-83.080908 -> V=1.0, theta=0.0
% INFO    : Bus 68764	: V=1.0027976, theta=-82.744257 -> V=1.0, theta=0.0
% INFO    : Bus 68765	: V=1.002806, theta=-82.697315 -> V=1.0, theta=0.0
% INFO    : Bus 68766	: V=1.0026104, theta=-82.98508 -> V=1.0, theta=0.0
% INFO    : Bus 68767	: V=1.0031812, theta=-82.961463 -> V=1.0, theta=0.0
% INFO    : Bus 68768	: V=1.00326, theta=-82.428883 -> V=1.0, theta=0.0
% INFO    : Bus 68769	: V=1.0031162, theta=-82.804629 -> V=1.0, theta=0.0
% INFO    : Bus 68770	: V=1.0031276, theta=-82.333778 -> V=1.0, theta=0.0
% INFO    : Bus 68771	: V=1.0024662, theta=-82.910842 -> V=1.0, theta=0.0
% INFO    : Bus 68772	: V=1.0031553, theta=-82.329131 -> V=1.0, theta=0.0
% INFO    : Bus 68773	: V=1.0023428, theta=-82.924792 -> V=1.0, theta=0.0
% INFO    : Bus 68774	: V=1.0028658, theta=-82.836726 -> V=1.0, theta=0.0
% INFO    : Bus 68775	: V=1.0028491, theta=-82.644328 -> V=1.0, theta=0.0
% INFO    : Bus 68776	: V=1.0028596, theta=-82.605388 -> V=1.0, theta=0.0
% INFO    : Bus 68777	: V=1.0029622, theta=-82.757348 -> V=1.0, theta=0.0
% INFO    : Bus 68778	: V=1.0030979, theta=-82.299284 -> V=1.0, theta=0.0
% INFO    : Bus 68779	: V=1.0030968, theta=-82.229948 -> V=1.0, theta=0.0
% INFO    : Bus 68780	: V=1.003099, theta=-83.120568 -> V=1.0, theta=0.0
% INFO    : Bus 68781	: V=1.0027383, theta=-82.942683 -> V=1.0, theta=0.0
% INFO    : Bus 68782	: V=1.0026055, theta=-83.155204 -> V=1.0, theta=0.0
% INFO    : Bus 68783	: V=1.0025413, theta=-83.078156 -> V=1.0, theta=0.0
% INFO    : Bus 68784	: V=1.0025752, theta=-83.106707 -> V=1.0, theta=0.0
% INFO    : Bus 68785	: V=1.0029624, theta=-82.613131 -> V=1.0, theta=0.0
% INFO    : Bus 68786	: V=1.0030343, theta=-82.59976 -> V=1.0, theta=0.0
% INFO    : Bus 68787	: V=1.0034058, theta=-82.890643 -> V=1.0, theta=0.0
% INFO    : Bus 68788	: V=1.0030541, theta=-82.910474 -> V=1.0, theta=0.0
% INFO    : Bus 68789	: V=1.0028258, theta=-82.922856 -> V=1.0, theta=0.0
% INFO    : Bus 68790	: V=1.0023796, theta=-82.949649 -> V=1.0, theta=0.0
% INFO    : Bus 68791	: V=1.0030624, theta=-82.451977 -> V=1.0, theta=0.0
% INFO    : Bus 68792	: V=1.0030929, theta=-82.458961 -> V=1.0, theta=0.0
% INFO    : Bus 68793	: V=1.0018918, theta=-83.581299 -> V=1.0, theta=0.0
% INFO    : Bus 68794	: V=1.0027312, theta=-82.965801 -> V=1.0, theta=0.0
% INFO    : Bus 68795	: V=1.0018732, theta=-83.266885 -> V=1.0, theta=0.0
% INFO    : Bus 68796	: V=1.0025699, theta=-83.041735 -> V=1.0, theta=0.0
% INFO    : Bus 68797	: V=1.0018744, theta=-83.268871 -> V=1.0, theta=0.0
% INFO    : Bus 68798	: V=1.0025603, theta=-83.043062 -> V=1.0, theta=0.0
% INFO    : Bus 68799	: V=1.0030319, theta=-82.339398 -> V=1.0, theta=0.0
% INFO    : Bus 68800	: V=1.0034662, theta=-82.613702 -> V=1.0, theta=0.0
% INFO    : Bus 68801	: V=1.0030004, theta=-82.350524 -> V=1.0, theta=0.0
% INFO    : Bus 68802	: V=1.0029128, theta=-82.572025 -> V=1.0, theta=0.0
% INFO    : Bus 68803	: V=1.0029609, theta=-82.521147 -> V=1.0, theta=0.0
% INFO    : Bus 68804	: V=1.0029915, theta=-82.350448 -> V=1.0, theta=0.0
% INFO    : Bus 68805	: V=1.0029984, theta=-82.355974 -> V=1.0, theta=0.0
% INFO    : Bus 68806	: V=1.0012438, theta=-82.5593 -> V=1.0, theta=0.0
% INFO    : Bus 68807	: V=1.0025625, theta=-82.171112 -> V=1.0, theta=0.0
% INFO    : Bus 68808	: V=1.0024465, theta=-82.163485 -> V=1.0, theta=0.0
% INFO    : Bus 68809	: V=1.0023913, theta=-82.157789 -> V=1.0, theta=0.0
% INFO    : Bus 68810	: V=1.0013762, theta=-82.541601 -> V=1.0, theta=0.0
% INFO    : Bus 68811	: V=1.0030507, theta=-82.36962 -> V=1.0, theta=0.0
% INFO    : Bus 68812	: V=1.0029991, theta=-82.239597 -> V=1.0, theta=0.0
% INFO    : Bus 68813	: V=1.0017646, theta=-82.536343 -> V=1.0, theta=0.0
% INFO    : Bus 68814	: V=1.0016603, theta=-82.519018 -> V=1.0, theta=0.0
% INFO    : Bus 68815	: V=1.0023416, theta=-82.151454 -> V=1.0, theta=0.0
% INFO    : Bus 68816	: V=1.0022889, theta=-82.142023 -> V=1.0, theta=0.0
% INFO    : Bus 68817	: V=1.0017432, theta=-82.533378 -> V=1.0, theta=0.0
% INFO    : Bus 68818	: V=1.0028729, theta=-82.206092 -> V=1.0, theta=0.0
% INFO    : Bus 68819	: V=1.0031167, theta=-82.117765 -> V=1.0, theta=0.0
% INFO    : Bus 68820	: V=1.0026676, theta=-82.173535 -> V=1.0, theta=0.0
% INFO    : Bus 68821	: V=1.0027132, theta=-82.156911 -> V=1.0, theta=0.0
% INFO    : Bus 68822	: V=1.002789, theta=-82.12675 -> V=1.0, theta=0.0
% INFO    : Bus 68823	: V=1.0026553, theta=-82.106251 -> V=1.0, theta=0.0
% INFO    : Bus 68824	: V=1.0025822, theta=-82.091463 -> V=1.0, theta=0.0
% INFO    : Bus 68825	: V=1.0025402, theta=-82.16976 -> V=1.0, theta=0.0
% INFO    : Bus 68826	: V=1.0024753, theta=-82.166485 -> V=1.0, theta=0.0
% INFO    : Bus 68827	: V=1.0024266, theta=-82.162675 -> V=1.0, theta=0.0
% INFO    : Bus 68828	: V=1.0023767, theta=-82.15692 -> V=1.0, theta=0.0
% INFO    : Bus 68829	: V=1.0025262, theta=-82.07684 -> V=1.0, theta=0.0
% INFO    : Bus 68830	: V=1.0024671, theta=-82.059232 -> V=1.0, theta=0.0
% INFO    : Bus 68831	: V=1.0024149, theta=-82.037856 -> V=1.0, theta=0.0
% INFO    : Bus 68832	: V=1.0012173, theta=-82.116228 -> V=1.0, theta=0.0
% INFO    : Bus 68833	: V=1.0023051, theta=-82.145665 -> V=1.0, theta=0.0
% INFO    : Bus 68834	: V=1.0022296, theta=-82.126258 -> V=1.0, theta=0.0
% INFO    : Bus 68835	: V=1.0022003, theta=-82.089909 -> V=1.0, theta=0.0
% INFO    : Bus 68836	: V=1.0021866, theta=-82.057418 -> V=1.0, theta=0.0
% INFO    : Bus 68837	: V=1.0022253, theta=-82.051458 -> V=1.0, theta=0.0
% INFO    : Bus 68838	: V=1.0008696, theta=-82.133486 -> V=1.0, theta=0.0
% INFO    : Bus 68839	: V=1.0010736, theta=-81.785764 -> V=1.0, theta=0.0
% INFO    : Bus 68840	: V=1.0007898, theta=-81.756237 -> V=1.0, theta=0.0
% INFO    : Bus 68841	: V=1.0006275, theta=-81.730725 -> V=1.0, theta=0.0
% INFO    : Bus 68842	: V=0.9966835, theta=-81.589696 -> V=1.0, theta=0.0
% INFO    : Bus 68843	: V=0.9969635, theta=-81.548596 -> V=1.0, theta=0.0
% INFO    : Bus 68844	: V=1.0020166, theta=-82.022747 -> V=1.0, theta=0.0
% INFO    : Bus 68845	: V=1.0020427, theta=-82.025826 -> V=1.0, theta=0.0
% INFO    : Bus 68846	: V=1.0021435, theta=-82.031439 -> V=1.0, theta=0.0
% INFO    : Bus 68847	: V=0.9999536, theta=-82.04998 -> V=1.0, theta=0.0
% INFO    : Bus 68848	: V=0.9987832, theta=-81.969339 -> V=1.0, theta=0.0
% INFO    : Bus 68849	: V=0.9996505, theta=-82.064654 -> V=1.0, theta=0.0
% INFO    : Bus 68850	: V=0.9987942, theta=-81.687085 -> V=1.0, theta=0.0
% INFO    : Bus 68851	: V=1.0004564, theta=-81.837439 -> V=1.0, theta=0.0
% INFO    : Bus 68852	: V=1.0013041, theta=-81.537204 -> V=1.0, theta=0.0
% INFO    : Bus 68853	: V=1.0013648, theta=-81.529312 -> V=1.0, theta=0.0
% INFO    : Bus 68854	: V=0.9986378, theta=-81.589089 -> V=1.0, theta=0.0
% INFO    : Bus 68855	: V=0.9988328, theta=-81.652025 -> V=1.0, theta=0.0
% INFO    : Bus 68856	: V=0.9996106, theta=-81.696678 -> V=1.0, theta=0.0
% INFO    : Bus 68857	: V=0.9997301, theta=-81.687636 -> V=1.0, theta=0.0
% INFO    : Bus 68858	: V=1.0043326, theta=-83.889408 -> V=1.0, theta=0.0
% INFO    : Bus 68859	: V=1.0046355, theta=-83.890746 -> V=1.0, theta=0.0
% INFO    : Bus 68860	: V=1.0043287, theta=-83.876109 -> V=1.0, theta=0.0
% INFO    : Bus 68861	: V=1.0043749, theta=-83.833097 -> V=1.0, theta=0.0
% INFO    : Bus 68862	: V=1.003513, theta=-83.515831 -> V=1.0, theta=0.0
% INFO    : Bus 68863	: V=1.0035262, theta=-83.551159 -> V=1.0, theta=0.0
% INFO    : Bus 68864	: V=1.0034857, theta=-83.443466 -> V=1.0, theta=0.0
% INFO    : Bus 68865	: V=1.0029695, theta=-83.737788 -> V=1.0, theta=0.0
% INFO    : Bus 68866	: V=1.0021154, theta=-83.639952 -> V=1.0, theta=0.0
% INFO    : Bus 68867	: V=1.0039556, theta=-83.325729 -> V=1.0, theta=0.0
% INFO    : Bus 68868	: V=1.006554, theta=-83.119506 -> V=1.0, theta=0.0
% INFO    : Bus 68869	: V=1.0065374, theta=-83.098102 -> V=1.0, theta=0.0
% INFO    : Bus 68870	: V=1.0065779, theta=-83.050714 -> V=1.0, theta=0.0
% INFO    : Bus 68871	: V=1.0092885, theta=-82.670157 -> V=1.0, theta=0.0
% INFO    : Bus 68872	: V=1.0028667, theta=-83.39997 -> V=1.0, theta=0.0
% INFO    : Bus 68873	: V=1.0015972, theta=-83.649053 -> V=1.0, theta=0.0
% INFO    : Bus 68874	: V=1.0035275, theta=-83.380668 -> V=1.0, theta=0.0
% INFO    : Bus 68875	: V=1.0035827, theta=-83.358337 -> V=1.0, theta=0.0
% INFO    : Bus 68876	: V=1.0035982, theta=-83.321317 -> V=1.0, theta=0.0
% INFO    : Bus 68877	: V=1.0015773, theta=-83.608604 -> V=1.0, theta=0.0
% INFO    : Bus 68878	: V=1.001781, theta=-83.886502 -> V=1.0, theta=0.0
% INFO    : Bus 68879	: V=1.0026864, theta=-83.850544 -> V=1.0, theta=0.0
% INFO    : Bus 68880	: V=1.0023135, theta=-83.821905 -> V=1.0, theta=0.0
% INFO    : Bus 68881	: V=1.0033033, theta=-83.882886 -> V=1.0, theta=0.0
% INFO    : Bus 68882	: V=1.0024113, theta=-83.814577 -> V=1.0, theta=0.0
% INFO    : Bus 68883	: V=1.0023484, theta=-83.817127 -> V=1.0, theta=0.0
% INFO    : Bus 68884	: V=1.0025392, theta=-83.833025 -> V=1.0, theta=0.0
% INFO    : Bus 68885	: V=1.0023659, theta=-83.744802 -> V=1.0, theta=0.0
% INFO    : Bus 68886	: V=1.0023475, theta=-83.776444 -> V=1.0, theta=0.0
% INFO    : Bus 68887	: V=1.0021044, theta=-83.774937 -> V=1.0, theta=0.0
% INFO    : Bus 68888	: V=1.0020519, theta=-83.731536 -> V=1.0, theta=0.0
% INFO    : Bus 68889	: V=1.0019052, theta=-83.838576 -> V=1.0, theta=0.0
% INFO    : Bus 68890	: V=1.0020148, theta=-83.834114 -> V=1.0, theta=0.0
% INFO    : Bus 68891	: V=1.0011272, theta=-83.828165 -> V=1.0, theta=0.0
% INFO    : Bus 68892	: V=1.0016058, theta=-83.806365 -> V=1.0, theta=0.0
% INFO    : Bus 68893	: V=1.0040227, theta=-83.14414 -> V=1.0, theta=0.0
% INFO    : Bus 68894	: V=1.0012327, theta=-83.645784 -> V=1.0, theta=0.0
% INFO    : Bus 68895	: V=1.0015109, theta=-83.604642 -> V=1.0, theta=0.0
% INFO    : Bus 68896	: V=1.0018694, theta=-83.650336 -> V=1.0, theta=0.0
% INFO    : Bus 68897	: V=1.0037183, theta=-83.263184 -> V=1.0, theta=0.0
% INFO    : Bus 68898	: V=1.0039655, theta=-83.19942 -> V=1.0, theta=0.0
% INFO    : Bus 68899	: V=1.0014281, theta=-83.620403 -> V=1.0, theta=0.0
% INFO    : Bus 68900	: V=1.0044041, theta=-83.103303 -> V=1.0, theta=0.0
% INFO    : Bus 68901	: V=1.0028948, theta=-83.612382 -> V=1.0, theta=0.0
% INFO    : Bus 68902	: V=1.0025195, theta=-83.640149 -> V=1.0, theta=0.0
% INFO    : Bus 68903	: V=1.0010574, theta=-83.835212 -> V=1.0, theta=0.0
% INFO    : Bus 68904	: V=1.001198, theta=-83.828943 -> V=1.0, theta=0.0
% INFO    : Bus 68905	: V=1.0021652, theta=-83.711964 -> V=1.0, theta=0.0
% INFO    : Bus 68906	: V=1.0014643, theta=-83.778864 -> V=1.0, theta=0.0
% INFO    : Bus 68907	: V=1.0009187, theta=-83.840359 -> V=1.0, theta=0.0
% INFO    : Bus 68908	: V=1.0020863, theta=-83.691073 -> V=1.0, theta=0.0
% INFO    : Bus 68909	: V=1.0031959, theta=-83.258054 -> V=1.0, theta=0.0
% INFO    : Bus 68910	: V=1.0022042, theta=-83.656996 -> V=1.0, theta=0.0
% INFO    : Bus 68911	: V=1.0022443, theta=-83.604599 -> V=1.0, theta=0.0
% INFO    : Bus 68912	: V=1.0021685, theta=-83.571599 -> V=1.0, theta=0.0
% INFO    : Bus 68913	: V=1.0035353, theta=-83.516499 -> V=1.0, theta=0.0
% INFO    : Bus 68914	: V=1.0027358, theta=-83.543332 -> V=1.0, theta=0.0
% INFO    : Bus 68915	: V=1.0034482, theta=-83.519738 -> V=1.0, theta=0.0
% INFO    : Bus 68916	: V=1.0023881, theta=-83.549034 -> V=1.0, theta=0.0
% INFO    : Bus 68917	: V=1.0025534, theta=-83.544985 -> V=1.0, theta=0.0
% INFO    : Bus 68918	: V=1.0021847, theta=-83.549253 -> V=1.0, theta=0.0
% INFO    : Bus 68919	: V=1.0034751, theta=-83.181596 -> V=1.0, theta=0.0
% INFO    : Bus 68920	: V=1.0022551, theta=-83.627667 -> V=1.0, theta=0.0
% INFO    : Bus 68921	: V=1.0030616, theta=-83.590629 -> V=1.0, theta=0.0
% INFO    : Bus 68922	: V=1.0034062, theta=-83.550992 -> V=1.0, theta=0.0
% INFO    : Bus 68923	: V=1.0045763, theta=-83.032086 -> V=1.0, theta=0.0
% INFO    : Bus 68924	: V=1.0056254, theta=-82.81321 -> V=1.0, theta=0.0
% INFO    : Bus 68925	: V=1.0050559, theta=-82.934006 -> V=1.0, theta=0.0
% INFO    : Bus 68926	: V=1.0039351, theta=-83.47101 -> V=1.0, theta=0.0
% INFO    : Bus 68927	: V=1.0041525, theta=-83.082221 -> V=1.0, theta=0.0
% INFO    : Bus 68928	: V=1.0042495, theta=-83.074006 -> V=1.0, theta=0.0
% INFO    : Bus 68929	: V=1.0036605, theta=-83.442282 -> V=1.0, theta=0.0
% INFO    : Bus 68930	: V=1.0038411, theta=-83.505119 -> V=1.0, theta=0.0
% INFO    : Bus 68931	: V=1.0038291, theta=-83.420166 -> V=1.0, theta=0.0
% INFO    : Bus 68932	: V=1.0041396, theta=-83.385559 -> V=1.0, theta=0.0
% INFO    : Bus 68933	: V=1.0058707, theta=-82.758857 -> V=1.0, theta=0.0
% INFO    : Bus 68934	: V=1.0059571, theta=-82.723263 -> V=1.0, theta=0.0
% INFO    : Bus 68935	: V=1.0063381, theta=-82.640264 -> V=1.0, theta=0.0
% INFO    : Bus 68936	: V=1.0037674, theta=-83.287716 -> V=1.0, theta=0.0
% INFO    : Bus 68937	: V=1.0060508, theta=-82.689944 -> V=1.0, theta=0.0
% INFO    : Bus 68938	: V=1.0060016, theta=-82.707322 -> V=1.0, theta=0.0
% INFO    : Bus 68939	: V=1.0036913, theta=-83.043491 -> V=1.0, theta=0.0
% INFO    : Bus 68940	: V=1.0041461, theta=-83.014132 -> V=1.0, theta=0.0
% INFO    : Bus 68941	: V=1.009967, theta=-82.22559 -> V=1.0, theta=0.0
% INFO    : Bus 68942	: V=1.0100003, theta=-82.143402 -> V=1.0, theta=0.0
% INFO    : Bus 68943	: V=1.0038642, theta=-83.042362 -> V=1.0, theta=0.0
% INFO    : Bus 68944	: V=1.0061815, theta=-82.653453 -> V=1.0, theta=0.0
% INFO    : Bus 68945	: V=1.0063217, theta=-82.617801 -> V=1.0, theta=0.0
% INFO    : Bus 68946	: V=1.0076269, theta=-82.372152 -> V=1.0, theta=0.0
% INFO    : Bus 68947	: V=1.0065225, theta=-82.580008 -> V=1.0, theta=0.0
% INFO    : Bus 68948	: V=1.0040945, theta=-82.826067 -> V=1.0, theta=0.0
% INFO    : Bus 68949	: V=1.0034325, theta=-83.261403 -> V=1.0, theta=0.0
% INFO    : Bus 68950	: V=1.0036871, theta=-83.227643 -> V=1.0, theta=0.0
% INFO    : Bus 68951	: V=1.0039925, theta=-83.177262 -> V=1.0, theta=0.0
% INFO    : Bus 68952	: V=1.0108176, theta=-81.79288 -> V=1.0, theta=0.0
% INFO    : Bus 68953	: V=1.005962, theta=-82.64032 -> V=1.0, theta=0.0
% INFO    : Bus 68954	: V=1.0064917, theta=-82.604762 -> V=1.0, theta=0.0
% INFO    : Bus 68955	: V=1.003723, theta=-83.155842 -> V=1.0, theta=0.0
% INFO    : Bus 68956	: V=1.0046115, theta=-82.77255 -> V=1.0, theta=0.0
% INFO    : Bus 68957	: V=1.0041043, theta=-83.002999 -> V=1.0, theta=0.0
% INFO    : Bus 68958	: V=1.0031217, theta=-82.947758 -> V=1.0, theta=0.0
% INFO    : Bus 68959	: V=1.0026468, theta=-83.104954 -> V=1.0, theta=0.0
% INFO    : Bus 68960	: V=1.0042486, theta=-82.69522 -> V=1.0, theta=0.0
% INFO    : Bus 68961	: V=1.0044848, theta=-82.67141 -> V=1.0, theta=0.0
% INFO    : Bus 68962	: V=1.0076201, theta=-82.275647 -> V=1.0, theta=0.0
% INFO    : Bus 68963	: V=1.0072744, theta=-82.35669 -> V=1.0, theta=0.0
% INFO    : Bus 68964	: V=1.0104924, theta=-81.04659 -> V=1.0, theta=0.0
% INFO    : Bus 68965	: V=1.0035075, theta=-82.872575 -> V=1.0, theta=0.0
% INFO    : Bus 68966	: V=1.0027603, theta=-83.016086 -> V=1.0, theta=0.0
% INFO    : Bus 68967	: V=1.0019824, theta=-83.035225 -> V=1.0, theta=0.0
% INFO    : Bus 68968	: V=1.0026911, theta=-82.930991 -> V=1.0, theta=0.0
% INFO    : Bus 68969	: V=1.00719, theta=-82.012667 -> V=1.0, theta=0.0
% INFO    : Bus 68970	: V=1.0100003, theta=-81.116866 -> V=1.0, theta=0.0
% INFO    : Bus 68971	: V=0.9980324, theta=-81.897306 -> V=1.0, theta=0.0
% INFO    : Bus 68972	: V=0.9974164, theta=-81.80332 -> V=1.0, theta=0.0
% INFO    : Bus 68973	: V=0.9999438, theta=-81.551375 -> V=1.0, theta=0.0
% INFO    : Bus 68974	: V=0.9959223, theta=-81.571383 -> V=1.0, theta=0.0
% INFO    : Bus 68975	: V=0.9946501, theta=-81.384561 -> V=1.0, theta=0.0
% INFO    : Bus 68976	: V=0.9905961, theta=-81.297331 -> V=1.0, theta=0.0
% INFO    : Bus 68977	: V=0.9996268, theta=-80.261881 -> V=1.0, theta=0.0
% INFO    : Bus 68978	: V=0.9911621, theta=-80.795624 -> V=1.0, theta=0.0
% INFO    : Bus 68979	: V=0.9912002, theta=-80.599785 -> V=1.0, theta=0.0
% INFO    : Bus 68980	: V=0.9921161, theta=-80.495501 -> V=1.0, theta=0.0
% INFO    : Bus 68981	: V=0.9918054, theta=-80.420834 -> V=1.0, theta=0.0
% INFO    : Bus 68982	: V=0.9938692, theta=-80.253049 -> V=1.0, theta=0.0
% INFO    : Bus 68983	: V=0.995053, theta=-80.244181 -> V=1.0, theta=0.0
% INFO    : Bus 68984	: V=0.9945137, theta=-80.246421 -> V=1.0, theta=0.0
% INFO    : Bus 68985	: V=0.999506, theta=-79.630821 -> V=1.0, theta=0.0
% INFO    : Bus 68986	: V=1.0001378, theta=-79.256449 -> V=1.0, theta=0.0
% INFO    : Bus 68987	: V=0.997451, theta=-79.965686 -> V=1.0, theta=0.0
% INFO    : Bus 68988	: V=0.9959446, theta=-80.072259 -> V=1.0, theta=0.0
% INFO    : Bus 68989	: V=0.9976602, theta=-79.969646 -> V=1.0, theta=0.0
% INFO    : Bus 68990	: V=0.9945649, theta=-80.165112 -> V=1.0, theta=0.0
% INFO    : Bus 68991	: V=0.9942097, theta=-80.249186 -> V=1.0, theta=0.0
% INFO    : Bus 68992	: V=0.9999485, theta=-79.739082 -> V=1.0, theta=0.0
% INFO    : Bus 68993	: V=1.0001753, theta=-79.73586 -> V=1.0, theta=0.0
% INFO    : Bus 68994	: V=1.0004006, theta=-79.61453 -> V=1.0, theta=0.0
% INFO    : Bus 68995	: V=1.0008839, theta=-79.378669 -> V=1.0, theta=0.0
% INFO    : Bus 68996	: V=1.0002729, theta=-79.446931 -> V=1.0, theta=0.0
% INFO    : Bus 68997	: V=1.0002081, theta=-79.928516 -> V=1.0, theta=0.0
% INFO    : Bus 68998	: V=1.0001715, theta=-79.84427 -> V=1.0, theta=0.0
% INFO    : Bus 68999	: V=1.0005501, theta=-79.788815 -> V=1.0, theta=0.0
% INFO    : Bus 69000	: V=1.0003753, theta=-80.054121 -> V=1.0, theta=0.0
% INFO    : Bus 69001	: V=1.0005224, theta=-80.337848 -> V=1.0, theta=0.0
% INFO    : Bus 69002	: V=1.0017917, theta=-80.239985 -> V=1.0, theta=0.0
% INFO    : Bus 69003	: V=1.0014538, theta=-80.342024 -> V=1.0, theta=0.0
% INFO    : Bus 69004	: V=1.0015501, theta=-80.486414 -> V=1.0, theta=0.0
% INFO    : Bus 69005	: V=0.9997751, theta=-80.531026 -> V=1.0, theta=0.0
% INFO    : Bus 69006	: V=1.0012891, theta=-80.488416 -> V=1.0, theta=0.0
% INFO    : Bus 69007	: V=1.0015491, theta=-80.350043 -> V=1.0, theta=0.0
% INFO    : Bus 69008	: V=1.0012841, theta=-80.445387 -> V=1.0, theta=0.0
% INFO    : Bus 69009	: V=1.0024752, theta=-80.628842 -> V=1.0, theta=0.0
% INFO    : Bus 69010	: V=1.0009883, theta=-80.446781 -> V=1.0, theta=0.0
% INFO    : Bus 69011	: V=0.9986774, theta=-80.538985 -> V=1.0, theta=0.0
% INFO    : Bus 69012	: V=1.0007494, theta=-80.451495 -> V=1.0, theta=0.0
% INFO    : Bus 69013	: V=1.0017067, theta=-80.636278 -> V=1.0, theta=0.0
% INFO    : Bus 69014	: V=1.0022217, theta=-80.628779 -> V=1.0, theta=0.0
% INFO    : Bus 69015	: V=1.0022148, theta=-80.63052 -> V=1.0, theta=0.0
% INFO    : Bus 69016	: V=1.0041374, theta=-80.839023 -> V=1.0, theta=0.0
% INFO    : Bus 69017	: V=0.9980823, theta=-80.540368 -> V=1.0, theta=0.0
% INFO    : Bus 69018	: V=1.0047008, theta=-80.832285 -> V=1.0, theta=0.0
% INFO    : Bus 69019	: V=1.0040041, theta=-80.835942 -> V=1.0, theta=0.0
% INFO    : Bus 69020	: V=1.0040987, theta=-80.835134 -> V=1.0, theta=0.0
% INFO    : Bus 69021	: V=1.0071269, theta=-83.848218 -> V=1.0, theta=0.0
% INFO    : Bus 69022	: V=1.0072896, theta=-83.299514 -> V=1.0, theta=0.0
% INFO    : Bus 69023	: V=1.0075174, theta=-83.299803 -> V=1.0, theta=0.0
% INFO    : Bus 69024	: V=1.0069103, theta=-83.859253 -> V=1.0, theta=0.0
% INFO    : Bus 69025	: V=1.0074796, theta=-83.836099 -> V=1.0, theta=0.0
% INFO    : Bus 69026	: V=1.0068089, theta=-83.820711 -> V=1.0, theta=0.0
% INFO    : Bus 69027	: V=1.0075019, theta=-83.79508 -> V=1.0, theta=0.0
% INFO    : Bus 69028	: V=1.0081396, theta=-83.708255 -> V=1.0, theta=0.0
% INFO    : Bus 69029	: V=1.0089542, theta=-83.554015 -> V=1.0, theta=0.0
% INFO    : Bus 69030	: V=1.004165, theta=-83.807195 -> V=1.0, theta=0.0
% INFO    : Bus 69031	: V=1.0030747, theta=-83.818919 -> V=1.0, theta=0.0
% INFO    : Bus 69032	: V=1.0026816, theta=-83.796416 -> V=1.0, theta=0.0
% INFO    : Bus 69033	: V=1.0053605, theta=-83.689317 -> V=1.0, theta=0.0
% INFO    : Bus 69034	: V=1.0056088, theta=-83.681406 -> V=1.0, theta=0.0
% INFO    : Bus 69035	: V=1.007718, theta=-83.555565 -> V=1.0, theta=0.0
% INFO    : Bus 69036	: V=1.0075249, theta=-83.571386 -> V=1.0, theta=0.0
% INFO    : Bus 69037	: V=1.0082262, theta=-83.513643 -> V=1.0, theta=0.0
% INFO    : Bus 69038	: V=1.0079567, theta=-83.522174 -> V=1.0, theta=0.0
% INFO    : Bus 69039	: V=1.0087748, theta=-83.459276 -> V=1.0, theta=0.0
% INFO    : Bus 69040	: V=1.0097148, theta=-83.367172 -> V=1.0, theta=0.0
% INFO    : Bus 69041	: V=1.0104211, theta=-83.290047 -> V=1.0, theta=0.0
% INFO    : Bus 69042	: V=1.0104683, theta=-83.288301 -> V=1.0, theta=0.0
% INFO    : Bus 69043	: V=1.0099121, theta=-82.681602 -> V=1.0, theta=0.0
% INFO    : Bus 69044	: V=1.00954, theta=-83.191931 -> V=1.0, theta=0.0
% INFO    : Bus 69045	: V=1.0098771, theta=-82.695168 -> V=1.0, theta=0.0
% INFO    : Bus 69046	: V=1.0090086, theta=-82.843731 -> V=1.0, theta=0.0
% INFO    : Bus 69047	: V=1.0073583, theta=-83.582456 -> V=1.0, theta=0.0
% INFO    : Bus 69048	: V=1.0084919, theta=-82.915041 -> V=1.0, theta=0.0
% INFO    : Bus 69049	: V=1.0060066, theta=-83.66528 -> V=1.0, theta=0.0
% INFO    : Bus 69050	: V=1.0070083, theta=-83.616416 -> V=1.0, theta=0.0
% INFO    : Bus 69051	: V=1.005719, theta=-83.664838 -> V=1.0, theta=0.0
% INFO    : Bus 69052	: V=1.0058524, theta=-83.659435 -> V=1.0, theta=0.0
% INFO    : Bus 69053	: V=1.0053184, theta=-83.670817 -> V=1.0, theta=0.0
% INFO    : Bus 69054	: V=1.0075349, theta=-83.02847 -> V=1.0, theta=0.0
% INFO    : Bus 69055	: V=1.0057542, theta=-83.649679 -> V=1.0, theta=0.0
% INFO    : Bus 69056	: V=1.007927, theta=-82.984045 -> V=1.0, theta=0.0
% INFO    : Bus 69057	: V=1.0066277, theta=-83.638756 -> V=1.0, theta=0.0
% INFO    : Bus 69058	: V=1.0069301, theta=-83.617301 -> V=1.0, theta=0.0
% INFO    : Bus 69059	: V=1.0066502, theta=-83.624482 -> V=1.0, theta=0.0
% INFO    : Bus 69060	: V=1.0074544, theta=-83.020979 -> V=1.0, theta=0.0
% INFO    : Bus 69061	: V=1.0064896, theta=-83.643747 -> V=1.0, theta=0.0
% INFO    : Bus 69062	: V=1.0064328, theta=-83.641976 -> V=1.0, theta=0.0
% INFO    : Bus 69063	: V=1.0072406, theta=-83.051279 -> V=1.0, theta=0.0
% INFO    : Bus 69064	: V=1.0062553, theta=-83.632127 -> V=1.0, theta=0.0
% INFO    : Bus 69065	: V=1.0106041, theta=-83.54143 -> V=1.0, theta=0.0
% INFO    : Bus 69066	: V=1.0141958, theta=-83.159897 -> V=1.0, theta=0.0
% INFO    : Bus 69067	: V=1.0142102, theta=-83.172438 -> V=1.0, theta=0.0
% INFO    : Bus 69068	: V=1.0109447, theta=-83.49246 -> V=1.0, theta=0.0
% INFO    : Bus 69069	: V=1.0104427, theta=-83.492233 -> V=1.0, theta=0.0
% INFO    : Bus 69070	: V=1.0114262, theta=-82.940516 -> V=1.0, theta=0.0
% INFO    : Bus 69071	: V=1.0109211, theta=-82.877884 -> V=1.0, theta=0.0
% INFO    : Bus 69072	: V=1.0106143, theta=-82.809495 -> V=1.0, theta=0.0
% INFO    : Bus 69073	: V=1.0103658, theta=-82.72073 -> V=1.0, theta=0.0
% INFO    : Bus 69074	: V=1.0146154, theta=-83.171636 -> V=1.0, theta=0.0
% INFO    : Bus 69075	: V=1.0121223, theta=-83.169231 -> V=1.0, theta=0.0
% INFO    : Bus 69076	: V=1.0098141, theta=-82.667365 -> V=1.0, theta=0.0
% INFO    : Bus 69077	: V=1.0101112, theta=-83.269925 -> V=1.0, theta=0.0
% INFO    : Bus 69078	: V=1.0095927, theta=-83.447278 -> V=1.0, theta=0.0
% INFO    : Bus 69079	: V=1.0095179, theta=-83.546407 -> V=1.0, theta=0.0
% INFO    : Bus 69080	: V=1.0091948, theta=-83.484593 -> V=1.0, theta=0.0
% INFO    : Bus 69081	: V=1.0092441, theta=-83.440425 -> V=1.0, theta=0.0
% INFO    : Bus 69082	: V=1.0093594, theta=-83.445091 -> V=1.0, theta=0.0
% INFO    : Bus 69083	: V=1.0095655, theta=-82.715643 -> V=1.0, theta=0.0
% INFO    : Bus 69084	: V=1.0081379, theta=-83.127871 -> V=1.0, theta=0.0
% INFO    : Bus 69085	: V=1.0089515, theta=-83.289161 -> V=1.0, theta=0.0
% INFO    : Bus 69086	: V=1.0092897, theta=-83.160835 -> V=1.0, theta=0.0
% INFO    : Bus 69087	: V=1.0090615, theta=-83.124553 -> V=1.0, theta=0.0
% INFO    : Bus 69088	: V=1.0064839, theta=-83.461123 -> V=1.0, theta=0.0
% INFO    : Bus 69089	: V=1.0111714, theta=-82.91404 -> V=1.0, theta=0.0
% INFO    : Bus 69090	: V=1.010423, theta=-83.441144 -> V=1.0, theta=0.0
% INFO    : Bus 69091	: V=1.0108793, theta=-83.401002 -> V=1.0, theta=0.0
% INFO    : Bus 69092	: V=1.0126517, theta=-82.890839 -> V=1.0, theta=0.0
% INFO    : Bus 69093	: V=0.9900212, theta=-76.89272 -> V=1.0, theta=0.0
% INFO    : Bus 69094	: V=0.9892991, theta=-76.016599 -> V=1.0, theta=0.0
% INFO    : Bus 69095	: V=0.9899515, theta=-75.98622 -> V=1.0, theta=0.0
% INFO    : Bus 69096	: V=0.9899131, theta=-77.260968 -> V=1.0, theta=0.0
% INFO    : Bus 69097	: V=0.9894537, theta=-77.187576 -> V=1.0, theta=0.0
% INFO    : Bus 69098	: V=0.9905035, theta=-77.494129 -> V=1.0, theta=0.0
% INFO    : Bus 69099	: V=0.9902378, theta=-78.216913 -> V=1.0, theta=0.0
% INFO    : Bus 69100	: V=0.9899688, theta=-77.678665 -> V=1.0, theta=0.0
% INFO    : Bus 69101	: V=0.989347, theta=-78.25113 -> V=1.0, theta=0.0
% INFO    : Bus 69102	: V=0.9909951, theta=-79.444215 -> V=1.0, theta=0.0
% INFO    : Bus 69103	: V=0.9905653, theta=-79.495665 -> V=1.0, theta=0.0
% INFO    : Bus 69104	: V=0.9953003, theta=-79.538562 -> V=1.0, theta=0.0
% INFO    : Bus 69105	: V=0.9914469, theta=-79.426341 -> V=1.0, theta=0.0
% INFO    : Bus 69106	: V=0.9909639, theta=-79.265992 -> V=1.0, theta=0.0
% INFO    : Bus 69107	: V=0.9908693, theta=-79.034403 -> V=1.0, theta=0.0
% INFO    : Bus 69108	: V=0.9902375, theta=-78.627146 -> V=1.0, theta=0.0
% INFO    : Bus 69109	: V=0.9904941, theta=-78.845353 -> V=1.0, theta=0.0
% INFO    : Bus 69110	: V=0.9907108, theta=-78.681935 -> V=1.0, theta=0.0
% INFO    : Bus 69111	: V=0.9904837, theta=-78.811851 -> V=1.0, theta=0.0
% INFO    : Bus 69112	: V=0.9903813, theta=-78.370275 -> V=1.0, theta=0.0
% INFO    : Bus 69113	: V=0.9902929, theta=-78.17936 -> V=1.0, theta=0.0
% INFO    : Bus 69114	: V=0.9909343, theta=-78.79686 -> V=1.0, theta=0.0
% INFO    : Bus 69115	: V=0.9911979, theta=-77.493901 -> V=1.0, theta=0.0
% INFO    : Bus 69116	: V=0.9908323, theta=-77.508356 -> V=1.0, theta=0.0
% INFO    : Bus 69117	: V=0.9903987, theta=-77.748951 -> V=1.0, theta=0.0
% INFO    : Bus 69118	: V=0.9902287, theta=-77.967678 -> V=1.0, theta=0.0
% INFO    : Bus 69119	: V=0.99021, theta=-76.854015 -> V=1.0, theta=0.0
% INFO    : Bus 69120	: V=0.9899906, theta=-76.940012 -> V=1.0, theta=0.0
% INFO    : Bus 69121	: V=0.9902785, theta=-76.767661 -> V=1.0, theta=0.0
% INFO    : Bus 69122	: V=0.9895783, theta=-76.991028 -> V=1.0, theta=0.0
% INFO    : Bus 69123	: V=0.990171, theta=-76.392164 -> V=1.0, theta=0.0
% INFO    : Bus 69124	: V=0.9905533, theta=-76.52387 -> V=1.0, theta=0.0
% INFO    : Bus 69125	: V=0.9904722, theta=-76.302882 -> V=1.0, theta=0.0
% INFO    : Bus 69126	: V=0.9909988, theta=-75.942561 -> V=1.0, theta=0.0
% INFO    : Bus 69127	: V=0.9910648, theta=-75.61909 -> V=1.0, theta=0.0
% INFO    : Bus 69128	: V=0.9905869, theta=-76.029335 -> V=1.0, theta=0.0
% INFO    : Bus 69129	: V=0.9913059, theta=-75.622841 -> V=1.0, theta=0.0
% INFO    : Bus 69130	: V=0.9910573, theta=-75.384704 -> V=1.0, theta=0.0
% INFO    : Bus 69131	: V=0.9910154, theta=-75.633791 -> V=1.0, theta=0.0
% INFO    : Bus 69132	: V=0.9911447, theta=-76.019568 -> V=1.0, theta=0.0
% INFO    : Bus 69133	: V=0.9914322, theta=-76.531854 -> V=1.0, theta=0.0
% INFO    : Bus 69134	: V=0.9914576, theta=-76.51927 -> V=1.0, theta=0.0
% INFO    : Bus 69135	: V=0.9914031, theta=-76.140055 -> V=1.0, theta=0.0
% INFO    : Bus 69136	: V=0.9914749, theta=-76.319756 -> V=1.0, theta=0.0
% INFO    : Bus 69137	: V=0.993541, theta=-75.193812 -> V=1.0, theta=0.0
% INFO    : Bus 69138	: V=0.9934121, theta=-75.717697 -> V=1.0, theta=0.0
% INFO    : Bus 69139	: V=0.9931461, theta=-75.844762 -> V=1.0, theta=0.0
% INFO    : Bus 69140	: V=0.9910486, theta=-76.977294 -> V=1.0, theta=0.0
% INFO    : Bus 69141	: V=0.9912639, theta=-76.739476 -> V=1.0, theta=0.0
% INFO    : Bus 69142	: V=0.9918738, theta=-76.284228 -> V=1.0, theta=0.0
% INFO    : Bus 69143	: V=0.9919844, theta=-76.151391 -> V=1.0, theta=0.0
% INFO    : Bus 69144	: V=0.9916503, theta=-75.993611 -> V=1.0, theta=0.0
% INFO    : Bus 69145	: V=0.9924923, theta=-75.805889 -> V=1.0, theta=0.0
% INFO    : Bus 69146	: V=0.9917706, theta=-75.607455 -> V=1.0, theta=0.0
% INFO    : Bus 69147	: V=0.9918865, theta=-75.768491 -> V=1.0, theta=0.0
% INFO    : Bus 69148	: V=0.992203, theta=-75.587807 -> V=1.0, theta=0.0
% INFO    : Bus 69149	: V=0.9924403, theta=-75.89077 -> V=1.0, theta=0.0
% INFO    : Bus 69150	: V=0.9926637, theta=-76.006415 -> V=1.0, theta=0.0
% INFO    : Bus 69151	: V=0.9929686, theta=-75.835381 -> V=1.0, theta=0.0
% INFO    : Bus 69152	: V=0.9926508, theta=-75.848733 -> V=1.0, theta=0.0
% INFO    : Bus 69153	: V=0.9926248, theta=-75.916215 -> V=1.0, theta=0.0
% INFO    : Bus 69154	: V=0.9931942, theta=-75.677153 -> V=1.0, theta=0.0
% INFO    : Bus 69155	: V=0.9922712, theta=-76.028362 -> V=1.0, theta=0.0
% INFO    : Bus 69156	: V=0.9926643, theta=-77.055568 -> V=1.0, theta=0.0
% INFO    : Bus 69157	: V=0.9974906, theta=-78.259839 -> V=1.0, theta=0.0
% INFO    : Bus 69158	: V=0.9926095, theta=-77.745564 -> V=1.0, theta=0.0
% INFO    : Bus 69159	: V=0.9924232, theta=-77.753344 -> V=1.0, theta=0.0
% INFO    : Bus 69160	: V=0.9928981, theta=-77.368496 -> V=1.0, theta=0.0
% INFO    : Bus 69161	: V=0.9921806, theta=-76.894412 -> V=1.0, theta=0.0
% INFO    : Bus 69162	: V=0.9919942, theta=-76.738074 -> V=1.0, theta=0.0
% INFO    : Bus 69163	: V=0.9922143, theta=-76.214032 -> V=1.0, theta=0.0
% INFO    : Bus 69164	: V=0.9926845, theta=-77.192586 -> V=1.0, theta=0.0
% INFO    : Bus 69165	: V=0.9925705, theta=-76.945455 -> V=1.0, theta=0.0
% INFO    : Bus 69166	: V=0.9924723, theta=-76.691664 -> V=1.0, theta=0.0
% INFO    : Bus 69167	: V=0.9934346, theta=-77.417944 -> V=1.0, theta=0.0
% INFO    : Bus 69168	: V=0.9934876, theta=-77.258882 -> V=1.0, theta=0.0
% INFO    : Bus 69169	: V=0.9923225, theta=-76.219827 -> V=1.0, theta=0.0
% INFO    : Bus 69170	: V=0.9919297, theta=-76.340233 -> V=1.0, theta=0.0
% INFO    : Bus 69171	: V=0.9937145, theta=-78.191351 -> V=1.0, theta=0.0
% INFO    : Bus 69172	: V=0.9938277, theta=-77.833015 -> V=1.0, theta=0.0
% INFO    : Bus 69173	: V=0.9931468, theta=-77.469026 -> V=1.0, theta=0.0
% INFO    : Bus 69174	: V=0.9935859, theta=-77.843032 -> V=1.0, theta=0.0
% INFO    : Bus 69175	: V=0.9925706, theta=-76.123284 -> V=1.0, theta=0.0
% INFO    : Bus 69176	: V=0.9922788, theta=-76.226449 -> V=1.0, theta=0.0
% INFO    : Bus 69177	: V=0.9945118, theta=-78.373129 -> V=1.0, theta=0.0
% INFO    : Bus 69178	: V=0.9943108, theta=-78.678908 -> V=1.0, theta=0.0
% INFO    : Bus 69179	: V=0.9927846, theta=-78.336682 -> V=1.0, theta=0.0
% INFO    : Bus 69180	: V=0.9922725, theta=-78.721815 -> V=1.0, theta=0.0
% INFO    : Bus 69181	: V=0.9915534, theta=-78.753422 -> V=1.0, theta=0.0
% INFO    : Bus 69182	: V=0.9912903, theta=-78.458168 -> V=1.0, theta=0.0
% INFO    : Bus 69183	: V=0.9916823, theta=-79.213161 -> V=1.0, theta=0.0
% INFO    : Bus 69184	: V=0.9917615, theta=-79.035665 -> V=1.0, theta=0.0
% INFO    : Bus 69185	: V=0.9911213, theta=-79.092095 -> V=1.0, theta=0.0
% INFO    : Bus 69186	: V=0.9904908, theta=-78.499891 -> V=1.0, theta=0.0
% INFO    : Bus 69187	: V=0.9907573, theta=-79.299131 -> V=1.0, theta=0.0
% INFO    : Bus 69188	: V=0.991066, theta=-79.286372 -> V=1.0, theta=0.0
% INFO    : Bus 69189	: V=0.9909353, theta=-79.432002 -> V=1.0, theta=0.0
% INFO    : Bus 69190	: V=0.9908606, theta=-79.516989 -> V=1.0, theta=0.0
% INFO    : Bus 69191	: V=0.9910048, theta=-79.473865 -> V=1.0, theta=0.0
% INFO    : Bus 69192	: V=0.9906843, theta=-79.4886 -> V=1.0, theta=0.0
% INFO    : Bus 69193	: V=0.9907554, theta=-79.543175 -> V=1.0, theta=0.0
% INFO    : Bus 69194	: V=0.9906652, theta=-79.523824 -> V=1.0, theta=0.0
% INFO    : Bus 69195	: V=0.9906634, theta=-79.626818 -> V=1.0, theta=0.0
% INFO    : Bus 69196	: V=0.9954293, theta=-79.698831 -> V=1.0, theta=0.0
% INFO    : Bus 69197	: V=0.9908126, theta=-79.739204 -> V=1.0, theta=0.0
% INFO    : Bus 69198	: V=0.9908199, theta=-79.784868 -> V=1.0, theta=0.0
% INFO    : Bus 69199	: V=0.9908075, theta=-79.638226 -> V=1.0, theta=0.0
% INFO    : Bus 69200	: V=1.0100003, theta=-79.111393 -> V=1.0, theta=0.0
% INFO    : Bus 69201	: V=0.9983379, theta=-79.990346 -> V=1.0, theta=0.0
% INFO    : Bus 69202	: V=0.9968437, theta=-80.71293 -> V=1.0, theta=0.0
% INFO    : Bus 69203	: V=0.9989089, theta=-79.953157 -> V=1.0, theta=0.0
% INFO    : Bus 69204	: V=0.9960545, theta=-80.701592 -> V=1.0, theta=0.0
% INFO    : Bus 69205	: V=0.9961674, theta=-80.572348 -> V=1.0, theta=0.0
% INFO    : Bus 69206	: V=0.9961991, theta=-80.463287 -> V=1.0, theta=0.0
% INFO    : Bus 69207	: V=0.99487, theta=-80.877477 -> V=1.0, theta=0.0
% INFO    : Bus 69208	: V=0.9954036, theta=-80.800659 -> V=1.0, theta=0.0
% INFO    : Bus 69209	: V=0.995282, theta=-80.805226 -> V=1.0, theta=0.0
% INFO    : Bus 69210	: V=0.9942226, theta=-81.02274 -> V=1.0, theta=0.0
% INFO    : Bus 69211	: V=0.9943219, theta=-80.882558 -> V=1.0, theta=0.0
% INFO    : Bus 69212	: V=0.9943658, theta=-80.918339 -> V=1.0, theta=0.0
% INFO    : Bus 69213	: V=0.9946293, theta=-80.828958 -> V=1.0, theta=0.0
% INFO    : Bus 69214	: V=0.9939737, theta=-80.662131 -> V=1.0, theta=0.0
% INFO    : Bus 69215	: V=0.9941751, theta=-80.876374 -> V=1.0, theta=0.0
% INFO    : Bus 69216	: V=0.9937786, theta=-80.891231 -> V=1.0, theta=0.0
% INFO    : Bus 69217	: V=0.9934872, theta=-80.519018 -> V=1.0, theta=0.0
% INFO    : Bus 69218	: V=0.9925543, theta=-80.040288 -> V=1.0, theta=0.0
% INFO    : Bus 69219	: V=0.9925418, theta=-80.304531 -> V=1.0, theta=0.0
% INFO    : Bus 69220	: V=0.9921896, theta=-80.07729 -> V=1.0, theta=0.0
% INFO    : Bus 69221	: V=0.9916077, theta=-80.104023 -> V=1.0, theta=0.0
% INFO    : Bus 69222	: V=0.9918977, theta=-80.128912 -> V=1.0, theta=0.0
% INFO    : Bus 69223	: V=0.9913692, theta=-79.969057 -> V=1.0, theta=0.0
% INFO    : Bus 69224	: V=0.9909042, theta=-79.820385 -> V=1.0, theta=0.0
% INFO    : Bus 69225	: V=0.9914703, theta=-79.37804 -> V=1.0, theta=0.0
% INFO    : Bus 69226	: V=0.9906857, theta=-79.994728 -> V=1.0, theta=0.0
% INFO    : Bus 69227	: V=0.9917111, theta=-79.396358 -> V=1.0, theta=0.0
% INFO    : Bus 69228	: V=0.9921079, theta=-79.389925 -> V=1.0, theta=0.0
% INFO    : Bus 69229	: V=0.9929227, theta=-79.606082 -> V=1.0, theta=0.0
% INFO    : Bus 69230	: V=0.9913887, theta=-79.664103 -> V=1.0, theta=0.0
% INFO    : Bus 69231	: V=0.9946389, theta=-79.526647 -> V=1.0, theta=0.0
% INFO    : Bus 69232	: V=0.9934751, theta=-79.586371 -> V=1.0, theta=0.0
% INFO    : Bus 69233	: V=0.9940331, theta=-79.557618 -> V=1.0, theta=0.0
% INFO    : Bus 69234	: V=0.9922288, theta=-80.059738 -> V=1.0, theta=0.0
% INFO    : Bus 69235	: V=0.9956383, theta=-79.621864 -> V=1.0, theta=0.0
% INFO    : Bus 69236	: V=0.9963155, theta=-79.755965 -> V=1.0, theta=0.0
% INFO    : Bus 69237	: V=0.9970452, theta=-79.901287 -> V=1.0, theta=0.0
% INFO    : Bus 69238	: V=0.9964503, theta=-79.425709 -> V=1.0, theta=0.0
% INFO    : Bus 69239	: V=0.9964327, theta=-80.229144 -> V=1.0, theta=0.0
% INFO    : Bus 69240	: V=0.9983849, theta=-80.431801 -> V=1.0, theta=0.0
% INFO    : Bus 69241	: V=0.9983315, theta=-80.32238 -> V=1.0, theta=0.0
% INFO    : Bus 69242	: V=0.9976739, theta=-80.524926 -> V=1.0, theta=0.0
% INFO    : Bus 69243	: V=1.0067806, theta=-79.177336 -> V=1.0, theta=0.0
% INFO    : Bus 69244	: V=0.998634, theta=-80.202809 -> V=1.0, theta=0.0
% INFO    : Bus 69245	: V=0.9985596, theta=-80.270839 -> V=1.0, theta=0.0
% INFO    : Bus 69246	: V=0.9989558, theta=-79.420338 -> V=1.0, theta=0.0
% INFO    : Bus 69247	: V=0.9980916, theta=-80.06452 -> V=1.0, theta=0.0
% INFO    : Bus 69248	: V=0.9982037, theta=-79.954836 -> V=1.0, theta=0.0
% INFO    : Bus 69249	: V=0.9979309, theta=-80.071117 -> V=1.0, theta=0.0
% INFO    : Bus 69250	: V=0.9972942, theta=-79.890849 -> V=1.0, theta=0.0
% INFO    : Bus 69251	: V=0.9970313, theta=-79.901641 -> V=1.0, theta=0.0
% INFO    : Bus 69252	: V=0.9987767, theta=-79.440357 -> V=1.0, theta=0.0
% INFO    : Bus 69253	: V=0.9983099, theta=-79.743677 -> V=1.0, theta=0.0
% INFO    : Bus 69254	: V=0.9978186, theta=-78.779558 -> V=1.0, theta=0.0
% INFO    : Bus 69255	: V=0.9982297, theta=-78.985073 -> V=1.0, theta=0.0
% INFO    : Bus 69256	: V=0.9961622, theta=-79.707373 -> V=1.0, theta=0.0
% INFO    : Bus 69257	: V=0.9969915, theta=-79.248817 -> V=1.0, theta=0.0
% INFO    : Bus 69258	: V=0.9967672, theta=-79.682553 -> V=1.0, theta=0.0
% INFO    : Bus 69259	: V=0.9961715, theta=-79.563684 -> V=1.0, theta=0.0
% INFO    : Bus 69260	: V=0.9959024, theta=-79.407577 -> V=1.0, theta=0.0
% INFO    : Bus 69261	: V=0.9950745, theta=-79.394315 -> V=1.0, theta=0.0
% INFO    : Bus 69262	: V=0.99704, theta=-78.487955 -> V=1.0, theta=0.0
% INFO    : Bus 69263	: V=0.9959501, theta=-79.061526 -> V=1.0, theta=0.0
% INFO    : Bus 69264	: V=0.9942145, theta=-78.371534 -> V=1.0, theta=0.0
% INFO    : Bus 69265	: V=0.9944051, theta=-78.369257 -> V=1.0, theta=0.0
% INFO    : Bus 69266	: V=0.9940981, theta=-78.095441 -> V=1.0, theta=0.0
% INFO    : Bus 69267	: V=0.9942654, theta=-78.186287 -> V=1.0, theta=0.0
% INFO    : Bus 69268	: V=0.9963157, theta=-78.993302 -> V=1.0, theta=0.0
% INFO    : Bus 69269	: V=0.9975947, theta=-78.602221 -> V=1.0, theta=0.0
% INFO    : Bus 69270	: V=0.9975366, theta=-78.590534 -> V=1.0, theta=0.0
% INFO    : Bus 69271	: V=0.9944799, theta=-78.270204 -> V=1.0, theta=0.0
% INFO    : Bus 69272	: V=1.0300003, theta=-77.310348 -> V=1.0, theta=0.0
% INFO    : Bus 69273	: V=0.9978302, theta=-78.375253 -> V=1.0, theta=0.0
% INFO    : Bus 69274	: V=0.9988701, theta=-77.514294 -> V=1.0, theta=0.0
% INFO    : Bus 69275	: V=0.9987081, theta=-80.595082 -> V=1.0, theta=0.0
% INFO    : Bus 69276	: V=0.9990823, theta=-80.742374 -> V=1.0, theta=0.0
% INFO    : Bus 69277	: V=0.9990344, theta=-80.55182 -> V=1.0, theta=0.0
% INFO    : Bus 69278	: V=0.9993073, theta=-79.979707 -> V=1.0, theta=0.0
% INFO    : Bus 69279	: V=0.9985991, theta=-79.608217 -> V=1.0, theta=0.0
% INFO    : Bus 69280	: V=0.9982302, theta=-79.103657 -> V=1.0, theta=0.0
% INFO    : Bus 69281	: V=0.9964011, theta=-79.098437 -> V=1.0, theta=0.0
% INFO    : Bus 69282	: V=0.9968586, theta=-79.027582 -> V=1.0, theta=0.0
% INFO    : Bus 69283	: V=0.9933658, theta=-78.975649 -> V=1.0, theta=0.0
% INFO    : Bus 69284	: V=0.9950339, theta=-78.676148 -> V=1.0, theta=0.0
% INFO    : Bus 69285	: V=0.9970526, theta=-78.954464 -> V=1.0, theta=0.0
% INFO    : Bus 69286	: V=0.9962525, theta=-78.923945 -> V=1.0, theta=0.0
% INFO    : Bus 69287	: V=0.9968912, theta=-78.271636 -> V=1.0, theta=0.0
% INFO    : Bus 69288	: V=0.9963013, theta=-78.430463 -> V=1.0, theta=0.0
% INFO    : Bus 69289	: V=0.9967482, theta=-78.902637 -> V=1.0, theta=0.0
% INFO    : Bus 69290	: V=0.9957349, theta=-78.832997 -> V=1.0, theta=0.0
% INFO    : Bus 69291	: V=0.9977084, theta=-79.04299 -> V=1.0, theta=0.0
% INFO    : Bus 69292	: V=0.9974291, theta=-79.006076 -> V=1.0, theta=0.0
% INFO    : Bus 69293	: V=1.0100003, theta=-75.928959 -> V=1.0, theta=0.0
% INFO    : Bus 69294	: V=0.9975416, theta=-77.793063 -> V=1.0, theta=0.0
% INFO    : Bus 69295	: V=0.9992687, theta=-77.477633 -> V=1.0, theta=0.0
% INFO    : Bus 69296	: V=0.9972085, theta=-77.628541 -> V=1.0, theta=0.0
% INFO    : Bus 69297	: V=0.9973042, theta=-77.935661 -> V=1.0, theta=0.0
% INFO    : Bus 69298	: V=0.9976978, theta=-77.927092 -> V=1.0, theta=0.0
% INFO    : Bus 69299	: V=1.0078859, theta=-76.201083 -> V=1.0, theta=0.0
% INFO    : Bus 69300	: V=0.9916145, theta=-76.096553 -> V=1.0, theta=0.0
% INFO    : Bus 69301	: V=0.9928552, theta=-81.301931 -> V=1.0, theta=0.0
% INFO    : Bus 69302	: V=0.9953497, theta=-79.579475 -> V=1.0, theta=0.0
% INFO    : Bus 69303	: V=0.9938795, theta=-81.808134 -> V=1.0, theta=0.0
% INFO    : Bus 69304	: V=0.9933302, theta=-81.854361 -> V=1.0, theta=0.0
% INFO    : Bus 69305	: V=0.9937113, theta=-81.815499 -> V=1.0, theta=0.0
% INFO    : Bus 69306	: V=0.9949346, theta=-81.528486 -> V=1.0, theta=0.0
% INFO    : Bus 69307	: V=0.9941196, theta=-81.952854 -> V=1.0, theta=0.0
% INFO    : Bus 69308	: V=0.9925177, theta=-82.315993 -> V=1.0, theta=0.0
% INFO    : Bus 69309	: V=0.995396, theta=-83.386582 -> V=1.0, theta=0.0
% INFO    : Bus 69310	: V=0.9957778, theta=-83.372179 -> V=1.0, theta=0.0
% INFO    : Bus 69311	: V=0.995427, theta=-83.385353 -> V=1.0, theta=0.0
% INFO    : Bus 69312	: V=0.9964896, theta=-83.046204 -> V=1.0, theta=0.0
% INFO    : Bus 69313	: V=0.9941503, theta=-82.665941 -> V=1.0, theta=0.0
% INFO    : Bus 69314	: V=0.9959784, theta=-82.970603 -> V=1.0, theta=0.0
% INFO    : Bus 69315	: V=0.9959249, theta=-82.946183 -> V=1.0, theta=0.0
% INFO    : Bus 69316	: V=0.9939649, theta=-82.467518 -> V=1.0, theta=0.0
% INFO    : Bus 69317	: V=0.9947744, theta=-82.064902 -> V=1.0, theta=0.0
% INFO    : Bus 69318	: V=0.995363, theta=-81.952314 -> V=1.0, theta=0.0
% INFO    : Bus 69319	: V=0.9941189, theta=-82.232631 -> V=1.0, theta=0.0
% INFO    : Bus 69320	: V=0.9943079, theta=-82.164747 -> V=1.0, theta=0.0
% INFO    : Bus 69321	: V=0.9939345, theta=-82.069546 -> V=1.0, theta=0.0
% INFO    : Bus 69322	: V=0.9936978, theta=-81.94202 -> V=1.0, theta=0.0
% INFO    : Bus 69323	: V=0.9943954, theta=-82.023268 -> V=1.0, theta=0.0
% INFO    : Bus 69324	: V=0.9940791, theta=-82.062247 -> V=1.0, theta=0.0
% INFO    : Bus 69325	: V=0.9943, theta=-82.068147 -> V=1.0, theta=0.0
% INFO    : Bus 69326	: V=0.9952739, theta=-81.794066 -> V=1.0, theta=0.0
% INFO    : Bus 69327	: V=0.9960263, theta=-81.982117 -> V=1.0, theta=0.0
% INFO    : Bus 69328	: V=0.9960271, theta=-81.759587 -> V=1.0, theta=0.0
% INFO    : Bus 69329	: V=0.9965167, theta=-82.3474 -> V=1.0, theta=0.0
% INFO    : Bus 69330	: V=0.9958227, theta=-82.375814 -> V=1.0, theta=0.0
% INFO    : Bus 69331	: V=0.995465, theta=-82.598267 -> V=1.0, theta=0.0
% INFO    : Bus 69332	: V=0.9954449, theta=-82.231266 -> V=1.0, theta=0.0
% INFO    : Bus 69333	: V=0.9959452, theta=-82.20839 -> V=1.0, theta=0.0
% INFO    : Bus 69334	: V=0.996538, theta=-82.082196 -> V=1.0, theta=0.0
% INFO    : Bus 69335	: V=0.9970145, theta=-81.924256 -> V=1.0, theta=0.0
% INFO    : Bus 69336	: V=0.9982114, theta=-82.212001 -> V=1.0, theta=0.0
% INFO    : Bus 69337	: V=0.9978656, theta=-82.123209 -> V=1.0, theta=0.0
% INFO    : Bus 69338	: V=0.9969298, theta=-81.975307 -> V=1.0, theta=0.0
% INFO    : Bus 69339	: V=0.9971491, theta=-81.631083 -> V=1.0, theta=0.0
% INFO    : Bus 69340	: V=0.9972893, theta=-81.608113 -> V=1.0, theta=0.0
% INFO    : Bus 69341	: V=0.9966532, theta=-81.55927 -> V=1.0, theta=0.0
% INFO    : Bus 69342	: V=0.997094, theta=-81.417926 -> V=1.0, theta=0.0
% INFO    : Bus 69343	: V=0.9976775, theta=-80.01655 -> V=1.0, theta=0.0
% INFO    : Bus 69344	: V=0.9976599, theta=-81.561257 -> V=1.0, theta=0.0
% INFO    : Bus 69345	: V=0.9981263, theta=-81.689156 -> V=1.0, theta=0.0
% INFO    : Bus 69346	: V=0.9979432, theta=-81.790803 -> V=1.0, theta=0.0
% INFO    : Bus 69347	: V=0.998061, theta=-82.005126 -> V=1.0, theta=0.0
% INFO    : Bus 69348	: V=0.9978416, theta=-81.893259 -> V=1.0, theta=0.0
% INFO    : Bus 69349	: V=0.9983232, theta=-81.723537 -> V=1.0, theta=0.0
% INFO    : Bus 69350	: V=0.9981592, theta=-81.729649 -> V=1.0, theta=0.0
% INFO    : Bus 69351	: V=0.9983336, theta=-81.447552 -> V=1.0, theta=0.0
% INFO    : Bus 69352	: V=0.9977618, theta=-81.119767 -> V=1.0, theta=0.0
% INFO    : Bus 69353	: V=0.9973179, theta=-81.136379 -> V=1.0, theta=0.0
% INFO    : Bus 69354	: V=0.9974152, theta=-81.027311 -> V=1.0, theta=0.0
% INFO    : Bus 69355	: V=0.997274, theta=-80.968102 -> V=1.0, theta=0.0
% INFO    : Bus 69356	: V=0.9972654, theta=-80.92667 -> V=1.0, theta=0.0
% INFO    : Bus 69357	: V=0.998477, theta=-81.454873 -> V=1.0, theta=0.0
% INFO    : Bus 69358	: V=0.9985313, theta=-81.377568 -> V=1.0, theta=0.0
% INFO    : Bus 69359	: V=0.9987064, theta=-81.282163 -> V=1.0, theta=0.0
% INFO    : Bus 69360	: V=0.9988609, theta=-81.6621 -> V=1.0, theta=0.0
% INFO    : Bus 69361	: V=0.9985261, theta=-81.526224 -> V=1.0, theta=0.0
% INFO    : Bus 69362	: V=0.9985886, theta=-81.596446 -> V=1.0, theta=0.0
% INFO    : Bus 69363	: V=0.9985698, theta=-81.815333 -> V=1.0, theta=0.0
% INFO    : Bus 69364	: V=0.9988941, theta=-81.80207 -> V=1.0, theta=0.0
% INFO    : Bus 69365	: V=0.9992868, theta=-80.378953 -> V=1.0, theta=0.0
% INFO    : Bus 69366	: V=0.9990048, theta=-80.268405 -> V=1.0, theta=0.0
% INFO    : Bus 69367	: V=0.9975643, theta=-81.282822 -> V=1.0, theta=0.0
% INFO    : Bus 69368	: V=0.9983763, theta=-81.061043 -> V=1.0, theta=0.0
% INFO    : Bus 69369	: V=0.9991824, theta=-80.239528 -> V=1.0, theta=0.0
% INFO    : Bus 69370	: V=0.9988446, theta=-80.992254 -> V=1.0, theta=0.0
% INFO    : Bus 69371	: V=0.999272, theta=-80.897288 -> V=1.0, theta=0.0
% INFO    : Bus 69372	: V=0.9999624, theta=-80.91404 -> V=1.0, theta=0.0
% INFO    : Bus 69373	: V=0.9980746, theta=-83.876275 -> V=1.0, theta=0.0
% INFO    : Bus 69374	: V=0.9991256, theta=-83.949368 -> V=1.0, theta=0.0
% INFO    : Bus 69375	: V=0.9999726, theta=-83.950142 -> V=1.0, theta=0.0
% INFO    : Bus 69376	: V=1.0013213, theta=-83.910366 -> V=1.0, theta=0.0
% INFO    : Bus 69377	: V=0.9989778, theta=-83.943853 -> V=1.0, theta=0.0
% INFO    : Bus 69378	: V=1.007116, theta=-83.185472 -> V=1.0, theta=0.0
% INFO    : Bus 69379	: V=1.0070744, theta=-83.220003 -> V=1.0, theta=0.0
% INFO    : Bus 69380	: V=1.0033991, theta=-83.851287 -> V=1.0, theta=0.0
% INFO    : Bus 69381	: V=1.0072395, theta=-83.259898 -> V=1.0, theta=0.0
% INFO    : Bus 69382	: V=1.0027192, theta=-83.881927 -> V=1.0, theta=0.0
% INFO    : Bus 69383	: V=1.001706, theta=-83.822336 -> V=1.0, theta=0.0
% INFO    : Bus 69384	: V=1.0000739, theta=-83.874649 -> V=1.0, theta=0.0
% INFO    : Bus 69385	: V=0.999276, theta=-83.930233 -> V=1.0, theta=0.0
% INFO    : Bus 69386	: V=0.9992329, theta=-83.850559 -> V=1.0, theta=0.0
% INFO    : Bus 69387	: V=0.9988097, theta=-83.929326 -> V=1.0, theta=0.0
% INFO    : Bus 69388	: V=0.9987007, theta=-83.902646 -> V=1.0, theta=0.0
% INFO    : Bus 69389	: V=0.9998347, theta=-83.742021 -> V=1.0, theta=0.0
% INFO    : Bus 69390	: V=0.9995983, theta=-83.802681 -> V=1.0, theta=0.0
% INFO    : Bus 69391	: V=0.9996816, theta=-83.832194 -> V=1.0, theta=0.0
% INFO    : Bus 69392	: V=1.0010747, theta=-83.813139 -> V=1.0, theta=0.0
% INFO    : Bus 69393	: V=1.001316, theta=-83.819795 -> V=1.0, theta=0.0
% INFO    : Bus 69394	: V=1.0016431, theta=-83.69395 -> V=1.0, theta=0.0
% INFO    : Bus 69395	: V=1.0024544, theta=-83.568317 -> V=1.0, theta=0.0
% INFO    : Bus 69396	: V=1.0008883, theta=-83.762386 -> V=1.0, theta=0.0
% INFO    : Bus 69397	: V=1.0010256, theta=-83.764252 -> V=1.0, theta=0.0
% INFO    : Bus 69398	: V=1.0007546, theta=-83.751757 -> V=1.0, theta=0.0
% INFO    : Bus 69399	: V=1.0011214, theta=-83.675944 -> V=1.0, theta=0.0
% INFO    : Bus 69400	: V=1.001491, theta=-83.620331 -> V=1.0, theta=0.0
% INFO    : Bus 69401	: V=1.0013705, theta=-83.581897 -> V=1.0, theta=0.0
% INFO    : Bus 69402	: V=1.0013513, theta=-83.555508 -> V=1.0, theta=0.0
% INFO    : Bus 69403	: V=1.0004011, theta=-83.671461 -> V=1.0, theta=0.0
% INFO    : Bus 69404	: V=0.9989443, theta=-83.840493 -> V=1.0, theta=0.0
% INFO    : Bus 69405	: V=0.9998417, theta=-83.677261 -> V=1.0, theta=0.0
% INFO    : Bus 69406	: V=1.0000345, theta=-83.668421 -> V=1.0, theta=0.0
% INFO    : Bus 69407	: V=0.9993672, theta=-83.695598 -> V=1.0, theta=0.0
% INFO    : Bus 69408	: V=0.9990582, theta=-83.531805 -> V=1.0, theta=0.0
% INFO    : Bus 69409	: V=0.9969125, theta=-83.28195 -> V=1.0, theta=0.0
% INFO    : Bus 69410	: V=0.9975292, theta=-83.180609 -> V=1.0, theta=0.0
% INFO    : Bus 69411	: V=0.9985829, theta=-83.303576 -> V=1.0, theta=0.0
% INFO    : Bus 69412	: V=0.9992432, theta=-83.328032 -> V=1.0, theta=0.0
% INFO    : Bus 69413	: V=1.0002701, theta=-83.352171 -> V=1.0, theta=0.0
% INFO    : Bus 69414	: V=1.0091068, theta=-82.519104 -> V=1.0, theta=0.0
% INFO    : Bus 69415	: V=1.0097815, theta=-82.477355 -> V=1.0, theta=0.0
% INFO    : Bus 69416	: V=1.0020641, theta=-83.596671 -> V=1.0, theta=0.0
% INFO    : Bus 69417	: V=1.0027367, theta=-83.555471 -> V=1.0, theta=0.0
% INFO    : Bus 69418	: V=1.0023307, theta=-83.575856 -> V=1.0, theta=0.0
% INFO    : Bus 69419	: V=1.0025184, theta=-83.560126 -> V=1.0, theta=0.0
% INFO    : Bus 69420	: V=1.0046245, theta=-83.144268 -> V=1.0, theta=0.0
% INFO    : Bus 69421	: V=1.0035668, theta=-83.217281 -> V=1.0, theta=0.0
% INFO    : Bus 69422	: V=1.0020261, theta=-83.206523 -> V=1.0, theta=0.0
% INFO    : Bus 69423	: V=1.0005344, theta=-83.312793 -> V=1.0, theta=0.0
% INFO    : Bus 69424	: V=1.0001433, theta=-83.327491 -> V=1.0, theta=0.0
% INFO    : Bus 69425	: V=0.9957766, theta=-82.815593 -> V=1.0, theta=0.0
% INFO    : Bus 69426	: V=0.9958002, theta=-82.721262 -> V=1.0, theta=0.0
% INFO    : Bus 69427	: V=0.9963159, theta=-82.675629 -> V=1.0, theta=0.0
% INFO    : Bus 69428	: V=0.9966869, theta=-82.661704 -> V=1.0, theta=0.0
% INFO    : Bus 69429	: V=0.9987867, theta=-82.664078 -> V=1.0, theta=0.0
% INFO    : Bus 69430	: V=0.9972756, theta=-82.591538 -> V=1.0, theta=0.0
% INFO    : Bus 69431	: V=1.0004446, theta=-82.73282 -> V=1.0, theta=0.0
% INFO    : Bus 69432	: V=1.0014683, theta=-82.857923 -> V=1.0, theta=0.0
% INFO    : Bus 69433	: V=1.0011286, theta=-82.822885 -> V=1.0, theta=0.0
% INFO    : Bus 69434	: V=1.0017981, theta=-82.989263 -> V=1.0, theta=0.0
% INFO    : Bus 69435	: V=1.0023409, theta=-83.101142 -> V=1.0, theta=0.0
% INFO    : Bus 69436	: V=1.0037546, theta=-83.136876 -> V=1.0, theta=0.0
% INFO    : Bus 69437	: V=1.0020212, theta=-83.198856 -> V=1.0, theta=0.0
% INFO    : Bus 69438	: V=1.0018768, theta=-83.252911 -> V=1.0, theta=0.0
% INFO    : Bus 69439	: V=1.0020308, theta=-83.180789 -> V=1.0, theta=0.0
% INFO    : Bus 69440	: V=1.005655, theta=-81.840216 -> V=1.0, theta=0.0
% INFO    : Bus 69441	: V=1.0036531, theta=-83.0146 -> V=1.0, theta=0.0
% INFO    : Bus 69442	: V=1.0031183, theta=-83.034424 -> V=1.0, theta=0.0
% INFO    : Bus 69443	: V=1.0061273, theta=-81.885353 -> V=1.0, theta=0.0
% INFO    : Bus 69444	: V=1.0023924, theta=-82.798589 -> V=1.0, theta=0.0
% INFO    : Bus 69445	: V=1.0022943, theta=-82.803868 -> V=1.0, theta=0.0
% INFO    : Bus 69446	: V=1.0055977, theta=-81.840705 -> V=1.0, theta=0.0
% INFO    : Bus 69447	: V=1.0002732, theta=-82.65887 -> V=1.0, theta=0.0
% INFO    : Bus 69448	: V=0.9990918, theta=-82.650122 -> V=1.0, theta=0.0
% INFO    : Bus 69449	: V=0.9975221, theta=-82.581399 -> V=1.0, theta=0.0
% INFO    : Bus 69450	: V=0.9982104, theta=-82.619123 -> V=1.0, theta=0.0
% INFO    : Bus 69451	: V=0.9966218, theta=-82.296904 -> V=1.0, theta=0.0
% INFO    : Bus 69452	: V=0.9969301, theta=-82.432423 -> V=1.0, theta=0.0
% INFO    : Bus 69453	: V=0.998258, theta=-82.002847 -> V=1.0, theta=0.0
% INFO    : Bus 69454	: V=0.9994511, theta=-82.554409 -> V=1.0, theta=0.0
% INFO    : Bus 69455	: V=0.9987256, theta=-82.276682 -> V=1.0, theta=0.0
% INFO    : Bus 69456	: V=0.9997968, theta=-82.540311 -> V=1.0, theta=0.0
% INFO    : Bus 69457	: V=1.0004803, theta=-82.514535 -> V=1.0, theta=0.0
% INFO    : Bus 69458	: V=1.0009238, theta=-82.493481 -> V=1.0, theta=0.0
% INFO    : Bus 69459	: V=1.0014994, theta=-82.384937 -> V=1.0, theta=0.0
% INFO    : Bus 69460	: V=1.0013291, theta=-82.445431 -> V=1.0, theta=0.0
% INFO    : Bus 69461	: V=1.0013088, theta=-82.273793 -> V=1.0, theta=0.0
% INFO    : Bus 69462	: V=1.0000095, theta=-82.139317 -> V=1.0, theta=0.0
% INFO    : Bus 69463	: V=1.0018179, theta=-82.430919 -> V=1.0, theta=0.0
% INFO    : Bus 69464	: V=1.0019122, theta=-82.424422 -> V=1.0, theta=0.0
% INFO    : Bus 69465	: V=1.0020816, theta=-82.557791 -> V=1.0, theta=0.0
% INFO    : Bus 69466	: V=1.0024479, theta=-82.799923 -> V=1.0, theta=0.0
% INFO    : Bus 69467	: V=1.0022224, theta=-82.699058 -> V=1.0, theta=0.0
% INFO    : Bus 69468	: V=1.0033523, theta=-82.610393 -> V=1.0, theta=0.0
% INFO    : Bus 69469	: V=1.0026645, theta=-82.552876 -> V=1.0, theta=0.0
% INFO    : Bus 69470	: V=1.0047814, theta=-81.695062 -> V=1.0, theta=0.0
% INFO    : Bus 69471	: V=1.0021365, theta=-82.29759 -> V=1.0, theta=0.0
% INFO    : Bus 69472	: V=1.0045244, theta=-81.603927 -> V=1.0, theta=0.0
% INFO    : Bus 69473	: V=1.0003463, theta=-82.089571 -> V=1.0, theta=0.0
% INFO    : Bus 69474	: V=0.9990142, theta=-82.159362 -> V=1.0, theta=0.0
% INFO    : Bus 69475	: V=0.9991126, theta=-82.098478 -> V=1.0, theta=0.0
% INFO    : Bus 69476	: V=0.9992372, theta=-82.067944 -> V=1.0, theta=0.0
% INFO    : Bus 69477	: V=0.9986066, theta=-81.989177 -> V=1.0, theta=0.0
% INFO    : Bus 69478	: V=0.9991388, theta=-81.781104 -> V=1.0, theta=0.0
% INFO    : Bus 69479	: V=0.9995243, theta=-82.019292 -> V=1.0, theta=0.0
% INFO    : Bus 69480	: V=0.9989888, theta=-81.887596 -> V=1.0, theta=0.0
% INFO    : Bus 69481	: V=0.9987888, theta=-81.775112 -> V=1.0, theta=0.0
% INFO    : Bus 69482	: V=0.9983947, theta=-81.590721 -> V=1.0, theta=0.0
% INFO    : Bus 69483	: V=1.0008682, theta=-81.970229 -> V=1.0, theta=0.0
% INFO    : Bus 69484	: V=1.0025535, theta=-82.259696 -> V=1.0, theta=0.0
% INFO    : Bus 69485	: V=1.0022844, theta=-82.278365 -> V=1.0, theta=0.0
% INFO    : Bus 69486	: V=1.0004669, theta=-81.799582 -> V=1.0, theta=0.0
% INFO    : Bus 69487	: V=0.9960029, theta=-78.798518 -> V=1.0, theta=0.0
% INFO    : Bus 69488	: V=0.9948107, theta=-78.636371 -> V=1.0, theta=0.0
% INFO    : Bus 69489	: V=0.9947805, theta=-78.642973 -> V=1.0, theta=0.0
% INFO    : Bus 69490	: V=1.0006883, theta=-80.876744 -> V=1.0, theta=0.0
% INFO    : Bus 69491	: V=0.9956042, theta=-80.949404 -> V=1.0, theta=0.0
% INFO    : Bus 69492	: V=0.9970497, theta=-80.928321 -> V=1.0, theta=0.0
% INFO    : Bus 69493	: V=0.9961096, theta=-81.117775 -> V=1.0, theta=0.0
% INFO    : Bus 69494	: V=0.9957421, theta=-81.163954 -> V=1.0, theta=0.0
% INFO    : Bus 69495	: V=0.9954139, theta=-81.065376 -> V=1.0, theta=0.0
% INFO    : Bus 69496	: V=0.9958334, theta=-80.874938 -> V=1.0, theta=0.0
% INFO    : Bus 69497	: V=0.9944938, theta=-80.718113 -> V=1.0, theta=0.0
% INFO    : Bus 69498	: V=0.9947616, theta=-80.770537 -> V=1.0, theta=0.0
% INFO    : Bus 69499	: V=0.993901, theta=-80.615522 -> V=1.0, theta=0.0
% INFO    : Bus 69500	: V=0.993107, theta=-80.435914 -> V=1.0, theta=0.0
% INFO    : Bus 69501	: V=0.996536, theta=-80.859117 -> V=1.0, theta=0.0
% INFO    : Bus 69502	: V=0.9976511, theta=-80.763226 -> V=1.0, theta=0.0
% INFO    : Bus 69503	: V=0.9969111, theta=-79.63572 -> V=1.0, theta=0.0
% INFO    : Bus 69504	: V=0.9981471, theta=-79.859159 -> V=1.0, theta=0.0
% INFO    : Bus 69505	: V=0.9973016, theta=-79.733618 -> V=1.0, theta=0.0
% INFO    : Bus 69506	: V=0.9926736, theta=-79.962428 -> V=1.0, theta=0.0
% INFO    : Bus 69507	: V=0.9960142, theta=-79.179463 -> V=1.0, theta=0.0
% INFO    : Bus 69508	: V=0.996033, theta=-79.218856 -> V=1.0, theta=0.0
% INFO    : Bus 69509	: V=0.9920575, theta=-79.872094 -> V=1.0, theta=0.0
% INFO    : Bus 69510	: V=0.9963386, theta=-79.52905 -> V=1.0, theta=0.0
% INFO    : Bus 69511	: V=0.9922982, theta=-79.871284 -> V=1.0, theta=0.0
% INFO    : Bus 69512	: V=0.9961143, theta=-79.23556 -> V=1.0, theta=0.0
% INFO    : Bus 69513	: V=0.9961535, theta=-79.410779 -> V=1.0, theta=0.0
% INFO    : Bus 69514	: V=0.9929165, theta=-79.737874 -> V=1.0, theta=0.0
% INFO    : Bus 69515	: V=0.9962793, theta=-79.144031 -> V=1.0, theta=0.0
% INFO    : Bus 69516	: V=0.9972689, theta=-79.604899 -> V=1.0, theta=0.0
% INFO    : Bus 69517	: V=0.9929159, theta=-80.459743 -> V=1.0, theta=0.0
% INFO    : Bus 69518	: V=0.9936176, theta=-80.526773 -> V=1.0, theta=0.0
% INFO    : Bus 69519	: V=0.9979856, theta=-79.54614 -> V=1.0, theta=0.0
% INFO    : Bus 69520	: V=0.9947049, theta=-80.634352 -> V=1.0, theta=0.0
% INFO    : Bus 69521	: V=0.9943175, theta=-80.598779 -> V=1.0, theta=0.0
% INFO    : Bus 69522	: V=1.0026883, theta=-79.99818 -> V=1.0, theta=0.0
% INFO    : Bus 69523	: V=0.9938339, theta=-79.797694 -> V=1.0, theta=0.0
% INFO    : Bus 69524	: V=1.0020494, theta=-79.884429 -> V=1.0, theta=0.0
% INFO    : Bus 69525	: V=1.0100003, theta=-78.626456 -> V=1.0, theta=0.0
% INFO    : Bus 69526	: V=1.0012338, theta=-79.538315 -> V=1.0, theta=0.0
% INFO    : Bus 69527	: V=0.9994217, theta=-79.197545 -> V=1.0, theta=0.0
% INFO    : Bus 69528	: V=0.9894376, theta=-79.507564 -> V=1.0, theta=0.0
% INFO    : Bus 69529	: V=0.9972148, theta=-79.255862 -> V=1.0, theta=0.0
% INFO    : Bus 69530	: V=0.9948705, theta=-78.912577 -> V=1.0, theta=0.0
% INFO    : Bus 69531	: V=0.9930982, theta=-79.003288 -> V=1.0, theta=0.0
% INFO    : Bus 69532	: V=0.9945943, theta=-78.914888 -> V=1.0, theta=0.0
% INFO    : Bus 69533	: V=0.9965815, theta=-78.56799 -> V=1.0, theta=0.0
% INFO    : Bus 69534	: V=0.9932029, theta=-78.856486 -> V=1.0, theta=0.0
% INFO    : Bus 69535	: V=0.9958879, theta=-78.7048 -> V=1.0, theta=0.0
% INFO    : Bus 69536	: V=0.9959011, theta=-78.899126 -> V=1.0, theta=0.0
% INFO    : Bus 69537	: V=0.989467, theta=-79.038773 -> V=1.0, theta=0.0
% INFO    : Bus 69538	: V=0.9898077, theta=-79.039473 -> V=1.0, theta=0.0
% INFO    : Bus 69539	: V=0.9896787, theta=-78.756991 -> V=1.0, theta=0.0
% INFO    : Bus 69540	: V=0.9949854, theta=-78.636475 -> V=1.0, theta=0.0
% INFO    : Bus 69541	: V=0.9954914, theta=-78.623046 -> V=1.0, theta=0.0
% INFO    : Bus 69542	: V=0.9909318, theta=-78.812541 -> V=1.0, theta=0.0
% INFO    : Bus 69543	: V=0.9954985, theta=-78.532079 -> V=1.0, theta=0.0
% INFO    : Bus 69544	: V=0.9914511, theta=-78.531829 -> V=1.0, theta=0.0
% INFO    : Bus 69545	: V=0.9908287, theta=-78.73933 -> V=1.0, theta=0.0
% INFO    : Bus 69546	: V=0.9907971, theta=-78.6409 -> V=1.0, theta=0.0
% INFO    : Bus 69547	: V=0.994138, theta=-78.014239 -> V=1.0, theta=0.0
% INFO    : Bus 69548	: V=0.9887347, theta=-77.910067 -> V=1.0, theta=0.0
% INFO    : Bus 69549	: V=0.9960442, theta=-78.219892 -> V=1.0, theta=0.0
% INFO    : Bus 69550	: V=0.9963885, theta=-78.137073 -> V=1.0, theta=0.0
% INFO    : Bus 69551	: V=0.9972384, theta=-78.036595 -> V=1.0, theta=0.0
% INFO    : Bus 69552	: V=0.9957007, theta=-78.369512 -> V=1.0, theta=0.0
% INFO    : Bus 69553	: V=0.9921149, theta=-78.555681 -> V=1.0, theta=0.0
% INFO    : Bus 69554	: V=0.9977607, theta=-78.354714 -> V=1.0, theta=0.0
% INFO    : Bus 69555	: V=1.0100003, theta=-77.33658 -> V=1.0, theta=0.0
% INFO    : Bus 69556	: V=0.9968534, theta=-81.377705 -> V=1.0, theta=0.0
% INFO    : Bus 69557	: V=0.996057, theta=-81.24782 -> V=1.0, theta=0.0
% INFO    : Bus 69558	: V=1.000275, theta=-81.647283 -> V=1.0, theta=0.0
% INFO    : Bus 69559	: V=1.0001153, theta=-81.518123 -> V=1.0, theta=0.0
% INFO    : Bus 69560	: V=0.9950794, theta=-81.06746 -> V=1.0, theta=0.0
% INFO    : Bus 69561	: V=1.0002671, theta=-81.424676 -> V=1.0, theta=0.0
% INFO    : Bus 69562	: V=1.0017918, theta=-81.873486 -> V=1.0, theta=0.0
% INFO    : Bus 69563	: V=1.0012991, theta=-81.758389 -> V=1.0, theta=0.0
% INFO    : Bus 69564	: V=1.0017765, theta=-81.723758 -> V=1.0, theta=0.0
% INFO    : Bus 69565	: V=1.0029259, theta=-82.101346 -> V=1.0, theta=0.0
% INFO    : Bus 69566	: V=1.0025609, theta=-81.978845 -> V=1.0, theta=0.0
% INFO    : Bus 69567	: V=1.002962, theta=-82.259644 -> V=1.0, theta=0.0
% INFO    : Bus 69568	: V=1.0037744, theta=-82.359453 -> V=1.0, theta=0.0
% INFO    : Bus 69569	: V=1.0046023, theta=-82.692279 -> V=1.0, theta=0.0
% INFO    : Bus 69570	: V=1.0045074, theta=-82.696127 -> V=1.0, theta=0.0
% INFO    : Bus 69571	: V=1.0103915, theta=-80.51058 -> V=1.0, theta=0.0
% INFO    : Bus 69572	: V=1.005149, theta=-82.511311 -> V=1.0, theta=0.0
% INFO    : Bus 69573	: V=1.0044595, theta=-82.698086 -> V=1.0, theta=0.0
% INFO    : Bus 69574	: V=1.0052277, theta=-82.368336 -> V=1.0, theta=0.0
% INFO    : Bus 69575	: V=1.0048491, theta=-82.394578 -> V=1.0, theta=0.0
% INFO    : Bus 69576	: V=1.0044982, theta=-82.417893 -> V=1.0, theta=0.0
% INFO    : Bus 69577	: V=1.0054816, theta=-82.260855 -> V=1.0, theta=0.0
% INFO    : Bus 69578	: V=1.0052847, theta=-82.268841 -> V=1.0, theta=0.0
% INFO    : Bus 69579	: V=1.0048763, theta=-82.170562 -> V=1.0, theta=0.0
% INFO    : Bus 69580	: V=1.0050414, theta=-82.163873 -> V=1.0, theta=0.0
% INFO    : Bus 69581	: V=1.0045131, theta=-82.050022 -> V=1.0, theta=0.0
% INFO    : Bus 69582	: V=1.0048923, theta=-82.023457 -> V=1.0, theta=0.0
% INFO    : Bus 69583	: V=1.0036327, theta=-81.961476 -> V=1.0, theta=0.0
% INFO    : Bus 69584	: V=1.00323, theta=-82.113836 -> V=1.0, theta=0.0
% INFO    : Bus 69585	: V=1.0034007, theta=-82.106886 -> V=1.0, theta=0.0
% INFO    : Bus 69586	: V=1.0032745, theta=-81.965208 -> V=1.0, theta=0.0
% INFO    : Bus 69587	: V=1.0031267, theta=-82.106931 -> V=1.0, theta=0.0
% INFO    : Bus 69588	: V=1.0032231, theta=-82.114957 -> V=1.0, theta=0.0
% INFO    : Bus 69589	: V=1.0028155, theta=-81.913344 -> V=1.0, theta=0.0
% INFO    : Bus 69590	: V=1.0030138, theta=-81.961762 -> V=1.0, theta=0.0
% INFO    : Bus 69591	: V=1.002123, theta=-81.710832 -> V=1.0, theta=0.0
% INFO    : Bus 69592	: V=1.0017949, theta=-81.724163 -> V=1.0, theta=0.0
% INFO    : Bus 69593	: V=1.0015084, theta=-81.498373 -> V=1.0, theta=0.0
% INFO    : Bus 69594	: V=1.0088991, theta=-79.192662 -> V=1.0, theta=0.0
% INFO    : Bus 69595	: V=0.9995944, theta=-81.170779 -> V=1.0, theta=0.0
% INFO    : Bus 69596	: V=0.9952389, theta=-81.048222 -> V=1.0, theta=0.0
% INFO    : Bus 69597	: V=0.9981062, theta=-81.061179 -> V=1.0, theta=0.0
% INFO    : Bus 69598	: V=0.9980545, theta=-80.90152 -> V=1.0, theta=0.0
% INFO    : Bus 69599	: V=1.0053082, theta=-80.64632 -> V=1.0, theta=0.0
% INFO    : Bus 69600	: V=1.0100003, theta=-79.098495 -> V=1.0, theta=0.0
% INFO    : Bus 69601	: V=1.0297792, theta=-76.9995 -> V=1.0, theta=0.0
% INFO    : Bus 69602	: V=1.0300003, theta=-77.491219 -> V=1.0, theta=0.0
% INFO    : Bus 69603	: V=1.0108918, theta=-80.107764 -> V=1.0, theta=0.0
% INFO    : Bus 69604	: V=1.002087, theta=-81.9704 -> V=1.0, theta=0.0
% INFO    : Bus 69605	: V=1.0018151, theta=-81.881345 -> V=1.0, theta=0.0
% INFO    : Bus 69606	: V=1.0039221, theta=-81.697406 -> V=1.0, theta=0.0
% INFO    : Bus 69607	: V=1.0019914, theta=-81.839653 -> V=1.0, theta=0.0
% INFO    : Bus 69608	: V=1.0035353, theta=-81.648402 -> V=1.0, theta=0.0
% INFO    : Bus 69609	: V=1.0050573, theta=-82.388093 -> V=1.0, theta=0.0
% INFO    : Bus 69610	: V=1.0028002, theta=-82.24922 -> V=1.0, theta=0.0
% INFO    : Bus 69611	: V=1.0019178, theta=-82.05504 -> V=1.0, theta=0.0
% INFO    : Bus 69612	: V=1.0022957, theta=-81.954182 -> V=1.0, theta=0.0
% INFO    : Bus 69613	: V=1.0016723, theta=-81.899674 -> V=1.0, theta=0.0
% INFO    : Bus 69614	: V=1.0018436, theta=-81.811992 -> V=1.0, theta=0.0
% INFO    : Bus 69615	: V=1.0021978, theta=-81.798554 -> V=1.0, theta=0.0
% INFO    : Bus 69616	: V=1.0018642, theta=-81.844845 -> V=1.0, theta=0.0
% INFO    : Bus 69617	: V=1.0022212, theta=-81.656696 -> V=1.0, theta=0.0
% INFO    : Bus 69618	: V=1.0031578, theta=-81.209574 -> V=1.0, theta=0.0
% INFO    : Bus 69619	: V=1.0028799, theta=-81.225713 -> V=1.0, theta=0.0
% INFO    : Bus 69620	: V=1.0025397, theta=-81.241688 -> V=1.0, theta=0.0
% INFO    : Bus 69621	: V=1.0043308, theta=-81.106937 -> V=1.0, theta=0.0
% INFO    : Bus 69622	: V=1.003559, theta=-81.440418 -> V=1.0, theta=0.0
% INFO    : Bus 69623	: V=1.0037099, theta=-81.396527 -> V=1.0, theta=0.0
% INFO    : Bus 69624	: V=1.0043546, theta=-80.566332 -> V=1.0, theta=0.0
% INFO    : Bus 69625	: V=1.003705, theta=-81.163162 -> V=1.0, theta=0.0
% INFO    : Bus 69626	: V=1.0026915, theta=-81.476008 -> V=1.0, theta=0.0
% INFO    : Bus 69627	: V=1.0029474, theta=-81.426756 -> V=1.0, theta=0.0
% INFO    : Bus 69628	: V=1.0022237, theta=-81.473672 -> V=1.0, theta=0.0
% INFO    : Bus 69629	: V=1.0018918, theta=-81.463105 -> V=1.0, theta=0.0
% INFO    : Bus 69630	: V=1.0017121, theta=-81.433743 -> V=1.0, theta=0.0
% INFO    : Bus 69631	: V=1.0031184, theta=-81.231588 -> V=1.0, theta=0.0
% INFO    : Bus 69632	: V=1.0044835, theta=-80.470603 -> V=1.0, theta=0.0
% INFO    : Bus 69633	: V=1.0041279, theta=-80.46705 -> V=1.0, theta=0.0
% INFO    : Bus 69634	: V=1.0012178, theta=-81.318495 -> V=1.0, theta=0.0
% INFO    : Bus 69635	: V=1.0010755, theta=-81.324285 -> V=1.0, theta=0.0
% INFO    : Bus 69636	: V=1.0010571, theta=-81.206137 -> V=1.0, theta=0.0
% INFO    : Bus 69637	: V=1.0009948, theta=-81.105298 -> V=1.0, theta=0.0
% INFO    : Bus 69638	: V=1.0023039, theta=-80.74208 -> V=1.0, theta=0.0
% INFO    : Bus 69639	: V=1.002635, theta=-79.998844 -> V=1.0, theta=0.0
% INFO    : Bus 69640	: V=1.0027097, theta=-79.989966 -> V=1.0, theta=0.0
% INFO    : Bus 69641	: V=1.0028374, theta=-79.977918 -> V=1.0, theta=0.0
% INFO    : Bus 69642	: V=1.0012131, theta=-81.027225 -> V=1.0, theta=0.0
% INFO    : Bus 69643	: V=1.0009158, theta=-81.027443 -> V=1.0, theta=0.0
% INFO    : Bus 69644	: V=0.9986451, theta=-81.096652 -> V=1.0, theta=0.0
% INFO    : Bus 69645	: V=0.9982121, theta=-81.088613 -> V=1.0, theta=0.0
% INFO    : Bus 69646	: V=0.9979416, theta=-81.070723 -> V=1.0, theta=0.0
% INFO    : Bus 69647	: V=1.0001075, theta=-81.214695 -> V=1.0, theta=0.0
% INFO    : Bus 69648	: V=0.9993493, theta=-81.099065 -> V=1.0, theta=0.0
% INFO    : Bus 69649	: V=1.0019212, theta=-81.491233 -> V=1.0, theta=0.0
% INFO    : Bus 69650	: V=1.0009296, theta=-81.373901 -> V=1.0, theta=0.0
% INFO    : Bus 69651	: V=1.0002879, theta=-81.300351 -> V=1.0, theta=0.0
% INFO    : Bus 69652	: V=1.000196, theta=-81.112577 -> V=1.0, theta=0.0
% INFO    : Bus 69653	: V=1.0020499, theta=-81.264465 -> V=1.0, theta=0.0
% INFO    : Bus 69654	: V=1.0022134, theta=-81.537042 -> V=1.0, theta=0.0
% INFO    : Bus 69655	: V=1.0021521, theta=-81.663387 -> V=1.0, theta=0.0
% INFO    : Bus 69656	: V=1.0020026, theta=-81.754017 -> V=1.0, theta=0.0
% INFO    : Bus 69657	: V=1.0019606, theta=-81.776441 -> V=1.0, theta=0.0
% INFO    : Bus 69658	: V=1.0021176, theta=-81.720909 -> V=1.0, theta=0.0
% INFO    : Bus 69659	: V=1.0018752, theta=-82.055305 -> V=1.0, theta=0.0
% INFO    : Bus 69660	: V=1.0023151, theta=-82.208035 -> V=1.0, theta=0.0
% INFO    : Bus 69661	: V=1.0023119, theta=-81.953646 -> V=1.0, theta=0.0
% INFO    : Bus 69662	: V=1.00235, theta=-81.94944 -> V=1.0, theta=0.0
% INFO    : Bus 69663	: V=1.0018548, theta=-81.836604 -> V=1.0, theta=0.0
% INFO    : Bus 69664	: V=1.0014574, theta=-81.814133 -> V=1.0, theta=0.0
% INFO    : Bus 69665	: V=1.0024263, theta=-81.85844 -> V=1.0, theta=0.0
% INFO    : Bus 69666	: V=1.0015516, theta=-81.496873 -> V=1.0, theta=0.0
% INFO    : Bus 69667	: V=1.0019039, theta=-81.439947 -> V=1.0, theta=0.0
% INFO    : Bus 69668	: V=1.0020585, theta=-81.640262 -> V=1.0, theta=0.0
% INFO    : Bus 69669	: V=1.0015508, theta=-81.570673 -> V=1.0, theta=0.0
% INFO    : Bus 69670	: V=1.001737, theta=-81.464264 -> V=1.0, theta=0.0
% INFO    : Bus 69671	: V=1.0006183, theta=-81.867892 -> V=1.0, theta=0.0
% INFO    : Bus 69672	: V=0.9999312, theta=-81.961882 -> V=1.0, theta=0.0
% INFO    : Bus 69673	: V=1.0007843, theta=-81.82505 -> V=1.0, theta=0.0
% INFO    : Bus 69674	: V=1.0008327, theta=-81.75661 -> V=1.0, theta=0.0
% INFO    : Bus 69675	: V=1.0014855, theta=-81.273801 -> V=1.0, theta=0.0
% INFO    : Bus 69676	: V=1.0010916, theta=-81.199877 -> V=1.0, theta=0.0
% INFO    : Bus 69677	: V=0.9999931, theta=-80.997764 -> V=1.0, theta=0.0
% INFO    : Bus 69678	: V=1.0011558, theta=-81.475636 -> V=1.0, theta=0.0
% INFO    : Bus 69679	: V=1.0005769, theta=-81.108242 -> V=1.0, theta=0.0
% INFO    : Bus 69680	: V=1.0000493, theta=-81.276688 -> V=1.0, theta=0.0
% INFO    : Bus 69681	: V=0.9996603, theta=-81.292534 -> V=1.0, theta=0.0
% INFO    : Bus 69682	: V=1.0003494, theta=-81.228853 -> V=1.0, theta=0.0
% INFO    : Bus 69683	: V=1.0091615, theta=-79.552573 -> V=1.0, theta=0.0
% INFO    : Bus 69684	: V=0.9987639, theta=-80.932262 -> V=1.0, theta=0.0
% INFO    : Bus 69685	: V=0.9982543, theta=-80.874951 -> V=1.0, theta=0.0
% INFO    : Bus 69686	: V=0.9984448, theta=-80.572413 -> V=1.0, theta=0.0
% INFO    : Bus 69687	: V=0.9984625, theta=-80.815544 -> V=1.0, theta=0.0
% INFO    : Bus 69688	: V=0.9985658, theta=-81.032209 -> V=1.0, theta=0.0
% INFO    : Bus 69689	: V=0.9982159, theta=-81.042953 -> V=1.0, theta=0.0
% INFO    : Bus 69690	: V=1.0005838, theta=-81.766736 -> V=1.0, theta=0.0
% INFO    : Bus 69691	: V=0.9995512, theta=-80.890215 -> V=1.0, theta=0.0
% INFO    : Bus 69692	: V=0.9992842, theta=-80.801996 -> V=1.0, theta=0.0
% INFO    : Bus 69693	: V=0.9991593, theta=-80.872559 -> V=1.0, theta=0.0
% INFO    : Bus 69694	: V=1.0000659, theta=-81.667326 -> V=1.0, theta=0.0
% INFO    : Bus 69695	: V=0.9993452, theta=-80.76993 -> V=1.0, theta=0.0
% INFO    : Bus 69696	: V=0.998211, theta=-81.03778 -> V=1.0, theta=0.0
% INFO    : Bus 69697	: V=0.9981906, theta=-81.347323 -> V=1.0, theta=0.0
% INFO    : Bus 69698	: V=0.9981455, theta=-81.01779 -> V=1.0, theta=0.0
% INFO    : Bus 69699	: V=0.9972159, theta=-81.489273 -> V=1.0, theta=0.0
% INFO    : Bus 69700	: V=1.0002029, theta=-81.652836 -> V=1.0, theta=0.0
% INFO    : Bus 69701	: V=0.9967335, theta=-81.533648 -> V=1.0, theta=0.0
% INFO    : Bus 69702	: V=0.9959764, theta=-81.545628 -> V=1.0, theta=0.0
% INFO    : Bus 69703	: V=0.9974317, theta=-81.044576 -> V=1.0, theta=0.0
% INFO    : Bus 69704	: V=0.9972551, theta=-81.076803 -> V=1.0, theta=0.0
% INFO    : Bus 69705	: V=0.9974584, theta=-81.066086 -> V=1.0, theta=0.0
% INFO    : Bus 69706	: V=0.996397, theta=-81.282546 -> V=1.0, theta=0.0
% INFO    : Bus 69707	: V=0.9961414, theta=-81.204236 -> V=1.0, theta=0.0
% INFO    : Bus 69708	: V=0.9960608, theta=-81.134376 -> V=1.0, theta=0.0
% INFO    : Bus 69709	: V=0.9987089, theta=-80.600802 -> V=1.0, theta=0.0
% INFO    : Bus 69710	: V=0.998618, theta=-80.488723 -> V=1.0, theta=0.0
% INFO    : Bus 69711	: V=0.9986746, theta=-80.387085 -> V=1.0, theta=0.0
% INFO    : Bus 69712	: V=0.9965083, theta=-80.992948 -> V=1.0, theta=0.0
% INFO    : Bus 69713	: V=0.9989162, theta=-80.652762 -> V=1.0, theta=0.0
% INFO    : Bus 69714	: V=0.9972631, theta=-80.793889 -> V=1.0, theta=0.0
% INFO    : Bus 69715	: V=0.9964329, theta=-80.636627 -> V=1.0, theta=0.0
% INFO    : Bus 69716	: V=0.9986264, theta=-80.481111 -> V=1.0, theta=0.0
% INFO    : Bus 69717	: V=0.9963249, theta=-80.681615 -> V=1.0, theta=0.0
% INFO    : Bus 69718	: V=0.996209, theta=-80.634462 -> V=1.0, theta=0.0
% INFO    : Bus 69719	: V=0.9955692, theta=-80.588636 -> V=1.0, theta=0.0
% INFO    : Bus 69720	: V=0.9954922, theta=-80.539002 -> V=1.0, theta=0.0
% INFO    : Bus 69721	: V=0.9951538, theta=-80.537744 -> V=1.0, theta=0.0
% INFO    : Bus 69722	: V=0.9983027, theta=-80.182543 -> V=1.0, theta=0.0
% INFO    : Bus 69723	: V=0.9978646, theta=-79.879261 -> V=1.0, theta=0.0
% INFO    : Bus 69724	: V=0.9959379, theta=-81.075527 -> V=1.0, theta=0.0
% INFO    : Bus 69725	: V=0.9961298, theta=-81.043064 -> V=1.0, theta=0.0
% INFO    : Bus 69726	: V=0.9985523, theta=-80.539023 -> V=1.0, theta=0.0
% INFO    : Bus 69727	: V=0.9985146, theta=-80.495622 -> V=1.0, theta=0.0
% INFO    : Bus 69728	: V=0.9957725, theta=-81.022436 -> V=1.0, theta=0.0
% INFO    : Bus 69729	: V=0.9965479, theta=-81.250359 -> V=1.0, theta=0.0
% INFO    : Bus 69730	: V=0.9964433, theta=-81.155787 -> V=1.0, theta=0.0
% INFO    : Bus 69731	: V=0.9972254, theta=-81.068355 -> V=1.0, theta=0.0
% INFO    : Bus 69732	: V=0.9972053, theta=-81.055402 -> V=1.0, theta=0.0
% INFO    : Bus 69733	: V=0.9954931, theta=-80.994185 -> V=1.0, theta=0.0
% INFO    : Bus 69734	: V=0.9953028, theta=-80.909132 -> V=1.0, theta=0.0
% INFO    : Bus 69735	: V=0.9871755, theta=-80.457445 -> V=1.0, theta=0.0
% INFO    : Bus 69736	: V=1.0100003, theta=-78.678905 -> V=1.0, theta=0.0
% INFO    : Bus 69737	: V=0.9849789, theta=-80.354574 -> V=1.0, theta=0.0
% INFO    : Bus 69738	: V=0.9898186, theta=-80.81908 -> V=1.0, theta=0.0
% INFO    : Bus 69739	: V=0.9874054, theta=-80.839317 -> V=1.0, theta=0.0
% INFO    : Bus 69740	: V=0.9863694, theta=-80.835438 -> V=1.0, theta=0.0
% INFO    : Bus 69741	: V=0.9994745, theta=-80.03275 -> V=1.0, theta=0.0
% INFO    : Bus 69742	: V=0.9887011, theta=-80.996745 -> V=1.0, theta=0.0
% INFO    : Bus 69743	: V=0.9887672, theta=-80.721061 -> V=1.0, theta=0.0
% INFO    : Bus 69744	: V=0.9924099, theta=-80.258148 -> V=1.0, theta=0.0
% INFO    : Bus 69745	: V=0.9917852, theta=-80.399557 -> V=1.0, theta=0.0
% INFO    : Bus 69746	: V=0.9928788, theta=-80.302578 -> V=1.0, theta=0.0
% INFO    : Bus 69747	: V=1.0029463, theta=-79.088816 -> V=1.0, theta=0.0
% INFO    : Bus 69748	: V=0.9933137, theta=-80.129279 -> V=1.0, theta=0.0
% INFO    : Bus 69749	: V=0.9950083, theta=-79.986472 -> V=1.0, theta=0.0
% INFO    : Bus 69750	: V=0.9960383, theta=-80.008716 -> V=1.0, theta=0.0
% INFO    : Bus 69751	: V=0.9996688, theta=-79.907919 -> V=1.0, theta=0.0
% INFO    : Bus 69752	: V=1.0000972, theta=-79.710174 -> V=1.0, theta=0.0
% INFO    : Bus 69753	: V=1.0008473, theta=-79.542115 -> V=1.0, theta=0.0
% INFO    : Bus 69754	: V=1.0023115, theta=-79.286142 -> V=1.0, theta=0.0
% INFO    : Bus 69755	: V=0.9995029, theta=-79.338758 -> V=1.0, theta=0.0
% INFO    : Bus 69756	: V=0.9916753, theta=-79.231344 -> V=1.0, theta=0.0
% INFO    : Bus 69757	: V=0.9992826, theta=-78.748606 -> V=1.0, theta=0.0
% INFO    : Bus 69758	: V=1.000474, theta=-79.192839 -> V=1.0, theta=0.0
% INFO    : Bus 69759	: V=1.0009667, theta=-79.355116 -> V=1.0, theta=0.0
% INFO    : Bus 69760	: V=1.0009783, theta=-79.431465 -> V=1.0, theta=0.0
% INFO    : Bus 69761	: V=1.0010244, theta=-79.53495 -> V=1.0, theta=0.0
% INFO    : Bus 69762	: V=0.9990904, theta=-79.547473 -> V=1.0, theta=0.0
% INFO    : Bus 69763	: V=1.0017111, theta=-79.767997 -> V=1.0, theta=0.0
% INFO    : Bus 69764	: V=0.99739, theta=-80.63554 -> V=1.0, theta=0.0
% INFO    : Bus 69765	: V=1.0018475, theta=-79.847746 -> V=1.0, theta=0.0
% INFO    : Bus 69766	: V=0.9984608, theta=-80.695342 -> V=1.0, theta=0.0
% INFO    : Bus 69767	: V=1.0021864, theta=-79.920042 -> V=1.0, theta=0.0
% INFO    : Bus 69768	: V=0.9989472, theta=-80.151227 -> V=1.0, theta=0.0
% INFO    : Bus 69769	: V=1.0017013, theta=-79.825391 -> V=1.0, theta=0.0
% INFO    : Bus 69770	: V=0.9996626, theta=-79.742572 -> V=1.0, theta=0.0
% INFO    : Bus 69771	: V=1.010169, theta=-79.194063 -> V=1.0, theta=0.0
% INFO    : Bus 69772	: V=1.0017021, theta=-79.657345 -> V=1.0, theta=0.0
% INFO    : Bus 69773	: V=1.0014682, theta=-79.69653 -> V=1.0, theta=0.0
% INFO    : Bus 69774	: V=1.0018215, theta=-79.706977 -> V=1.0, theta=0.0
% INFO    : Bus 69775	: V=1.0017083, theta=-79.774 -> V=1.0, theta=0.0
% INFO    : Bus 69776	: V=0.9982835, theta=-80.760443 -> V=1.0, theta=0.0
% INFO    : Bus 69777	: V=1.0018668, theta=-79.854224 -> V=1.0, theta=0.0
% INFO    : Bus 69778	: V=1.0017286, theta=-79.829494 -> V=1.0, theta=0.0
% INFO    : Bus 69779	: V=1.0012092, theta=-79.684659 -> V=1.0, theta=0.0
% INFO    : Bus 69780	: V=0.9980152, theta=-80.572663 -> V=1.0, theta=0.0
% INFO    : Bus 69781	: V=1.0005503, theta=-79.509971 -> V=1.0, theta=0.0
% INFO    : Bus 69782	: V=1.0101082, theta=-79.170689 -> V=1.0, theta=0.0
% INFO    : Bus 69783	: V=1.0012664, theta=-79.549813 -> V=1.0, theta=0.0
% INFO    : Bus 69784	: V=1.0013896, theta=-79.433809 -> V=1.0, theta=0.0
% INFO    : Bus 69785	: V=1.0011777, theta=-79.36649 -> V=1.0, theta=0.0
% INFO    : Bus 69786	: V=1.0016366, theta=-78.749567 -> V=1.0, theta=0.0
% INFO    : Bus 69787	: V=1.0010704, theta=-78.968928 -> V=1.0, theta=0.0
% INFO    : Bus 69788	: V=0.9977765, theta=-78.634029 -> V=1.0, theta=0.0
% INFO    : Bus 69789	: V=0.9969131, theta=-78.550144 -> V=1.0, theta=0.0
% INFO    : Bus 69790	: V=0.995707, theta=-78.416252 -> V=1.0, theta=0.0
% INFO    : Bus 69791	: V=1.0021721, theta=-78.68465 -> V=1.0, theta=0.0
% INFO    : Bus 69792	: V=0.9959248, theta=-78.270903 -> V=1.0, theta=0.0
% INFO    : Bus 69793	: V=1.0016422, theta=-78.802779 -> V=1.0, theta=0.0
% INFO    : Bus 69794	: V=1.0020694, theta=-78.60432 -> V=1.0, theta=0.0
% INFO    : Bus 69795	: V=1.0019736, theta=-78.386709 -> V=1.0, theta=0.0
% INFO    : Bus 69796	: V=1.0027833, theta=-79.179344 -> V=1.0, theta=0.0
% INFO    : Bus 69797	: V=1.0090857, theta=-79.079502 -> V=1.0, theta=0.0
% INFO    : Bus 69798	: V=1.0102049, theta=-79.139868 -> V=1.0, theta=0.0
% INFO    : Bus 69799	: V=1.000691, theta=-79.284831 -> V=1.0, theta=0.0
% INFO    : Bus 69800	: V=1.0006178, theta=-79.393556 -> V=1.0, theta=0.0
% INFO    : Bus 69801	: V=0.9999125, theta=-79.312228 -> V=1.0, theta=0.0
% INFO    : Bus 69802	: V=1.0002642, theta=-79.443988 -> V=1.0, theta=0.0
% INFO    : Bus 69803	: V=1.0000853, theta=-79.38759 -> V=1.0, theta=0.0
% INFO    : Bus 69804	: V=0.9992401, theta=-80.183564 -> V=1.0, theta=0.0
% INFO    : Bus 69805	: V=0.9948148, theta=-80.149606 -> V=1.0, theta=0.0
% INFO    : Bus 69806	: V=0.995825, theta=-80.424717 -> V=1.0, theta=0.0
% INFO    : Bus 69807	: V=0.9985816, theta=-80.349824 -> V=1.0, theta=0.0
% INFO    : Bus 69808	: V=0.9987374, theta=-80.248203 -> V=1.0, theta=0.0
% INFO    : Bus 69809	: V=0.993702, theta=-79.826125 -> V=1.0, theta=0.0
% INFO    : Bus 69810	: V=0.9998794, theta=-79.223903 -> V=1.0, theta=0.0
% INFO    : Bus 69811	: V=0.9999154, theta=-79.129894 -> V=1.0, theta=0.0
% INFO    : Bus 69812	: V=1.0009477, theta=-79.162744 -> V=1.0, theta=0.0
% INFO    : Bus 69813	: V=0.9984846, theta=-79.349205 -> V=1.0, theta=0.0
% INFO    : Bus 69814	: V=1.0013276, theta=-79.016537 -> V=1.0, theta=0.0
% INFO    : Bus 69815	: V=1.0026926, theta=-78.905785 -> V=1.0, theta=0.0
% INFO    : Bus 69816	: V=1.0092044, theta=-79.095151 -> V=1.0, theta=0.0
% INFO    : Bus 69817	: V=1.0016784, theta=-78.89415 -> V=1.0, theta=0.0
% INFO    : Bus 69818	: V=0.9977769, theta=-79.26703 -> V=1.0, theta=0.0
% INFO    : Bus 69819	: V=0.9994588, theta=-79.227643 -> V=1.0, theta=0.0
% INFO    : Bus 69820	: V=0.9994075, theta=-79.258754 -> V=1.0, theta=0.0
% INFO    : Bus 69821	: V=0.9975057, theta=-79.218631 -> V=1.0, theta=0.0
% INFO    : Bus 69822	: V=0.9975107, theta=-79.086299 -> V=1.0, theta=0.0
% INFO    : Bus 69823	: V=1.0006687, theta=-78.753526 -> V=1.0, theta=0.0
% INFO    : Bus 69824	: V=1.0009684, theta=-78.647012 -> V=1.0, theta=0.0
% INFO    : Bus 69825	: V=1.0010304, theta=-78.480186 -> V=1.0, theta=0.0
% INFO    : Bus 69826	: V=0.9996308, theta=-78.343002 -> V=1.0, theta=0.0
% INFO    : Bus 69827	: V=0.9988111, theta=-77.766447 -> V=1.0, theta=0.0
% INFO    : Bus 69828	: V=1.0095232, theta=-76.766823 -> V=1.0, theta=0.0
% INFO    : Bus 69829	: V=0.9962084, theta=-78.227155 -> V=1.0, theta=0.0
% INFO    : Bus 69830	: V=0.9964991, theta=-77.961757 -> V=1.0, theta=0.0
% INFO    : Bus 69831	: V=1.0031838, theta=-77.29674 -> V=1.0, theta=0.0
% INFO    : Bus 69832	: V=1.0032494, theta=-77.221361 -> V=1.0, theta=0.0
% INFO    : Bus 69833	: V=1.0100003, theta=-76.461672 -> V=1.0, theta=0.0
% INFO    : Bus 69834	: V=1.0000059, theta=-77.577053 -> V=1.0, theta=0.0
% INFO    : Bus 69835	: V=1.0100003, theta=-76.274808 -> V=1.0, theta=0.0
% INFO    : Bus 69836	: V=1.0082436, theta=-76.623736 -> V=1.0, theta=0.0
% INFO    : Bus 69837	: V=1.0014133, theta=-77.595911 -> V=1.0, theta=0.0
% INFO    : Bus 69838	: V=1.0020016, theta=-78.167953 -> V=1.0, theta=0.0
% INFO    : Bus 69839	: V=0.9964173, theta=-78.226612 -> V=1.0, theta=0.0
% INFO    : Bus 69840	: V=1.0020877, theta=-77.919167 -> V=1.0, theta=0.0
% INFO    : Bus 69841	: V=1.0023207, theta=-77.689223 -> V=1.0, theta=0.0
% INFO    : Bus 69842	: V=1.0026216, theta=-77.433914 -> V=1.0, theta=0.0
% INFO    : Bus 69843	: V=1.004095, theta=-77.077754 -> V=1.0, theta=0.0
% INFO    : Bus 69844	: V=1.004732, theta=-76.940171 -> V=1.0, theta=0.0
% INFO    : Bus 69845	: V=1.0018226, theta=-77.342705 -> V=1.0, theta=0.0
% INFO    : Bus 69846	: V=1.0040001, theta=-77.045402 -> V=1.0, theta=0.0
% INFO    : Bus 69847	: V=1.0044439, theta=-76.95245 -> V=1.0, theta=0.0
% INFO    : Bus 69848	: V=1.0056517, theta=-76.688568 -> V=1.0, theta=0.0
% INFO    : Bus 69849	: V=1.0032417, theta=-77.009856 -> V=1.0, theta=0.0
% INFO    : Bus 69850	: V=1.0048997, theta=-76.845246 -> V=1.0, theta=0.0
% INFO    : Bus 69851	: V=1.0012988, theta=-78.232176 -> V=1.0, theta=0.0
% INFO    : Bus 69852	: V=1.0006408, theta=-78.578206 -> V=1.0, theta=0.0
% INFO    : Bus 69853	: V=0.9997853, theta=-78.52246 -> V=1.0, theta=0.0
% INFO    : Bus 69854	: V=0.9995165, theta=-78.552313 -> V=1.0, theta=0.0
% INFO    : Bus 69855	: V=0.9941832, theta=-79.70927 -> V=1.0, theta=0.0
% INFO    : Bus 69856	: V=1.0000126, theta=-79.011589 -> V=1.0, theta=0.0
% INFO    : Bus 69857	: V=0.9962888, theta=-79.216756 -> V=1.0, theta=0.0
% INFO    : Bus 69858	: V=0.9975342, theta=-79.37586 -> V=1.0, theta=0.0
% INFO    : Bus 69859	: V=0.9907707, theta=-79.161187 -> V=1.0, theta=0.0
% INFO    : Bus 69860	: V=0.9909335, theta=-79.157877 -> V=1.0, theta=0.0
% INFO    : Bus 69861	: V=0.9976031, theta=-79.536531 -> V=1.0, theta=0.0
% INFO    : Bus 69862	: V=0.9977274, theta=-79.736507 -> V=1.0, theta=0.0
% INFO    : Bus 69863	: V=0.995284, theta=-80.504314 -> V=1.0, theta=0.0
% INFO    : Bus 69864	: V=0.9975278, theta=-79.210282 -> V=1.0, theta=0.0
% INFO    : Bus 69865	: V=0.9962134, theta=-79.080279 -> V=1.0, theta=0.0
% INFO    : Bus 69866	: V=0.9976693, theta=-78.958445 -> V=1.0, theta=0.0
% INFO    : Bus 69867	: V=0.9978993, theta=-78.825064 -> V=1.0, theta=0.0
% INFO    : Bus 69868	: V=0.9968323, theta=-78.897731 -> V=1.0, theta=0.0
% INFO    : Bus 69869	: V=0.9976463, theta=-78.720034 -> V=1.0, theta=0.0
% INFO    : Bus 69870	: V=0.9949063, theta=-78.597584 -> V=1.0, theta=0.0
% INFO    : Bus 69871	: V=1.0001949, theta=-78.480168 -> V=1.0, theta=0.0
% INFO    : Bus 69872	: V=0.9989542, theta=-77.948886 -> V=1.0, theta=0.0
% INFO    : Bus 69873	: V=1.001588, theta=-77.966438 -> V=1.0, theta=0.0
% INFO    : Bus 69874	: V=1.0000528, theta=-77.642799 -> V=1.0, theta=0.0
% INFO    : Bus 69875	: V=1.0021417, theta=-77.691209 -> V=1.0, theta=0.0
% INFO    : Bus 69876	: V=1.0025059, theta=-77.502884 -> V=1.0, theta=0.0
% INFO    : Bus 69877	: V=0.9991205, theta=-78.408563 -> V=1.0, theta=0.0
% INFO    : Bus 69878	: V=0.9958639, theta=-78.33852 -> V=1.0, theta=0.0
% INFO    : Bus 69879	: V=0.9992866, theta=-78.229752 -> V=1.0, theta=0.0
% INFO    : Bus 69880	: V=0.9915549, theta=-79.125946 -> V=1.0, theta=0.0
% INFO    : Bus 69881	: V=0.9982543, theta=-78.664926 -> V=1.0, theta=0.0
% INFO    : Bus 69882	: V=0.9987068, theta=-78.449503 -> V=1.0, theta=0.0
% INFO    : Bus 69883	: V=0.992337, theta=-79.061186 -> V=1.0, theta=0.0
% INFO    : Bus 69884	: V=0.9909535, theta=-79.18826 -> V=1.0, theta=0.0
% INFO    : Bus 69885	: V=0.9913706, theta=-79.146445 -> V=1.0, theta=0.0
% INFO    : Bus 69886	: V=0.9917043, theta=-79.122411 -> V=1.0, theta=0.0
% INFO    : Bus 69887	: V=0.9929162, theta=-78.747428 -> V=1.0, theta=0.0
% INFO    : Bus 69888	: V=0.9920347, theta=-79.034659 -> V=1.0, theta=0.0
% INFO    : Bus 69889	: V=0.992282, theta=-78.963076 -> V=1.0, theta=0.0
% INFO    : Bus 69890	: V=0.993379, theta=-78.742195 -> V=1.0, theta=0.0
% INFO    : Bus 69891	: V=0.9924319, theta=-79.189742 -> V=1.0, theta=0.0
% INFO    : Bus 69892	: V=0.9942898, theta=-78.723982 -> V=1.0, theta=0.0
% INFO    : Bus 69893	: V=0.9948748, theta=-78.721867 -> V=1.0, theta=0.0
% INFO    : Bus 69894	: V=0.9903451, theta=-79.373686 -> V=1.0, theta=0.0
% INFO    : Bus 69895	: V=0.9933226, theta=-79.141544 -> V=1.0, theta=0.0
% INFO    : Bus 69896	: V=0.9924771, theta=-79.188009 -> V=1.0, theta=0.0
% INFO    : Bus 69897	: V=0.990179, theta=-79.373997 -> V=1.0, theta=0.0
% INFO    : Bus 69898	: V=0.9943069, theta=-79.097802 -> V=1.0, theta=0.0
% INFO    : Bus 69899	: V=0.9969094, theta=-78.851231 -> V=1.0, theta=0.0
% INFO    : Bus 69900	: V=0.9988258, theta=-78.750113 -> V=1.0, theta=0.0
% INFO    : Bus 69901	: V=0.9992285, theta=-78.600152 -> V=1.0, theta=0.0
% INFO    : Bus 69902	: V=0.9975015, theta=-78.510817 -> V=1.0, theta=0.0
% INFO    : Bus 69903	: V=0.998372, theta=-78.558223 -> V=1.0, theta=0.0
% INFO    : Bus 69904	: V=0.9978218, theta=-78.527033 -> V=1.0, theta=0.0
% INFO    : Bus 69905	: V=0.9955908, theta=-78.646573 -> V=1.0, theta=0.0
% INFO    : Bus 69906	: V=0.9960991, theta=-78.591818 -> V=1.0, theta=0.0
% INFO    : Bus 69907	: V=0.9971604, theta=-78.481413 -> V=1.0, theta=0.0
% INFO    : Bus 69908	: V=0.9974695, theta=-78.356799 -> V=1.0, theta=0.0
% INFO    : Bus 69909	: V=0.9930294, theta=-78.878923 -> V=1.0, theta=0.0
% INFO    : Bus 69910	: V=1.0011128, theta=-77.704502 -> V=1.0, theta=0.0
% INFO    : Bus 69911	: V=1.0015181, theta=-77.67143 -> V=1.0, theta=0.0
% INFO    : Bus 69912	: V=1.0002563, theta=-78.184593 -> V=1.0, theta=0.0
% INFO    : Bus 69913	: V=1.0032636, theta=-77.217283 -> V=1.0, theta=0.0
% INFO    : Bus 69914	: V=1.0027735, theta=-77.185978 -> V=1.0, theta=0.0
% INFO    : Bus 69915	: V=1.0064431, theta=-76.532739 -> V=1.0, theta=0.0
% INFO    : Bus 69916	: V=1.0042974, theta=-76.873075 -> V=1.0, theta=0.0
% INFO    : Bus 69917	: V=1.0009443, theta=-77.843641 -> V=1.0, theta=0.0
% INFO    : Bus 69918	: V=0.9987942, theta=-77.54192 -> V=1.0, theta=0.0
% INFO    : Bus 69919	: V=0.9967224, theta=-77.739315 -> V=1.0, theta=0.0
% INFO    : Bus 69920	: V=1.0018461, theta=-77.431738 -> V=1.0, theta=0.0
% INFO    : Bus 69921	: V=1.0044842, theta=-76.769023 -> V=1.0, theta=0.0
% INFO    : Bus 69922	: V=1.0051347, theta=-76.558266 -> V=1.0, theta=0.0
% INFO    : Bus 69923	: V=1.0037053, theta=-76.600053 -> V=1.0, theta=0.0
% INFO    : Bus 69924	: V=1.0044038, theta=-76.431766 -> V=1.0, theta=0.0
% INFO    : Bus 69925	: V=1.0043394, theta=-76.727315 -> V=1.0, theta=0.0
% INFO    : Bus 69926	: V=1.0037378, theta=-76.940253 -> V=1.0, theta=0.0
% INFO    : Bus 69927	: V=1.0034714, theta=-76.959508 -> V=1.0, theta=0.0
% INFO    : Bus 69928	: V=0.9980273, theta=-77.673863 -> V=1.0, theta=0.0
% INFO    : Bus 69929	: V=0.9972496, theta=-77.711706 -> V=1.0, theta=0.0
% INFO    : Bus 69930	: V=0.9982821, theta=-77.697958 -> V=1.0, theta=0.0
% INFO    : Bus 69931	: V=0.9972308, theta=-78.361436 -> V=1.0, theta=0.0
% INFO    : Bus 69932	: V=1.0027361, theta=-77.593148 -> V=1.0, theta=0.0
% INFO    : Bus 69933	: V=0.9988213, theta=-77.714618 -> V=1.0, theta=0.0
% INFO    : Bus 69934	: V=0.9969594, theta=-78.437742 -> V=1.0, theta=0.0
% INFO    : Bus 69935	: V=0.9972219, theta=-78.394617 -> V=1.0, theta=0.0
% INFO    : Bus 69936	: V=0.997302, theta=-78.431026 -> V=1.0, theta=0.0
% INFO    : Bus 69937	: V=1.0046772, theta=-77.970636 -> V=1.0, theta=0.0
% INFO    : Bus 69938	: V=0.9974195, theta=-78.458889 -> V=1.0, theta=0.0
% INFO    : Bus 69939	: V=1.0154565, theta=-78.078493 -> V=1.0, theta=0.0
% INFO    : Bus 69940	: V=0.9978018, theta=-78.444205 -> V=1.0, theta=0.0
% INFO    : Bus 69941	: V=0.9979094, theta=-78.423839 -> V=1.0, theta=0.0
% INFO    : Bus 69942	: V=0.9979214, theta=-78.409632 -> V=1.0, theta=0.0
% INFO    : Bus 69943	: V=0.9979794, theta=-78.427997 -> V=1.0, theta=0.0
% INFO    : Bus 69944	: V=0.9983134, theta=-78.411765 -> V=1.0, theta=0.0
% INFO    : Bus 69945	: V=1.004461, theta=-77.713661 -> V=1.0, theta=0.0
% INFO    : Bus 69946	: V=0.9986353, theta=-78.319363 -> V=1.0, theta=0.0
% INFO    : Bus 69947	: V=0.998026, theta=-78.387442 -> V=1.0, theta=0.0
% INFO    : Bus 69948	: V=0.9969007, theta=-78.391966 -> V=1.0, theta=0.0
% INFO    : Bus 69949	: V=0.9970668, theta=-78.39056 -> V=1.0, theta=0.0
% INFO    : Bus 69950	: V=0.9969677, theta=-78.392045 -> V=1.0, theta=0.0
% INFO    : Bus 69951	: V=0.9969725, theta=-78.388929 -> V=1.0, theta=0.0
% INFO    : Bus 69952	: V=0.9986623, theta=-78.238012 -> V=1.0, theta=0.0
% INFO    : Bus 69953	: V=0.9987716, theta=-78.17796 -> V=1.0, theta=0.0
% INFO    : Bus 69954	: V=0.9986161, theta=-78.180004 -> V=1.0, theta=0.0
% INFO    : Bus 69955	: V=0.9984006, theta=-78.238985 -> V=1.0, theta=0.0
% INFO    : Bus 69956	: V=1.0037647, theta=-77.520534 -> V=1.0, theta=0.0
% INFO    : Bus 69957	: V=1.0036041, theta=-77.401799 -> V=1.0, theta=0.0
% INFO    : Bus 69958	: V=0.9990645, theta=-77.948487 -> V=1.0, theta=0.0
% INFO    : Bus 69959	: V=0.9991139, theta=-77.866476 -> V=1.0, theta=0.0
% INFO    : Bus 69960	: V=0.9970853, theta=-78.380296 -> V=1.0, theta=0.0
% INFO    : Bus 69961	: V=1.0028474, theta=-77.479134 -> V=1.0, theta=0.0
% INFO    : Bus 69962	: V=0.9990779, theta=-77.808005 -> V=1.0, theta=0.0
% INFO    : Bus 69963	: V=0.9999077, theta=-77.259853 -> V=1.0, theta=0.0
% INFO    : Bus 69964	: V=0.999338, theta=-77.83987 -> V=1.0, theta=0.0
% INFO    : Bus 69965	: V=1.0034902, theta=-77.274612 -> V=1.0, theta=0.0
% INFO    : Bus 69966	: V=1.0035191, theta=-77.123269 -> V=1.0, theta=0.0
% INFO    : Bus 69967	: V=0.998969, theta=-77.33411 -> V=1.0, theta=0.0
% INFO    : Bus 69968	: V=0.9983688, theta=-77.339948 -> V=1.0, theta=0.0
% INFO    : Bus 69969	: V=0.9983369, theta=-77.341142 -> V=1.0, theta=0.0
% INFO    : Bus 69970	: V=1.009303, theta=-75.17021 -> V=1.0, theta=0.0
% INFO    : Bus 69971	: V=0.999262, theta=-77.30755 -> V=1.0, theta=0.0
% INFO    : Bus 69972	: V=1.0056317, theta=-75.952998 -> V=1.0, theta=0.0
% INFO    : Bus 69973	: V=0.9712796, theta=-81.762459 -> V=1.0, theta=0.0
% INFO    : Bus 69974	: V=0.9681645, theta=-81.892188 -> V=1.0, theta=0.0
% INFO    : Bus 69975	: V=1.0021471, theta=-82.126427 -> V=1.0, theta=0.0
% INFO    : Bus 69976	: V=1.0020186, theta=-82.496212 -> V=1.0, theta=0.0
% INFO    : Bus 69977	: V=1.0021477, theta=-82.106428 -> V=1.0, theta=0.0
% INFO    : Bus 69978	: V=1.0022003, theta=-82.073674 -> V=1.0, theta=0.0
% INFO    : Bus 69979	: V=1.0021668, theta=-82.087547 -> V=1.0, theta=0.0
% INFO    : Bus 69980	: V=1.0021199, theta=-81.98853 -> V=1.0, theta=0.0
% INFO    : Bus 69981	: V=1.001486, theta=-82.245174 -> V=1.0, theta=0.0
% INFO    : Bus 69982	: V=1.0019762, theta=-82.302427 -> V=1.0, theta=0.0
% INFO    : Bus 69983	: V=1.0029614, theta=-82.058343 -> V=1.0, theta=0.0
% INFO    : Bus 69984	: V=1.0030659, theta=-82.232934 -> V=1.0, theta=0.0
% INFO    : Bus 69985	: V=1.00298, theta=-82.210553 -> V=1.0, theta=0.0
% INFO    : Bus 69986	: V=1.00335, theta=-82.260516 -> V=1.0, theta=0.0
% INFO    : Bus 69987	: V=1.0029794, theta=-82.88842 -> V=1.0, theta=0.0
% INFO    : Bus 69988	: V=1.0032364, theta=-82.322067 -> V=1.0, theta=0.0
% INFO    : Bus 69989	: V=1.0031535, theta=-82.379383 -> V=1.0, theta=0.0
% INFO    : Bus 69990	: V=1.0031694, theta=-82.45876 -> V=1.0, theta=0.0
% INFO    : Bus 69991	: V=1.0035101, theta=-82.515142 -> V=1.0, theta=0.0
% INFO    : Bus 69992	: V=1.002968, theta=-82.92243 -> V=1.0, theta=0.0
% INFO    : Bus 69993	: V=1.0027157, theta=-82.934351 -> V=1.0, theta=0.0
% INFO    : Bus 69994	: V=1.0033142, theta=-82.455947 -> V=1.0, theta=0.0
% INFO    : Bus 69995	: V=1.0033331, theta=-82.386573 -> V=1.0, theta=0.0
% INFO    : Bus 69996	: V=1.0033075, theta=-82.309077 -> V=1.0, theta=0.0
% INFO    : Bus 69997	: V=1.0026156, theta=-82.846711 -> V=1.0, theta=0.0
% INFO    : Bus 69998	: V=1.0027749, theta=-82.911136 -> V=1.0, theta=0.0
% INFO    : Bus 69999	: V=1.0027393, theta=-82.901471 -> V=1.0, theta=0.0
% INFO    : Bus 70000	: V=1.002757, theta=-83.089977 -> V=1.0, theta=0.0
% INFO    : Bus 70001	: V=1.0041361, theta=-82.530958 -> V=1.0, theta=0.0
% INFO    : Bus 70002	: V=1.0029224, theta=-83.076519 -> V=1.0, theta=0.0
% INFO    : Bus 70003	: V=1.0050275, theta=-82.413229 -> V=1.0, theta=0.0
% INFO    : Bus 70004	: V=1.0028396, theta=-82.92543 -> V=1.0, theta=0.0
% INFO    : Bus 70005	: V=1.002988, theta=-82.861657 -> V=1.0, theta=0.0
% INFO    : Bus 70006	: V=1.0031093, theta=-82.850669 -> V=1.0, theta=0.0
% INFO    : Bus 70007	: V=1.0033076, theta=-82.832652 -> V=1.0, theta=0.0
% INFO    : Bus 70008	: V=1.0034616, theta=-82.146122 -> V=1.0, theta=0.0
% INFO    : Bus 70009	: V=1.00334, theta=-82.246862 -> V=1.0, theta=0.0
% INFO    : Bus 70010	: V=1.0033898, theta=-82.206244 -> V=1.0, theta=0.0
% INFO    : Bus 70011	: V=1.0027398, theta=-82.589989 -> V=1.0, theta=0.0
% INFO    : Bus 70012	: V=1.0030316, theta=-82.118896 -> V=1.0, theta=0.0
% INFO    : Bus 70013	: V=1.0029747, theta=-82.164334 -> V=1.0, theta=0.0
% INFO    : Bus 70014	: V=1.0029579, theta=-82.213603 -> V=1.0, theta=0.0
% INFO    : Bus 70015	: V=1.0039267, theta=-82.048593 -> V=1.0, theta=0.0
% INFO    : Bus 70016	: V=1.0032015, theta=-82.130988 -> V=1.0, theta=0.0
% INFO    : Bus 70017	: V=0.9995525, theta=-82.104396 -> V=1.0, theta=0.0
% INFO    : Bus 70018	: V=1.0044234, theta=-81.965983 -> V=1.0, theta=0.0
% INFO    : Bus 70019	: V=1.0048869, theta=-81.960193 -> V=1.0, theta=0.0
% INFO    : Bus 70020	: V=1.0001334, theta=-82.0232 -> V=1.0, theta=0.0
% INFO    : Bus 70021	: V=1.0071845, theta=-81.515892 -> V=1.0, theta=0.0
% INFO    : Bus 70022	: V=1.0050016, theta=-81.853799 -> V=1.0, theta=0.0
% INFO    : Bus 70023	: V=0.9996504, theta=-82.059346 -> V=1.0, theta=0.0
% INFO    : Bus 70024	: V=0.999968, theta=-82.021221 -> V=1.0, theta=0.0
% INFO    : Bus 70025	: V=1.0030365, theta=-81.739634 -> V=1.0, theta=0.0
% INFO    : Bus 70026	: V=1.0037264, theta=-81.781225 -> V=1.0, theta=0.0
% INFO    : Bus 70027	: V=1.0028045, theta=-81.758855 -> V=1.0, theta=0.0
% INFO    : Bus 70028	: V=0.9982235, theta=-82.009278 -> V=1.0, theta=0.0
% INFO    : Bus 70029	: V=1.0032844, theta=-81.886744 -> V=1.0, theta=0.0
% INFO    : Bus 70030	: V=1.0029002, theta=-81.969385 -> V=1.0, theta=0.0
% INFO    : Bus 70031	: V=1.0025269, theta=-81.789691 -> V=1.0, theta=0.0
% INFO    : Bus 70032	: V=1.002324, theta=-82.029368 -> V=1.0, theta=0.0
% INFO    : Bus 70033	: V=1.0021747, theta=-81.935385 -> V=1.0, theta=0.0
% INFO    : Bus 70034	: V=1.0022576, theta=-81.896043 -> V=1.0, theta=0.0
% INFO    : Bus 70035	: V=1.0024335, theta=-81.820126 -> V=1.0, theta=0.0
% INFO    : Bus 70036	: V=0.9999569, theta=-81.512368 -> V=1.0, theta=0.0
% INFO    : Bus 70037	: V=0.9959383, theta=-81.588274 -> V=1.0, theta=0.0
% INFO    : Bus 70038	: V=1.0000605, theta=-81.463881 -> V=1.0, theta=0.0
% INFO    : Bus 70039	: V=0.9996729, theta=-81.334589 -> V=1.0, theta=0.0
% INFO    : Bus 70040	: V=0.9954734, theta=-81.526503 -> V=1.0, theta=0.0
% INFO    : Bus 70041	: V=0.9983776, theta=-81.141136 -> V=1.0, theta=0.0
% INFO    : Bus 70042	: V=0.9922345, theta=-81.351002 -> V=1.0, theta=0.0
% INFO    : Bus 70043	: V=0.9993884, theta=-81.266293 -> V=1.0, theta=0.0
% INFO    : Bus 70044	: V=0.9990103, theta=-81.184666 -> V=1.0, theta=0.0
% INFO    : Bus 70045	: V=1.0002208, theta=-81.408841 -> V=1.0, theta=0.0
% INFO    : Bus 70046	: V=0.9979491, theta=-82.005496 -> V=1.0, theta=0.0
% INFO    : Bus 70047	: V=1.0011176, theta=-81.42813 -> V=1.0, theta=0.0
% INFO    : Bus 70048	: V=1.0024135, theta=-81.449141 -> V=1.0, theta=0.0
% INFO    : Bus 70049	: V=1.0034138, theta=-81.713994 -> V=1.0, theta=0.0
% INFO    : Bus 70050	: V=0.9982842, theta=-82.003296 -> V=1.0, theta=0.0
% INFO    : Bus 70051	: V=1.0048245, theta=-81.7314 -> V=1.0, theta=0.0
% INFO    : Bus 70052	: V=1.003503, theta=-81.577069 -> V=1.0, theta=0.0
% INFO    : Bus 70053	: V=1.0060638, theta=-81.676646 -> V=1.0, theta=0.0
% INFO    : Bus 70054	: V=1.0034919, theta=-81.574772 -> V=1.0, theta=0.0
% INFO    : Bus 70055	: V=1.0010188, theta=-81.527899 -> V=1.0, theta=0.0
% INFO    : Bus 70056	: V=1.0038885, theta=-81.462744 -> V=1.0, theta=0.0
% INFO    : Bus 70057	: V=1.0010427, theta=-80.448468 -> V=1.0, theta=0.0
% INFO    : Bus 70058	: V=1.0091502, theta=-81.748396 -> V=1.0, theta=0.0
% INFO    : Bus 70059	: V=1.0099946, theta=-81.633675 -> V=1.0, theta=0.0
% INFO    : Bus 70060	: V=1.0100003, theta=-80.727279 -> V=1.0, theta=0.0
% INFO    : Bus 70061	: V=1.0119769, theta=-80.670858 -> V=1.0, theta=0.0
% INFO    : Bus 70062	: V=1.0094394, theta=-81.664454 -> V=1.0, theta=0.0
% INFO    : Bus 70063	: V=1.0125066, theta=-81.298005 -> V=1.0, theta=0.0
% INFO    : Bus 70064	: V=1.0122257, theta=-81.251863 -> V=1.0, theta=0.0
% INFO    : Bus 70065	: V=1.0092235, theta=-81.654312 -> V=1.0, theta=0.0
% INFO    : Bus 70066	: V=1.0101475, theta=-81.43298 -> V=1.0, theta=0.0
% INFO    : Bus 70067	: V=1.0141477, theta=-80.423785 -> V=1.0, theta=0.0
% INFO    : Bus 70068	: V=1.0038358, theta=-81.534495 -> V=1.0, theta=0.0
% INFO    : Bus 70069	: V=1.00464, theta=-81.523168 -> V=1.0, theta=0.0
% INFO    : Bus 70070	: V=1.006186, theta=-81.268764 -> V=1.0, theta=0.0
% INFO    : Bus 70071	: V=0.9979624, theta=-81.463844 -> V=1.0, theta=0.0
% INFO    : Bus 70072	: V=1.0055767, theta=-81.500531 -> V=1.0, theta=0.0
% INFO    : Bus 70073	: V=1.0061197, theta=-81.474343 -> V=1.0, theta=0.0
% INFO    : Bus 70074	: V=1.006161, theta=-81.559222 -> V=1.0, theta=0.0
% INFO    : Bus 70075	: V=1.0118515, theta=-81.186282 -> V=1.0, theta=0.0
% INFO    : Bus 70076	: V=1.0072331, theta=-81.587258 -> V=1.0, theta=0.0
% INFO    : Bus 70077	: V=1.0115836, theta=-81.042497 -> V=1.0, theta=0.0
% INFO    : Bus 70078	: V=1.0077116, theta=-81.403943 -> V=1.0, theta=0.0
% INFO    : Bus 70079	: V=1.0116573, theta=-81.096225 -> V=1.0, theta=0.0
% INFO    : Bus 70080	: V=1.0067385, theta=-81.431806 -> V=1.0, theta=0.0
% INFO    : Bus 70081	: V=1.0196916, theta=-80.135087 -> V=1.0, theta=0.0
% INFO    : Bus 70082	: V=1.0092818, theta=-80.870705 -> V=1.0, theta=0.0
% INFO    : Bus 70083	: V=1.0109437, theta=-80.87083 -> V=1.0, theta=0.0
% INFO    : Bus 70084	: V=1.0026664, theta=-81.595852 -> V=1.0, theta=0.0
% INFO    : Bus 70085	: V=1.0022646, theta=-81.59981 -> V=1.0, theta=0.0
% INFO    : Bus 70086	: V=1.0000106, theta=-81.680576 -> V=1.0, theta=0.0
% INFO    : Bus 70087	: V=1.0004172, theta=-81.6791 -> V=1.0, theta=0.0
% INFO    : Bus 70088	: V=0.9954103, theta=-81.500838 -> V=1.0, theta=0.0
% INFO    : Bus 70089	: V=0.9991108, theta=-81.549574 -> V=1.0, theta=0.0
% INFO    : Bus 70090	: V=0.9991772, theta=-81.628832 -> V=1.0, theta=0.0
% INFO    : Bus 70091	: V=0.9971822, theta=-81.483089 -> V=1.0, theta=0.0
% INFO    : Bus 70092	: V=0.9996413, theta=-81.52649 -> V=1.0, theta=0.0
% INFO    : Bus 70093	: V=0.9999254, theta=-81.427355 -> V=1.0, theta=0.0
% INFO    : Bus 70094	: V=0.9980208, theta=-81.55089 -> V=1.0, theta=0.0
% INFO    : Bus 70095	: V=1.0100003, theta=-79.824692 -> V=1.0, theta=0.0
% INFO    : Bus 70096	: V=0.9966101, theta=-81.412782 -> V=1.0, theta=0.0
% INFO    : Bus 70097	: V=1.0069367, theta=-80.86605 -> V=1.0, theta=0.0
% INFO    : Bus 70098	: V=0.9949454, theta=-81.356583 -> V=1.0, theta=0.0
% INFO    : Bus 70099	: V=0.9957539, theta=-81.383557 -> V=1.0, theta=0.0
% INFO    : Bus 70100	: V=0.9949792, theta=-81.317159 -> V=1.0, theta=0.0
% INFO    : Bus 70101	: V=0.9947051, theta=-81.318506 -> V=1.0, theta=0.0
% INFO    : Bus 70102	: V=0.9929035, theta=-81.357295 -> V=1.0, theta=0.0
% INFO    : Bus 70103	: V=1.0021498, theta=-81.601587 -> V=1.0, theta=0.0
% INFO    : Bus 70104	: V=0.9935241, theta=-81.392171 -> V=1.0, theta=0.0
% INFO    : Bus 70105	: V=1.0100003, theta=-79.933784 -> V=1.0, theta=0.0
% INFO    : Bus 70106	: V=1.0008969, theta=-80.600342 -> V=1.0, theta=0.0
% INFO    : Bus 70107	: V=0.9917651, theta=-80.551413 -> V=1.0, theta=0.0
% INFO    : Bus 70108	: V=0.991582, theta=-80.590442 -> V=1.0, theta=0.0
% INFO    : Bus 70109	: V=0.9877741, theta=-81.134152 -> V=1.0, theta=0.0
% INFO    : Bus 70110	: V=0.991215, theta=-81.292524 -> V=1.0, theta=0.0
% INFO    : Bus 70111	: V=0.9984531, theta=-81.693465 -> V=1.0, theta=0.0
% INFO    : Bus 70112	: V=0.9918513, theta=-81.324899 -> V=1.0, theta=0.0
% INFO    : Bus 70113	: V=0.9968886, theta=-81.680824 -> V=1.0, theta=0.0
% INFO    : Bus 70114	: V=0.9979845, theta=-81.785268 -> V=1.0, theta=0.0
% INFO    : Bus 70115	: V=0.9998562, theta=-81.6809 -> V=1.0, theta=0.0
% INFO    : Bus 70116	: V=0.9893895, theta=-80.856094 -> V=1.0, theta=0.0
% INFO    : Bus 70117	: V=0.9877132, theta=-81.020542 -> V=1.0, theta=0.0
% INFO    : Bus 70118	: V=0.9911166, theta=-80.43273 -> V=1.0, theta=0.0
% INFO    : Bus 70119	: V=0.9909058, theta=-80.649936 -> V=1.0, theta=0.0
% INFO    : Bus 70120	: V=0.9897569, theta=-80.814582 -> V=1.0, theta=0.0
% INFO    : Bus 70121	: V=0.9917535, theta=-80.645027 -> V=1.0, theta=0.0
% INFO    : Bus 70122	: V=0.9888275, theta=-80.856005 -> V=1.0, theta=0.0
% INFO    : Bus 70123	: V=0.9868843, theta=-81.03055 -> V=1.0, theta=0.0
% INFO    : Bus 70124	: V=0.9992984, theta=-81.84366 -> V=1.0, theta=0.0
% INFO    : Bus 70125	: V=0.9983726, theta=-81.842989 -> V=1.0, theta=0.0
% INFO    : Bus 70126	: V=0.9953047, theta=-81.905338 -> V=1.0, theta=0.0
% INFO    : Bus 70127	: V=0.9976599, theta=-81.571787 -> V=1.0, theta=0.0
% INFO    : Bus 70128	: V=0.996982, theta=-81.579369 -> V=1.0, theta=0.0
% INFO    : Bus 70129	: V=0.9967538, theta=-81.580129 -> V=1.0, theta=0.0
% INFO    : Bus 70130	: V=0.9958857, theta=-81.575295 -> V=1.0, theta=0.0
% INFO    : Bus 70131	: V=0.9984023, theta=-81.84555 -> V=1.0, theta=0.0
% INFO    : Bus 70132	: V=0.9953887, theta=-81.575458 -> V=1.0, theta=0.0
% INFO    : Bus 70133	: V=0.9944934, theta=-81.916798 -> V=1.0, theta=0.0
% INFO    : Bus 70134	: V=0.9984995, theta=-81.238867 -> V=1.0, theta=0.0
% INFO    : Bus 70135	: V=0.9819787, theta=-81.046962 -> V=1.0, theta=0.0
% INFO    : Bus 70136	: V=1.0002299, theta=-80.700449 -> V=1.0, theta=0.0
% INFO    : Bus 70137	: V=0.9991449, theta=-80.930175 -> V=1.0, theta=0.0
% INFO    : Bus 70138	: V=1.0030969, theta=-83.339906 -> V=1.0, theta=0.0
% INFO    : Bus 70139	: V=1.0030701, theta=-83.324387 -> V=1.0, theta=0.0
% INFO    : Bus 70140	: V=0.9999394, theta=-83.928954 -> V=1.0, theta=0.0
% INFO    : Bus 70141	: V=0.9998574, theta=-83.913993 -> V=1.0, theta=0.0
% INFO    : Bus 70142	: V=1.0031304, theta=-83.4271 -> V=1.0, theta=0.0
% INFO    : Bus 70143	: V=0.9996376, theta=-83.918318 -> V=1.0, theta=0.0
% INFO    : Bus 70144	: V=0.9998661, theta=-83.907902 -> V=1.0, theta=0.0
% INFO    : Bus 70145	: V=1.0000335, theta=-83.925662 -> V=1.0, theta=0.0
% INFO    : Bus 70146	: V=1.0009175, theta=-83.913034 -> V=1.0, theta=0.0
% INFO    : Bus 70147	: V=1.0005544, theta=-83.867284 -> V=1.0, theta=0.0
% INFO    : Bus 70148	: V=1.0026964, theta=-83.398037 -> V=1.0, theta=0.0
% INFO    : Bus 70149	: V=1.0027585, theta=-83.391679 -> V=1.0, theta=0.0
% INFO    : Bus 70150	: V=1.0010308, theta=-83.822487 -> V=1.0, theta=0.0
% INFO    : Bus 70151	: V=1.000787, theta=-83.851471 -> V=1.0, theta=0.0
% INFO    : Bus 70152	: V=1.002021, theta=-83.686442 -> V=1.0, theta=0.0
% INFO    : Bus 70153	: V=1.0019499, theta=-83.463015 -> V=1.0, theta=0.0
% INFO    : Bus 70154	: V=1.0015136, theta=-83.50643 -> V=1.0, theta=0.0
% INFO    : Bus 70155	: V=1.0015962, theta=-83.444319 -> V=1.0, theta=0.0
% INFO    : Bus 70156	: V=1.0015684, theta=-83.382564 -> V=1.0, theta=0.0
% INFO    : Bus 70157	: V=1.0096797, theta=-82.533661 -> V=1.0, theta=0.0
% INFO    : Bus 70158	: V=1.0007281, theta=-83.484818 -> V=1.0, theta=0.0
% INFO    : Bus 70159	: V=0.9999975, theta=-83.483505 -> V=1.0, theta=0.0
% INFO    : Bus 70160	: V=1.0011207, theta=-83.547336 -> V=1.0, theta=0.0
% INFO    : Bus 70161	: V=1.000763, theta=-83.521095 -> V=1.0, theta=0.0
% INFO    : Bus 70162	: V=1.0004059, theta=-83.521272 -> V=1.0, theta=0.0
% INFO    : Bus 70163	: V=0.999739, theta=-83.471655 -> V=1.0, theta=0.0
% INFO    : Bus 70164	: V=1.0051893, theta=-82.968182 -> V=1.0, theta=0.0
% INFO    : Bus 70165	: V=1.0057287, theta=-82.843829 -> V=1.0, theta=0.0
% INFO    : Bus 70166	: V=1.0100003, theta=-82.465005 -> V=1.0, theta=0.0
% INFO    : Bus 70167	: V=1.0100003, theta=-82.371127 -> V=1.0, theta=0.0
% INFO    : Bus 70168	: V=1.0100003, theta=-82.307279 -> V=1.0, theta=0.0
% INFO    : Bus 70169	: V=1.0057589, theta=-82.802502 -> V=1.0, theta=0.0
% INFO    : Bus 70170	: V=1.0058487, theta=-82.757473 -> V=1.0, theta=0.0
% INFO    : Bus 70171	: V=1.005343, theta=-82.892962 -> V=1.0, theta=0.0
% INFO    : Bus 70172	: V=1.0038008, theta=-83.093076 -> V=1.0, theta=0.0
% INFO    : Bus 70173	: V=1.0033845, theta=-83.37467 -> V=1.0, theta=0.0
% INFO    : Bus 70174	: V=1.0023229, theta=-83.394703 -> V=1.0, theta=0.0
% INFO    : Bus 70175	: V=1.0028793, theta=-83.283089 -> V=1.0, theta=0.0
% INFO    : Bus 70176	: V=1.0033418, theta=-83.290976 -> V=1.0, theta=0.0
% INFO    : Bus 70177	: V=1.0037389, theta=-83.299243 -> V=1.0, theta=0.0
% INFO    : Bus 70178	: V=1.0036571, theta=-83.28629 -> V=1.0, theta=0.0
% INFO    : Bus 70179	: V=1.006234, theta=-82.668883 -> V=1.0, theta=0.0
% INFO    : Bus 70180	: V=1.0069188, theta=-82.470909 -> V=1.0, theta=0.0
% INFO    : Bus 70181	: V=1.0025425, theta=-83.270508 -> V=1.0, theta=0.0
% INFO    : Bus 70182	: V=1.0025371, theta=-83.191202 -> V=1.0, theta=0.0
% INFO    : Bus 70183	: V=1.0033692, theta=-82.785197 -> V=1.0, theta=0.0
% INFO    : Bus 70184	: V=1.0022814, theta=-83.068594 -> V=1.0, theta=0.0
% INFO    : Bus 70185	: V=1.0010835, theta=-84.328704 -> V=1.0, theta=0.0
% INFO    : Bus 70186	: V=1.0100003, theta=-82.995496 -> V=1.0, theta=0.0
% INFO    : Bus 70187	: V=1.0100003, theta=-83.109421 -> V=1.0, theta=0.0
% INFO    : Bus 70188	: V=0.999844, theta=-84.552259 -> V=1.0, theta=0.0
% INFO    : Bus 70189	: V=1.0043523, theta=-83.62805 -> V=1.0, theta=0.0
% INFO    : Bus 70190	: V=1.0087161, theta=-83.253725 -> V=1.0, theta=0.0
% INFO    : Bus 70191	: V=0.9960368, theta=-84.062567 -> V=1.0, theta=0.0
% INFO    : Bus 70192	: V=0.9920791, theta=-84.11517 -> V=1.0, theta=0.0
% INFO    : Bus 70193	: V=1.0040283, theta=-83.61238 -> V=1.0, theta=0.0
% INFO    : Bus 70194	: V=1.0038775, theta=-83.645956 -> V=1.0, theta=0.0
% INFO    : Bus 70195	: V=1.009046, theta=-83.201563 -> V=1.0, theta=0.0
% INFO    : Bus 70196	: V=0.995932, theta=-83.985413 -> V=1.0, theta=0.0
% INFO    : Bus 70197	: V=1.0035537, theta=-83.651453 -> V=1.0, theta=0.0
% INFO    : Bus 70198	: V=1.0036635, theta=-83.639677 -> V=1.0, theta=0.0
% INFO    : Bus 70199	: V=0.9886862, theta=-84.107462 -> V=1.0, theta=0.0
% INFO    : Bus 70200	: V=0.9849648, theta=-84.199145 -> V=1.0, theta=0.0
% INFO    : Bus 70201	: V=0.9912633, theta=-84.08213 -> V=1.0, theta=0.0
% INFO    : Bus 70202	: V=0.9914946, theta=-83.92054 -> V=1.0, theta=0.0
% INFO    : Bus 70203	: V=0.9960333, theta=-83.694163 -> V=1.0, theta=0.0
% INFO    : Bus 70204	: V=0.988458, theta=-69.28545 -> V=1.0, theta=0.0
% INFO    : Bus 70205	: V=0.9842486, theta=-71.808472 -> V=1.0, theta=0.0
% INFO    : Bus 70206	: V=0.9830487, theta=-72.93094 -> V=1.0, theta=0.0
% INFO    : Bus 70207	: V=0.9844776, theta=-77.231033 -> V=1.0, theta=0.0
% INFO    : Bus 70208	: V=0.9883221, theta=-77.156007 -> V=1.0, theta=0.0
% INFO    : Bus 70209	: V=0.9896007, theta=-76.881002 -> V=1.0, theta=0.0
% INFO    : Bus 70210	: V=0.9892361, theta=-76.866413 -> V=1.0, theta=0.0
% INFO    : Bus 70211	: V=0.9880033, theta=-77.044332 -> V=1.0, theta=0.0
% INFO    : Bus 70212	: V=0.9882351, theta=-77.03474 -> V=1.0, theta=0.0
% INFO    : Bus 70213	: V=0.9884209, theta=-76.998884 -> V=1.0, theta=0.0
% INFO    : Bus 70214	: V=0.9880373, theta=-77.016734 -> V=1.0, theta=0.0
% INFO    : Bus 70215	: V=0.9899598, theta=-76.951517 -> V=1.0, theta=0.0
% INFO    : Bus 70216	: V=0.9878345, theta=-77.067108 -> V=1.0, theta=0.0
% INFO    : Bus 70217	: V=0.9901104, theta=-76.966239 -> V=1.0, theta=0.0
% INFO    : Bus 70218	: V=0.9896901, theta=-76.982047 -> V=1.0, theta=0.0
% INFO    : Bus 70219	: V=0.9888395, theta=-77.03375 -> V=1.0, theta=0.0
% INFO    : Bus 70220	: V=0.9883087, theta=-77.055663 -> V=1.0, theta=0.0
% INFO    : Bus 70221	: V=0.9903056, theta=-76.890818 -> V=1.0, theta=0.0
% INFO    : Bus 70222	: V=0.9899241, theta=-76.926494 -> V=1.0, theta=0.0
% INFO    : Bus 70223	: V=0.9881143, theta=-77.006672 -> V=1.0, theta=0.0
% INFO    : Bus 70224	: V=0.9876528, theta=-77.050511 -> V=1.0, theta=0.0
% INFO    : Bus 70225	: V=0.9909309, theta=-76.91565 -> V=1.0, theta=0.0
% INFO    : Bus 70226	: V=0.9905615, theta=-76.850699 -> V=1.0, theta=0.0
% INFO    : Bus 70227	: V=0.9904982, theta=-76.878113 -> V=1.0, theta=0.0
% INFO    : Bus 70228	: V=0.9922104, theta=-74.638083 -> V=1.0, theta=0.0
% INFO    : Bus 70229	: V=0.9971009, theta=-75.083624 -> V=1.0, theta=0.0
% INFO    : Bus 70230	: V=0.9932718, theta=-76.78453 -> V=1.0, theta=0.0
% INFO    : Bus 70231	: V=0.9922194, theta=-76.918427 -> V=1.0, theta=0.0
% INFO    : Bus 70232	: V=0.9877565, theta=-77.056024 -> V=1.0, theta=0.0
% INFO    : Bus 70233	: V=0.9897796, theta=-76.959296 -> V=1.0, theta=0.0
% INFO    : Bus 70234	: V=0.9888896, theta=-76.997385 -> V=1.0, theta=0.0
% INFO    : Bus 70235	: V=0.9904718, theta=-76.987069 -> V=1.0, theta=0.0
% INFO    : Bus 70236	: V=0.9880723, theta=-77.043832 -> V=1.0, theta=0.0
% INFO    : Bus 70237	: V=0.9925764, theta=-76.478674 -> V=1.0, theta=0.0
% INFO    : Bus 70238	: V=0.9910844, theta=-76.980779 -> V=1.0, theta=0.0
% INFO    : Bus 70239	: V=0.9951869, theta=-76.495316 -> V=1.0, theta=0.0
% INFO    : Bus 70240	: V=1.0201277, theta=-77.986632 -> V=1.0, theta=0.0
% INFO    : Bus 70241	: V=0.9986624, theta=-78.313099 -> V=1.0, theta=0.0
% INFO    : Bus 70242	: V=0.9970805, theta=-77.653586 -> V=1.0, theta=0.0
% INFO    : Bus 70243	: V=0.9873806, theta=-75.995332 -> V=1.0, theta=0.0
% INFO    : Bus 70244	: V=0.9918141, theta=-76.095263 -> V=1.0, theta=0.0
% INFO    : Bus 70245	: V=0.9872184, theta=-76.322081 -> V=1.0, theta=0.0
% INFO    : Bus 70246	: V=0.9891247, theta=-77.266419 -> V=1.0, theta=0.0
% INFO    : Bus 70247	: V=0.9902628, theta=-77.015353 -> V=1.0, theta=0.0
% INFO    : Bus 70248	: V=0.9872697, theta=-78.106614 -> V=1.0, theta=0.0
% INFO    : Bus 70249	: V=0.9892793, theta=-77.074939 -> V=1.0, theta=0.0
% INFO    : Bus 70250	: V=0.9890101, theta=-77.068748 -> V=1.0, theta=0.0
% INFO    : Bus 70251	: V=0.9887278, theta=-76.006248 -> V=1.0, theta=0.0
% INFO    : Bus 70252	: V=0.9896799, theta=-76.375641 -> V=1.0, theta=0.0
% INFO    : Bus 70253	: V=0.9902335, theta=-76.408299 -> V=1.0, theta=0.0
% INFO    : Bus 70254	: V=0.9906012, theta=-77.004135 -> V=1.0, theta=0.0
% INFO    : Bus 70255	: V=0.9902892, theta=-77.035019 -> V=1.0, theta=0.0
% INFO    : Bus 70256	: V=0.9891365, theta=-76.716184 -> V=1.0, theta=0.0
% INFO    : Bus 70257	: V=0.9882691, theta=-77.460227 -> V=1.0, theta=0.0
% INFO    : Bus 70258	: V=0.9885056, theta=-77.386129 -> V=1.0, theta=0.0
% INFO    : Bus 70259	: V=0.9874646, theta=-77.770746 -> V=1.0, theta=0.0
% INFO    : Bus 70260	: V=0.9879724, theta=-77.586215 -> V=1.0, theta=0.0
% INFO    : Bus 70261	: V=0.9876465, theta=-77.598569 -> V=1.0, theta=0.0
% INFO    : Bus 70262	: V=0.98728, theta=-77.682863 -> V=1.0, theta=0.0
% INFO    : Bus 70263	: V=0.9868575, theta=-77.76071 -> V=1.0, theta=0.0
% INFO    : Bus 70264	: V=0.985134, theta=-77.698975 -> V=1.0, theta=0.0
% INFO    : Bus 70265	: V=0.985664, theta=-77.673529 -> V=1.0, theta=0.0
% INFO    : Bus 70266	: V=0.9863215, theta=-77.673493 -> V=1.0, theta=0.0
% INFO    : Bus 70267	: V=0.986204, theta=-77.601886 -> V=1.0, theta=0.0
% INFO    : Bus 70268	: V=0.9860288, theta=-77.609162 -> V=1.0, theta=0.0
% INFO    : Bus 70269	: V=0.9876977, theta=-77.179792 -> V=1.0, theta=0.0
% INFO    : Bus 70270	: V=0.9883598, theta=-76.871456 -> V=1.0, theta=0.0
% INFO    : Bus 70271	: V=0.9864117, theta=-77.911082 -> V=1.0, theta=0.0
% INFO    : Bus 70272	: V=0.985303, theta=-77.682792 -> V=1.0, theta=0.0
% INFO    : Bus 70273	: V=0.9875184, theta=-77.508902 -> V=1.0, theta=0.0
% INFO    : Bus 70274	: V=0.9856492, theta=-77.666179 -> V=1.0, theta=0.0
% INFO    : Bus 70275	: V=0.9874637, theta=-77.390642 -> V=1.0, theta=0.0
% INFO    : Bus 70276	: V=0.9870768, theta=-77.406687 -> V=1.0, theta=0.0
% INFO    : Bus 70277	: V=0.9862967, theta=-77.638441 -> V=1.0, theta=0.0
% INFO    : Bus 70278	: V=0.9858435, theta=-77.658055 -> V=1.0, theta=0.0
% INFO    : Bus 70279	: V=0.9882958, theta=-77.145563 -> V=1.0, theta=0.0
% INFO    : Bus 70280	: V=0.9962435, theta=-79.906677 -> V=1.0, theta=0.0
% INFO    : Bus 70281	: V=1.0004489, theta=-81.061292 -> V=1.0, theta=0.0
% INFO    : Bus 70282	: V=0.9990445, theta=-80.836731 -> V=1.0, theta=0.0
% INFO    : Bus 70283	: V=0.9989179, theta=-81.462322 -> V=1.0, theta=0.0
% INFO    : Bus 70284	: V=0.997828, theta=-80.570632 -> V=1.0, theta=0.0
% INFO    : Bus 70285	: V=0.9955567, theta=-79.942661 -> V=1.0, theta=0.0
% INFO    : Bus 70286	: V=0.9856182, theta=-77.670939 -> V=1.0, theta=0.0
% INFO    : Bus 70287	: V=0.9952681, theta=-79.823891 -> V=1.0, theta=0.0
% INFO    : Bus 70288	: V=0.9930497, theta=-76.147242 -> V=1.0, theta=0.0
% INFO    : Bus 70289	: V=1.0019205, theta=-79.343582 -> V=1.0, theta=0.0
% INFO    : Bus 70290	: V=0.9996051, theta=-78.266586 -> V=1.0, theta=0.0
% INFO    : Bus 70291	: V=1.0012077, theta=-81.584452 -> V=1.0, theta=0.0
% INFO    : Bus 70292	: V=1.000069, theta=-81.451941 -> V=1.0, theta=0.0
% INFO    : Bus 70293	: V=1.0009275, theta=-81.447602 -> V=1.0, theta=0.0
% INFO    : Bus 70294	: V=1.002406, theta=-81.500301 -> V=1.0, theta=0.0
% INFO    : Bus 70295	: V=1.0021786, theta=-81.514313 -> V=1.0, theta=0.0
% INFO    : Bus 70296	: V=1.0012462, theta=-81.234302 -> V=1.0, theta=0.0
% INFO    : Bus 70297	: V=1.0005515, theta=-81.543106 -> V=1.0, theta=0.0
% INFO    : Bus 70298	: V=1.0038614, theta=-80.030557 -> V=1.0, theta=0.0
% INFO    : Bus 70299	: V=1.0005962, theta=-81.434771 -> V=1.0, theta=0.0
% INFO    : Bus 70300	: V=0.9999435, theta=-81.504053 -> V=1.0, theta=0.0
% INFO    : Bus 70301	: V=1.0006417, theta=-81.635709 -> V=1.0, theta=0.0
% INFO    : Bus 70302	: V=1.0020249, theta=-81.761955 -> V=1.0, theta=0.0
% INFO    : Bus 70303	: V=1.0023257, theta=-81.157225 -> V=1.0, theta=0.0
% INFO    : Bus 70304	: V=1.004435, theta=-80.252332 -> V=1.0, theta=0.0
% INFO    : Bus 70305	: V=1.0011709, theta=-81.217958 -> V=1.0, theta=0.0
% INFO    : Bus 70306	: V=1.0002187, theta=-81.582565 -> V=1.0, theta=0.0
% INFO    : Bus 70307	: V=1.0000893, theta=-81.575337 -> V=1.0, theta=0.0
% INFO    : Bus 70308	: V=1.0001182, theta=-81.411821 -> V=1.0, theta=0.0
% INFO    : Bus 70309	: V=1.0004838, theta=-81.295308 -> V=1.0, theta=0.0
% INFO    : Bus 70310	: V=1.0007547, theta=-81.230588 -> V=1.0, theta=0.0
% INFO    : Bus 70311	: V=1.0052881, theta=-80.515281 -> V=1.0, theta=0.0
% INFO    : Bus 70312	: V=1.0001228, theta=-81.31186 -> V=1.0, theta=0.0
% INFO    : Bus 70313	: V=1.0012854, theta=-81.88 -> V=1.0, theta=0.0
% INFO    : Bus 70314	: V=0.999126, theta=-81.921041 -> V=1.0, theta=0.0
% INFO    : Bus 70315	: V=1.0014954, theta=-81.555631 -> V=1.0, theta=0.0
% INFO    : Bus 70316	: V=1.0019659, theta=-81.556643 -> V=1.0, theta=0.0
% INFO    : Bus 70317	: V=1.0207276, theta=-79.288401 -> V=1.0, theta=0.0
% INFO    : Bus 70318	: V=1.0192786, theta=-79.689145 -> V=1.0, theta=0.0
% INFO    : Bus 70319	: V=1.0040576, theta=-81.967694 -> V=1.0, theta=0.0
% INFO    : Bus 70320	: V=1.0300003, theta=-79.761978 -> V=1.0, theta=0.0
% INFO    : Bus 70321	: V=1.0102544, theta=-81.374073 -> V=1.0, theta=0.0
% INFO    : Bus 70322	: V=1.0051586, theta=-81.503428 -> V=1.0, theta=0.0
% INFO    : Bus 70323	: V=1.0038947, theta=-81.532222 -> V=1.0, theta=0.0
% INFO    : Bus 70324	: V=1.0034434, theta=-81.532417 -> V=1.0, theta=0.0
% INFO    : Bus 70325	: V=1.002853, theta=-81.520387 -> V=1.0, theta=0.0
% INFO    : Bus 70326	: V=1.0148469, theta=-81.079944 -> V=1.0, theta=0.0
% INFO    : Bus 70327	: V=1.0139121, theta=-81.176466 -> V=1.0, theta=0.0
% INFO    : Bus 70328	: V=1.0098466, theta=-81.266979 -> V=1.0, theta=0.0
% INFO    : Bus 70329	: V=1.0098676, theta=-81.293962 -> V=1.0, theta=0.0
% INFO    : Bus 70330	: V=1.0091005, theta=-81.31365 -> V=1.0, theta=0.0
% INFO    : Bus 70331	: V=1.0077536, theta=-81.386344 -> V=1.0, theta=0.0
% INFO    : Bus 70332	: V=1.000652, theta=-83.445449 -> V=1.0, theta=0.0
% INFO    : Bus 70333	: V=1.0107018, theta=-81.792684 -> V=1.0, theta=0.0
% INFO    : Bus 70334	: V=1.0065159, theta=-82.223335 -> V=1.0, theta=0.0
% INFO    : Bus 70335	: V=1.010182, theta=-81.343559 -> V=1.0, theta=0.0
% INFO    : Bus 70336	: V=1.0063242, theta=-82.101872 -> V=1.0, theta=0.0
% INFO    : Bus 70337	: V=1.0012935, theta=-82.851248 -> V=1.0, theta=0.0
% INFO    : Bus 70338	: V=1.0136222, theta=-81.206836 -> V=1.0, theta=0.0
% INFO    : Bus 70339	: V=1.0130696, theta=-81.283592 -> V=1.0, theta=0.0
% INFO    : Bus 70340	: V=1.0070397, theta=-82.006337 -> V=1.0, theta=0.0
% INFO    : Bus 70341	: V=1.0066028, theta=-82.015956 -> V=1.0, theta=0.0
% INFO    : Bus 70342	: V=1.010515, theta=-81.650642 -> V=1.0, theta=0.0
% INFO    : Bus 70343	: V=1.0064998, theta=-82.064667 -> V=1.0, theta=0.0
% INFO    : Bus 70344	: V=1.0115589, theta=-81.564322 -> V=1.0, theta=0.0
% INFO    : Bus 70345	: V=1.006063, theta=-82.014371 -> V=1.0, theta=0.0
% INFO    : Bus 70346	: V=1.001352, theta=-82.569884 -> V=1.0, theta=0.0
% INFO    : Bus 70347	: V=1.0020781, theta=-82.22755 -> V=1.0, theta=0.0
% INFO    : Bus 70348	: V=1.0004609, theta=-83.951462 -> V=1.0, theta=0.0
% INFO    : Bus 70349	: V=1.0034734, theta=-81.829002 -> V=1.0, theta=0.0
% INFO    : Bus 70350	: V=0.9940558, theta=-78.123681 -> V=1.0, theta=0.0
% INFO    : Bus 70351	: V=1.0012594, theta=-84.318503 -> V=1.0, theta=0.0
% INFO    : Bus 70352	: V=1.0099354, theta=-83.68758 -> V=1.0, theta=0.0
% INFO    : Bus 70353	: V=1.0100003, theta=-77.91004 -> V=1.0, theta=0.0
% INFO    : Bus 70354	: V=0.9845586, theta=-77.238314 -> V=1.0, theta=0.0
% INFO    : Bus 70355	: V=0.9863734, theta=-74.978359 -> V=1.0, theta=0.0
% INFO    : Bus 70356	: V=1.0005338, theta=-80.968879 -> V=1.0, theta=0.0
% INFO    : Bus 70357	: V=1.0036991, theta=-77.104233 -> V=1.0, theta=0.0
% INFO    : Bus 70358	: V=1.0100003, theta=-74.925101 -> V=1.0, theta=0.0
% INFO    : Bus 70359	: V=1.0093365, theta=-84.084368 -> V=1.0, theta=0.0
% INFO    : Bus 70360	: V=1.008934, theta=-83.219865 -> V=1.0, theta=0.0
% INFO    : Bus 70361	: V=1.0047013, theta=-83.612506 -> V=1.0, theta=0.0
% INFO    : Bus 70362	: V=1.0100003, theta=-80.725845 -> V=1.0, theta=0.0
% INFO    : Bus 70363	: V=1.0056462, theta=-78.418137 -> V=1.0, theta=0.0
% INFO    : Bus 70364	: V=0.996505, theta=-80.238957 -> V=1.0, theta=0.0
% INFO    : Bus 70365	: V=1.0009537, theta=-77.71305 -> V=1.0, theta=0.0
% INFO    : Bus 70366	: V=1.0029887, theta=-83.610506 -> V=1.0, theta=0.0
% INFO    : Bus 70367	: V=1.0100621, theta=-83.647803 -> V=1.0, theta=0.0
% INFO    : Bus 70368	: V=1.0089761, theta=-83.003915 -> V=1.0, theta=0.0
% INFO    : Bus 70369	: V=1.0084478, theta=-83.343662 -> V=1.0, theta=0.0
% INFO    : Bus 70370	: V=0.9978674, theta=-84.048388 -> V=1.0, theta=0.0
% INFO    : Bus 70371	: V=1.009538, theta=-83.76948 -> V=1.0, theta=0.0
% INFO    : Bus 70372	: V=0.9838818, theta=-80.361591 -> V=1.0, theta=0.0
% INFO    : Bus 70373	: V=1.0092472, theta=-83.803966 -> V=1.0, theta=0.0
% INFO    : Bus 70374	: V=1.0320012, theta=-78.369566 -> V=1.0, theta=0.0
% INFO    : Bus 70375	: V=1.0117682, theta=-81.439537 -> V=1.0, theta=0.0
% INFO    : Bus 70376	: V=1.0040604, theta=-78.366294 -> V=1.0, theta=0.0
% INFO    : Bus 70377	: V=1.0054716, theta=-77.826841 -> V=1.0, theta=0.0
% INFO    : Bus 70378	: V=0.9873101, theta=-85.591764 -> V=1.0, theta=0.0
% INFO    : Bus 70379	: V=0.9813871, theta=-88.852577 -> V=1.0, theta=0.0
% INFO    : Bus 70380	: V=0.9898663, theta=-87.926353 -> V=1.0, theta=0.0
% INFO    : Bus 70381	: V=0.9789695, theta=-89.815007 -> V=1.0, theta=0.0
% INFO    : Bus 70382	: V=0.9963317, theta=-88.334886 -> V=1.0, theta=0.0
% INFO    : Bus 70383	: V=0.9825198, theta=-93.868165 -> V=1.0, theta=0.0
% INFO    : Bus 70384	: V=0.9942585, theta=-98.997633 -> V=1.0, theta=0.0
% INFO    : Bus 70385	: V=0.9991125, theta=-99.340644 -> V=1.0, theta=0.0
% INFO    : Bus 70386	: V=1.0251891, theta=-101.115588 -> V=1.0, theta=0.0
% INFO    : Bus 70387	: V=0.9969884, theta=-97.346941 -> V=1.0, theta=0.0
% INFO    : Bus 70388	: V=0.9810591, theta=-95.525961 -> V=1.0, theta=0.0
% INFO    : Bus 70389	: V=0.9870883, theta=-94.254273 -> V=1.0, theta=0.0
% INFO    : Bus 70390	: V=0.9805891, theta=-96.688548 -> V=1.0, theta=0.0
% INFO    : Bus 70391	: V=0.9792698, theta=-95.330746 -> V=1.0, theta=0.0
% INFO    : Bus 70392	: V=0.9824341, theta=-93.671028 -> V=1.0, theta=0.0
% INFO    : Bus 70393	: V=0.9867519, theta=-92.861484 -> V=1.0, theta=0.0
% INFO    : Bus 70394	: V=0.9791648, theta=-95.680828 -> V=1.0, theta=0.0
% INFO    : Bus 70395	: V=0.9786092, theta=-95.704027 -> V=1.0, theta=0.0
% INFO    : Bus 70396	: V=0.9786285, theta=-95.70122 -> V=1.0, theta=0.0
% INFO    : Bus 70397	: V=0.982947, theta=-94.324102 -> V=1.0, theta=0.0
% INFO    : Bus 70398	: V=0.9822073, theta=-94.277693 -> V=1.0, theta=0.0
% INFO    : Bus 70399	: V=0.9792909, theta=-95.654332 -> V=1.0, theta=0.0
% INFO    : Bus 70400	: V=0.9803045, theta=-95.252272 -> V=1.0, theta=0.0
% INFO    : Bus 70401	: V=0.9988181, theta=-102.440336 -> V=1.0, theta=0.0
% INFO    : Bus 70402	: V=0.9996092, theta=-102.898044 -> V=1.0, theta=0.0
% INFO    : Bus 70403	: V=0.9971084, theta=-103.048716 -> V=1.0, theta=0.0
% INFO    : Bus 70404	: V=0.9975988, theta=-103.03019 -> V=1.0, theta=0.0
% INFO    : Bus 70405	: V=0.9994585, theta=-102.676438 -> V=1.0, theta=0.0
% INFO    : Bus 70406	: V=0.9980199, theta=-102.792321 -> V=1.0, theta=0.0
% INFO    : Bus 70407	: V=0.9964017, theta=-103.079319 -> V=1.0, theta=0.0
% INFO    : Bus 70408	: V=0.999287, theta=-102.975532 -> V=1.0, theta=0.0
% INFO    : Bus 70409	: V=0.999365, theta=-102.898557 -> V=1.0, theta=0.0
% INFO    : Bus 70410	: V=0.9996857, theta=-103.269528 -> V=1.0, theta=0.0
% INFO    : Bus 70411	: V=1.0006511, theta=-103.350642 -> V=1.0, theta=0.0
% INFO    : Bus 70412	: V=1.0014951, theta=-103.653249 -> V=1.0, theta=0.0
% INFO    : Bus 70413	: V=1.0012085, theta=-105.478184 -> V=1.0, theta=0.0
% INFO    : Bus 70414	: V=1.0049653, theta=-105.477874 -> V=1.0, theta=0.0
% INFO    : Bus 70415	: V=1.0002922, theta=-103.657591 -> V=1.0, theta=0.0
% INFO    : Bus 70416	: V=1.0009387, theta=-104.051594 -> V=1.0, theta=0.0
% INFO    : Bus 70417	: V=1.0015357, theta=-104.344054 -> V=1.0, theta=0.0
% INFO    : Bus 70418	: V=0.9990582, theta=-105.166093 -> V=1.0, theta=0.0
% INFO    : Bus 70419	: V=1.0020433, theta=-104.552429 -> V=1.0, theta=0.0
% INFO    : Bus 70420	: V=1.005492, theta=-105.750205 -> V=1.0, theta=0.0
% INFO    : Bus 70421	: V=1.0041906, theta=-105.799043 -> V=1.0, theta=0.0
% INFO    : Bus 70422	: V=1.0028146, theta=-104.828945 -> V=1.0, theta=0.0
% INFO    : Bus 70423	: V=1.0036943, theta=-105.044337 -> V=1.0, theta=0.0
% INFO    : Bus 70424	: V=1.0056618, theta=-105.975966 -> V=1.0, theta=0.0
% INFO    : Bus 70425	: V=1.01125, theta=-105.006245 -> V=1.0, theta=0.0
% INFO    : Bus 70426	: V=0.998472, theta=-104.242731 -> V=1.0, theta=0.0
% INFO    : Bus 70427	: V=0.998423, theta=-104.891721 -> V=1.0, theta=0.0
% INFO    : Bus 70428	: V=0.9984915, theta=-104.927363 -> V=1.0, theta=0.0
% INFO    : Bus 70429	: V=0.9989406, theta=-104.906767 -> V=1.0, theta=0.0
% INFO    : Bus 70430	: V=0.9982966, theta=-105.095568 -> V=1.0, theta=0.0
% INFO    : Bus 70431	: V=0.9987223, theta=-105.079613 -> V=1.0, theta=0.0
% INFO    : Bus 70432	: V=0.998515, theta=-105.088194 -> V=1.0, theta=0.0
% INFO    : Bus 70433	: V=1.0047525, theta=-106.449928 -> V=1.0, theta=0.0
% INFO    : Bus 70434	: V=1.0049674, theta=-106.191447 -> V=1.0, theta=0.0
% INFO    : Bus 70435	: V=1.0040804, theta=-105.851632 -> V=1.0, theta=0.0
% INFO    : Bus 70436	: V=1.0054617, theta=-106.420944 -> V=1.0, theta=0.0
% INFO    : Bus 70437	: V=1.0035137, theta=-105.551671 -> V=1.0, theta=0.0
% INFO    : Bus 70438	: V=1.0036122, theta=-105.495671 -> V=1.0, theta=0.0
% INFO    : Bus 70439	: V=1.0056334, theta=-105.972766 -> V=1.0, theta=0.0
% INFO    : Bus 70440	: V=1.0057555, theta=-107.802463 -> V=1.0, theta=0.0
% INFO    : Bus 70441	: V=1.0058653, theta=-107.342116 -> V=1.0, theta=0.0
% INFO    : Bus 70442	: V=1.0058092, theta=-107.946758 -> V=1.0, theta=0.0
% INFO    : Bus 70443	: V=1.006949, theta=-107.490601 -> V=1.0, theta=0.0
% INFO    : Bus 70444	: V=1.0076398, theta=-107.092433 -> V=1.0, theta=0.0
% INFO    : Bus 70445	: V=1.0071946, theta=-107.341037 -> V=1.0, theta=0.0
% INFO    : Bus 70446	: V=1.0069079, theta=-107.164156 -> V=1.0, theta=0.0
% INFO    : Bus 70447	: V=1.006652, theta=-107.830014 -> V=1.0, theta=0.0
% INFO    : Bus 70448	: V=1.0068084, theta=-107.123525 -> V=1.0, theta=0.0
% INFO    : Bus 70449	: V=1.0068037, theta=-107.716562 -> V=1.0, theta=0.0
% INFO    : Bus 70450	: V=1.0061051, theta=-108.913083 -> V=1.0, theta=0.0
% INFO    : Bus 70451	: V=1.0061346, theta=-108.38525 -> V=1.0, theta=0.0
% INFO    : Bus 70452	: V=1.0043968, theta=-107.272019 -> V=1.0, theta=0.0
% INFO    : Bus 70453	: V=1.0023106, theta=-107.361037 -> V=1.0, theta=0.0
% INFO    : Bus 70454	: V=0.9904513, theta=-98.576392 -> V=1.0, theta=0.0
% INFO    : Bus 70455	: V=0.9943083, theta=-98.380344 -> V=1.0, theta=0.0
% INFO    : Bus 70456	: V=0.9906754, theta=-95.810566 -> V=1.0, theta=0.0
% INFO    : Bus 70457	: V=0.9968875, theta=-93.114529 -> V=1.0, theta=0.0
% INFO    : Bus 70458	: V=0.9950355, theta=-94.480884 -> V=1.0, theta=0.0
% INFO    : Bus 70459	: V=1.000441, theta=-89.523959 -> V=1.0, theta=0.0
% INFO    : Bus 70460	: V=1.0039767, theta=-89.654402 -> V=1.0, theta=0.0
% INFO    : Bus 70461	: V=0.9800805, theta=-90.315012 -> V=1.0, theta=0.0
% INFO    : Bus 70462	: V=1.0066349, theta=-80.667004 -> V=1.0, theta=0.0
% INFO    : Bus 70463	: V=1.0017633, theta=-79.724079 -> V=1.0, theta=0.0
% INFO    : Bus 70464	: V=0.9971359, theta=-83.761976 -> V=1.0, theta=0.0
% INFO    : Bus 70465	: V=0.9964034, theta=-84.496008 -> V=1.0, theta=0.0
% INFO    : Bus 70466	: V=0.9965202, theta=-84.544052 -> V=1.0, theta=0.0
% INFO    : Bus 70467	: V=1.0084289, theta=-83.449975 -> V=1.0, theta=0.0
% INFO    : Bus 70468	: V=1.0049319, theta=-84.076365 -> V=1.0, theta=0.0
% INFO    : Bus 70469	: V=1.0008496, theta=-86.789088 -> V=1.0, theta=0.0
% INFO    : Bus 70470	: V=1.0050248, theta=-86.074146 -> V=1.0, theta=0.0
% INFO    : Bus 70471	: V=0.9969932, theta=-87.458782 -> V=1.0, theta=0.0
% INFO    : Bus 70472	: V=0.9867621, theta=-84.811061 -> V=1.0, theta=0.0
% INFO    : Bus 70473	: V=0.99378, theta=-84.460904 -> V=1.0, theta=0.0
% INFO    : Bus 70474	: V=0.9717812, theta=-91.204303 -> V=1.0, theta=0.0
% INFO    : Bus 70475	: V=0.9802502, theta=-90.585724 -> V=1.0, theta=0.0
% INFO    : Bus 70476	: V=0.9894548, theta=-90.211821 -> V=1.0, theta=0.0
% INFO    : Bus 70477	: V=0.9956577, theta=-88.899844 -> V=1.0, theta=0.0
% INFO    : Bus 70478	: V=0.996694, theta=-88.856876 -> V=1.0, theta=0.0
% INFO    : Bus 70479	: V=0.9953492, theta=-89.256717 -> V=1.0, theta=0.0
% INFO    : Bus 70480	: V=0.9939032, theta=-89.059915 -> V=1.0, theta=0.0
% INFO    : Bus 70481	: V=0.9926009, theta=-88.28493 -> V=1.0, theta=0.0
% INFO    : Bus 70482	: V=0.9983488, theta=-104.477031 -> V=1.0, theta=0.0
% INFO    : Bus 70483	: V=1.0033051, theta=-105.381456 -> V=1.0, theta=0.0
% INFO    : Bus 70484	: V=1.0038481, theta=-104.890347 -> V=1.0, theta=0.0
% INFO    : Bus 70485	: V=1.0014106, theta=-104.217807 -> V=1.0, theta=0.0
% INFO    : Bus 70486	: V=0.9999355, theta=-105.433423 -> V=1.0, theta=0.0
% INFO    : Bus 70487	: V=1.0018716, theta=-104.445612 -> V=1.0, theta=0.0
% INFO    : Bus 70488	: V=1.0044183, theta=-106.594473 -> V=1.0, theta=0.0
% INFO    : Bus 70489	: V=1.0048598, theta=-106.70001 -> V=1.0, theta=0.0
% INFO    : Bus 70490	: V=1.0066941, theta=-102.185784 -> V=1.0, theta=0.0
% INFO    : Bus 70491	: V=1.0026883, theta=-103.472342 -> V=1.0, theta=0.0
% INFO    : Bus 70492	: V=1.0008044, theta=-103.821862 -> V=1.0, theta=0.0
% INFO    : Bus 70493	: V=1.0006942, theta=-103.643104 -> V=1.0, theta=0.0
% INFO    : Bus 70494	: V=1.0006328, theta=-103.594289 -> V=1.0, theta=0.0
% INFO    : Bus 70495	: V=1.0017378, theta=-103.546563 -> V=1.0, theta=0.0
% INFO    : Bus 70496	: V=1.0007176, theta=-103.476248 -> V=1.0, theta=0.0
% INFO    : Bus 70497	: V=1.0004733, theta=-103.255438 -> V=1.0, theta=0.0
% INFO    : Bus 70498	: V=0.999646, theta=-103.631352 -> V=1.0, theta=0.0
% INFO    : Bus 70499	: V=1.0004226, theta=-103.600315 -> V=1.0, theta=0.0
% INFO    : Bus 70500	: V=0.9939524, theta=-104.109767 -> V=1.0, theta=0.0
% INFO    : Bus 70501	: V=0.9988644, theta=-103.645315 -> V=1.0, theta=0.0
% INFO    : Bus 70502	: V=0.9964965, theta=-103.705633 -> V=1.0, theta=0.0
% INFO    : Bus 70503	: V=0.9983259, theta=-103.445949 -> V=1.0, theta=0.0
% INFO    : Bus 70504	: V=1.0020799, theta=-102.433737 -> V=1.0, theta=0.0
% INFO    : Bus 70505	: V=0.998003, theta=-103.566774 -> V=1.0, theta=0.0
% INFO    : Bus 70506	: V=0.9978955, theta=-103.026872 -> V=1.0, theta=0.0
% INFO    : Bus 70507	: V=0.9973519, theta=-103.407882 -> V=1.0, theta=0.0
% INFO    : Bus 70508	: V=0.9982358, theta=-103.573061 -> V=1.0, theta=0.0
% INFO    : Bus 70509	: V=0.9971995, theta=-103.773536 -> V=1.0, theta=0.0
% INFO    : Bus 70510	: V=0.9964149, theta=-103.810829 -> V=1.0, theta=0.0
% INFO    : Bus 70511	: V=0.9969823, theta=-103.424829 -> V=1.0, theta=0.0
% INFO    : Bus 70512	: V=1.0013999, theta=-102.384269 -> V=1.0, theta=0.0
% INFO    : Bus 70513	: V=0.9984946, theta=-103.557228 -> V=1.0, theta=0.0
% INFO    : Bus 70514	: V=0.9987033, theta=-103.538496 -> V=1.0, theta=0.0
% INFO    : Bus 70515	: V=0.9964281, theta=-103.844766 -> V=1.0, theta=0.0
% INFO    : Bus 70516	: V=0.9956601, theta=-103.88128 -> V=1.0, theta=0.0
% INFO    : Bus 70517	: V=0.9951782, theta=-103.888719 -> V=1.0, theta=0.0
% INFO    : Bus 70518	: V=0.9963282, theta=-102.468523 -> V=1.0, theta=0.0
% INFO    : Bus 70519	: V=0.9932645, theta=-100.84039 -> V=1.0, theta=0.0
% INFO    : Bus 70520	: V=0.9894038, theta=-98.588181 -> V=1.0, theta=0.0
% INFO    : Bus 70521	: V=1.0055941, theta=-104.440377 -> V=1.0, theta=0.0
% INFO    : Bus 70522	: V=1.0023407, theta=-105.519797 -> V=1.0, theta=0.0
% INFO    : Bus 70523	: V=1.003978, theta=-105.218343 -> V=1.0, theta=0.0
% INFO    : Bus 70524	: V=1.0058439, theta=-103.768953 -> V=1.0, theta=0.0
% INFO    : Bus 70525	: V=1.0019926, theta=-105.343078 -> V=1.0, theta=0.0
% INFO    : Bus 70526	: V=1.006327, theta=-103.152176 -> V=1.0, theta=0.0
% INFO    : Bus 70527	: V=0.9867198, theta=-99.810897 -> V=1.0, theta=0.0
% INFO    : Bus 70528	: V=1.0018081, theta=-99.017595 -> V=1.0, theta=0.0
% INFO    : Bus 70529	: V=1.0092016, theta=-101.853585 -> V=1.0, theta=0.0
% INFO    : Bus 70530	: V=1.0073003, theta=-102.166982 -> V=1.0, theta=0.0
% INFO    : Bus 70531	: V=0.9731008, theta=-60.374872 -> V=1.0, theta=0.0
% INFO    : Bus 70532	: V=1.006058, theta=-66.048212 -> V=1.0, theta=0.0
% INFO    : Bus 70533	: V=0.9819697, theta=-62.709257 -> V=1.0, theta=0.0
% INFO    : Bus 70534	: V=0.9763365, theta=-62.245333 -> V=1.0, theta=0.0
% INFO    : Bus 70535	: V=1.0003172, theta=-77.533537 -> V=1.0, theta=0.0
% INFO    : Bus 70536	: V=0.9973419, theta=-80.447374 -> V=1.0, theta=0.0
% INFO    : Bus 70537	: V=1.0201669, theta=-77.881473 -> V=1.0, theta=0.0
% INFO    : Bus 70538	: V=1.0104011, theta=-100.377145 -> V=1.0, theta=0.0
% INFO    : Bus 70539	: V=1.0116186, theta=-99.885444 -> V=1.0, theta=0.0
% INFO    : Bus 70540	: V=1.0120031, theta=-100.062865 -> V=1.0, theta=0.0
% INFO    : Bus 70541	: V=1.0109557, theta=-99.865731 -> V=1.0, theta=0.0
% INFO    : Bus 70542	: V=1.0126266, theta=-99.799693 -> V=1.0, theta=0.0
% INFO    : Bus 70543	: V=1.012804, theta=-99.58903 -> V=1.0, theta=0.0
% INFO    : Bus 70544	: V=1.0297475, theta=-97.246339 -> V=1.0, theta=0.0
% INFO    : Bus 70545	: V=1.0300004, theta=-96.976151 -> V=1.0, theta=0.0
% INFO    : Bus 70546	: V=1.0299295, theta=-97.079693 -> V=1.0, theta=0.0
% INFO    : Bus 70547	: V=1.013173, theta=-99.42979 -> V=1.0, theta=0.0
% INFO    : Bus 70548	: V=1.0121677, theta=-99.552357 -> V=1.0, theta=0.0
% INFO    : Bus 70549	: V=1.0124685, theta=-99.514076 -> V=1.0, theta=0.0
% INFO    : Bus 70550	: V=1.0127764, theta=-99.430468 -> V=1.0, theta=0.0
% INFO    : Bus 70551	: V=1.0297248, theta=-96.870022 -> V=1.0, theta=0.0
% INFO    : Bus 70552	: V=1.0117165, theta=-99.457108 -> V=1.0, theta=0.0
% INFO    : Bus 70553	: V=1.012161, theta=-99.519499 -> V=1.0, theta=0.0
% INFO    : Bus 70554	: V=1.011836, theta=-99.519074 -> V=1.0, theta=0.0
% INFO    : Bus 70555	: V=1.0113027, theta=-99.485376 -> V=1.0, theta=0.0
% INFO    : Bus 70556	: V=1.0116122, theta=-99.531873 -> V=1.0, theta=0.0
% INFO    : Bus 70557	: V=1.0119561, theta=-99.567079 -> V=1.0, theta=0.0
% INFO    : Bus 70558	: V=1.0124365, theta=-99.588348 -> V=1.0, theta=0.0
% INFO    : Bus 70559	: V=1.0128546, theta=-99.564104 -> V=1.0, theta=0.0
% INFO    : Bus 70560	: V=1.001882, theta=-106.275808 -> V=1.0, theta=0.0
% INFO    : Bus 70561	: V=0.9937311, theta=-105.542241 -> V=1.0, theta=0.0
% INFO    : Bus 70562	: V=0.9953037, theta=-105.475648 -> V=1.0, theta=0.0
% INFO    : Bus 70563	: V=0.9980093, theta=-105.360783 -> V=1.0, theta=0.0
% INFO    : Bus 70564	: V=1.006062, theta=-102.983148 -> V=1.0, theta=0.0
% INFO    : Bus 70565	: V=1.0034809, theta=-103.023151 -> V=1.0, theta=0.0
% INFO    : Bus 70566	: V=0.9946132, theta=-104.032513 -> V=1.0, theta=0.0
% INFO    : Bus 70567	: V=1.0296456, theta=-97.731329 -> V=1.0, theta=0.0
% INFO    : Bus 70568	: V=1.011155, theta=-100.372492 -> V=1.0, theta=0.0
% INFO    : Bus 70569	: V=1.011656, theta=-100.36713 -> V=1.0, theta=0.0
% INFO    : Bus 70570	: V=1.0104318, theta=-99.843252 -> V=1.0, theta=0.0
% INFO    : Bus 70571	: V=1.0109676, theta=-99.729252 -> V=1.0, theta=0.0
% INFO    : Bus 70572	: V=1.0115678, theta=-99.628218 -> V=1.0, theta=0.0
% INFO    : Bus 70573	: V=0.9981376, theta=-100.147405 -> V=1.0, theta=0.0
% INFO    : Bus 70574	: V=1.0121937, theta=-99.574829 -> V=1.0, theta=0.0
% INFO    : Bus 70575	: V=1.0123281, theta=-99.591128 -> V=1.0, theta=0.0
% INFO    : Bus 70576	: V=0.9950358, theta=-101.639716 -> V=1.0, theta=0.0
% INFO    : Bus 70577	: V=0.9945493, theta=-100.752558 -> V=1.0, theta=0.0
% INFO    : Bus 70578	: V=0.9940682, theta=-98.007716 -> V=1.0, theta=0.0
% INFO    : Bus 70579	: V=0.9948777, theta=-95.982622 -> V=1.0, theta=0.0
% INFO    : Bus 70580	: V=0.9823601, theta=-99.727807 -> V=1.0, theta=0.0
% INFO    : Bus 70581	: V=0.9851876, theta=-97.427963 -> V=1.0, theta=0.0
% INFO    : Bus 70582	: V=0.9944176, theta=-94.019883 -> V=1.0, theta=0.0
% INFO    : Bus 70583	: V=0.99757, theta=-90.767862 -> V=1.0, theta=0.0
% INFO    : Bus 70584	: V=0.9885188, theta=-91.502473 -> V=1.0, theta=0.0
% INFO    : Bus 70585	: V=0.9970523, theta=-91.112232 -> V=1.0, theta=0.0
% INFO    : Bus 70586	: V=1.0184475, theta=-88.675939 -> V=1.0, theta=0.0
% INFO    : Bus 70587	: V=1.0028281, theta=-89.711729 -> V=1.0, theta=0.0
% INFO    : Bus 70588	: V=0.9957848, theta=-89.084902 -> V=1.0, theta=0.0
% INFO    : Bus 70589	: V=1.0056719, theta=-84.928382 -> V=1.0, theta=0.0
% INFO    : Bus 70590	: V=0.9759655, theta=-100.000585 -> V=1.0, theta=0.0
% INFO    : Bus 70591	: V=1.0042791, theta=-107.0267 -> V=1.0, theta=0.0
% INFO    : Bus 70592	: V=1.0018973, theta=-107.119103 -> V=1.0, theta=0.0
% INFO    : Bus 70593	: V=1.0089215, theta=-107.155684 -> V=1.0, theta=0.0
% INFO    : Bus 70594	: V=1.0092916, theta=-107.141882 -> V=1.0, theta=0.0
% INFO    : Bus 70595	: V=1.0091466, theta=-107.147325 -> V=1.0, theta=0.0
% INFO    : Bus 70596	: V=1.0088542, theta=-107.303381 -> V=1.0, theta=0.0
% INFO    : Bus 70597	: V=1.0100053, theta=-107.260468 -> V=1.0, theta=0.0
% INFO    : Bus 70598	: V=1.0102051, theta=-107.267609 -> V=1.0, theta=0.0
% INFO    : Bus 70599	: V=1.0103576, theta=-107.261441 -> V=1.0, theta=0.0
% INFO    : Bus 70600	: V=1.010556, theta=-107.253404 -> V=1.0, theta=0.0
% INFO    : Bus 70601	: V=1.0104252, theta=-107.259294 -> V=1.0, theta=0.0
% INFO    : Bus 70602	: V=1.0102399, theta=-107.266339 -> V=1.0, theta=0.0
% INFO    : Bus 70603	: V=1.0112338, theta=-107.184919 -> V=1.0, theta=0.0
% INFO    : Bus 70604	: V=1.0110696, theta=-107.191603 -> V=1.0, theta=0.0
% INFO    : Bus 70605	: V=1.012692, theta=-106.969474 -> V=1.0, theta=0.0
% INFO    : Bus 70606	: V=1.0117242, theta=-107.029614 -> V=1.0, theta=0.0
% INFO    : Bus 70607	: V=1.0115051, theta=-106.912615 -> V=1.0, theta=0.0
% INFO    : Bus 70608	: V=1.0105285, theta=-106.818631 -> V=1.0, theta=0.0
% INFO    : Bus 70609	: V=1.0059743, theta=-106.872596 -> V=1.0, theta=0.0
% INFO    : Bus 70610	: V=1.0083547, theta=-106.595475 -> V=1.0, theta=0.0
% INFO    : Bus 70611	: V=1.007688, theta=-106.622524 -> V=1.0, theta=0.0
% INFO    : Bus 70612	: V=1.0067337, theta=-106.260783 -> V=1.0, theta=0.0
% INFO    : Bus 70613	: V=1.0067346, theta=-106.259364 -> V=1.0, theta=0.0
% INFO    : Bus 70614	: V=1.0071293, theta=-106.244708 -> V=1.0, theta=0.0
% INFO    : Bus 70615	: V=1.0064629, theta=-106.271796 -> V=1.0, theta=0.0
% INFO    : Bus 70616	: V=1.0063268, theta=-106.277969 -> V=1.0, theta=0.0
% INFO    : Bus 70617	: V=0.999487, theta=-104.339447 -> V=1.0, theta=0.0
% INFO    : Bus 70618	: V=1.0050428, theta=-104.678677 -> V=1.0, theta=0.0
% INFO    : Bus 70619	: V=1.005908, theta=-104.817413 -> V=1.0, theta=0.0
% INFO    : Bus 70620	: V=1.0041939, theta=-104.603026 -> V=1.0, theta=0.0
% INFO    : Bus 70621	: V=0.9978439, theta=-103.278021 -> V=1.0, theta=0.0
% INFO    : Bus 70622	: V=1.0066239, theta=-104.790216 -> V=1.0, theta=0.0
% INFO    : Bus 70623	: V=1.0069806, theta=-104.77444 -> V=1.0, theta=0.0
% INFO    : Bus 70624	: V=1.0044358, theta=-104.952148 -> V=1.0, theta=0.0
% INFO    : Bus 70625	: V=1.0055214, theta=-104.902621 -> V=1.0, theta=0.0
% INFO    : Bus 70626	: V=1.0289785, theta=-96.583345 -> V=1.0, theta=0.0
% INFO    : Bus 70627	: V=0.9997354, theta=-104.830926 -> V=1.0, theta=0.0
% INFO    : Bus 70628	: V=1.0002996, theta=-105.156322 -> V=1.0, theta=0.0
% INFO    : Bus 70629	: V=0.9924046, theta=-96.628723 -> V=1.0, theta=0.0
% INFO    : Bus 70630	: V=1.0125749, theta=-99.428147 -> V=1.0, theta=0.0
% INFO    : Bus 70631	: V=0.9933633, theta=-101.408734 -> V=1.0, theta=0.0
% INFO    : Bus 70632	: V=0.993331, theta=-101.500391 -> V=1.0, theta=0.0
% INFO    : Bus 70633	: V=0.9925709, theta=-102.161261 -> V=1.0, theta=0.0
% INFO    : Bus 70634	: V=0.9933054, theta=-101.616454 -> V=1.0, theta=0.0
% INFO    : Bus 70635	: V=0.9964238, theta=-102.98275 -> V=1.0, theta=0.0
% INFO    : Bus 70636	: V=0.9967967, theta=-103.23602 -> V=1.0, theta=0.0
% INFO    : Bus 70637	: V=0.9957082, theta=-102.840676 -> V=1.0, theta=0.0
% INFO    : Bus 70638	: V=0.9961626, theta=-103.011552 -> V=1.0, theta=0.0
% INFO    : Bus 70639	: V=0.9949498, theta=-102.869045 -> V=1.0, theta=0.0
% INFO    : Bus 70640	: V=0.9957101, theta=-103.032305 -> V=1.0, theta=0.0
% INFO    : Bus 70641	: V=0.9959423, theta=-102.494387 -> V=1.0, theta=0.0
% INFO    : Bus 70642	: V=0.995373, theta=-102.517677 -> V=1.0, theta=0.0
% INFO    : Bus 70643	: V=0.9956709, theta=-102.401923 -> V=1.0, theta=0.0
% INFO    : Bus 70644	: V=0.9957575, theta=-102.623549 -> V=1.0, theta=0.0
% INFO    : Bus 70645	: V=0.9930129, theta=-101.642112 -> V=1.0, theta=0.0
% INFO    : Bus 70646	: V=0.995517, theta=-102.587142 -> V=1.0, theta=0.0
% INFO    : Bus 70647	: V=0.9957865, theta=-102.576963 -> V=1.0, theta=0.0
% INFO    : Bus 70648	: V=0.9952425, theta=-103.365775 -> V=1.0, theta=0.0
% INFO    : Bus 70649	: V=0.9935432, theta=-101.140724 -> V=1.0, theta=0.0
% INFO    : Bus 70650	: V=0.9934186, theta=-101.324987 -> V=1.0, theta=0.0
% INFO    : Bus 70651	: V=0.996824, theta=-103.306188 -> V=1.0, theta=0.0
% INFO    : Bus 70652	: V=0.9959623, theta=-104.426837 -> V=1.0, theta=0.0
% INFO    : Bus 70653	: V=1.0006539, theta=-104.752088 -> V=1.0, theta=0.0
% INFO    : Bus 70654	: V=0.9994163, theta=-103.873991 -> V=1.0, theta=0.0
% INFO    : Bus 70655	: V=1.000303, theta=-104.427943 -> V=1.0, theta=0.0
% INFO    : Bus 70656	: V=1.000655, theta=-104.609891 -> V=1.0, theta=0.0
% INFO    : Bus 70657	: V=0.995475, theta=-102.409438 -> V=1.0, theta=0.0
% INFO    : Bus 70658	: V=0.9940915, theta=-100.878155 -> V=1.0, theta=0.0
% INFO    : Bus 70659	: V=0.9936952, theta=-101.209239 -> V=1.0, theta=0.0
% INFO    : Bus 70660	: V=0.9934737, theta=-100.898181 -> V=1.0, theta=0.0
% INFO    : Bus 70661	: V=0.9958332, theta=-101.92399 -> V=1.0, theta=0.0
% INFO    : Bus 70662	: V=0.9977205, theta=-103.538687 -> V=1.0, theta=0.0
% INFO    : Bus 70663	: V=0.9983096, theta=-102.482584 -> V=1.0, theta=0.0
% INFO    : Bus 70664	: V=0.9940917, theta=-98.808773 -> V=1.0, theta=0.0
% INFO    : Bus 70665	: V=0.9934253, theta=-98.172303 -> V=1.0, theta=0.0
% INFO    : Bus 70666	: V=0.9938671, theta=-98.095948 -> V=1.0, theta=0.0
% INFO    : Bus 70667	: V=0.9922762, theta=-98.327928 -> V=1.0, theta=0.0
% INFO    : Bus 70668	: V=0.9931895, theta=-97.384485 -> V=1.0, theta=0.0
% INFO    : Bus 70669	: V=0.9994453, theta=-94.601355 -> V=1.0, theta=0.0
% INFO    : Bus 70670	: V=1.0020851, theta=-93.952355 -> V=1.0, theta=0.0
% INFO    : Bus 70671	: V=0.9993093, theta=-91.820482 -> V=1.0, theta=0.0
% INFO    : Bus 70672	: V=1.0004565, theta=-91.886686 -> V=1.0, theta=0.0
% INFO    : Bus 70673	: V=1.0030389, theta=-91.535645 -> V=1.0, theta=0.0
% INFO    : Bus 70674	: V=0.9996358, theta=-91.881545 -> V=1.0, theta=0.0
% INFO    : Bus 70675	: V=1.0030294, theta=-92.666646 -> V=1.0, theta=0.0
% INFO    : Bus 70676	: V=1.0044755, theta=-91.475507 -> V=1.0, theta=0.0
% INFO    : Bus 70677	: V=1.0102258, theta=-89.261271 -> V=1.0, theta=0.0
% INFO    : Bus 70678	: V=1.0089418, theta=-90.190134 -> V=1.0, theta=0.0
% INFO    : Bus 70679	: V=1.0001741, theta=-91.720158 -> V=1.0, theta=0.0
% INFO    : Bus 70680	: V=1.0014109, theta=-91.673411 -> V=1.0, theta=0.0
% INFO    : Bus 70681	: V=1.0006145, theta=-91.537109 -> V=1.0, theta=0.0
% INFO    : Bus 70682	: V=1.0092869, theta=-89.115637 -> V=1.0, theta=0.0
% INFO    : Bus 70683	: V=0.9980725, theta=-91.63597 -> V=1.0, theta=0.0
% INFO    : Bus 70684	: V=0.9962231, theta=-89.310231 -> V=1.0, theta=0.0
% INFO    : Bus 70685	: V=0.9982504, theta=-91.81197 -> V=1.0, theta=0.0
% INFO    : Bus 70686	: V=0.9791429, theta=-87.072452 -> V=1.0, theta=0.0
% INFO    : Bus 70687	: V=0.963439, theta=-82.99559 -> V=1.0, theta=0.0
% INFO    : Bus 70688	: V=0.9623071, theta=-83.610403 -> V=1.0, theta=0.0
% INFO    : Bus 70689	: V=0.9613895, theta=-82.426896 -> V=1.0, theta=0.0
% INFO    : Bus 70690	: V=0.9652171, theta=-82.447559 -> V=1.0, theta=0.0
% INFO    : Bus 70691	: V=0.9942432, theta=-78.479417 -> V=1.0, theta=0.0
% INFO    : Bus 70692	: V=0.9939633, theta=-78.360843 -> V=1.0, theta=0.0
% INFO    : Bus 70693	: V=0.9885483, theta=-78.550547 -> V=1.0, theta=0.0
% INFO    : Bus 70694	: V=0.9886705, theta=-78.486458 -> V=1.0, theta=0.0
% INFO    : Bus 70695	: V=0.9891473, theta=-78.419983 -> V=1.0, theta=0.0
% INFO    : Bus 70696	: V=0.9939465, theta=-78.24026 -> V=1.0, theta=0.0
% INFO    : Bus 70697	: V=0.9864747, theta=-78.360722 -> V=1.0, theta=0.0
% INFO    : Bus 70698	: V=0.9870332, theta=-78.352967 -> V=1.0, theta=0.0
% INFO    : Bus 70699	: V=0.9898085, theta=-78.332343 -> V=1.0, theta=0.0
% INFO    : Bus 70700	: V=0.9953334, theta=-78.681997 -> V=1.0, theta=0.0
% INFO    : Bus 70701	: V=0.9920331, theta=-78.069771 -> V=1.0, theta=0.0
% INFO    : Bus 70702	: V=0.995044, theta=-78.650656 -> V=1.0, theta=0.0
% INFO    : Bus 70703	: V=0.9923226, theta=-77.971685 -> V=1.0, theta=0.0
% INFO    : Bus 70704	: V=0.9918118, theta=-77.87071 -> V=1.0, theta=0.0
% INFO    : Bus 70705	: V=0.9979165, theta=-77.002044 -> V=1.0, theta=0.0
% INFO    : Bus 70706	: V=0.9970282, theta=-76.962539 -> V=1.0, theta=0.0
% INFO    : Bus 70707	: V=1.0100003, theta=-76.091443 -> V=1.0, theta=0.0
% INFO    : Bus 70708	: V=1.0090277, theta=-76.156158 -> V=1.0, theta=0.0
% INFO    : Bus 70709	: V=0.9909168, theta=-77.975056 -> V=1.0, theta=0.0
% INFO    : Bus 70710	: V=0.9961985, theta=-76.909086 -> V=1.0, theta=0.0
% INFO    : Bus 70711	: V=0.9857356, theta=-77.680691 -> V=1.0, theta=0.0
% INFO    : Bus 70712	: V=0.9894395, theta=-78.223705 -> V=1.0, theta=0.0
% INFO    : Bus 70713	: V=0.9949757, theta=-76.944738 -> V=1.0, theta=0.0
% INFO    : Bus 70714	: V=0.9899441, theta=-78.381069 -> V=1.0, theta=0.0
% INFO    : Bus 70715	: V=0.9897951, theta=-78.244055 -> V=1.0, theta=0.0
% INFO    : Bus 70716	: V=0.9872359, theta=-77.700879 -> V=1.0, theta=0.0
% INFO    : Bus 70717	: V=0.9865142, theta=-77.671018 -> V=1.0, theta=0.0
% INFO    : Bus 70718	: V=0.9861941, theta=-77.62876 -> V=1.0, theta=0.0
% INFO    : Bus 70719	: V=0.9863337, theta=-77.607199 -> V=1.0, theta=0.0
% INFO    : Bus 70720	: V=0.9860642, theta=-77.576586 -> V=1.0, theta=0.0
% INFO    : Bus 70721	: V=0.9869192, theta=-77.65752 -> V=1.0, theta=0.0
% INFO    : Bus 70722	: V=0.9854042, theta=-77.495583 -> V=1.0, theta=0.0
% INFO    : Bus 70723	: V=0.9854113, theta=-77.473062 -> V=1.0, theta=0.0
% INFO    : Bus 70724	: V=0.9869031, theta=-77.395219 -> V=1.0, theta=0.0
% INFO    : Bus 70725	: V=0.995056, theta=-76.87477 -> V=1.0, theta=0.0
% INFO    : Bus 70726	: V=0.9881347, theta=-77.33194 -> V=1.0, theta=0.0
% INFO    : Bus 70727	: V=0.9885317, theta=-77.321154 -> V=1.0, theta=0.0
% INFO    : Bus 70728	: V=0.9959072, theta=-76.806395 -> V=1.0, theta=0.0
% INFO    : Bus 70729	: V=0.9885473, theta=-77.265359 -> V=1.0, theta=0.0
% INFO    : Bus 70730	: V=0.9877579, theta=-77.272504 -> V=1.0, theta=0.0
% INFO    : Bus 70731	: V=0.9871279, theta=-77.273425 -> V=1.0, theta=0.0
% INFO    : Bus 70732	: V=0.9856369, theta=-77.439498 -> V=1.0, theta=0.0
% INFO    : Bus 70733	: V=1.0100003, theta=-76.235838 -> V=1.0, theta=0.0
% INFO    : Bus 70734	: V=0.9875177, theta=-77.267729 -> V=1.0, theta=0.0
% INFO    : Bus 70735	: V=0.9863807, theta=-77.280213 -> V=1.0, theta=0.0
% INFO    : Bus 70736	: V=0.9868413, theta=-77.241295 -> V=1.0, theta=0.0
% INFO    : Bus 70737	: V=0.9858644, theta=-77.26299 -> V=1.0, theta=0.0
% INFO    : Bus 70738	: V=0.9853227, theta=-77.334901 -> V=1.0, theta=0.0
% INFO    : Bus 70739	: V=0.9853282, theta=-77.413259 -> V=1.0, theta=0.0
% INFO    : Bus 70740	: V=0.9905573, theta=-76.489706 -> V=1.0, theta=0.0
% INFO    : Bus 70741	: V=0.9840487, theta=-77.335059 -> V=1.0, theta=0.0
% INFO    : Bus 70742	: V=0.9852856, theta=-77.403694 -> V=1.0, theta=0.0
% INFO    : Bus 70743	: V=0.9867065, theta=-77.202118 -> V=1.0, theta=0.0
% INFO    : Bus 70744	: V=0.9868166, theta=-77.159859 -> V=1.0, theta=0.0
% INFO    : Bus 70745	: V=0.9853522, theta=-77.431368 -> V=1.0, theta=0.0
% INFO    : Bus 70746	: V=0.985698, theta=-77.41367 -> V=1.0, theta=0.0
% INFO    : Bus 70747	: V=0.9862484, theta=-77.40121 -> V=1.0, theta=0.0
% INFO    : Bus 70748	: V=0.9887771, theta=-76.700092 -> V=1.0, theta=0.0
% INFO    : Bus 70749	: V=0.9909919, theta=-76.201017 -> V=1.0, theta=0.0
% INFO    : Bus 70750	: V=0.9874268, theta=-77.025906 -> V=1.0, theta=0.0
% INFO    : Bus 70751	: V=0.9881326, theta=-76.889711 -> V=1.0, theta=0.0
% INFO    : Bus 70752	: V=0.9896487, theta=-76.443687 -> V=1.0, theta=0.0
% INFO    : Bus 70753	: V=0.9903247, theta=-76.377927 -> V=1.0, theta=0.0
% INFO    : Bus 70754	: V=0.9896054, theta=-77.283155 -> V=1.0, theta=0.0
% INFO    : Bus 70755	: V=0.9913205, theta=-76.41519 -> V=1.0, theta=0.0
% INFO    : Bus 70756	: V=0.9897045, theta=-76.470201 -> V=1.0, theta=0.0
% INFO    : Bus 70757	: V=0.9902788, theta=-76.327287 -> V=1.0, theta=0.0
% INFO    : Bus 70758	: V=0.9886548, theta=-76.835859 -> V=1.0, theta=0.0
% INFO    : Bus 70759	: V=0.9890085, theta=-76.822497 -> V=1.0, theta=0.0
% INFO    : Bus 70760	: V=0.9901905, theta=-76.528686 -> V=1.0, theta=0.0
% INFO    : Bus 70761	: V=0.9908104, theta=-76.373229 -> V=1.0, theta=0.0
% INFO    : Bus 70762	: V=0.9905957, theta=-76.381406 -> V=1.0, theta=0.0
% INFO    : Bus 70763	: V=0.991484, theta=-76.048106 -> V=1.0, theta=0.0
% INFO    : Bus 70764	: V=0.9910192, theta=-74.717863 -> V=1.0, theta=0.0
% INFO    : Bus 70765	: V=0.9920836, theta=-75.776511 -> V=1.0, theta=0.0
% INFO    : Bus 70766	: V=0.991072, theta=-74.577145 -> V=1.0, theta=0.0
% INFO    : Bus 70767	: V=0.9904678, theta=-76.348642 -> V=1.0, theta=0.0
% INFO    : Bus 70768	: V=0.9899106, theta=-76.37164 -> V=1.0, theta=0.0
% INFO    : Bus 70769	: V=0.9904716, theta=-76.316427 -> V=1.0, theta=0.0
% INFO    : Bus 70770	: V=0.9908875, theta=-76.20273 -> V=1.0, theta=0.0
% INFO    : Bus 70771	: V=0.9897335, theta=-75.983062 -> V=1.0, theta=0.0
% INFO    : Bus 70772	: V=0.9896002, theta=-76.074197 -> V=1.0, theta=0.0
% INFO    : Bus 70773	: V=0.9893773, theta=-75.873325 -> V=1.0, theta=0.0
% INFO    : Bus 70774	: V=0.9920807, theta=-75.585145 -> V=1.0, theta=0.0
% INFO    : Bus 70775	: V=0.9917851, theta=-75.476812 -> V=1.0, theta=0.0
% INFO    : Bus 70776	: V=0.9884561, theta=-76.117854 -> V=1.0, theta=0.0
% INFO    : Bus 70777	: V=0.9888935, theta=-76.101176 -> V=1.0, theta=0.0
% INFO    : Bus 70778	: V=0.991521, theta=-75.347699 -> V=1.0, theta=0.0
% INFO    : Bus 70779	: V=0.9899532, theta=-76.138415 -> V=1.0, theta=0.0
% INFO    : Bus 70780	: V=0.9913621, theta=-75.219526 -> V=1.0, theta=0.0
% INFO    : Bus 70781	: V=0.9912507, theta=-75.087614 -> V=1.0, theta=0.0
% INFO    : Bus 70782	: V=0.9899985, theta=-76.037515 -> V=1.0, theta=0.0
% INFO    : Bus 70783	: V=0.9879606, theta=-76.140271 -> V=1.0, theta=0.0
% INFO    : Bus 70784	: V=1.0016222, theta=-72.304471 -> V=1.0, theta=0.0
% INFO    : Bus 70785	: V=1.0018265, theta=-72.202693 -> V=1.0, theta=0.0
% INFO    : Bus 70786	: V=0.9925812, theta=-72.433447 -> V=1.0, theta=0.0
% INFO    : Bus 70787	: V=1.002136, theta=-72.026775 -> V=1.0, theta=0.0
% INFO    : Bus 70788	: V=0.9999642, theta=-72.05453 -> V=1.0, theta=0.0
% INFO    : Bus 70789	: V=1.000503, theta=-72.671694 -> V=1.0, theta=0.0
% INFO    : Bus 70790	: V=1.0005598, theta=-72.586888 -> V=1.0, theta=0.0
% INFO    : Bus 70791	: V=1.002248, theta=-72.08604 -> V=1.0, theta=0.0
% INFO    : Bus 70792	: V=1.0023833, theta=-71.637913 -> V=1.0, theta=0.0
% INFO    : Bus 70793	: V=1.0127356, theta=-67.53118 -> V=1.0, theta=0.0
% INFO    : Bus 70794	: V=0.9998872, theta=-72.842046 -> V=1.0, theta=0.0
% INFO    : Bus 70795	: V=1.0000762, theta=-72.777736 -> V=1.0, theta=0.0
% INFO    : Bus 70796	: V=1.0001013, theta=-72.780457 -> V=1.0, theta=0.0
% INFO    : Bus 70797	: V=1.0003444, theta=-72.708082 -> V=1.0, theta=0.0
% INFO    : Bus 70798	: V=1.000898, theta=-72.665024 -> V=1.0, theta=0.0
% INFO    : Bus 70799	: V=1.0006995, theta=-72.585957 -> V=1.0, theta=0.0
% INFO    : Bus 70800	: V=1.001349, theta=-72.572951 -> V=1.0, theta=0.0
% INFO    : Bus 70801	: V=1.0019784, theta=-72.444129 -> V=1.0, theta=0.0
% INFO    : Bus 70802	: V=1.0019717, theta=-72.290117 -> V=1.0, theta=0.0
% INFO    : Bus 70803	: V=1.0011848, theta=-72.409557 -> V=1.0, theta=0.0
% INFO    : Bus 70804	: V=1.0022122, theta=-72.28016 -> V=1.0, theta=0.0
% INFO    : Bus 70805	: V=1.0028358, theta=-72.062084 -> V=1.0, theta=0.0
% INFO    : Bus 70806	: V=1.002693, theta=-71.764026 -> V=1.0, theta=0.0
% INFO    : Bus 70807	: V=1.0025511, theta=-71.76934 -> V=1.0, theta=0.0
% INFO    : Bus 70808	: V=1.0026215, theta=-70.819875 -> V=1.0, theta=0.0
% INFO    : Bus 70809	: V=1.0035638, theta=-71.684374 -> V=1.0, theta=0.0
% INFO    : Bus 70810	: V=1.0048017, theta=-71.678294 -> V=1.0, theta=0.0
% INFO    : Bus 70811	: V=1.0052241, theta=-72.059262 -> V=1.0, theta=0.0
% INFO    : Bus 70812	: V=1.0049785, theta=-71.667689 -> V=1.0, theta=0.0
% INFO    : Bus 70813	: V=1.0052911, theta=-71.655911 -> V=1.0, theta=0.0
% INFO    : Bus 70814	: V=1.0006374, theta=-72.731945 -> V=1.0, theta=0.0
% INFO    : Bus 70815	: V=1.0005219, theta=-72.773533 -> V=1.0, theta=0.0
% INFO    : Bus 70816	: V=1.0005336, theta=-72.797677 -> V=1.0, theta=0.0
% INFO    : Bus 70817	: V=1.0041113, theta=-72.31089 -> V=1.0, theta=0.0
% INFO    : Bus 70818	: V=1.0043444, theta=-72.302229 -> V=1.0, theta=0.0
% INFO    : Bus 70819	: V=1.0034669, theta=-72.124512 -> V=1.0, theta=0.0
% INFO    : Bus 70820	: V=1.0051391, theta=-72.257411 -> V=1.0, theta=0.0
% INFO    : Bus 70821	: V=1.0048426, theta=-72.269503 -> V=1.0, theta=0.0
% INFO    : Bus 70822	: V=1.0066762, theta=-70.017958 -> V=1.0, theta=0.0
% INFO    : Bus 70823	: V=1.002202, theta=-71.767939 -> V=1.0, theta=0.0
% INFO    : Bus 70824	: V=1.0043904, theta=-71.113651 -> V=1.0, theta=0.0
% INFO    : Bus 70825	: V=1.0042007, theta=-71.339673 -> V=1.0, theta=0.0
% INFO    : Bus 70826	: V=1.004826, theta=-70.768442 -> V=1.0, theta=0.0
% INFO    : Bus 70827	: V=1.0171938, theta=-65.156666 -> V=1.0, theta=0.0
% INFO    : Bus 70828	: V=1.0101581, theta=-67.97434 -> V=1.0, theta=0.0
% INFO    : Bus 70829	: V=1.0108254, theta=-67.740119 -> V=1.0, theta=0.0
% INFO    : Bus 70830	: V=1.0089831, theta=-68.271123 -> V=1.0, theta=0.0
% INFO    : Bus 70831	: V=1.0099859, theta=-67.971847 -> V=1.0, theta=0.0
% INFO    : Bus 70832	: V=1.0081388, theta=-68.849641 -> V=1.0, theta=0.0
% INFO    : Bus 70833	: V=1.012135, theta=-67.482771 -> V=1.0, theta=0.0
% INFO    : Bus 70834	: V=1.0083064, theta=-68.276236 -> V=1.0, theta=0.0
% INFO    : Bus 70835	: V=1.0116652, theta=-67.348125 -> V=1.0, theta=0.0
% INFO    : Bus 70836	: V=1.0086837, theta=-68.629029 -> V=1.0, theta=0.0
% INFO    : Bus 70837	: V=1.006676, theta=-69.736034 -> V=1.0, theta=0.0
% INFO    : Bus 70838	: V=1.0101162, theta=-68.201181 -> V=1.0, theta=0.0
% INFO    : Bus 70839	: V=1.0094446, theta=-68.276535 -> V=1.0, theta=0.0
% INFO    : Bus 70840	: V=1.0038944, theta=-71.210576 -> V=1.0, theta=0.0
% INFO    : Bus 70841	: V=1.0006309, theta=-72.509896 -> V=1.0, theta=0.0
% INFO    : Bus 70842	: V=1.0081735, theta=-68.906989 -> V=1.0, theta=0.0
% INFO    : Bus 70843	: V=1.0080089, theta=-69.023084 -> V=1.0, theta=0.0
% INFO    : Bus 70844	: V=1.0081133, theta=-69.079149 -> V=1.0, theta=0.0
% INFO    : Bus 70845	: V=1.0054392, theta=-69.985742 -> V=1.0, theta=0.0
% INFO    : Bus 70846	: V=1.0026138, theta=-71.390253 -> V=1.0, theta=0.0
% INFO    : Bus 70847	: V=1.0048658, theta=-70.843825 -> V=1.0, theta=0.0
% INFO    : Bus 70848	: V=1.0022694, theta=-71.37703 -> V=1.0, theta=0.0
% INFO    : Bus 70849	: V=1.000643, theta=-71.945592 -> V=1.0, theta=0.0
% INFO    : Bus 70850	: V=1.0044787, theta=-69.991631 -> V=1.0, theta=0.0
% INFO    : Bus 70851	: V=1.0044774, theta=-71.057713 -> V=1.0, theta=0.0
% INFO    : Bus 70852	: V=1.0018197, theta=-71.515242 -> V=1.0, theta=0.0
% INFO    : Bus 70853	: V=1.0022583, theta=-71.497205 -> V=1.0, theta=0.0
% INFO    : Bus 70854	: V=1.000712, theta=-72.341004 -> V=1.0, theta=0.0
% INFO    : Bus 70855	: V=1.0004864, theta=-72.351306 -> V=1.0, theta=0.0
% INFO    : Bus 70856	: V=1.0031669, theta=-71.150291 -> V=1.0, theta=0.0
% INFO    : Bus 70857	: V=1.0033622, theta=-71.142186 -> V=1.0, theta=0.0
% INFO    : Bus 70858	: V=1.0040041, theta=-71.016322 -> V=1.0, theta=0.0
% INFO    : Bus 70859	: V=1.0052963, theta=-70.624916 -> V=1.0, theta=0.0
% INFO    : Bus 70860	: V=1.0009217, theta=-72.018728 -> V=1.0, theta=0.0
% INFO    : Bus 70861	: V=1.0012114, theta=-71.868316 -> V=1.0, theta=0.0
% INFO    : Bus 70862	: V=1.0013826, theta=-71.743299 -> V=1.0, theta=0.0
% INFO    : Bus 70863	: V=1.0016471, theta=-71.520799 -> V=1.0, theta=0.0
% INFO    : Bus 70864	: V=1.0051308, theta=-70.796006 -> V=1.0, theta=0.0
% INFO    : Bus 70865	: V=1.0053952, theta=-70.373307 -> V=1.0, theta=0.0
% INFO    : Bus 70866	: V=1.0054138, theta=-70.237502 -> V=1.0, theta=0.0
% INFO    : Bus 70867	: V=0.9971571, theta=-73.671849 -> V=1.0, theta=0.0
% INFO    : Bus 70868	: V=1.0008788, theta=-72.682813 -> V=1.0, theta=0.0
% INFO    : Bus 70869	: V=1.0036979, theta=-72.513887 -> V=1.0, theta=0.0
% INFO    : Bus 70870	: V=1.0005699, theta=-72.712726 -> V=1.0, theta=0.0
% INFO    : Bus 70871	: V=1.0008336, theta=-72.558241 -> V=1.0, theta=0.0
% INFO    : Bus 70872	: V=1.0010941, theta=-72.546381 -> V=1.0, theta=0.0
% INFO    : Bus 70873	: V=0.9937041, theta=-74.891124 -> V=1.0, theta=0.0
% INFO    : Bus 70874	: V=0.9943409, theta=-74.620907 -> V=1.0, theta=0.0
% INFO    : Bus 70875	: V=0.9931796, theta=-75.188448 -> V=1.0, theta=0.0
% INFO    : Bus 70876	: V=0.9948162, theta=-74.762973 -> V=1.0, theta=0.0
% INFO    : Bus 70877	: V=0.9931795, theta=-74.912766 -> V=1.0, theta=0.0
% INFO    : Bus 70878	: V=0.9983242, theta=-73.322183 -> V=1.0, theta=0.0
% INFO    : Bus 70879	: V=0.9992419, theta=-73.057011 -> V=1.0, theta=0.0
% INFO    : Bus 70880	: V=0.9996269, theta=-72.934843 -> V=1.0, theta=0.0
% INFO    : Bus 70881	: V=0.9989413, theta=-73.129593 -> V=1.0, theta=0.0
% INFO    : Bus 70882	: V=0.9948313, theta=-74.02364 -> V=1.0, theta=0.0
% INFO    : Bus 70883	: V=0.9969265, theta=-73.369175 -> V=1.0, theta=0.0
% INFO    : Bus 70884	: V=0.9976324, theta=-73.061976 -> V=1.0, theta=0.0
% INFO    : Bus 70885	: V=1.0057136, theta=-74.059968 -> V=1.0, theta=0.0
% INFO    : Bus 70886	: V=0.9938518, theta=-74.712359 -> V=1.0, theta=0.0
% INFO    : Bus 70887	: V=0.9951931, theta=-74.58415 -> V=1.0, theta=0.0
% INFO    : Bus 70888	: V=0.996281, theta=-74.641141 -> V=1.0, theta=0.0
% INFO    : Bus 70889	: V=0.9955957, theta=-74.582729 -> V=1.0, theta=0.0
% INFO    : Bus 70890	: V=0.9961262, theta=-74.530922 -> V=1.0, theta=0.0
% INFO    : Bus 70891	: V=0.9978919, theta=-74.56567 -> V=1.0, theta=0.0
% INFO    : Bus 70892	: V=0.9957378, theta=-74.39838 -> V=1.0, theta=0.0
% INFO    : Bus 70893	: V=1.003402, theta=-73.247366 -> V=1.0, theta=0.0
% INFO    : Bus 70894	: V=0.9970005, theta=-74.530114 -> V=1.0, theta=0.0
% INFO    : Bus 70895	: V=0.9965374, theta=-74.533427 -> V=1.0, theta=0.0
% INFO    : Bus 70896	: V=0.9995608, theta=-74.484124 -> V=1.0, theta=0.0
% INFO    : Bus 70897	: V=0.9993746, theta=-74.486133 -> V=1.0, theta=0.0
% INFO    : Bus 70898	: V=0.9978487, theta=-74.520132 -> V=1.0, theta=0.0
% INFO    : Bus 70899	: V=0.9925157, theta=-75.352806 -> V=1.0, theta=0.0
% INFO    : Bus 70900	: V=0.9930362, theta=-75.152979 -> V=1.0, theta=0.0
% INFO    : Bus 70901	: V=0.9933062, theta=-74.818176 -> V=1.0, theta=0.0
% INFO    : Bus 70902	: V=0.9926375, theta=-75.058502 -> V=1.0, theta=0.0
% INFO    : Bus 70903	: V=0.9947574, theta=-74.734853 -> V=1.0, theta=0.0
% INFO    : Bus 70904	: V=0.9988864, theta=-72.579158 -> V=1.0, theta=0.0
% INFO    : Bus 70905	: V=1.0005332, theta=-72.194265 -> V=1.0, theta=0.0
% INFO    : Bus 70906	: V=1.0027914, theta=-74.458888 -> V=1.0, theta=0.0
% INFO    : Bus 70907	: V=0.997374, theta=-74.525339 -> V=1.0, theta=0.0
% INFO    : Bus 70908	: V=0.9960948, theta=-74.611526 -> V=1.0, theta=0.0
% INFO    : Bus 70909	: V=0.9916142, theta=-74.934556 -> V=1.0, theta=0.0
% INFO    : Bus 70910	: V=1.0013766, theta=-71.920241 -> V=1.0, theta=0.0
% INFO    : Bus 70911	: V=1.001846, theta=-71.766826 -> V=1.0, theta=0.0
% INFO    : Bus 70912	: V=0.9976082, theta=-73.548829 -> V=1.0, theta=0.0
% INFO    : Bus 70913	: V=0.9997881, theta=-72.748433 -> V=1.0, theta=0.0
% INFO    : Bus 70914	: V=1.0002886, theta=-72.356901 -> V=1.0, theta=0.0
% INFO    : Bus 70915	: V=0.9928778, theta=-74.856858 -> V=1.0, theta=0.0
% INFO    : Bus 70916	: V=0.9937448, theta=-74.79919 -> V=1.0, theta=0.0
% INFO    : Bus 70917	: V=0.9950338, theta=-74.632575 -> V=1.0, theta=0.0
% INFO    : Bus 70918	: V=0.9940558, theta=-74.637522 -> V=1.0, theta=0.0
% INFO    : Bus 70919	: V=0.9948256, theta=-74.641374 -> V=1.0, theta=0.0
% INFO    : Bus 70920	: V=0.994287, theta=-74.635453 -> V=1.0, theta=0.0
% INFO    : Bus 70921	: V=1.0009931, theta=-72.049647 -> V=1.0, theta=0.0
% INFO    : Bus 70922	: V=1.0007342, theta=-71.828059 -> V=1.0, theta=0.0
% INFO    : Bus 70923	: V=0.9991029, theta=-72.660386 -> V=1.0, theta=0.0
% INFO    : Bus 70924	: V=0.9986083, theta=-72.884778 -> V=1.0, theta=0.0
% INFO    : Bus 70925	: V=0.999551, theta=-72.247028 -> V=1.0, theta=0.0
% INFO    : Bus 70926	: V=0.999802, theta=-72.235547 -> V=1.0, theta=0.0
% INFO    : Bus 70927	: V=0.9993784, theta=-72.254668 -> V=1.0, theta=0.0
% INFO    : Bus 70928	: V=1.001201, theta=-71.809046 -> V=1.0, theta=0.0
% INFO    : Bus 70929	: V=1.0007866, theta=-71.824475 -> V=1.0, theta=0.0
% INFO    : Bus 70930	: V=0.9992445, theta=-72.654393 -> V=1.0, theta=0.0
% INFO    : Bus 70931	: V=0.9904485, theta=-74.936798 -> V=1.0, theta=0.0
% INFO    : Bus 70932	: V=0.9992607, theta=-73.815695 -> V=1.0, theta=0.0
% INFO    : Bus 70933	: V=0.9986924, theta=-74.112277 -> V=1.0, theta=0.0
% INFO    : Bus 70934	: V=0.999033, theta=-73.942603 -> V=1.0, theta=0.0
% INFO    : Bus 70935	: V=0.9995182, theta=-72.628918 -> V=1.0, theta=0.0
% INFO    : Bus 70936	: V=0.9998096, theta=-72.603673 -> V=1.0, theta=0.0
% INFO    : Bus 70937	: V=0.9982231, theta=-73.079397 -> V=1.0, theta=0.0
% INFO    : Bus 70938	: V=0.9982862, theta=-72.896956 -> V=1.0, theta=0.0
% INFO    : Bus 70939	: V=0.9908983, theta=-74.941949 -> V=1.0, theta=0.0
% INFO    : Bus 70940	: V=0.9907925, theta=-74.933267 -> V=1.0, theta=0.0
% INFO    : Bus 70941	: V=0.99172, theta=-74.918681 -> V=1.0, theta=0.0
% INFO    : Bus 70942	: V=0.9987029, theta=-74.353928 -> V=1.0, theta=0.0
% INFO    : Bus 70943	: V=0.9923244, theta=-74.91885 -> V=1.0, theta=0.0
% INFO    : Bus 70944	: V=0.9906884, theta=-74.941667 -> V=1.0, theta=0.0
% INFO    : Bus 70945	: V=0.9985437, theta=-74.259471 -> V=1.0, theta=0.0
% INFO    : Bus 70946	: V=0.9914189, theta=-74.934896 -> V=1.0, theta=0.0
% INFO    : Bus 70947	: V=0.9951325, theta=-75.157759 -> V=1.0, theta=0.0
% INFO    : Bus 70948	: V=0.9990579, theta=-74.477474 -> V=1.0, theta=0.0
% INFO    : Bus 70949	: V=1.0014871, theta=-74.562316 -> V=1.0, theta=0.0
% INFO    : Bus 70950	: V=1.000844, theta=-74.612462 -> V=1.0, theta=0.0
% INFO    : Bus 70951	: V=0.995102, theta=-75.155299 -> V=1.0, theta=0.0
% INFO    : Bus 70952	: V=0.9952701, theta=-75.154677 -> V=1.0, theta=0.0
% INFO    : Bus 70953	: V=0.9950855, theta=-75.151057 -> V=1.0, theta=0.0
% INFO    : Bus 70954	: V=0.9998305, theta=-74.573815 -> V=1.0, theta=0.0
% INFO    : Bus 70955	: V=0.9946916, theta=-75.155421 -> V=1.0, theta=0.0
% INFO    : Bus 70956	: V=0.9940233, theta=-75.163836 -> V=1.0, theta=0.0
% INFO    : Bus 70957	: V=0.9952689, theta=-75.002262 -> V=1.0, theta=0.0
% INFO    : Bus 70958	: V=1.0019448, theta=-74.648946 -> V=1.0, theta=0.0
% INFO    : Bus 70959	: V=0.9965972, theta=-74.995701 -> V=1.0, theta=0.0
% INFO    : Bus 70960	: V=1.0068066, theta=-74.440315 -> V=1.0, theta=0.0
% INFO    : Bus 70961	: V=1.0004907, theta=-74.608453 -> V=1.0, theta=0.0
% INFO    : Bus 70962	: V=1.000723, theta=-74.652101 -> V=1.0, theta=0.0
% INFO    : Bus 70963	: V=0.995104, theta=-75.151234 -> V=1.0, theta=0.0
% INFO    : Bus 70964	: V=0.9931072, theta=-75.388516 -> V=1.0, theta=0.0
% INFO    : Bus 70965	: V=0.9976367, theta=-75.107503 -> V=1.0, theta=0.0
% INFO    : Bus 70966	: V=0.9930586, theta=-75.411827 -> V=1.0, theta=0.0
% INFO    : Bus 70967	: V=0.9933559, theta=-75.409687 -> V=1.0, theta=0.0
% INFO    : Bus 70968	: V=0.9963762, theta=-75.140043 -> V=1.0, theta=0.0
% INFO    : Bus 70969	: V=1.0005914, theta=-74.654678 -> V=1.0, theta=0.0
% INFO    : Bus 70970	: V=0.9928013, theta=-75.336892 -> V=1.0, theta=0.0
% INFO    : Bus 70971	: V=0.9928406, theta=-75.281718 -> V=1.0, theta=0.0
% INFO    : Bus 70972	: V=0.9937791, theta=-75.234765 -> V=1.0, theta=0.0
% INFO    : Bus 70973	: V=1.0004913, theta=-74.649754 -> V=1.0, theta=0.0
% INFO    : Bus 70974	: V=1.0005859, theta=-74.637539 -> V=1.0, theta=0.0
% INFO    : Bus 70975	: V=0.992425, theta=-75.359167 -> V=1.0, theta=0.0
% INFO    : Bus 70976	: V=0.9922598, theta=-75.2638 -> V=1.0, theta=0.0
% INFO    : Bus 70977	: V=1.0030489, theta=-74.492897 -> V=1.0, theta=0.0
% INFO    : Bus 70978	: V=0.9942321, theta=-75.352559 -> V=1.0, theta=0.0
% INFO    : Bus 70979	: V=0.993662, theta=-75.383853 -> V=1.0, theta=0.0
% INFO    : Bus 70980	: V=0.9929371, theta=-75.342959 -> V=1.0, theta=0.0
% INFO    : Bus 70981	: V=0.9941026, theta=-75.493776 -> V=1.0, theta=0.0
% INFO    : Bus 70982	: V=0.9939447, theta=-75.451136 -> V=1.0, theta=0.0
% INFO    : Bus 70983	: V=1.0100003, theta=-74.682423 -> V=1.0, theta=0.0
% INFO    : Bus 70984	: V=0.9923303, theta=-75.359488 -> V=1.0, theta=0.0
% INFO    : Bus 70985	: V=1.0024146, theta=-74.718572 -> V=1.0, theta=0.0
% INFO    : Bus 70986	: V=0.9937855, theta=-75.556719 -> V=1.0, theta=0.0
% INFO    : Bus 70987	: V=0.9940446, theta=-75.351955 -> V=1.0, theta=0.0
% INFO    : Bus 70988	: V=0.9937382, theta=-75.373455 -> V=1.0, theta=0.0
% INFO    : Bus 70989	: V=1.0017699, theta=-74.671944 -> V=1.0, theta=0.0
% INFO    : Bus 70990	: V=0.9937121, theta=-75.392773 -> V=1.0, theta=0.0
% INFO    : Bus 70991	: V=1.0014066, theta=-74.68984 -> V=1.0, theta=0.0
% INFO    : Bus 70992	: V=0.9883456, theta=-76.050263 -> V=1.0, theta=0.0
% INFO    : Bus 70993	: V=0.9910632, theta=-75.619467 -> V=1.0, theta=0.0
% INFO    : Bus 70994	: V=0.9908276, theta=-75.546334 -> V=1.0, theta=0.0
% INFO    : Bus 70995	: V=0.990888, theta=-75.530285 -> V=1.0, theta=0.0
% INFO    : Bus 70996	: V=0.992449, theta=-75.486089 -> V=1.0, theta=0.0
% INFO    : Bus 70997	: V=0.9924042, theta=-75.452651 -> V=1.0, theta=0.0
% INFO    : Bus 70998	: V=0.9927073, theta=-75.487845 -> V=1.0, theta=0.0
% INFO    : Bus 70999	: V=0.9928888, theta=-75.48257 -> V=1.0, theta=0.0
% INFO    : Bus 71000	: V=0.9992443, theta=-74.97501 -> V=1.0, theta=0.0
% INFO    : Bus 71001	: V=0.9933578, theta=-75.462996 -> V=1.0, theta=0.0
% INFO    : Bus 71002	: V=0.9983927, theta=-75.016116 -> V=1.0, theta=0.0
% INFO    : Bus 71003	: V=0.9985374, theta=-75.025402 -> V=1.0, theta=0.0
% INFO    : Bus 71004	: V=0.9986675, theta=-75.050129 -> V=1.0, theta=0.0
% INFO    : Bus 71005	: V=0.9987085, theta=-75.034125 -> V=1.0, theta=0.0
% INFO    : Bus 71006	: V=0.9949779, theta=-75.476876 -> V=1.0, theta=0.0
% INFO    : Bus 71007	: V=0.9983148, theta=-75.003432 -> V=1.0, theta=0.0
% INFO    : Bus 71008	: V=0.9931047, theta=-75.4792 -> V=1.0, theta=0.0
% INFO    : Bus 71009	: V=0.9983946, theta=-74.97928 -> V=1.0, theta=0.0
% INFO    : Bus 71010	: V=0.9883335, theta=-76.116481 -> V=1.0, theta=0.0
% INFO    : Bus 71011	: V=0.9881233, theta=-76.131346 -> V=1.0, theta=0.0
% INFO    : Bus 71012	: V=0.9877684, theta=-76.120785 -> V=1.0, theta=0.0
% INFO    : Bus 71013	: V=0.9888019, theta=-76.046127 -> V=1.0, theta=0.0
% INFO    : Bus 71014	: V=0.9881437, theta=-76.088712 -> V=1.0, theta=0.0
% INFO    : Bus 71015	: V=0.9859866, theta=-76.277729 -> V=1.0, theta=0.0
% INFO    : Bus 71016	: V=0.9865313, theta=-76.208609 -> V=1.0, theta=0.0
% INFO    : Bus 71017	: V=0.9877907, theta=-76.136583 -> V=1.0, theta=0.0
% INFO    : Bus 71018	: V=0.987855, theta=-76.145251 -> V=1.0, theta=0.0
% INFO    : Bus 71019	: V=0.9979524, theta=-75.026872 -> V=1.0, theta=0.0
% INFO    : Bus 71020	: V=0.9964429, theta=-75.203189 -> V=1.0, theta=0.0
% INFO    : Bus 71021	: V=0.9907645, theta=-75.750028 -> V=1.0, theta=0.0
% INFO    : Bus 71022	: V=0.9901775, theta=-75.694449 -> V=1.0, theta=0.0
% INFO    : Bus 71023	: V=0.9906312, theta=-75.607376 -> V=1.0, theta=0.0
% INFO    : Bus 71024	: V=0.9914366, theta=-75.487652 -> V=1.0, theta=0.0
% INFO    : Bus 71025	: V=0.9915073, theta=-75.473766 -> V=1.0, theta=0.0
% INFO    : Bus 71026	: V=0.9914334, theta=-75.47446 -> V=1.0, theta=0.0
% INFO    : Bus 71027	: V=0.9918319, theta=-75.438358 -> V=1.0, theta=0.0
% INFO    : Bus 71028	: V=0.9911559, theta=-75.506599 -> V=1.0, theta=0.0
% INFO    : Bus 71029	: V=1.0294129, theta=-71.61528 -> V=1.0, theta=0.0
% INFO    : Bus 71030	: V=0.9915686, theta=-75.491422 -> V=1.0, theta=0.0
% INFO    : Bus 71031	: V=0.9907959, theta=-75.780982 -> V=1.0, theta=0.0
% INFO    : Bus 71032	: V=0.9910179, theta=-75.703174 -> V=1.0, theta=0.0
% INFO    : Bus 71033	: V=0.992068, theta=-75.484236 -> V=1.0, theta=0.0
% INFO    : Bus 71034	: V=0.9916718, theta=-75.384674 -> V=1.0, theta=0.0
% INFO    : Bus 71035	: V=0.9902092, theta=-75.84134 -> V=1.0, theta=0.0
% INFO    : Bus 71036	: V=0.9898943, theta=-75.706185 -> V=1.0, theta=0.0
% INFO    : Bus 71037	: V=0.9895102, theta=-75.836489 -> V=1.0, theta=0.0
% INFO    : Bus 71038	: V=0.9882329, theta=-76.169802 -> V=1.0, theta=0.0
% INFO    : Bus 71039	: V=0.9886186, theta=-75.955209 -> V=1.0, theta=0.0
% INFO    : Bus 71040	: V=0.9891552, theta=-76.018837 -> V=1.0, theta=0.0
% INFO    : Bus 71041	: V=0.989246, theta=-75.930291 -> V=1.0, theta=0.0
% INFO    : Bus 71042	: V=0.9902747, theta=-76.164165 -> V=1.0, theta=0.0
% INFO    : Bus 71043	: V=0.9874498, theta=-76.275127 -> V=1.0, theta=0.0
% INFO    : Bus 71044	: V=0.987771, theta=-76.353246 -> V=1.0, theta=0.0
% INFO    : Bus 71045	: V=0.98781, theta=-76.258352 -> V=1.0, theta=0.0
% INFO    : Bus 71046	: V=0.9925407, theta=-75.648196 -> V=1.0, theta=0.0
% INFO    : Bus 71047	: V=0.9904359, theta=-76.197 -> V=1.0, theta=0.0
% INFO    : Bus 71048	: V=0.9885432, theta=-76.160431 -> V=1.0, theta=0.0
% INFO    : Bus 71049	: V=0.9890671, theta=-76.087711 -> V=1.0, theta=0.0
% INFO    : Bus 71050	: V=0.9946437, theta=-75.447464 -> V=1.0, theta=0.0
% INFO    : Bus 71051	: V=0.9954232, theta=-75.337542 -> V=1.0, theta=0.0
% INFO    : Bus 71052	: V=0.9866912, theta=-76.15692 -> V=1.0, theta=0.0
% INFO    : Bus 71053	: V=0.9859964, theta=-76.23148 -> V=1.0, theta=0.0
% INFO    : Bus 71054	: V=0.9858539, theta=-76.326764 -> V=1.0, theta=0.0
% INFO    : Bus 71055	: V=0.9863146, theta=-76.37553 -> V=1.0, theta=0.0
% INFO    : Bus 71056	: V=0.9859483, theta=-76.822787 -> V=1.0, theta=0.0
% INFO    : Bus 71057	: V=0.9863391, theta=-76.679935 -> V=1.0, theta=0.0
% INFO    : Bus 71058	: V=1.0088251, theta=-73.565752 -> V=1.0, theta=0.0
% INFO    : Bus 71059	: V=0.9937374, theta=-75.569964 -> V=1.0, theta=0.0
% INFO    : Bus 71060	: V=0.9882905, theta=-76.157575 -> V=1.0, theta=0.0
% INFO    : Bus 71061	: V=0.9931387, theta=-75.694996 -> V=1.0, theta=0.0
% INFO    : Bus 71062	: V=0.9850575, theta=-76.796685 -> V=1.0, theta=0.0
% INFO    : Bus 71063	: V=0.9918801, theta=-76.161366 -> V=1.0, theta=0.0
% INFO    : Bus 71064	: V=0.9851329, theta=-76.549559 -> V=1.0, theta=0.0
% INFO    : Bus 71065	: V=0.9855973, theta=-76.550729 -> V=1.0, theta=0.0
% INFO    : Bus 71066	: V=0.9861493, theta=-76.40561 -> V=1.0, theta=0.0
% INFO    : Bus 71067	: V=0.9870833, theta=-77.142118 -> V=1.0, theta=0.0
% INFO    : Bus 71068	: V=0.9911928, theta=-77.279933 -> V=1.0, theta=0.0
% INFO    : Bus 71069	: V=0.9875747, theta=-77.38533 -> V=1.0, theta=0.0
% INFO    : Bus 71070	: V=0.9865651, theta=-77.066941 -> V=1.0, theta=0.0
% INFO    : Bus 71071	: V=0.9913454, theta=-76.312133 -> V=1.0, theta=0.0
% INFO    : Bus 71072	: V=0.9872108, theta=-77.38102 -> V=1.0, theta=0.0
% INFO    : Bus 71073	: V=0.988777, theta=-77.378805 -> V=1.0, theta=0.0
% INFO    : Bus 71074	: V=0.9859806, theta=-77.298407 -> V=1.0, theta=0.0
% INFO    : Bus 71075	: V=0.9856138, theta=-77.246743 -> V=1.0, theta=0.0
% INFO    : Bus 71076	: V=0.9858691, theta=-77.507263 -> V=1.0, theta=0.0
% INFO    : Bus 71077	: V=0.9849967, theta=-77.355448 -> V=1.0, theta=0.0
% INFO    : Bus 71078	: V=0.987504, theta=-77.649932 -> V=1.0, theta=0.0
% INFO    : Bus 71079	: V=0.986655, theta=-77.674547 -> V=1.0, theta=0.0
% INFO    : Bus 71080	: V=0.9876689, theta=-77.559548 -> V=1.0, theta=0.0
% INFO    : Bus 71081	: V=0.9918624, theta=-77.144982 -> V=1.0, theta=0.0
% INFO    : Bus 71082	: V=0.9911108, theta=-77.101103 -> V=1.0, theta=0.0
% INFO    : Bus 71083	: V=0.9903934, theta=-77.040404 -> V=1.0, theta=0.0
% INFO    : Bus 71084	: V=0.9890953, theta=-77.053248 -> V=1.0, theta=0.0
% INFO    : Bus 71085	: V=0.9883661, theta=-77.049423 -> V=1.0, theta=0.0
% INFO    : Bus 71086	: V=0.987834, theta=-77.055949 -> V=1.0, theta=0.0
% INFO    : Bus 71087	: V=0.9858416, theta=-77.352939 -> V=1.0, theta=0.0
% INFO    : Bus 71088	: V=0.9866623, theta=-77.107329 -> V=1.0, theta=0.0
% INFO    : Bus 71089	: V=0.9857318, theta=-77.200299 -> V=1.0, theta=0.0
% INFO    : Bus 71090	: V=0.9852072, theta=-77.200262 -> V=1.0, theta=0.0
% INFO    : Bus 71091	: V=0.9853554, theta=-77.16723 -> V=1.0, theta=0.0
% INFO    : Bus 71092	: V=0.9934534, theta=-76.498964 -> V=1.0, theta=0.0
% INFO    : Bus 71093	: V=0.9927885, theta=-76.406481 -> V=1.0, theta=0.0
% INFO    : Bus 71094	: V=0.9850387, theta=-76.79447 -> V=1.0, theta=0.0
% INFO    : Bus 71095	: V=0.992408, theta=-76.341988 -> V=1.0, theta=0.0
% INFO    : Bus 71096	: V=0.9923397, theta=-76.331004 -> V=1.0, theta=0.0
% INFO    : Bus 71097	: V=0.992592, theta=-76.256088 -> V=1.0, theta=0.0
% INFO    : Bus 71098	: V=0.9860111, theta=-76.447322 -> V=1.0, theta=0.0
% INFO    : Bus 71099	: V=0.9863828, theta=-76.705212 -> V=1.0, theta=0.0
% INFO    : Bus 71100	: V=0.9863938, theta=-76.705666 -> V=1.0, theta=0.0
% INFO    : Bus 71101	: V=0.9869661, theta=-76.700349 -> V=1.0, theta=0.0
% INFO    : Bus 71102	: V=0.9877951, theta=-77.013801 -> V=1.0, theta=0.0
% INFO    : Bus 71103	: V=0.9902856, theta=-76.819026 -> V=1.0, theta=0.0
% INFO    : Bus 71104	: V=0.989895, theta=-76.820762 -> V=1.0, theta=0.0
% INFO    : Bus 71105	: V=0.9922854, theta=-76.669516 -> V=1.0, theta=0.0
% INFO    : Bus 71106	: V=0.9923091, theta=-76.812154 -> V=1.0, theta=0.0
% INFO    : Bus 71107	: V=0.9934749, theta=-76.868918 -> V=1.0, theta=0.0
% INFO    : Bus 71108	: V=0.994117, theta=-76.957216 -> V=1.0, theta=0.0
% INFO    : Bus 71109	: V=0.9916621, theta=-76.867949 -> V=1.0, theta=0.0
% INFO    : Bus 71110	: V=0.9905754, theta=-76.388034 -> V=1.0, theta=0.0
% INFO    : Bus 71111	: V=0.9910468, theta=-76.38789 -> V=1.0, theta=0.0
% INFO    : Bus 71112	: V=0.9900115, theta=-76.491731 -> V=1.0, theta=0.0
% INFO    : Bus 71113	: V=0.9894389, theta=-76.542442 -> V=1.0, theta=0.0
% INFO    : Bus 71114	: V=1.0077703, theta=-74.770937 -> V=1.0, theta=0.0
% INFO    : Bus 71115	: V=0.9905049, theta=-76.389544 -> V=1.0, theta=0.0
% INFO    : Bus 71116	: V=0.9906886, theta=-76.210092 -> V=1.0, theta=0.0
% INFO    : Bus 71117	: V=0.9914986, theta=-76.224992 -> V=1.0, theta=0.0
% INFO    : Bus 71118	: V=0.9914207, theta=-76.184187 -> V=1.0, theta=0.0
% INFO    : Bus 71119	: V=0.9889388, theta=-76.683053 -> V=1.0, theta=0.0
% INFO    : Bus 71120	: V=0.9885509, theta=-76.625764 -> V=1.0, theta=0.0
% INFO    : Bus 71121	: V=0.989254, theta=-76.231895 -> V=1.0, theta=0.0
% INFO    : Bus 71122	: V=0.9876019, theta=-76.617821 -> V=1.0, theta=0.0
% INFO    : Bus 71123	: V=0.9879859, theta=-76.497847 -> V=1.0, theta=0.0
% INFO    : Bus 71124	: V=0.9870201, theta=-76.492264 -> V=1.0, theta=0.0
% INFO    : Bus 71125	: V=0.9866133, theta=-76.482723 -> V=1.0, theta=0.0
% INFO    : Bus 71126	: V=0.9866328, theta=-76.46272 -> V=1.0, theta=0.0
% INFO    : Bus 71127	: V=0.9879157, theta=-76.253863 -> V=1.0, theta=0.0
% INFO    : Bus 71128	: V=0.9867592, theta=-76.313498 -> V=1.0, theta=0.0
% INFO    : Bus 71129	: V=0.9885432, theta=-76.31749 -> V=1.0, theta=0.0
% INFO    : Bus 71130	: V=0.9881013, theta=-76.320211 -> V=1.0, theta=0.0
% INFO    : Bus 71131	: V=0.9887432, theta=-76.238063 -> V=1.0, theta=0.0
% INFO    : Bus 71132	: V=0.9889005, theta=-76.236205 -> V=1.0, theta=0.0
% INFO    : Bus 71133	: V=0.9920668, theta=-76.147249 -> V=1.0, theta=0.0
% INFO    : Bus 71134	: V=0.9938175, theta=-75.987297 -> V=1.0, theta=0.0
% INFO    : Bus 71135	: V=0.9898225, theta=-76.212426 -> V=1.0, theta=0.0
% INFO    : Bus 71136	: V=0.9891472, theta=-76.235629 -> V=1.0, theta=0.0
% INFO    : Bus 71137	: V=0.9900237, theta=-76.140616 -> V=1.0, theta=0.0
% INFO    : Bus 71138	: V=0.9913969, theta=-76.015634 -> V=1.0, theta=0.0
% INFO    : Bus 71139	: V=0.992369, theta=-76.011512 -> V=1.0, theta=0.0
% INFO    : Bus 71140	: V=0.9890016, theta=-76.080158 -> V=1.0, theta=0.0
% INFO    : Bus 71141	: V=0.988553, theta=-76.180375 -> V=1.0, theta=0.0
% INFO    : Bus 71142	: V=0.9896873, theta=-76.073187 -> V=1.0, theta=0.0
% INFO    : Bus 71143	: V=0.9876811, theta=-76.214101 -> V=1.0, theta=0.0
% INFO    : Bus 71144	: V=0.9880129, theta=-76.159813 -> V=1.0, theta=0.0
% INFO    : Bus 71145	: V=0.9910463, theta=-75.987846 -> V=1.0, theta=0.0
% INFO    : Bus 71146	: V=0.9872266, theta=-76.272054 -> V=1.0, theta=0.0
% INFO    : Bus 71147	: V=0.9870248, theta=-76.289965 -> V=1.0, theta=0.0
% INFO    : Bus 71148	: V=0.9918737, theta=-75.845436 -> V=1.0, theta=0.0
% INFO    : Bus 71149	: V=0.9985387, theta=-75.149651 -> V=1.0, theta=0.0
% INFO    : Bus 71150	: V=0.9927323, theta=-75.898692 -> V=1.0, theta=0.0
% INFO    : Bus 71151	: V=1.0013904, theta=-75.069611 -> V=1.0, theta=0.0
% INFO    : Bus 71152	: V=1.0012138, theta=-75.033104 -> V=1.0, theta=0.0
% INFO    : Bus 71153	: V=1.0013395, theta=-75.02255 -> V=1.0, theta=0.0
% INFO    : Bus 71154	: V=0.9943837, theta=-75.420136 -> V=1.0, theta=0.0
% INFO    : Bus 71155	: V=0.9993172, theta=-75.130849 -> V=1.0, theta=0.0
% INFO    : Bus 71156	: V=1.0085316, theta=-74.423257 -> V=1.0, theta=0.0
% INFO    : Bus 71157	: V=0.9937969, theta=-75.8566 -> V=1.0, theta=0.0
% INFO    : Bus 71158	: V=0.9989177, theta=-75.189563 -> V=1.0, theta=0.0
% INFO    : Bus 71159	: V=0.995416, theta=-75.73822 -> V=1.0, theta=0.0
% INFO    : Bus 71160	: V=0.994605, theta=-75.781813 -> V=1.0, theta=0.0
% INFO    : Bus 71161	: V=0.9935008, theta=-75.782844 -> V=1.0, theta=0.0
% INFO    : Bus 71162	: V=0.9931254, theta=-75.775268 -> V=1.0, theta=0.0
% INFO    : Bus 71163	: V=1.0100003, theta=-74.664117 -> V=1.0, theta=0.0
% INFO    : Bus 71164	: V=0.9929959, theta=-75.568454 -> V=1.0, theta=0.0
% INFO    : Bus 71165	: V=0.9940303, theta=-75.564632 -> V=1.0, theta=0.0
% INFO    : Bus 71166	: V=1.0010778, theta=-75.045113 -> V=1.0, theta=0.0
% INFO    : Bus 71167	: V=1.0011928, theta=-75.076754 -> V=1.0, theta=0.0
% INFO    : Bus 71168	: V=1.0010358, theta=-75.081287 -> V=1.0, theta=0.0
% INFO    : Bus 71169	: V=0.9920865, theta=-75.624035 -> V=1.0, theta=0.0
% INFO    : Bus 71170	: V=0.9991697, theta=-75.155601 -> V=1.0, theta=0.0
% INFO    : Bus 71171	: V=1.0075394, theta=-74.440849 -> V=1.0, theta=0.0
% INFO    : Bus 71172	: V=1.0033894, theta=-74.669931 -> V=1.0, theta=0.0
% INFO    : Bus 71173	: V=1.0030806, theta=-74.665154 -> V=1.0, theta=0.0
% INFO    : Bus 71174	: V=0.995104, theta=-75.769504 -> V=1.0, theta=0.0
% INFO    : Bus 71175	: V=0.9948302, theta=-75.701652 -> V=1.0, theta=0.0
% INFO    : Bus 71176	: V=0.9992887, theta=-75.193668 -> V=1.0, theta=0.0
% INFO    : Bus 71177	: V=0.9991568, theta=-75.165815 -> V=1.0, theta=0.0
% INFO    : Bus 71178	: V=0.9985402, theta=-75.353578 -> V=1.0, theta=0.0
% INFO    : Bus 71179	: V=0.9971835, theta=-75.422507 -> V=1.0, theta=0.0
% INFO    : Bus 71180	: V=0.9985203, theta=-75.141187 -> V=1.0, theta=0.0
% INFO    : Bus 71181	: V=0.9983662, theta=-75.115931 -> V=1.0, theta=0.0
% INFO    : Bus 71182	: V=0.9984074, theta=-75.082396 -> V=1.0, theta=0.0
% INFO    : Bus 71183	: V=1.0009976, theta=-75.067862 -> V=1.0, theta=0.0
% INFO    : Bus 71184	: V=1.0012025, theta=-75.0503 -> V=1.0, theta=0.0
% INFO    : Bus 71185	: V=1.0091004, theta=-74.539438 -> V=1.0, theta=0.0
% INFO    : Bus 71186	: V=1.0093303, theta=-74.505375 -> V=1.0, theta=0.0
% INFO    : Bus 71187	: V=1.009582, theta=-74.472607 -> V=1.0, theta=0.0
% INFO    : Bus 71188	: V=0.9981038, theta=-75.281796 -> V=1.0, theta=0.0
% INFO    : Bus 71189	: V=0.99942, theta=-75.279486 -> V=1.0, theta=0.0
% INFO    : Bus 71190	: V=0.9995753, theta=-75.352759 -> V=1.0, theta=0.0
% INFO    : Bus 71191	: V=1.0034621, theta=-74.829183 -> V=1.0, theta=0.0
% INFO    : Bus 71192	: V=1.0018065, theta=-75.054851 -> V=1.0, theta=0.0
% INFO    : Bus 71193	: V=0.9898393, theta=-75.768613 -> V=1.0, theta=0.0
% INFO    : Bus 71194	: V=0.9915556, theta=-75.779455 -> V=1.0, theta=0.0
% INFO    : Bus 71195	: V=0.9911409, theta=-75.781116 -> V=1.0, theta=0.0
% INFO    : Bus 71196	: V=0.9967476, theta=-75.775438 -> V=1.0, theta=0.0
% INFO    : Bus 71197	: V=0.9971874, theta=-75.773193 -> V=1.0, theta=0.0
% INFO    : Bus 71198	: V=1.000725, theta=-75.185434 -> V=1.0, theta=0.0
% INFO    : Bus 71199	: V=1.0010874, theta=-75.136828 -> V=1.0, theta=0.0
% INFO    : Bus 71200	: V=0.9892166, theta=-75.76499 -> V=1.0, theta=0.0
% INFO    : Bus 71201	: V=0.9886838, theta=-75.701617 -> V=1.0, theta=0.0
% INFO    : Bus 71202	: V=0.9978968, theta=-75.599091 -> V=1.0, theta=0.0
% INFO    : Bus 71203	: V=0.9967259, theta=-75.869412 -> V=1.0, theta=0.0
% INFO    : Bus 71204	: V=0.9962831, theta=-75.876481 -> V=1.0, theta=0.0
% INFO    : Bus 71205	: V=0.9988523, theta=-76.260776 -> V=1.0, theta=0.0
% INFO    : Bus 71206	: V=1.0059512, theta=-75.952474 -> V=1.0, theta=0.0
% INFO    : Bus 71207	: V=0.9967974, theta=-76.004573 -> V=1.0, theta=0.0
% INFO    : Bus 71208	: V=0.9963728, theta=-75.872162 -> V=1.0, theta=0.0
% INFO    : Bus 71209	: V=1.0061937, theta=-76.154973 -> V=1.0, theta=0.0
% INFO    : Bus 71210	: V=1.0066081, theta=-76.058119 -> V=1.0, theta=0.0
% INFO    : Bus 71211	: V=1.0049472, theta=-75.96081 -> V=1.0, theta=0.0
% INFO    : Bus 71212	: V=1.0050591, theta=-75.958896 -> V=1.0, theta=0.0
% INFO    : Bus 71213	: V=0.9968525, theta=-76.002299 -> V=1.0, theta=0.0
% INFO    : Bus 71214	: V=0.9971367, theta=-75.995493 -> V=1.0, theta=0.0
% INFO    : Bus 71215	: V=1.0100813, theta=-74.348475 -> V=1.0, theta=0.0
% INFO    : Bus 71216	: V=0.9994244, theta=-75.644881 -> V=1.0, theta=0.0
% INFO    : Bus 71217	: V=1.0278135, theta=-71.790804 -> V=1.0, theta=0.0
% INFO    : Bus 71218	: V=1.0006232, theta=-75.443273 -> V=1.0, theta=0.0
% INFO    : Bus 71219	: V=1.0006332, theta=-75.328113 -> V=1.0, theta=0.0
% INFO    : Bus 71220	: V=0.994132, theta=-75.945635 -> V=1.0, theta=0.0
% INFO    : Bus 71221	: V=0.9945276, theta=-75.867941 -> V=1.0, theta=0.0
% INFO    : Bus 71222	: V=1.0002377, theta=-75.174768 -> V=1.0, theta=0.0
% INFO    : Bus 71223	: V=0.9994633, theta=-75.314182 -> V=1.0, theta=0.0
% INFO    : Bus 71224	: V=1.0000236, theta=-75.293927 -> V=1.0, theta=0.0
% INFO    : Bus 71225	: V=0.9935413, theta=-75.988167 -> V=1.0, theta=0.0
% INFO    : Bus 71226	: V=0.9975843, theta=-75.973663 -> V=1.0, theta=0.0
% INFO    : Bus 71227	: V=0.9962096, theta=-76.048185 -> V=1.0, theta=0.0
% INFO    : Bus 71228	: V=0.9949019, theta=-76.070813 -> V=1.0, theta=0.0
% INFO    : Bus 71229	: V=0.997148, theta=-76.092564 -> V=1.0, theta=0.0
% INFO    : Bus 71230	: V=0.997483, theta=-76.087709 -> V=1.0, theta=0.0
% INFO    : Bus 71231	: V=0.9974135, theta=-76.236006 -> V=1.0, theta=0.0
% INFO    : Bus 71232	: V=0.9966102, theta=-76.166061 -> V=1.0, theta=0.0
% INFO    : Bus 71233	: V=0.9968784, theta=-76.164626 -> V=1.0, theta=0.0
% INFO    : Bus 71234	: V=1.0093027, theta=-74.659489 -> V=1.0, theta=0.0
% INFO    : Bus 71235	: V=1.0056093, theta=-76.45527 -> V=1.0, theta=0.0
% INFO    : Bus 71236	: V=1.0054504, theta=-76.363061 -> V=1.0, theta=0.0
% INFO    : Bus 71237	: V=1.0056038, theta=-76.295231 -> V=1.0, theta=0.0
% INFO    : Bus 71238	: V=0.9962108, theta=-76.274818 -> V=1.0, theta=0.0
% INFO    : Bus 71239	: V=0.9957665, theta=-76.282446 -> V=1.0, theta=0.0
% INFO    : Bus 71240	: V=1.0013035, theta=-76.150924 -> V=1.0, theta=0.0
% INFO    : Bus 71241	: V=1.0071127, theta=-76.339028 -> V=1.0, theta=0.0
% INFO    : Bus 71242	: V=1.0068947, theta=-76.332809 -> V=1.0, theta=0.0
% INFO    : Bus 71243	: V=1.0028693, theta=-77.107941 -> V=1.0, theta=0.0
% INFO    : Bus 71244	: V=1.0017285, theta=-77.026784 -> V=1.0, theta=0.0
% INFO    : Bus 71245	: V=1.0028447, theta=-76.948311 -> V=1.0, theta=0.0
% INFO    : Bus 71246	: V=1.029891, theta=-71.515523 -> V=1.0, theta=0.0
% INFO    : Bus 71247	: V=0.9932145, theta=-77.137617 -> V=1.0, theta=0.0
% INFO    : Bus 71248	: V=0.9999194, theta=-77.101362 -> V=1.0, theta=0.0
% INFO    : Bus 71249	: V=1.0109198, theta=-75.813862 -> V=1.0, theta=0.0
% INFO    : Bus 71250	: V=0.9947855, theta=-76.911418 -> V=1.0, theta=0.0
% INFO    : Bus 71251	: V=0.9943451, theta=-76.910288 -> V=1.0, theta=0.0
% INFO    : Bus 71252	: V=1.0011639, theta=-77.402158 -> V=1.0, theta=0.0
% INFO    : Bus 71253	: V=1.0024312, theta=-77.216773 -> V=1.0, theta=0.0
% INFO    : Bus 71254	: V=1.0027978, theta=-76.97468 -> V=1.0, theta=0.0
% INFO    : Bus 71255	: V=1.0025811, theta=-76.974081 -> V=1.0, theta=0.0
% INFO    : Bus 71256	: V=0.9972822, theta=-77.225793 -> V=1.0, theta=0.0
% INFO    : Bus 71257	: V=0.992202, theta=-77.149149 -> V=1.0, theta=0.0
% INFO    : Bus 71258	: V=0.9923573, theta=-77.144896 -> V=1.0, theta=0.0
% INFO    : Bus 71259	: V=0.9941642, theta=-77.478282 -> V=1.0, theta=0.0
% INFO    : Bus 71260	: V=0.996675, theta=-77.285071 -> V=1.0, theta=0.0
% INFO    : Bus 71261	: V=0.997418, theta=-77.228009 -> V=1.0, theta=0.0
% INFO    : Bus 71262	: V=0.9941714, theta=-77.309628 -> V=1.0, theta=0.0
% INFO    : Bus 71263	: V=0.9878373, theta=-77.556347 -> V=1.0, theta=0.0
% INFO    : Bus 71264	: V=0.9889786, theta=-77.546631 -> V=1.0, theta=0.0
% INFO    : Bus 71265	: V=0.9959267, theta=-77.343473 -> V=1.0, theta=0.0
% INFO    : Bus 71266	: V=0.9940884, theta=-77.417792 -> V=1.0, theta=0.0
% INFO    : Bus 71267	: V=0.9887526, theta=-77.839867 -> V=1.0, theta=0.0
% INFO    : Bus 71268	: V=0.9876551, theta=-77.792296 -> V=1.0, theta=0.0
% INFO    : Bus 71269	: V=0.9894676, theta=-77.787424 -> V=1.0, theta=0.0
% INFO    : Bus 71270	: V=0.9944432, theta=-77.40805 -> V=1.0, theta=0.0
% INFO    : Bus 71271	: V=0.9923872, theta=-76.293109 -> V=1.0, theta=0.0
% INFO    : Bus 71272	: V=0.9843359, theta=-83.088362 -> V=1.0, theta=0.0
% INFO    : Bus 71273	: V=0.9826992, theta=-83.098279 -> V=1.0, theta=0.0
% INFO    : Bus 71274	: V=0.9797316, theta=-81.636635 -> V=1.0, theta=0.0
% INFO    : Bus 71275	: V=0.982529, theta=-81.435958 -> V=1.0, theta=0.0
% INFO    : Bus 71276	: V=0.9986957, theta=-88.891603 -> V=1.0, theta=0.0
% INFO    : Bus 71277	: V=1.0010022, theta=-91.334108 -> V=1.0, theta=0.0
% INFO    : Bus 71278	: V=1.0008706, theta=-91.333617 -> V=1.0, theta=0.0
% INFO    : Bus 71279	: V=1.0018647, theta=-92.699294 -> V=1.0, theta=0.0
% INFO    : Bus 71280	: V=0.9997981, theta=-94.425537 -> V=1.0, theta=0.0
% INFO    : Bus 71281	: V=1.0001868, theta=-92.761444 -> V=1.0, theta=0.0
% INFO    : Bus 71282	: V=1.0024295, theta=-95.532682 -> V=1.0, theta=0.0
% INFO    : Bus 71283	: V=1.0021457, theta=-96.056454 -> V=1.0, theta=0.0
% INFO    : Bus 71284	: V=1.0019921, theta=-96.160193 -> V=1.0, theta=0.0
% INFO    : Bus 71285	: V=1.001822, theta=-96.366591 -> V=1.0, theta=0.0
% INFO    : Bus 71286	: V=1.0012569, theta=-96.387795 -> V=1.0, theta=0.0
% INFO    : Bus 71287	: V=1.0026921, theta=-97.825061 -> V=1.0, theta=0.0
% INFO    : Bus 71288	: V=1.0021374, theta=-97.750759 -> V=1.0, theta=0.0
% INFO    : Bus 71289	: V=1.0044821, theta=-97.949445 -> V=1.0, theta=0.0
% INFO    : Bus 71290	: V=1.0048601, theta=-97.934096 -> V=1.0, theta=0.0
% INFO    : Bus 71291	: V=1.004345, theta=-97.994748 -> V=1.0, theta=0.0
% INFO    : Bus 71292	: V=1.0034647, theta=-97.889557 -> V=1.0, theta=0.0
% INFO    : Bus 71293	: V=1.0019061, theta=-97.624941 -> V=1.0, theta=0.0
% INFO    : Bus 71294	: V=1.0024758, theta=-98.068134 -> V=1.0, theta=0.0
% INFO    : Bus 71295	: V=1.0044777, theta=-97.768683 -> V=1.0, theta=0.0
% INFO    : Bus 71296	: V=1.0028034, theta=-97.925614 -> V=1.0, theta=0.0
% INFO    : Bus 71297	: V=1.0034935, theta=-97.802601 -> V=1.0, theta=0.0
% INFO    : Bus 71298	: V=1.0054461, theta=-96.413337 -> V=1.0, theta=0.0
% INFO    : Bus 71299	: V=1.005603, theta=-97.145718 -> V=1.0, theta=0.0
% INFO    : Bus 71300	: V=1.00724, theta=-96.426035 -> V=1.0, theta=0.0
% INFO    : Bus 71301	: V=1.0042438, theta=-97.504451 -> V=1.0, theta=0.0
% INFO    : Bus 71302	: V=1.0039863, theta=-97.62672 -> V=1.0, theta=0.0
% INFO    : Bus 71303	: V=1.0077849, theta=-96.196974 -> V=1.0, theta=0.0
% INFO    : Bus 71304	: V=1.0075724, theta=-96.297757 -> V=1.0, theta=0.0
% INFO    : Bus 71305	: V=1.0053235, theta=-97.260804 -> V=1.0, theta=0.0
% INFO    : Bus 71306	: V=1.006282, theta=-97.105206 -> V=1.0, theta=0.0
% INFO    : Bus 71307	: V=1.0033586, theta=-97.538086 -> V=1.0, theta=0.0
% INFO    : Bus 71308	: V=1.0036663, theta=-97.526552 -> V=1.0, theta=0.0
% INFO    : Bus 71309	: V=1.0026586, theta=-97.126709 -> V=1.0, theta=0.0
% INFO    : Bus 71310	: V=1.0033635, theta=-97.087445 -> V=1.0, theta=0.0
% INFO    : Bus 71311	: V=1.0025599, theta=-97.22951 -> V=1.0, theta=0.0
% INFO    : Bus 71312	: V=1.0016751, theta=-97.177347 -> V=1.0, theta=0.0
% INFO    : Bus 71313	: V=1.0025097, theta=-96.405184 -> V=1.0, theta=0.0
% INFO    : Bus 71314	: V=1.0022971, theta=-96.274015 -> V=1.0, theta=0.0
% INFO    : Bus 71315	: V=1.002573, theta=-97.348747 -> V=1.0, theta=0.0
% INFO    : Bus 71316	: V=1.0021124, theta=-97.371237 -> V=1.0, theta=0.0
% INFO    : Bus 71317	: V=1.0036411, theta=-96.901596 -> V=1.0, theta=0.0
% INFO    : Bus 71318	: V=1.0035681, theta=-97.027371 -> V=1.0, theta=0.0
% INFO    : Bus 71319	: V=1.0018995, theta=-96.495733 -> V=1.0, theta=0.0
% INFO    : Bus 71320	: V=1.001049, theta=-95.380964 -> V=1.0, theta=0.0
% INFO    : Bus 71321	: V=1.0036288, theta=-94.399742 -> V=1.0, theta=0.0
% INFO    : Bus 71322	: V=1.0029477, theta=-96.644068 -> V=1.0, theta=0.0
% INFO    : Bus 71323	: V=1.010476, theta=-94.024094 -> V=1.0, theta=0.0
% INFO    : Bus 71324	: V=1.0025996, theta=-95.895189 -> V=1.0, theta=0.0
% INFO    : Bus 71325	: V=1.0024913, theta=-95.925654 -> V=1.0, theta=0.0
% INFO    : Bus 71326	: V=0.9990872, theta=-93.599694 -> V=1.0, theta=0.0
% INFO    : Bus 71327	: V=1.002002, theta=-92.366539 -> V=1.0, theta=0.0
% INFO    : Bus 71328	: V=0.9991968, theta=-92.606248 -> V=1.0, theta=0.0
% INFO    : Bus 71329	: V=1.0012211, theta=-92.565016 -> V=1.0, theta=0.0
% INFO    : Bus 71330	: V=1.0016009, theta=-92.399452 -> V=1.0, theta=0.0
% INFO    : Bus 71331	: V=1.0011973, theta=-90.976768 -> V=1.0, theta=0.0
% INFO    : Bus 71332	: V=1.002694, theta=-91.984335 -> V=1.0, theta=0.0
% INFO    : Bus 71333	: V=1.0012039, theta=-92.120431 -> V=1.0, theta=0.0
% INFO    : Bus 71334	: V=1.0035742, theta=-90.5771 -> V=1.0, theta=0.0
% INFO    : Bus 71335	: V=0.9718942, theta=-82.079646 -> V=1.0, theta=0.0
% INFO    : Bus 71336	: V=1.0070972, theta=-88.716394 -> V=1.0, theta=0.0
% INFO    : Bus 71337	: V=0.9642422, theta=-84.93109 -> V=1.0, theta=0.0
% INFO    : Bus 71338	: V=0.9870597, theta=-83.106857 -> V=1.0, theta=0.0
% INFO    : Bus 71339	: V=0.9877829, theta=-83.074954 -> V=1.0, theta=0.0
% INFO    : Bus 71340	: V=0.9831941, theta=-83.120702 -> V=1.0, theta=0.0
% INFO    : Bus 71341	: V=1.0008757, theta=-97.667764 -> V=1.0, theta=0.0
% INFO    : Bus 71342	: V=1.0068575, theta=-96.598542 -> V=1.0, theta=0.0
% INFO    : Bus 71343	: V=1.0041422, theta=-97.234474 -> V=1.0, theta=0.0
% INFO    : Bus 71344	: V=1.0034206, theta=-97.289714 -> V=1.0, theta=0.0
% INFO    : Bus 71345	: V=1.0045098, theta=-96.898194 -> V=1.0, theta=0.0
% INFO    : Bus 71346	: V=1.0061445, theta=-96.689197 -> V=1.0, theta=0.0
% INFO    : Bus 71347	: V=1.0087363, theta=-96.590783 -> V=1.0, theta=0.0
% INFO    : Bus 71348	: V=1.0038908, theta=-96.019536 -> V=1.0, theta=0.0
% INFO    : Bus 71349	: V=1.0036548, theta=-95.888708 -> V=1.0, theta=0.0
% INFO    : Bus 71350	: V=1.0048162, theta=-95.502311 -> V=1.0, theta=0.0
% INFO    : Bus 71351	: V=1.0013479, theta=-96.106049 -> V=1.0, theta=0.0
% INFO    : Bus 71352	: V=1.0006987, theta=-96.10506 -> V=1.0, theta=0.0
% INFO    : Bus 71353	: V=1.0017027, theta=-96.017576 -> V=1.0, theta=0.0
% INFO    : Bus 71354	: V=1.0009037, theta=-96.072115 -> V=1.0, theta=0.0
% INFO    : Bus 71355	: V=1.0039998, theta=-95.754445 -> V=1.0, theta=0.0
% INFO    : Bus 71356	: V=1.0012752, theta=-76.258601 -> V=1.0, theta=0.0
% INFO    : Bus 71357	: V=0.9856355, theta=-80.395762 -> V=1.0, theta=0.0
% INFO    : Bus 71358	: V=0.9954868, theta=-77.648203 -> V=1.0, theta=0.0
% INFO    : Bus 71359	: V=0.98159, theta=-77.436364 -> V=1.0, theta=0.0
% INFO    : Bus 71360	: V=1.0027762, theta=-77.304065 -> V=1.0, theta=0.0
% INFO    : Bus 71361	: V=1.00558, theta=-74.886244 -> V=1.0, theta=0.0
% INFO    : Bus 71362	: V=1.0076745, theta=-76.734918 -> V=1.0, theta=0.0
% INFO    : Bus 71363	: V=1.0005229, theta=-66.908141 -> V=1.0, theta=0.0
% INFO    : Bus 71364	: V=1.0064902, theta=-65.785668 -> V=1.0, theta=0.0
% INFO    : Bus 71365	: V=1.0072848, theta=-65.699293 -> V=1.0, theta=0.0
% INFO    : Bus 71366	: V=0.9968239, theta=-67.687748 -> V=1.0, theta=0.0
% INFO    : Bus 71367	: V=0.9960909, theta=-67.680293 -> V=1.0, theta=0.0
% INFO    : Bus 71368	: V=0.9960192, theta=-67.690987 -> V=1.0, theta=0.0
% INFO    : Bus 71369	: V=0.9959868, theta=-67.720068 -> V=1.0, theta=0.0
% INFO    : Bus 71370	: V=1.0058641, theta=-65.855353 -> V=1.0, theta=0.0
% INFO    : Bus 71371	: V=0.9965244, theta=-67.632361 -> V=1.0, theta=0.0
% INFO    : Bus 71372	: V=0.9955342, theta=-68.109831 -> V=1.0, theta=0.0
% INFO    : Bus 71373	: V=0.9946091, theta=-68.138407 -> V=1.0, theta=0.0
% INFO    : Bus 71374	: V=0.9952565, theta=-67.892862 -> V=1.0, theta=0.0
% INFO    : Bus 71375	: V=0.993095, theta=-68.384942 -> V=1.0, theta=0.0
% INFO    : Bus 71376	: V=0.995519, theta=-68.096516 -> V=1.0, theta=0.0
% INFO    : Bus 71377	: V=0.9956874, theta=-69.183682 -> V=1.0, theta=0.0
% INFO    : Bus 71378	: V=0.9935743, theta=-68.737841 -> V=1.0, theta=0.0
% INFO    : Bus 71379	: V=0.9933165, theta=-68.96484 -> V=1.0, theta=0.0
% INFO    : Bus 71380	: V=0.994065, theta=-68.373916 -> V=1.0, theta=0.0
% INFO    : Bus 71381	: V=0.9940318, theta=-68.258282 -> V=1.0, theta=0.0
% INFO    : Bus 71382	: V=0.9900013, theta=-69.293571 -> V=1.0, theta=0.0
% INFO    : Bus 71383	: V=0.9906392, theta=-69.224324 -> V=1.0, theta=0.0
% INFO    : Bus 71384	: V=0.991941, theta=-69.096481 -> V=1.0, theta=0.0
% INFO    : Bus 71385	: V=0.9892557, theta=-69.542466 -> V=1.0, theta=0.0
% INFO    : Bus 71386	: V=0.9920799, theta=-69.499068 -> V=1.0, theta=0.0
% INFO    : Bus 71387	: V=0.9892631, theta=-69.808666 -> V=1.0, theta=0.0
% INFO    : Bus 71388	: V=0.9892044, theta=-69.671995 -> V=1.0, theta=0.0
% INFO    : Bus 71389	: V=0.9877336, theta=-69.321382 -> V=1.0, theta=0.0
% INFO    : Bus 71390	: V=0.9893042, theta=-69.797136 -> V=1.0, theta=0.0
% INFO    : Bus 71391	: V=0.9895882, theta=-69.730074 -> V=1.0, theta=0.0
% INFO    : Bus 71392	: V=0.988563, theta=-69.327376 -> V=1.0, theta=0.0
% INFO    : Bus 71393	: V=1.0072216, theta=-65.616223 -> V=1.0, theta=0.0
% INFO    : Bus 71394	: V=0.9962159, theta=-68.586967 -> V=1.0, theta=0.0
% INFO    : Bus 71395	: V=0.9970459, theta=-67.859955 -> V=1.0, theta=0.0
% INFO    : Bus 71396	: V=0.9964473, theta=-67.865089 -> V=1.0, theta=0.0
% INFO    : Bus 71397	: V=0.998426, theta=-67.686412 -> V=1.0, theta=0.0
% INFO    : Bus 71398	: V=0.9990387, theta=-67.51702 -> V=1.0, theta=0.0
% INFO    : Bus 71399	: V=1.0045278, theta=-66.190459 -> V=1.0, theta=0.0
% INFO    : Bus 71400	: V=0.9972717, theta=-68.242201 -> V=1.0, theta=0.0
% INFO    : Bus 71401	: V=0.9963208, theta=-68.640857 -> V=1.0, theta=0.0
% INFO    : Bus 71402	: V=0.9947734, theta=-69.353547 -> V=1.0, theta=0.0
% INFO    : Bus 71403	: V=0.9942038, theta=-69.688092 -> V=1.0, theta=0.0
% INFO    : Bus 71404	: V=0.9983179, theta=-69.018121 -> V=1.0, theta=0.0
% INFO    : Bus 71405	: V=1.0014352, theta=-67.013387 -> V=1.0, theta=0.0
% INFO    : Bus 71406	: V=0.9956356, theta=-69.193478 -> V=1.0, theta=0.0
% INFO    : Bus 71407	: V=0.9957697, theta=-69.335345 -> V=1.0, theta=0.0
% INFO    : Bus 71408	: V=0.9967313, theta=-69.781812 -> V=1.0, theta=0.0
% INFO    : Bus 71409	: V=0.989973, theta=-70.75409 -> V=1.0, theta=0.0
% INFO    : Bus 71410	: V=0.991721, theta=-70.511275 -> V=1.0, theta=0.0
% INFO    : Bus 71411	: V=0.9920298, theta=-70.148686 -> V=1.0, theta=0.0
% INFO    : Bus 71412	: V=0.9926517, theta=-70.143953 -> V=1.0, theta=0.0
% INFO    : Bus 71413	: V=1.0006678, theta=-70.604548 -> V=1.0, theta=0.0
% INFO    : Bus 71414	: V=0.9883243, theta=-72.786356 -> V=1.0, theta=0.0
% INFO    : Bus 71415	: V=0.9872752, theta=-72.38892 -> V=1.0, theta=0.0
% INFO    : Bus 71416	: V=0.987102, theta=-72.117776 -> V=1.0, theta=0.0
% INFO    : Bus 71417	: V=0.9874394, theta=-71.644972 -> V=1.0, theta=0.0
% INFO    : Bus 71418	: V=0.9863169, theta=-71.458948 -> V=1.0, theta=0.0
% INFO    : Bus 71419	: V=0.985628, theta=-71.433952 -> V=1.0, theta=0.0
% INFO    : Bus 71420	: V=0.9865376, theta=-71.272787 -> V=1.0, theta=0.0
% INFO    : Bus 71421	: V=0.9874738, theta=-71.11523 -> V=1.0, theta=0.0
% INFO    : Bus 71422	: V=0.9842851, theta=-71.509848 -> V=1.0, theta=0.0
% INFO    : Bus 71423	: V=0.9849055, theta=-71.615982 -> V=1.0, theta=0.0
% INFO    : Bus 71424	: V=0.9854812, theta=-71.529479 -> V=1.0, theta=0.0
% INFO    : Bus 71425	: V=0.9874977, theta=-71.316908 -> V=1.0, theta=0.0
% INFO    : Bus 71426	: V=0.9865031, theta=-71.168625 -> V=1.0, theta=0.0
% INFO    : Bus 71427	: V=0.9859282, theta=-71.01164 -> V=1.0, theta=0.0
% INFO    : Bus 71428	: V=0.9862039, theta=-70.724358 -> V=1.0, theta=0.0
% INFO    : Bus 71429	: V=0.986201, theta=-70.622445 -> V=1.0, theta=0.0
% INFO    : Bus 71430	: V=0.9860871, theta=-70.828906 -> V=1.0, theta=0.0
% INFO    : Bus 71431	: V=0.9861322, theta=-70.8488 -> V=1.0, theta=0.0
% INFO    : Bus 71432	: V=0.9875082, theta=-70.449769 -> V=1.0, theta=0.0
% INFO    : Bus 71433	: V=0.9868245, theta=-70.611094 -> V=1.0, theta=0.0
% INFO    : Bus 71434	: V=0.9865412, theta=-70.612643 -> V=1.0, theta=0.0
% INFO    : Bus 71435	: V=0.9875797, theta=-70.397368 -> V=1.0, theta=0.0
% INFO    : Bus 71436	: V=0.9944338, theta=-69.469185 -> V=1.0, theta=0.0
% INFO    : Bus 71437	: V=0.9955138, theta=-69.366939 -> V=1.0, theta=0.0
% INFO    : Bus 71438	: V=0.9919875, theta=-69.632411 -> V=1.0, theta=0.0
% INFO    : Bus 71439	: V=0.9923065, theta=-69.631612 -> V=1.0, theta=0.0
% INFO    : Bus 71440	: V=0.9935033, theta=-69.558347 -> V=1.0, theta=0.0
% INFO    : Bus 71441	: V=0.989724, theta=-70.01425 -> V=1.0, theta=0.0
% INFO    : Bus 71442	: V=0.9894653, theta=-69.906227 -> V=1.0, theta=0.0
% INFO    : Bus 71443	: V=0.9890001, theta=-69.947845 -> V=1.0, theta=0.0
% INFO    : Bus 71444	: V=0.9895094, theta=-69.75849 -> V=1.0, theta=0.0
% INFO    : Bus 71445	: V=0.9885375, theta=-70.186548 -> V=1.0, theta=0.0
% INFO    : Bus 71446	: V=0.9883091, theta=-70.207372 -> V=1.0, theta=0.0
% INFO    : Bus 71447	: V=0.9876235, theta=-70.246669 -> V=1.0, theta=0.0
% INFO    : Bus 71448	: V=0.9870436, theta=-70.249685 -> V=1.0, theta=0.0
% INFO    : Bus 71449	: V=0.9866607, theta=-70.506348 -> V=1.0, theta=0.0
% INFO    : Bus 71450	: V=0.9872531, theta=-70.421133 -> V=1.0, theta=0.0
% INFO    : Bus 71451	: V=0.9879084, theta=-70.236566 -> V=1.0, theta=0.0
% INFO    : Bus 71452	: V=0.9879546, theta=-70.244222 -> V=1.0, theta=0.0
% INFO    : Bus 71453	: V=0.9948518, theta=-67.828929 -> V=1.0, theta=0.0
% INFO    : Bus 71454	: V=0.9863487, theta=-70.811478 -> V=1.0, theta=0.0
% INFO    : Bus 71455	: V=0.9864196, theta=-70.670054 -> V=1.0, theta=0.0
% INFO    : Bus 71456	: V=0.986678, theta=-70.529635 -> V=1.0, theta=0.0
% INFO    : Bus 71457	: V=0.9916278, theta=-73.480708 -> V=1.0, theta=0.0
% INFO    : Bus 71458	: V=0.9861662, theta=-71.357159 -> V=1.0, theta=0.0
% INFO    : Bus 71459	: V=0.9845605, theta=-71.683548 -> V=1.0, theta=0.0
% INFO    : Bus 71460	: V=0.9844523, theta=-71.759598 -> V=1.0, theta=0.0
% INFO    : Bus 71461	: V=0.9843197, theta=-71.727391 -> V=1.0, theta=0.0
% INFO    : Bus 71462	: V=0.9847813, theta=-71.67393 -> V=1.0, theta=0.0
% INFO    : Bus 71463	: V=0.9837753, theta=-71.811927 -> V=1.0, theta=0.0
% INFO    : Bus 71464	: V=0.9840096, theta=-71.896462 -> V=1.0, theta=0.0
% INFO    : Bus 71465	: V=0.9841773, theta=-71.805978 -> V=1.0, theta=0.0
% INFO    : Bus 71466	: V=0.9844804, theta=-71.636866 -> V=1.0, theta=0.0
% INFO    : Bus 71467	: V=0.9844471, theta=-71.533403 -> V=1.0, theta=0.0
% INFO    : Bus 71468	: V=0.9842802, theta=-71.111996 -> V=1.0, theta=0.0
% INFO    : Bus 71469	: V=0.9839638, theta=-71.196012 -> V=1.0, theta=0.0
% INFO    : Bus 71470	: V=0.9846756, theta=-71.373116 -> V=1.0, theta=0.0
% INFO    : Bus 71471	: V=0.9851301, theta=-71.371871 -> V=1.0, theta=0.0
% INFO    : Bus 71472	: V=0.9921481, theta=-73.580569 -> V=1.0, theta=0.0
% INFO    : Bus 71473	: V=0.9835614, theta=-72.049344 -> V=1.0, theta=0.0
% INFO    : Bus 71474	: V=0.9837643, theta=-72.049734 -> V=1.0, theta=0.0
% INFO    : Bus 71475	: V=0.985527, theta=-70.804044 -> V=1.0, theta=0.0
% INFO    : Bus 71476	: V=0.9887969, theta=-70.189299 -> V=1.0, theta=0.0
% INFO    : Bus 71477	: V=0.9925286, theta=-69.408066 -> V=1.0, theta=0.0
% INFO    : Bus 71478	: V=0.9915278, theta=-73.943119 -> V=1.0, theta=0.0
% INFO    : Bus 71479	: V=0.9917563, theta=-73.764572 -> V=1.0, theta=0.0
% INFO    : Bus 71480	: V=0.9948841, theta=-68.166605 -> V=1.0, theta=0.0
% INFO    : Bus 71481	: V=0.9958307, theta=-68.130877 -> V=1.0, theta=0.0
% INFO    : Bus 71482	: V=0.9970402, theta=-68.024668 -> V=1.0, theta=0.0
% INFO    : Bus 71483	: V=0.9929047, theta=-69.315587 -> V=1.0, theta=0.0
% INFO    : Bus 71484	: V=0.993883, theta=-68.044267 -> V=1.0, theta=0.0
% INFO    : Bus 71485	: V=0.9993924, theta=-67.732704 -> V=1.0, theta=0.0
% INFO    : Bus 71486	: V=1.0008659, theta=-67.518088 -> V=1.0, theta=0.0
% INFO    : Bus 71487	: V=0.9993058, theta=-67.805441 -> V=1.0, theta=0.0
% INFO    : Bus 71488	: V=1.0009367, theta=-67.55444 -> V=1.0, theta=0.0
% INFO    : Bus 71489	: V=0.9986335, theta=-67.861663 -> V=1.0, theta=0.0
% INFO    : Bus 71490	: V=0.9981433, theta=-67.577951 -> V=1.0, theta=0.0
% INFO    : Bus 71491	: V=0.9970159, theta=-67.590027 -> V=1.0, theta=0.0
% INFO    : Bus 71492	: V=0.9968538, theta=-67.591187 -> V=1.0, theta=0.0
% INFO    : Bus 71493	: V=1.0066254, theta=-65.744024 -> V=1.0, theta=0.0
% INFO    : Bus 71494	: V=0.9993786, theta=-66.909136 -> V=1.0, theta=0.0
% INFO    : Bus 71495	: V=1.0012878, theta=-67.687903 -> V=1.0, theta=0.0
% INFO    : Bus 71496	: V=0.9973229, theta=-67.503328 -> V=1.0, theta=0.0
% INFO    : Bus 71497	: V=1.0013249, theta=-67.147863 -> V=1.0, theta=0.0
% INFO    : Bus 71498	: V=1.0003964, theta=-67.680087 -> V=1.0, theta=0.0
% INFO    : Bus 71499	: V=1.0006606, theta=-66.796648 -> V=1.0, theta=0.0
% INFO    : Bus 71500	: V=0.9990669, theta=-65.163981 -> V=1.0, theta=0.0
% INFO    : Bus 71501	: V=1.0028524, theta=-67.239085 -> V=1.0, theta=0.0
% INFO    : Bus 71502	: V=1.0042473, theta=-67.515219 -> V=1.0, theta=0.0
% INFO    : Bus 71503	: V=1.0028342, theta=-67.566451 -> V=1.0, theta=0.0
% INFO    : Bus 71504	: V=1.0030001, theta=-67.558819 -> V=1.0, theta=0.0
% INFO    : Bus 71505	: V=1.002988, theta=-67.534886 -> V=1.0, theta=0.0
% INFO    : Bus 71506	: V=1.0046139, theta=-67.489713 -> V=1.0, theta=0.0
% INFO    : Bus 71507	: V=1.0047936, theta=-67.483014 -> V=1.0, theta=0.0
% INFO    : Bus 71508	: V=1.0030495, theta=-67.489113 -> V=1.0, theta=0.0
% INFO    : Bus 71509	: V=1.003191, theta=-67.410857 -> V=1.0, theta=0.0
% INFO    : Bus 71510	: V=1.0041413, theta=-67.380641 -> V=1.0, theta=0.0
% INFO    : Bus 71511	: V=1.005538, theta=-66.380558 -> V=1.0, theta=0.0
% INFO    : Bus 71512	: V=1.0046229, theta=-67.703365 -> V=1.0, theta=0.0
% INFO    : Bus 71513	: V=1.0031667, theta=-67.620108 -> V=1.0, theta=0.0
% INFO    : Bus 71514	: V=1.0056659, theta=-65.707461 -> V=1.0, theta=0.0
% INFO    : Bus 71515	: V=1.0042045, theta=-67.118513 -> V=1.0, theta=0.0
% INFO    : Bus 71516	: V=1.0034857, theta=-67.261233 -> V=1.0, theta=0.0
% INFO    : Bus 71517	: V=1.0034163, theta=-67.275702 -> V=1.0, theta=0.0
% INFO    : Bus 71518	: V=1.0032484, theta=-67.407597 -> V=1.0, theta=0.0
% INFO    : Bus 71519	: V=1.0029854, theta=-67.418294 -> V=1.0, theta=0.0
% INFO    : Bus 71520	: V=1.0028226, theta=-67.604361 -> V=1.0, theta=0.0
% INFO    : Bus 71521	: V=1.0030082, theta=-67.578794 -> V=1.0, theta=0.0
% INFO    : Bus 71522	: V=1.0031443, theta=-67.552313 -> V=1.0, theta=0.0
% INFO    : Bus 71523	: V=1.003151, theta=-67.470302 -> V=1.0, theta=0.0
% INFO    : Bus 71524	: V=1.0028224, theta=-67.289184 -> V=1.0, theta=0.0
% INFO    : Bus 71525	: V=1.0030052, theta=-67.28086 -> V=1.0, theta=0.0
% INFO    : Bus 71526	: V=1.0037376, theta=-67.449318 -> V=1.0, theta=0.0
% INFO    : Bus 71527	: V=1.0034963, theta=-67.424012 -> V=1.0, theta=0.0
% INFO    : Bus 71528	: V=1.0033292, theta=-67.377707 -> V=1.0, theta=0.0
% INFO    : Bus 71529	: V=1.0045376, theta=-66.6265 -> V=1.0, theta=0.0
% INFO    : Bus 71530	: V=1.0047357, theta=-66.665363 -> V=1.0, theta=0.0
% INFO    : Bus 71531	: V=1.0052085, theta=-66.652626 -> V=1.0, theta=0.0
% INFO    : Bus 71532	: V=1.0080172, theta=-65.266034 -> V=1.0, theta=0.0
% INFO    : Bus 71533	: V=1.0024228, theta=-67.22914 -> V=1.0, theta=0.0
% INFO    : Bus 71534	: V=1.0022769, theta=-67.197567 -> V=1.0, theta=0.0
% INFO    : Bus 71535	: V=1.006818, theta=-66.433285 -> V=1.0, theta=0.0
% INFO    : Bus 71536	: V=1.0063543, theta=-65.816081 -> V=1.0, theta=0.0
% INFO    : Bus 71537	: V=1.004724, theta=-66.508069 -> V=1.0, theta=0.0
% INFO    : Bus 71538	: V=1.0027813, theta=-65.983668 -> V=1.0, theta=0.0
% INFO    : Bus 71539	: V=1.0042084, theta=-66.055143 -> V=1.0, theta=0.0
% INFO    : Bus 71540	: V=1.0038848, theta=-66.031676 -> V=1.0, theta=0.0
% INFO    : Bus 71541	: V=1.0018172, theta=-66.369518 -> V=1.0, theta=0.0
% INFO    : Bus 71542	: V=1.0052466, theta=-65.102847 -> V=1.0, theta=0.0
% INFO    : Bus 71543	: V=1.0020821, theta=-66.329348 -> V=1.0, theta=0.0
% INFO    : Bus 71544	: V=1.0014692, theta=-66.354441 -> V=1.0, theta=0.0
% INFO    : Bus 71545	: V=1.0055648, theta=-66.174118 -> V=1.0, theta=0.0
% INFO    : Bus 71546	: V=1.0048989, theta=-64.979578 -> V=1.0, theta=0.0
% INFO    : Bus 71547	: V=1.0026116, theta=-65.029626 -> V=1.0, theta=0.0
% INFO    : Bus 71548	: V=1.0034497, theta=-65.50533 -> V=1.0, theta=0.0
% INFO    : Bus 71549	: V=1.0031454, theta=-65.334538 -> V=1.0, theta=0.0
% INFO    : Bus 71550	: V=1.0066482, theta=-65.542728 -> V=1.0, theta=0.0
% INFO    : Bus 71551	: V=1.004626, theta=-65.508002 -> V=1.0, theta=0.0
% INFO    : Bus 71552	: V=1.0061667, theta=-65.28758 -> V=1.0, theta=0.0
% INFO    : Bus 71553	: V=1.00484, theta=-66.084368 -> V=1.0, theta=0.0
% INFO    : Bus 71554	: V=1.0030785, theta=-66.169784 -> V=1.0, theta=0.0
% INFO    : Bus 71555	: V=1.0018249, theta=-66.147895 -> V=1.0, theta=0.0
% INFO    : Bus 71556	: V=1.0044293, theta=-64.752916 -> V=1.0, theta=0.0
% INFO    : Bus 71557	: V=1.0031827, theta=-65.662697 -> V=1.0, theta=0.0
% INFO    : Bus 71558	: V=1.0032701, theta=-65.558801 -> V=1.0, theta=0.0
% INFO    : Bus 71559	: V=1.0048296, theta=-65.927329 -> V=1.0, theta=0.0
% INFO    : Bus 71560	: V=1.0049685, theta=-65.922101 -> V=1.0, theta=0.0
% INFO    : Bus 71561	: V=1.0034552, theta=-65.956251 -> V=1.0, theta=0.0
% INFO    : Bus 71562	: V=1.00296, theta=-65.97687 -> V=1.0, theta=0.0
% INFO    : Bus 71563	: V=1.0022987, theta=-64.010309 -> V=1.0, theta=0.0
% INFO    : Bus 71564	: V=1.0039901, theta=-64.634939 -> V=1.0, theta=0.0
% INFO    : Bus 71565	: V=1.004163, theta=-66.573572 -> V=1.0, theta=0.0
% INFO    : Bus 71566	: V=1.0046811, theta=-66.460932 -> V=1.0, theta=0.0
% INFO    : Bus 71567	: V=1.0018815, theta=-67.115103 -> V=1.0, theta=0.0
% INFO    : Bus 71568	: V=1.0013373, theta=-67.34984 -> V=1.0, theta=0.0
% INFO    : Bus 71569	: V=1.0018938, theta=-67.314661 -> V=1.0, theta=0.0
% INFO    : Bus 71570	: V=1.0032309, theta=-67.005488 -> V=1.0, theta=0.0
% INFO    : Bus 71571	: V=0.9999464, theta=-68.29822 -> V=1.0, theta=0.0
% INFO    : Bus 71572	: V=0.9988864, theta=-68.064957 -> V=1.0, theta=0.0
% INFO    : Bus 71573	: V=1.0037517, theta=-65.335545 -> V=1.0, theta=0.0
% INFO    : Bus 71574	: V=0.9956775, theta=-68.674713 -> V=1.0, theta=0.0
% INFO    : Bus 71575	: V=1.0005064, theta=-69.072538 -> V=1.0, theta=0.0
% INFO    : Bus 71576	: V=0.9989806, theta=-68.188201 -> V=1.0, theta=0.0
% INFO    : Bus 71577	: V=0.9993542, theta=-68.260361 -> V=1.0, theta=0.0
% INFO    : Bus 71578	: V=1.0039072, theta=-64.332511 -> V=1.0, theta=0.0
% INFO    : Bus 71579	: V=1.0011521, theta=-65.773439 -> V=1.0, theta=0.0
% INFO    : Bus 71580	: V=1.003751, theta=-64.342151 -> V=1.0, theta=0.0
% INFO    : Bus 71581	: V=0.9995069, theta=-65.603921 -> V=1.0, theta=0.0
% INFO    : Bus 71582	: V=0.9985231, theta=-65.71526 -> V=1.0, theta=0.0
% INFO    : Bus 71583	: V=0.999566, theta=-65.455788 -> V=1.0, theta=0.0
% INFO    : Bus 71584	: V=0.9992021, theta=-65.417593 -> V=1.0, theta=0.0
% INFO    : Bus 71585	: V=0.9996189, theta=-65.992728 -> V=1.0, theta=0.0
% INFO    : Bus 71586	: V=1.0000459, theta=-65.912258 -> V=1.0, theta=0.0
% INFO    : Bus 71587	: V=1.000865, theta=-65.852037 -> V=1.0, theta=0.0
% INFO    : Bus 71588	: V=1.0035914, theta=-65.288158 -> V=1.0, theta=0.0
% INFO    : Bus 71589	: V=0.9957623, theta=-65.797764 -> V=1.0, theta=0.0
% INFO    : Bus 71590	: V=1.0025441, theta=-65.398425 -> V=1.0, theta=0.0
% INFO    : Bus 71591	: V=1.0018286, theta=-65.454388 -> V=1.0, theta=0.0
% INFO    : Bus 71592	: V=0.9989849, theta=-65.74612 -> V=1.0, theta=0.0
% INFO    : Bus 71593	: V=0.9956387, theta=-65.769969 -> V=1.0, theta=0.0
% INFO    : Bus 71594	: V=1.0005098, theta=-65.596957 -> V=1.0, theta=0.0
% INFO    : Bus 71595	: V=0.9969506, theta=-65.629922 -> V=1.0, theta=0.0
% INFO    : Bus 71596	: V=0.9987374, theta=-65.333811 -> V=1.0, theta=0.0
% INFO    : Bus 71597	: V=0.9976874, theta=-65.381971 -> V=1.0, theta=0.0
% INFO    : Bus 71598	: V=1.0014395, theta=-64.826958 -> V=1.0, theta=0.0
% INFO    : Bus 71599	: V=0.9972438, theta=-65.617901 -> V=1.0, theta=0.0
% INFO    : Bus 71600	: V=0.990323, theta=-65.908912 -> V=1.0, theta=0.0
% INFO    : Bus 71601	: V=0.9973137, theta=-65.777534 -> V=1.0, theta=0.0
% INFO    : Bus 71602	: V=0.9969481, theta=-65.769867 -> V=1.0, theta=0.0
% INFO    : Bus 71603	: V=0.9968263, theta=-65.720994 -> V=1.0, theta=0.0
% INFO    : Bus 71604	: V=0.9998514, theta=-65.46485 -> V=1.0, theta=0.0
% INFO    : Bus 71605	: V=0.997768, theta=-65.762154 -> V=1.0, theta=0.0
% INFO    : Bus 71606	: V=0.9982976, theta=-66.384037 -> V=1.0, theta=0.0
% INFO    : Bus 71607	: V=0.9989533, theta=-66.359436 -> V=1.0, theta=0.0
% INFO    : Bus 71608	: V=0.9991277, theta=-66.108651 -> V=1.0, theta=0.0
% INFO    : Bus 71609	: V=1.000965, theta=-66.267964 -> V=1.0, theta=0.0
% INFO    : Bus 71610	: V=0.9995297, theta=-66.064798 -> V=1.0, theta=0.0
% INFO    : Bus 71611	: V=1.0021387, theta=-65.688896 -> V=1.0, theta=0.0
% INFO    : Bus 71612	: V=0.9999911, theta=-66.139608 -> V=1.0, theta=0.0
% INFO    : Bus 71613	: V=1.0003393, theta=-65.719603 -> V=1.0, theta=0.0
% INFO    : Bus 71614	: V=1.0064486, theta=-63.575615 -> V=1.0, theta=0.0
% INFO    : Bus 71615	: V=1.0021356, theta=-64.660477 -> V=1.0, theta=0.0
% INFO    : Bus 71616	: V=1.0032392, theta=-64.53572 -> V=1.0, theta=0.0
% INFO    : Bus 71617	: V=1.0041106, theta=-64.345723 -> V=1.0, theta=0.0
% INFO    : Bus 71618	: V=1.0037814, theta=-64.359084 -> V=1.0, theta=0.0
% INFO    : Bus 71619	: V=1.0049705, theta=-64.144287 -> V=1.0, theta=0.0
% INFO    : Bus 71620	: V=1.0052576, theta=-63.949514 -> V=1.0, theta=0.0
% INFO    : Bus 71621	: V=1.003674, theta=-64.442083 -> V=1.0, theta=0.0
% INFO    : Bus 71622	: V=1.0042714, theta=-64.290389 -> V=1.0, theta=0.0
% INFO    : Bus 71623	: V=1.0045272, theta=-64.233479 -> V=1.0, theta=0.0
% INFO    : Bus 71624	: V=1.0043604, theta=-64.240351 -> V=1.0, theta=0.0
% INFO    : Bus 71625	: V=1.0034162, theta=-64.50557 -> V=1.0, theta=0.0
% INFO    : Bus 71626	: V=1.0041295, theta=-64.419053 -> V=1.0, theta=0.0
% INFO    : Bus 71627	: V=1.003184, theta=-64.463531 -> V=1.0, theta=0.0
% INFO    : Bus 71628	: V=1.0029577, theta=-64.472033 -> V=1.0, theta=0.0
% INFO    : Bus 71629	: V=1.0022838, theta=-64.647403 -> V=1.0, theta=0.0
% INFO    : Bus 71630	: V=1.0025518, theta=-64.637264 -> V=1.0, theta=0.0
% INFO    : Bus 71631	: V=1.0023527, theta=-64.698361 -> V=1.0, theta=0.0
% INFO    : Bus 71632	: V=1.0069213, theta=-64.25888 -> V=1.0, theta=0.0
% INFO    : Bus 71633	: V=1.0023288, theta=-64.64564 -> V=1.0, theta=0.0
% INFO    : Bus 71634	: V=1.0013374, theta=-64.692677 -> V=1.0, theta=0.0
% INFO    : Bus 71635	: V=1.0023037, theta=-64.563549 -> V=1.0, theta=0.0
% INFO    : Bus 71636	: V=1.0034819, theta=-64.065908 -> V=1.0, theta=0.0
% INFO    : Bus 71637	: V=1.0056578, theta=-63.730793 -> V=1.0, theta=0.0
% INFO    : Bus 71638	: V=1.0037617, theta=-63.965765 -> V=1.0, theta=0.0
% INFO    : Bus 71639	: V=1.0046582, theta=-63.886051 -> V=1.0, theta=0.0
% INFO    : Bus 71640	: V=1.0030317, theta=-63.849102 -> V=1.0, theta=0.0
% INFO    : Bus 71641	: V=1.0041917, theta=-63.785786 -> V=1.0, theta=0.0
% INFO    : Bus 71642	: V=1.0037351, theta=-63.802834 -> V=1.0, theta=0.0
% INFO    : Bus 71643	: V=1.0081779, theta=-62.929375 -> V=1.0, theta=0.0
% INFO    : Bus 71644	: V=1.0055528, theta=-63.728429 -> V=1.0, theta=0.0
% INFO    : Bus 71645	: V=1.0059217, theta=-63.562399 -> V=1.0, theta=0.0
% INFO    : Bus 71646	: V=1.0026639, theta=-65.003528 -> V=1.0, theta=0.0
% INFO    : Bus 71647	: V=1.0067612, theta=-63.191881 -> V=1.0, theta=0.0
% INFO    : Bus 71648	: V=1.0085609, theta=-62.659139 -> V=1.0, theta=0.0
% INFO    : Bus 71649	: V=1.0054192, theta=-63.580361 -> V=1.0, theta=0.0
% INFO    : Bus 71650	: V=1.0041638, theta=-64.174437 -> V=1.0, theta=0.0
% INFO    : Bus 71651	: V=1.0015215, theta=-62.764109 -> V=1.0, theta=0.0
% INFO    : Bus 71652	: V=1.0159198, theta=-58.443317 -> V=1.0, theta=0.0
% INFO    : Bus 71653	: V=1.0052569, theta=-63.587624 -> V=1.0, theta=0.0
% INFO    : Bus 71654	: V=1.0063524, theta=-62.083737 -> V=1.0, theta=0.0
% INFO    : Bus 71655	: V=1.0054827, theta=-62.391484 -> V=1.0, theta=0.0
% INFO    : Bus 71656	: V=1.005948, theta=-62.204508 -> V=1.0, theta=0.0
% INFO    : Bus 71657	: V=1.0056835, theta=-64.822543 -> V=1.0, theta=0.0
% INFO    : Bus 71658	: V=1.0001429, theta=-65.111318 -> V=1.0, theta=0.0
% INFO    : Bus 71659	: V=1.0054121, theta=-62.408384 -> V=1.0, theta=0.0
% INFO    : Bus 71660	: V=1.0048251, theta=-62.605887 -> V=1.0, theta=0.0
% INFO    : Bus 71661	: V=1.009045, theta=-60.478192 -> V=1.0, theta=0.0
% INFO    : Bus 71662	: V=1.0089557, theta=-60.481802 -> V=1.0, theta=0.0
% INFO    : Bus 71663	: V=1.0071477, theta=-61.582126 -> V=1.0, theta=0.0
% INFO    : Bus 71664	: V=1.0108583, theta=-61.862322 -> V=1.0, theta=0.0
% INFO    : Bus 71665	: V=1.0139802, theta=-58.722406 -> V=1.0, theta=0.0
% INFO    : Bus 71666	: V=1.0094285, theta=-60.462434 -> V=1.0, theta=0.0
% INFO    : Bus 71667	: V=1.01372, theta=-58.971324 -> V=1.0, theta=0.0
% INFO    : Bus 71668	: V=1.0145128, theta=-54.527606 -> V=1.0, theta=0.0
% INFO    : Bus 71669	: V=1.0114546, theta=-59.365885 -> V=1.0, theta=0.0
% INFO    : Bus 71670	: V=1.0145829, theta=-57.769309 -> V=1.0, theta=0.0
% INFO    : Bus 71671	: V=1.0233665, theta=-54.34383 -> V=1.0, theta=0.0
% INFO    : Bus 71672	: V=1.0207702, theta=-53.452081 -> V=1.0, theta=0.0
% INFO    : Bus 71673	: V=1.0195783, theta=-53.594863 -> V=1.0, theta=0.0
% INFO    : Bus 71674	: V=1.0195892, theta=-53.711343 -> V=1.0, theta=0.0
% INFO    : Bus 71675	: V=1.0199898, theta=-53.483519 -> V=1.0, theta=0.0
% INFO    : Bus 71676	: V=1.0208397, theta=-53.790004 -> V=1.0, theta=0.0
% INFO    : Bus 71677	: V=1.0211594, theta=-53.368425 -> V=1.0, theta=0.0
% INFO    : Bus 71678	: V=1.0191376, theta=-53.664524 -> V=1.0, theta=0.0
% INFO    : Bus 71679	: V=1.0221033, theta=-54.422837 -> V=1.0, theta=0.0
% INFO    : Bus 71680	: V=1.0137205, theta=-54.643655 -> V=1.0, theta=0.0
% INFO    : Bus 71681	: V=1.018, theta=-53.847834 -> V=1.0, theta=0.0
% INFO    : Bus 71682	: V=1.0223498, theta=-54.28161 -> V=1.0, theta=0.0
% INFO    : Bus 71683	: V=1.0227923, theta=-54.131665 -> V=1.0, theta=0.0
% INFO    : Bus 71684	: V=1.0222359, theta=-53.811224 -> V=1.0, theta=0.0
% INFO    : Bus 71685	: V=1.0190027, theta=-55.971881 -> V=1.0, theta=0.0
% INFO    : Bus 71686	: V=1.021657, theta=-54.35164 -> V=1.0, theta=0.0
% INFO    : Bus 71687	: V=1.0226921, theta=-54.319371 -> V=1.0, theta=0.0
% INFO    : Bus 71688	: V=1.0224829, theta=-54.202302 -> V=1.0, theta=0.0
% INFO    : Bus 71689	: V=1.0206647, theta=-54.534104 -> V=1.0, theta=0.0
% INFO    : Bus 71690	: V=1.0207699, theta=-54.529858 -> V=1.0, theta=0.0
% INFO    : Bus 71691	: V=1.0201627, theta=-54.518412 -> V=1.0, theta=0.0
% INFO    : Bus 71692	: V=1.021578, theta=-53.743825 -> V=1.0, theta=0.0
% INFO    : Bus 71693	: V=1.0239349, theta=-54.429466 -> V=1.0, theta=0.0
% INFO    : Bus 71694	: V=1.0210108, theta=-53.977293 -> V=1.0, theta=0.0
% INFO    : Bus 71695	: V=1.0237588, theta=-54.42525 -> V=1.0, theta=0.0
% INFO    : Bus 71696	: V=1.023143, theta=-54.413206 -> V=1.0, theta=0.0
% INFO    : Bus 71697	: V=1.0225042, theta=-54.359686 -> V=1.0, theta=0.0
% INFO    : Bus 71698	: V=1.0222258, theta=-54.317658 -> V=1.0, theta=0.0
% INFO    : Bus 71699	: V=1.0209902, theta=-54.365631 -> V=1.0, theta=0.0
% INFO    : Bus 71700	: V=1.022821, theta=-54.39131 -> V=1.0, theta=0.0
% INFO    : Bus 71701	: V=1.021192, theta=-54.377116 -> V=1.0, theta=0.0
% INFO    : Bus 71702	: V=1.0238924, theta=-54.554262 -> V=1.0, theta=0.0
% INFO    : Bus 71703	: V=1.0240908, theta=-54.545497 -> V=1.0, theta=0.0
% INFO    : Bus 71704	: V=1.0245519, theta=-54.528609 -> V=1.0, theta=0.0
% INFO    : Bus 71705	: V=1.0250166, theta=-54.497836 -> V=1.0, theta=0.0
% INFO    : Bus 71706	: V=1.020943, theta=-54.125168 -> V=1.0, theta=0.0
% INFO    : Bus 71707	: V=1.0208961, theta=-54.233392 -> V=1.0, theta=0.0
% INFO    : Bus 71708	: V=1.021585, theta=-54.34665 -> V=1.0, theta=0.0
% INFO    : Bus 71709	: V=1.0201322, theta=-54.400145 -> V=1.0, theta=0.0
% INFO    : Bus 71710	: V=1.0241123, theta=-54.531195 -> V=1.0, theta=0.0
% INFO    : Bus 71711	: V=1.0239164, theta=-54.539031 -> V=1.0, theta=0.0
% INFO    : Bus 71712	: V=1.0214076, theta=-53.429304 -> V=1.0, theta=0.0
% INFO    : Bus 71713	: V=1.0215503, theta=-54.453293 -> V=1.0, theta=0.0
% INFO    : Bus 71714	: V=1.0240485, theta=-54.509708 -> V=1.0, theta=0.0
% INFO    : Bus 71715	: V=1.016467, theta=-53.806555 -> V=1.0, theta=0.0
% INFO    : Bus 71716	: V=1.0167719, theta=-53.795291 -> V=1.0, theta=0.0
% INFO    : Bus 71717	: V=1.0222429, theta=-54.569249 -> V=1.0, theta=0.0
% INFO    : Bus 71718	: V=1.0226693, theta=-54.561377 -> V=1.0, theta=0.0
% INFO    : Bus 71719	: V=1.0227609, theta=-54.560587 -> V=1.0, theta=0.0
% INFO    : Bus 71720	: V=1.023386, theta=-54.53541 -> V=1.0, theta=0.0
% INFO    : Bus 71721	: V=1.0230439, theta=-54.549821 -> V=1.0, theta=0.0
% INFO    : Bus 71722	: V=1.0238319, theta=-54.517644 -> V=1.0, theta=0.0
% INFO    : Bus 71723	: V=1.0180583, theta=-53.728731 -> V=1.0, theta=0.0
% INFO    : Bus 71724	: V=1.0192242, theta=-53.621485 -> V=1.0, theta=0.0
% INFO    : Bus 71725	: V=1.0217042, theta=-54.111606 -> V=1.0, theta=0.0
% INFO    : Bus 71726	: V=1.0228879, theta=-54.32136 -> V=1.0, theta=0.0
% INFO    : Bus 71727	: V=1.0206989, theta=-54.577061 -> V=1.0, theta=0.0
% INFO    : Bus 71728	: V=1.0161747, theta=-53.817622 -> V=1.0, theta=0.0
% INFO    : Bus 71729	: V=1.022692, theta=-52.777147 -> V=1.0, theta=0.0
% INFO    : Bus 71730	: V=1.0210315, theta=-52.824701 -> V=1.0, theta=0.0
% INFO    : Bus 71731	: V=1.0214132, theta=-53.053515 -> V=1.0, theta=0.0
% INFO    : Bus 71732	: V=1.0212701, theta=-53.213167 -> V=1.0, theta=0.0
% INFO    : Bus 71733	: V=1.0210607, theta=-53.643777 -> V=1.0, theta=0.0
% INFO    : Bus 71734	: V=1.0211907, theta=-53.390964 -> V=1.0, theta=0.0
% INFO    : Bus 71735	: V=1.0207073, theta=-53.053974 -> V=1.0, theta=0.0
% INFO    : Bus 71736	: V=1.0214298, theta=-52.907088 -> V=1.0, theta=0.0
% INFO    : Bus 71737	: V=1.0199142, theta=-51.775529 -> V=1.0, theta=0.0
% INFO    : Bus 71738	: V=1.0214662, theta=-52.826186 -> V=1.0, theta=0.0
% INFO    : Bus 71739	: V=1.0210041, theta=-51.770163 -> V=1.0, theta=0.0
% INFO    : Bus 71740	: V=1.0169717, theta=-52.878644 -> V=1.0, theta=0.0
% INFO    : Bus 71741	: V=1.0208694, theta=-53.559351 -> V=1.0, theta=0.0
% INFO    : Bus 71742	: V=1.0208974, theta=-52.699627 -> V=1.0, theta=0.0
% INFO    : Bus 71743	: V=1.0206498, theta=-52.47853 -> V=1.0, theta=0.0
% INFO    : Bus 71744	: V=1.0204839, theta=-52.680574 -> V=1.0, theta=0.0
% INFO    : Bus 71745	: V=1.0216243, theta=-52.444108 -> V=1.0, theta=0.0
% INFO    : Bus 71746	: V=1.0220935, theta=-52.801258 -> V=1.0, theta=0.0
% INFO    : Bus 71747	: V=1.0000976, theta=-41.196173 -> V=1.0, theta=0.0
% INFO    : Bus 71748	: V=1.0235429, theta=-45.490217 -> V=1.0, theta=0.0
% INFO    : Bus 71749	: V=1.0199692, theta=-52.2049 -> V=1.0, theta=0.0
% INFO    : Bus 71750	: V=1.0189916, theta=-52.242234 -> V=1.0, theta=0.0
% INFO    : Bus 71751	: V=1.0031584, theta=-48.262155 -> V=1.0, theta=0.0
% INFO    : Bus 71752	: V=1.0059413, theta=-48.907658 -> V=1.0, theta=0.0
% INFO    : Bus 71753	: V=1.0189796, theta=-50.854389 -> V=1.0, theta=0.0
% INFO    : Bus 71754	: V=1.0191297, theta=-50.969117 -> V=1.0, theta=0.0
% INFO    : Bus 71755	: V=1.0192621, theta=-50.750055 -> V=1.0, theta=0.0
% INFO    : Bus 71756	: V=1.0204432, theta=-51.202332 -> V=1.0, theta=0.0
% INFO    : Bus 71757	: V=1.0052349, theta=-22.533761 -> V=1.0, theta=0.0
% INFO    : Bus 71758	: V=0.9949631, theta=-22.556001 -> V=1.0, theta=0.0
% INFO    : Bus 71759	: V=0.9949756, theta=-22.639825 -> V=1.0, theta=0.0
% INFO    : Bus 71760	: V=0.994827, theta=-22.602323 -> V=1.0, theta=0.0
% INFO    : Bus 71761	: V=0.9972542, theta=-22.304332 -> V=1.0, theta=0.0
% INFO    : Bus 71762	: V=1.0041286, theta=-68.12472 -> V=1.0, theta=0.0
% INFO    : Bus 71763	: V=1.0033709, theta=-67.256218 -> V=1.0, theta=0.0
% INFO    : Bus 71764	: V=0.9999542, theta=-66.401052 -> V=1.0, theta=0.0
% INFO    : Bus 71765	: V=1.001295, theta=-66.442117 -> V=1.0, theta=0.0
% INFO    : Bus 71766	: V=1.0002741, theta=-66.357075 -> V=1.0, theta=0.0
% INFO    : Bus 71767	: V=0.9979501, theta=-67.499428 -> V=1.0, theta=0.0
% INFO    : Bus 71768	: V=0.9847856, theta=-71.473984 -> V=1.0, theta=0.0
% INFO    : Bus 71769	: V=0.9848493, theta=-71.496778 -> V=1.0, theta=0.0
% INFO    : Bus 71770	: V=1.0055348, theta=-65.676963 -> V=1.0, theta=0.0
% INFO    : Bus 71771	: V=1.0026799, theta=-67.401934 -> V=1.0, theta=0.0
% INFO    : Bus 71772	: V=0.9663105, theta=-34.317136 -> V=1.0, theta=0.0
% INFO    : Bus 71773	: V=0.9947827, theta=-22.480586 -> V=1.0, theta=0.0
% INFO    : Bus 71774	: V=1.0245075, theta=-53.841385 -> V=1.0, theta=0.0
% INFO    : Bus 71775	: V=1.0235372, theta=-53.885888 -> V=1.0, theta=0.0
% INFO    : Bus 71776	: V=0.9857652, theta=-71.307684 -> V=1.0, theta=0.0
% INFO    : Bus 71777	: V=0.9867398, theta=-71.731279 -> V=1.0, theta=0.0
% INFO    : Bus 71778	: V=0.9869099, theta=-70.990703 -> V=1.0, theta=0.0
% INFO    : Bus 71779	: V=1.0063844, theta=-66.820788 -> V=1.0, theta=0.0
% INFO    : Bus 71780	: V=1.0032954, theta=-67.115075 -> V=1.0, theta=0.0
% INFO    : Bus 71781	: V=1.0061624, theta=-65.633276 -> V=1.0, theta=0.0
% INFO    : Bus 71782	: V=1.0044816, theta=-67.008341 -> V=1.0, theta=0.0
% INFO    : Bus 71783	: V=1.0039216, theta=-67.148337 -> V=1.0, theta=0.0
% INFO    : Bus 71784	: V=1.0058177, theta=-66.805101 -> V=1.0, theta=0.0
% INFO    : Bus 71785	: V=1.0211575, theta=-52.159039 -> V=1.0, theta=0.0
% INFO    : Bus 71786	: V=1.0209447, theta=-53.415034 -> V=1.0, theta=0.0
% INFO    : Bus 71787	: V=1.0206119, theta=-52.286053 -> V=1.0, theta=0.0
% INFO    : Bus 71788	: V=1.0038095, theta=-64.263083 -> V=1.0, theta=0.0
% INFO    : Bus 71789	: V=0.9994532, theta=-65.830026 -> V=1.0, theta=0.0
% INFO    : Bus 71790	: V=1.0014545, theta=-65.747236 -> V=1.0, theta=0.0
% INFO    : Bus 71791	: V=1.0012559, theta=-65.661868 -> V=1.0, theta=0.0
% INFO    : Bus 71792	: V=1.0012158, theta=-65.810692 -> V=1.0, theta=0.0
% INFO    : Bus 71793	: V=1.0040786, theta=-64.192959 -> V=1.0, theta=0.0
% INFO    : Bus 71794	: V=0.9992929, theta=-65.966137 -> V=1.0, theta=0.0
% INFO    : Bus 71795	: V=1.0049705, theta=-64.523872 -> V=1.0, theta=0.0
% INFO    : Bus 71796	: V=1.002935, theta=-67.683533 -> V=1.0, theta=0.0
% INFO    : Bus 71797	: V=1.0047339, theta=-66.998057 -> V=1.0, theta=0.0
% INFO    : Bus 71798	: V=1.0043012, theta=-64.424554 -> V=1.0, theta=0.0
% INFO    : Bus 71799	: V=1.0069381, theta=-63.514746 -> V=1.0, theta=0.0
% INFO    : Bus 71800	: V=1.0210714, theta=-53.671793 -> V=1.0, theta=0.0
% INFO    : Bus 71801	: V=0.9930739, theta=-20.14673 -> V=1.0, theta=0.0
% INFO    : Bus 71802	: V=1.0204788, theta=-51.754247 -> V=1.0, theta=0.0
% INFO    : Bus 71803	: V=1.0180977, theta=-54.740857 -> V=1.0, theta=0.0
% INFO    : Bus 71804	: V=1.0215238, theta=-54.507408 -> V=1.0, theta=0.0
% INFO    : Bus 71805	: V=1.021682, theta=-54.343653 -> V=1.0, theta=0.0
% INFO    : Bus 71806	: V=1.0204107, theta=-54.546213 -> V=1.0, theta=0.0
% INFO    : Bus 71807	: V=1.0226074, theta=-54.319571 -> V=1.0, theta=0.0
% INFO    : Bus 71808	: V=1.0218515, theta=-53.336607 -> V=1.0, theta=0.0
% INFO    : Bus 71809	: V=1.0234668, theta=-54.300909 -> V=1.0, theta=0.0
% INFO    : Bus 71810	: V=1.0221202, theta=-54.39042 -> V=1.0, theta=0.0
% INFO    : Bus 71811	: V=1.0216201, theta=-53.888962 -> V=1.0, theta=0.0
% INFO    : Bus 71812	: V=1.0201113, theta=-54.662046 -> V=1.0, theta=0.0
% INFO    : Bus 71813	: V=1.0064068, theta=-62.695722 -> V=1.0, theta=0.0
% INFO    : Bus 71814	: V=1.0015319, theta=-67.679685 -> V=1.0, theta=0.0
% INFO    : Bus 71815	: V=0.9848554, theta=-23.131661 -> V=1.0, theta=0.0
% INFO    : Bus 71816	: V=1.0059158, theta=-100.595307 -> V=1.0, theta=0.0
% INFO    : Bus 71817	: V=1.0060537, theta=-100.743022 -> V=1.0, theta=0.0
% INFO    : Bus 71818	: V=1.0056769, theta=-100.815325 -> V=1.0, theta=0.0
% INFO    : Bus 71819	: V=1.0054307, theta=-100.89767 -> V=1.0, theta=0.0
% INFO    : Bus 71820	: V=1.0052533, theta=-100.930426 -> V=1.0, theta=0.0
% INFO    : Bus 71821	: V=1.0052015, theta=-100.953459 -> V=1.0, theta=0.0
% INFO    : Bus 71822	: V=1.0059052, theta=-100.840546 -> V=1.0, theta=0.0
% INFO    : Bus 71823	: V=1.0060353, theta=-100.835708 -> V=1.0, theta=0.0
% INFO    : Bus 71824	: V=1.0054329, theta=-100.93539 -> V=1.0, theta=0.0
% INFO    : Bus 71825	: V=1.0050816, theta=-100.948392 -> V=1.0, theta=0.0
% INFO    : Bus 71826	: V=1.0053186, theta=-100.914104 -> V=1.0, theta=0.0
% INFO    : Bus 71827	: V=1.0053107, theta=-100.910856 -> V=1.0, theta=0.0
% INFO    : Bus 71828	: V=1.0036273, theta=-101.107962 -> V=1.0, theta=0.0
% INFO    : Bus 71829	: V=1.0059558, theta=-100.880198 -> V=1.0, theta=0.0
% INFO    : Bus 71830	: V=1.0061842, theta=-100.934212 -> V=1.0, theta=0.0
% INFO    : Bus 71831	: V=1.0045558, theta=-101.049529 -> V=1.0, theta=0.0
% INFO    : Bus 71832	: V=1.0056349, theta=-100.904836 -> V=1.0, theta=0.0
% INFO    : Bus 71833	: V=1.0057775, theta=-100.918744 -> V=1.0, theta=0.0
% INFO    : Bus 71834	: V=1.0085727, theta=-99.426218 -> V=1.0, theta=0.0
% INFO    : Bus 71835	: V=1.0090193, theta=-100.262314 -> V=1.0, theta=0.0
% INFO    : Bus 71836	: V=1.005427, theta=-100.931763 -> V=1.0, theta=0.0
% INFO    : Bus 71837	: V=1.0086319, theta=-100.523608 -> V=1.0, theta=0.0
% INFO    : Bus 71838	: V=1.0065278, theta=-100.79478 -> V=1.0, theta=0.0
% INFO    : Bus 71839	: V=1.0058502, theta=-100.857988 -> V=1.0, theta=0.0
% INFO    : Bus 71840	: V=1.0042235, theta=-101.061892 -> V=1.0, theta=0.0
% INFO    : Bus 71841	: V=1.0042288, theta=-101.062926 -> V=1.0, theta=0.0
% INFO    : Bus 71842	: V=1.0068136, theta=-100.960928 -> V=1.0, theta=0.0
% INFO    : Bus 71843	: V=1.0073591, theta=-100.96719 -> V=1.0, theta=0.0
% INFO    : Bus 71844	: V=1.0118319, theta=-100.924679 -> V=1.0, theta=0.0
% INFO    : Bus 71845	: V=1.0081221, theta=-100.957157 -> V=1.0, theta=0.0
% INFO    : Bus 71846	: V=1.0092512, theta=-100.932977 -> V=1.0, theta=0.0
% INFO    : Bus 71847	: V=1.0117076, theta=-100.951719 -> V=1.0, theta=0.0
% INFO    : Bus 71848	: V=1.0120909, theta=-100.914209 -> V=1.0, theta=0.0
% INFO    : Bus 71849	: V=1.0081403, theta=-100.533754 -> V=1.0, theta=0.0
% INFO    : Bus 71850	: V=1.0056294, theta=-100.99926 -> V=1.0, theta=0.0
% INFO    : Bus 71851	: V=1.0081271, theta=-100.684669 -> V=1.0, theta=0.0
% INFO    : Bus 71852	: V=1.008342, theta=-100.645165 -> V=1.0, theta=0.0
% INFO    : Bus 71853	: V=1.0079439, theta=-100.764853 -> V=1.0, theta=0.0
% INFO    : Bus 71854	: V=1.0078289, theta=-100.817618 -> V=1.0, theta=0.0
% INFO    : Bus 71855	: V=1.0082424, theta=-100.782518 -> V=1.0, theta=0.0
% INFO    : Bus 71856	: V=1.0082036, theta=-100.491956 -> V=1.0, theta=0.0
% INFO    : Bus 71857	: V=1.006472, theta=-100.967952 -> V=1.0, theta=0.0
% INFO    : Bus 71858	: V=1.005783, theta=-100.908346 -> V=1.0, theta=0.0
% INFO    : Bus 71859	: V=1.0052638, theta=-101.020287 -> V=1.0, theta=0.0
% INFO    : Bus 71860	: V=1.005586, theta=-101.00831 -> V=1.0, theta=0.0
% INFO    : Bus 71861	: V=1.0054304, theta=-100.963558 -> V=1.0, theta=0.0
% INFO    : Bus 71862	: V=1.0052739, theta=-100.994777 -> V=1.0, theta=0.0
% INFO    : Bus 71863	: V=1.0052378, theta=-101.013767 -> V=1.0, theta=0.0
% INFO    : Bus 71864	: V=1.0045405, theta=-101.044945 -> V=1.0, theta=0.0
% INFO    : Bus 71865	: V=1.0046814, theta=-101.039206 -> V=1.0, theta=0.0
% INFO    : Bus 71866	: V=1.0090694, theta=-100.751949 -> V=1.0, theta=0.0
% INFO    : Bus 71867	: V=1.0072985, theta=-100.952867 -> V=1.0, theta=0.0
% INFO    : Bus 71868	: V=1.0080657, theta=-100.921817 -> V=1.0, theta=0.0
% INFO    : Bus 71869	: V=1.0081205, theta=-100.951516 -> V=1.0, theta=0.0
% INFO    : Bus 71870	: V=1.0097089, theta=-100.275251 -> V=1.0, theta=0.0
% INFO    : Bus 71871	: V=1.00653, theta=-100.932941 -> V=1.0, theta=0.0
% INFO    : Bus 71872	: V=1.0071649, theta=-100.878891 -> V=1.0, theta=0.0
% INFO    : Bus 71873	: V=1.0088682, theta=-100.793765 -> V=1.0, theta=0.0
% INFO    : Bus 71874	: V=1.0097239, theta=-99.724264 -> V=1.0, theta=0.0
% INFO    : Bus 71875	: V=1.0085398, theta=-100.947543 -> V=1.0, theta=0.0
% INFO    : Bus 71876	: V=1.0085285, theta=-100.806347 -> V=1.0, theta=0.0
% INFO    : Bus 71877	: V=1.008052, theta=-101.040559 -> V=1.0, theta=0.0
% INFO    : Bus 71878	: V=1.0084127, theta=-100.828664 -> V=1.0, theta=0.0
% INFO    : Bus 71879	: V=1.0113427, theta=-100.982418 -> V=1.0, theta=0.0
% INFO    : Bus 71880	: V=1.0105637, theta=-101.043159 -> V=1.0, theta=0.0
% INFO    : Bus 71881	: V=1.0084176, theta=-100.962651 -> V=1.0, theta=0.0
% INFO    : Bus 71882	: V=1.0079496, theta=-101.075558 -> V=1.0, theta=0.0
% INFO    : Bus 71883	: V=1.0078688, theta=-101.18247 -> V=1.0, theta=0.0
% INFO    : Bus 71884	: V=1.0081431, theta=-100.972906 -> V=1.0, theta=0.0
% INFO    : Bus 71885	: V=1.0093246, theta=-101.135453 -> V=1.0, theta=0.0
% INFO    : Bus 71886	: V=1.0085106, theta=-101.16164 -> V=1.0, theta=0.0
% INFO    : Bus 71887	: V=1.0089291, theta=-101.167017 -> V=1.0, theta=0.0
% INFO    : Bus 71888	: V=1.0089102, theta=-101.177112 -> V=1.0, theta=0.0
% INFO    : Bus 71889	: V=1.0106803, theta=-100.591039 -> V=1.0, theta=0.0
% INFO    : Bus 71890	: V=1.014367, theta=-100.719337 -> V=1.0, theta=0.0
% INFO    : Bus 71891	: V=1.0146738, theta=-100.706866 -> V=1.0, theta=0.0
% INFO    : Bus 71892	: V=1.017281, theta=-100.760482 -> V=1.0, theta=0.0
% INFO    : Bus 71893	: V=1.005377, theta=-100.92985 -> V=1.0, theta=0.0
% INFO    : Bus 71894	: V=1.0059134, theta=-100.412212 -> V=1.0, theta=0.0
% INFO    : Bus 71895	: V=1.0097788, theta=-100.544662 -> V=1.0, theta=0.0
% INFO    : Bus 71896	: V=1.0118842, theta=-100.593751 -> V=1.0, theta=0.0
% INFO    : Bus 71897	: V=1.0029563, theta=-98.93913 -> V=1.0, theta=0.0
% INFO    : Bus 71898	: V=1.0065221, theta=-100.222153 -> V=1.0, theta=0.0
% INFO    : Bus 71899	: V=1.0071872, theta=-100.338056 -> V=1.0, theta=0.0
% INFO    : Bus 71900	: V=1.0086114, theta=-100.469212 -> V=1.0, theta=0.0
% INFO    : Bus 71901	: V=1.0076969, theta=-100.412809 -> V=1.0, theta=0.0
% INFO    : Bus 71902	: V=1.007786, theta=-100.409491 -> V=1.0, theta=0.0
% INFO    : Bus 71903	: V=1.0081883, theta=-100.286479 -> V=1.0, theta=0.0
% INFO    : Bus 71904	: V=1.0093373, theta=-100.407 -> V=1.0, theta=0.0
% INFO    : Bus 71905	: V=1.0106216, theta=-100.507551 -> V=1.0, theta=0.0
% INFO    : Bus 71906	: V=1.0021367, theta=-99.605261 -> V=1.0, theta=0.0
% INFO    : Bus 71907	: V=1.0107272, theta=-100.256787 -> V=1.0, theta=0.0
% INFO    : Bus 71908	: V=1.0019272, theta=-99.540179 -> V=1.0, theta=0.0
% INFO    : Bus 71909	: V=1.0125483, theta=-100.1955 -> V=1.0, theta=0.0
% INFO    : Bus 71910	: V=1.0142284, theta=-100.090146 -> V=1.0, theta=0.0
% INFO    : Bus 71911	: V=1.0018781, theta=-99.235934 -> V=1.0, theta=0.0
% INFO    : Bus 71912	: V=1.0029207, theta=-99.504654 -> V=1.0, theta=0.0
% INFO    : Bus 71913	: V=1.0024313, theta=-99.381399 -> V=1.0, theta=0.0
% INFO    : Bus 71914	: V=1.0029279, theta=-99.573042 -> V=1.0, theta=0.0
% INFO    : Bus 71915	: V=1.0019696, theta=-99.234773 -> V=1.0, theta=0.0
% INFO    : Bus 71916	: V=1.0023679, theta=-99.401223 -> V=1.0, theta=0.0
% INFO    : Bus 71917	: V=1.0040062, theta=-99.827823 -> V=1.0, theta=0.0
% INFO    : Bus 71918	: V=1.0076885, theta=-100.305026 -> V=1.0, theta=0.0
% INFO    : Bus 71919	: V=1.0052383, theta=-100.042527 -> V=1.0, theta=0.0
% INFO    : Bus 71920	: V=1.0029377, theta=-98.873866 -> V=1.0, theta=0.0
% INFO    : Bus 71921	: V=1.002943, theta=-98.825084 -> V=1.0, theta=0.0
% INFO    : Bus 71922	: V=1.0012347, theta=-99.078855 -> V=1.0, theta=0.0
% INFO    : Bus 71923	: V=1.0012581, theta=-99.260063 -> V=1.0, theta=0.0
% INFO    : Bus 71924	: V=1.0035309, theta=-99.695838 -> V=1.0, theta=0.0
% INFO    : Bus 71925	: V=1.0014708, theta=-99.44915 -> V=1.0, theta=0.0
% INFO    : Bus 71926	: V=1.0030939, theta=-99.881026 -> V=1.0, theta=0.0
% INFO    : Bus 71927	: V=1.0022928, theta=-100.182223 -> V=1.0, theta=0.0
% INFO    : Bus 71928	: V=1.0036047, theta=-100.12884 -> V=1.0, theta=0.0
% INFO    : Bus 71929	: V=1.0028288, theta=-99.959857 -> V=1.0, theta=0.0
% INFO    : Bus 71930	: V=1.0026927, theta=-99.782316 -> V=1.0, theta=0.0
% INFO    : Bus 71931	: V=1.0027487, theta=-100.01598 -> V=1.0, theta=0.0
% INFO    : Bus 71932	: V=1.0030301, theta=-99.947279 -> V=1.0, theta=0.0
% INFO    : Bus 71933	: V=1.0031924, theta=-99.933678 -> V=1.0, theta=0.0
% INFO    : Bus 71934	: V=1.0029591, theta=-99.920412 -> V=1.0, theta=0.0
% INFO    : Bus 71935	: V=1.0027391, theta=-99.848365 -> V=1.0, theta=0.0
% INFO    : Bus 71936	: V=1.0027451, theta=-99.980835 -> V=1.0, theta=0.0
% INFO    : Bus 71937	: V=1.0035445, theta=-99.838318 -> V=1.0, theta=0.0
% INFO    : Bus 71938	: V=1.0032027, theta=-99.894392 -> V=1.0, theta=0.0
% INFO    : Bus 71939	: V=1.0029992, theta=-99.933692 -> V=1.0, theta=0.0
% INFO    : Bus 71940	: V=1.0032571, theta=-99.594328 -> V=1.0, theta=0.0
% INFO    : Bus 71941	: V=1.002607, theta=-99.650112 -> V=1.0, theta=0.0
% INFO    : Bus 71942	: V=1.0029542, theta=-99.948235 -> V=1.0, theta=0.0
% INFO    : Bus 71943	: V=1.0052199, theta=-97.940067 -> V=1.0, theta=0.0
% INFO    : Bus 71944	: V=1.0051664, theta=-98.492291 -> V=1.0, theta=0.0
% INFO    : Bus 71945	: V=1.0039094, theta=-99.490597 -> V=1.0, theta=0.0
% INFO    : Bus 71946	: V=1.0052359, theta=-98.632763 -> V=1.0, theta=0.0
% INFO    : Bus 71947	: V=1.0028671, theta=-99.425952 -> V=1.0, theta=0.0
% INFO    : Bus 71948	: V=1.0023635, theta=-99.429718 -> V=1.0, theta=0.0
% INFO    : Bus 71949	: V=1.0025133, theta=-99.877197 -> V=1.0, theta=0.0
% INFO    : Bus 71950	: V=1.0026262, theta=-98.752793 -> V=1.0, theta=0.0
% INFO    : Bus 71951	: V=0.9995132, theta=-99.149648 -> V=1.0, theta=0.0
% INFO    : Bus 71952	: V=1.0027827, theta=-98.773597 -> V=1.0, theta=0.0
% INFO    : Bus 71953	: V=1.0032957, theta=-98.607108 -> V=1.0, theta=0.0
% INFO    : Bus 71954	: V=1.0019879, theta=-99.142905 -> V=1.0, theta=0.0
% INFO    : Bus 71955	: V=1.0019695, theta=-98.953711 -> V=1.0, theta=0.0
% INFO    : Bus 71956	: V=1.0033643, theta=-98.35113 -> V=1.0, theta=0.0
% INFO    : Bus 71957	: V=1.0040003, theta=-98.055238 -> V=1.0, theta=0.0
% INFO    : Bus 71958	: V=1.0037527, theta=-98.205576 -> V=1.0, theta=0.0
% INFO    : Bus 71959	: V=1.0043452, theta=-97.870759 -> V=1.0, theta=0.0
% INFO    : Bus 71960	: V=1.0017338, theta=-98.942099 -> V=1.0, theta=0.0
% INFO    : Bus 71961	: V=1.0018579, theta=-98.601639 -> V=1.0, theta=0.0
% INFO    : Bus 71962	: V=1.001075, theta=-98.720287 -> V=1.0, theta=0.0
% INFO    : Bus 71963	: V=1.0013744, theta=-98.676362 -> V=1.0, theta=0.0
% INFO    : Bus 71964	: V=1.0041271, theta=-98.32264 -> V=1.0, theta=0.0
% INFO    : Bus 71965	: V=1.0023185, theta=-98.3725 -> V=1.0, theta=0.0
% INFO    : Bus 71966	: V=1.0013391, theta=-98.555646 -> V=1.0, theta=0.0
% INFO    : Bus 71967	: V=1.0012967, theta=-98.706282 -> V=1.0, theta=0.0
% INFO    : Bus 71968	: V=1.0010004, theta=-98.71836 -> V=1.0, theta=0.0
% INFO    : Bus 71969	: V=1.0036786, theta=-98.3074 -> V=1.0, theta=0.0
% INFO    : Bus 71970	: V=1.0035142, theta=-98.27473 -> V=1.0, theta=0.0
% INFO    : Bus 71971	: V=1.0019454, theta=-98.515838 -> V=1.0, theta=0.0
% INFO    : Bus 71972	: V=1.0025669, theta=-98.464123 -> V=1.0, theta=0.0
% INFO    : Bus 71973	: V=1.0046054, theta=-98.065381 -> V=1.0, theta=0.0
% INFO    : Bus 71974	: V=1.004358, theta=-98.223761 -> V=1.0, theta=0.0
% INFO    : Bus 71975	: V=1.004017, theta=-98.019768 -> V=1.0, theta=0.0
% INFO    : Bus 71976	: V=1.0033703, theta=-98.218502 -> V=1.0, theta=0.0
% INFO    : Bus 71977	: V=1.0005797, theta=-98.797278 -> V=1.0, theta=0.0
% INFO    : Bus 71978	: V=1.0010398, theta=-99.004876 -> V=1.0, theta=0.0
% INFO    : Bus 71979	: V=1.001474, theta=-99.126933 -> V=1.0, theta=0.0
% INFO    : Bus 71980	: V=1.0001329, theta=-99.038769 -> V=1.0, theta=0.0
% INFO    : Bus 71981	: V=1.0021134, theta=-99.533043 -> V=1.0, theta=0.0
% INFO    : Bus 71982	: V=1.0031141, theta=-99.495766 -> V=1.0, theta=0.0
% INFO    : Bus 71983	: V=1.0025578, theta=-99.518564 -> V=1.0, theta=0.0
% INFO    : Bus 71984	: V=1.0018132, theta=-98.929191 -> V=1.0, theta=0.0
% INFO    : Bus 71985	: V=1.0067295, theta=-99.072806 -> V=1.0, theta=0.0
% INFO    : Bus 71986	: V=0.9990828, theta=-98.813732 -> V=1.0, theta=0.0
% INFO    : Bus 71987	: V=1.0025362, theta=-98.442817 -> V=1.0, theta=0.0
% INFO    : Bus 71988	: V=1.0027367, theta=-98.852813 -> V=1.0, theta=0.0
% INFO    : Bus 71989	: V=1.0011022, theta=-98.977296 -> V=1.0, theta=0.0
% INFO    : Bus 71990	: V=1.0047988, theta=-97.696446 -> V=1.0, theta=0.0
% INFO    : Bus 71991	: V=1.0038937, theta=-97.736467 -> V=1.0, theta=0.0
% INFO    : Bus 71992	: V=1.0031119, theta=-98.419266 -> V=1.0, theta=0.0
% INFO    : Bus 71993	: V=1.0056471, theta=-98.308675 -> V=1.0, theta=0.0
% INFO    : Bus 71994	: V=1.005666, theta=-98.394652 -> V=1.0, theta=0.0
% INFO    : Bus 71995	: V=1.003886, theta=-98.743762 -> V=1.0, theta=0.0
% INFO    : Bus 71996	: V=1.0016109, theta=-98.432837 -> V=1.0, theta=0.0
% INFO    : Bus 71997	: V=1.0019973, theta=-98.294465 -> V=1.0, theta=0.0
% INFO    : Bus 71998	: V=0.9994638, theta=-98.799485 -> V=1.0, theta=0.0
% INFO    : Bus 71999	: V=1.0010326, theta=-98.501369 -> V=1.0, theta=0.0
% INFO    : Bus 72000	: V=1.0032588, theta=-98.137752 -> V=1.0, theta=0.0
% INFO    : Bus 72001	: V=1.0057579, theta=-98.208703 -> V=1.0, theta=0.0
% INFO    : Bus 72002	: V=1.0031969, theta=-97.910422 -> V=1.0, theta=0.0
% INFO    : Bus 72003	: V=1.0031308, theta=-97.914231 -> V=1.0, theta=0.0
% INFO    : Bus 72004	: V=1.0016135, theta=-98.448603 -> V=1.0, theta=0.0
% INFO    : Bus 72005	: V=1.0017775, theta=-98.303446 -> V=1.0, theta=0.0
% INFO    : Bus 72006	: V=1.0012388, theta=-98.482904 -> V=1.0, theta=0.0
% INFO    : Bus 72007	: V=1.00091, theta=-98.582352 -> V=1.0, theta=0.0
% INFO    : Bus 72008	: V=1.0006639, theta=-98.700375 -> V=1.0, theta=0.0
% INFO    : Bus 72009	: V=1.0010937, theta=-98.50166 -> V=1.0, theta=0.0
% INFO    : Bus 72010	: V=1.0002658, theta=-98.811631 -> V=1.0, theta=0.0
% INFO    : Bus 72011	: V=0.9999713, theta=-98.770683 -> V=1.0, theta=0.0
% INFO    : Bus 72012	: V=1.0010338, theta=-98.484112 -> V=1.0, theta=0.0
% INFO    : Bus 72013	: V=1.0021721, theta=-98.478915 -> V=1.0, theta=0.0
% INFO    : Bus 72014	: V=1.0037633, theta=-98.3815 -> V=1.0, theta=0.0
% INFO    : Bus 72015	: V=1.0040078, theta=-98.371538 -> V=1.0, theta=0.0
% INFO    : Bus 72016	: V=1.0046792, theta=-98.311797 -> V=1.0, theta=0.0
% INFO    : Bus 72017	: V=1.0033763, theta=-98.127247 -> V=1.0, theta=0.0
% INFO    : Bus 72018	: V=1.0032758, theta=-98.329276 -> V=1.0, theta=0.0
% INFO    : Bus 72019	: V=1.0035376, theta=-98.105815 -> V=1.0, theta=0.0
% INFO    : Bus 72020	: V=1.0038632, theta=-98.057633 -> V=1.0, theta=0.0
% INFO    : Bus 72021	: V=1.0032176, theta=-97.903298 -> V=1.0, theta=0.0
% INFO    : Bus 72022	: V=1.0034648, theta=-97.894043 -> V=1.0, theta=0.0
% INFO    : Bus 72023	: V=1.0032641, theta=-97.630026 -> V=1.0, theta=0.0
% INFO    : Bus 72024	: V=1.0058199, theta=-97.990914 -> V=1.0, theta=0.0
% INFO    : Bus 72025	: V=1.0059549, theta=-96.574028 -> V=1.0, theta=0.0
% INFO    : Bus 72026	: V=1.00585, theta=-97.508936 -> V=1.0, theta=0.0
% INFO    : Bus 72027	: V=1.0050192, theta=-97.688059 -> V=1.0, theta=0.0
% INFO    : Bus 72028	: V=1.0028075, theta=-96.921492 -> V=1.0, theta=0.0
% INFO    : Bus 72029	: V=1.0033948, theta=-96.894916 -> V=1.0, theta=0.0
% INFO    : Bus 72030	: V=1.0033089, theta=-97.305315 -> V=1.0, theta=0.0
% INFO    : Bus 72031	: V=1.0039121, theta=-96.790483 -> V=1.0, theta=0.0
% INFO    : Bus 72032	: V=1.0051613, theta=-97.057077 -> V=1.0, theta=0.0
% INFO    : Bus 72033	: V=1.0045764, theta=-97.080859 -> V=1.0, theta=0.0
% INFO    : Bus 72034	: V=1.0036368, theta=-96.254181 -> V=1.0, theta=0.0
% INFO    : Bus 72035	: V=1.0065741, theta=-97.259445 -> V=1.0, theta=0.0
% INFO    : Bus 72036	: V=1.0032816, theta=-96.816006 -> V=1.0, theta=0.0
% INFO    : Bus 72037	: V=1.0034203, theta=-96.810791 -> V=1.0, theta=0.0
% INFO    : Bus 72038	: V=1.0041411, theta=-96.354922 -> V=1.0, theta=0.0
% INFO    : Bus 72039	: V=1.0033622, theta=-96.38396 -> V=1.0, theta=0.0
% INFO    : Bus 72040	: V=1.0038732, theta=-96.078518 -> V=1.0, theta=0.0
% INFO    : Bus 72041	: V=1.004125, theta=-95.918422 -> V=1.0, theta=0.0
% INFO    : Bus 72042	: V=1.0046339, theta=-95.733916 -> V=1.0, theta=0.0
% INFO    : Bus 72043	: V=1.0044531, theta=-95.998815 -> V=1.0, theta=0.0
% INFO    : Bus 72044	: V=1.0111493, theta=-97.616868 -> V=1.0, theta=0.0
% INFO    : Bus 72045	: V=1.0055858, theta=-98.501984 -> V=1.0, theta=0.0
% INFO    : Bus 72046	: V=1.0058719, theta=-98.490281 -> V=1.0, theta=0.0
% INFO    : Bus 72047	: V=1.0087506, theta=-97.751183 -> V=1.0, theta=0.0
% INFO    : Bus 72048	: V=1.0106195, theta=-95.628208 -> V=1.0, theta=0.0
% INFO    : Bus 72049	: V=1.008034, theta=-98.364945 -> V=1.0, theta=0.0
% INFO    : Bus 72050	: V=1.0113638, theta=-99.531599 -> V=1.0, theta=0.0
% INFO    : Bus 72051	: V=1.008304, theta=-98.988524 -> V=1.0, theta=0.0
% INFO    : Bus 72052	: V=1.0088205, theta=-99.066295 -> V=1.0, theta=0.0
% INFO    : Bus 72053	: V=1.0131421, theta=-99.915883 -> V=1.0, theta=0.0
% INFO    : Bus 72054	: V=1.0122179, theta=-99.718712 -> V=1.0, theta=0.0
% INFO    : Bus 72055	: V=1.0127492, theta=-99.832289 -> V=1.0, theta=0.0
% INFO    : Bus 72056	: V=1.0071911, theta=-98.760854 -> V=1.0, theta=0.0
% INFO    : Bus 72057	: V=1.0074083, theta=-99.0452 -> V=1.0, theta=0.0
% INFO    : Bus 72058	: V=1.0162921, theta=-100.206527 -> V=1.0, theta=0.0
% INFO    : Bus 72059	: V=1.0082344, theta=-98.913599 -> V=1.0, theta=0.0
% INFO    : Bus 72060	: V=1.016531, theta=-100.195818 -> V=1.0, theta=0.0
% INFO    : Bus 72061	: V=1.0101346, theta=-99.590094 -> V=1.0, theta=0.0
% INFO    : Bus 72062	: V=1.0105854, theta=-99.571819 -> V=1.0, theta=0.0
% INFO    : Bus 72063	: V=1.0081871, theta=-97.998219 -> V=1.0, theta=0.0
% INFO    : Bus 72064	: V=1.0102203, theta=-99.222562 -> V=1.0, theta=0.0
% INFO    : Bus 72065	: V=1.0154162, theta=-100.422988 -> V=1.0, theta=0.0
% INFO    : Bus 72066	: V=1.0146283, theta=-100.61954 -> V=1.0, theta=0.0
% INFO    : Bus 72067	: V=1.0143934, theta=-100.630103 -> V=1.0, theta=0.0
% INFO    : Bus 72068	: V=1.0160131, theta=-100.216721 -> V=1.0, theta=0.0
% INFO    : Bus 72069	: V=1.014692, theta=-100.519923 -> V=1.0, theta=0.0
% INFO    : Bus 72070	: V=1.0147165, theta=-100.536618 -> V=1.0, theta=0.0
% INFO    : Bus 72071	: V=1.0146494, theta=-100.643861 -> V=1.0, theta=0.0
% INFO    : Bus 72072	: V=1.0149076, theta=-100.477277 -> V=1.0, theta=0.0
% INFO    : Bus 72073	: V=1.0154346, theta=-100.406988 -> V=1.0, theta=0.0
% INFO    : Bus 72074	: V=1.0082172, theta=-99.22469 -> V=1.0, theta=0.0
% INFO    : Bus 72075	: V=1.0063131, theta=-101.462083 -> V=1.0, theta=0.0
% INFO    : Bus 72076	: V=1.0065762, theta=-101.471951 -> V=1.0, theta=0.0
% INFO    : Bus 72077	: V=1.006783, theta=-101.416061 -> V=1.0, theta=0.0
% INFO    : Bus 72078	: V=1.0066794, theta=-100.996873 -> V=1.0, theta=0.0
% INFO    : Bus 72079	: V=1.007033, theta=-101.258625 -> V=1.0, theta=0.0
% INFO    : Bus 72080	: V=1.0078613, theta=-101.221394 -> V=1.0, theta=0.0
% INFO    : Bus 72081	: V=1.0074772, theta=-101.33751 -> V=1.0, theta=0.0
% INFO    : Bus 72082	: V=1.0084982, theta=-101.212674 -> V=1.0, theta=0.0
% INFO    : Bus 72083	: V=1.0080048, theta=-101.245311 -> V=1.0, theta=0.0
% INFO    : Bus 72084	: V=1.0068532, theta=-101.438156 -> V=1.0, theta=0.0
% INFO    : Bus 72085	: V=1.0072689, theta=-101.416725 -> V=1.0, theta=0.0
% INFO    : Bus 72086	: V=1.0072312, theta=-101.417337 -> V=1.0, theta=0.0
% INFO    : Bus 72087	: V=1.0076045, theta=-101.261545 -> V=1.0, theta=0.0
% INFO    : Bus 72088	: V=1.0066833, theta=-101.450786 -> V=1.0, theta=0.0
% INFO    : Bus 72089	: V=1.0068013, theta=-101.413613 -> V=1.0, theta=0.0
% INFO    : Bus 72090	: V=1.0074384, theta=-101.268802 -> V=1.0, theta=0.0
% INFO    : Bus 72091	: V=1.0066572, theta=-100.554459 -> V=1.0, theta=0.0
% INFO    : Bus 72092	: V=1.0071672, theta=-99.886531 -> V=1.0, theta=0.0
% INFO    : Bus 72093	: V=1.0068854, theta=-101.399801 -> V=1.0, theta=0.0
% INFO    : Bus 72094	: V=1.0076034, theta=-101.231165 -> V=1.0, theta=0.0
% INFO    : Bus 72095	: V=1.0063821, theta=-100.26345 -> V=1.0, theta=0.0
% INFO    : Bus 72096	: V=1.0069083, theta=-101.418347 -> V=1.0, theta=0.0
% INFO    : Bus 72097	: V=1.007178, theta=-101.351704 -> V=1.0, theta=0.0
% INFO    : Bus 72098	: V=1.0042204, theta=-100.971179 -> V=1.0, theta=0.0
% INFO    : Bus 72099	: V=1.0175242, theta=-96.163158 -> V=1.0, theta=0.0
% INFO    : Bus 72100	: V=1.0158736, theta=-97.54762 -> V=1.0, theta=0.0
% INFO    : Bus 72101	: V=1.0018139, theta=-101.800871 -> V=1.0, theta=0.0
% INFO    : Bus 72102	: V=1.0022444, theta=-102.123894 -> V=1.0, theta=0.0
% INFO    : Bus 72103	: V=0.9999708, theta=-102.252866 -> V=1.0, theta=0.0
% INFO    : Bus 72104	: V=1.0005975, theta=-102.228508 -> V=1.0, theta=0.0
% INFO    : Bus 72105	: V=1.0016452, theta=-102.184727 -> V=1.0, theta=0.0
% INFO    : Bus 72106	: V=1.0004256, theta=-102.210072 -> V=1.0, theta=0.0
% INFO    : Bus 72107	: V=1.0098628, theta=-100.205598 -> V=1.0, theta=0.0
% INFO    : Bus 72108	: V=1.0077407, theta=-101.342001 -> V=1.0, theta=0.0
% INFO    : Bus 72109	: V=1.0073762, theta=-101.390576 -> V=1.0, theta=0.0
% INFO    : Bus 72110	: V=1.0073738, theta=-101.391358 -> V=1.0, theta=0.0
% INFO    : Bus 72111	: V=1.0074524, theta=-101.336422 -> V=1.0, theta=0.0
% INFO    : Bus 72112	: V=1.0066633, theta=-101.489979 -> V=1.0, theta=0.0
% INFO    : Bus 72113	: V=1.0067655, theta=-101.49798 -> V=1.0, theta=0.0
% INFO    : Bus 72114	: V=1.0073341, theta=-101.422035 -> V=1.0, theta=0.0
% INFO    : Bus 72115	: V=1.0073374, theta=-101.438099 -> V=1.0, theta=0.0
% INFO    : Bus 72116	: V=1.0070496, theta=-101.484957 -> V=1.0, theta=0.0
% INFO    : Bus 72117	: V=1.0072317, theta=-101.441746 -> V=1.0, theta=0.0
% INFO    : Bus 72118	: V=1.0099085, theta=-100.373808 -> V=1.0, theta=0.0
% INFO    : Bus 72119	: V=1.007093, theta=-101.370091 -> V=1.0, theta=0.0
% INFO    : Bus 72120	: V=1.0064927, theta=-101.394423 -> V=1.0, theta=0.0
% INFO    : Bus 72121	: V=1.0081653, theta=-100.897227 -> V=1.0, theta=0.0
% INFO    : Bus 72122	: V=1.007089, theta=-101.487635 -> V=1.0, theta=0.0
% INFO    : Bus 72123	: V=1.0074841, theta=-101.260658 -> V=1.0, theta=0.0
% INFO    : Bus 72124	: V=1.0076597, theta=-101.254133 -> V=1.0, theta=0.0
% INFO    : Bus 72125	: V=1.0067413, theta=-101.414894 -> V=1.0, theta=0.0
% INFO    : Bus 72126	: V=1.0073347, theta=-101.418848 -> V=1.0, theta=0.0
% INFO    : Bus 72127	: V=1.0078965, theta=-100.996034 -> V=1.0, theta=0.0
% INFO    : Bus 72128	: V=1.0069735, theta=-101.30673 -> V=1.0, theta=0.0
% INFO    : Bus 72129	: V=1.0068081, theta=-101.469652 -> V=1.0, theta=0.0
% INFO    : Bus 72130	: V=1.010969, theta=-103.770615 -> V=1.0, theta=0.0
% INFO    : Bus 72131	: V=1.0082455, theta=-102.202649 -> V=1.0, theta=0.0
% INFO    : Bus 72132	: V=1.0033059, theta=-96.452448 -> V=1.0, theta=0.0
% INFO    : Bus 72133	: V=0.995144, theta=-106.664211 -> V=1.0, theta=0.0
% INFO    : Bus 72134	: V=0.9928422, theta=-105.475825 -> V=1.0, theta=0.0
% INFO    : Bus 72135	: V=0.9878476, theta=-107.0336 -> V=1.0, theta=0.0
% INFO    : Bus 72136	: V=0.9888915, theta=-106.989401 -> V=1.0, theta=0.0
% INFO    : Bus 72137	: V=0.9874283, theta=-107.082971 -> V=1.0, theta=0.0
% INFO    : Bus 72138	: V=0.9879805, theta=-107.062102 -> V=1.0, theta=0.0
% INFO    : Bus 72139	: V=0.9872393, theta=-107.122912 -> V=1.0, theta=0.0
% INFO    : Bus 72140	: V=0.9901497, theta=-106.806929 -> V=1.0, theta=0.0
% INFO    : Bus 72141	: V=0.9905223, theta=-106.792759 -> V=1.0, theta=0.0
% INFO    : Bus 72142	: V=0.9865193, theta=-107.150979 -> V=1.0, theta=0.0
% INFO    : Bus 72143	: V=1.0100004, theta=-90.238328 -> V=1.0, theta=0.0
% INFO    : Bus 72144	: V=0.9932248, theta=-75.737062 -> V=1.0, theta=0.0
% INFO    : Bus 72145	: V=0.9934857, theta=-75.750251 -> V=1.0, theta=0.0
% INFO    : Bus 72146	: V=0.9949135, theta=-75.739602 -> V=1.0, theta=0.0
% INFO    : Bus 72147	: V=0.9954469, theta=-75.68745 -> V=1.0, theta=0.0
% INFO    : Bus 72148	: V=0.9959094, theta=-75.918671 -> V=1.0, theta=0.0
% INFO    : Bus 72149	: V=0.9965594, theta=-75.68892 -> V=1.0, theta=0.0
% INFO    : Bus 72150	: V=0.9939343, theta=-76.163347 -> V=1.0, theta=0.0
% INFO    : Bus 72151	: V=0.9972338, theta=-75.564378 -> V=1.0, theta=0.0
% INFO    : Bus 72152	: V=0.9966488, theta=-74.67069 -> V=1.0, theta=0.0
% INFO    : Bus 72153	: V=0.9941467, theta=-75.32817 -> V=1.0, theta=0.0
% INFO    : Bus 72154	: V=0.9950155, theta=-76.107915 -> V=1.0, theta=0.0
% INFO    : Bus 72155	: V=0.9945829, theta=-76.394279 -> V=1.0, theta=0.0
% INFO    : Bus 72156	: V=0.9915562, theta=-75.044125 -> V=1.0, theta=0.0
% INFO    : Bus 72157	: V=0.990701, theta=-75.092824 -> V=1.0, theta=0.0
% INFO    : Bus 72158	: V=0.9922229, theta=-74.658068 -> V=1.0, theta=0.0
% INFO    : Bus 72159	: V=0.9928567, theta=-75.211294 -> V=1.0, theta=0.0
% INFO    : Bus 72160	: V=0.9928398, theta=-74.867759 -> V=1.0, theta=0.0
% INFO    : Bus 72161	: V=0.9957021, theta=-73.991348 -> V=1.0, theta=0.0
% INFO    : Bus 72162	: V=0.9921441, theta=-75.083685 -> V=1.0, theta=0.0
% INFO    : Bus 72163	: V=0.9931799, theta=-74.784391 -> V=1.0, theta=0.0
% INFO    : Bus 72164	: V=0.9930125, theta=-75.355718 -> V=1.0, theta=0.0
% INFO    : Bus 72165	: V=0.9925182, theta=-74.871437 -> V=1.0, theta=0.0
% INFO    : Bus 72166	: V=0.9920725, theta=-74.490077 -> V=1.0, theta=0.0
% INFO    : Bus 72167	: V=0.9930365, theta=-74.850004 -> V=1.0, theta=0.0
% INFO    : Bus 72168	: V=0.9929243, theta=-75.007749 -> V=1.0, theta=0.0
% INFO    : Bus 72169	: V=0.9929895, theta=-73.652995 -> V=1.0, theta=0.0
% INFO    : Bus 72170	: V=0.993301, theta=-74.484441 -> V=1.0, theta=0.0
% INFO    : Bus 72171	: V=0.9933826, theta=-74.595832 -> V=1.0, theta=0.0
% INFO    : Bus 72172	: V=0.9938728, theta=-74.742438 -> V=1.0, theta=0.0
% INFO    : Bus 72173	: V=0.9935218, theta=-74.528324 -> V=1.0, theta=0.0
% INFO    : Bus 72174	: V=0.9905732, theta=-74.724025 -> V=1.0, theta=0.0
% INFO    : Bus 72175	: V=0.9908024, theta=-74.168169 -> V=1.0, theta=0.0
% INFO    : Bus 72176	: V=0.991838, theta=-72.841573 -> V=1.0, theta=0.0
% INFO    : Bus 72177	: V=0.9919202, theta=-74.672927 -> V=1.0, theta=0.0
% INFO    : Bus 72178	: V=0.9908981, theta=-74.711681 -> V=1.0, theta=0.0
% INFO    : Bus 72179	: V=0.9911501, theta=-75.21465 -> V=1.0, theta=0.0
% INFO    : Bus 72180	: V=0.9916825, theta=-74.681683 -> V=1.0, theta=0.0
% INFO    : Bus 72181	: V=0.9915294, theta=-75.198901 -> V=1.0, theta=0.0
% INFO    : Bus 72182	: V=0.9928878, theta=-74.635549 -> V=1.0, theta=0.0
% INFO    : Bus 72183	: V=0.9922952, theta=-73.246581 -> V=1.0, theta=0.0
% INFO    : Bus 72184	: V=0.9900682, theta=-74.266311 -> V=1.0, theta=0.0
% INFO    : Bus 72185	: V=0.9913665, theta=-75.227911 -> V=1.0, theta=0.0
% INFO    : Bus 72186	: V=0.9919216, theta=-74.876222 -> V=1.0, theta=0.0
% INFO    : Bus 72187	: V=0.992014, theta=-73.829466 -> V=1.0, theta=0.0
% INFO    : Bus 72188	: V=0.991451, theta=-74.895588 -> V=1.0, theta=0.0
% INFO    : Bus 72189	: V=0.9920725, theta=-73.993924 -> V=1.0, theta=0.0
% INFO    : Bus 72190	: V=0.9917288, theta=-74.168144 -> V=1.0, theta=0.0
% INFO    : Bus 72191	: V=0.9920894, theta=-74.056357 -> V=1.0, theta=0.0
% INFO    : Bus 72192	: V=0.9925722, theta=-73.927677 -> V=1.0, theta=0.0
% INFO    : Bus 72193	: V=0.9926831, theta=-74.303814 -> V=1.0, theta=0.0
% INFO    : Bus 72194	: V=0.9919332, theta=-74.315952 -> V=1.0, theta=0.0
% INFO    : Bus 72195	: V=0.993352, theta=-73.66237 -> V=1.0, theta=0.0
% INFO    : Bus 72196	: V=0.9933574, theta=-73.935345 -> V=1.0, theta=0.0
% INFO    : Bus 72197	: V=0.9927989, theta=-74.19117 -> V=1.0, theta=0.0
% INFO    : Bus 72198	: V=0.9937363, theta=-73.674533 -> V=1.0, theta=0.0
% INFO    : Bus 72199	: V=0.9950446, theta=-73.190154 -> V=1.0, theta=0.0
% INFO    : Bus 72200	: V=0.9946912, theta=-73.194034 -> V=1.0, theta=0.0
% INFO    : Bus 72201	: V=1.0002067, theta=-71.971709 -> V=1.0, theta=0.0
% INFO    : Bus 72202	: V=0.995486, theta=-73.011608 -> V=1.0, theta=0.0
% INFO    : Bus 72203	: V=0.9942691, theta=-73.451479 -> V=1.0, theta=0.0
% INFO    : Bus 72204	: V=1.0010608, theta=-71.822084 -> V=1.0, theta=0.0
% INFO    : Bus 72205	: V=0.9952788, theta=-73.089408 -> V=1.0, theta=0.0
% INFO    : Bus 72206	: V=0.9938683, theta=-73.659275 -> V=1.0, theta=0.0
% INFO    : Bus 72207	: V=0.9942626, theta=-73.456111 -> V=1.0, theta=0.0
% INFO    : Bus 72208	: V=0.9947113, theta=-73.248934 -> V=1.0, theta=0.0
% INFO    : Bus 72209	: V=0.9966819, theta=-72.893474 -> V=1.0, theta=0.0
% INFO    : Bus 72210	: V=1.0065259, theta=-71.610108 -> V=1.0, theta=0.0
% INFO    : Bus 72211	: V=0.9931923, theta=-74.372064 -> V=1.0, theta=0.0
% INFO    : Bus 72212	: V=0.9922289, theta=-73.836708 -> V=1.0, theta=0.0
% INFO    : Bus 72213	: V=0.9928973, theta=-73.703125 -> V=1.0, theta=0.0
% INFO    : Bus 72214	: V=0.9934828, theta=-73.751577 -> V=1.0, theta=0.0
% INFO    : Bus 72215	: V=0.9933028, theta=-73.987671 -> V=1.0, theta=0.0
% INFO    : Bus 72216	: V=0.9990207, theta=-72.195009 -> V=1.0, theta=0.0
% INFO    : Bus 72217	: V=0.9925012, theta=-73.635772 -> V=1.0, theta=0.0
% INFO    : Bus 72218	: V=0.9927799, theta=-73.27553 -> V=1.0, theta=0.0
% INFO    : Bus 72219	: V=0.9928282, theta=-73.102422 -> V=1.0, theta=0.0
% INFO    : Bus 72220	: V=0.9940479, theta=-72.262006 -> V=1.0, theta=0.0
% INFO    : Bus 72221	: V=0.9928748, theta=-73.459389 -> V=1.0, theta=0.0
% INFO    : Bus 72222	: V=0.9941077, theta=-73.399101 -> V=1.0, theta=0.0
% INFO    : Bus 72223	: V=1.0058284, theta=-72.096106 -> V=1.0, theta=0.0
% INFO    : Bus 72224	: V=0.9927672, theta=-74.231868 -> V=1.0, theta=0.0
% INFO    : Bus 72225	: V=0.9915343, theta=-73.49847 -> V=1.0, theta=0.0
% INFO    : Bus 72226	: V=0.993337, theta=-72.446065 -> V=1.0, theta=0.0
% INFO    : Bus 72227	: V=0.9930008, theta=-71.408067 -> V=1.0, theta=0.0
% INFO    : Bus 72228	: V=0.9980082, theta=-69.734487 -> V=1.0, theta=0.0
% INFO    : Bus 72229	: V=0.9893171, theta=-72.878038 -> V=1.0, theta=0.0
% INFO    : Bus 72230	: V=0.9915546, theta=-72.863327 -> V=1.0, theta=0.0
% INFO    : Bus 72231	: V=0.9898372, theta=-72.874187 -> V=1.0, theta=0.0
% INFO    : Bus 72232	: V=0.9927992, theta=-72.835712 -> V=1.0, theta=0.0
% INFO    : Bus 72233	: V=0.9920277, theta=-73.29637 -> V=1.0, theta=0.0
% INFO    : Bus 72234	: V=0.9910393, theta=-72.476856 -> V=1.0, theta=0.0
% INFO    : Bus 72235	: V=0.9919275, theta=-72.476014 -> V=1.0, theta=0.0
% INFO    : Bus 72236	: V=0.999739, theta=-70.838613 -> V=1.0, theta=0.0
% INFO    : Bus 72237	: V=0.9996644, theta=-70.705463 -> V=1.0, theta=0.0
% INFO    : Bus 72238	: V=0.996927, theta=-70.535765 -> V=1.0, theta=0.0
% INFO    : Bus 72239	: V=0.9936518, theta=-72.444881 -> V=1.0, theta=0.0
% INFO    : Bus 72240	: V=0.9941046, theta=-72.227608 -> V=1.0, theta=0.0
% INFO    : Bus 72241	: V=0.9938591, theta=-72.78463 -> V=1.0, theta=0.0
% INFO    : Bus 72242	: V=0.9945641, theta=-72.421554 -> V=1.0, theta=0.0
% INFO    : Bus 72243	: V=0.995071, theta=-71.882883 -> V=1.0, theta=0.0
% INFO    : Bus 72244	: V=1.0000138, theta=-71.051495 -> V=1.0, theta=0.0
% INFO    : Bus 72245	: V=0.9966722, theta=-70.961656 -> V=1.0, theta=0.0
% INFO    : Bus 72246	: V=1.004883, theta=-70.620784 -> V=1.0, theta=0.0
% INFO    : Bus 72247	: V=1.0005341, theta=-71.170748 -> V=1.0, theta=0.0
% INFO    : Bus 72248	: V=1.001094, theta=-71.219583 -> V=1.0, theta=0.0
% INFO    : Bus 72249	: V=0.9960768, theta=-70.342035 -> V=1.0, theta=0.0
% INFO    : Bus 72250	: V=0.9958395, theta=-70.158197 -> V=1.0, theta=0.0
% INFO    : Bus 72251	: V=0.9918615, theta=-73.301465 -> V=1.0, theta=0.0
% INFO    : Bus 72252	: V=0.9925306, theta=-73.290825 -> V=1.0, theta=0.0
% INFO    : Bus 72253	: V=1.0006613, theta=-71.636235 -> V=1.0, theta=0.0
% INFO    : Bus 72254	: V=0.9971084, theta=-72.099172 -> V=1.0, theta=0.0
% INFO    : Bus 72255	: V=0.9992108, theta=-71.321234 -> V=1.0, theta=0.0
% INFO    : Bus 72256	: V=1.0100003, theta=-70.452476 -> V=1.0, theta=0.0
% INFO    : Bus 72257	: V=1.0100003, theta=-69.081748 -> V=1.0, theta=0.0
% INFO    : Bus 72258	: V=0.9952553, theta=-71.925058 -> V=1.0, theta=0.0
% INFO    : Bus 72259	: V=1.0054645, theta=-70.652331 -> V=1.0, theta=0.0
% INFO    : Bus 72260	: V=0.996613, theta=-68.826664 -> V=1.0, theta=0.0
% INFO    : Bus 72261	: V=0.9966252, theta=-69.544451 -> V=1.0, theta=0.0
% INFO    : Bus 72262	: V=0.9954615, theta=-69.705575 -> V=1.0, theta=0.0
% INFO    : Bus 72263	: V=0.9941925, theta=-68.08397 -> V=1.0, theta=0.0
% INFO    : Bus 72264	: V=0.9948402, theta=-68.077035 -> V=1.0, theta=0.0
% INFO    : Bus 72265	: V=0.9948888, theta=-69.298271 -> V=1.0, theta=0.0
% INFO    : Bus 72266	: V=0.9941449, theta=-68.999476 -> V=1.0, theta=0.0
% INFO    : Bus 72267	: V=1.0041651, theta=-68.535196 -> V=1.0, theta=0.0
% INFO    : Bus 72268	: V=1.0045571, theta=-68.152543 -> V=1.0, theta=0.0
% INFO    : Bus 72269	: V=1.0053366, theta=-67.394919 -> V=1.0, theta=0.0
% INFO    : Bus 72270	: V=0.9965938, theta=-69.199705 -> V=1.0, theta=0.0
% INFO    : Bus 72271	: V=0.9963045, theta=-69.128819 -> V=1.0, theta=0.0
% INFO    : Bus 72272	: V=0.9965812, theta=-68.847295 -> V=1.0, theta=0.0
% INFO    : Bus 72273	: V=0.9966951, theta=-68.494223 -> V=1.0, theta=0.0
% INFO    : Bus 72274	: V=1.0092634, theta=-68.023201 -> V=1.0, theta=0.0
% INFO    : Bus 72275	: V=1.0075699, theta=-68.130613 -> V=1.0, theta=0.0
% INFO    : Bus 72276	: V=0.9967671, theta=-67.918147 -> V=1.0, theta=0.0
% INFO    : Bus 72277	: V=1.0130846, theta=-67.800439 -> V=1.0, theta=0.0
% INFO    : Bus 72278	: V=0.9954566, theta=-68.678579 -> V=1.0, theta=0.0
% INFO    : Bus 72279	: V=0.9949974, theta=-68.53692 -> V=1.0, theta=0.0
% INFO    : Bus 72280	: V=0.9946445, theta=-68.87099 -> V=1.0, theta=0.0
% INFO    : Bus 72281	: V=0.9946844, theta=-68.256201 -> V=1.0, theta=0.0
% INFO    : Bus 72282	: V=0.994646, theta=-68.161968 -> V=1.0, theta=0.0
% INFO    : Bus 72283	: V=0.9945825, theta=-68.361709 -> V=1.0, theta=0.0
% INFO    : Bus 72284	: V=0.9992609, theta=-67.981185 -> V=1.0, theta=0.0
% INFO    : Bus 72285	: V=0.9988179, theta=-67.934804 -> V=1.0, theta=0.0
% INFO    : Bus 72286	: V=0.9987703, theta=-67.765387 -> V=1.0, theta=0.0
% INFO    : Bus 72287	: V=0.9980724, theta=-68.159701 -> V=1.0, theta=0.0
% INFO    : Bus 72288	: V=0.9990485, theta=-67.610573 -> V=1.0, theta=0.0
% INFO    : Bus 72289	: V=0.9951406, theta=-68.058739 -> V=1.0, theta=0.0
% INFO    : Bus 72290	: V=0.9991659, theta=-67.564482 -> V=1.0, theta=0.0
% INFO    : Bus 72291	: V=0.9958598, theta=-67.987527 -> V=1.0, theta=0.0
% INFO    : Bus 72292	: V=0.9947694, theta=-68.064073 -> V=1.0, theta=0.0
% INFO    : Bus 72293	: V=0.9975781, theta=-67.88259 -> V=1.0, theta=0.0
% INFO    : Bus 72294	: V=0.9983577, theta=-67.850626 -> V=1.0, theta=0.0
% INFO    : Bus 72295	: V=0.9976283, theta=-67.885644 -> V=1.0, theta=0.0
% INFO    : Bus 72296	: V=0.9968355, theta=-67.89319 -> V=1.0, theta=0.0
% INFO    : Bus 72297	: V=0.9988074, theta=-67.683268 -> V=1.0, theta=0.0
% INFO    : Bus 72298	: V=0.9970399, theta=-67.807122 -> V=1.0, theta=0.0
% INFO    : Bus 72299	: V=0.997945, theta=-67.645228 -> V=1.0, theta=0.0
% INFO    : Bus 72300	: V=0.9986101, theta=-67.532957 -> V=1.0, theta=0.0
% INFO    : Bus 72301	: V=0.9996121, theta=-67.344826 -> V=1.0, theta=0.0
% INFO    : Bus 72302	: V=1.000244, theta=-67.225441 -> V=1.0, theta=0.0
% INFO    : Bus 72303	: V=1.0003558, theta=-67.20078 -> V=1.0, theta=0.0
% INFO    : Bus 72304	: V=1.0011427, theta=-66.998818 -> V=1.0, theta=0.0
% INFO    : Bus 72305	: V=1.0100733, theta=-65.085628 -> V=1.0, theta=0.0
% INFO    : Bus 72306	: V=0.9992715, theta=-67.600421 -> V=1.0, theta=0.0
% INFO    : Bus 72307	: V=1.0001575, theta=-67.788725 -> V=1.0, theta=0.0
% INFO    : Bus 72308	: V=0.9976358, theta=-67.880141 -> V=1.0, theta=0.0
% INFO    : Bus 72309	: V=1.00165, theta=-67.710948 -> V=1.0, theta=0.0
% INFO    : Bus 72310	: V=0.9998599, theta=-67.488676 -> V=1.0, theta=0.0
% INFO    : Bus 72311	: V=1.001236, theta=-66.939304 -> V=1.0, theta=0.0
% INFO    : Bus 72312	: V=1.0049172, theta=-66.246522 -> V=1.0, theta=0.0
% INFO    : Bus 72313	: V=1.0282941, theta=-61.698516 -> V=1.0, theta=0.0
% INFO    : Bus 72314	: V=1.0071563, theta=-68.036029 -> V=1.0, theta=0.0
% INFO    : Bus 72315	: V=1.0037501, theta=-67.912582 -> V=1.0, theta=0.0
% INFO    : Bus 72316	: V=1.0052111, theta=-67.995584 -> V=1.0, theta=0.0
% INFO    : Bus 72317	: V=1.0012852, theta=-67.868109 -> V=1.0, theta=0.0
% INFO    : Bus 72318	: V=1.0015556, theta=-67.939491 -> V=1.0, theta=0.0
% INFO    : Bus 72319	: V=1.0014035, theta=-67.447705 -> V=1.0, theta=0.0
% INFO    : Bus 72320	: V=1.0008584, theta=-67.516339 -> V=1.0, theta=0.0
% INFO    : Bus 72321	: V=1.0008046, theta=-67.234583 -> V=1.0, theta=0.0
% INFO    : Bus 72322	: V=1.0018278, theta=-66.984393 -> V=1.0, theta=0.0
% INFO    : Bus 72323	: V=1.0014379, theta=-67.22868 -> V=1.0, theta=0.0
% INFO    : Bus 72324	: V=1.0130145, theta=-67.420926 -> V=1.0, theta=0.0
% INFO    : Bus 72325	: V=1.0168136, theta=-68.197912 -> V=1.0, theta=0.0
% INFO    : Bus 72326	: V=1.0081182, theta=-67.878783 -> V=1.0, theta=0.0
% INFO    : Bus 72327	: V=1.0087583, theta=-67.99239 -> V=1.0, theta=0.0
% INFO    : Bus 72328	: V=1.0098098, theta=-67.992477 -> V=1.0, theta=0.0
% INFO    : Bus 72329	: V=1.0120768, theta=-67.965509 -> V=1.0, theta=0.0
% INFO    : Bus 72330	: V=1.0069034, theta=-68.064454 -> V=1.0, theta=0.0
% INFO    : Bus 72331	: V=1.008045, theta=-68.046905 -> V=1.0, theta=0.0
% INFO    : Bus 72332	: V=1.003673, theta=-67.899543 -> V=1.0, theta=0.0
% INFO    : Bus 72333	: V=1.0021819, theta=-67.944018 -> V=1.0, theta=0.0
% INFO    : Bus 72334	: V=1.0025217, theta=-67.563294 -> V=1.0, theta=0.0
% INFO    : Bus 72335	: V=1.0015036, theta=-67.489779 -> V=1.0, theta=0.0
% INFO    : Bus 72336	: V=1.0056186, theta=-67.780471 -> V=1.0, theta=0.0
% INFO    : Bus 72337	: V=1.0043503, theta=-67.732458 -> V=1.0, theta=0.0
% INFO    : Bus 72338	: V=1.0038011, theta=-67.771115 -> V=1.0, theta=0.0
% INFO    : Bus 72339	: V=1.003433, theta=-67.795676 -> V=1.0, theta=0.0
% INFO    : Bus 72340	: V=1.0031851, theta=-67.798746 -> V=1.0, theta=0.0
% INFO    : Bus 72341	: V=1.0030845, theta=-67.746446 -> V=1.0, theta=0.0
% INFO    : Bus 72342	: V=1.0030497, theta=-67.539067 -> V=1.0, theta=0.0
% INFO    : Bus 72343	: V=1.0031077, theta=-67.655097 -> V=1.0, theta=0.0
% INFO    : Bus 72344	: V=1.005225, theta=-67.575127 -> V=1.0, theta=0.0
% INFO    : Bus 72345	: V=1.0042224, theta=-67.615005 -> V=1.0, theta=0.0
% INFO    : Bus 72346	: V=1.0046921, theta=-67.526336 -> V=1.0, theta=0.0
% INFO    : Bus 72347	: V=1.0046018, theta=-67.495029 -> V=1.0, theta=0.0
% INFO    : Bus 72348	: V=1.0043083, theta=-67.495574 -> V=1.0, theta=0.0
% INFO    : Bus 72349	: V=1.0045646, theta=-67.422135 -> V=1.0, theta=0.0
% INFO    : Bus 72350	: V=1.004505, theta=-67.30875 -> V=1.0, theta=0.0
% INFO    : Bus 72351	: V=1.0051368, theta=-67.320667 -> V=1.0, theta=0.0
% INFO    : Bus 72352	: V=1.0050999, theta=-67.286579 -> V=1.0, theta=0.0
% INFO    : Bus 72353	: V=1.004747, theta=-66.096808 -> V=1.0, theta=0.0
% INFO    : Bus 72354	: V=1.0033226, theta=-66.431361 -> V=1.0, theta=0.0
% INFO    : Bus 72355	: V=1.0021688, theta=-66.766034 -> V=1.0, theta=0.0
% INFO    : Bus 72356	: V=0.9995278, theta=-66.832381 -> V=1.0, theta=0.0
% INFO    : Bus 72357	: V=0.9974251, theta=-66.890238 -> V=1.0, theta=0.0
% INFO    : Bus 72358	: V=0.9955883, theta=-66.898132 -> V=1.0, theta=0.0
% INFO    : Bus 72359	: V=0.9951602, theta=-66.899205 -> V=1.0, theta=0.0
% INFO    : Bus 72360	: V=0.9980823, theta=-66.820105 -> V=1.0, theta=0.0
% INFO    : Bus 72361	: V=0.9971595, theta=-66.859625 -> V=1.0, theta=0.0
% INFO    : Bus 72362	: V=0.9958532, theta=-66.888214 -> V=1.0, theta=0.0
% INFO    : Bus 72363	: V=0.9965789, theta=-66.888105 -> V=1.0, theta=0.0
% INFO    : Bus 72364	: V=0.9976721, theta=-66.763294 -> V=1.0, theta=0.0
% INFO    : Bus 72365	: V=1.0086303, theta=-65.763256 -> V=1.0, theta=0.0
% INFO    : Bus 72366	: V=1.0065695, theta=-66.204359 -> V=1.0, theta=0.0
% INFO    : Bus 72367	: V=0.9991711, theta=-66.774644 -> V=1.0, theta=0.0
% INFO    : Bus 72368	: V=1.001484, theta=-66.70139 -> V=1.0, theta=0.0
% INFO    : Bus 72369	: V=1.0076094, theta=-66.076455 -> V=1.0, theta=0.0
% INFO    : Bus 72370	: V=1.0050123, theta=-67.283294 -> V=1.0, theta=0.0
% INFO    : Bus 72371	: V=1.00556, theta=-66.948408 -> V=1.0, theta=0.0
% INFO    : Bus 72372	: V=1.0054606, theta=-67.170277 -> V=1.0, theta=0.0
% INFO    : Bus 72373	: V=1.0052131, theta=-67.181492 -> V=1.0, theta=0.0
% INFO    : Bus 72374	: V=1.006172, theta=-66.892006 -> V=1.0, theta=0.0
% INFO    : Bus 72375	: V=1.0057453, theta=-66.918977 -> V=1.0, theta=0.0
% INFO    : Bus 72376	: V=1.0058062, theta=-67.174985 -> V=1.0, theta=0.0
% INFO    : Bus 72377	: V=1.0052994, theta=-67.193879 -> V=1.0, theta=0.0
% INFO    : Bus 72378	: V=1.0072061, theta=-65.81503 -> V=1.0, theta=0.0
% INFO    : Bus 72379	: V=1.0147863, theta=-65.512664 -> V=1.0, theta=0.0
% INFO    : Bus 72380	: V=1.0063819, theta=-65.593594 -> V=1.0, theta=0.0
% INFO    : Bus 72381	: V=1.0063357, theta=-66.739567 -> V=1.0, theta=0.0
% INFO    : Bus 72382	: V=1.0029933, theta=-66.832357 -> V=1.0, theta=0.0
% INFO    : Bus 72383	: V=0.9994808, theta=-66.895571 -> V=1.0, theta=0.0
% INFO    : Bus 72384	: V=1.0002518, theta=-66.863998 -> V=1.0, theta=0.0
% INFO    : Bus 72385	: V=0.9994556, theta=-66.893697 -> V=1.0, theta=0.0
% INFO    : Bus 72386	: V=0.9996493, theta=-66.784282 -> V=1.0, theta=0.0
% INFO    : Bus 72387	: V=0.9975658, theta=-66.73649 -> V=1.0, theta=0.0
% INFO    : Bus 72388	: V=0.9969174, theta=-66.735887 -> V=1.0, theta=0.0
% INFO    : Bus 72389	: V=1.0009176, theta=-66.888053 -> V=1.0, theta=0.0
% INFO    : Bus 72390	: V=0.9995467, theta=-66.931536 -> V=1.0, theta=0.0
% INFO    : Bus 72391	: V=0.9990642, theta=-66.937892 -> V=1.0, theta=0.0
% INFO    : Bus 72392	: V=0.9993085, theta=-66.914418 -> V=1.0, theta=0.0
% INFO    : Bus 72393	: V=0.9999474, theta=-66.501036 -> V=1.0, theta=0.0
% INFO    : Bus 72394	: V=1.0002231, theta=-66.777285 -> V=1.0, theta=0.0
% INFO    : Bus 72395	: V=1.0000237, theta=-66.539247 -> V=1.0, theta=0.0
% INFO    : Bus 72396	: V=0.998558, theta=-65.160805 -> V=1.0, theta=0.0
% INFO    : Bus 72397	: V=1.0017617, theta=-65.763042 -> V=1.0, theta=0.0
% INFO    : Bus 72398	: V=1.0013299, theta=-66.133096 -> V=1.0, theta=0.0
% INFO    : Bus 72399	: V=1.0006832, theta=-66.27389 -> V=1.0, theta=0.0
% INFO    : Bus 72400	: V=1.0017865, theta=-65.036715 -> V=1.0, theta=0.0
% INFO    : Bus 72401	: V=1.0023057, theta=-65.422427 -> V=1.0, theta=0.0
% INFO    : Bus 72402	: V=1.0017413, theta=-65.619267 -> V=1.0, theta=0.0
% INFO    : Bus 72403	: V=1.0014507, theta=-65.820085 -> V=1.0, theta=0.0
% INFO    : Bus 72404	: V=0.9524695, theta=-62.490905 -> V=1.0, theta=0.0
% INFO    : Bus 72405	: V=0.9948382, theta=-70.213838 -> V=1.0, theta=0.0
% INFO    : Bus 72406	: V=0.9963896, theta=-67.974429 -> V=1.0, theta=0.0
% INFO    : Bus 72407	: V=1.0013165, theta=-66.957438 -> V=1.0, theta=0.0
% INFO    : Bus 72408	: V=1.0026525, theta=-64.960303 -> V=1.0, theta=0.0
% INFO    : Bus 72409	: V=1.0057614, theta=-64.373742 -> V=1.0, theta=0.0
% INFO    : Bus 72410	: V=1.0068222, theta=-63.793991 -> V=1.0, theta=0.0
% INFO    : Bus 72411	: V=1.0089441, theta=-62.917128 -> V=1.0, theta=0.0
% INFO    : Bus 72412	: V=0.9993932, theta=-61.442709 -> V=1.0, theta=0.0
% INFO    : Bus 72413	: V=1.0046356, theta=-64.941004 -> V=1.0, theta=0.0
% INFO    : Bus 72414	: V=1.0015806, theta=-66.700288 -> V=1.0, theta=0.0
% INFO    : Bus 72415	: V=1.0001466, theta=-68.043166 -> V=1.0, theta=0.0
% INFO    : Bus 72416	: V=0.9995585, theta=-69.385712 -> V=1.0, theta=0.0
% INFO    : Bus 72417	: V=0.9884425, theta=-57.650058 -> V=1.0, theta=0.0
% INFO    : Bus 72418	: V=0.9885443, theta=-57.556719 -> V=1.0, theta=0.0
% INFO    : Bus 72419	: V=0.9886757, theta=-57.640084 -> V=1.0, theta=0.0
% INFO    : Bus 72420	: V=1.0033824, theta=-65.684973 -> V=1.0, theta=0.0
% INFO    : Bus 72421	: V=1.0051165, theta=-65.078256 -> V=1.0, theta=0.0
% INFO    : Bus 72422	: V=1.0017461, theta=-65.19272 -> V=1.0, theta=0.0
% INFO    : Bus 72423	: V=1.0011444, theta=-65.179923 -> V=1.0, theta=0.0
% INFO    : Bus 72424	: V=1.0011061, theta=-65.105901 -> V=1.0, theta=0.0
% INFO    : Bus 72425	: V=0.9979468, theta=-65.226818 -> V=1.0, theta=0.0
% INFO    : Bus 72426	: V=0.9977277, theta=-65.022048 -> V=1.0, theta=0.0
% INFO    : Bus 72427	: V=0.9992581, theta=-64.951993 -> V=1.0, theta=0.0
% INFO    : Bus 72428	: V=1.0008085, theta=-64.808389 -> V=1.0, theta=0.0
% INFO    : Bus 72429	: V=1.0003413, theta=-64.339021 -> V=1.0, theta=0.0
% INFO    : Bus 72430	: V=0.9998756, theta=-65.043408 -> V=1.0, theta=0.0
% INFO    : Bus 72431	: V=0.9983823, theta=-65.267131 -> V=1.0, theta=0.0
% INFO    : Bus 72432	: V=1.0067418, theta=-63.613935 -> V=1.0, theta=0.0
% INFO    : Bus 72433	: V=0.9988212, theta=-65.219135 -> V=1.0, theta=0.0
% INFO    : Bus 72434	: V=1.0021591, theta=-65.672158 -> V=1.0, theta=0.0
% INFO    : Bus 72435	: V=1.00221, theta=-65.526261 -> V=1.0, theta=0.0
% INFO    : Bus 72436	: V=1.0031559, theta=-65.322827 -> V=1.0, theta=0.0
% INFO    : Bus 72437	: V=1.0030386, theta=-65.347975 -> V=1.0, theta=0.0
% INFO    : Bus 72438	: V=1.0033425, theta=-65.194234 -> V=1.0, theta=0.0
% INFO    : Bus 72439	: V=0.9997145, theta=-65.248369 -> V=1.0, theta=0.0
% INFO    : Bus 72440	: V=1.0026681, theta=-65.287779 -> V=1.0, theta=0.0
% INFO    : Bus 72441	: V=1.0021918, theta=-65.934677 -> V=1.0, theta=0.0
% INFO    : Bus 72442	: V=1.0020397, theta=-65.471694 -> V=1.0, theta=0.0
% INFO    : Bus 72443	: V=1.0042959, theta=-65.521537 -> V=1.0, theta=0.0
% INFO    : Bus 72444	: V=1.0045168, theta=-65.56148 -> V=1.0, theta=0.0
% INFO    : Bus 72445	: V=1.0064992, theta=-64.381429 -> V=1.0, theta=0.0
% INFO    : Bus 72446	: V=1.0042835, theta=-65.705107 -> V=1.0, theta=0.0
% INFO    : Bus 72447	: V=1.0035277, theta=-65.787875 -> V=1.0, theta=0.0
% INFO    : Bus 72448	: V=1.0028347, theta=-65.902411 -> V=1.0, theta=0.0
% INFO    : Bus 72449	: V=1.0038467, theta=-66.244742 -> V=1.0, theta=0.0
% INFO    : Bus 72450	: V=1.0028726, theta=-65.968947 -> V=1.0, theta=0.0
% INFO    : Bus 72451	: V=1.0072219, theta=-64.587202 -> V=1.0, theta=0.0
% INFO    : Bus 72452	: V=1.0069504, theta=-64.528782 -> V=1.0, theta=0.0
% INFO    : Bus 72453	: V=1.0041443, theta=-65.625831 -> V=1.0, theta=0.0
% INFO    : Bus 72454	: V=1.0035443, theta=-65.650455 -> V=1.0, theta=0.0
% INFO    : Bus 72455	: V=1.0077986, theta=-64.666084 -> V=1.0, theta=0.0
% INFO    : Bus 72456	: V=1.0086728, theta=-64.756433 -> V=1.0, theta=0.0
% INFO    : Bus 72457	: V=1.003077, theta=-65.360088 -> V=1.0, theta=0.0
% INFO    : Bus 72458	: V=1.0067541, theta=-63.815715 -> V=1.0, theta=0.0
% INFO    : Bus 72459	: V=0.9557334, theta=-37.168157 -> V=1.0, theta=0.0
% INFO    : Bus 72460	: V=0.9693304, theta=-48.034246 -> V=1.0, theta=0.0
% INFO    : Bus 72461	: V=0.9643543, theta=-40.929276 -> V=1.0, theta=0.0
% INFO    : Bus 72462	: V=1.0030974, theta=-56.664834 -> V=1.0, theta=0.0
% INFO    : Bus 72463	: V=1.0051793, theta=-56.575937 -> V=1.0, theta=0.0
% INFO    : Bus 72464	: V=1.0025271, theta=-56.760797 -> V=1.0, theta=0.0
% INFO    : Bus 72465	: V=1.006393, theta=-56.065043 -> V=1.0, theta=0.0
% INFO    : Bus 72466	: V=0.9837737, theta=-58.861015 -> V=1.0, theta=0.0
% INFO    : Bus 72467	: V=0.9950897, theta=-57.326972 -> V=1.0, theta=0.0
% INFO    : Bus 72468	: V=1.0108589, theta=-55.174645 -> V=1.0, theta=0.0
% INFO    : Bus 72469	: V=0.9988677, theta=-57.158992 -> V=1.0, theta=0.0
% INFO    : Bus 72470	: V=0.9959357, theta=-57.283343 -> V=1.0, theta=0.0
% INFO    : Bus 72471	: V=0.9861552, theta=-58.731091 -> V=1.0, theta=0.0
% INFO    : Bus 72472	: V=0.9827549, theta=-58.905488 -> V=1.0, theta=0.0
% INFO    : Bus 72473	: V=0.9968618, theta=-56.906141 -> V=1.0, theta=0.0
% INFO    : Bus 72474	: V=1.0168145, theta=-64.466283 -> V=1.0, theta=0.0
% INFO    : Bus 72475	: V=1.0114616, theta=-18.81226 -> V=1.0, theta=0.0
% INFO    : Bus 72476	: V=1.0115094, theta=-66.840449 -> V=1.0, theta=0.0
% INFO    : Bus 72477	: V=1.0070029, theta=-66.758155 -> V=1.0, theta=0.0
% INFO    : Bus 72478	: V=1.0075615, theta=-66.666525 -> V=1.0, theta=0.0
% INFO    : Bus 72479	: V=1.0051955, theta=-66.619947 -> V=1.0, theta=0.0
% INFO    : Bus 72480	: V=1.00525, theta=-66.222946 -> V=1.0, theta=0.0
% INFO    : Bus 72481	: V=1.0053145, theta=-66.784529 -> V=1.0, theta=0.0
% INFO    : Bus 72482	: V=1.0053734, theta=-67.012153 -> V=1.0, theta=0.0
% INFO    : Bus 72483	: V=1.0053054, theta=-65.046708 -> V=1.0, theta=0.0
% INFO    : Bus 72484	: V=1.0039118, theta=-64.009092 -> V=1.0, theta=0.0
% INFO    : Bus 72485	: V=1.0257215, theta=-63.940309 -> V=1.0, theta=0.0
% INFO    : Bus 72486	: V=1.0241166, theta=-63.828667 -> V=1.0, theta=0.0
% INFO    : Bus 72487	: V=1.0251892, theta=-63.963107 -> V=1.0, theta=0.0
% INFO    : Bus 72488	: V=1.0250667, theta=-63.967898 -> V=1.0, theta=0.0
% INFO    : Bus 72489	: V=1.0026408, theta=-62.63643 -> V=1.0, theta=0.0
% INFO    : Bus 72490	: V=1.0243223, theta=-64.083184 -> V=1.0, theta=0.0
% INFO    : Bus 72491	: V=1.0237209, theta=-64.107643 -> V=1.0, theta=0.0
% INFO    : Bus 72492	: V=1.0198878, theta=-64.323719 -> V=1.0, theta=0.0
% INFO    : Bus 72493	: V=1.018357, theta=-63.183899 -> V=1.0, theta=0.0
% INFO    : Bus 72494	: V=1.0057171, theta=-55.198455 -> V=1.0, theta=0.0
% INFO    : Bus 72495	: V=0.9905867, theta=-61.20604 -> V=1.0, theta=0.0
% INFO    : Bus 72496	: V=0.9875885, theta=-58.889119 -> V=1.0, theta=0.0
% INFO    : Bus 72497	: V=0.9907582, theta=-57.244621 -> V=1.0, theta=0.0
% INFO    : Bus 72498	: V=0.9896134, theta=-57.530122 -> V=1.0, theta=0.0
% INFO    : Bus 72499	: V=1.0067289, theta=-55.445211 -> V=1.0, theta=0.0
% INFO    : Bus 72500	: V=0.9995169, theta=-63.39715 -> V=1.0, theta=0.0
% INFO    : Bus 72501	: V=1.0018367, theta=-61.412558 -> V=1.0, theta=0.0
% INFO    : Bus 72502	: V=0.9941323, theta=-57.39566 -> V=1.0, theta=0.0
% INFO    : Bus 72503	: V=1.0023824, theta=-75.405655 -> V=1.0, theta=0.0
% INFO    : Bus 72504	: V=1.0056837, theta=-67.032491 -> V=1.0, theta=0.0
% INFO    : Bus 72505	: V=0.9966621, theta=-66.882822 -> V=1.0, theta=0.0
% INFO    : Bus 72506	: V=0.995483, theta=-66.892321 -> V=1.0, theta=0.0
% INFO    : Bus 72507	: V=1.0100003, theta=-70.032279 -> V=1.0, theta=0.0
% INFO    : Bus 72508	: V=0.990759, theta=-56.981563 -> V=1.0, theta=0.0
% INFO    : Bus 72509	: V=0.9937718, theta=-18.666055 -> V=1.0, theta=0.0
% INFO    : Bus 72510	: V=0.9923313, theta=-18.706594 -> V=1.0, theta=0.0
% INFO    : Bus 72511	: V=1.0084083, theta=-65.987195 -> V=1.0, theta=0.0
% INFO    : Bus 72512	: V=1.0104107, theta=-62.540397 -> V=1.0, theta=0.0
% INFO    : Bus 72513	: V=0.9941824, theta=-63.883822 -> V=1.0, theta=0.0
% INFO    : Bus 72514	: V=0.994607, theta=-63.881194 -> V=1.0, theta=0.0
% INFO    : Bus 72515	: V=0.9941832, theta=-63.940433 -> V=1.0, theta=0.0
% INFO    : Bus 72516	: V=0.9948774, theta=-63.915207 -> V=1.0, theta=0.0
% INFO    : Bus 72517	: V=0.9954925, theta=-63.828482 -> V=1.0, theta=0.0
% INFO    : Bus 72518	: V=0.9975503, theta=-63.690569 -> V=1.0, theta=0.0
% INFO    : Bus 72519	: V=0.996661, theta=-63.747557 -> V=1.0, theta=0.0
% INFO    : Bus 72520	: V=0.9969574, theta=-63.7271 -> V=1.0, theta=0.0
% INFO    : Bus 72521	: V=1.0020821, theta=-63.047852 -> V=1.0, theta=0.0
% INFO    : Bus 72522	: V=1.0022743, theta=-63.037417 -> V=1.0, theta=0.0
% INFO    : Bus 72523	: V=1.002629, theta=-63.015336 -> V=1.0, theta=0.0
% INFO    : Bus 72524	: V=0.9997133, theta=-63.593223 -> V=1.0, theta=0.0
% INFO    : Bus 72525	: V=0.9988295, theta=-63.633157 -> V=1.0, theta=0.0
% INFO    : Bus 72526	: V=1.0021795, theta=-63.049603 -> V=1.0, theta=0.0
% INFO    : Bus 72527	: V=1.0019679, theta=-63.062489 -> V=1.0, theta=0.0
% INFO    : Bus 72528	: V=0.9968723, theta=-63.812422 -> V=1.0, theta=0.0
% INFO    : Bus 72529	: V=0.9977261, theta=-63.771674 -> V=1.0, theta=0.0
% INFO    : Bus 72530	: V=0.9974278, theta=-63.782811 -> V=1.0, theta=0.0
% INFO    : Bus 72531	: V=0.9979199, theta=-63.70893 -> V=1.0, theta=0.0
% INFO    : Bus 72532	: V=0.9985892, theta=-63.671804 -> V=1.0, theta=0.0
% INFO    : Bus 72533	: V=0.9960263, theta=-63.89011 -> V=1.0, theta=0.0
% INFO    : Bus 72534	: V=0.9965536, theta=-63.895585 -> V=1.0, theta=0.0
% INFO    : Bus 72535	: V=0.9958454, theta=-63.917177 -> V=1.0, theta=0.0
% INFO    : Bus 72536	: V=0.9959868, theta=-63.891926 -> V=1.0, theta=0.0
% INFO    : Bus 72537	: V=0.9959397, theta=-63.921069 -> V=1.0, theta=0.0
% INFO    : Bus 72538	: V=0.9963107, theta=-63.91769 -> V=1.0, theta=0.0
% INFO    : Bus 72539	: V=0.9963733, theta=-63.920276 -> V=1.0, theta=0.0
% INFO    : Bus 72540	: V=0.9967337, theta=-63.840063 -> V=1.0, theta=0.0
% INFO    : Bus 72541	: V=0.9957016, theta=-63.929977 -> V=1.0, theta=0.0
% INFO    : Bus 72542	: V=0.9971322, theta=-63.850102 -> V=1.0, theta=0.0
% INFO    : Bus 72543	: V=0.9978171, theta=-63.845411 -> V=1.0, theta=0.0
% INFO    : Bus 72544	: V=0.996633, theta=-63.914319 -> V=1.0, theta=0.0
% INFO    : Bus 72545	: V=0.9969698, theta=-63.885215 -> V=1.0, theta=0.0
% INFO    : Bus 72546	: V=0.9977506, theta=-63.857872 -> V=1.0, theta=0.0
% INFO    : Bus 72547	: V=0.9984441, theta=-63.837694 -> V=1.0, theta=0.0
% INFO    : Bus 72548	: V=0.9970802, theta=-63.938877 -> V=1.0, theta=0.0
% INFO    : Bus 72549	: V=0.9962013, theta=-63.924584 -> V=1.0, theta=0.0
% INFO    : Bus 72550	: V=0.9972875, theta=-63.891186 -> V=1.0, theta=0.0
% INFO    : Bus 72551	: V=0.9967183, theta=-63.916628 -> V=1.0, theta=0.0
% INFO    : Bus 72552	: V=0.9968925, theta=-63.912539 -> V=1.0, theta=0.0
% INFO    : Bus 72553	: V=0.9982625, theta=-63.844504 -> V=1.0, theta=0.0
% INFO    : Bus 72554	: V=0.9975306, theta=-63.922012 -> V=1.0, theta=0.0
% INFO    : Bus 72555	: V=0.9972787, theta=-63.805063 -> V=1.0, theta=0.0
% INFO    : Bus 72556	: V=0.9967582, theta=-63.869127 -> V=1.0, theta=0.0
% INFO    : Bus 72557	: V=0.9978289, theta=-63.813533 -> V=1.0, theta=0.0
% INFO    : Bus 72558	: V=0.9981807, theta=-63.778605 -> V=1.0, theta=0.0
% INFO    : Bus 72559	: V=0.9988317, theta=-63.76689 -> V=1.0, theta=0.0
% INFO    : Bus 72560	: V=0.998779, theta=-63.734646 -> V=1.0, theta=0.0
% INFO    : Bus 72561	: V=0.9993079, theta=-63.690869 -> V=1.0, theta=0.0
% INFO    : Bus 72562	: V=0.9975561, theta=-63.7461 -> V=1.0, theta=0.0
% INFO    : Bus 72563	: V=0.9981356, theta=-63.722174 -> V=1.0, theta=0.0
% INFO    : Bus 72564	: V=0.9971368, theta=-63.803769 -> V=1.0, theta=0.0
% INFO    : Bus 72565	: V=0.997137, theta=-63.85686 -> V=1.0, theta=0.0
% INFO    : Bus 72566	: V=0.9969695, theta=-63.812574 -> V=1.0, theta=0.0
% INFO    : Bus 72567	: V=0.9948084, theta=-63.743384 -> V=1.0, theta=0.0
% INFO    : Bus 72568	: V=0.995098, theta=-63.731517 -> V=1.0, theta=0.0
% INFO    : Bus 72569	: V=0.9955546, theta=-63.713497 -> V=1.0, theta=0.0
% INFO    : Bus 72570	: V=0.9940541, theta=-63.873875 -> V=1.0, theta=0.0
% INFO    : Bus 72571	: V=0.9964179, theta=-63.875803 -> V=1.0, theta=0.0
% INFO    : Bus 72572	: V=0.9965951, theta=-63.84869 -> V=1.0, theta=0.0
% INFO    : Bus 72573	: V=0.9950772, theta=-63.867515 -> V=1.0, theta=0.0
% INFO    : Bus 72574	: V=0.9967807, theta=-63.819663 -> V=1.0, theta=0.0
% INFO    : Bus 72575	: V=0.9945941, theta=-63.823192 -> V=1.0, theta=0.0
% INFO    : Bus 72576	: V=0.9931898, theta=-63.87059 -> V=1.0, theta=0.0
% INFO    : Bus 72577	: V=0.990225, theta=-63.876264 -> V=1.0, theta=0.0
% INFO    : Bus 72578	: V=0.9896311, theta=-63.76685 -> V=1.0, theta=0.0
% INFO    : Bus 72579	: V=0.9916904, theta=-63.7499 -> V=1.0, theta=0.0
% INFO    : Bus 72580	: V=0.9917167, theta=-63.85576 -> V=1.0, theta=0.0
% INFO    : Bus 72581	: V=0.9924319, theta=-63.823917 -> V=1.0, theta=0.0
% INFO    : Bus 72582	: V=0.9910312, theta=-63.869366 -> V=1.0, theta=0.0
% INFO    : Bus 72583	: V=0.9899323, theta=-63.887334 -> V=1.0, theta=0.0
% INFO    : Bus 72584	: V=0.9933936, theta=-63.807273 -> V=1.0, theta=0.0
% INFO    : Bus 72585	: V=0.9940992, theta=-63.782698 -> V=1.0, theta=0.0
% INFO    : Bus 72586	: V=1.0001369, theta=-63.811034 -> V=1.0, theta=0.0
% INFO    : Bus 72587	: V=0.9981073, theta=-63.806198 -> V=1.0, theta=0.0
% INFO    : Bus 72588	: V=0.9980985, theta=-63.85825 -> V=1.0, theta=0.0
% INFO    : Bus 72589	: V=0.9982213, theta=-63.843974 -> V=1.0, theta=0.0
% INFO    : Bus 72590	: V=0.9979157, theta=-63.86297 -> V=1.0, theta=0.0
% INFO    : Bus 72591	: V=0.9986857, theta=-63.855841 -> V=1.0, theta=0.0
% INFO    : Bus 72592	: V=0.9976901, theta=-63.87659 -> V=1.0, theta=0.0
% INFO    : Bus 72593	: V=1.0001428, theta=-63.823654 -> V=1.0, theta=0.0
% INFO    : Bus 72594	: V=1.0015858, theta=-63.791025 -> V=1.0, theta=0.0
% INFO    : Bus 72595	: V=1.0032765, theta=-63.692754 -> V=1.0, theta=0.0
% INFO    : Bus 72596	: V=1.0019264, theta=-63.738808 -> V=1.0, theta=0.0
% INFO    : Bus 72597	: V=1.0018359, theta=-63.717953 -> V=1.0, theta=0.0
% INFO    : Bus 72598	: V=1.0057377, theta=-63.548511 -> V=1.0, theta=0.0
% INFO    : Bus 72599	: V=1.0016933, theta=-63.665724 -> V=1.0, theta=0.0
% INFO    : Bus 72600	: V=1.0032712, theta=-63.65563 -> V=1.0, theta=0.0
% INFO    : Bus 72601	: V=1.000893, theta=-63.666131 -> V=1.0, theta=0.0
% INFO    : Bus 72602	: V=1.0016109, theta=-63.075003 -> V=1.0, theta=0.0
% INFO    : Bus 72603	: V=0.998636, theta=-63.793548 -> V=1.0, theta=0.0
% INFO    : Bus 72604	: V=1.0017395, theta=-63.078206 -> V=1.0, theta=0.0
% INFO    : Bus 72605	: V=1.0016451, theta=-63.07836 -> V=1.0, theta=0.0
% INFO    : Bus 72606	: V=0.99892, theta=-63.754337 -> V=1.0, theta=0.0
% INFO    : Bus 72607	: V=0.9965125, theta=-63.798266 -> V=1.0, theta=0.0
% INFO    : Bus 72608	: V=0.9961991, theta=-63.809372 -> V=1.0, theta=0.0
% INFO    : Bus 72609	: V=0.9970669, theta=-63.789145 -> V=1.0, theta=0.0
% INFO    : Bus 72610	: V=0.9974354, theta=-63.783309 -> V=1.0, theta=0.0
% INFO    : Bus 72611	: V=1.0156504, theta=-61.952906 -> V=1.0, theta=0.0
% INFO    : Bus 72612	: V=1.0003093, theta=-63.167316 -> V=1.0, theta=0.0
% INFO    : Bus 72613	: V=0.9939227, theta=-63.930133 -> V=1.0, theta=0.0
% INFO    : Bus 72614	: V=0.9926751, theta=-64.050295 -> V=1.0, theta=0.0
% INFO    : Bus 72615	: V=0.9913651, theta=-64.123576 -> V=1.0, theta=0.0
% INFO    : Bus 72616	: V=0.9971394, theta=-63.783933 -> V=1.0, theta=0.0
% INFO    : Bus 72617	: V=1.0019613, theta=-63.049885 -> V=1.0, theta=0.0
% INFO    : Bus 72618	: V=0.9936522, theta=-64.046255 -> V=1.0, theta=0.0
% INFO    : Bus 72619	: V=0.9940626, theta=-64.081218 -> V=1.0, theta=0.0
% INFO    : Bus 72620	: V=0.9940669, theta=-64.034411 -> V=1.0, theta=0.0
% INFO    : Bus 72621	: V=0.9943665, theta=-63.982913 -> V=1.0, theta=0.0
% INFO    : Bus 72622	: V=0.9939513, theta=-63.994203 -> V=1.0, theta=0.0
% INFO    : Bus 72623	: V=0.9952207, theta=-64.309438 -> V=1.0, theta=0.0
% INFO    : Bus 72624	: V=0.9966016, theta=-64.412487 -> V=1.0, theta=0.0
% INFO    : Bus 72625	: V=0.9956149, theta=-64.346516 -> V=1.0, theta=0.0
% INFO    : Bus 72626	: V=0.9970062, theta=-64.476597 -> V=1.0, theta=0.0
% INFO    : Bus 72627	: V=0.9945253, theta=-64.618763 -> V=1.0, theta=0.0
% INFO    : Bus 72628	: V=0.9953026, theta=-64.575454 -> V=1.0, theta=0.0
% INFO    : Bus 72629	: V=0.9948776, theta=-64.583171 -> V=1.0, theta=0.0
% INFO    : Bus 72630	: V=0.9949077, theta=-64.68855 -> V=1.0, theta=0.0
% INFO    : Bus 72631	: V=0.993646, theta=-64.74018 -> V=1.0, theta=0.0
% INFO    : Bus 72632	: V=0.9930518, theta=-64.749513 -> V=1.0, theta=0.0
% INFO    : Bus 72633	: V=0.9934347, theta=-64.688376 -> V=1.0, theta=0.0
% INFO    : Bus 72634	: V=0.9940717, theta=-64.687053 -> V=1.0, theta=0.0
% INFO    : Bus 72635	: V=0.9937866, theta=-64.661849 -> V=1.0, theta=0.0
% INFO    : Bus 72636	: V=0.9934145, theta=-64.684142 -> V=1.0, theta=0.0
% INFO    : Bus 72637	: V=0.9934283, theta=-64.687153 -> V=1.0, theta=0.0
% INFO    : Bus 72638	: V=0.9906771, theta=-64.119838 -> V=1.0, theta=0.0
% INFO    : Bus 72639	: V=0.9893454, theta=-64.048926 -> V=1.0, theta=0.0
% INFO    : Bus 72640	: V=0.9894646, theta=-64.066416 -> V=1.0, theta=0.0
% INFO    : Bus 72641	: V=0.9926172, theta=-63.755228 -> V=1.0, theta=0.0
% INFO    : Bus 72642	: V=0.9889217, theta=-64.006551 -> V=1.0, theta=0.0
% INFO    : Bus 72643	: V=0.9889638, theta=-64.051557 -> V=1.0, theta=0.0
% INFO    : Bus 72644	: V=0.9895698, theta=-64.0028 -> V=1.0, theta=0.0
% INFO    : Bus 72645	: V=0.9889805, theta=-64.008134 -> V=1.0, theta=0.0
% INFO    : Bus 72646	: V=0.9891427, theta=-64.040685 -> V=1.0, theta=0.0
% INFO    : Bus 72647	: V=0.9887553, theta=-64.008035 -> V=1.0, theta=0.0
% INFO    : Bus 72648	: V=0.9889302, theta=-64.062394 -> V=1.0, theta=0.0
% INFO    : Bus 72649	: V=0.9893294, theta=-64.075557 -> V=1.0, theta=0.0
% INFO    : Bus 72650	: V=0.9963287, theta=-64.154197 -> V=1.0, theta=0.0
% INFO    : Bus 72651	: V=0.9928822, theta=-64.145076 -> V=1.0, theta=0.0
% INFO    : Bus 72652	: V=0.9984859, theta=-64.118523 -> V=1.0, theta=0.0
% INFO    : Bus 72653	: V=0.9947359, theta=-63.633035 -> V=1.0, theta=0.0
% INFO    : Bus 72654	: V=0.9976654, theta=-64.11575 -> V=1.0, theta=0.0
% INFO    : Bus 72655	: V=1.0020468, theta=-63.004176 -> V=1.0, theta=0.0
% INFO    : Bus 72656	: V=1.0003439, theta=-63.476146 -> V=1.0, theta=0.0
% INFO    : Bus 72657	: V=1.0011935, theta=-63.312591 -> V=1.0, theta=0.0
% INFO    : Bus 72658	: V=0.996466, theta=-63.506373 -> V=1.0, theta=0.0
% INFO    : Bus 72659	: V=0.9912632, theta=-64.115691 -> V=1.0, theta=0.0
% INFO    : Bus 72660	: V=1.0030971, theta=-63.712417 -> V=1.0, theta=0.0
% INFO    : Bus 72661	: V=1.0021975, theta=-63.6255 -> V=1.0, theta=0.0
% INFO    : Bus 72662	: V=1.0060524, theta=-62.65296 -> V=1.0, theta=0.0
% INFO    : Bus 72663	: V=1.0065333, theta=-62.651516 -> V=1.0, theta=0.0
% INFO    : Bus 72664	: V=1.0017077, theta=-63.345916 -> V=1.0, theta=0.0
% INFO    : Bus 72665	: V=1.005568, theta=-62.655365 -> V=1.0, theta=0.0
% INFO    : Bus 72666	: V=0.9999838, theta=-63.256903 -> V=1.0, theta=0.0
% INFO    : Bus 72667	: V=1.0050849, theta=-62.614851 -> V=1.0, theta=0.0
% INFO    : Bus 72668	: V=1.0042558, theta=-62.533074 -> V=1.0, theta=0.0
% INFO    : Bus 72669	: V=1.002921, theta=-63.044303 -> V=1.0, theta=0.0
% INFO    : Bus 72670	: V=0.9982387, theta=-63.658008 -> V=1.0, theta=0.0
% INFO    : Bus 72671	: V=0.9985352, theta=-63.645858 -> V=1.0, theta=0.0
% INFO    : Bus 72672	: V=1.0026951, theta=-62.902949 -> V=1.0, theta=0.0
% INFO    : Bus 72673	: V=1.0023463, theta=-62.977 -> V=1.0, theta=0.0
% INFO    : Bus 72674	: V=1.0021838, theta=-62.996559 -> V=1.0, theta=0.0
% INFO    : Bus 72675	: V=1.0014849, theta=-63.467629 -> V=1.0, theta=0.0
% INFO    : Bus 72676	: V=1.0009539, theta=-62.964685 -> V=1.0, theta=0.0
% INFO    : Bus 72677	: V=1.0000095, theta=-63.090931 -> V=1.0, theta=0.0
% INFO    : Bus 72678	: V=1.0035493, theta=-62.415528 -> V=1.0, theta=0.0
% INFO    : Bus 72679	: V=0.9939165, theta=-63.443292 -> V=1.0, theta=0.0
% INFO    : Bus 72680	: V=0.9940679, theta=-63.280005 -> V=1.0, theta=0.0
% INFO    : Bus 72681	: V=0.9945273, theta=-63.433478 -> V=1.0, theta=0.0
% INFO    : Bus 72682	: V=1.0100002, theta=-61.691757 -> V=1.0, theta=0.0
% INFO    : Bus 72683	: V=0.9948072, theta=-63.277115 -> V=1.0, theta=0.0
% INFO    : Bus 72684	: V=0.9945461, theta=-63.532517 -> V=1.0, theta=0.0
% INFO    : Bus 72685	: V=0.9949199, theta=-63.562608 -> V=1.0, theta=0.0
% INFO    : Bus 72686	: V=0.994046, theta=-63.758229 -> V=1.0, theta=0.0
% INFO    : Bus 72687	: V=0.9943166, theta=-63.616123 -> V=1.0, theta=0.0
% INFO    : Bus 72688	: V=0.9943312, theta=-63.485111 -> V=1.0, theta=0.0
% INFO    : Bus 72689	: V=0.993877, theta=-63.480989 -> V=1.0, theta=0.0
% INFO    : Bus 72690	: V=0.993611, theta=-63.45808 -> V=1.0, theta=0.0
% INFO    : Bus 72691	: V=0.9944798, theta=-63.551963 -> V=1.0, theta=0.0
% INFO    : Bus 72692	: V=0.9942946, theta=-63.413933 -> V=1.0, theta=0.0
% INFO    : Bus 72693	: V=1.0050409, theta=-63.790067 -> V=1.0, theta=0.0
% INFO    : Bus 72694	: V=1.0023539, theta=-63.622688 -> V=1.0, theta=0.0
% INFO    : Bus 72695	: V=1.0018691, theta=-63.53682 -> V=1.0, theta=0.0
% INFO    : Bus 72696	: V=1.0015185, theta=-63.539966 -> V=1.0, theta=0.0
% INFO    : Bus 72697	: V=0.9958516, theta=-63.604923 -> V=1.0, theta=0.0
% INFO    : Bus 72698	: V=0.9969649, theta=-63.630603 -> V=1.0, theta=0.0
% INFO    : Bus 72699	: V=0.9977022, theta=-63.501748 -> V=1.0, theta=0.0
% INFO    : Bus 72700	: V=0.9992308, theta=-63.364803 -> V=1.0, theta=0.0
% INFO    : Bus 72701	: V=0.9946212, theta=-63.587261 -> V=1.0, theta=0.0
% INFO    : Bus 72702	: V=0.9968916, theta=-63.426141 -> V=1.0, theta=0.0
% INFO    : Bus 72703	: V=0.9999074, theta=-63.13643 -> V=1.0, theta=0.0
% INFO    : Bus 72704	: V=1.0001359, theta=-63.161845 -> V=1.0, theta=0.0
% INFO    : Bus 72705	: V=1.0088357, theta=-61.63907 -> V=1.0, theta=0.0
% INFO    : Bus 72706	: V=1.0100002, theta=-63.049153 -> V=1.0, theta=0.0
% INFO    : Bus 72707	: V=1.0096475, theta=-63.049382 -> V=1.0, theta=0.0
% INFO    : Bus 72708	: V=1.0100002, theta=-61.297179 -> V=1.0, theta=0.0
% INFO    : Bus 72709	: V=0.9973886, theta=-63.529038 -> V=1.0, theta=0.0
% INFO    : Bus 72710	: V=0.9971537, theta=-63.530393 -> V=1.0, theta=0.0
% INFO    : Bus 72711	: V=0.9954488, theta=-63.62577 -> V=1.0, theta=0.0
% INFO    : Bus 72712	: V=1.0001309, theta=-63.494692 -> V=1.0, theta=0.0
% INFO    : Bus 72713	: V=1.0028055, theta=-62.999953 -> V=1.0, theta=0.0
% INFO    : Bus 72714	: V=0.995412, theta=-63.675485 -> V=1.0, theta=0.0
% INFO    : Bus 72715	: V=0.9947525, theta=-63.775429 -> V=1.0, theta=0.0
% INFO    : Bus 72716	: V=0.9942634, theta=-63.849838 -> V=1.0, theta=0.0
% INFO    : Bus 72717	: V=0.9944436, theta=-63.780183 -> V=1.0, theta=0.0
% INFO    : Bus 72718	: V=0.9942663, theta=-63.754117 -> V=1.0, theta=0.0
% INFO    : Bus 72719	: V=0.9956723, theta=-63.649739 -> V=1.0, theta=0.0
% INFO    : Bus 72720	: V=0.9932122, theta=-63.901353 -> V=1.0, theta=0.0
% INFO    : Bus 72721	: V=0.9927296, theta=-63.980529 -> V=1.0, theta=0.0
% INFO    : Bus 72722	: V=0.9924906, theta=-64.082434 -> V=1.0, theta=0.0
% INFO    : Bus 72723	: V=0.9936776, theta=-63.84864 -> V=1.0, theta=0.0
% INFO    : Bus 72724	: V=1.0032331, theta=-62.9804 -> V=1.0, theta=0.0
% INFO    : Bus 72725	: V=1.0033015, theta=-62.965849 -> V=1.0, theta=0.0
% INFO    : Bus 72726	: V=0.9957169, theta=-63.612333 -> V=1.0, theta=0.0
% INFO    : Bus 72727	: V=1.0111056, theta=-61.691154 -> V=1.0, theta=0.0
% INFO    : Bus 72728	: V=0.9954383, theta=-63.652112 -> V=1.0, theta=0.0
% INFO    : Bus 72729	: V=0.9954976, theta=-63.622607 -> V=1.0, theta=0.0
% INFO    : Bus 72730	: V=0.9984029, theta=-63.358476 -> V=1.0, theta=0.0
% INFO    : Bus 72731	: V=0.9968371, theta=-63.549493 -> V=1.0, theta=0.0
% INFO    : Bus 72732	: V=0.9977229, theta=-63.434329 -> V=1.0, theta=0.0
% INFO    : Bus 72733	: V=0.999956, theta=-63.109954 -> V=1.0, theta=0.0
% INFO    : Bus 72734	: V=0.99585, theta=-63.628164 -> V=1.0, theta=0.0
% INFO    : Bus 72735	: V=1.0001585, theta=-63.211399 -> V=1.0, theta=0.0
% INFO    : Bus 72736	: V=0.9964912, theta=-63.603808 -> V=1.0, theta=0.0
% INFO    : Bus 72737	: V=0.9960912, theta=-63.591746 -> V=1.0, theta=0.0
% INFO    : Bus 72738	: V=0.996029, theta=-63.61264 -> V=1.0, theta=0.0
% INFO    : Bus 72739	: V=0.9977841, theta=-63.703723 -> V=1.0, theta=0.0
% INFO    : Bus 72740	: V=0.995755, theta=-63.765957 -> V=1.0, theta=0.0
% INFO    : Bus 72741	: V=0.9968068, theta=-63.748827 -> V=1.0, theta=0.0
% INFO    : Bus 72742	: V=0.998557, theta=-63.651587 -> V=1.0, theta=0.0
% INFO    : Bus 72743	: V=0.999964, theta=-63.300604 -> V=1.0, theta=0.0
% INFO    : Bus 72744	: V=0.9976486, theta=-63.732171 -> V=1.0, theta=0.0
% INFO    : Bus 72745	: V=1.0004108, theta=-63.372212 -> V=1.0, theta=0.0
% INFO    : Bus 72746	: V=1.0033632, theta=-63.148956 -> V=1.0, theta=0.0
% INFO    : Bus 72747	: V=1.0073551, theta=-61.759656 -> V=1.0, theta=0.0
% INFO    : Bus 72748	: V=1.0030089, theta=-62.908649 -> V=1.0, theta=0.0
% INFO    : Bus 72749	: V=1.0027289, theta=-63.172803 -> V=1.0, theta=0.0
% INFO    : Bus 72750	: V=0.9815961, theta=-64.568657 -> V=1.0, theta=0.0
% INFO    : Bus 72751	: V=0.9951317, theta=-64.709984 -> V=1.0, theta=0.0
% INFO    : Bus 72752	: V=0.9921384, theta=-63.160444 -> V=1.0, theta=0.0
% INFO    : Bus 72753	: V=0.9911271, theta=-63.099341 -> V=1.0, theta=0.0
% INFO    : Bus 72754	: V=0.991512, theta=-63.086118 -> V=1.0, theta=0.0
% INFO    : Bus 72755	: V=0.9917258, theta=-63.053382 -> V=1.0, theta=0.0
% INFO    : Bus 72756	: V=0.9898675, theta=-63.062423 -> V=1.0, theta=0.0
% INFO    : Bus 72757	: V=0.9902944, theta=-63.141576 -> V=1.0, theta=0.0
% INFO    : Bus 72758	: V=0.9913983, theta=-63.109938 -> V=1.0, theta=0.0
% INFO    : Bus 72759	: V=0.9908252, theta=-63.052928 -> V=1.0, theta=0.0
% INFO    : Bus 72760	: V=0.9909577, theta=-63.05694 -> V=1.0, theta=0.0
% INFO    : Bus 72761	: V=1.008664, theta=-61.441143 -> V=1.0, theta=0.0
% INFO    : Bus 72762	: V=1.025136, theta=-60.546789 -> V=1.0, theta=0.0
% INFO    : Bus 72763	: V=0.986071, theta=-63.536939 -> V=1.0, theta=0.0
% INFO    : Bus 72764	: V=0.9875366, theta=-63.339056 -> V=1.0, theta=0.0
% INFO    : Bus 72765	: V=0.9890046, theta=-63.166852 -> V=1.0, theta=0.0
% INFO    : Bus 72766	: V=0.9882562, theta=-63.273972 -> V=1.0, theta=0.0
% INFO    : Bus 72767	: V=0.9865613, theta=-63.183268 -> V=1.0, theta=0.0
% INFO    : Bus 72768	: V=0.9877756, theta=-63.334445 -> V=1.0, theta=0.0
% INFO    : Bus 72769	: V=0.99053, theta=-63.053804 -> V=1.0, theta=0.0
% INFO    : Bus 72770	: V=0.988258, theta=-63.183563 -> V=1.0, theta=0.0
% INFO    : Bus 72771	: V=0.9849783, theta=-63.199565 -> V=1.0, theta=0.0
% INFO    : Bus 72772	: V=0.9864199, theta=-63.512546 -> V=1.0, theta=0.0
% INFO    : Bus 72773	: V=0.9862679, theta=-63.520476 -> V=1.0, theta=0.0
% INFO    : Bus 72774	: V=0.9870873, theta=-63.507161 -> V=1.0, theta=0.0
% INFO    : Bus 72775	: V=0.9859073, theta=-63.515069 -> V=1.0, theta=0.0
% INFO    : Bus 72776	: V=0.9853436, theta=-63.537874 -> V=1.0, theta=0.0
% INFO    : Bus 72777	: V=0.9843788, theta=-63.545756 -> V=1.0, theta=0.0
% INFO    : Bus 72778	: V=0.9875204, theta=-64.355694 -> V=1.0, theta=0.0
% INFO    : Bus 72779	: V=0.9884919, theta=-64.298146 -> V=1.0, theta=0.0
% INFO    : Bus 72780	: V=0.989167, theta=-64.259677 -> V=1.0, theta=0.0
% INFO    : Bus 72781	: V=0.9872459, theta=-64.356891 -> V=1.0, theta=0.0
% INFO    : Bus 72782	: V=0.9855557, theta=-64.527407 -> V=1.0, theta=0.0
% INFO    : Bus 72783	: V=0.9918864, theta=-63.939006 -> V=1.0, theta=0.0
% INFO    : Bus 72784	: V=0.9904732, theta=-63.92936 -> V=1.0, theta=0.0
% INFO    : Bus 72785	: V=0.9941176, theta=-63.905628 -> V=1.0, theta=0.0
% INFO    : Bus 72786	: V=1.0020341, theta=-63.689828 -> V=1.0, theta=0.0
% INFO    : Bus 72787	: V=0.9985322, theta=-63.805086 -> V=1.0, theta=0.0
% INFO    : Bus 72788	: V=0.9948967, theta=-63.945902 -> V=1.0, theta=0.0
% INFO    : Bus 72789	: V=0.9942833, theta=-63.95642 -> V=1.0, theta=0.0
% INFO    : Bus 72790	: V=0.9941176, theta=-63.962621 -> V=1.0, theta=0.0
% INFO    : Bus 72791	: V=0.9917585, theta=-63.944302 -> V=1.0, theta=0.0
% INFO    : Bus 72792	: V=0.9902012, theta=-63.919493 -> V=1.0, theta=0.0
% INFO    : Bus 72793	: V=0.9904082, theta=-63.91094 -> V=1.0, theta=0.0
% INFO    : Bus 72794	: V=0.9891001, theta=-63.760982 -> V=1.0, theta=0.0
% INFO    : Bus 72795	: V=0.9881621, theta=-63.783001 -> V=1.0, theta=0.0
% INFO    : Bus 72796	: V=0.9886567, theta=-63.775829 -> V=1.0, theta=0.0
% INFO    : Bus 72797	: V=0.989679, theta=-63.892891 -> V=1.0, theta=0.0
% INFO    : Bus 72798	: V=0.9893235, theta=-63.845858 -> V=1.0, theta=0.0
% INFO    : Bus 72799	: V=0.9886779, theta=-63.909246 -> V=1.0, theta=0.0
% INFO    : Bus 72800	: V=0.9879965, theta=-63.940686 -> V=1.0, theta=0.0
% INFO    : Bus 72801	: V=0.9855021, theta=-63.745909 -> V=1.0, theta=0.0
% INFO    : Bus 72802	: V=0.9886742, theta=-63.851169 -> V=1.0, theta=0.0
% INFO    : Bus 72803	: V=0.9890605, theta=-63.636423 -> V=1.0, theta=0.0
% INFO    : Bus 72804	: V=0.9882217, theta=-63.613183 -> V=1.0, theta=0.0
% INFO    : Bus 72805	: V=0.9862592, theta=-63.67832 -> V=1.0, theta=0.0
% INFO    : Bus 72806	: V=0.9877508, theta=-63.566448 -> V=1.0, theta=0.0
% INFO    : Bus 72807	: V=0.9839803, theta=-63.712584 -> V=1.0, theta=0.0
% INFO    : Bus 72808	: V=0.9867588, theta=-63.574858 -> V=1.0, theta=0.0
% INFO    : Bus 72809	: V=0.9893502, theta=-63.42494 -> V=1.0, theta=0.0
% INFO    : Bus 72810	: V=0.9908179, theta=-63.275333 -> V=1.0, theta=0.0
% INFO    : Bus 72811	: V=0.987969, theta=-63.371412 -> V=1.0, theta=0.0
% INFO    : Bus 72812	: V=0.9871996, theta=-63.379917 -> V=1.0, theta=0.0
% INFO    : Bus 72813	: V=0.9914244, theta=-63.224877 -> V=1.0, theta=0.0
% INFO    : Bus 72814	: V=0.9921046, theta=-63.141722 -> V=1.0, theta=0.0
% INFO    : Bus 72815	: V=0.9929595, theta=-63.057971 -> V=1.0, theta=0.0
% INFO    : Bus 72816	: V=0.995266, theta=-62.795676 -> V=1.0, theta=0.0
% INFO    : Bus 72817	: V=1.0017302, theta=-62.266738 -> V=1.0, theta=0.0
% INFO    : Bus 72818	: V=0.9929312, theta=-63.055918 -> V=1.0, theta=0.0
% INFO    : Bus 72819	: V=0.9934878, theta=-63.073636 -> V=1.0, theta=0.0
% INFO    : Bus 72820	: V=1.0047276, theta=-61.744264 -> V=1.0, theta=0.0
% INFO    : Bus 72821	: V=0.9953124, theta=-63.30813 -> V=1.0, theta=0.0
% INFO    : Bus 72822	: V=1.0025538, theta=-62.117643 -> V=1.0, theta=0.0
% INFO    : Bus 72823	: V=1.0111893, theta=-60.534987 -> V=1.0, theta=0.0
% INFO    : Bus 72824	: V=1.0092494, theta=-61.586341 -> V=1.0, theta=0.0
% INFO    : Bus 72825	: V=0.9898668, theta=-63.452577 -> V=1.0, theta=0.0
% INFO    : Bus 72826	: V=0.9892652, theta=-63.490772 -> V=1.0, theta=0.0
% INFO    : Bus 72827	: V=0.9950128, theta=-63.50822 -> V=1.0, theta=0.0
% INFO    : Bus 72828	: V=0.9910034, theta=-63.367177 -> V=1.0, theta=0.0
% INFO    : Bus 72829	: V=0.989176, theta=-63.550477 -> V=1.0, theta=0.0
% INFO    : Bus 72830	: V=0.9916411, theta=-63.364278 -> V=1.0, theta=0.0
% INFO    : Bus 72831	: V=0.992037, theta=-63.349152 -> V=1.0, theta=0.0
% INFO    : Bus 72832	: V=0.9921846, theta=-63.365354 -> V=1.0, theta=0.0
% INFO    : Bus 72833	: V=0.9947766, theta=-63.422284 -> V=1.0, theta=0.0
% INFO    : Bus 72834	: V=0.9947894, theta=-63.381063 -> V=1.0, theta=0.0
% INFO    : Bus 72835	: V=0.9960691, theta=-63.33564 -> V=1.0, theta=0.0
% INFO    : Bus 72836	: V=0.9907861, theta=-63.499151 -> V=1.0, theta=0.0
% INFO    : Bus 72837	: V=0.9903104, theta=-63.547358 -> V=1.0, theta=0.0
% INFO    : Bus 72838	: V=1.0013061, theta=-63.405521 -> V=1.0, theta=0.0
% INFO    : Bus 72839	: V=0.9995171, theta=-63.513497 -> V=1.0, theta=0.0
% INFO    : Bus 72840	: V=1.0022686, theta=-63.177914 -> V=1.0, theta=0.0
% INFO    : Bus 72841	: V=1.0014912, theta=-63.209698 -> V=1.0, theta=0.0
% INFO    : Bus 72842	: V=1.0031544, theta=-63.091471 -> V=1.0, theta=0.0
% INFO    : Bus 72843	: V=1.0031163, theta=-62.36967 -> V=1.0, theta=0.0
% INFO    : Bus 72844	: V=1.0041418, theta=-62.315639 -> V=1.0, theta=0.0
% INFO    : Bus 72845	: V=1.0054461, theta=-62.205002 -> V=1.0, theta=0.0
% INFO    : Bus 72846	: V=1.0025806, theta=-63.2265 -> V=1.0, theta=0.0
% INFO    : Bus 72847	: V=1.0003714, theta=-63.486694 -> V=1.0, theta=0.0
% INFO    : Bus 72848	: V=1.0005468, theta=-63.484546 -> V=1.0, theta=0.0
% INFO    : Bus 72849	: V=0.9997419, theta=-63.533394 -> V=1.0, theta=0.0
% INFO    : Bus 72850	: V=0.9961624, theta=-63.616101 -> V=1.0, theta=0.0
% INFO    : Bus 72851	: V=0.9981471, theta=-63.582402 -> V=1.0, theta=0.0
% INFO    : Bus 72852	: V=0.9990799, theta=-63.564239 -> V=1.0, theta=0.0
% INFO    : Bus 72853	: V=0.9979176, theta=-63.612238 -> V=1.0, theta=0.0
% INFO    : Bus 72854	: V=0.9962285, theta=-63.670119 -> V=1.0, theta=0.0
% INFO    : Bus 72855	: V=0.99722, theta=-63.607825 -> V=1.0, theta=0.0
% INFO    : Bus 72856	: V=1.0000182, theta=-63.548365 -> V=1.0, theta=0.0
% INFO    : Bus 72857	: V=0.9995632, theta=-63.567029 -> V=1.0, theta=0.0
% INFO    : Bus 72858	: V=0.9992383, theta=-63.591273 -> V=1.0, theta=0.0
% INFO    : Bus 72859	: V=0.9990474, theta=-63.611311 -> V=1.0, theta=0.0
% INFO    : Bus 72860	: V=1.0025312, theta=-62.809779 -> V=1.0, theta=0.0
% INFO    : Bus 72861	: V=0.9996919, theta=-63.584098 -> V=1.0, theta=0.0
% INFO    : Bus 72862	: V=1.0035758, theta=-62.667727 -> V=1.0, theta=0.0
% INFO    : Bus 72863	: V=0.9994947, theta=-63.672161 -> V=1.0, theta=0.0
% INFO    : Bus 72864	: V=1.0007398, theta=-63.525519 -> V=1.0, theta=0.0
% INFO    : Bus 72865	: V=1.0003342, theta=-63.55076 -> V=1.0, theta=0.0
% INFO    : Bus 72866	: V=0.999909, theta=-63.629221 -> V=1.0, theta=0.0
% INFO    : Bus 72867	: V=1.0023606, theta=-63.3283 -> V=1.0, theta=0.0
% INFO    : Bus 72868	: V=1.0027405, theta=-63.290098 -> V=1.0, theta=0.0
% INFO    : Bus 72869	: V=1.0021467, theta=-63.372946 -> V=1.0, theta=0.0
% INFO    : Bus 72870	: V=1.001548, theta=-63.41384 -> V=1.0, theta=0.0
% INFO    : Bus 72871	: V=1.001459, theta=-63.386291 -> V=1.0, theta=0.0
% INFO    : Bus 72872	: V=1.0019178, theta=-63.358614 -> V=1.0, theta=0.0
% INFO    : Bus 72873	: V=1.0031433, theta=-63.24369 -> V=1.0, theta=0.0
% INFO    : Bus 72874	: V=1.0066816, theta=-62.474008 -> V=1.0, theta=0.0
% INFO    : Bus 72875	: V=1.0036137, theta=-63.082673 -> V=1.0, theta=0.0
% INFO    : Bus 72876	: V=1.0051276, theta=-62.4247 -> V=1.0, theta=0.0
% INFO    : Bus 72877	: V=1.0051217, theta=-62.877065 -> V=1.0, theta=0.0
% INFO    : Bus 72878	: V=1.0034325, theta=-62.396106 -> V=1.0, theta=0.0
% INFO    : Bus 72879	: V=1.0030607, theta=-62.458613 -> V=1.0, theta=0.0
% INFO    : Bus 72880	: V=1.0021916, theta=-62.452492 -> V=1.0, theta=0.0
% INFO    : Bus 72881	: V=1.0018587, theta=-62.466322 -> V=1.0, theta=0.0
% INFO    : Bus 72882	: V=0.9981144, theta=-62.160697 -> V=1.0, theta=0.0
% INFO    : Bus 72883	: V=0.9973075, theta=-61.935578 -> V=1.0, theta=0.0
% INFO    : Bus 72884	: V=1.0017157, theta=-62.469748 -> V=1.0, theta=0.0
% INFO    : Bus 72885	: V=1.0015841, theta=-62.428037 -> V=1.0, theta=0.0
% INFO    : Bus 72886	: V=1.0043532, theta=-62.437522 -> V=1.0, theta=0.0
% INFO    : Bus 72887	: V=1.0047034, theta=-62.428262 -> V=1.0, theta=0.0
% INFO    : Bus 72888	: V=1.0038031, theta=-62.440116 -> V=1.0, theta=0.0
% INFO    : Bus 72889	: V=1.0053399, theta=-62.429089 -> V=1.0, theta=0.0
% INFO    : Bus 72890	: V=1.0056724, theta=-62.451602 -> V=1.0, theta=0.0
% INFO    : Bus 72891	: V=1.0068094, theta=-62.500238 -> V=1.0, theta=0.0
% INFO    : Bus 72892	: V=1.0060876, theta=-62.634921 -> V=1.0, theta=0.0
% INFO    : Bus 72893	: V=1.0076073, theta=-62.462519 -> V=1.0, theta=0.0
% INFO    : Bus 72894	: V=1.0062258, theta=-62.493373 -> V=1.0, theta=0.0
% INFO    : Bus 72895	: V=1.0094439, theta=-61.440991 -> V=1.0, theta=0.0
% INFO    : Bus 72896	: V=1.0288491, theta=-56.104958 -> V=1.0, theta=0.0
% INFO    : Bus 72897	: V=1.0050923, theta=-62.397502 -> V=1.0, theta=0.0
% INFO    : Bus 72898	: V=1.0025151, theta=-62.483135 -> V=1.0, theta=0.0
% INFO    : Bus 72899	: V=1.0021237, theta=-62.446703 -> V=1.0, theta=0.0
% INFO    : Bus 72900	: V=1.0016168, theta=-62.3843 -> V=1.0, theta=0.0
% INFO    : Bus 72901	: V=1.0032129, theta=-62.447329 -> V=1.0, theta=0.0
% INFO    : Bus 72902	: V=1.00664, theta=-62.244777 -> V=1.0, theta=0.0
% INFO    : Bus 72903	: V=1.0104233, theta=-61.223954 -> V=1.0, theta=0.0
% INFO    : Bus 72904	: V=1.0022648, theta=-62.762421 -> V=1.0, theta=0.0
% INFO    : Bus 72905	: V=1.0020171, theta=-62.74265 -> V=1.0, theta=0.0
% INFO    : Bus 72906	: V=1.0028401, theta=-62.530978 -> V=1.0, theta=0.0
% INFO    : Bus 72907	: V=1.0023751, theta=-62.539616 -> V=1.0, theta=0.0
% INFO    : Bus 72908	: V=1.0007968, theta=-62.830723 -> V=1.0, theta=0.0
% INFO    : Bus 72909	: V=1.0024382, theta=-62.626898 -> V=1.0, theta=0.0
% INFO    : Bus 72910	: V=1.0015606, theta=-62.795719 -> V=1.0, theta=0.0
% INFO    : Bus 72911	: V=1.0021537, theta=-62.72822 -> V=1.0, theta=0.0
% INFO    : Bus 72912	: V=1.0024834, theta=-62.702939 -> V=1.0, theta=0.0
% INFO    : Bus 72913	: V=1.0031371, theta=-62.627909 -> V=1.0, theta=0.0
% INFO    : Bus 72914	: V=1.0037994, theta=-62.631333 -> V=1.0, theta=0.0
% INFO    : Bus 72915	: V=1.0044389, theta=-62.512733 -> V=1.0, theta=0.0
% INFO    : Bus 72916	: V=1.0012916, theta=-62.51955 -> V=1.0, theta=0.0
% INFO    : Bus 72917	: V=0.999211, theta=-62.532712 -> V=1.0, theta=0.0
% INFO    : Bus 72918	: V=0.9971838, theta=-62.098949 -> V=1.0, theta=0.0
% INFO    : Bus 72919	: V=0.9979577, theta=-62.45579 -> V=1.0, theta=0.0
% INFO    : Bus 72920	: V=1.001652, theta=-62.46829 -> V=1.0, theta=0.0
% INFO    : Bus 72921	: V=0.9996125, theta=-62.536878 -> V=1.0, theta=0.0
% INFO    : Bus 72922	: V=0.9998319, theta=-62.356312 -> V=1.0, theta=0.0
% INFO    : Bus 72923	: V=0.9993714, theta=-62.496477 -> V=1.0, theta=0.0
% INFO    : Bus 72924	: V=0.999419, theta=-62.450407 -> V=1.0, theta=0.0
% INFO    : Bus 72925	: V=1.0014425, theta=-62.534053 -> V=1.0, theta=0.0
% INFO    : Bus 72926	: V=0.9955244, theta=-62.170684 -> V=1.0, theta=0.0
% INFO    : Bus 72927	: V=1.0003139, theta=-63.52473 -> V=1.0, theta=0.0
% INFO    : Bus 72928	: V=0.9945733, theta=-63.987643 -> V=1.0, theta=0.0
% INFO    : Bus 72929	: V=0.9967261, theta=-63.498871 -> V=1.0, theta=0.0
% INFO    : Bus 72930	: V=0.999824, theta=-63.560269 -> V=1.0, theta=0.0
% INFO    : Bus 72931	: V=1.0008638, theta=-63.434812 -> V=1.0, theta=0.0
% INFO    : Bus 72932	: V=0.9957145, theta=-63.805256 -> V=1.0, theta=0.0
% INFO    : Bus 72933	: V=1.0014756, theta=-63.265006 -> V=1.0, theta=0.0
% INFO    : Bus 72934	: V=0.9976118, theta=-63.129493 -> V=1.0, theta=0.0
% INFO    : Bus 72935	: V=0.9963161, theta=-63.399497 -> V=1.0, theta=0.0
% INFO    : Bus 72936	: V=0.9953005, theta=-63.628707 -> V=1.0, theta=0.0
% INFO    : Bus 72937	: V=1.0047053, theta=-62.936646 -> V=1.0, theta=0.0
% INFO    : Bus 72938	: V=1.0034589, theta=-63.394644 -> V=1.0, theta=0.0
% INFO    : Bus 72939	: V=1.0004941, theta=-63.512792 -> V=1.0, theta=0.0
% INFO    : Bus 72940	: V=1.0066713, theta=-62.462522 -> V=1.0, theta=0.0
% INFO    : Bus 72941	: V=0.9973217, theta=-63.696339 -> V=1.0, theta=0.0
% INFO    : Bus 72942	: V=0.9985775, theta=-63.757114 -> V=1.0, theta=0.0
% INFO    : Bus 72943	: V=0.9962195, theta=-63.81865 -> V=1.0, theta=0.0
% INFO    : Bus 72944	: V=1.0023521, theta=-63.074953 -> V=1.0, theta=0.0
% INFO    : Bus 72945	: V=0.9949605, theta=-63.799291 -> V=1.0, theta=0.0
% INFO    : Bus 72946	: V=0.9950393, theta=-63.828086 -> V=1.0, theta=0.0
% INFO    : Bus 72947	: V=0.9960928, theta=-63.876128 -> V=1.0, theta=0.0
% INFO    : Bus 72948	: V=0.9953436, theta=-63.952346 -> V=1.0, theta=0.0
% INFO    : Bus 72949	: V=0.9945645, theta=-63.816146 -> V=1.0, theta=0.0
% INFO    : Bus 72950	: V=0.99376, theta=-63.810441 -> V=1.0, theta=0.0
% INFO    : Bus 72951	: V=0.9940214, theta=-63.806445 -> V=1.0, theta=0.0
% INFO    : Bus 72952	: V=0.993752, theta=-63.846857 -> V=1.0, theta=0.0
% INFO    : Bus 72953	: V=0.9943348, theta=-63.730455 -> V=1.0, theta=0.0
% INFO    : Bus 72954	: V=0.9935184, theta=-63.82725 -> V=1.0, theta=0.0
% INFO    : Bus 72955	: V=0.9970681, theta=-63.713767 -> V=1.0, theta=0.0
% INFO    : Bus 72956	: V=0.9982644, theta=-63.505841 -> V=1.0, theta=0.0
% INFO    : Bus 72957	: V=0.9961217, theta=-63.863603 -> V=1.0, theta=0.0
% INFO    : Bus 72958	: V=0.9983666, theta=-63.644778 -> V=1.0, theta=0.0
% INFO    : Bus 72959	: V=0.9987227, theta=-63.630235 -> V=1.0, theta=0.0
% INFO    : Bus 72960	: V=0.998665, theta=-63.652553 -> V=1.0, theta=0.0
% INFO    : Bus 72961	: V=0.9973306, theta=-63.75577 -> V=1.0, theta=0.0
% INFO    : Bus 72962	: V=0.9963458, theta=-63.866106 -> V=1.0, theta=0.0
% INFO    : Bus 72963	: V=0.9969778, theta=-63.823341 -> V=1.0, theta=0.0
% INFO    : Bus 72964	: V=1.0106766, theta=-62.862522 -> V=1.0, theta=0.0
% INFO    : Bus 72965	: V=1.0078393, theta=-62.725038 -> V=1.0, theta=0.0
% INFO    : Bus 72966	: V=1.0116184, theta=-62.807795 -> V=1.0, theta=0.0
% INFO    : Bus 72967	: V=1.0120608, theta=-62.454441 -> V=1.0, theta=0.0
% INFO    : Bus 72968	: V=1.0118375, theta=-62.941205 -> V=1.0, theta=0.0
% INFO    : Bus 72969	: V=1.0062753, theta=-63.393852 -> V=1.0, theta=0.0
% INFO    : Bus 72970	: V=1.0068457, theta=-62.637545 -> V=1.0, theta=0.0
% INFO    : Bus 72971	: V=1.0090263, theta=-62.580097 -> V=1.0, theta=0.0
% INFO    : Bus 72972	: V=1.0081415, theta=-62.608301 -> V=1.0, theta=0.0
% INFO    : Bus 72973	: V=1.0064291, theta=-63.080351 -> V=1.0, theta=0.0
% INFO    : Bus 72974	: V=1.0050952, theta=-63.160228 -> V=1.0, theta=0.0
% INFO    : Bus 72975	: V=1.0104827, theta=-62.515638 -> V=1.0, theta=0.0
% INFO    : Bus 72976	: V=1.0109915, theta=-62.518012 -> V=1.0, theta=0.0
% INFO    : Bus 72977	: V=1.0090059, theta=-63.005644 -> V=1.0, theta=0.0
% INFO    : Bus 72978	: V=1.0120659, theta=-62.419152 -> V=1.0, theta=0.0
% INFO    : Bus 72979	: V=1.0107602, theta=-62.609588 -> V=1.0, theta=0.0
% INFO    : Bus 72980	: V=1.0149314, theta=-62.260806 -> V=1.0, theta=0.0
% INFO    : Bus 72981	: V=1.011939, theta=-62.544802 -> V=1.0, theta=0.0
% INFO    : Bus 72982	: V=1.0219512, theta=-61.455752 -> V=1.0, theta=0.0
% INFO    : Bus 72983	: V=1.0111623, theta=-62.502876 -> V=1.0, theta=0.0
% INFO    : Bus 72984	: V=1.0116653, theta=-62.546688 -> V=1.0, theta=0.0
% INFO    : Bus 72985	: V=1.0176213, theta=-63.30448 -> V=1.0, theta=0.0
% INFO    : Bus 72986	: V=1.0144424, theta=-62.388589 -> V=1.0, theta=0.0
% INFO    : Bus 72987	: V=1.0229881, theta=-61.866269 -> V=1.0, theta=0.0
% INFO    : Bus 72988	: V=1.0239354, theta=-61.687969 -> V=1.0, theta=0.0
% INFO    : Bus 72989	: V=1.0212118, theta=-61.763019 -> V=1.0, theta=0.0
% INFO    : Bus 72990	: V=1.0226002, theta=-61.640507 -> V=1.0, theta=0.0
% INFO    : Bus 72991	: V=1.0231653, theta=-61.87565 -> V=1.0, theta=0.0
% INFO    : Bus 72992	: V=1.0181607, theta=-63.110597 -> V=1.0, theta=0.0
% INFO    : Bus 72993	: V=1.0216217, theta=-62.171235 -> V=1.0, theta=0.0
% INFO    : Bus 72994	: V=1.0206007, theta=-62.3868 -> V=1.0, theta=0.0
% INFO    : Bus 72995	: V=1.0167266, theta=-63.336952 -> V=1.0, theta=0.0
% INFO    : Bus 72996	: V=1.0168304, theta=-63.334759 -> V=1.0, theta=0.0
% INFO    : Bus 72997	: V=1.0196648, theta=-62.53229 -> V=1.0, theta=0.0
% INFO    : Bus 72998	: V=1.0083312, theta=-64.262132 -> V=1.0, theta=0.0
% INFO    : Bus 72999	: V=1.0166437, theta=-63.439643 -> V=1.0, theta=0.0
% INFO    : Bus 73000	: V=1.0165384, theta=-63.455006 -> V=1.0, theta=0.0
% INFO    : Bus 73001	: V=1.0167247, theta=-63.440242 -> V=1.0, theta=0.0
% INFO    : Bus 73002	: V=1.0114858, theta=-63.968868 -> V=1.0, theta=0.0
% INFO    : Bus 73003	: V=1.0116481, theta=-63.915038 -> V=1.0, theta=0.0
% INFO    : Bus 73004	: V=1.0089198, theta=-64.15783 -> V=1.0, theta=0.0
% INFO    : Bus 73005	: V=1.0155859, theta=-63.479442 -> V=1.0, theta=0.0
% INFO    : Bus 73006	: V=1.0126072, theta=-63.803841 -> V=1.0, theta=0.0
% INFO    : Bus 73007	: V=1.0146169, theta=-63.585824 -> V=1.0, theta=0.0
% INFO    : Bus 73008	: V=1.0133589, theta=-63.689148 -> V=1.0, theta=0.0
% INFO    : Bus 73009	: V=1.0123744, theta=-63.764535 -> V=1.0, theta=0.0
% INFO    : Bus 73010	: V=1.0153364, theta=-63.654658 -> V=1.0, theta=0.0
% INFO    : Bus 73011	: V=1.0221436, theta=-62.391403 -> V=1.0, theta=0.0
% INFO    : Bus 73012	: V=1.0092908, theta=-64.194635 -> V=1.0, theta=0.0
% INFO    : Bus 73013	: V=1.0085402, theta=-64.254718 -> V=1.0, theta=0.0
% INFO    : Bus 73014	: V=1.0077886, theta=-64.321135 -> V=1.0, theta=0.0
% INFO    : Bus 73015	: V=1.0036151, theta=-64.529084 -> V=1.0, theta=0.0
% INFO    : Bus 73016	: V=1.0054472, theta=-64.323701 -> V=1.0, theta=0.0
% INFO    : Bus 73017	: V=1.0111858, theta=-64.039874 -> V=1.0, theta=0.0
% INFO    : Bus 73018	: V=1.0119244, theta=-63.968584 -> V=1.0, theta=0.0
% INFO    : Bus 73019	: V=1.0100002, theta=-64.484292 -> V=1.0, theta=0.0
% INFO    : Bus 73020	: V=0.9992572, theta=-64.930425 -> V=1.0, theta=0.0
% INFO    : Bus 73021	: V=1.0009826, theta=-64.222481 -> V=1.0, theta=0.0
% INFO    : Bus 73022	: V=1.0023447, theta=-64.171407 -> V=1.0, theta=0.0
% INFO    : Bus 73023	: V=0.998815, theta=-65.084621 -> V=1.0, theta=0.0
% INFO    : Bus 73024	: V=0.9991319, theta=-65.012702 -> V=1.0, theta=0.0
% INFO    : Bus 73025	: V=0.9994937, theta=-64.987286 -> V=1.0, theta=0.0
% INFO    : Bus 73026	: V=0.9998439, theta=-64.906211 -> V=1.0, theta=0.0
% INFO    : Bus 73027	: V=0.9989718, theta=-65.508251 -> V=1.0, theta=0.0
% INFO    : Bus 73028	: V=1.0003006, theta=-63.710911 -> V=1.0, theta=0.0
% INFO    : Bus 73029	: V=1.0118383, theta=-64.345855 -> V=1.0, theta=0.0
% INFO    : Bus 73030	: V=0.9995103, theta=-63.165672 -> V=1.0, theta=0.0
% INFO    : Bus 73031	: V=1.0003485, theta=-63.168645 -> V=1.0, theta=0.0
% INFO    : Bus 73032	: V=0.9942884, theta=-63.062595 -> V=1.0, theta=0.0
% INFO    : Bus 73033	: V=0.9930644, theta=-63.12567 -> V=1.0, theta=0.0
% INFO    : Bus 73034	: V=1.0070956, theta=-64.134689 -> V=1.0, theta=0.0
% INFO    : Bus 73035	: V=1.0077145, theta=-64.064015 -> V=1.0, theta=0.0
% INFO    : Bus 73036	: V=1.0084413, theta=-64.04215 -> V=1.0, theta=0.0
% INFO    : Bus 73037	: V=1.0043509, theta=-64.009977 -> V=1.0, theta=0.0
% INFO    : Bus 73038	: V=1.0024174, theta=-63.69396 -> V=1.0, theta=0.0
% INFO    : Bus 73039	: V=1.0088675, theta=-64.136426 -> V=1.0, theta=0.0
% INFO    : Bus 73040	: V=1.0092893, theta=-64.094304 -> V=1.0, theta=0.0
% INFO    : Bus 73041	: V=1.0065703, theta=-64.200856 -> V=1.0, theta=0.0
% INFO    : Bus 73042	: V=1.0098365, theta=-64.028956 -> V=1.0, theta=0.0
% INFO    : Bus 73043	: V=1.0091917, theta=-64.04562 -> V=1.0, theta=0.0
% INFO    : Bus 73044	: V=1.0116213, theta=-63.822476 -> V=1.0, theta=0.0
% INFO    : Bus 73045	: V=1.010734, theta=-63.936874 -> V=1.0, theta=0.0
% INFO    : Bus 73046	: V=1.0090938, theta=-64.036889 -> V=1.0, theta=0.0
% INFO    : Bus 73047	: V=1.0092564, theta=-64.013425 -> V=1.0, theta=0.0
% INFO    : Bus 73048	: V=1.0099588, theta=-63.948767 -> V=1.0, theta=0.0
% INFO    : Bus 73049	: V=1.0090597, theta=-63.93379 -> V=1.0, theta=0.0
% INFO    : Bus 73050	: V=1.0098468, theta=-63.816306 -> V=1.0, theta=0.0
% INFO    : Bus 73051	: V=1.0119492, theta=-63.769435 -> V=1.0, theta=0.0
% INFO    : Bus 73052	: V=1.0104763, theta=-63.912092 -> V=1.0, theta=0.0
% INFO    : Bus 73053	: V=1.0211279, theta=-62.246783 -> V=1.0, theta=0.0
% INFO    : Bus 73054	: V=1.0219575, theta=-62.07771 -> V=1.0, theta=0.0
% INFO    : Bus 73055	: V=1.0138774, theta=-63.604424 -> V=1.0, theta=0.0
% INFO    : Bus 73056	: V=1.0176109, theta=-62.093616 -> V=1.0, theta=0.0
% INFO    : Bus 73057	: V=1.0135926, theta=-63.493154 -> V=1.0, theta=0.0
% INFO    : Bus 73058	: V=1.0127174, theta=-63.635548 -> V=1.0, theta=0.0
% INFO    : Bus 73059	: V=1.0106809, theta=-63.840911 -> V=1.0, theta=0.0
% INFO    : Bus 73060	: V=1.0100842, theta=-63.865233 -> V=1.0, theta=0.0
% INFO    : Bus 73061	: V=1.0112322, theta=-63.844819 -> V=1.0, theta=0.0
% INFO    : Bus 73062	: V=1.0118722, theta=-63.783745 -> V=1.0, theta=0.0
% INFO    : Bus 73063	: V=1.0148338, theta=-62.939486 -> V=1.0, theta=0.0
% INFO    : Bus 73064	: V=1.0130834, theta=-62.956163 -> V=1.0, theta=0.0
% INFO    : Bus 73065	: V=1.0124775, theta=-62.940236 -> V=1.0, theta=0.0
% INFO    : Bus 73066	: V=1.0118968, theta=-62.888745 -> V=1.0, theta=0.0
% INFO    : Bus 73067	: V=1.0149898, theta=-62.251418 -> V=1.0, theta=0.0
% INFO    : Bus 73068	: V=1.0147432, theta=-62.235625 -> V=1.0, theta=0.0
% INFO    : Bus 73069	: V=1.0117482, theta=-63.770031 -> V=1.0, theta=0.0
% INFO    : Bus 73070	: V=1.0135829, theta=-62.194495 -> V=1.0, theta=0.0
% INFO    : Bus 73071	: V=1.0117974, theta=-63.051574 -> V=1.0, theta=0.0
% INFO    : Bus 73072	: V=1.013176, theta=-62.149218 -> V=1.0, theta=0.0
% INFO    : Bus 73073	: V=1.0129417, theta=-62.082032 -> V=1.0, theta=0.0
% INFO    : Bus 73074	: V=1.0026446, theta=-62.757319 -> V=1.0, theta=0.0
% INFO    : Bus 73075	: V=1.0130269, theta=-61.977683 -> V=1.0, theta=0.0
% INFO    : Bus 73076	: V=1.0111055, theta=-63.157441 -> V=1.0, theta=0.0
% INFO    : Bus 73077	: V=1.0140557, theta=-62.14045 -> V=1.0, theta=0.0
% INFO    : Bus 73078	: V=1.0116032, theta=-62.929907 -> V=1.0, theta=0.0
% INFO    : Bus 73079	: V=1.0146814, theta=-62.204208 -> V=1.0, theta=0.0
% INFO    : Bus 73080	: V=0.9976477, theta=-62.851826 -> V=1.0, theta=0.0
% INFO    : Bus 73081	: V=1.0013897, theta=-62.796556 -> V=1.0, theta=0.0
% INFO    : Bus 73082	: V=1.0024686, theta=-62.698611 -> V=1.0, theta=0.0
% INFO    : Bus 73083	: V=1.001061, theta=-62.729131 -> V=1.0, theta=0.0
% INFO    : Bus 73084	: V=1.0040328, theta=-62.505665 -> V=1.0, theta=0.0
% INFO    : Bus 73085	: V=1.000569, theta=-62.705758 -> V=1.0, theta=0.0
% INFO    : Bus 73086	: V=1.0016619, theta=-62.550731 -> V=1.0, theta=0.0
% INFO    : Bus 73087	: V=0.9996724, theta=-62.74244 -> V=1.0, theta=0.0
% INFO    : Bus 73088	: V=0.999919, theta=-62.674013 -> V=1.0, theta=0.0
% INFO    : Bus 73089	: V=0.9992647, theta=-62.764708 -> V=1.0, theta=0.0
% INFO    : Bus 73090	: V=1.0000271, theta=-62.670566 -> V=1.0, theta=0.0
% INFO    : Bus 73091	: V=0.9986779, theta=-62.792995 -> V=1.0, theta=0.0
% INFO    : Bus 73092	: V=1.000657, theta=-62.67338 -> V=1.0, theta=0.0
% INFO    : Bus 73093	: V=1.0020926, theta=-62.534626 -> V=1.0, theta=0.0
% INFO    : Bus 73094	: V=1.002959, theta=-62.511859 -> V=1.0, theta=0.0
% INFO    : Bus 73095	: V=1.0119395, theta=-62.915268 -> V=1.0, theta=0.0
% INFO    : Bus 73096	: V=1.001594, theta=-62.795608 -> V=1.0, theta=0.0
% INFO    : Bus 73097	: V=1.0136789, theta=-61.954281 -> V=1.0, theta=0.0
% INFO    : Bus 73098	: V=1.0107397, theta=-62.049056 -> V=1.0, theta=0.0
% INFO    : Bus 73099	: V=1.0061767, theta=-62.316684 -> V=1.0, theta=0.0
% INFO    : Bus 73100	: V=1.0083205, theta=-62.139297 -> V=1.0, theta=0.0
% INFO    : Bus 73101	: V=1.002307, theta=-62.586439 -> V=1.0, theta=0.0
% INFO    : Bus 73102	: V=1.0043153, theta=-62.57337 -> V=1.0, theta=0.0
% INFO    : Bus 73103	: V=1.0075676, theta=-62.273672 -> V=1.0, theta=0.0
% INFO    : Bus 73104	: V=1.0027133, theta=-62.587735 -> V=1.0, theta=0.0
% INFO    : Bus 73105	: V=1.0064495, theta=-62.286362 -> V=1.0, theta=0.0
% INFO    : Bus 73106	: V=1.004141, theta=-62.490599 -> V=1.0, theta=0.0
% INFO    : Bus 73107	: V=1.0023375, theta=-62.565473 -> V=1.0, theta=0.0
% INFO    : Bus 73108	: V=1.0018263, theta=-62.571863 -> V=1.0, theta=0.0
% INFO    : Bus 73109	: V=1.0019383, theta=-62.612076 -> V=1.0, theta=0.0
% INFO    : Bus 73110	: V=1.0035417, theta=-62.584259 -> V=1.0, theta=0.0
% INFO    : Bus 73111	: V=1.0030341, theta=-62.760609 -> V=1.0, theta=0.0
% INFO    : Bus 73112	: V=0.9943449, theta=-62.959784 -> V=1.0, theta=0.0
% INFO    : Bus 73113	: V=0.9987858, theta=-63.074866 -> V=1.0, theta=0.0
% INFO    : Bus 73114	: V=0.9980305, theta=-62.149503 -> V=1.0, theta=0.0
% INFO    : Bus 73115	: V=0.998082, theta=-61.998837 -> V=1.0, theta=0.0
% INFO    : Bus 73116	: V=0.9973527, theta=-62.047885 -> V=1.0, theta=0.0
% INFO    : Bus 73117	: V=1.0003274, theta=-61.275176 -> V=1.0, theta=0.0
% INFO    : Bus 73118	: V=0.9973042, theta=-61.954143 -> V=1.0, theta=0.0
% INFO    : Bus 73119	: V=0.9953423, theta=-61.422531 -> V=1.0, theta=0.0
% INFO    : Bus 73120	: V=0.9938387, theta=-61.480063 -> V=1.0, theta=0.0
% INFO    : Bus 73121	: V=0.9824349, theta=-58.538358 -> V=1.0, theta=0.0
% INFO    : Bus 73122	: V=0.9848243, theta=-63.489017 -> V=1.0, theta=0.0
% INFO    : Bus 73123	: V=0.9891011, theta=-60.108254 -> V=1.0, theta=0.0
% INFO    : Bus 73124	: V=0.9696515, theta=-50.799033 -> V=1.0, theta=0.0
% INFO    : Bus 73125	: V=0.9942, theta=-55.2083 -> V=1.0, theta=0.0
% INFO    : Bus 73126	: V=0.9875641, theta=-59.90632 -> V=1.0, theta=0.0
% INFO    : Bus 73127	: V=0.9944817, theta=-61.384479 -> V=1.0, theta=0.0
% INFO    : Bus 73128	: V=0.9954819, theta=-61.480385 -> V=1.0, theta=0.0
% INFO    : Bus 73129	: V=0.9928671, theta=-61.084839 -> V=1.0, theta=0.0
% INFO    : Bus 73130	: V=1.0063976, theta=-60.147524 -> V=1.0, theta=0.0
% INFO    : Bus 73131	: V=1.0026713, theta=-61.546969 -> V=1.0, theta=0.0
% INFO    : Bus 73132	: V=1.0035124, theta=-61.011761 -> V=1.0, theta=0.0
% INFO    : Bus 73133	: V=0.9963931, theta=-64.667757 -> V=1.0, theta=0.0
% INFO    : Bus 73134	: V=1.0012189, theta=-63.404705 -> V=1.0, theta=0.0
% INFO    : Bus 73135	: V=1.0109026, theta=-63.778805 -> V=1.0, theta=0.0
% INFO    : Bus 73136	: V=0.9873088, theta=-64.356671 -> V=1.0, theta=0.0
% INFO    : Bus 73137	: V=1.0023717, theta=-62.822758 -> V=1.0, theta=0.0
% INFO    : Bus 73138	: V=0.9934227, theta=-63.934126 -> V=1.0, theta=0.0
% INFO    : Bus 73139	: V=1.0392695, theta=-58.741719 -> V=1.0, theta=0.0
% INFO    : Bus 73140	: V=1.0089039, theta=-110.25977 -> V=1.0, theta=0.0
% INFO    : Bus 73141	: V=1.0172794, theta=-110.063992 -> V=1.0, theta=0.0
% INFO    : Bus 73142	: V=1.0175431, theta=-110.054344 -> V=1.0, theta=0.0
% INFO    : Bus 73143	: V=1.0176283, theta=-110.041095 -> V=1.0, theta=0.0
% INFO    : Bus 73144	: V=1.0097773, theta=-109.17991 -> V=1.0, theta=0.0
% INFO    : Bus 73145	: V=1.0177436, theta=-110.036877 -> V=1.0, theta=0.0
% INFO    : Bus 73146	: V=1.0179706, theta=-110.02779 -> V=1.0, theta=0.0
% INFO    : Bus 73147	: V=1.0093055, theta=-110.372471 -> V=1.0, theta=0.0
% INFO    : Bus 73148	: V=1.0089907, theta=-110.412055 -> V=1.0, theta=0.0
% INFO    : Bus 73149	: V=1.0087932, theta=-110.4327 -> V=1.0, theta=0.0
% INFO    : Bus 73150	: V=1.0090644, theta=-109.360749 -> V=1.0, theta=0.0
% INFO    : Bus 73151	: V=1.0095073, theta=-110.343564 -> V=1.0, theta=0.0
% INFO    : Bus 73152	: V=1.0093622, theta=-110.350027 -> V=1.0, theta=0.0
% INFO    : Bus 73153	: V=1.0126769, theta=-107.698183 -> V=1.0, theta=0.0
% INFO    : Bus 73154	: V=1.009819, theta=-110.169427 -> V=1.0, theta=0.0
% INFO    : Bus 73155	: V=1.0093759, theta=-110.370702 -> V=1.0, theta=0.0
% INFO    : Bus 73156	: V=1.009337, theta=-110.350418 -> V=1.0, theta=0.0
% INFO    : Bus 73157	: V=1.0090251, theta=-110.416139 -> V=1.0, theta=0.0
% INFO    : Bus 73158	: V=1.0093779, theta=-110.369904 -> V=1.0, theta=0.0
% INFO    : Bus 73159	: V=1.0090476, theta=-110.41989 -> V=1.0, theta=0.0
% INFO    : Bus 73160	: V=1.0089358, theta=-110.448734 -> V=1.0, theta=0.0
% INFO    : Bus 73161	: V=1.0094437, theta=-110.362176 -> V=1.0, theta=0.0
% INFO    : Bus 73162	: V=1.0093723, theta=-110.365053 -> V=1.0, theta=0.0
% INFO    : Bus 73163	: V=1.008909, theta=-110.425003 -> V=1.0, theta=0.0
% INFO    : Bus 73164	: V=1.0087435, theta=-109.444912 -> V=1.0, theta=0.0
% INFO    : Bus 73165	: V=1.0092757, theta=-110.376825 -> V=1.0, theta=0.0
% INFO    : Bus 73166	: V=1.0092008, theta=-110.379584 -> V=1.0, theta=0.0
% INFO    : Bus 73167	: V=1.0078375, theta=-110.558682 -> V=1.0, theta=0.0
% INFO    : Bus 73168	: V=1.0077888, theta=-110.521941 -> V=1.0, theta=0.0
% INFO    : Bus 73169	: V=1.0077628, theta=-110.560465 -> V=1.0, theta=0.0
% INFO    : Bus 73170	: V=1.0079578, theta=-110.553246 -> V=1.0, theta=0.0
% INFO    : Bus 73171	: V=1.0082013, theta=-110.495516 -> V=1.0, theta=0.0
% INFO    : Bus 73172	: V=1.0079716, theta=-110.515185 -> V=1.0, theta=0.0
% INFO    : Bus 73173	: V=1.007816, theta=-110.5222 -> V=1.0, theta=0.0
% INFO    : Bus 73174	: V=1.008532, theta=-110.442351 -> V=1.0, theta=0.0
% INFO    : Bus 73175	: V=1.008483, theta=-110.444161 -> V=1.0, theta=0.0
% INFO    : Bus 73176	: V=1.0077727, theta=-110.560724 -> V=1.0, theta=0.0
% INFO    : Bus 73177	: V=1.007812, theta=-110.938365 -> V=1.0, theta=0.0
% INFO    : Bus 73178	: V=1.0078137, theta=-110.577232 -> V=1.0, theta=0.0
% INFO    : Bus 73179	: V=1.0083388, theta=-110.529598 -> V=1.0, theta=0.0
% INFO    : Bus 73180	: V=1.0088411, theta=-109.419724 -> V=1.0, theta=0.0
% INFO    : Bus 73181	: V=1.0085108, theta=-110.523252 -> V=1.0, theta=0.0
% INFO    : Bus 73182	: V=1.0079971, theta=-110.57047 -> V=1.0, theta=0.0
% INFO    : Bus 73183	: V=1.0080114, theta=-110.929378 -> V=1.0, theta=0.0
% INFO    : Bus 73184	: V=1.0086124, theta=-109.462188 -> V=1.0, theta=0.0
% INFO    : Bus 73185	: V=1.0075092, theta=-110.979489 -> V=1.0, theta=0.0
% INFO    : Bus 73186	: V=1.0074325, theta=-110.964183 -> V=1.0, theta=0.0
% INFO    : Bus 73187	: V=1.0079618, theta=-110.567899 -> V=1.0, theta=0.0
% INFO    : Bus 73188	: V=1.0078303, theta=-110.573208 -> V=1.0, theta=0.0
% INFO    : Bus 73189	: V=1.0082712, theta=-110.540228 -> V=1.0, theta=0.0
% INFO    : Bus 73190	: V=1.008727, theta=-110.482589 -> V=1.0, theta=0.0
% INFO    : Bus 73191	: V=1.0081248, theta=-110.545632 -> V=1.0, theta=0.0
% INFO    : Bus 73192	: V=1.008342, theta=-110.554923 -> V=1.0, theta=0.0
% INFO    : Bus 73193	: V=1.0080972, theta=-110.585585 -> V=1.0, theta=0.0
% INFO    : Bus 73194	: V=1.0079609, theta=-110.705355 -> V=1.0, theta=0.0
% INFO    : Bus 73195	: V=1.0070575, theta=-111.007106 -> V=1.0, theta=0.0
% INFO    : Bus 73196	: V=1.0067769, theta=-111.030628 -> V=1.0, theta=0.0
% INFO    : Bus 73197	: V=1.0077938, theta=-110.755024 -> V=1.0, theta=0.0
% INFO    : Bus 73198	: V=1.0081927, theta=-110.599038 -> V=1.0, theta=0.0
% INFO    : Bus 73199	: V=1.008244, theta=-110.580158 -> V=1.0, theta=0.0
% INFO    : Bus 73200	: V=1.0079428, theta=-110.700313 -> V=1.0, theta=0.0
% INFO    : Bus 73201	: V=1.0076058, theta=-110.807126 -> V=1.0, theta=0.0
% INFO    : Bus 73202	: V=1.0073271, theta=-110.894566 -> V=1.0, theta=0.0
% INFO    : Bus 73203	: V=1.0071078, theta=-110.950961 -> V=1.0, theta=0.0
% INFO    : Bus 73204	: V=1.0088824, theta=-109.421182 -> V=1.0, theta=0.0
% INFO    : Bus 73205	: V=1.0088945, theta=-109.597959 -> V=1.0, theta=0.0
% INFO    : Bus 73206	: V=1.0094282, theta=-109.53569 -> V=1.0, theta=0.0
% INFO    : Bus 73207	: V=1.0090098, theta=-109.397202 -> V=1.0, theta=0.0
% INFO    : Bus 73208	: V=1.009657, theta=-109.211815 -> V=1.0, theta=0.0
% INFO    : Bus 73209	: V=1.0092286, theta=-109.352229 -> V=1.0, theta=0.0
% INFO    : Bus 73210	: V=1.0087486, theta=-109.625864 -> V=1.0, theta=0.0
% INFO    : Bus 73211	: V=1.0081822, theta=-110.654279 -> V=1.0, theta=0.0
% INFO    : Bus 73212	: V=1.0080845, theta=-110.694599 -> V=1.0, theta=0.0
% INFO    : Bus 73213	: V=1.0078815, theta=-110.74922 -> V=1.0, theta=0.0
% INFO    : Bus 73214	: V=1.0075705, theta=-110.71885 -> V=1.0, theta=0.0
% INFO    : Bus 73215	: V=1.0079937, theta=-110.744194 -> V=1.0, theta=0.0
% INFO    : Bus 73216	: V=1.0076426, theta=-110.330581 -> V=1.0, theta=0.0
% INFO    : Bus 73217	: V=1.0082344, theta=-109.810795 -> V=1.0, theta=0.0
% INFO    : Bus 73218	: V=1.0084601, theta=-109.746079 -> V=1.0, theta=0.0
% INFO    : Bus 73219	: V=1.0083148, theta=-109.752583 -> V=1.0, theta=0.0
% INFO    : Bus 73220	: V=1.0063175, theta=-110.909376 -> V=1.0, theta=0.0
% INFO    : Bus 73221	: V=1.0059076, theta=-110.975534 -> V=1.0, theta=0.0
% INFO    : Bus 73222	: V=1.0079729, theta=-110.718981 -> V=1.0, theta=0.0
% INFO    : Bus 73223	: V=1.007254, theta=-110.048294 -> V=1.0, theta=0.0
% INFO    : Bus 73224	: V=1.0060462, theta=-110.969922 -> V=1.0, theta=0.0
% INFO    : Bus 73225	: V=1.0059168, theta=-110.984769 -> V=1.0, theta=0.0
% INFO    : Bus 73226	: V=1.0078761, theta=-110.707867 -> V=1.0, theta=0.0
% INFO    : Bus 73227	: V=1.0067583, theta=-110.176852 -> V=1.0, theta=0.0
% INFO    : Bus 73228	: V=1.0058152, theta=-110.998329 -> V=1.0, theta=0.0
% INFO    : Bus 73229	: V=1.0085271, theta=-110.083278 -> V=1.0, theta=0.0
% INFO    : Bus 73230	: V=1.0084143, theta=-110.087861 -> V=1.0, theta=0.0
% INFO    : Bus 73231	: V=1.007778, theta=-110.272338 -> V=1.0, theta=0.0
% INFO    : Bus 73232	: V=1.0086142, theta=-109.700246 -> V=1.0, theta=0.0
% INFO    : Bus 73233	: V=1.0069191, theta=-111.375892 -> V=1.0, theta=0.0
% INFO    : Bus 73234	: V=1.0078759, theta=-110.386933 -> V=1.0, theta=0.0
% INFO    : Bus 73235	: V=1.0071931, theta=-110.44676 -> V=1.0, theta=0.0
% INFO    : Bus 73236	: V=1.0076391, theta=-110.41759 -> V=1.0, theta=0.0
% INFO    : Bus 73237	: V=1.0074933, theta=-110.43462 -> V=1.0, theta=0.0
% INFO    : Bus 73238	: V=1.0065526, theta=-110.849896 -> V=1.0, theta=0.0
% INFO    : Bus 73239	: V=1.0063836, theta=-110.856162 -> V=1.0, theta=0.0
% INFO    : Bus 73240	: V=1.0063627, theta=-110.732936 -> V=1.0, theta=0.0
% INFO    : Bus 73241	: V=1.0059927, theta=-110.877324 -> V=1.0, theta=0.0
% INFO    : Bus 73242	: V=1.0064166, theta=-110.859975 -> V=1.0, theta=0.0
% INFO    : Bus 73243	: V=1.0065935, theta=-110.184824 -> V=1.0, theta=0.0
% INFO    : Bus 73244	: V=1.0062599, theta=-110.901767 -> V=1.0, theta=0.0
% INFO    : Bus 73245	: V=1.0066825, theta=-110.471843 -> V=1.0, theta=0.0
% INFO    : Bus 73246	: V=1.0068336, theta=-110.465721 -> V=1.0, theta=0.0
% INFO    : Bus 73247	: V=1.006069, theta=-110.9702 -> V=1.0, theta=0.0
% INFO    : Bus 73248	: V=1.0058226, theta=-110.99888 -> V=1.0, theta=0.0
% INFO    : Bus 73249	: V=1.0056762, theta=-111.004842 -> V=1.0, theta=0.0
% INFO    : Bus 73250	: V=1.0057227, theta=-111.009532 -> V=1.0, theta=0.0
% INFO    : Bus 73251	: V=1.0051437, theta=-111.141279 -> V=1.0, theta=0.0
% INFO    : Bus 73252	: V=1.005598, theta=-111.019845 -> V=1.0, theta=0.0
% INFO    : Bus 73253	: V=1.0059784, theta=-110.92836 -> V=1.0, theta=0.0
% INFO    : Bus 73254	: V=1.0062353, theta=-110.918845 -> V=1.0, theta=0.0
% INFO    : Bus 73255	: V=1.0063321, theta=-110.905825 -> V=1.0, theta=0.0
% INFO    : Bus 73256	: V=1.0060735, theta=-110.928163 -> V=1.0, theta=0.0
% INFO    : Bus 73257	: V=1.0052406, theta=-111.109004 -> V=1.0, theta=0.0
% INFO    : Bus 73258	: V=1.0054817, theta=-111.02511 -> V=1.0, theta=0.0
% INFO    : Bus 73259	: V=1.0054, theta=-111.073679 -> V=1.0, theta=0.0
% INFO    : Bus 73260	: V=1.0053491, theta=-111.062613 -> V=1.0, theta=0.0
% INFO    : Bus 73261	: V=1.0047307, theta=-111.22808 -> V=1.0, theta=0.0
% INFO    : Bus 73262	: V=1.0052271, theta=-110.519004 -> V=1.0, theta=0.0
% INFO    : Bus 73263	: V=1.0045598, theta=-111.231745 -> V=1.0, theta=0.0
% INFO    : Bus 73264	: V=1.0053621, theta=-111.038109 -> V=1.0, theta=0.0
% INFO    : Bus 73265	: V=1.0045251, theta=-111.220834 -> V=1.0, theta=0.0
% INFO    : Bus 73266	: V=1.0055792, theta=-110.947277 -> V=1.0, theta=0.0
% INFO    : Bus 73267	: V=1.0056537, theta=-110.948099 -> V=1.0, theta=0.0
% INFO    : Bus 73268	: V=1.0056465, theta=-110.948432 -> V=1.0, theta=0.0
% INFO    : Bus 73269	: V=1.0055452, theta=-110.940023 -> V=1.0, theta=0.0
% INFO    : Bus 73270	: V=1.0062285, theta=-111.22068 -> V=1.0, theta=0.0
% INFO    : Bus 73271	: V=1.0058795, theta=-111.236309 -> V=1.0, theta=0.0
% INFO    : Bus 73272	: V=1.0056328, theta=-111.323303 -> V=1.0, theta=0.0
% INFO    : Bus 73273	: V=1.0058549, theta=-111.314312 -> V=1.0, theta=0.0
% INFO    : Bus 73274	: V=1.0056131, theta=-111.395556 -> V=1.0, theta=0.0
% INFO    : Bus 73275	: V=1.0054753, theta=-111.445605 -> V=1.0, theta=0.0
% INFO    : Bus 73276	: V=1.0050799, theta=-111.505227 -> V=1.0, theta=0.0
% INFO    : Bus 73277	: V=1.0073512, theta=-110.727744 -> V=1.0, theta=0.0
% INFO    : Bus 73278	: V=1.0040995, theta=-111.580162 -> V=1.0, theta=0.0
% INFO    : Bus 73279	: V=1.0060223, theta=-110.676209 -> V=1.0, theta=0.0
% INFO    : Bus 73280	: V=1.0046451, theta=-111.558002 -> V=1.0, theta=0.0
% INFO    : Bus 73281	: V=1.0038588, theta=-111.677662 -> V=1.0, theta=0.0
% INFO    : Bus 73282	: V=1.0055767, theta=-111.127899 -> V=1.0, theta=0.0
% INFO    : Bus 73283	: V=1.006072, theta=-110.342047 -> V=1.0, theta=0.0
% INFO    : Bus 73284	: V=1.0055805, theta=-111.15706 -> V=1.0, theta=0.0
% INFO    : Bus 73285	: V=1.0054688, theta=-111.161596 -> V=1.0, theta=0.0
% INFO    : Bus 73286	: V=1.0035237, theta=-111.697074 -> V=1.0, theta=0.0
% INFO    : Bus 73287	: V=1.0033605, theta=-111.701068 -> V=1.0, theta=0.0
% INFO    : Bus 73288	: V=1.005576, theta=-111.14333 -> V=1.0, theta=0.0
% INFO    : Bus 73289	: V=1.0066974, theta=-111.401557 -> V=1.0, theta=0.0
% INFO    : Bus 73290	: V=1.0065557, theta=-111.40796 -> V=1.0, theta=0.0
% INFO    : Bus 73291	: V=1.0059711, theta=-111.431106 -> V=1.0, theta=0.0
% INFO    : Bus 73292	: V=1.0055637, theta=-111.454106 -> V=1.0, theta=0.0
% INFO    : Bus 73293	: V=1.0058696, theta=-111.442773 -> V=1.0, theta=0.0
% INFO    : Bus 73294	: V=1.0052082, theta=-111.562805 -> V=1.0, theta=0.0
% INFO    : Bus 73295	: V=1.0057127, theta=-111.440707 -> V=1.0, theta=0.0
% INFO    : Bus 73296	: V=1.0041047, theta=-111.61001 -> V=1.0, theta=0.0
% INFO    : Bus 73297	: V=1.0038362, theta=-111.622072 -> V=1.0, theta=0.0
% INFO    : Bus 73298	: V=1.0032892, theta=-111.746504 -> V=1.0, theta=0.0
% INFO    : Bus 73299	: V=1.0027978, theta=-111.780303 -> V=1.0, theta=0.0
% INFO    : Bus 73300	: V=1.0029414, theta=-111.77447 -> V=1.0, theta=0.0
% INFO    : Bus 73301	: V=1.00574, theta=-111.476516 -> V=1.0, theta=0.0
% INFO    : Bus 73302	: V=1.0054489, theta=-111.488321 -> V=1.0, theta=0.0
% INFO    : Bus 73303	: V=1.0055048, theta=-111.485244 -> V=1.0, theta=0.0
% INFO    : Bus 73304	: V=1.0046382, theta=-111.603914 -> V=1.0, theta=0.0
% INFO    : Bus 73305	: V=1.0043155, theta=-111.616993 -> V=1.0, theta=0.0
% INFO    : Bus 73306	: V=1.007946, theta=-110.968088 -> V=1.0, theta=0.0
% INFO    : Bus 73307	: V=1.0081549, theta=-110.959465 -> V=1.0, theta=0.0
% INFO    : Bus 73308	: V=1.0075502, theta=-110.992108 -> V=1.0, theta=0.0
% INFO    : Bus 73309	: V=1.007762, theta=-110.984226 -> V=1.0, theta=0.0
% INFO    : Bus 73310	: V=1.0071926, theta=-111.166668 -> V=1.0, theta=0.0
% INFO    : Bus 73311	: V=1.0074438, theta=-110.996435 -> V=1.0, theta=0.0
% INFO    : Bus 73312	: V=1.0075806, theta=-110.98409 -> V=1.0, theta=0.0
% INFO    : Bus 73313	: V=1.0077849, theta=-110.98034 -> V=1.0, theta=0.0
% INFO    : Bus 73314	: V=1.0076036, theta=-111.092715 -> V=1.0, theta=0.0
% INFO    : Bus 73315	: V=1.0072109, theta=-111.17668 -> V=1.0, theta=0.0
% INFO    : Bus 73316	: V=1.0070552, theta=-111.229138 -> V=1.0, theta=0.0
% INFO    : Bus 73317	: V=1.007282, theta=-111.151018 -> V=1.0, theta=0.0
% INFO    : Bus 73318	: V=1.0073783, theta=-111.127796 -> V=1.0, theta=0.0
% INFO    : Bus 73319	: V=1.0072982, theta=-111.105966 -> V=1.0, theta=0.0
% INFO    : Bus 73320	: V=1.0075397, theta=-111.09507 -> V=1.0, theta=0.0
% INFO    : Bus 73321	: V=1.0074575, theta=-110.637811 -> V=1.0, theta=0.0
% INFO    : Bus 73322	: V=1.0026026, theta=-111.78714 -> V=1.0, theta=0.0
% INFO    : Bus 73323	: V=1.0056945, theta=-110.934631 -> V=1.0, theta=0.0
% INFO    : Bus 73324	: V=1.012328, theta=-107.825055 -> V=1.0, theta=0.0
% INFO    : Bus 73325	: V=1.0058667, theta=-110.938445 -> V=1.0, theta=0.0
% INFO    : Bus 73326	: V=1.0097969, theta=-109.156759 -> V=1.0, theta=0.0
% INFO    : Bus 73327	: V=1.0065183, theta=-110.726625 -> V=1.0, theta=0.0
% INFO    : Bus 73328	: V=1.0080076, theta=-110.263038 -> V=1.0, theta=0.0
% INFO    : Bus 73329	: V=1.0249958, theta=-104.076131 -> V=1.0, theta=0.0
% INFO    : Bus 73330	: V=1.0075265, theta=-111.095707 -> V=1.0, theta=0.0
% INFO    : Bus 73331	: V=1.0069052, theta=-111.320808 -> V=1.0, theta=0.0
% INFO    : Bus 73332	: V=1.0058789, theta=-110.932269 -> V=1.0, theta=0.0
% INFO    : Bus 73333	: V=1.0057637, theta=-110.886683 -> V=1.0, theta=0.0
% INFO    : Bus 73334	: V=1.0078061, theta=-109.95603 -> V=1.0, theta=0.0
% INFO    : Bus 73335	: V=0.9903607, theta=-106.07728 -> V=1.0, theta=0.0
% INFO    : Bus 73336	: V=0.9892237, theta=-106.125405 -> V=1.0, theta=0.0
% INFO    : Bus 73337	: V=0.9887121, theta=-106.136258 -> V=1.0, theta=0.0
% INFO    : Bus 73338	: V=0.9896419, theta=-106.111652 -> V=1.0, theta=0.0
% INFO    : Bus 73339	: V=0.9885003, theta=-106.054096 -> V=1.0, theta=0.0
% INFO    : Bus 73340	: V=0.9867452, theta=-105.973137 -> V=1.0, theta=0.0
% INFO    : Bus 73341	: V=0.9886227, theta=-105.922502 -> V=1.0, theta=0.0
% INFO    : Bus 73342	: V=1.0100004, theta=-103.38734 -> V=1.0, theta=0.0
% INFO    : Bus 73343	: V=0.9947629, theta=-105.933766 -> V=1.0, theta=0.0
% INFO    : Bus 73344	: V=0.9966946, theta=-105.09571 -> V=1.0, theta=0.0
% INFO    : Bus 73345	: V=0.9893874, theta=-106.082533 -> V=1.0, theta=0.0
% INFO    : Bus 73346	: V=0.9910328, theta=-106.052916 -> V=1.0, theta=0.0
% INFO    : Bus 73347	: V=0.9893663, theta=-106.126075 -> V=1.0, theta=0.0
% INFO    : Bus 73348	: V=0.9892913, theta=-106.12929 -> V=1.0, theta=0.0
% INFO    : Bus 73349	: V=0.9878986, theta=-106.133739 -> V=1.0, theta=0.0
% INFO    : Bus 73350	: V=0.99298, theta=-105.193094 -> V=1.0, theta=0.0
% INFO    : Bus 73351	: V=0.9888427, theta=-106.039983 -> V=1.0, theta=0.0
% INFO    : Bus 73352	: V=0.9888968, theta=-106.031601 -> V=1.0, theta=0.0
% INFO    : Bus 73353	: V=0.9924167, theta=-105.140922 -> V=1.0, theta=0.0
% INFO    : Bus 73354	: V=0.9853222, theta=-106.00076 -> V=1.0, theta=0.0
% INFO    : Bus 73355	: V=0.9844294, theta=-106.013199 -> V=1.0, theta=0.0
% INFO    : Bus 73356	: V=0.977808, theta=-106.090426 -> V=1.0, theta=0.0
% INFO    : Bus 73357	: V=0.9910177, theta=-106.495744 -> V=1.0, theta=0.0
% INFO    : Bus 73358	: V=0.990321, theta=-106.521921 -> V=1.0, theta=0.0
% INFO    : Bus 73359	: V=0.9922898, theta=-105.261754 -> V=1.0, theta=0.0
% INFO    : Bus 73360	: V=0.9930022, theta=-105.230199 -> V=1.0, theta=0.0
% INFO    : Bus 73361	: V=0.9878271, theta=-105.641916 -> V=1.0, theta=0.0
% INFO    : Bus 73362	: V=0.9944217, theta=-105.165893 -> V=1.0, theta=0.0
% INFO    : Bus 73363	: V=0.9882665, theta=-105.642693 -> V=1.0, theta=0.0
% INFO    : Bus 73364	: V=0.9924356, theta=-105.105284 -> V=1.0, theta=0.0
% INFO    : Bus 73365	: V=0.9913168, theta=-105.986172 -> V=1.0, theta=0.0
% INFO    : Bus 73366	: V=0.9906414, theta=-105.350277 -> V=1.0, theta=0.0
% INFO    : Bus 73367	: V=0.9882696, theta=-106.194726 -> V=1.0, theta=0.0
% INFO    : Bus 73368	: V=0.9889222, theta=-106.185003 -> V=1.0, theta=0.0
% INFO    : Bus 73369	: V=0.9892884, theta=-106.199514 -> V=1.0, theta=0.0
% INFO    : Bus 73370	: V=0.9890561, theta=-106.17998 -> V=1.0, theta=0.0
% INFO    : Bus 73371	: V=0.9860531, theta=-106.209479 -> V=1.0, theta=0.0
% INFO    : Bus 73372	: V=0.9862036, theta=-106.209497 -> V=1.0, theta=0.0
% INFO    : Bus 73373	: V=0.987984, theta=-106.1339 -> V=1.0, theta=0.0
% INFO    : Bus 73374	: V=0.9873222, theta=-106.19397 -> V=1.0, theta=0.0
% INFO    : Bus 73375	: V=0.9897585, theta=-106.180217 -> V=1.0, theta=0.0
% INFO    : Bus 73376	: V=0.9902544, theta=-106.142376 -> V=1.0, theta=0.0
% INFO    : Bus 73377	: V=0.9922893, theta=-106.021667 -> V=1.0, theta=0.0
% INFO    : Bus 73378	: V=0.9912232, theta=-106.05534 -> V=1.0, theta=0.0
% INFO    : Bus 73379	: V=0.989962, theta=-106.152494 -> V=1.0, theta=0.0
% INFO    : Bus 73380	: V=0.9923968, theta=-106.001711 -> V=1.0, theta=0.0
% INFO    : Bus 73381	: V=0.9932668, theta=-105.934529 -> V=1.0, theta=0.0
% INFO    : Bus 73382	: V=0.995392, theta=-105.731472 -> V=1.0, theta=0.0
% INFO    : Bus 73383	: V=0.9901599, theta=-106.144999 -> V=1.0, theta=0.0
% INFO    : Bus 73384	: V=0.9903777, theta=-106.136714 -> V=1.0, theta=0.0
% INFO    : Bus 73385	: V=0.9842075, theta=-106.264633 -> V=1.0, theta=0.0
% INFO    : Bus 73386	: V=0.9891149, theta=-106.182064 -> V=1.0, theta=0.0
% INFO    : Bus 73387	: V=0.9893659, theta=-106.170487 -> V=1.0, theta=0.0
% INFO    : Bus 73388	: V=0.9875909, theta=-106.132347 -> V=1.0, theta=0.0
% INFO    : Bus 73389	: V=0.9899227, theta=-106.118934 -> V=1.0, theta=0.0
% INFO    : Bus 73390	: V=0.9913105, theta=-106.02154 -> V=1.0, theta=0.0
% INFO    : Bus 73391	: V=0.9836506, theta=-106.266466 -> V=1.0, theta=0.0
% INFO    : Bus 73392	: V=0.9834845, theta=-106.266861 -> V=1.0, theta=0.0
% INFO    : Bus 73393	: V=0.9932514, theta=-104.783056 -> V=1.0, theta=0.0
% INFO    : Bus 73394	: V=0.9909349, theta=-105.999664 -> V=1.0, theta=0.0
% INFO    : Bus 73395	: V=0.9905017, theta=-106.071583 -> V=1.0, theta=0.0
% INFO    : Bus 73396	: V=0.990638, theta=-106.048363 -> V=1.0, theta=0.0
% INFO    : Bus 73397	: V=0.98972, theta=-106.15461 -> V=1.0, theta=0.0
% INFO    : Bus 73398	: V=0.9890882, theta=-106.17844 -> V=1.0, theta=0.0
% INFO    : Bus 73399	: V=0.9900079, theta=-106.134302 -> V=1.0, theta=0.0
% INFO    : Bus 73400	: V=0.9897078, theta=-106.032078 -> V=1.0, theta=0.0
% INFO    : Bus 73401	: V=0.9901187, theta=-105.81953 -> V=1.0, theta=0.0
% INFO    : Bus 73402	: V=0.9902855, theta=-105.162831 -> V=1.0, theta=0.0
% INFO    : Bus 73403	: V=0.9932178, theta=-104.914821 -> V=1.0, theta=0.0
% INFO    : Bus 73404	: V=0.9876936, theta=-105.683567 -> V=1.0, theta=0.0
% INFO    : Bus 73405	: V=0.9864499, theta=-105.68381 -> V=1.0, theta=0.0
% INFO    : Bus 73406	: V=0.9902823, theta=-105.400906 -> V=1.0, theta=0.0
% INFO    : Bus 73407	: V=0.9980121, theta=-105.074155 -> V=1.0, theta=0.0
% INFO    : Bus 73408	: V=1.0025516, theta=-104.909457 -> V=1.0, theta=0.0
% INFO    : Bus 73409	: V=0.996403, theta=-105.693263 -> V=1.0, theta=0.0
% INFO    : Bus 73410	: V=0.9943171, theta=-104.269911 -> V=1.0, theta=0.0
% INFO    : Bus 73411	: V=0.9992997, theta=-104.602916 -> V=1.0, theta=0.0
% INFO    : Bus 73412	: V=0.9997449, theta=-104.592043 -> V=1.0, theta=0.0
% INFO    : Bus 73413	: V=1.0021995, theta=-104.774958 -> V=1.0, theta=0.0
% INFO    : Bus 73414	: V=1.0004006, theta=-104.557786 -> V=1.0, theta=0.0
% INFO    : Bus 73415	: V=0.9986847, theta=-104.541436 -> V=1.0, theta=0.0
% INFO    : Bus 73416	: V=0.9987989, theta=-104.536153 -> V=1.0, theta=0.0
% INFO    : Bus 73417	: V=0.998219, theta=-104.59332 -> V=1.0, theta=0.0
% INFO    : Bus 73418	: V=0.9974689, theta=-104.633129 -> V=1.0, theta=0.0
% INFO    : Bus 73419	: V=0.9966618, theta=-104.728455 -> V=1.0, theta=0.0
% INFO    : Bus 73420	: V=0.9956287, theta=-104.782282 -> V=1.0, theta=0.0
% INFO    : Bus 73421	: V=0.9966728, theta=-104.713998 -> V=1.0, theta=0.0
% INFO    : Bus 73422	: V=0.9962283, theta=-104.730597 -> V=1.0, theta=0.0
% INFO    : Bus 73423	: V=0.9961202, theta=-104.507745 -> V=1.0, theta=0.0
% INFO    : Bus 73424	: V=0.99689, theta=-104.42965 -> V=1.0, theta=0.0
% INFO    : Bus 73425	: V=0.9957314, theta=-103.595659 -> V=1.0, theta=0.0
% INFO    : Bus 73426	: V=0.9976602, theta=-104.131811 -> V=1.0, theta=0.0
% INFO    : Bus 73427	: V=0.9960321, theta=-103.431744 -> V=1.0, theta=0.0
% INFO    : Bus 73428	: V=0.9982829, theta=-102.818022 -> V=1.0, theta=0.0
% INFO    : Bus 73429	: V=0.997318, theta=-102.360342 -> V=1.0, theta=0.0
% INFO    : Bus 73430	: V=1.0086811, theta=-97.617599 -> V=1.0, theta=0.0
% INFO    : Bus 73431	: V=0.9917998, theta=-102.919719 -> V=1.0, theta=0.0
% INFO    : Bus 73432	: V=0.9942619, theta=-103.343863 -> V=1.0, theta=0.0
% INFO    : Bus 73433	: V=0.9923652, theta=-107.940136 -> V=1.0, theta=0.0
% INFO    : Bus 73434	: V=0.9909796, theta=-108.082532 -> V=1.0, theta=0.0
% INFO    : Bus 73435	: V=0.9984925, theta=-105.251372 -> V=1.0, theta=0.0
% INFO    : Bus 73436	: V=1.0080532, theta=-105.762976 -> V=1.0, theta=0.0
% INFO    : Bus 73437	: V=0.9934729, theta=-105.48631 -> V=1.0, theta=0.0
% INFO    : Bus 73438	: V=0.9858748, theta=-105.845643 -> V=1.0, theta=0.0
% INFO    : Bus 73439	: V=0.9861978, theta=-106.009086 -> V=1.0, theta=0.0
% INFO    : Bus 73440	: V=0.9848051, theta=-106.112329 -> V=1.0, theta=0.0
% INFO    : Bus 73441	: V=0.9855645, theta=-106.088477 -> V=1.0, theta=0.0
% INFO    : Bus 73442	: V=0.9846837, theta=-106.109246 -> V=1.0, theta=0.0
% INFO    : Bus 73443	: V=0.9842641, theta=-106.107088 -> V=1.0, theta=0.0
% INFO    : Bus 73444	: V=1.0100004, theta=-103.767563 -> V=1.0, theta=0.0
% INFO    : Bus 73445	: V=0.9841881, theta=-105.727944 -> V=1.0, theta=0.0
% INFO    : Bus 73446	: V=0.9975559, theta=-105.215066 -> V=1.0, theta=0.0
% INFO    : Bus 73447	: V=0.9867967, theta=-105.958835 -> V=1.0, theta=0.0
% INFO    : Bus 73448	: V=0.9856115, theta=-105.964208 -> V=1.0, theta=0.0
% INFO    : Bus 73449	: V=0.9853268, theta=-105.996655 -> V=1.0, theta=0.0
% INFO    : Bus 73450	: V=0.9873792, theta=-105.679727 -> V=1.0, theta=0.0
% INFO    : Bus 73451	: V=0.9897395, theta=-105.650607 -> V=1.0, theta=0.0
% INFO    : Bus 73452	: V=0.9977281, theta=-105.190178 -> V=1.0, theta=0.0
% INFO    : Bus 73453	: V=0.9697238, theta=-106.423272 -> V=1.0, theta=0.0
% INFO    : Bus 73454	: V=0.9836084, theta=-106.120788 -> V=1.0, theta=0.0
% INFO    : Bus 73455	: V=0.9840155, theta=-106.119541 -> V=1.0, theta=0.0
% INFO    : Bus 73456	: V=0.9857789, theta=-105.962697 -> V=1.0, theta=0.0
% INFO    : Bus 73457	: V=0.9842264, theta=-105.7909 -> V=1.0, theta=0.0
% INFO    : Bus 73458	: V=0.9987006, theta=-106.158994 -> V=1.0, theta=0.0
% INFO    : Bus 73459	: V=0.9996103, theta=-107.482124 -> V=1.0, theta=0.0
% INFO    : Bus 73460	: V=1.0166894, theta=-106.269434 -> V=1.0, theta=0.0
% INFO    : Bus 73461	: V=1.0049345, theta=-107.270297 -> V=1.0, theta=0.0
% INFO    : Bus 73462	: V=1.0051141, theta=-107.429259 -> V=1.0, theta=0.0
% INFO    : Bus 73463	: V=1.0055761, theta=-107.36504 -> V=1.0, theta=0.0
% INFO    : Bus 73464	: V=1.0042968, theta=-106.314595 -> V=1.0, theta=0.0
% INFO    : Bus 73465	: V=1.005749, theta=-106.342207 -> V=1.0, theta=0.0
% INFO    : Bus 73466	: V=1.005395, theta=-107.114357 -> V=1.0, theta=0.0
% INFO    : Bus 73467	: V=1.0053858, theta=-107.157088 -> V=1.0, theta=0.0
% INFO    : Bus 73468	: V=1.0053807, theta=-107.19226 -> V=1.0, theta=0.0
% INFO    : Bus 73469	: V=1.0099564, theta=-106.370711 -> V=1.0, theta=0.0
% INFO    : Bus 73470	: V=1.006891, theta=-107.028526 -> V=1.0, theta=0.0
% INFO    : Bus 73471	: V=1.0079651, theta=-106.366047 -> V=1.0, theta=0.0
% INFO    : Bus 73472	: V=0.9860174, theta=-106.658195 -> V=1.0, theta=0.0
% INFO    : Bus 73473	: V=1.0027473, theta=-108.177977 -> V=1.0, theta=0.0
% INFO    : Bus 73474	: V=1.0047784, theta=-85.220697 -> V=1.0, theta=0.0
% INFO    : Bus 73475	: V=1.0042093, theta=-80.74641 -> V=1.0, theta=0.0
% INFO    : Bus 73476	: V=1.0111466, theta=-80.645718 -> V=1.0, theta=0.0
% INFO    : Bus 73477	: V=1.0294343, theta=-79.304315 -> V=1.0, theta=0.0
% INFO    : Bus 73478	: V=1.0300004, theta=-79.828844 -> V=1.0, theta=0.0
% INFO    : Bus 73479	: V=1.0011957, theta=-81.157427 -> V=1.0, theta=0.0
% INFO    : Bus 73480	: V=1.0050749, theta=-80.974291 -> V=1.0, theta=0.0
% INFO    : Bus 73481	: V=1.0072647, theta=-80.868796 -> V=1.0, theta=0.0
% INFO    : Bus 73482	: V=0.9972448, theta=-80.548517 -> V=1.0, theta=0.0
% INFO    : Bus 73483	: V=0.9983927, theta=-84.793123 -> V=1.0, theta=0.0
% INFO    : Bus 73484	: V=0.9997487, theta=-84.736285 -> V=1.0, theta=0.0
% INFO    : Bus 73485	: V=1.0077417, theta=-82.588175 -> V=1.0, theta=0.0
% INFO    : Bus 73486	: V=1.0055818, theta=-82.626744 -> V=1.0, theta=0.0
% INFO    : Bus 73487	: V=1.0103663, theta=-82.316695 -> V=1.0, theta=0.0
% INFO    : Bus 73488	: V=1.0090221, theta=-82.432041 -> V=1.0, theta=0.0
% INFO    : Bus 73489	: V=1.0141203, theta=-82.004036 -> V=1.0, theta=0.0
% INFO    : Bus 73490	: V=1.0147946, theta=-82.002668 -> V=1.0, theta=0.0
% INFO    : Bus 73491	: V=1.0131189, theta=-82.025697 -> V=1.0, theta=0.0
% INFO    : Bus 73492	: V=0.9916908, theta=-81.392412 -> V=1.0, theta=0.0
% INFO    : Bus 73493	: V=0.9911452, theta=-81.340686 -> V=1.0, theta=0.0
% INFO    : Bus 73494	: V=0.9910435, theta=-81.441363 -> V=1.0, theta=0.0
% INFO    : Bus 73495	: V=0.9916373, theta=-81.390343 -> V=1.0, theta=0.0
% INFO    : Bus 73496	: V=0.9925128, theta=-81.334923 -> V=1.0, theta=0.0
% INFO    : Bus 73497	: V=0.9909678, theta=-81.331382 -> V=1.0, theta=0.0
% INFO    : Bus 73498	: V=0.9999699, theta=-80.33196 -> V=1.0, theta=0.0
% INFO    : Bus 73499	: V=1.0063584, theta=-80.824153 -> V=1.0, theta=0.0
% INFO    : Bus 73500	: V=1.0016187, theta=-80.20525 -> V=1.0, theta=0.0
% INFO    : Bus 73501	: V=1.008584, theta=-80.775453 -> V=1.0, theta=0.0
% INFO    : Bus 73502	: V=0.9932323, theta=-81.483752 -> V=1.0, theta=0.0
% INFO    : Bus 73503	: V=0.9909698, theta=-81.502042 -> V=1.0, theta=0.0
% INFO    : Bus 73504	: V=0.9874973, theta=-81.67082 -> V=1.0, theta=0.0
% INFO    : Bus 73505	: V=1.0019472, theta=-80.649526 -> V=1.0, theta=0.0
% INFO    : Bus 73506	: V=0.9869423, theta=-82.585214 -> V=1.0, theta=0.0
% INFO    : Bus 73507	: V=0.9858636, theta=-82.703418 -> V=1.0, theta=0.0
% INFO    : Bus 73508	: V=0.9863493, theta=-82.465859 -> V=1.0, theta=0.0
% INFO    : Bus 73509	: V=0.9890637, theta=-82.2366 -> V=1.0, theta=0.0
% INFO    : Bus 73510	: V=0.9846532, theta=-82.737165 -> V=1.0, theta=0.0
% INFO    : Bus 73511	: V=0.9842758, theta=-82.779132 -> V=1.0, theta=0.0
% INFO    : Bus 73512	: V=0.9847415, theta=-82.779391 -> V=1.0, theta=0.0
% INFO    : Bus 73513	: V=0.9839169, theta=-82.781064 -> V=1.0, theta=0.0
% INFO    : Bus 73514	: V=0.9748919, theta=-81.842426 -> V=1.0, theta=0.0
% INFO    : Bus 73515	: V=1.0081876, theta=-80.374292 -> V=1.0, theta=0.0
% INFO    : Bus 73516	: V=0.9949323, theta=-81.939784 -> V=1.0, theta=0.0
% INFO    : Bus 73517	: V=1.0095878, theta=-80.248621 -> V=1.0, theta=0.0
% INFO    : Bus 73518	: V=1.0089708, theta=-80.77616 -> V=1.0, theta=0.0
% INFO    : Bus 73519	: V=1.0085786, theta=-80.827951 -> V=1.0, theta=0.0
% INFO    : Bus 73520	: V=1.0077796, theta=-80.431855 -> V=1.0, theta=0.0
% INFO    : Bus 73521	: V=1.0077205, theta=-80.379433 -> V=1.0, theta=0.0
% INFO    : Bus 73522	: V=1.0011508, theta=-77.533281 -> V=1.0, theta=0.0
% INFO    : Bus 73523	: V=1.0283292, theta=-77.52755 -> V=1.0, theta=0.0
% INFO    : Bus 73524	: V=1.0085865, theta=-80.826234 -> V=1.0, theta=0.0
% INFO    : Bus 73525	: V=1.0035084, theta=-82.129461 -> V=1.0, theta=0.0
% INFO    : Bus 73526	: V=1.0049348, theta=-84.454507 -> V=1.0, theta=0.0
% INFO    : Bus 73527	: V=1.0045682, theta=-110.466354 -> V=1.0, theta=0.0
% INFO    : Bus 73528	: V=1.005238, theta=-110.401449 -> V=1.0, theta=0.0
% INFO    : Bus 73529	: V=1.004939, theta=-111.055302 -> V=1.0, theta=0.0
% INFO    : Bus 73530	: V=1.0045536, theta=-111.204346 -> V=1.0, theta=0.0
% INFO    : Bus 73531	: V=1.0048741, theta=-111.169401 -> V=1.0, theta=0.0
% INFO    : Bus 73532	: V=1.0036796, theta=-111.419863 -> V=1.0, theta=0.0
% INFO    : Bus 73533	: V=1.0013353, theta=-112.242176 -> V=1.0, theta=0.0
% INFO    : Bus 73534	: V=1.0048236, theta=-110.584285 -> V=1.0, theta=0.0
% INFO    : Bus 73535	: V=1.0016815, theta=-112.137833 -> V=1.0, theta=0.0
% INFO    : Bus 73536	: V=1.0021416, theta=-112.046508 -> V=1.0, theta=0.0
% INFO    : Bus 73537	: V=0.9994725, theta=-112.473526 -> V=1.0, theta=0.0
% INFO    : Bus 73538	: V=1.0009573, theta=-112.116926 -> V=1.0, theta=0.0
% INFO    : Bus 73539	: V=1.0013758, theta=-112.101326 -> V=1.0, theta=0.0
% INFO    : Bus 73540	: V=1.0042666, theta=-110.665049 -> V=1.0, theta=0.0
% INFO    : Bus 73541	: V=1.0002848, theta=-112.44325 -> V=1.0, theta=0.0
% INFO    : Bus 73542	: V=1.0000463, theta=-112.48975 -> V=1.0, theta=0.0
% INFO    : Bus 73543	: V=0.9998359, theta=-112.518157 -> V=1.0, theta=0.0
% INFO    : Bus 73544	: V=1.0041118, theta=-110.678784 -> V=1.0, theta=0.0
% INFO    : Bus 73545	: V=1.0004275, theta=-111.966074 -> V=1.0, theta=0.0
% INFO    : Bus 73546	: V=0.9998598, theta=-112.529915 -> V=1.0, theta=0.0
% INFO    : Bus 73547	: V=0.999945, theta=-112.021211 -> V=1.0, theta=0.0
% INFO    : Bus 73548	: V=1.0001069, theta=-111.978044 -> V=1.0, theta=0.0
% INFO    : Bus 73549	: V=1.0013192, theta=-111.83395 -> V=1.0, theta=0.0
% INFO    : Bus 73550	: V=1.0014161, theta=-111.118226 -> V=1.0, theta=0.0
% INFO    : Bus 73551	: V=1.0036307, theta=-110.680732 -> V=1.0, theta=0.0
% INFO    : Bus 73552	: V=1.0018065, theta=-111.102256 -> V=1.0, theta=0.0
% INFO    : Bus 73553	: V=1.003153, theta=-111.097192 -> V=1.0, theta=0.0
% INFO    : Bus 73554	: V=1.0026911, theta=-111.046172 -> V=1.0, theta=0.0
% INFO    : Bus 73555	: V=1.0100004, theta=-108.844244 -> V=1.0, theta=0.0
% INFO    : Bus 73556	: V=1.0017834, theta=-111.704647 -> V=1.0, theta=0.0
% INFO    : Bus 73557	: V=1.0007692, theta=-111.693468 -> V=1.0, theta=0.0
% INFO    : Bus 73558	: V=1.0000827, theta=-112.043319 -> V=1.0, theta=0.0
% INFO    : Bus 73559	: V=0.9993694, theta=-112.069939 -> V=1.0, theta=0.0
% INFO    : Bus 73560	: V=0.9990337, theta=-112.072885 -> V=1.0, theta=0.0
% INFO    : Bus 73561	: V=0.9985552, theta=-112.090742 -> V=1.0, theta=0.0
% INFO    : Bus 73562	: V=0.9987282, theta=-112.094107 -> V=1.0, theta=0.0
% INFO    : Bus 73563	: V=0.999487, theta=-111.753099 -> V=1.0, theta=0.0
% INFO    : Bus 73564	: V=0.9977606, theta=-112.166812 -> V=1.0, theta=0.0
% INFO    : Bus 73565	: V=0.998306, theta=-112.146162 -> V=1.0, theta=0.0
% INFO    : Bus 73566	: V=1.0009511, theta=-111.547011 -> V=1.0, theta=0.0
% INFO    : Bus 73567	: V=1.0010776, theta=-111.679423 -> V=1.0, theta=0.0
% INFO    : Bus 73568	: V=1.0025176, theta=-111.446804 -> V=1.0, theta=0.0
% INFO    : Bus 73569	: V=1.0024073, theta=-111.480485 -> V=1.0, theta=0.0
% INFO    : Bus 73570	: V=1.0024274, theta=-111.051509 -> V=1.0, theta=0.0
% INFO    : Bus 73571	: V=1.0025191, theta=-111.344102 -> V=1.0, theta=0.0
% INFO    : Bus 73572	: V=1.0027811, theta=-111.332289 -> V=1.0, theta=0.0
% INFO    : Bus 73573	: V=1.0033656, theta=-110.895222 -> V=1.0, theta=0.0
% INFO    : Bus 73574	: V=1.0028821, theta=-111.281945 -> V=1.0, theta=0.0
% INFO    : Bus 73575	: V=1.0012485, theta=-111.555055 -> V=1.0, theta=0.0
% INFO    : Bus 73576	: V=1.0025084, theta=-111.373618 -> V=1.0, theta=0.0
% INFO    : Bus 73577	: V=1.0021121, theta=-111.090729 -> V=1.0, theta=0.0
% INFO    : Bus 73578	: V=1.0019031, theta=-111.115885 -> V=1.0, theta=0.0
% INFO    : Bus 73579	: V=1.0011847, theta=-111.55807 -> V=1.0, theta=0.0
% INFO    : Bus 73580	: V=1.0017322, theta=-111.134375 -> V=1.0, theta=0.0
% INFO    : Bus 73581	: V=1.0015665, theta=-111.154947 -> V=1.0, theta=0.0
% INFO    : Bus 73582	: V=1.0015254, theta=-111.181903 -> V=1.0, theta=0.0
% INFO    : Bus 73583	: V=0.9998142, theta=-112.284863 -> V=1.0, theta=0.0
% INFO    : Bus 73584	: V=1.0011579, theta=-111.226688 -> V=1.0, theta=0.0
% INFO    : Bus 73585	: V=1.0006512, theta=-111.589554 -> V=1.0, theta=0.0
% INFO    : Bus 73586	: V=1.000996, theta=-111.241023 -> V=1.0, theta=0.0
% INFO    : Bus 73587	: V=1.0000933, theta=-111.590954 -> V=1.0, theta=0.0
% INFO    : Bus 73588	: V=1.0005085, theta=-111.272174 -> V=1.0, theta=0.0
% INFO    : Bus 73589	: V=1.0007923, theta=-111.255828 -> V=1.0, theta=0.0
% INFO    : Bus 73590	: V=0.9997231, theta=-112.141016 -> V=1.0, theta=0.0
% INFO    : Bus 73591	: V=1.0006965, theta=-111.278082 -> V=1.0, theta=0.0
% INFO    : Bus 73592	: V=0.9997807, theta=-112.140186 -> V=1.0, theta=0.0
% INFO    : Bus 73593	: V=1.0005809, theta=-111.284263 -> V=1.0, theta=0.0
% INFO    : Bus 73594	: V=1.0006284, theta=-111.271189 -> V=1.0, theta=0.0
% INFO    : Bus 73595	: V=1.0006759, theta=-111.269509 -> V=1.0, theta=0.0
% INFO    : Bus 73596	: V=1.0001874, theta=-111.572919 -> V=1.0, theta=0.0
% INFO    : Bus 73597	: V=1.0002416, theta=-111.5848 -> V=1.0, theta=0.0
% INFO    : Bus 73598	: V=1.0002122, theta=-111.304758 -> V=1.0, theta=0.0
% INFO    : Bus 73599	: V=1.0003209, theta=-111.28181 -> V=1.0, theta=0.0
% INFO    : Bus 73600	: V=0.9975344, theta=-111.827285 -> V=1.0, theta=0.0
% INFO    : Bus 73601	: V=0.9977537, theta=-111.838176 -> V=1.0, theta=0.0
% INFO    : Bus 73602	: V=0.997481, theta=-111.780106 -> V=1.0, theta=0.0
% INFO    : Bus 73603	: V=1.0007546, theta=-111.213712 -> V=1.0, theta=0.0
% INFO    : Bus 73604	: V=0.9980658, theta=-111.75419 -> V=1.0, theta=0.0
% INFO    : Bus 73605	: V=1.0003357, theta=-111.301953 -> V=1.0, theta=0.0
% INFO    : Bus 73606	: V=1.000656, theta=-111.244793 -> V=1.0, theta=0.0
% INFO    : Bus 73607	: V=1.0006202, theta=-111.262138 -> V=1.0, theta=0.0
% INFO    : Bus 73608	: V=1.0004415, theta=-111.290373 -> V=1.0, theta=0.0
% INFO    : Bus 73609	: V=1.0004219, theta=-111.285772 -> V=1.0, theta=0.0
% INFO    : Bus 73610	: V=1.0003131, theta=-111.288448 -> V=1.0, theta=0.0
% INFO    : Bus 73611	: V=1.0002655, theta=-111.291056 -> V=1.0, theta=0.0
% INFO    : Bus 73612	: V=0.9942929, theta=-112.072019 -> V=1.0, theta=0.0
% INFO    : Bus 73613	: V=0.994801, theta=-112.01916 -> V=1.0, theta=0.0
% INFO    : Bus 73614	: V=1.0002334, theta=-111.285315 -> V=1.0, theta=0.0
% INFO    : Bus 73615	: V=0.9948444, theta=-112.018195 -> V=1.0, theta=0.0
% INFO    : Bus 73616	: V=0.9950206, theta=-112.010125 -> V=1.0, theta=0.0
% INFO    : Bus 73617	: V=0.9937025, theta=-112.094303 -> V=1.0, theta=0.0
% INFO    : Bus 73618	: V=0.9935107, theta=-112.101506 -> V=1.0, theta=0.0
% INFO    : Bus 73619	: V=0.994091, theta=-112.081286 -> V=1.0, theta=0.0
% INFO    : Bus 73620	: V=0.9961567, theta=-111.976322 -> V=1.0, theta=0.0
% INFO    : Bus 73621	: V=0.9958796, theta=-111.940311 -> V=1.0, theta=0.0
% INFO    : Bus 73622	: V=0.9958004, theta=-111.938122 -> V=1.0, theta=0.0
% INFO    : Bus 73623	: V=0.9957645, theta=-111.925792 -> V=1.0, theta=0.0
% INFO    : Bus 73624	: V=0.9967608, theta=-111.799774 -> V=1.0, theta=0.0
% INFO    : Bus 73625	: V=0.9973009, theta=-111.863349 -> V=1.0, theta=0.0
% INFO    : Bus 73626	: V=0.996973, theta=-111.863742 -> V=1.0, theta=0.0
% INFO    : Bus 73627	: V=0.9963511, theta=-111.750902 -> V=1.0, theta=0.0
% INFO    : Bus 73628	: V=1.0100004, theta=-109.948774 -> V=1.0, theta=0.0
% INFO    : Bus 73629	: V=0.9962712, theta=-111.65232 -> V=1.0, theta=0.0
% INFO    : Bus 73630	: V=0.9966418, theta=-111.666376 -> V=1.0, theta=0.0
% INFO    : Bus 73631	: V=0.9956543, theta=-111.676936 -> V=1.0, theta=0.0
% INFO    : Bus 73632	: V=0.9960252, theta=-111.654921 -> V=1.0, theta=0.0
% INFO    : Bus 73633	: V=0.9961312, theta=-111.685805 -> V=1.0, theta=0.0
% INFO    : Bus 73634	: V=0.9958107, theta=-111.695162 -> V=1.0, theta=0.0
% INFO    : Bus 73635	: V=0.995678, theta=-111.697446 -> V=1.0, theta=0.0
% INFO    : Bus 73636	: V=0.995635, theta=-111.695414 -> V=1.0, theta=0.0
% INFO    : Bus 73637	: V=0.9957073, theta=-111.695288 -> V=1.0, theta=0.0
% INFO    : Bus 73638	: V=0.9955426, theta=-111.684791 -> V=1.0, theta=0.0
% INFO    : Bus 73639	: V=0.9949261, theta=-111.685903 -> V=1.0, theta=0.0
% INFO    : Bus 73640	: V=0.9952665, theta=-111.683672 -> V=1.0, theta=0.0
% INFO    : Bus 73641	: V=0.999959, theta=-111.15359 -> V=1.0, theta=0.0
% INFO    : Bus 73642	: V=0.9992966, theta=-111.177207 -> V=1.0, theta=0.0
% INFO    : Bus 73643	: V=0.9995577, theta=-111.170025 -> V=1.0, theta=0.0
% INFO    : Bus 73644	: V=0.9984103, theta=-112.180098 -> V=1.0, theta=0.0
% INFO    : Bus 73645	: V=0.9944668, theta=-111.812192 -> V=1.0, theta=0.0
% INFO    : Bus 73646	: V=0.995009, theta=-111.921437 -> V=1.0, theta=0.0
% INFO    : Bus 73647	: V=0.9961266, theta=-111.863522 -> V=1.0, theta=0.0
% INFO    : Bus 73648	: V=0.9981785, theta=-111.525549 -> V=1.0, theta=0.0
% INFO    : Bus 73649	: V=0.9987706, theta=-111.181668 -> V=1.0, theta=0.0
% INFO    : Bus 73650	: V=0.9973101, theta=-111.625206 -> V=1.0, theta=0.0
% INFO    : Bus 73651	: V=0.9984688, theta=-111.178624 -> V=1.0, theta=0.0
% INFO    : Bus 73652	: V=0.9980851, theta=-111.208518 -> V=1.0, theta=0.0
% INFO    : Bus 73653	: V=0.9967607, theta=-111.675374 -> V=1.0, theta=0.0
% INFO    : Bus 73654	: V=0.997986, theta=-112.199255 -> V=1.0, theta=0.0
% INFO    : Bus 73655	: V=0.9962812, theta=-111.69913 -> V=1.0, theta=0.0
% INFO    : Bus 73656	: V=0.9965998, theta=-111.255178 -> V=1.0, theta=0.0
% INFO    : Bus 73657	: V=0.9967718, theta=-111.228057 -> V=1.0, theta=0.0
% INFO    : Bus 73658	: V=0.9969341, theta=-111.209657 -> V=1.0, theta=0.0
% INFO    : Bus 73659	: V=0.9965874, theta=-111.181415 -> V=1.0, theta=0.0
% INFO    : Bus 73660	: V=0.9980805, theta=-111.153972 -> V=1.0, theta=0.0
% INFO    : Bus 73661	: V=0.9980993, theta=-111.404117 -> V=1.0, theta=0.0
% INFO    : Bus 73662	: V=0.9991233, theta=-110.830277 -> V=1.0, theta=0.0
% INFO    : Bus 73663	: V=0.9985923, theta=-110.86415 -> V=1.0, theta=0.0
% INFO    : Bus 73664	: V=0.9980656, theta=-110.904214 -> V=1.0, theta=0.0
% INFO    : Bus 73665	: V=0.9952692, theta=-111.644237 -> V=1.0, theta=0.0
% INFO    : Bus 73666	: V=0.9972737, theta=-110.999219 -> V=1.0, theta=0.0
% INFO    : Bus 73667	: V=0.9976726, theta=-111.122624 -> V=1.0, theta=0.0
% INFO    : Bus 73668	: V=0.9960279, theta=-111.111395 -> V=1.0, theta=0.0
% INFO    : Bus 73669	: V=0.9961095, theta=-111.461123 -> V=1.0, theta=0.0
% INFO    : Bus 73670	: V=0.9960324, theta=-111.460214 -> V=1.0, theta=0.0
% INFO    : Bus 73671	: V=0.994833, theta=-111.102778 -> V=1.0, theta=0.0
% INFO    : Bus 73672	: V=0.9947472, theta=-111.119765 -> V=1.0, theta=0.0
% INFO    : Bus 73673	: V=0.9858954, theta=-111.467562 -> V=1.0, theta=0.0
% INFO    : Bus 73674	: V=0.9952564, theta=-111.693505 -> V=1.0, theta=0.0
% INFO    : Bus 73675	: V=0.9912174, theta=-112.187276 -> V=1.0, theta=0.0
% INFO    : Bus 73676	: V=0.9951344, theta=-112.567481 -> V=1.0, theta=0.0
% INFO    : Bus 73677	: V=0.9929891, theta=-112.657222 -> V=1.0, theta=0.0
% INFO    : Bus 73678	: V=0.9962614, theta=-112.370792 -> V=1.0, theta=0.0
% INFO    : Bus 73679	: V=0.9857191, theta=-111.924349 -> V=1.0, theta=0.0
% INFO    : Bus 73680	: V=0.9792527, theta=-112.510788 -> V=1.0, theta=0.0
% INFO    : Bus 73681	: V=0.9974527, theta=-111.069845 -> V=1.0, theta=0.0
% INFO    : Bus 73682	: V=1.000374, theta=-111.719631 -> V=1.0, theta=0.0
% INFO    : Bus 73683	: V=1.0018951, theta=-111.42876 -> V=1.0, theta=0.0
% INFO    : Bus 73684	: V=1.0100003, theta=-83.188915 -> V=1.0, theta=0.0
% INFO    : Bus 73685	: V=1.0100003, theta=-83.242448 -> V=1.0, theta=0.0
% INFO    : Bus 73686	: V=1.0073688, theta=-82.470818 -> V=1.0, theta=0.0
% INFO    : Bus 73687	: V=1.0098169, theta=-83.301718 -> V=1.0, theta=0.0
% INFO    : Bus 73688	: V=1.000782, theta=-83.919088 -> V=1.0, theta=0.0
% INFO    : Bus 73689	: V=1.0051002, theta=-83.572427 -> V=1.0, theta=0.0
% INFO    : Bus 73690	: V=1.0004251, theta=-83.965314 -> V=1.0, theta=0.0
% INFO    : Bus 73691	: V=1.0009233, theta=-83.886441 -> V=1.0, theta=0.0
% INFO    : Bus 73692	: V=1.0023155, theta=-83.878565 -> V=1.0, theta=0.0
% INFO    : Bus 73693	: V=0.9995647, theta=-84.02708 -> V=1.0, theta=0.0
% INFO    : Bus 73694	: V=0.9964573, theta=-84.054605 -> V=1.0, theta=0.0
% INFO    : Bus 73695	: V=0.9992837, theta=-84.048211 -> V=1.0, theta=0.0
% INFO    : Bus 73696	: V=1.0094977, theta=-83.427264 -> V=1.0, theta=0.0
% INFO    : Bus 73697	: V=1.0100003, theta=-83.393614 -> V=1.0, theta=0.0
% INFO    : Bus 73698	: V=1.0051671, theta=-83.546336 -> V=1.0, theta=0.0
% INFO    : Bus 73699	: V=1.000225, theta=-83.958387 -> V=1.0, theta=0.0
% INFO    : Bus 73700	: V=0.9998171, theta=-83.9817 -> V=1.0, theta=0.0
% INFO    : Bus 73701	: V=0.9988713, theta=-83.987972 -> V=1.0, theta=0.0
% INFO    : Bus 73702	: V=0.9998759, theta=-84.019758 -> V=1.0, theta=0.0
% INFO    : Bus 73703	: V=0.9984976, theta=-83.98781 -> V=1.0, theta=0.0
% INFO    : Bus 73704	: V=1.0051321, theta=-83.438344 -> V=1.0, theta=0.0
% INFO    : Bus 73705	: V=1.005268, theta=-83.359722 -> V=1.0, theta=0.0
% INFO    : Bus 73706	: V=0.9970457, theta=-84.03615 -> V=1.0, theta=0.0
% INFO    : Bus 73707	: V=0.9965462, theta=-84.243158 -> V=1.0, theta=0.0
% INFO    : Bus 73708	: V=0.9936397, theta=-84.336478 -> V=1.0, theta=0.0
% INFO    : Bus 73709	: V=0.9948055, theta=-84.317806 -> V=1.0, theta=0.0
% INFO    : Bus 73710	: V=1.0077253, theta=-83.59274 -> V=1.0, theta=0.0
% INFO    : Bus 73711	: V=0.993221, theta=-84.35431 -> V=1.0, theta=0.0
% INFO    : Bus 73712	: V=1.0100775, theta=-79.210153 -> V=1.0, theta=0.0
% INFO    : Bus 73713	: V=0.9961044, theta=-82.336645 -> V=1.0, theta=0.0
% INFO    : Bus 73714	: V=1.0090882, theta=-82.439 -> V=1.0, theta=0.0
% INFO    : Bus 73715	: V=0.9972473, theta=-82.284728 -> V=1.0, theta=0.0
% INFO    : Bus 73716	: V=1.0100003, theta=-82.633462 -> V=1.0, theta=0.0
% INFO    : Bus 73717	: V=0.9680449, theta=-83.550176 -> V=1.0, theta=0.0
% INFO    : Bus 73718	: V=0.967056, theta=-83.146778 -> V=1.0, theta=0.0
% INFO    : Bus 73719	: V=0.9677217, theta=-83.41742 -> V=1.0, theta=0.0
% INFO    : Bus 73720	: V=0.9671125, theta=-83.487304 -> V=1.0, theta=0.0
% INFO    : Bus 73721	: V=0.9669784, theta=-83.512282 -> V=1.0, theta=0.0
% INFO    : Bus 73722	: V=0.9672265, theta=-83.458607 -> V=1.0, theta=0.0
% INFO    : Bus 73723	: V=0.971634, theta=-83.16866 -> V=1.0, theta=0.0
% INFO    : Bus 73724	: V=0.966437, theta=-83.535712 -> V=1.0, theta=0.0
% INFO    : Bus 73725	: V=0.9704572, theta=-83.169423 -> V=1.0, theta=0.0
% INFO    : Bus 73726	: V=0.9796177, theta=-82.771998 -> V=1.0, theta=0.0
% INFO    : Bus 73727	: V=0.978453, theta=-82.772364 -> V=1.0, theta=0.0
% INFO    : Bus 73728	: V=0.9771393, theta=-82.77479 -> V=1.0, theta=0.0
% INFO    : Bus 73729	: V=0.9803144, theta=-82.742609 -> V=1.0, theta=0.0
% INFO    : Bus 73730	: V=0.9807167, theta=-82.739026 -> V=1.0, theta=0.0
% INFO    : Bus 73731	: V=0.9857849, theta=-82.463268 -> V=1.0, theta=0.0
% INFO    : Bus 73732	: V=0.9775433, theta=-82.760997 -> V=1.0, theta=0.0
% INFO    : Bus 73733	: V=0.9731781, theta=-82.869776 -> V=1.0, theta=0.0
% INFO    : Bus 73734	: V=0.9845903, theta=-82.558906 -> V=1.0, theta=0.0
% INFO    : Bus 73735	: V=0.9947792, theta=-81.825835 -> V=1.0, theta=0.0
% INFO    : Bus 73736	: V=0.9954185, theta=-81.784275 -> V=1.0, theta=0.0
% INFO    : Bus 73737	: V=1.0100003, theta=-80.505495 -> V=1.0, theta=0.0
% INFO    : Bus 73738	: V=0.9958034, theta=-81.763033 -> V=1.0, theta=0.0
% INFO    : Bus 73739	: V=0.9816919, theta=-82.681447 -> V=1.0, theta=0.0
% INFO    : Bus 73740	: V=0.9808843, theta=-82.686511 -> V=1.0, theta=0.0
% INFO    : Bus 73741	: V=0.9827898, theta=-82.212444 -> V=1.0, theta=0.0
% INFO    : Bus 73742	: V=0.9992707, theta=-82.50807 -> V=1.0, theta=0.0
% INFO    : Bus 73743	: V=1.0100003, theta=-81.41509 -> V=1.0, theta=0.0
% INFO    : Bus 73744	: V=0.9920901, theta=-83.176562 -> V=1.0, theta=0.0
% INFO    : Bus 73745	: V=0.9924189, theta=-83.114823 -> V=1.0, theta=0.0
% INFO    : Bus 73746	: V=0.9912525, theta=-83.180521 -> V=1.0, theta=0.0
% INFO    : Bus 73747	: V=0.9929602, theta=-83.109193 -> V=1.0, theta=0.0
% INFO    : Bus 73748	: V=0.9918642, theta=-83.180518 -> V=1.0, theta=0.0
% INFO    : Bus 73749	: V=0.9922968, theta=-83.112541 -> V=1.0, theta=0.0
% INFO    : Bus 73750	: V=1.0083494, theta=-81.8509 -> V=1.0, theta=0.0
% INFO    : Bus 73751	: V=0.9909311, theta=-83.184678 -> V=1.0, theta=0.0
% INFO    : Bus 73752	: V=0.9814663, theta=-83.459215 -> V=1.0, theta=0.0
% INFO    : Bus 73753	: V=1.0100003, theta=-82.053177 -> V=1.0, theta=0.0
% INFO    : Bus 73754	: V=1.0003011, theta=-83.522204 -> V=1.0, theta=0.0
% INFO    : Bus 73755	: V=1.0098781, theta=-83.049498 -> V=1.0, theta=0.0
% INFO    : Bus 73756	: V=1.0020494, theta=-83.228014 -> V=1.0, theta=0.0
% INFO    : Bus 73757	: V=0.9987695, theta=-83.724701 -> V=1.0, theta=0.0
% INFO    : Bus 73758	: V=0.998686, theta=-83.685256 -> V=1.0, theta=0.0
% INFO    : Bus 73759	: V=1.002696, theta=-83.24182 -> V=1.0, theta=0.0
% INFO    : Bus 73760	: V=1.0069939, theta=-82.737821 -> V=1.0, theta=0.0
% INFO    : Bus 73761	: V=1.0023794, theta=-83.284635 -> V=1.0, theta=0.0
% INFO    : Bus 73762	: V=1.0071186, theta=-82.711535 -> V=1.0, theta=0.0
% INFO    : Bus 73763	: V=1.0026512, theta=-83.254395 -> V=1.0, theta=0.0
% INFO    : Bus 73764	: V=1.0078293, theta=-82.613324 -> V=1.0, theta=0.0
% INFO    : Bus 73765	: V=1.0088777, theta=-82.117031 -> V=1.0, theta=0.0
% INFO    : Bus 73766	: V=1.0063329, theta=-82.956862 -> V=1.0, theta=0.0
% INFO    : Bus 73767	: V=1.0060308, theta=-83.080179 -> V=1.0, theta=0.0
% INFO    : Bus 73768	: V=1.0060397, theta=-83.112865 -> V=1.0, theta=0.0
% INFO    : Bus 73769	: V=1.0056126, theta=-83.202783 -> V=1.0, theta=0.0
% INFO    : Bus 73770	: V=0.9982655, theta=-82.769011 -> V=1.0, theta=0.0
% INFO    : Bus 73771	: V=1.000644, theta=-83.355881 -> V=1.0, theta=0.0
% INFO    : Bus 73772	: V=1.0003379, theta=-82.947364 -> V=1.0, theta=0.0
% INFO    : Bus 73773	: V=0.9945019, theta=-111.610341 -> V=1.0, theta=0.0
% INFO    : Bus 73774	: V=0.9938701, theta=-111.665059 -> V=1.0, theta=0.0
% INFO    : Bus 73775	: V=1.0009816, theta=-110.457919 -> V=1.0, theta=0.0
% INFO    : Bus 73776	: V=0.9982767, theta=-111.501122 -> V=1.0, theta=0.0
% INFO    : Bus 73777	: V=0.9964479, theta=-111.737521 -> V=1.0, theta=0.0
% INFO    : Bus 73778	: V=0.9963173, theta=-111.896869 -> V=1.0, theta=0.0
% INFO    : Bus 73779	: V=0.9952754, theta=-112.022507 -> V=1.0, theta=0.0
% INFO    : Bus 73780	: V=0.9945983, theta=-111.996126 -> V=1.0, theta=0.0
% INFO    : Bus 73781	: V=0.9945458, theta=-112.0163 -> V=1.0, theta=0.0
% INFO    : Bus 73782	: V=0.994394, theta=-111.895788 -> V=1.0, theta=0.0
% INFO    : Bus 73783	: V=0.994472, theta=-111.799023 -> V=1.0, theta=0.0
% INFO    : Bus 73784	: V=0.9939731, theta=-111.632049 -> V=1.0, theta=0.0
% INFO    : Bus 73785	: V=0.9968368, theta=-111.898425 -> V=1.0, theta=0.0
% INFO    : Bus 73786	: V=0.9941036, theta=-112.014662 -> V=1.0, theta=0.0
% INFO    : Bus 73787	: V=0.9974133, theta=-111.874874 -> V=1.0, theta=0.0
% INFO    : Bus 73788	: V=0.9972365, theta=-111.881508 -> V=1.0, theta=0.0
% INFO    : Bus 73789	: V=0.9959615, theta=-111.939791 -> V=1.0, theta=0.0
% INFO    : Bus 73790	: V=0.9956818, theta=-111.951246 -> V=1.0, theta=0.0
% INFO    : Bus 73791	: V=0.9946207, theta=-112.030568 -> V=1.0, theta=0.0
% INFO    : Bus 73792	: V=0.9946378, theta=-112.072865 -> V=1.0, theta=0.0
% INFO    : Bus 73793	: V=0.9946198, theta=-112.036524 -> V=1.0, theta=0.0
% INFO    : Bus 73794	: V=0.9952142, theta=-112.014245 -> V=1.0, theta=0.0
% INFO    : Bus 73795	: V=0.9957159, theta=-111.842292 -> V=1.0, theta=0.0
% INFO    : Bus 73796	: V=0.9952623, theta=-111.932256 -> V=1.0, theta=0.0
% INFO    : Bus 73797	: V=0.9946551, theta=-112.007759 -> V=1.0, theta=0.0
% INFO    : Bus 73798	: V=0.9949355, theta=-112.000219 -> V=1.0, theta=0.0
% INFO    : Bus 73799	: V=0.9947269, theta=-112.013125 -> V=1.0, theta=0.0
% INFO    : Bus 73800	: V=0.9947782, theta=-112.004258 -> V=1.0, theta=0.0
% INFO    : Bus 73801	: V=0.9949048, theta=-112.014949 -> V=1.0, theta=0.0
% INFO    : Bus 73802	: V=0.9948637, theta=-112.02186 -> V=1.0, theta=0.0
% INFO    : Bus 73803	: V=0.9953782, theta=-111.989321 -> V=1.0, theta=0.0
% INFO    : Bus 73804	: V=0.995477, theta=-111.982462 -> V=1.0, theta=0.0
% INFO    : Bus 73805	: V=0.9949616, theta=-111.982377 -> V=1.0, theta=0.0
% INFO    : Bus 73806	: V=0.9946723, theta=-111.992751 -> V=1.0, theta=0.0
% INFO    : Bus 73807	: V=0.9947297, theta=-111.989815 -> V=1.0, theta=0.0
% INFO    : Bus 73808	: V=0.9946863, theta=-111.932577 -> V=1.0, theta=0.0
% INFO    : Bus 73809	: V=0.9956819, theta=-111.863525 -> V=1.0, theta=0.0
% INFO    : Bus 73810	: V=0.9968157, theta=-111.80796 -> V=1.0, theta=0.0
% INFO    : Bus 73811	: V=0.9949753, theta=-111.903303 -> V=1.0, theta=0.0
% INFO    : Bus 73812	: V=0.9944154, theta=-112.030094 -> V=1.0, theta=0.0
% INFO    : Bus 73813	: V=0.9950767, theta=-111.998397 -> V=1.0, theta=0.0
% INFO    : Bus 73814	: V=0.9985066, theta=-111.56046 -> V=1.0, theta=0.0
% INFO    : Bus 73815	: V=0.9984182, theta=-111.624892 -> V=1.0, theta=0.0
% INFO    : Bus 73816	: V=0.9975935, theta=-111.72883 -> V=1.0, theta=0.0
% INFO    : Bus 73817	: V=0.9987872, theta=-111.60801 -> V=1.0, theta=0.0
% INFO    : Bus 73818	: V=1.0011465, theta=-110.602544 -> V=1.0, theta=0.0
% INFO    : Bus 73819	: V=0.9958939, theta=-111.938829 -> V=1.0, theta=0.0
% INFO    : Bus 73820	: V=0.9971115, theta=-111.838435 -> V=1.0, theta=0.0
% INFO    : Bus 73821	: V=0.997952, theta=-111.723422 -> V=1.0, theta=0.0
% INFO    : Bus 73822	: V=0.9946686, theta=-112.046769 -> V=1.0, theta=0.0
% INFO    : Bus 73823	: V=0.9972967, theta=-111.78374 -> V=1.0, theta=0.0
% INFO    : Bus 73824	: V=0.9950387, theta=-112.035456 -> V=1.0, theta=0.0
% INFO    : Bus 73825	: V=0.9957468, theta=-112.009414 -> V=1.0, theta=0.0
% INFO    : Bus 73826	: V=0.9950253, theta=-112.025251 -> V=1.0, theta=0.0
% INFO    : Bus 73827	: V=0.9941992, theta=-112.090858 -> V=1.0, theta=0.0
% INFO    : Bus 73828	: V=0.9977215, theta=-111.744219 -> V=1.0, theta=0.0
% INFO    : Bus 73829	: V=0.9994259, theta=-111.653064 -> V=1.0, theta=0.0
% INFO    : Bus 73830	: V=0.9946624, theta=-112.048943 -> V=1.0, theta=0.0
% INFO    : Bus 73831	: V=0.9959648, theta=-112.00127 -> V=1.0, theta=0.0
% INFO    : Bus 73832	: V=1.0013697, theta=-110.432102 -> V=1.0, theta=0.0
% INFO    : Bus 73833	: V=0.9951598, theta=-112.055581 -> V=1.0, theta=0.0
% INFO    : Bus 73834	: V=0.9965913, theta=-111.897471 -> V=1.0, theta=0.0
% INFO    : Bus 73835	: V=0.9999664, theta=-111.607293 -> V=1.0, theta=0.0
% INFO    : Bus 73836	: V=1.0005895, theta=-111.430843 -> V=1.0, theta=0.0
% INFO    : Bus 73837	: V=1.0006485, theta=-111.168447 -> V=1.0, theta=0.0
% INFO    : Bus 73838	: V=1.0008112, theta=-111.421785 -> V=1.0, theta=0.0
% INFO    : Bus 73839	: V=0.9968319, theta=-111.901597 -> V=1.0, theta=0.0
% INFO    : Bus 73840	: V=0.9966382, theta=-111.896317 -> V=1.0, theta=0.0
% INFO    : Bus 73841	: V=0.9986472, theta=-111.721348 -> V=1.0, theta=0.0
% INFO    : Bus 73842	: V=0.997462, theta=-111.806764 -> V=1.0, theta=0.0
% INFO    : Bus 73843	: V=1.0004995, theta=-111.453454 -> V=1.0, theta=0.0
% INFO    : Bus 73844	: V=1.000535, theta=-111.456596 -> V=1.0, theta=0.0
% INFO    : Bus 73845	: V=0.997729, theta=-111.792313 -> V=1.0, theta=0.0
% INFO    : Bus 73846	: V=1.0011665, theta=-110.20565 -> V=1.0, theta=0.0
% INFO    : Bus 73847	: V=0.9972032, theta=-111.831431 -> V=1.0, theta=0.0
% INFO    : Bus 73848	: V=0.9979417, theta=-111.519508 -> V=1.0, theta=0.0
% INFO    : Bus 73849	: V=0.9985123, theta=-111.497763 -> V=1.0, theta=0.0
% INFO    : Bus 73850	: V=1.0014341, theta=-110.186971 -> V=1.0, theta=0.0
% INFO    : Bus 73851	: V=0.9981703, theta=-111.791881 -> V=1.0, theta=0.0
% INFO    : Bus 73852	: V=0.9967431, theta=-111.844225 -> V=1.0, theta=0.0
% INFO    : Bus 73853	: V=0.9984903, theta=-111.669597 -> V=1.0, theta=0.0
% INFO    : Bus 73854	: V=0.9988145, theta=-111.595376 -> V=1.0, theta=0.0
% INFO    : Bus 73855	: V=0.9995981, theta=-111.551544 -> V=1.0, theta=0.0
% INFO    : Bus 73856	: V=0.9988378, theta=-111.378322 -> V=1.0, theta=0.0
% INFO    : Bus 73857	: V=1.0020989, theta=-110.11729 -> V=1.0, theta=0.0
% INFO    : Bus 73858	: V=0.9980511, theta=-110.492522 -> V=1.0, theta=0.0
% INFO    : Bus 73859	: V=0.9992932, theta=-111.120177 -> V=1.0, theta=0.0
% INFO    : Bus 73860	: V=0.9970707, theta=-110.358049 -> V=1.0, theta=0.0
% INFO    : Bus 73861	: V=0.9961885, theta=-110.350933 -> V=1.0, theta=0.0
% INFO    : Bus 73862	: V=1.0024768, theta=-110.081584 -> V=1.0, theta=0.0
% INFO    : Bus 73863	: V=1.0047367, theta=-109.75814 -> V=1.0, theta=0.0
% INFO    : Bus 73864	: V=1.0027635, theta=-111.250649 -> V=1.0, theta=0.0
% INFO    : Bus 73865	: V=1.0020164, theta=-111.316915 -> V=1.0, theta=0.0
% INFO    : Bus 73866	: V=0.994725, theta=-112.047234 -> V=1.0, theta=0.0
% INFO    : Bus 73867	: V=0.9954598, theta=-112.02436 -> V=1.0, theta=0.0
% INFO    : Bus 73868	: V=0.9959091, theta=-111.936351 -> V=1.0, theta=0.0
% INFO    : Bus 73869	: V=0.9953462, theta=-111.931757 -> V=1.0, theta=0.0
% INFO    : Bus 73870	: V=0.9956656, theta=-111.939403 -> V=1.0, theta=0.0
% INFO    : Bus 73871	: V=0.9953664, theta=-111.899096 -> V=1.0, theta=0.0
% INFO    : Bus 73872	: V=0.9959881, theta=-111.874292 -> V=1.0, theta=0.0
% INFO    : Bus 73873	: V=0.9952701, theta=-111.902343 -> V=1.0, theta=0.0
% INFO    : Bus 73874	: V=0.9964272, theta=-111.854688 -> V=1.0, theta=0.0
% INFO    : Bus 73875	: V=1.0011939, theta=-109.932215 -> V=1.0, theta=0.0
% INFO    : Bus 73876	: V=0.9957186, theta=-111.945597 -> V=1.0, theta=0.0
% INFO    : Bus 73877	: V=0.9956875, theta=-111.934597 -> V=1.0, theta=0.0
% INFO    : Bus 73878	: V=0.9964446, theta=-111.856993 -> V=1.0, theta=0.0
% INFO    : Bus 73879	: V=0.991917, theta=-111.495856 -> V=1.0, theta=0.0
% INFO    : Bus 73880	: V=0.9922135, theta=-111.493764 -> V=1.0, theta=0.0
% INFO    : Bus 73881	: V=0.9960377, theta=-111.899008 -> V=1.0, theta=0.0
% INFO    : Bus 73882	: V=0.9958435, theta=-111.906284 -> V=1.0, theta=0.0
% INFO    : Bus 73883	: V=0.9917303, theta=-111.597606 -> V=1.0, theta=0.0
% INFO    : Bus 73884	: V=0.9915796, theta=-111.599249 -> V=1.0, theta=0.0
% INFO    : Bus 73885	: V=0.9916242, theta=-111.79514 -> V=1.0, theta=0.0
% INFO    : Bus 73886	: V=0.9919224, theta=-111.745513 -> V=1.0, theta=0.0
% INFO    : Bus 73887	: V=0.9923703, theta=-111.728667 -> V=1.0, theta=0.0
% INFO    : Bus 73888	: V=0.9920358, theta=-111.756738 -> V=1.0, theta=0.0
% INFO    : Bus 73889	: V=0.9917735, theta=-111.697925 -> V=1.0, theta=0.0
% INFO    : Bus 73890	: V=0.9939935, theta=-111.918086 -> V=1.0, theta=0.0
% INFO    : Bus 73891	: V=0.994462, theta=-111.903181 -> V=1.0, theta=0.0
% INFO    : Bus 73892	: V=0.9921463, theta=-111.829937 -> V=1.0, theta=0.0
% INFO    : Bus 73893	: V=0.9925196, theta=-111.885347 -> V=1.0, theta=0.0
% INFO    : Bus 73894	: V=0.9911581, theta=-111.812746 -> V=1.0, theta=0.0
% INFO    : Bus 73895	: V=0.9916361, theta=-111.922066 -> V=1.0, theta=0.0
% INFO    : Bus 73896	: V=0.9912782, theta=-111.458274 -> V=1.0, theta=0.0
% INFO    : Bus 73897	: V=0.988884, theta=-111.156712 -> V=1.0, theta=0.0
% INFO    : Bus 73898	: V=0.9935518, theta=-111.184526 -> V=1.0, theta=0.0
% INFO    : Bus 73899	: V=0.9909003, theta=-111.153973 -> V=1.0, theta=0.0
% INFO    : Bus 73900	: V=0.9913185, theta=-111.052845 -> V=1.0, theta=0.0
% INFO    : Bus 73901	: V=0.9919143, theta=-111.254568 -> V=1.0, theta=0.0
% INFO    : Bus 73902	: V=0.9925081, theta=-111.236006 -> V=1.0, theta=0.0
% INFO    : Bus 73903	: V=1.0100004, theta=-109.057578 -> V=1.0, theta=0.0
% INFO    : Bus 73904	: V=0.9927473, theta=-111.378755 -> V=1.0, theta=0.0
% INFO    : Bus 73905	: V=0.9908654, theta=-111.2698 -> V=1.0, theta=0.0
% INFO    : Bus 73906	: V=0.9912183, theta=-111.269762 -> V=1.0, theta=0.0
% INFO    : Bus 73907	: V=0.9907969, theta=-111.171948 -> V=1.0, theta=0.0
% INFO    : Bus 73908	: V=0.9915305, theta=-111.10888 -> V=1.0, theta=0.0
% INFO    : Bus 73909	: V=0.9918956, theta=-110.928175 -> V=1.0, theta=0.0
% INFO    : Bus 73910	: V=0.9918219, theta=-110.946919 -> V=1.0, theta=0.0
% INFO    : Bus 73911	: V=0.9952213, theta=-110.321218 -> V=1.0, theta=0.0
% INFO    : Bus 73912	: V=1.0001296, theta=-109.996647 -> V=1.0, theta=0.0
% INFO    : Bus 73913	: V=1.0027948, theta=-109.655379 -> V=1.0, theta=0.0
% INFO    : Bus 73914	: V=0.9932448, theta=-110.705381 -> V=1.0, theta=0.0
% INFO    : Bus 73915	: V=0.9927213, theta=-110.812639 -> V=1.0, theta=0.0
% INFO    : Bus 73916	: V=0.9917684, theta=-110.949746 -> V=1.0, theta=0.0
% INFO    : Bus 73917	: V=0.9944638, theta=-110.463703 -> V=1.0, theta=0.0
% INFO    : Bus 73918	: V=0.9945964, theta=-110.281399 -> V=1.0, theta=0.0
% INFO    : Bus 73919	: V=1.0031519, theta=-109.649221 -> V=1.0, theta=0.0
% INFO    : Bus 73920	: V=1.0034331, theta=-109.641689 -> V=1.0, theta=0.0
% INFO    : Bus 73921	: V=0.9938584, theta=-110.601689 -> V=1.0, theta=0.0
% INFO    : Bus 73922	: V=1.0010618, theta=-109.769387 -> V=1.0, theta=0.0
% INFO    : Bus 73923	: V=0.9938898, theta=-110.718517 -> V=1.0, theta=0.0
% INFO    : Bus 73924	: V=1.0100004, theta=-109.142296 -> V=1.0, theta=0.0
% INFO    : Bus 73925	: V=1.001853, theta=-109.89329 -> V=1.0, theta=0.0
% INFO    : Bus 73926	: V=1.0100004, theta=-109.537188 -> V=1.0, theta=0.0
% INFO    : Bus 73927	: V=0.9981201, theta=-109.779995 -> V=1.0, theta=0.0
% INFO    : Bus 73928	: V=1.0097126, theta=-109.365899 -> V=1.0, theta=0.0
% INFO    : Bus 73929	: V=1.0004027, theta=-110.12141 -> V=1.0, theta=0.0
% INFO    : Bus 73930	: V=0.9905844, theta=-110.829364 -> V=1.0, theta=0.0
% INFO    : Bus 73931	: V=0.9841658, theta=-111.199052 -> V=1.0, theta=0.0
% INFO    : Bus 73932	: V=0.9926823, theta=-110.57802 -> V=1.0, theta=0.0
% INFO    : Bus 73933	: V=1.0021571, theta=-109.886211 -> V=1.0, theta=0.0
% INFO    : Bus 73934	: V=1.0013588, theta=-109.99083 -> V=1.0, theta=0.0
% INFO    : Bus 73935	: V=1.0004927, theta=-109.731135 -> V=1.0, theta=0.0
% INFO    : Bus 73936	: V=1.0100004, theta=-108.81249 -> V=1.0, theta=0.0
% INFO    : Bus 73937	: V=1.0100004, theta=-108.975989 -> V=1.0, theta=0.0
% INFO    : Bus 73938	: V=1.009689, theta=-109.048539 -> V=1.0, theta=0.0
% INFO    : Bus 73939	: V=1.0013162, theta=-111.033618 -> V=1.0, theta=0.0
% INFO    : Bus 73940	: V=1.0300004, theta=-104.835018 -> V=1.0, theta=0.0
% INFO    : Bus 73941	: V=0.9986816, theta=-111.484514 -> V=1.0, theta=0.0
% INFO    : Bus 73942	: V=1.0021296, theta=-110.532915 -> V=1.0, theta=0.0
% INFO    : Bus 73943	: V=1.0100086, theta=-108.851842 -> V=1.0, theta=0.0
% INFO    : Bus 73944	: V=1.0032964, theta=-110.036448 -> V=1.0, theta=0.0
% INFO    : Bus 73945	: V=1.0095814, theta=-108.954705 -> V=1.0, theta=0.0
% INFO    : Bus 73946	: V=1.0092196, theta=-109.039813 -> V=1.0, theta=0.0
% INFO    : Bus 73947	: V=1.0002781, theta=-110.837757 -> V=1.0, theta=0.0
% INFO    : Bus 73948	: V=1.0003309, theta=-109.680837 -> V=1.0, theta=0.0
% INFO    : Bus 73949	: V=0.9992879, theta=-111.008193 -> V=1.0, theta=0.0
% INFO    : Bus 73950	: V=0.9975728, theta=-111.868094 -> V=1.0, theta=0.0
% INFO    : Bus 73951	: V=0.9966507, theta=-111.933333 -> V=1.0, theta=0.0
% INFO    : Bus 73952	: V=0.9971882, theta=-111.899297 -> V=1.0, theta=0.0
% INFO    : Bus 73953	: V=0.9962802, theta=-111.933228 -> V=1.0, theta=0.0
% INFO    : Bus 73954	: V=0.996662, theta=-111.919876 -> V=1.0, theta=0.0
% INFO    : Bus 73955	: V=0.997041, theta=-111.910345 -> V=1.0, theta=0.0
% INFO    : Bus 73956	: V=0.9987121, theta=-111.160862 -> V=1.0, theta=0.0
% INFO    : Bus 73957	: V=0.99631, theta=-111.915435 -> V=1.0, theta=0.0
% INFO    : Bus 73958	: V=0.9981693, theta=-111.276252 -> V=1.0, theta=0.0
% INFO    : Bus 73959	: V=0.9948832, theta=-111.888373 -> V=1.0, theta=0.0
% INFO    : Bus 73960	: V=0.997564, theta=-111.48985 -> V=1.0, theta=0.0
% INFO    : Bus 73961	: V=0.9971215, theta=-110.616364 -> V=1.0, theta=0.0
% INFO    : Bus 73962	: V=0.996211, theta=-111.900949 -> V=1.0, theta=0.0
% INFO    : Bus 73963	: V=0.9954751, theta=-111.958044 -> V=1.0, theta=0.0
% INFO    : Bus 73964	: V=0.9964902, theta=-111.804792 -> V=1.0, theta=0.0
% INFO    : Bus 73965	: V=0.9958185, theta=-111.888971 -> V=1.0, theta=0.0
% INFO    : Bus 73966	: V=0.9953007, theta=-111.857935 -> V=1.0, theta=0.0
% INFO    : Bus 73967	: V=0.9948089, theta=-111.988699 -> V=1.0, theta=0.0
% INFO    : Bus 73968	: V=0.9950087, theta=-111.970232 -> V=1.0, theta=0.0
% INFO    : Bus 73969	: V=0.9979777, theta=-110.525501 -> V=1.0, theta=0.0
% INFO    : Bus 73970	: V=0.9948521, theta=-111.980163 -> V=1.0, theta=0.0
% INFO    : Bus 73971	: V=0.9943817, theta=-111.973349 -> V=1.0, theta=0.0
% INFO    : Bus 73972	: V=0.9941639, theta=-111.99529 -> V=1.0, theta=0.0
% INFO    : Bus 73973	: V=0.993659, theta=-112.042676 -> V=1.0, theta=0.0
% INFO    : Bus 73974	: V=0.9954195, theta=-111.903898 -> V=1.0, theta=0.0
% INFO    : Bus 73975	: V=0.9940516, theta=-112.016458 -> V=1.0, theta=0.0
% INFO    : Bus 73976	: V=0.9934164, theta=-112.043707 -> V=1.0, theta=0.0
% INFO    : Bus 73977	: V=0.9943277, theta=-111.997761 -> V=1.0, theta=0.0
% INFO    : Bus 73978	: V=0.9937044, theta=-112.027592 -> V=1.0, theta=0.0
% INFO    : Bus 73979	: V=0.9925629, theta=-112.05833 -> V=1.0, theta=0.0
% INFO    : Bus 73980	: V=0.9969271, theta=-111.754298 -> V=1.0, theta=0.0
% INFO    : Bus 73981	: V=0.9973929, theta=-111.66908 -> V=1.0, theta=0.0
% INFO    : Bus 73982	: V=0.9976946, theta=-110.420174 -> V=1.0, theta=0.0
% INFO    : Bus 73983	: V=0.9965433, theta=-111.515617 -> V=1.0, theta=0.0
% INFO    : Bus 73984	: V=0.9936536, theta=-111.887473 -> V=1.0, theta=0.0
% INFO    : Bus 73985	: V=0.9976273, theta=-110.236189 -> V=1.0, theta=0.0
% INFO    : Bus 73986	: V=0.993701, theta=-111.935235 -> V=1.0, theta=0.0
% INFO    : Bus 73987	: V=0.9934604, theta=-112.019361 -> V=1.0, theta=0.0
% INFO    : Bus 73988	: V=0.9931974, theta=-112.040922 -> V=1.0, theta=0.0
% INFO    : Bus 73989	: V=0.9934247, theta=-111.946675 -> V=1.0, theta=0.0
% INFO    : Bus 73990	: V=0.9918543, theta=-112.091661 -> V=1.0, theta=0.0
% INFO    : Bus 73991	: V=0.9922583, theta=-111.94583 -> V=1.0, theta=0.0
% INFO    : Bus 73992	: V=0.9924316, theta=-112.115498 -> V=1.0, theta=0.0
% INFO    : Bus 73993	: V=0.9931612, theta=-112.061382 -> V=1.0, theta=0.0
% INFO    : Bus 73994	: V=0.9914878, theta=-112.149067 -> V=1.0, theta=0.0
% INFO    : Bus 73995	: V=0.9904445, theta=-112.197406 -> V=1.0, theta=0.0
% INFO    : Bus 73996	: V=0.9925555, theta=-111.943659 -> V=1.0, theta=0.0
% INFO    : Bus 73997	: V=0.9910039, theta=-112.091649 -> V=1.0, theta=0.0
% INFO    : Bus 73998	: V=0.990883, theta=-112.012625 -> V=1.0, theta=0.0
% INFO    : Bus 73999	: V=0.9934835, theta=-111.662494 -> V=1.0, theta=0.0
% INFO    : Bus 74000	: V=0.9932415, theta=-111.829754 -> V=1.0, theta=0.0
% INFO    : Bus 74001	: V=0.9922089, theta=-112.007946 -> V=1.0, theta=0.0
% INFO    : Bus 74002	: V=0.9918858, theta=-112.055177 -> V=1.0, theta=0.0
% INFO    : Bus 74003	: V=0.9931605, theta=-112.042995 -> V=1.0, theta=0.0
% INFO    : Bus 74004	: V=0.9938883, theta=-111.982073 -> V=1.0, theta=0.0
% INFO    : Bus 74005	: V=0.9921626, theta=-112.058294 -> V=1.0, theta=0.0
% INFO    : Bus 74006	: V=0.9926052, theta=-112.055838 -> V=1.0, theta=0.0
% INFO    : Bus 74007	: V=0.9928445, theta=-112.033727 -> V=1.0, theta=0.0
% INFO    : Bus 74008	: V=0.9920594, theta=-110.991985 -> V=1.0, theta=0.0
% INFO    : Bus 74009	: V=0.9971339, theta=-110.61526 -> V=1.0, theta=0.0
% INFO    : Bus 74010	: V=0.993522, theta=-111.934323 -> V=1.0, theta=0.0
% INFO    : Bus 74011	: V=0.9973841, theta=-110.60396 -> V=1.0, theta=0.0
% INFO    : Bus 74012	: V=0.9975792, theta=-110.810766 -> V=1.0, theta=0.0
% INFO    : Bus 74013	: V=0.9952268, theta=-111.168532 -> V=1.0, theta=0.0
% INFO    : Bus 74014	: V=0.9961545, theta=-111.025149 -> V=1.0, theta=0.0
% INFO    : Bus 74015	: V=0.9939178, theta=-111.436588 -> V=1.0, theta=0.0
% INFO    : Bus 74016	: V=0.9938486, theta=-111.442249 -> V=1.0, theta=0.0
% INFO    : Bus 74017	: V=0.9942501, theta=-111.305535 -> V=1.0, theta=0.0
% INFO    : Bus 74018	: V=0.995252, theta=-110.794256 -> V=1.0, theta=0.0
% INFO    : Bus 74019	: V=0.9968481, theta=-110.643066 -> V=1.0, theta=0.0
% INFO    : Bus 74020	: V=0.9961186, theta=-110.70406 -> V=1.0, theta=0.0
% INFO    : Bus 74021	: V=0.9979804, theta=-110.54534 -> V=1.0, theta=0.0
% INFO    : Bus 74022	: V=0.998634, theta=-110.478944 -> V=1.0, theta=0.0
% INFO    : Bus 74023	: V=0.9996047, theta=-110.38572 -> V=1.0, theta=0.0
% INFO    : Bus 74024	: V=1.0011564, theta=-110.244818 -> V=1.0, theta=0.0
% INFO    : Bus 74025	: V=1.0004118, theta=-110.312051 -> V=1.0, theta=0.0
% INFO    : Bus 74026	: V=0.9979456, theta=-110.588684 -> V=1.0, theta=0.0
% INFO    : Bus 74027	: V=0.9988189, theta=-110.459445 -> V=1.0, theta=0.0
% INFO    : Bus 74028	: V=1.000105, theta=-110.319781 -> V=1.0, theta=0.0
% INFO    : Bus 74029	: V=1.0100004, theta=-109.079639 -> V=1.0, theta=0.0
% INFO    : Bus 74030	: V=0.9908667, theta=-110.823857 -> V=1.0, theta=0.0
% INFO    : Bus 74031	: V=0.9929784, theta=-110.578589 -> V=1.0, theta=0.0
% INFO    : Bus 74032	: V=0.9914375, theta=-110.81845 -> V=1.0, theta=0.0
% INFO    : Bus 74033	: V=0.9981855, theta=-110.519875 -> V=1.0, theta=0.0
% INFO    : Bus 74034	: V=0.996485, theta=-110.786451 -> V=1.0, theta=0.0
% INFO    : Bus 74035	: V=0.9972743, theta=-110.687724 -> V=1.0, theta=0.0
% INFO    : Bus 74036	: V=0.9896714, theta=-111.063818 -> V=1.0, theta=0.0
% INFO    : Bus 74037	: V=0.9975669, theta=-110.683107 -> V=1.0, theta=0.0
% INFO    : Bus 74038	: V=0.9932829, theta=-111.786845 -> V=1.0, theta=0.0
% INFO    : Bus 74039	: V=0.9973357, theta=-110.731629 -> V=1.0, theta=0.0
% INFO    : Bus 74040	: V=0.9974212, theta=-110.772771 -> V=1.0, theta=0.0
% INFO    : Bus 74041	: V=0.9946764, theta=-111.034759 -> V=1.0, theta=0.0
% INFO    : Bus 74042	: V=0.9947156, theta=-111.02729 -> V=1.0, theta=0.0
% INFO    : Bus 74043	: V=0.9973959, theta=-110.799947 -> V=1.0, theta=0.0
% INFO    : Bus 74044	: V=0.9941237, theta=-111.089013 -> V=1.0, theta=0.0
% INFO    : Bus 74045	: V=0.9945717, theta=-111.037389 -> V=1.0, theta=0.0
% INFO    : Bus 74046	: V=0.9943246, theta=-111.0666 -> V=1.0, theta=0.0
% INFO    : Bus 74047	: V=0.9947838, theta=-111.010942 -> V=1.0, theta=0.0
% INFO    : Bus 74048	: V=0.9951641, theta=-110.954332 -> V=1.0, theta=0.0
% INFO    : Bus 74049	: V=0.9956516, theta=-110.888617 -> V=1.0, theta=0.0
% INFO    : Bus 74050	: V=0.9932041, theta=-111.722026 -> V=1.0, theta=0.0
% INFO    : Bus 74051	: V=0.993219, theta=-111.693513 -> V=1.0, theta=0.0
% INFO    : Bus 74052	: V=0.9939514, theta=-110.933592 -> V=1.0, theta=0.0
% INFO    : Bus 74053	: V=0.9944589, theta=-110.877198 -> V=1.0, theta=0.0
% INFO    : Bus 74054	: V=0.9932816, theta=-111.613217 -> V=1.0, theta=0.0
% INFO    : Bus 74055	: V=0.9933326, theta=-111.543255 -> V=1.0, theta=0.0
% INFO    : Bus 74056	: V=0.9931183, theta=-111.552102 -> V=1.0, theta=0.0
% INFO    : Bus 74057	: V=0.9936651, theta=-110.978932 -> V=1.0, theta=0.0
% INFO    : Bus 74058	: V=0.9934984, theta=-111.008121 -> V=1.0, theta=0.0
% INFO    : Bus 74059	: V=0.9937026, theta=-111.639781 -> V=1.0, theta=0.0
% INFO    : Bus 74060	: V=0.9926382, theta=-111.562272 -> V=1.0, theta=0.0
% INFO    : Bus 74061	: V=0.9939528, theta=-111.104022 -> V=1.0, theta=0.0
% INFO    : Bus 74062	: V=0.9941436, theta=-111.102146 -> V=1.0, theta=0.0
% INFO    : Bus 74063	: V=0.9978023, theta=-110.827888 -> V=1.0, theta=0.0
% INFO    : Bus 74064	: V=0.994826, theta=-111.443501 -> V=1.0, theta=0.0
% INFO    : Bus 74065	: V=0.9948314, theta=-111.427332 -> V=1.0, theta=0.0
% INFO    : Bus 74066	: V=0.9947762, theta=-111.501124 -> V=1.0, theta=0.0
% INFO    : Bus 74067	: V=0.9976417, theta=-110.863588 -> V=1.0, theta=0.0
% INFO    : Bus 74068	: V=0.9970394, theta=-110.946763 -> V=1.0, theta=0.0
% INFO    : Bus 74069	: V=0.995944, theta=-111.568678 -> V=1.0, theta=0.0
% INFO    : Bus 74070	: V=0.9955627, theta=-111.556533 -> V=1.0, theta=0.0
% INFO    : Bus 74071	: V=0.9957686, theta=-111.542712 -> V=1.0, theta=0.0
% INFO    : Bus 74072	: V=0.9951405, theta=-111.539553 -> V=1.0, theta=0.0
% INFO    : Bus 74073	: V=0.9946742, theta=-111.080079 -> V=1.0, theta=0.0
% INFO    : Bus 74074	: V=0.9951093, theta=-111.06148 -> V=1.0, theta=0.0
% INFO    : Bus 74075	: V=0.9954568, theta=-111.0849 -> V=1.0, theta=0.0
% INFO    : Bus 74076	: V=0.9934312, theta=-111.050134 -> V=1.0, theta=0.0
% INFO    : Bus 74077	: V=0.9929178, theta=-111.628369 -> V=1.0, theta=0.0
% INFO    : Bus 74078	: V=0.9882616, theta=-111.431304 -> V=1.0, theta=0.0
% INFO    : Bus 74079	: V=0.9934872, theta=-111.12155 -> V=1.0, theta=0.0
% INFO    : Bus 74080	: V=0.9906049, theta=-112.059199 -> V=1.0, theta=0.0
% INFO    : Bus 74081	: V=0.9973192, theta=-109.877831 -> V=1.0, theta=0.0
% INFO    : Bus 74082	: V=0.9987144, theta=-111.202829 -> V=1.0, theta=0.0
% INFO    : Bus 74083	: V=0.9983988, theta=-111.214597 -> V=1.0, theta=0.0
% INFO    : Bus 74084	: V=0.999855, theta=-110.800518 -> V=1.0, theta=0.0
% INFO    : Bus 74085	: V=0.9985018, theta=-111.21083 -> V=1.0, theta=0.0
% INFO    : Bus 74086	: V=1.0025338, theta=-110.589722 -> V=1.0, theta=0.0
% INFO    : Bus 74087	: V=1.0011081, theta=-110.717251 -> V=1.0, theta=0.0
% INFO    : Bus 74088	: V=0.9978997, theta=-111.495823 -> V=1.0, theta=0.0
% INFO    : Bus 74089	: V=0.9971698, theta=-111.523135 -> V=1.0, theta=0.0
% INFO    : Bus 74090	: V=0.9988717, theta=-111.541413 -> V=1.0, theta=0.0
% INFO    : Bus 74091	: V=0.9981438, theta=-111.566159 -> V=1.0, theta=0.0
% INFO    : Bus 74092	: V=1.0061538, theta=-109.57931 -> V=1.0, theta=0.0
% INFO    : Bus 74093	: V=0.9990323, theta=-111.685102 -> V=1.0, theta=0.0
% INFO    : Bus 74094	: V=1.0008831, theta=-111.15775 -> V=1.0, theta=0.0
% INFO    : Bus 74095	: V=1.0000548, theta=-111.574877 -> V=1.0, theta=0.0
% INFO    : Bus 74096	: V=1.0004537, theta=-111.493987 -> V=1.0, theta=0.0
% INFO    : Bus 74097	: V=1.0014135, theta=-111.21408 -> V=1.0, theta=0.0
% INFO    : Bus 74098	: V=1.0019882, theta=-111.010558 -> V=1.0, theta=0.0
% INFO    : Bus 74099	: V=1.004008, theta=-110.300441 -> V=1.0, theta=0.0
% INFO    : Bus 74100	: V=1.0002606, theta=-111.335262 -> V=1.0, theta=0.0
% INFO    : Bus 74101	: V=1.0008583, theta=-111.324752 -> V=1.0, theta=0.0
% INFO    : Bus 74102	: V=1.0036422, theta=-110.348922 -> V=1.0, theta=0.0
% INFO    : Bus 74103	: V=1.0007871, theta=-111.315618 -> V=1.0, theta=0.0
% INFO    : Bus 74104	: V=1.002399, theta=-110.991757 -> V=1.0, theta=0.0
% INFO    : Bus 74105	: V=1.0020965, theta=-110.902146 -> V=1.0, theta=0.0
% INFO    : Bus 74106	: V=1.0024651, theta=-110.780293 -> V=1.0, theta=0.0
% INFO    : Bus 74107	: V=1.0036731, theta=-110.398098 -> V=1.0, theta=0.0
% INFO    : Bus 74108	: V=1.0164848, theta=-108.595604 -> V=1.0, theta=0.0
% INFO    : Bus 74109	: V=1.004613, theta=-110.291446 -> V=1.0, theta=0.0
% INFO    : Bus 74110	: V=1.0079845, theta=-109.288721 -> V=1.0, theta=0.0
% INFO    : Bus 74111	: V=1.0020144, theta=-110.780821 -> V=1.0, theta=0.0
% INFO    : Bus 74112	: V=1.0021647, theta=-111.002462 -> V=1.0, theta=0.0
% INFO    : Bus 74113	: V=1.0071796, theta=-109.51381 -> V=1.0, theta=0.0
% INFO    : Bus 74114	: V=1.0021391, theta=-110.614855 -> V=1.0, theta=0.0
% INFO    : Bus 74115	: V=1.0011662, theta=-111.122242 -> V=1.0, theta=0.0
% INFO    : Bus 74116	: V=1.0016198, theta=-111.07568 -> V=1.0, theta=0.0
% INFO    : Bus 74117	: V=1.0018354, theta=-111.023535 -> V=1.0, theta=0.0
% INFO    : Bus 74118	: V=1.0017836, theta=-111.099064 -> V=1.0, theta=0.0
% INFO    : Bus 74119	: V=1.0019057, theta=-110.523716 -> V=1.0, theta=0.0
% INFO    : Bus 74120	: V=1.001646, theta=-111.158736 -> V=1.0, theta=0.0
% INFO    : Bus 74121	: V=1.0108069, theta=-108.161112 -> V=1.0, theta=0.0
% INFO    : Bus 74122	: V=1.0008818, theta=-107.652676 -> V=1.0, theta=0.0
% INFO    : Bus 74123	: V=1.0017099, theta=-108.557358 -> V=1.0, theta=0.0
% INFO    : Bus 74124	: V=1.0042653, theta=-108.328428 -> V=1.0, theta=0.0
% INFO    : Bus 74125	: V=1.0028733, theta=-108.534587 -> V=1.0, theta=0.0
% INFO    : Bus 74126	: V=1.0025391, theta=-108.467668 -> V=1.0, theta=0.0
% INFO    : Bus 74127	: V=1.0036539, theta=-108.421898 -> V=1.0, theta=0.0
% INFO    : Bus 74128	: V=1.0059841, theta=-107.522245 -> V=1.0, theta=0.0
% INFO    : Bus 74129	: V=1.0039891, theta=-108.471656 -> V=1.0, theta=0.0
% INFO    : Bus 74130	: V=1.0026886, theta=-108.461239 -> V=1.0, theta=0.0
% INFO    : Bus 74131	: V=1.0021802, theta=-108.538134 -> V=1.0, theta=0.0
% INFO    : Bus 74132	: V=1.0055072, theta=-107.961635 -> V=1.0, theta=0.0
% INFO    : Bus 74133	: V=1.0026171, theta=-108.099408 -> V=1.0, theta=0.0
% INFO    : Bus 74134	: V=1.0042911, theta=-107.508985 -> V=1.0, theta=0.0
% INFO    : Bus 74135	: V=1.0062686, theta=-107.380157 -> V=1.0, theta=0.0
% INFO    : Bus 74136	: V=1.0062932, theta=-106.051989 -> V=1.0, theta=0.0
% INFO    : Bus 74137	: V=1.0062486, theta=-107.038615 -> V=1.0, theta=0.0
% INFO    : Bus 74138	: V=1.006617, theta=-107.030392 -> V=1.0, theta=0.0
% INFO    : Bus 74139	: V=1.0043501, theta=-105.336876 -> V=1.0, theta=0.0
% INFO    : Bus 74140	: V=1.0125129, theta=-104.956803 -> V=1.0, theta=0.0
% INFO    : Bus 74141	: V=1.0068432, theta=-105.623601 -> V=1.0, theta=0.0
% INFO    : Bus 74142	: V=1.007081, theta=-107.223813 -> V=1.0, theta=0.0
% INFO    : Bus 74143	: V=0.9951518, theta=-111.052781 -> V=1.0, theta=0.0
% INFO    : Bus 74144	: V=1.0010425, theta=-106.517545 -> V=1.0, theta=0.0
% INFO    : Bus 74145	: V=0.9980002, theta=-110.257523 -> V=1.0, theta=0.0
% INFO    : Bus 74146	: V=0.9974256, theta=-110.55102 -> V=1.0, theta=0.0
% INFO    : Bus 74147	: V=0.995962, theta=-108.857286 -> V=1.0, theta=0.0
% INFO    : Bus 74148	: V=0.9969567, theta=-110.327359 -> V=1.0, theta=0.0
% INFO    : Bus 74149	: V=0.9960176, theta=-110.82732 -> V=1.0, theta=0.0
% INFO    : Bus 74150	: V=0.9974014, theta=-110.709332 -> V=1.0, theta=0.0
% INFO    : Bus 74151	: V=0.9979321, theta=-110.425306 -> V=1.0, theta=0.0
% INFO    : Bus 74152	: V=0.9980696, theta=-110.496997 -> V=1.0, theta=0.0
% INFO    : Bus 74153	: V=0.9983272, theta=-110.429388 -> V=1.0, theta=0.0
% INFO    : Bus 74154	: V=0.998216, theta=-110.676058 -> V=1.0, theta=0.0
% INFO    : Bus 74155	: V=0.997686, theta=-110.697748 -> V=1.0, theta=0.0
% INFO    : Bus 74156	: V=0.9966295, theta=-110.802152 -> V=1.0, theta=0.0
% INFO    : Bus 74157	: V=1.0009436, theta=-105.792949 -> V=1.0, theta=0.0
% INFO    : Bus 74158	: V=0.9998107, theta=-106.429062 -> V=1.0, theta=0.0
% INFO    : Bus 74159	: V=1.0009828, theta=-105.996542 -> V=1.0, theta=0.0
% INFO    : Bus 74160	: V=1.0013573, theta=-106.172487 -> V=1.0, theta=0.0
% INFO    : Bus 74161	: V=1.0002304, theta=-107.21609 -> V=1.0, theta=0.0
% INFO    : Bus 74162	: V=0.9998231, theta=-107.343859 -> V=1.0, theta=0.0
% INFO    : Bus 74163	: V=0.9995998, theta=-107.416832 -> V=1.0, theta=0.0
% INFO    : Bus 74164	: V=0.9988141, theta=-107.461861 -> V=1.0, theta=0.0
% INFO    : Bus 74165	: V=0.9822026, theta=-112.460742 -> V=1.0, theta=0.0
% INFO    : Bus 74166	: V=0.9912891, theta=-111.203615 -> V=1.0, theta=0.0
% INFO    : Bus 74167	: V=0.9921883, theta=-111.078496 -> V=1.0, theta=0.0
% INFO    : Bus 74168	: V=0.9905268, theta=-111.495397 -> V=1.0, theta=0.0
% INFO    : Bus 74169	: V=0.9903043, theta=-111.770849 -> V=1.0, theta=0.0
% INFO    : Bus 74170	: V=0.9920689, theta=-111.087797 -> V=1.0, theta=0.0
% INFO    : Bus 74171	: V=0.9952656, theta=-110.607154 -> V=1.0, theta=0.0
% INFO    : Bus 74172	: V=0.9952538, theta=-108.990369 -> V=1.0, theta=0.0
% INFO    : Bus 74173	: V=0.9933087, theta=-110.924097 -> V=1.0, theta=0.0
% INFO    : Bus 74174	: V=0.996965, theta=-109.347516 -> V=1.0, theta=0.0
% INFO    : Bus 74175	: V=0.9965524, theta=-110.423807 -> V=1.0, theta=0.0
% INFO    : Bus 74176	: V=0.9952851, theta=-110.609131 -> V=1.0, theta=0.0
% INFO    : Bus 74177	: V=0.997836, theta=-110.269537 -> V=1.0, theta=0.0
% INFO    : Bus 74178	: V=0.9983053, theta=-110.243326 -> V=1.0, theta=0.0
% INFO    : Bus 74179	: V=0.9988892, theta=-110.221222 -> V=1.0, theta=0.0
% INFO    : Bus 74180	: V=0.9985762, theta=-110.334092 -> V=1.0, theta=0.0
% INFO    : Bus 74181	: V=0.9982554, theta=-110.244996 -> V=1.0, theta=0.0
% INFO    : Bus 74182	: V=0.9983909, theta=-110.042403 -> V=1.0, theta=0.0
% INFO    : Bus 74183	: V=1.0005947, theta=-108.633271 -> V=1.0, theta=0.0
% INFO    : Bus 74184	: V=0.9981649, theta=-110.05161 -> V=1.0, theta=0.0
% INFO    : Bus 74185	: V=0.9982963, theta=-110.063524 -> V=1.0, theta=0.0
% INFO    : Bus 74186	: V=0.9981611, theta=-108.703432 -> V=1.0, theta=0.0
% INFO    : Bus 74187	: V=0.9984446, theta=-109.720393 -> V=1.0, theta=0.0
% INFO    : Bus 74188	: V=0.9981683, theta=-109.730786 -> V=1.0, theta=0.0
% INFO    : Bus 74189	: V=0.9990572, theta=-108.308845 -> V=1.0, theta=0.0
% INFO    : Bus 74190	: V=0.9989083, theta=-109.402937 -> V=1.0, theta=0.0
% INFO    : Bus 74191	: V=0.9990264, theta=-109.398493 -> V=1.0, theta=0.0
% INFO    : Bus 74192	: V=1.0008634, theta=-107.10822 -> V=1.0, theta=0.0
% INFO    : Bus 74193	: V=0.99998, theta=-108.313888 -> V=1.0, theta=0.0
% INFO    : Bus 74194	: V=0.9980671, theta=-107.427583 -> V=1.0, theta=0.0
% INFO    : Bus 74195	: V=0.9983562, theta=-107.481102 -> V=1.0, theta=0.0
% INFO    : Bus 74196	: V=1.0011907, theta=-105.015588 -> V=1.0, theta=0.0
% INFO    : Bus 74197	: V=1.0100005, theta=-73.43053 -> V=1.0, theta=0.0
% INFO    : Bus 74198	: V=1.0063291, theta=-73.440325 -> V=1.0, theta=0.0
% INFO    : Bus 74199	: V=1.0040094, theta=-73.388662 -> V=1.0, theta=0.0
% INFO    : Bus 74200	: V=1.0103501, theta=-73.370725 -> V=1.0, theta=0.0
% INFO    : Bus 74201	: V=1.0103646, theta=-73.254329 -> V=1.0, theta=0.0
% INFO    : Bus 74202	: V=1.0102129, theta=-73.314406 -> V=1.0, theta=0.0
% INFO    : Bus 74203	: V=1.0080082, theta=-73.342003 -> V=1.0, theta=0.0
% INFO    : Bus 74204	: V=1.0093374, theta=-73.235721 -> V=1.0, theta=0.0
% INFO    : Bus 74205	: V=1.0083828, theta=-73.224987 -> V=1.0, theta=0.0
% INFO    : Bus 74206	: V=1.0060611, theta=-73.472298 -> V=1.0, theta=0.0
% INFO    : Bus 74207	: V=1.0100005, theta=-73.156723 -> V=1.0, theta=0.0
% INFO    : Bus 74208	: V=1.0110703, theta=-73.155797 -> V=1.0, theta=0.0
% INFO    : Bus 74209	: V=1.0054608, theta=-73.496037 -> V=1.0, theta=0.0
% INFO    : Bus 74210	: V=1.0082979, theta=-73.15185 -> V=1.0, theta=0.0
% INFO    : Bus 74211	: V=1.0168997, theta=-73.220138 -> V=1.0, theta=0.0
% INFO    : Bus 74212	: V=1.0091702, theta=-73.044966 -> V=1.0, theta=0.0
% INFO    : Bus 74213	: V=1.0104488, theta=-73.330369 -> V=1.0, theta=0.0
% INFO    : Bus 74214	: V=1.0187408, theta=-73.82453 -> V=1.0, theta=0.0
% INFO    : Bus 74215	: V=1.0121898, theta=-73.437104 -> V=1.0, theta=0.0
% INFO    : Bus 74216	: V=1.0049487, theta=-73.580018 -> V=1.0, theta=0.0
% INFO    : Bus 74217	: V=1.0068567, theta=-73.479639 -> V=1.0, theta=0.0
% INFO    : Bus 74218	: V=1.0084653, theta=-73.167426 -> V=1.0, theta=0.0
% INFO    : Bus 74219	: V=1.0082351, theta=-73.1759 -> V=1.0, theta=0.0
% INFO    : Bus 74220	: V=1.0062535, theta=-73.484624 -> V=1.0, theta=0.0
% INFO    : Bus 74221	: V=1.0015301, theta=-73.421654 -> V=1.0, theta=0.0
% INFO    : Bus 74222	: V=1.0049327, theta=-73.525761 -> V=1.0, theta=0.0
% INFO    : Bus 74223	: V=1.0109353, theta=-72.601844 -> V=1.0, theta=0.0
% INFO    : Bus 74224	: V=1.0108317, theta=-72.839969 -> V=1.0, theta=0.0
% INFO    : Bus 74225	: V=1.0169042, theta=-72.998736 -> V=1.0, theta=0.0
% INFO    : Bus 74226	: V=1.0101379, theta=-72.535492 -> V=1.0, theta=0.0
% INFO    : Bus 74227	: V=1.0086928, theta=-73.056508 -> V=1.0, theta=0.0
% INFO    : Bus 74228	: V=1.0086665, theta=-72.577205 -> V=1.0, theta=0.0
% INFO    : Bus 74229	: V=1.0086828, theta=-71.882063 -> V=1.0, theta=0.0
% INFO    : Bus 74230	: V=1.00277, theta=-72.724449 -> V=1.0, theta=0.0
% INFO    : Bus 74231	: V=0.9998947, theta=-73.484892 -> V=1.0, theta=0.0
% INFO    : Bus 74232	: V=1.0011436, theta=-73.432286 -> V=1.0, theta=0.0
% INFO    : Bus 74233	: V=1.0003665, theta=-73.404755 -> V=1.0, theta=0.0
% INFO    : Bus 74234	: V=0.997266, theta=-73.311363 -> V=1.0, theta=0.0
% INFO    : Bus 74235	: V=1.0087197, theta=-73.58079 -> V=1.0, theta=0.0
% INFO    : Bus 74236	: V=1.0198483, theta=-74.275144 -> V=1.0, theta=0.0
% INFO    : Bus 74237	: V=1.0001319, theta=-74.362043 -> V=1.0, theta=0.0
% INFO    : Bus 74238	: V=1.0038165, theta=-71.892991 -> V=1.0, theta=0.0
% INFO    : Bus 74239	: V=1.0151636, theta=-68.716071 -> V=1.0, theta=0.0
% INFO    : Bus 74240	: V=1.00976, theta=-68.139113 -> V=1.0, theta=0.0
% INFO    : Bus 74241	: V=1.0058732, theta=-71.769865 -> V=1.0, theta=0.0
% INFO    : Bus 74242	: V=1.0049403, theta=-72.25215 -> V=1.0, theta=0.0
% INFO    : Bus 74243	: V=1.0132586, theta=-68.62577 -> V=1.0, theta=0.0
% INFO    : Bus 74244	: V=1.0089434, theta=-68.509403 -> V=1.0, theta=0.0
% INFO    : Bus 74245	: V=0.9769533, theta=-82.462218 -> V=1.0, theta=0.0
% INFO    : Bus 74246	: V=1.0077568, theta=-64.274795 -> V=1.0, theta=0.0
% INFO    : Bus 74247	: V=1.0054049, theta=-59.605687 -> V=1.0, theta=0.0
% INFO    : Bus 74248	: V=0.976207, theta=-59.2876 -> V=1.0, theta=0.0
% INFO    : Bus 74249	: V=0.9908571, theta=-59.404618 -> V=1.0, theta=0.0
% INFO    : Bus 74250	: V=0.9954558, theta=-64.047908 -> V=1.0, theta=0.0
% INFO    : Bus 74251	: V=0.9957447, theta=-65.348729 -> V=1.0, theta=0.0
% INFO    : Bus 74252	: V=0.9971756, theta=-65.834199 -> V=1.0, theta=0.0
% INFO    : Bus 74253	: V=0.9966826, theta=-64.96414 -> V=1.0, theta=0.0
% INFO    : Bus 74254	: V=0.9952411, theta=-65.023606 -> V=1.0, theta=0.0
% INFO    : Bus 74255	: V=1.0078093, theta=-69.295469 -> V=1.0, theta=0.0
% INFO    : Bus 74256	: V=1.0095238, theta=-67.775142 -> V=1.0, theta=0.0
% INFO    : Bus 74257	: V=0.9947957, theta=-68.595823 -> V=1.0, theta=0.0
% INFO    : Bus 74258	: V=0.9997276, theta=-68.755263 -> V=1.0, theta=0.0
% INFO    : Bus 74259	: V=1.0085598, theta=-66.062026 -> V=1.0, theta=0.0
% INFO    : Bus 74260	: V=1.0006857, theta=-105.678831 -> V=1.0, theta=0.0
% INFO    : Bus 74261	: V=1.0029785, theta=-105.532622 -> V=1.0, theta=0.0
% INFO    : Bus 74262	: V=1.0000703, theta=-105.728813 -> V=1.0, theta=0.0
% INFO    : Bus 74263	: V=0.99911, theta=-105.77289 -> V=1.0, theta=0.0
% INFO    : Bus 74264	: V=1.0022303, theta=-105.251519 -> V=1.0, theta=0.0
% INFO    : Bus 74265	: V=1.0018169, theta=-105.19804 -> V=1.0, theta=0.0
% INFO    : Bus 74266	: V=1.0018313, theta=-105.687951 -> V=1.0, theta=0.0
% INFO    : Bus 74267	: V=1.0021015, theta=-105.698266 -> V=1.0, theta=0.0
% INFO    : Bus 74268	: V=1.0024845, theta=-105.704261 -> V=1.0, theta=0.0
% INFO    : Bus 74269	: V=1.00046, theta=-105.716153 -> V=1.0, theta=0.0
% INFO    : Bus 74270	: V=1.0023033, theta=-105.755341 -> V=1.0, theta=0.0
% INFO    : Bus 74271	: V=1.0026985, theta=-105.737309 -> V=1.0, theta=0.0
% INFO    : Bus 74272	: V=1.0013331, theta=-105.680383 -> V=1.0, theta=0.0
% INFO    : Bus 74273	: V=0.998975, theta=-105.749574 -> V=1.0, theta=0.0
% INFO    : Bus 74274	: V=1.0007072, theta=-105.69042 -> V=1.0, theta=0.0
% INFO    : Bus 74275	: V=1.0008396, theta=-105.697886 -> V=1.0, theta=0.0
% INFO    : Bus 74276	: V=1.0015405, theta=-105.66399 -> V=1.0, theta=0.0
% INFO    : Bus 74277	: V=1.0014166, theta=-105.618032 -> V=1.0, theta=0.0
% INFO    : Bus 74278	: V=1.0013775, theta=-105.53206 -> V=1.0, theta=0.0
% INFO    : Bus 74279	: V=1.0010317, theta=-105.04831 -> V=1.0, theta=0.0
% INFO    : Bus 74280	: V=1.0013561, theta=-105.595567 -> V=1.0, theta=0.0
% INFO    : Bus 74281	: V=1.0007237, theta=-105.667378 -> V=1.0, theta=0.0
% INFO    : Bus 74282	: V=1.0008652, theta=-105.633692 -> V=1.0, theta=0.0
% INFO    : Bus 74283	: V=1.0009639, theta=-105.608129 -> V=1.0, theta=0.0
% INFO    : Bus 74284	: V=1.0008976, theta=-104.98374 -> V=1.0, theta=0.0
% INFO    : Bus 74285	: V=1.0007752, theta=-104.876515 -> V=1.0, theta=0.0
% INFO    : Bus 74286	: V=1.0007317, theta=-104.754786 -> V=1.0, theta=0.0
% INFO    : Bus 74287	: V=1.0008962, theta=-104.960369 -> V=1.0, theta=0.0
% INFO    : Bus 74288	: V=0.9988084, theta=-104.879789 -> V=1.0, theta=0.0
% INFO    : Bus 74289	: V=0.9987477, theta=-104.882146 -> V=1.0, theta=0.0
% INFO    : Bus 74290	: V=1.0049378, theta=-105.366703 -> V=1.0, theta=0.0
% INFO    : Bus 74291	: V=0.9993082, theta=-105.748074 -> V=1.0, theta=0.0
% INFO    : Bus 74292	: V=1.0021947, theta=-105.27271 -> V=1.0, theta=0.0
% INFO    : Bus 74293	: V=1.0032538, theta=-105.754936 -> V=1.0, theta=0.0
% INFO    : Bus 74294	: V=1.0033396, theta=-105.343788 -> V=1.0, theta=0.0
% INFO    : Bus 74295	: V=1.0038698, theta=-105.365518 -> V=1.0, theta=0.0
% INFO    : Bus 74296	: V=1.0044802, theta=-105.786445 -> V=1.0, theta=0.0
% INFO    : Bus 74297	: V=1.0045751, theta=-105.368818 -> V=1.0, theta=0.0
% INFO    : Bus 74298	: V=0.998871, theta=-104.353851 -> V=1.0, theta=0.0
% INFO    : Bus 74299	: V=1.0012496, theta=-105.595818 -> V=1.0, theta=0.0
% INFO    : Bus 74300	: V=1.0018878, theta=-104.834706 -> V=1.0, theta=0.0
% INFO    : Bus 74301	: V=1.001858, theta=-104.849007 -> V=1.0, theta=0.0
% INFO    : Bus 74302	: V=1.001862, theta=-104.582039 -> V=1.0, theta=0.0
% INFO    : Bus 74303	: V=1.0018773, theta=-104.694464 -> V=1.0, theta=0.0
% INFO    : Bus 74304	: V=1.0023934, theta=-104.776943 -> V=1.0, theta=0.0
% INFO    : Bus 74305	: V=1.0021216, theta=-104.737836 -> V=1.0, theta=0.0
% INFO    : Bus 74306	: V=1.0009491, theta=-104.925767 -> V=1.0, theta=0.0
% INFO    : Bus 74307	: V=1.0008363, theta=-104.872505 -> V=1.0, theta=0.0
% INFO    : Bus 74308	: V=1.0004136, theta=-104.917099 -> V=1.0, theta=0.0
% INFO    : Bus 74309	: V=1.0090407, theta=-103.66009 -> V=1.0, theta=0.0
% INFO    : Bus 74310	: V=1.0065285, theta=-104.05044 -> V=1.0, theta=0.0
% INFO    : Bus 74311	: V=1.0071161, theta=-103.990478 -> V=1.0, theta=0.0
% INFO    : Bus 74312	: V=1.000605, theta=-104.889292 -> V=1.0, theta=0.0
% INFO    : Bus 74313	: V=1.0008321, theta=-104.955413 -> V=1.0, theta=0.0
% INFO    : Bus 74314	: V=1.0061349, theta=-104.079809 -> V=1.0, theta=0.0
% INFO    : Bus 74315	: V=1.0016197, theta=-104.900751 -> V=1.0, theta=0.0
% INFO    : Bus 74316	: V=1.0007017, theta=-104.925676 -> V=1.0, theta=0.0
% INFO    : Bus 74317	: V=0.9995357, theta=-104.924679 -> V=1.0, theta=0.0
% INFO    : Bus 74318	: V=1.0004653, theta=-104.929942 -> V=1.0, theta=0.0
% INFO    : Bus 74319	: V=0.9988812, theta=-104.971414 -> V=1.0, theta=0.0
% INFO    : Bus 74320	: V=1.0003, theta=-104.936708 -> V=1.0, theta=0.0
% INFO    : Bus 74321	: V=1.0075627, theta=-103.709896 -> V=1.0, theta=0.0
% INFO    : Bus 74322	: V=0.9990344, theta=-104.933327 -> V=1.0, theta=0.0
% INFO    : Bus 74323	: V=0.998897, theta=-104.918183 -> V=1.0, theta=0.0
% INFO    : Bus 74324	: V=0.9986257, theta=-104.866388 -> V=1.0, theta=0.0
% INFO    : Bus 74325	: V=0.999067, theta=-104.762429 -> V=1.0, theta=0.0
% INFO    : Bus 74326	: V=0.9991487, theta=-104.959132 -> V=1.0, theta=0.0
% INFO    : Bus 74327	: V=1.0018304, theta=-104.61324 -> V=1.0, theta=0.0
% INFO    : Bus 74328	: V=1.0016231, theta=-104.622703 -> V=1.0, theta=0.0
% INFO    : Bus 74329	: V=1.0032057, theta=-103.590154 -> V=1.0, theta=0.0
% INFO    : Bus 74330	: V=1.0118192, theta=-103.105349 -> V=1.0, theta=0.0
% INFO    : Bus 74331	: V=1.0095485, theta=-103.546146 -> V=1.0, theta=0.0
% INFO    : Bus 74332	: V=1.0080057, theta=-104.049688 -> V=1.0, theta=0.0
% INFO    : Bus 74333	: V=1.0076307, theta=-104.093814 -> V=1.0, theta=0.0
% INFO    : Bus 74334	: V=1.0106282, theta=-103.301572 -> V=1.0, theta=0.0
% INFO    : Bus 74335	: V=1.0101188, theta=-103.423105 -> V=1.0, theta=0.0
% INFO    : Bus 74336	: V=1.0091744, theta=-103.635011 -> V=1.0, theta=0.0
% INFO    : Bus 74337	: V=1.0070821, theta=-104.114369 -> V=1.0, theta=0.0
% INFO    : Bus 74338	: V=1.0066387, theta=-104.134464 -> V=1.0, theta=0.0
% INFO    : Bus 74339	: V=1.007315, theta=-104.181656 -> V=1.0, theta=0.0
% INFO    : Bus 74340	: V=1.0049912, theta=-104.376952 -> V=1.0, theta=0.0
% INFO    : Bus 74341	: V=1.0083996, theta=-104.10436 -> V=1.0, theta=0.0
% INFO    : Bus 74342	: V=1.0072523, theta=-104.16204 -> V=1.0, theta=0.0
% INFO    : Bus 74343	: V=1.0068335, theta=-104.214818 -> V=1.0, theta=0.0
% INFO    : Bus 74344	: V=1.0064933, theta=-104.215097 -> V=1.0, theta=0.0
% INFO    : Bus 74345	: V=1.0050098, theta=-104.205457 -> V=1.0, theta=0.0
% INFO    : Bus 74346	: V=1.0053388, theta=-104.297923 -> V=1.0, theta=0.0
% INFO    : Bus 74347	: V=1.0058706, theta=-104.173092 -> V=1.0, theta=0.0
% INFO    : Bus 74348	: V=1.006629, theta=-104.117386 -> V=1.0, theta=0.0
% INFO    : Bus 74349	: V=1.0061293, theta=-104.007525 -> V=1.0, theta=0.0
% INFO    : Bus 74350	: V=1.0056901, theta=-103.493461 -> V=1.0, theta=0.0
% INFO    : Bus 74351	: V=1.0105407, theta=-102.67809 -> V=1.0, theta=0.0
% INFO    : Bus 74352	: V=1.006077, theta=-103.344792 -> V=1.0, theta=0.0
% INFO    : Bus 74353	: V=1.0063958, theta=-103.218919 -> V=1.0, theta=0.0
% INFO    : Bus 74354	: V=1.0096777, theta=-102.455072 -> V=1.0, theta=0.0
% INFO    : Bus 74355	: V=1.0009648, theta=-104.534532 -> V=1.0, theta=0.0
% INFO    : Bus 74356	: V=0.9921465, theta=-103.210352 -> V=1.0, theta=0.0
% INFO    : Bus 74357	: V=0.9950491, theta=-100.314445 -> V=1.0, theta=0.0
% INFO    : Bus 74358	: V=0.9923134, theta=-100.917601 -> V=1.0, theta=0.0
% INFO    : Bus 74359	: V=0.9929105, theta=-100.892989 -> V=1.0, theta=0.0
% INFO    : Bus 74360	: V=0.9949075, theta=-100.199169 -> V=1.0, theta=0.0
% INFO    : Bus 74361	: V=0.9934216, theta=-100.542875 -> V=1.0, theta=0.0
% INFO    : Bus 74362	: V=0.9944419, theta=-100.504344 -> V=1.0, theta=0.0
% INFO    : Bus 74363	: V=0.9936325, theta=-100.538686 -> V=1.0, theta=0.0
% INFO    : Bus 74364	: V=0.9963211, theta=-98.991651 -> V=1.0, theta=0.0
% INFO    : Bus 74365	: V=0.9958177, theta=-100.452064 -> V=1.0, theta=0.0
% INFO    : Bus 74366	: V=0.9958917, theta=-100.423977 -> V=1.0, theta=0.0
% INFO    : Bus 74367	: V=0.9961184, theta=-100.363895 -> V=1.0, theta=0.0
% INFO    : Bus 74368	: V=0.9969271, theta=-99.462719 -> V=1.0, theta=0.0
% INFO    : Bus 74369	: V=0.9968534, theta=-99.715598 -> V=1.0, theta=0.0
% INFO    : Bus 74370	: V=0.996852, theta=-99.610658 -> V=1.0, theta=0.0
% INFO    : Bus 74371	: V=0.9948344, theta=-100.416902 -> V=1.0, theta=0.0
% INFO    : Bus 74372	: V=0.9974674, theta=-101.267959 -> V=1.0, theta=0.0
% INFO    : Bus 74373	: V=0.9968435, theta=-100.164864 -> V=1.0, theta=0.0
% INFO    : Bus 74374	: V=0.9916637, theta=-100.304459 -> V=1.0, theta=0.0
% INFO    : Bus 74375	: V=0.9932201, theta=-100.232243 -> V=1.0, theta=0.0
% INFO    : Bus 74376	: V=0.9968038, theta=-99.915314 -> V=1.0, theta=0.0
% INFO    : Bus 74377	: V=0.9960399, theta=-100.210925 -> V=1.0, theta=0.0
% INFO    : Bus 74378	: V=0.9944192, theta=-100.196193 -> V=1.0, theta=0.0
% INFO    : Bus 74379	: V=0.9993159, theta=-96.45254 -> V=1.0, theta=0.0
% INFO    : Bus 74380	: V=0.9977482, theta=-97.685163 -> V=1.0, theta=0.0
% INFO    : Bus 74381	: V=0.9970156, theta=-98.902361 -> V=1.0, theta=0.0
% INFO    : Bus 74382	: V=0.9967245, theta=-98.970362 -> V=1.0, theta=0.0
% INFO    : Bus 74383	: V=0.9972108, theta=-98.824053 -> V=1.0, theta=0.0
% INFO    : Bus 74384	: V=0.9974079, theta=-98.740629 -> V=1.0, theta=0.0
% INFO    : Bus 74385	: V=0.9974893, theta=-98.616663 -> V=1.0, theta=0.0
% INFO    : Bus 74386	: V=0.9968108, theta=-98.64202 -> V=1.0, theta=0.0
% INFO    : Bus 74387	: V=0.9974786, theta=-97.744961 -> V=1.0, theta=0.0
% INFO    : Bus 74388	: V=0.9956187, theta=-97.27581 -> V=1.0, theta=0.0
% INFO    : Bus 74389	: V=0.9972468, theta=-98.196758 -> V=1.0, theta=0.0
% INFO    : Bus 74390	: V=0.9971444, theta=-98.485742 -> V=1.0, theta=0.0
% INFO    : Bus 74391	: V=0.9982788, theta=-96.89173 -> V=1.0, theta=0.0
% INFO    : Bus 74392	: V=0.9990379, theta=-94.771593 -> V=1.0, theta=0.0
% INFO    : Bus 74393	: V=0.997593, theta=-97.192615 -> V=1.0, theta=0.0
% INFO    : Bus 74394	: V=0.99673, theta=-97.490939 -> V=1.0, theta=0.0
% INFO    : Bus 74395	: V=0.9936291, theta=-97.324759 -> V=1.0, theta=0.0
% INFO    : Bus 74396	: V=0.995358, theta=-97.995216 -> V=1.0, theta=0.0
% INFO    : Bus 74397	: V=0.9961695, theta=-97.672163 -> V=1.0, theta=0.0
% INFO    : Bus 74398	: V=0.9941497, theta=-97.305038 -> V=1.0, theta=0.0
% INFO    : Bus 74399	: V=0.9927721, theta=-97.445907 -> V=1.0, theta=0.0
% INFO    : Bus 74400	: V=0.9952565, theta=-97.314407 -> V=1.0, theta=0.0
% INFO    : Bus 74401	: V=0.9958201, theta=-97.293339 -> V=1.0, theta=0.0
% INFO    : Bus 74402	: V=0.9941367, theta=-97.362787 -> V=1.0, theta=0.0
% INFO    : Bus 74403	: V=0.993592, theta=-97.383196 -> V=1.0, theta=0.0
% INFO    : Bus 74404	: V=0.9932225, theta=-97.371711 -> V=1.0, theta=0.0
% INFO    : Bus 74405	: V=0.9954677, theta=-97.307782 -> V=1.0, theta=0.0
% INFO    : Bus 74406	: V=0.9912883, theta=-97.506978 -> V=1.0, theta=0.0
% INFO    : Bus 74407	: V=0.9956031, theta=-97.189744 -> V=1.0, theta=0.0
% INFO    : Bus 74408	: V=0.9947411, theta=-97.236128 -> V=1.0, theta=0.0
% INFO    : Bus 74409	: V=0.9954551, theta=-97.129076 -> V=1.0, theta=0.0
% INFO    : Bus 74410	: V=1.0000443, theta=-95.354586 -> V=1.0, theta=0.0
% INFO    : Bus 74411	: V=0.9954985, theta=-96.750068 -> V=1.0, theta=0.0
% INFO    : Bus 74412	: V=0.9950899, theta=-96.712766 -> V=1.0, theta=0.0
% INFO    : Bus 74413	: V=0.9951641, theta=-97.15807 -> V=1.0, theta=0.0
% INFO    : Bus 74414	: V=0.9947538, theta=-97.304272 -> V=1.0, theta=0.0
% INFO    : Bus 74415	: V=0.9947162, theta=-97.326587 -> V=1.0, theta=0.0
% INFO    : Bus 74416	: V=0.9947235, theta=-97.29822 -> V=1.0, theta=0.0
% INFO    : Bus 74417	: V=0.9948897, theta=-97.25631 -> V=1.0, theta=0.0
% INFO    : Bus 74418	: V=0.9928015, theta=-96.818286 -> V=1.0, theta=0.0
% INFO    : Bus 74419	: V=0.9949587, theta=-97.333711 -> V=1.0, theta=0.0
% INFO    : Bus 74420	: V=0.9956363, theta=-97.250617 -> V=1.0, theta=0.0
% INFO    : Bus 74421	: V=0.9961271, theta=-97.22282 -> V=1.0, theta=0.0
% INFO    : Bus 74422	: V=0.9920419, theta=-97.721644 -> V=1.0, theta=0.0
% INFO    : Bus 74423	: V=0.9946481, theta=-97.299927 -> V=1.0, theta=0.0
% INFO    : Bus 74424	: V=0.9975454, theta=-96.975634 -> V=1.0, theta=0.0
% INFO    : Bus 74425	: V=0.9971856, theta=-96.990396 -> V=1.0, theta=0.0
% INFO    : Bus 74426	: V=0.9983677, theta=-96.105972 -> V=1.0, theta=0.0
% INFO    : Bus 74427	: V=1.0062504, theta=-87.93452 -> V=1.0, theta=0.0
% INFO    : Bus 74428	: V=0.9973965, theta=-96.840411 -> V=1.0, theta=0.0
% INFO    : Bus 74429	: V=0.9901487, theta=-98.224261 -> V=1.0, theta=0.0
% INFO    : Bus 74430	: V=0.9937276, theta=-97.728653 -> V=1.0, theta=0.0
% INFO    : Bus 74431	: V=0.9929824, theta=-97.757068 -> V=1.0, theta=0.0
% INFO    : Bus 74432	: V=0.9922395, theta=-97.786651 -> V=1.0, theta=0.0
% INFO    : Bus 74433	: V=0.9903673, theta=-97.860315 -> V=1.0, theta=0.0
% INFO    : Bus 74434	: V=0.9881666, theta=-98.415254 -> V=1.0, theta=0.0
% INFO    : Bus 74435	: V=0.9879575, theta=-95.45056 -> V=1.0, theta=0.0
% INFO    : Bus 74436	: V=0.9924469, theta=-95.241837 -> V=1.0, theta=0.0
% INFO    : Bus 74437	: V=0.9939091, theta=-96.147417 -> V=1.0, theta=0.0
% INFO    : Bus 74438	: V=0.9915423, theta=-96.237767 -> V=1.0, theta=0.0
% INFO    : Bus 74439	: V=0.9968229, theta=-95.931812 -> V=1.0, theta=0.0
% INFO    : Bus 74440	: V=0.9951296, theta=-96.347836 -> V=1.0, theta=0.0
% INFO    : Bus 74441	: V=0.9955003, theta=-96.334969 -> V=1.0, theta=0.0
% INFO    : Bus 74442	: V=0.9970035, theta=-96.173038 -> V=1.0, theta=0.0
% INFO    : Bus 74443	: V=0.9957993, theta=-96.32263 -> V=1.0, theta=0.0
% INFO    : Bus 74444	: V=0.9945702, theta=-96.782154 -> V=1.0, theta=0.0
% INFO    : Bus 74445	: V=0.9992742, theta=-95.008237 -> V=1.0, theta=0.0
% INFO    : Bus 74446	: V=1.0010481, theta=-91.9417 -> V=1.0, theta=0.0
% INFO    : Bus 74447	: V=1.0002675, theta=-94.399562 -> V=1.0, theta=0.0
% INFO    : Bus 74448	: V=0.9985238, theta=-94.477705 -> V=1.0, theta=0.0
% INFO    : Bus 74449	: V=1.0068768, theta=-86.746203 -> V=1.0, theta=0.0
% INFO    : Bus 74450	: V=1.0012449, theta=-87.937339 -> V=1.0, theta=0.0
% INFO    : Bus 74451	: V=0.9964758, theta=-88.688911 -> V=1.0, theta=0.0
% INFO    : Bus 74452	: V=0.9814574, theta=-98.701211 -> V=1.0, theta=0.0
% INFO    : Bus 74453	: V=0.9830067, theta=-89.69375 -> V=1.0, theta=0.0
% INFO    : Bus 74454	: V=0.9875055, theta=-89.509224 -> V=1.0, theta=0.0
% INFO    : Bus 74455	: V=0.9920908, theta=-104.353894 -> V=1.0, theta=0.0
% INFO    : Bus 74456	: V=0.9948667, theta=-103.718641 -> V=1.0, theta=0.0
% INFO    : Bus 74457	: V=0.9915029, theta=-105.538372 -> V=1.0, theta=0.0
% INFO    : Bus 74458	: V=0.9917033, theta=-105.62919 -> V=1.0, theta=0.0
% INFO    : Bus 74459	: V=0.9916662, theta=-105.214058 -> V=1.0, theta=0.0
% INFO    : Bus 74460	: V=0.9975601, theta=-107.021389 -> V=1.0, theta=0.0
% INFO    : Bus 74461	: V=0.997068, theta=-107.043747 -> V=1.0, theta=0.0
% INFO    : Bus 74462	: V=0.9977102, theta=-107.1182 -> V=1.0, theta=0.0
% INFO    : Bus 74463	: V=0.9966022, theta=-106.831314 -> V=1.0, theta=0.0
% INFO    : Bus 74464	: V=1.0006429, theta=-105.842768 -> V=1.0, theta=0.0
% INFO    : Bus 74465	: V=0.9967637, theta=-107.608948 -> V=1.0, theta=0.0
% INFO    : Bus 74466	: V=0.9976948, theta=-107.574074 -> V=1.0, theta=0.0
% INFO    : Bus 74467	: V=1.002783, theta=-106.315496 -> V=1.0, theta=0.0
% INFO    : Bus 74468	: V=1.0000135, theta=-106.735611 -> V=1.0, theta=0.0
% INFO    : Bus 74469	: V=0.9989813, theta=-106.956593 -> V=1.0, theta=0.0
% INFO    : Bus 74470	: V=0.9985497, theta=-107.144036 -> V=1.0, theta=0.0
% INFO    : Bus 74471	: V=0.9976685, theta=-107.312082 -> V=1.0, theta=0.0
% INFO    : Bus 74472	: V=1.0028667, theta=-106.149558 -> V=1.0, theta=0.0
% INFO    : Bus 74473	: V=1.0028545, theta=-107.00816 -> V=1.0, theta=0.0
% INFO    : Bus 74474	: V=1.0050798, theta=-107.268883 -> V=1.0, theta=0.0
% INFO    : Bus 74475	: V=0.9980796, theta=-107.418988 -> V=1.0, theta=0.0
% INFO    : Bus 74476	: V=0.9995248, theta=-107.055847 -> V=1.0, theta=0.0
% INFO    : Bus 74477	: V=0.9993467, theta=-107.165903 -> V=1.0, theta=0.0
% INFO    : Bus 74478	: V=0.9986634, theta=-107.171305 -> V=1.0, theta=0.0
% INFO    : Bus 74479	: V=0.9990049, theta=-107.075255 -> V=1.0, theta=0.0
% INFO    : Bus 74480	: V=1.0004838, theta=-107.770856 -> V=1.0, theta=0.0
% INFO    : Bus 74481	: V=1.0014348, theta=-107.716273 -> V=1.0, theta=0.0
% INFO    : Bus 74482	: V=0.9980421, theta=-107.485502 -> V=1.0, theta=0.0
% INFO    : Bus 74483	: V=0.9973655, theta=-107.731013 -> V=1.0, theta=0.0
% INFO    : Bus 74484	: V=0.9988341, theta=-107.453966 -> V=1.0, theta=0.0
% INFO    : Bus 74485	: V=0.9975304, theta=-107.776111 -> V=1.0, theta=0.0
% INFO    : Bus 74486	: V=0.9998793, theta=-107.7609 -> V=1.0, theta=0.0
% INFO    : Bus 74487	: V=0.9996426, theta=-107.701241 -> V=1.0, theta=0.0
% INFO    : Bus 74488	: V=0.9985993, theta=-107.791206 -> V=1.0, theta=0.0
% INFO    : Bus 74489	: V=1.0003222, theta=-107.443637 -> V=1.0, theta=0.0
% INFO    : Bus 74490	: V=1.0000073, theta=-107.403734 -> V=1.0, theta=0.0
% INFO    : Bus 74491	: V=1.0007388, theta=-107.374208 -> V=1.0, theta=0.0
% INFO    : Bus 74492	: V=1.0004685, theta=-107.328053 -> V=1.0, theta=0.0
% INFO    : Bus 74493	: V=1.0003181, theta=-107.199685 -> V=1.0, theta=0.0
% INFO    : Bus 74494	: V=1.0041656, theta=-107.317143 -> V=1.0, theta=0.0
% INFO    : Bus 74495	: V=1.0023373, theta=-107.475047 -> V=1.0, theta=0.0
% INFO    : Bus 74496	: V=1.0045154, theta=-106.315005 -> V=1.0, theta=0.0
% INFO    : Bus 74497	: V=1.0037293, theta=-107.397807 -> V=1.0, theta=0.0
% INFO    : Bus 74498	: V=1.0013586, theta=-107.452669 -> V=1.0, theta=0.0
% INFO    : Bus 74499	: V=1.0011354, theta=-107.401499 -> V=1.0, theta=0.0
% INFO    : Bus 74500	: V=1.0010726, theta=-107.475744 -> V=1.0, theta=0.0
% INFO    : Bus 74501	: V=1.0107698, theta=-106.645171 -> V=1.0, theta=0.0
% INFO    : Bus 74502	: V=1.0030012, theta=-107.667625 -> V=1.0, theta=0.0
% INFO    : Bus 74503	: V=1.0024354, theta=-107.69699 -> V=1.0, theta=0.0
% INFO    : Bus 74504	: V=1.002123, theta=-107.709702 -> V=1.0, theta=0.0
% INFO    : Bus 74505	: V=1.0024802, theta=-107.442284 -> V=1.0, theta=0.0
% INFO    : Bus 74506	: V=1.0015432, theta=-107.504583 -> V=1.0, theta=0.0
% INFO    : Bus 74507	: V=1.0036112, theta=-107.449013 -> V=1.0, theta=0.0
% INFO    : Bus 74508	: V=1.0026858, theta=-107.387824 -> V=1.0, theta=0.0
% INFO    : Bus 74509	: V=1.0027403, theta=-107.466969 -> V=1.0, theta=0.0
% INFO    : Bus 74510	: V=1.0030687, theta=-107.454766 -> V=1.0, theta=0.0
% INFO    : Bus 74511	: V=1.0060104, theta=-106.293095 -> V=1.0, theta=0.0
% INFO    : Bus 74512	: V=1.0038454, theta=-106.762297 -> V=1.0, theta=0.0
% INFO    : Bus 74513	: V=1.0048332, theta=-107.422968 -> V=1.0, theta=0.0
% INFO    : Bus 74514	: V=1.0043638, theta=-106.734924 -> V=1.0, theta=0.0
% INFO    : Bus 74515	: V=1.0047923, theta=-107.016716 -> V=1.0, theta=0.0
% INFO    : Bus 74516	: V=1.0048553, theta=-107.168567 -> V=1.0, theta=0.0
% INFO    : Bus 74517	: V=1.0076135, theta=-106.306938 -> V=1.0, theta=0.0
% INFO    : Bus 74518	: V=1.0062903, theta=-106.295585 -> V=1.0, theta=0.0
% INFO    : Bus 74519	: V=1.004183, theta=-107.255383 -> V=1.0, theta=0.0
% INFO    : Bus 74520	: V=0.9954152, theta=-104.082812 -> V=1.0, theta=0.0
% INFO    : Bus 74521	: V=1.0068214, theta=-107.939244 -> V=1.0, theta=0.0
% INFO    : Bus 74522	: V=1.0004395, theta=-107.721584 -> V=1.0, theta=0.0
% INFO    : Bus 74523	: V=0.9980827, theta=-104.074203 -> V=1.0, theta=0.0
% INFO    : Bus 74524	: V=1.0018718, theta=-106.872242 -> V=1.0, theta=0.0
% INFO    : Bus 74525	: V=1.0033233, theta=-106.935962 -> V=1.0, theta=0.0
% INFO    : Bus 74526	: V=1.0080584, theta=-106.02951 -> V=1.0, theta=0.0
% INFO    : Bus 74527	: V=1.0050441, theta=-106.177263 -> V=1.0, theta=0.0
% INFO    : Bus 74528	: V=1.005053, theta=-105.953676 -> V=1.0, theta=0.0
% INFO    : Bus 74529	: V=1.0086784, theta=-106.573471 -> V=1.0, theta=0.0
% INFO    : Bus 74530	: V=0.9960376, theta=-107.132646 -> V=1.0, theta=0.0
% INFO    : Bus 74531	: V=0.9992348, theta=-107.258768 -> V=1.0, theta=0.0
% INFO    : Bus 74532	: V=1.0055149, theta=-105.269889 -> V=1.0, theta=0.0
% INFO    : Bus 74533	: V=1.0142018, theta=-105.944557 -> V=1.0, theta=0.0
% INFO    : Bus 74534	: V=0.9987998, theta=-105.058331 -> V=1.0, theta=0.0
% INFO    : Bus 74535	: V=1.0015104, theta=-106.543499 -> V=1.0, theta=0.0
% INFO    : Bus 74536	: V=1.0009993, theta=-106.57784 -> V=1.0, theta=0.0
% INFO    : Bus 74537	: V=1.0090201, theta=-105.449025 -> V=1.0, theta=0.0
% INFO    : Bus 74538	: V=1.0046328, theta=-105.905217 -> V=1.0, theta=0.0
% INFO    : Bus 74539	: V=1.005567, theta=-105.246663 -> V=1.0, theta=0.0
% INFO    : Bus 74540	: V=1.0046724, theta=-105.970231 -> V=1.0, theta=0.0
% INFO    : Bus 74541	: V=1.0075287, theta=-105.365856 -> V=1.0, theta=0.0
% INFO    : Bus 74542	: V=1.0040189, theta=-105.797928 -> V=1.0, theta=0.0
% INFO    : Bus 74543	: V=1.003555, theta=-105.819032 -> V=1.0, theta=0.0
% INFO    : Bus 74544	: V=1.0031321, theta=-105.838915 -> V=1.0, theta=0.0
% INFO    : Bus 74545	: V=1.0026152, theta=-105.754087 -> V=1.0, theta=0.0
% INFO    : Bus 74546	: V=1.00366, theta=-105.909386 -> V=1.0, theta=0.0
% INFO    : Bus 74547	: V=1.0020775, theta=-106.469714 -> V=1.0, theta=0.0
% INFO    : Bus 74548	: V=0.9945861, theta=-106.445023 -> V=1.0, theta=0.0
% INFO    : Bus 74549	: V=1.0115749, theta=-91.122955 -> V=1.0, theta=0.0
% INFO    : Bus 74550	: V=1.0123209, theta=-91.084709 -> V=1.0, theta=0.0
% INFO    : Bus 74551	: V=1.0109051, theta=-90.814843 -> V=1.0, theta=0.0
% INFO    : Bus 74552	: V=1.0104798, theta=-90.892661 -> V=1.0, theta=0.0
% INFO    : Bus 74553	: V=1.0102446, theta=-91.467638 -> V=1.0, theta=0.0
% INFO    : Bus 74554	: V=1.0101792, theta=-91.060322 -> V=1.0, theta=0.0
% INFO    : Bus 74555	: V=1.0092892, theta=-91.454531 -> V=1.0, theta=0.0
% INFO    : Bus 74556	: V=1.0080082, theta=-91.522215 -> V=1.0, theta=0.0
% INFO    : Bus 74557	: V=1.0087503, theta=-91.491999 -> V=1.0, theta=0.0
% INFO    : Bus 74558	: V=1.0115043, theta=-90.886314 -> V=1.0, theta=0.0
% INFO    : Bus 74559	: V=1.0121778, theta=-91.18082 -> V=1.0, theta=0.0
% INFO    : Bus 74560	: V=1.0136822, theta=-91.777731 -> V=1.0, theta=0.0
% INFO    : Bus 74561	: V=1.0110887, theta=-90.393997 -> V=1.0, theta=0.0
% INFO    : Bus 74562	: V=1.0106892, theta=-91.187212 -> V=1.0, theta=0.0
% INFO    : Bus 74563	: V=1.0169846, theta=-91.17634 -> V=1.0, theta=0.0
% INFO    : Bus 74564	: V=1.0098383, theta=-88.32996 -> V=1.0, theta=0.0
% INFO    : Bus 74565	: V=1.0105054, theta=-89.077747 -> V=1.0, theta=0.0
% INFO    : Bus 74566	: V=1.0005635, theta=-87.645994 -> V=1.0, theta=0.0
% INFO    : Bus 74567	: V=1.0143758, theta=-92.767878 -> V=1.0, theta=0.0
% INFO    : Bus 74568	: V=1.0246572, theta=-93.261625 -> V=1.0, theta=0.0
% INFO    : Bus 74569	: V=1.0056591, theta=-95.479314 -> V=1.0, theta=0.0
% INFO    : Bus 74570	: V=1.001806, theta=-73.29382 -> V=1.0, theta=0.0
% INFO    : Bus 74571	: V=1.0045989, theta=-75.344347 -> V=1.0, theta=0.0
% INFO    : Bus 74572	: V=0.9861755, theta=-76.318346 -> V=1.0, theta=0.0
% INFO    : Bus 74573	: V=1.0270349, theta=-76.478276 -> V=1.0, theta=0.0
% INFO    : Bus 74574	: V=1.0093727, theta=-78.694175 -> V=1.0, theta=0.0
% INFO    : Bus 74575	: V=1.0080475, theta=-78.754774 -> V=1.0, theta=0.0
% INFO    : Bus 74576	: V=1.0301699, theta=-77.274385 -> V=1.0, theta=0.0
% INFO    : Bus 74577	: V=1.0331082, theta=-78.035439 -> V=1.0, theta=0.0
% INFO    : Bus 74578	: V=1.0245293, theta=-81.127635 -> V=1.0, theta=0.0
% INFO    : Bus 74579	: V=1.0335023, theta=-79.526381 -> V=1.0, theta=0.0
% INFO    : Bus 74580	: V=1.0231978, theta=-82.420016 -> V=1.0, theta=0.0
% INFO    : Bus 74581	: V=1.0020015, theta=-72.63146 -> V=1.0, theta=0.0
% INFO    : Bus 74582	: V=1.0069402, theta=-71.83278 -> V=1.0, theta=0.0
% INFO    : Bus 74583	: V=1.010006, theta=-71.179397 -> V=1.0, theta=0.0
% INFO    : Bus 74584	: V=1.005539, theta=-73.17557 -> V=1.0, theta=0.0
% INFO    : Bus 74585	: V=1.0049685, theta=-76.509716 -> V=1.0, theta=0.0
% INFO    : Bus 74586	: V=0.9925248, theta=-79.056882 -> V=1.0, theta=0.0
% INFO    : Bus 74587	: V=0.9753669, theta=-91.571497 -> V=1.0, theta=0.0
% INFO    : Bus 74588	: V=0.9787455, theta=-91.410945 -> V=1.0, theta=0.0
% INFO    : Bus 74589	: V=0.990177, theta=-90.031535 -> V=1.0, theta=0.0
% INFO    : Bus 74590	: V=0.9921029, theta=-89.617426 -> V=1.0, theta=0.0
% INFO    : Bus 74591	: V=0.9831307, theta=-91.105629 -> V=1.0, theta=0.0
% INFO    : Bus 74592	: V=0.9825929, theta=-91.1514 -> V=1.0, theta=0.0
% INFO    : Bus 74593	: V=0.9817395, theta=-91.193705 -> V=1.0, theta=0.0
% INFO    : Bus 74594	: V=0.9812697, theta=-91.179371 -> V=1.0, theta=0.0
% INFO    : Bus 74595	: V=0.9735669, theta=-91.448134 -> V=1.0, theta=0.0
% INFO    : Bus 74596	: V=0.9636048, theta=-84.455758 -> V=1.0, theta=0.0
% INFO    : Bus 74597	: V=0.9616942, theta=-84.49405 -> V=1.0, theta=0.0
% INFO    : Bus 74598	: V=0.9690993, theta=-91.060906 -> V=1.0, theta=0.0
% INFO    : Bus 74599	: V=0.9930622, theta=-89.268569 -> V=1.0, theta=0.0
% INFO    : Bus 74600	: V=1.0100004, theta=-87.930137 -> V=1.0, theta=0.0
% INFO    : Bus 74601	: V=0.9745365, theta=-90.095575 -> V=1.0, theta=0.0
% INFO    : Bus 74602	: V=0.9870252, theta=-89.403486 -> V=1.0, theta=0.0
% INFO    : Bus 74603	: V=0.9937493, theta=-89.047002 -> V=1.0, theta=0.0
% INFO    : Bus 74604	: V=0.9726082, theta=-90.180375 -> V=1.0, theta=0.0
% INFO    : Bus 74605	: V=0.9722284, theta=-90.203273 -> V=1.0, theta=0.0
% INFO    : Bus 74606	: V=0.9694178, theta=-90.002509 -> V=1.0, theta=0.0
% INFO    : Bus 74607	: V=0.9673455, theta=-89.838147 -> V=1.0, theta=0.0
% INFO    : Bus 74608	: V=0.9659682, theta=-87.126906 -> V=1.0, theta=0.0
% INFO    : Bus 74609	: V=0.9666346, theta=-87.54652 -> V=1.0, theta=0.0
% INFO    : Bus 74610	: V=0.9651077, theta=-88.089797 -> V=1.0, theta=0.0
% INFO    : Bus 74611	: V=0.9572186, theta=-90.250321 -> V=1.0, theta=0.0
% INFO    : Bus 74612	: V=0.9599781, theta=-90.21317 -> V=1.0, theta=0.0
% INFO    : Bus 74613	: V=0.9705303, theta=-90.273609 -> V=1.0, theta=0.0
% INFO    : Bus 74614	: V=0.9648404, theta=-90.001685 -> V=1.0, theta=0.0
% INFO    : Bus 74615	: V=0.9680996, theta=-90.283844 -> V=1.0, theta=0.0
% INFO    : Bus 74616	: V=0.9734988, theta=-90.162533 -> V=1.0, theta=0.0
% INFO    : Bus 74617	: V=0.9718053, theta=-90.194626 -> V=1.0, theta=0.0
% INFO    : Bus 74618	: V=0.9714522, theta=-90.20096 -> V=1.0, theta=0.0
% INFO    : Bus 74619	: V=0.9930805, theta=-89.067775 -> V=1.0, theta=0.0
% INFO    : Bus 74620	: V=0.9734551, theta=-90.138544 -> V=1.0, theta=0.0
% INFO    : Bus 74621	: V=0.9718229, theta=-90.132956 -> V=1.0, theta=0.0
% INFO    : Bus 74622	: V=0.9835217, theta=-89.472208 -> V=1.0, theta=0.0
% INFO    : Bus 74623	: V=0.9741046, theta=-89.965914 -> V=1.0, theta=0.0
% INFO    : Bus 74624	: V=0.9837871, theta=-89.646864 -> V=1.0, theta=0.0
% INFO    : Bus 74625	: V=0.9842193, theta=-89.647715 -> V=1.0, theta=0.0
% INFO    : Bus 74626	: V=0.9797801, theta=-89.515013 -> V=1.0, theta=0.0
% INFO    : Bus 74627	: V=0.972821, theta=-89.678592 -> V=1.0, theta=0.0
% INFO    : Bus 74628	: V=0.9720443, theta=-89.682513 -> V=1.0, theta=0.0
% INFO    : Bus 74629	: V=0.9718247, theta=-89.698378 -> V=1.0, theta=0.0
% INFO    : Bus 74630	: V=0.9740753, theta=-89.494918 -> V=1.0, theta=0.0
% INFO    : Bus 74631	: V=0.9718662, theta=-89.706914 -> V=1.0, theta=0.0
% INFO    : Bus 74632	: V=0.9764144, theta=-89.460001 -> V=1.0, theta=0.0
% INFO    : Bus 74633	: V=0.9809101, theta=-88.40052 -> V=1.0, theta=0.0
% INFO    : Bus 74634	: V=0.9644276, theta=-88.839933 -> V=1.0, theta=0.0
% INFO    : Bus 74635	: V=0.9671404, theta=-87.50412 -> V=1.0, theta=0.0
% INFO    : Bus 74636	: V=0.9640957, theta=-88.909618 -> V=1.0, theta=0.0
% INFO    : Bus 74637	: V=0.9951861, theta=-67.59424 -> V=1.0, theta=0.0
% INFO    : Bus 74638	: V=0.9639655, theta=-88.987993 -> V=1.0, theta=0.0
% INFO    : Bus 74639	: V=0.9872186, theta=-87.21739 -> V=1.0, theta=0.0
% INFO    : Bus 74640	: V=0.9754383, theta=-89.490268 -> V=1.0, theta=0.0
% INFO    : Bus 74641	: V=0.9763798, theta=-89.478657 -> V=1.0, theta=0.0
% INFO    : Bus 74642	: V=0.9719289, theta=-89.69734 -> V=1.0, theta=0.0
% INFO    : Bus 74643	: V=0.9714374, theta=-89.704875 -> V=1.0, theta=0.0
% INFO    : Bus 74644	: V=0.9732767, theta=-90.889148 -> V=1.0, theta=0.0
% INFO    : Bus 74645	: V=0.9922065, theta=-86.382621 -> V=1.0, theta=0.0
% INFO    : Bus 74646	: V=0.9602427, theta=-89.592232 -> V=1.0, theta=0.0
% INFO    : Bus 74647	: V=0.9614366, theta=-89.692464 -> V=1.0, theta=0.0
% INFO    : Bus 74648	: V=0.9573988, theta=-90.000168 -> V=1.0, theta=0.0
% INFO    : Bus 74649	: V=0.9565557, theta=-90.08614 -> V=1.0, theta=0.0
% INFO    : Bus 74650	: V=0.9559665, theta=-90.094889 -> V=1.0, theta=0.0
% INFO    : Bus 74651	: V=0.9561052, theta=-90.100449 -> V=1.0, theta=0.0
% INFO    : Bus 74652	: V=0.955396, theta=-90.173045 -> V=1.0, theta=0.0
% INFO    : Bus 74653	: V=0.9550709, theta=-90.171455 -> V=1.0, theta=0.0
% INFO    : Bus 74654	: V=0.954458, theta=-90.186746 -> V=1.0, theta=0.0
% INFO    : Bus 74655	: V=0.9534682, theta=-90.284893 -> V=1.0, theta=0.0
% INFO    : Bus 74656	: V=0.9510286, theta=-90.382596 -> V=1.0, theta=0.0
% INFO    : Bus 74657	: V=0.9532102, theta=-90.295881 -> V=1.0, theta=0.0
% INFO    : Bus 74658	: V=0.9558375, theta=-90.038533 -> V=1.0, theta=0.0
% INFO    : Bus 74659	: V=0.9586823, theta=-89.893293 -> V=1.0, theta=0.0
% INFO    : Bus 74660	: V=0.9832748, theta=-84.177663 -> V=1.0, theta=0.0
% INFO    : Bus 74661	: V=0.9853197, theta=-82.920956 -> V=1.0, theta=0.0
% INFO    : Bus 74662	: V=0.9873599, theta=-82.93983 -> V=1.0, theta=0.0
% INFO    : Bus 74663	: V=0.9679912, theta=-86.010258 -> V=1.0, theta=0.0
% INFO    : Bus 74664	: V=0.9903874, theta=-98.17978 -> V=1.0, theta=0.0
% INFO    : Bus 74665	: V=0.9924227, theta=-98.146675 -> V=1.0, theta=0.0
% INFO    : Bus 74666	: V=1.0017612, theta=-92.832 -> V=1.0, theta=0.0
% INFO    : Bus 74667	: V=0.9940153, theta=-96.716725 -> V=1.0, theta=0.0
% INFO    : Bus 74668	: V=0.9970508, theta=-91.305654 -> V=1.0, theta=0.0
% INFO    : Bus 74669	: V=0.9998754, theta=-94.099801 -> V=1.0, theta=0.0
% INFO    : Bus 74670	: V=0.9948996, theta=-99.81993 -> V=1.0, theta=0.0
% INFO    : Bus 74671	: V=0.9933857, theta=-91.660866 -> V=1.0, theta=0.0
% INFO    : Bus 74672	: V=0.9966301, theta=-100.546708 -> V=1.0, theta=0.0
% INFO    : Bus 74673	: V=1.0026978, theta=-100.902883 -> V=1.0, theta=0.0
% INFO    : Bus 74674	: V=1.001349, theta=-101.089526 -> V=1.0, theta=0.0
% INFO    : Bus 74675	: V=0.9807886, theta=-82.542892 -> V=1.0, theta=0.0
% INFO    : Bus 74676	: V=0.9985727, theta=-82.962739 -> V=1.0, theta=0.0
% INFO    : Bus 74677	: V=0.9836378, theta=-85.045009 -> V=1.0, theta=0.0
% INFO    : Bus 74678	: V=0.9763154, theta=-85.723157 -> V=1.0, theta=0.0
% INFO    : Bus 74679	: V=0.9793683, theta=-85.545128 -> V=1.0, theta=0.0
% INFO    : Bus 74680	: V=0.9796338, theta=-85.380897 -> V=1.0, theta=0.0
% INFO    : Bus 74681	: V=0.9838098, theta=-85.358174 -> V=1.0, theta=0.0
% INFO    : Bus 74682	: V=0.9800609, theta=-85.537174 -> V=1.0, theta=0.0
% INFO    : Bus 74683	: V=0.981141, theta=-85.509611 -> V=1.0, theta=0.0
% INFO    : Bus 74684	: V=0.9808673, theta=-85.520034 -> V=1.0, theta=0.0
% INFO    : Bus 74685	: V=0.978173, theta=-85.667326 -> V=1.0, theta=0.0
% INFO    : Bus 74686	: V=0.9769563, theta=-85.62295 -> V=1.0, theta=0.0
% INFO    : Bus 74687	: V=0.9782065, theta=-85.338059 -> V=1.0, theta=0.0
% INFO    : Bus 74688	: V=0.9799666, theta=-84.793895 -> V=1.0, theta=0.0
% INFO    : Bus 74689	: V=0.9754208, theta=-85.86947 -> V=1.0, theta=0.0
% INFO    : Bus 74690	: V=0.9766504, theta=-85.730326 -> V=1.0, theta=0.0
% INFO    : Bus 74691	: V=0.9757914, theta=-85.852046 -> V=1.0, theta=0.0
% INFO    : Bus 74692	: V=0.9770367, theta=-85.785332 -> V=1.0, theta=0.0
% INFO    : Bus 74693	: V=0.9881369, theta=-84.322874 -> V=1.0, theta=0.0
% INFO    : Bus 74694	: V=0.9875783, theta=-84.799121 -> V=1.0, theta=0.0
% INFO    : Bus 74695	: V=0.9838198, theta=-85.288767 -> V=1.0, theta=0.0
% INFO    : Bus 74696	: V=1.0009452, theta=-84.067487 -> V=1.0, theta=0.0
% INFO    : Bus 74697	: V=0.9896029, theta=-84.318247 -> V=1.0, theta=0.0
% INFO    : Bus 74698	: V=0.9889915, theta=-84.315868 -> V=1.0, theta=0.0
% INFO    : Bus 74699	: V=0.9880516, theta=-84.788513 -> V=1.0, theta=0.0
% INFO    : Bus 74700	: V=0.9973827, theta=-84.172518 -> V=1.0, theta=0.0
% INFO    : Bus 74701	: V=0.9992259, theta=-84.140934 -> V=1.0, theta=0.0
% INFO    : Bus 74702	: V=0.9982504, theta=-84.166629 -> V=1.0, theta=0.0
% INFO    : Bus 74703	: V=0.9977476, theta=-84.171766 -> V=1.0, theta=0.0
% INFO    : Bus 74704	: V=0.986877, theta=-84.78476 -> V=1.0, theta=0.0
% INFO    : Bus 74705	: V=0.9910541, theta=-84.741749 -> V=1.0, theta=0.0
% INFO    : Bus 74706	: V=0.9896573, theta=-84.739641 -> V=1.0, theta=0.0
% INFO    : Bus 74707	: V=0.9866247, theta=-84.78733 -> V=1.0, theta=0.0
% INFO    : Bus 74708	: V=0.9875001, theta=-84.775242 -> V=1.0, theta=0.0
% INFO    : Bus 74709	: V=0.9863731, theta=-84.777531 -> V=1.0, theta=0.0
% INFO    : Bus 74710	: V=0.9933169, theta=-84.602244 -> V=1.0, theta=0.0
% INFO    : Bus 74711	: V=1.0001401, theta=-84.16882 -> V=1.0, theta=0.0
% INFO    : Bus 74712	: V=0.9995969, theta=-84.183058 -> V=1.0, theta=0.0
% INFO    : Bus 74713	: V=0.9994328, theta=-84.186746 -> V=1.0, theta=0.0
% INFO    : Bus 74714	: V=1.0004936, theta=-84.157598 -> V=1.0, theta=0.0
% INFO    : Bus 74715	: V=1.0022462, theta=-84.090427 -> V=1.0, theta=0.0
% INFO    : Bus 74716	: V=0.9926692, theta=-84.629937 -> V=1.0, theta=0.0
% INFO    : Bus 74717	: V=0.9902085, theta=-84.699437 -> V=1.0, theta=0.0
% INFO    : Bus 74718	: V=1.0100003, theta=-83.459723 -> V=1.0, theta=0.0
% INFO    : Bus 74719	: V=1.0048491, theta=-83.865519 -> V=1.0, theta=0.0
% INFO    : Bus 74720	: V=1.0183183, theta=-83.464349 -> V=1.0, theta=0.0
% INFO    : Bus 74721	: V=1.0032939, theta=-83.87532 -> V=1.0, theta=0.0
% INFO    : Bus 74722	: V=1.003735, theta=-83.87417 -> V=1.0, theta=0.0
% INFO    : Bus 74723	: V=0.9952176, theta=-84.128758 -> V=1.0, theta=0.0
% INFO    : Bus 74724	: V=0.9968123, theta=-84.10423 -> V=1.0, theta=0.0
% INFO    : Bus 74725	: V=1.0026279, theta=-83.872617 -> V=1.0, theta=0.0
% INFO    : Bus 74726	: V=1.0004038, theta=-83.686897 -> V=1.0, theta=0.0
% INFO    : Bus 74727	: V=1.0005522, theta=-83.988389 -> V=1.0, theta=0.0
% INFO    : Bus 74728	: V=1.0034359, theta=-84.015611 -> V=1.0, theta=0.0
% INFO    : Bus 74729	: V=1.0006506, theta=-83.933196 -> V=1.0, theta=0.0
% INFO    : Bus 74730	: V=1.0088919, theta=-83.830902 -> V=1.0, theta=0.0
% INFO    : Bus 74731	: V=0.9921061, theta=-83.959929 -> V=1.0, theta=0.0
% INFO    : Bus 74732	: V=0.9997021, theta=-84.006117 -> V=1.0, theta=0.0
% INFO    : Bus 74733	: V=0.998982, theta=-83.924655 -> V=1.0, theta=0.0
% INFO    : Bus 74734	: V=0.9984944, theta=-84.007286 -> V=1.0, theta=0.0
% INFO    : Bus 74735	: V=0.9967694, theta=-84.072777 -> V=1.0, theta=0.0
% INFO    : Bus 74736	: V=0.9987852, theta=-84.004775 -> V=1.0, theta=0.0
% INFO    : Bus 74737	: V=0.9991696, theta=-83.987425 -> V=1.0, theta=0.0
% INFO    : Bus 74738	: V=0.9996567, theta=-83.974383 -> V=1.0, theta=0.0
% INFO    : Bus 74739	: V=1.0025928, theta=-84.008644 -> V=1.0, theta=0.0
% INFO    : Bus 74740	: V=0.9989845, theta=-83.980019 -> V=1.0, theta=0.0
% INFO    : Bus 74741	: V=1.0042553, theta=-84.043465 -> V=1.0, theta=0.0
% INFO    : Bus 74742	: V=1.0018783, theta=-83.95419 -> V=1.0, theta=0.0
% INFO    : Bus 74743	: V=1.008635, theta=-83.665589 -> V=1.0, theta=0.0
% INFO    : Bus 74744	: V=1.0008433, theta=-83.950793 -> V=1.0, theta=0.0
% INFO    : Bus 74745	: V=1.0088482, theta=-83.711501 -> V=1.0, theta=0.0
% INFO    : Bus 74746	: V=1.0300003, theta=-81.927885 -> V=1.0, theta=0.0
% INFO    : Bus 74747	: V=0.9990966, theta=-83.947498 -> V=1.0, theta=0.0
% INFO    : Bus 74748	: V=0.9995448, theta=-84.020044 -> V=1.0, theta=0.0
% INFO    : Bus 74749	: V=0.9989807, theta=-84.011931 -> V=1.0, theta=0.0
% INFO    : Bus 74750	: V=1.0010685, theta=-83.996923 -> V=1.0, theta=0.0
% INFO    : Bus 74751	: V=0.9969064, theta=-84.086703 -> V=1.0, theta=0.0
% INFO    : Bus 74752	: V=0.9989521, theta=-84.032388 -> V=1.0, theta=0.0
% INFO    : Bus 74753	: V=1.0033573, theta=-83.817806 -> V=1.0, theta=0.0
% INFO    : Bus 74754	: V=1.0025595, theta=-83.887763 -> V=1.0, theta=0.0
% INFO    : Bus 74755	: V=0.9976572, theta=-84.117125 -> V=1.0, theta=0.0
% INFO    : Bus 74756	: V=0.9972945, theta=-84.14793 -> V=1.0, theta=0.0
% INFO    : Bus 74757	: V=0.9972302, theta=-84.159391 -> V=1.0, theta=0.0
% INFO    : Bus 74758	: V=0.9874993, theta=-84.908894 -> V=1.0, theta=0.0
% INFO    : Bus 74759	: V=0.9917729, theta=-84.566634 -> V=1.0, theta=0.0
% INFO    : Bus 74760	: V=1.0010957, theta=-83.879663 -> V=1.0, theta=0.0
% INFO    : Bus 74761	: V=1.0002953, theta=-83.932266 -> V=1.0, theta=0.0
% INFO    : Bus 74762	: V=0.9993143, theta=-83.998948 -> V=1.0, theta=0.0
% INFO    : Bus 74763	: V=1.0062057, theta=-83.404057 -> V=1.0, theta=0.0
% INFO    : Bus 74764	: V=0.9962088, theta=-84.15524 -> V=1.0, theta=0.0
% INFO    : Bus 74765	: V=0.9957952, theta=-84.148871 -> V=1.0, theta=0.0
% INFO    : Bus 74766	: V=0.9965383, theta=-84.162668 -> V=1.0, theta=0.0
% INFO    : Bus 74767	: V=1.0068171, theta=-83.362614 -> V=1.0, theta=0.0
% INFO    : Bus 74768	: V=0.9973182, theta=-84.190572 -> V=1.0, theta=0.0
% INFO    : Bus 74769	: V=0.9983622, theta=-84.123773 -> V=1.0, theta=0.0
% INFO    : Bus 74770	: V=1.0012745, theta=-83.8929 -> V=1.0, theta=0.0
% INFO    : Bus 74771	: V=0.9965001, theta=-84.231567 -> V=1.0, theta=0.0
% INFO    : Bus 74772	: V=0.9960778, theta=-84.261571 -> V=1.0, theta=0.0
% INFO    : Bus 74773	: V=1.0009216, theta=-83.754348 -> V=1.0, theta=0.0
% INFO    : Bus 74774	: V=0.9982494, theta=-83.810206 -> V=1.0, theta=0.0
% INFO    : Bus 74775	: V=0.994337, theta=-84.16671 -> V=1.0, theta=0.0
% INFO    : Bus 74776	: V=0.9942259, theta=-84.17168 -> V=1.0, theta=0.0
% INFO    : Bus 74777	: V=0.9952894, theta=-84.149024 -> V=1.0, theta=0.0
% INFO    : Bus 74778	: V=1.0017237, theta=-83.733244 -> V=1.0, theta=0.0
% INFO    : Bus 74779	: V=1.0012756, theta=-83.743314 -> V=1.0, theta=0.0
% INFO    : Bus 74780	: V=0.9973259, theta=-84.10234 -> V=1.0, theta=0.0
% INFO    : Bus 74781	: V=0.9972904, theta=-84.102056 -> V=1.0, theta=0.0
% INFO    : Bus 74782	: V=0.9964265, theta=-84.12452 -> V=1.0, theta=0.0
% INFO    : Bus 74783	: V=0.9978685, theta=-84.074135 -> V=1.0, theta=0.0
% INFO    : Bus 74784	: V=0.9961586, theta=-84.133221 -> V=1.0, theta=0.0
% INFO    : Bus 74785	: V=1.0273514, theta=-81.817623 -> V=1.0, theta=0.0
% INFO    : Bus 74786	: V=1.0045612, theta=-83.548456 -> V=1.0, theta=0.0
% INFO    : Bus 74787	: V=0.9965738, theta=-84.10708 -> V=1.0, theta=0.0
% INFO    : Bus 74788	: V=0.9956442, theta=-84.12359 -> V=1.0, theta=0.0
% INFO    : Bus 74789	: V=0.9951909, theta=-84.10663 -> V=1.0, theta=0.0
% INFO    : Bus 74790	: V=0.995718, theta=-84.133972 -> V=1.0, theta=0.0
% INFO    : Bus 74791	: V=0.9953633, theta=-84.121784 -> V=1.0, theta=0.0
% INFO    : Bus 74792	: V=0.9967922, theta=-84.119057 -> V=1.0, theta=0.0
% INFO    : Bus 74793	: V=0.9965308, theta=-84.120429 -> V=1.0, theta=0.0
% INFO    : Bus 74794	: V=1.0031667, theta=-83.666483 -> V=1.0, theta=0.0
% INFO    : Bus 74795	: V=1.0028045, theta=-83.687689 -> V=1.0, theta=0.0
% INFO    : Bus 74796	: V=1.0025116, theta=-83.704091 -> V=1.0, theta=0.0
% INFO    : Bus 74797	: V=0.9973795, theta=-84.107831 -> V=1.0, theta=0.0
% INFO    : Bus 74798	: V=1.0100003, theta=-83.195576 -> V=1.0, theta=0.0
% INFO    : Bus 74799	: V=0.9934654, theta=-84.155997 -> V=1.0, theta=0.0
% INFO    : Bus 74800	: V=1.0032272, theta=-83.669627 -> V=1.0, theta=0.0
% INFO    : Bus 74801	: V=0.9989513, theta=-83.995426 -> V=1.0, theta=0.0
% INFO    : Bus 74802	: V=0.9982668, theta=-83.999297 -> V=1.0, theta=0.0
% INFO    : Bus 74803	: V=0.997967, theta=-84.038775 -> V=1.0, theta=0.0
% INFO    : Bus 74804	: V=0.9995631, theta=-83.736747 -> V=1.0, theta=0.0
% INFO    : Bus 74805	: V=0.9942023, theta=-84.230549 -> V=1.0, theta=0.0
% INFO    : Bus 74806	: V=0.9989075, theta=-83.771047 -> V=1.0, theta=0.0
% INFO    : Bus 74807	: V=0.9954502, theta=-84.099747 -> V=1.0, theta=0.0
% INFO    : Bus 74808	: V=0.9961195, theta=-84.108066 -> V=1.0, theta=0.0
% INFO    : Bus 74809	: V=0.9958931, theta=-84.101158 -> V=1.0, theta=0.0
% INFO    : Bus 74810	: V=0.9966064, theta=-84.037826 -> V=1.0, theta=0.0
% INFO    : Bus 74811	: V=0.994468, theta=-84.039609 -> V=1.0, theta=0.0
% INFO    : Bus 74812	: V=0.9993144, theta=-83.748613 -> V=1.0, theta=0.0
% INFO    : Bus 74813	: V=0.9969891, theta=-84.000899 -> V=1.0, theta=0.0
% INFO    : Bus 74814	: V=0.9912007, theta=-84.204056 -> V=1.0, theta=0.0
% INFO    : Bus 74815	: V=0.9918149, theta=-84.220914 -> V=1.0, theta=0.0
% INFO    : Bus 74816	: V=0.9911031, theta=-84.1967 -> V=1.0, theta=0.0
% INFO    : Bus 74817	: V=0.992238, theta=-84.180983 -> V=1.0, theta=0.0
% INFO    : Bus 74818	: V=0.9914182, theta=-84.195493 -> V=1.0, theta=0.0
% INFO    : Bus 74819	: V=0.9911728, theta=-84.213193 -> V=1.0, theta=0.0
% INFO    : Bus 74820	: V=0.9946978, theta=-84.106344 -> V=1.0, theta=0.0
% INFO    : Bus 74821	: V=0.9933585, theta=-84.082493 -> V=1.0, theta=0.0
% INFO    : Bus 74822	: V=1.0100935, theta=-82.585625 -> V=1.0, theta=0.0
% INFO    : Bus 74823	: V=0.9962423, theta=-84.136301 -> V=1.0, theta=0.0
% INFO    : Bus 74824	: V=1.0004141, theta=-83.680745 -> V=1.0, theta=0.0
% INFO    : Bus 74825	: V=0.9956567, theta=-84.102954 -> V=1.0, theta=0.0
% INFO    : Bus 74826	: V=0.9995992, theta=-83.722345 -> V=1.0, theta=0.0
% INFO    : Bus 74827	: V=0.9967562, theta=-84.161429 -> V=1.0, theta=0.0
% INFO    : Bus 74828	: V=0.993939, theta=-84.023247 -> V=1.0, theta=0.0
% INFO    : Bus 74829	: V=0.9968511, theta=-84.146744 -> V=1.0, theta=0.0
% INFO    : Bus 74830	: V=0.9975183, theta=-84.100488 -> V=1.0, theta=0.0
% INFO    : Bus 74831	: V=0.9989326, theta=-83.749036 -> V=1.0, theta=0.0
% INFO    : Bus 74832	: V=0.9981945, theta=-83.78477 -> V=1.0, theta=0.0
% INFO    : Bus 74833	: V=0.9945097, theta=-83.985683 -> V=1.0, theta=0.0
% INFO    : Bus 74834	: V=0.9977671, theta=-83.818642 -> V=1.0, theta=0.0
% INFO    : Bus 74835	: V=0.9962735, theta=-83.95351 -> V=1.0, theta=0.0
% INFO    : Bus 74836	: V=0.9978561, theta=-83.815914 -> V=1.0, theta=0.0
% INFO    : Bus 74837	: V=0.996111, theta=-83.832506 -> V=1.0, theta=0.0
% INFO    : Bus 74838	: V=0.9957014, theta=-83.944766 -> V=1.0, theta=0.0
% INFO    : Bus 74839	: V=0.9944007, theta=-83.957198 -> V=1.0, theta=0.0
% INFO    : Bus 74840	: V=0.9972369, theta=-83.654965 -> V=1.0, theta=0.0
% INFO    : Bus 74841	: V=0.9948216, theta=-83.979107 -> V=1.0, theta=0.0
% INFO    : Bus 74842	: V=1.0001427, theta=-83.836306 -> V=1.0, theta=0.0
% INFO    : Bus 74843	: V=0.9990959, theta=-83.837368 -> V=1.0, theta=0.0
% INFO    : Bus 74844	: V=1.0013758, theta=-83.992189 -> V=1.0, theta=0.0
% INFO    : Bus 74845	: V=0.9987847, theta=-83.991654 -> V=1.0, theta=0.0
% INFO    : Bus 74846	: V=1.0022281, theta=-83.861267 -> V=1.0, theta=0.0
% INFO    : Bus 74847	: V=0.976638, theta=-85.35341 -> V=1.0, theta=0.0
% INFO    : Bus 74848	: V=1.0049978, theta=-99.901997 -> V=1.0, theta=0.0
% INFO    : Bus 74849	: V=1.002502, theta=-98.829103 -> V=1.0, theta=0.0
% INFO    : Bus 74850	: V=1.009463, theta=-97.956746 -> V=1.0, theta=0.0
% INFO    : Bus 74851	: V=1.0100004, theta=-98.052519 -> V=1.0, theta=0.0
% INFO    : Bus 74852	: V=1.0078569, theta=-99.853977 -> V=1.0, theta=0.0
% INFO    : Bus 74853	: V=1.0085088, theta=-100.411544 -> V=1.0, theta=0.0
% INFO    : Bus 74854	: V=1.0083892, theta=-99.514584 -> V=1.0, theta=0.0
% INFO    : Bus 74855	: V=1.0078299, theta=-100.436797 -> V=1.0, theta=0.0
% INFO    : Bus 74856	: V=1.0008632, theta=-101.023714 -> V=1.0, theta=0.0
% INFO    : Bus 74857	: V=1.0061746, theta=-100.813722 -> V=1.0, theta=0.0
% INFO    : Bus 74858	: V=1.0031364, theta=-102.521977 -> V=1.0, theta=0.0
% INFO    : Bus 74859	: V=1.0006016, theta=-100.027955 -> V=1.0, theta=0.0
% INFO    : Bus 74860	: V=1.0021125, theta=-102.40885 -> V=1.0, theta=0.0
% INFO    : Bus 74861	: V=1.001445, theta=-102.022107 -> V=1.0, theta=0.0
% INFO    : Bus 74862	: V=1.001668, theta=-101.839944 -> V=1.0, theta=0.0
% INFO    : Bus 74863	: V=1.0011112, theta=-102.265955 -> V=1.0, theta=0.0
% INFO    : Bus 74864	: V=1.0019542, theta=-102.325209 -> V=1.0, theta=0.0
% INFO    : Bus 74865	: V=1.002317, theta=-102.400444 -> V=1.0, theta=0.0
% INFO    : Bus 74866	: V=1.0011234, theta=-102.053074 -> V=1.0, theta=0.0
% INFO    : Bus 74867	: V=0.999506, theta=-102.13934 -> V=1.0, theta=0.0
% INFO    : Bus 74868	: V=1.0003931, theta=-102.106177 -> V=1.0, theta=0.0
% INFO    : Bus 74869	: V=1.0005981, theta=-102.047938 -> V=1.0, theta=0.0
% INFO    : Bus 74870	: V=1.0011829, theta=-102.025992 -> V=1.0, theta=0.0
% INFO    : Bus 74871	: V=1.0011311, theta=-102.115361 -> V=1.0, theta=0.0
% INFO    : Bus 74872	: V=1.0015725, theta=-102.244861 -> V=1.0, theta=0.0
% INFO    : Bus 74873	: V=1.0012415, theta=-102.152195 -> V=1.0, theta=0.0
% INFO    : Bus 74874	: V=1.0014609, theta=-98.655701 -> V=1.0, theta=0.0
% INFO    : Bus 74875	: V=1.0016399, theta=-98.533027 -> V=1.0, theta=0.0
% INFO    : Bus 74876	: V=1.0015689, theta=-98.59735 -> V=1.0, theta=0.0
% INFO    : Bus 74877	: V=1.0004537, theta=-99.623341 -> V=1.0, theta=0.0
% INFO    : Bus 74878	: V=1.0000856, theta=-99.637185 -> V=1.0, theta=0.0
% INFO    : Bus 74879	: V=1.0046434, theta=-100.160426 -> V=1.0, theta=0.0
% INFO    : Bus 74880	: V=1.0049736, theta=-100.148164 -> V=1.0, theta=0.0
% INFO    : Bus 74881	: V=1.0054791, theta=-100.266302 -> V=1.0, theta=0.0
% INFO    : Bus 74882	: V=0.9999219, theta=-99.644697 -> V=1.0, theta=0.0
% INFO    : Bus 74883	: V=1.0043133, theta=-100.174986 -> V=1.0, theta=0.0
% INFO    : Bus 74884	: V=1.0037702, theta=-99.870806 -> V=1.0, theta=0.0
% INFO    : Bus 74885	: V=1.0018232, theta=-99.524342 -> V=1.0, theta=0.0
% INFO    : Bus 74886	: V=0.9944485, theta=-104.490383 -> V=1.0, theta=0.0
% INFO    : Bus 74887	: V=1.0037465, theta=-96.361984 -> V=1.0, theta=0.0
% INFO    : Bus 74888	: V=0.9991288, theta=-95.563116 -> V=1.0, theta=0.0
% INFO    : Bus 74889	: V=1.0103064, theta=-91.22304 -> V=1.0, theta=0.0
% INFO    : Bus 74890	: V=1.0103889, theta=-90.545926 -> V=1.0, theta=0.0
% INFO    : Bus 74891	: V=1.0095521, theta=-91.499959 -> V=1.0, theta=0.0
% INFO    : Bus 74892	: V=1.0099602, theta=-91.472476 -> V=1.0, theta=0.0
% INFO    : Bus 74893	: V=1.009289, theta=-91.575766 -> V=1.0, theta=0.0
% INFO    : Bus 74894	: V=1.0094521, theta=-91.358118 -> V=1.0, theta=0.0
% INFO    : Bus 74895	: V=1.0089016, theta=-91.695797 -> V=1.0, theta=0.0
% INFO    : Bus 74896	: V=1.0086067, theta=-91.990053 -> V=1.0, theta=0.0
% INFO    : Bus 74897	: V=1.0076167, theta=-93.062424 -> V=1.0, theta=0.0
% INFO    : Bus 74898	: V=1.0090728, theta=-93.270812 -> V=1.0, theta=0.0
% INFO    : Bus 74899	: V=1.0074409, theta=-91.645313 -> V=1.0, theta=0.0
% INFO    : Bus 74900	: V=1.0120509, theta=-92.403781 -> V=1.0, theta=0.0
% INFO    : Bus 74901	: V=1.0108347, theta=-88.383848 -> V=1.0, theta=0.0
% INFO    : Bus 74902	: V=1.0095003, theta=-87.324904 -> V=1.0, theta=0.0
% INFO    : Bus 75433	: V=1.0122923, theta=12.587654 -> V=1.0, theta=0.0
% INFO    : Bus 75434	: V=1.0100005, theta=12.732452 -> V=1.0, theta=0.0
% INFO    : Bus 75435	: V=1.0099992, theta=12.601552 -> V=1.0, theta=0.0
% INFO    : Bus 75436	: V=1.028085, theta=12.787812 -> V=1.0, theta=0.0
% INFO    : Bus 75437	: V=1.0232943, theta=16.062316 -> V=1.0, theta=0.0
% INFO    : Bus 75438	: V=1.0328128, theta=16.653217 -> V=1.0, theta=0.0
% INFO    : Bus 75439	: V=1.0320564, theta=16.702489 -> V=1.0, theta=0.0
% INFO    : Bus 75440	: V=1.0230727, theta=16.729498 -> V=1.0, theta=0.0
% INFO    : Bus 75441	: V=1.0231249, theta=16.721559 -> V=1.0, theta=0.0
% INFO    : Bus 75442	: V=1.0296831, theta=20.472455 -> V=1.0, theta=0.0
% INFO    : Bus 75443	: V=1.0285684, theta=20.152012 -> V=1.0, theta=0.0
% INFO    : Bus 75444	: V=1.0188137, theta=16.04845 -> V=1.0, theta=0.0
% INFO    : Bus 75445	: V=1.0228713, theta=14.547066 -> V=1.0, theta=0.0
% INFO    : Bus 75446	: V=1.0082978, theta=17.550001 -> V=1.0, theta=0.0
% INFO    : Bus 75447	: V=1.0236212, theta=18.405341 -> V=1.0, theta=0.0
% INFO    : Bus 75448	: V=1.0243733, theta=18.300161 -> V=1.0, theta=0.0
% INFO    : Bus 75449	: V=1.0312773, theta=16.4489 -> V=1.0, theta=0.0
% INFO    : Bus 75450	: V=1.0322512, theta=16.19794 -> V=1.0, theta=0.0
% INFO    : Bus 75451	: V=1.0167735, theta=12.420055 -> V=1.0, theta=0.0
% INFO    : Bus 75452	: V=1.0190346, theta=12.525292 -> V=1.0, theta=0.0
% INFO    : Bus 75453	: V=1.0091408, theta=14.982292 -> V=1.0, theta=0.0
% INFO    : Bus 75454	: V=1.0145334, theta=12.703363 -> V=1.0, theta=0.0
% INFO    : Bus 75455	: V=1.0247311, theta=11.014214 -> V=1.0, theta=0.0
% INFO    : Bus 75456	: V=1.0224765, theta=16.372474 -> V=1.0, theta=0.0
% INFO    : Bus 75457	: V=1.0395846, theta=12.587705 -> V=1.0, theta=0.0
% INFO    : Bus 75458	: V=1.0394038, theta=12.21329 -> V=1.0, theta=0.0
% INFO    : Bus 75459	: V=1.0216326, theta=11.043474 -> V=1.0, theta=0.0
% INFO    : Bus 75460	: V=1.0266149, theta=14.370863 -> V=1.0, theta=0.0
% INFO    : Bus 75461	: V=1.023731, theta=14.623485 -> V=1.0, theta=0.0
% INFO    : Bus 75462	: V=1.0237236, theta=14.623339 -> V=1.0, theta=0.0
% INFO    : Bus 75463	: V=1.0432073, theta=14.190733 -> V=1.0, theta=0.0
% INFO    : Bus 75464	: V=1.0407991, theta=14.258646 -> V=1.0, theta=0.0
% INFO    : Bus 75465	: V=1.0219771, theta=16.042714 -> V=1.0, theta=0.0
% INFO    : Bus 75466	: V=1.0265308, theta=7.905128 -> V=1.0, theta=0.0
% INFO    : Bus 75467	: V=1.024944, theta=7.568717 -> V=1.0, theta=0.0
% INFO    : Bus 75468	: V=1.025353, theta=7.364999 -> V=1.0, theta=0.0
% INFO    : Bus 75469	: V=1.0178851, theta=24.019675 -> V=1.0, theta=0.0
% INFO    : Bus 75470	: V=1.0128681, theta=-0.433823 -> V=1.0, theta=0.0
% INFO    : Bus 75471	: V=1.02038, theta=24.448842 -> V=1.0, theta=0.0
% INFO    : Bus 75472	: V=1.0209051, theta=24.454431 -> V=1.0, theta=0.0
% INFO    : Bus 75473	: V=1.0212325, theta=24.544852 -> V=1.0, theta=0.0
% INFO    : Bus 75474	: V=1.0132146, theta=23.759774 -> V=1.0, theta=0.0
% INFO    : Bus 75475	: V=1.0185754, theta=23.466231 -> V=1.0, theta=0.0
% INFO    : Bus 75476	: V=1.0201118, theta=-59.841881 -> V=1.0, theta=0.0
% INFO    : Bus 75477	: V=1.0185694, theta=-59.492434 -> V=1.0, theta=0.0
% INFO    : Bus 75478	: V=1.0268596, theta=19.014124 -> V=1.0, theta=0.0
% INFO    : Bus 75479	: V=1.0271758, theta=18.860559 -> V=1.0, theta=0.0
% INFO    : Bus 75480	: V=1.0228621, theta=12.714876 -> V=1.0, theta=0.0
% INFO    : Bus 75481	: V=1.0230519, theta=19.831669 -> V=1.0, theta=0.0
% INFO    : Bus 75482	: V=1.0200006, theta=20.70599 -> V=1.0, theta=0.0
% INFO    : Bus 75483	: V=1.0195071, theta=21.677734 -> V=1.0, theta=0.0
% INFO    : Bus 75484	: V=1.0202891, theta=21.542268 -> V=1.0, theta=0.0
% INFO    : Bus 75485	: V=1.0085293, theta=-7.151754 -> V=1.0, theta=0.0
% INFO    : Bus 75486	: V=1.0240329, theta=19.14644 -> V=1.0, theta=0.0
% INFO    : Bus 75487	: V=1.0269918, theta=14.03154 -> V=1.0, theta=0.0
% INFO    : Bus 75488	: V=1.0265051, theta=13.933848 -> V=1.0, theta=0.0
% INFO    : Bus 75489	: V=1.0137317, theta=20.839909 -> V=1.0, theta=0.0
% INFO    : Bus 75490	: V=1.0200006, theta=20.011751 -> V=1.0, theta=0.0
% INFO    : Bus 75491	: V=1.0158284, theta=19.560192 -> V=1.0, theta=0.0
% INFO    : Bus 75492	: V=1.0228116, theta=19.165406 -> V=1.0, theta=0.0
% INFO    : Bus 75493	: V=1.0257389, theta=22.990181 -> V=1.0, theta=0.0
% INFO    : Bus 75494	: V=1.0211875, theta=23.72209 -> V=1.0, theta=0.0
% INFO    : Bus 75495	: V=1.0226246, theta=23.429903 -> V=1.0, theta=0.0
% INFO    : Bus 75496	: V=1.0150364, theta=0.364746 -> V=1.0, theta=0.0
% INFO    : Bus 75497	: V=1.0104899, theta=-20.034427 -> V=1.0, theta=0.0
% INFO    : Bus 75498	: V=1.0000006, theta=-34.865377 -> V=1.0, theta=0.0
% INFO    : Bus 75499	: V=1.0222453, theta=-5.753427 -> V=1.0, theta=0.0
% INFO    : Bus 75500	: V=1.0262852, theta=12.449028 -> V=1.0, theta=0.0
% INFO    : Bus 75501	: V=1.0278239, theta=12.533367 -> V=1.0, theta=0.0
% INFO    : Bus 75502	: V=1.0126718, theta=-39.461242 -> V=1.0, theta=0.0
% INFO    : Bus 75503	: V=1.0087536, theta=-58.443412 -> V=1.0, theta=0.0
% INFO    : Bus 75504	: V=1.0114844, theta=-14.723129 -> V=1.0, theta=0.0
% INFO    : Bus 75505	: V=1.0110068, theta=-5.773041 -> V=1.0, theta=0.0
% INFO    : Bus 75506	: V=1.0170882, theta=-59.467581 -> V=1.0, theta=0.0
% INFO    : Bus 75507	: V=1.0170331, theta=-59.560211 -> V=1.0, theta=0.0
% INFO    : Bus 75508	: V=1.023522, theta=19.371999 -> V=1.0, theta=0.0
% INFO    : Bus 75509	: V=1.0244628, theta=44.285118 -> V=1.0, theta=0.0
% INFO    : Bus 75510	: V=1.0246003, theta=44.14253 -> V=1.0, theta=0.0
% INFO    : Bus 75511	: V=1.0154835, theta=23.766692 -> V=1.0, theta=0.0
% INFO    : Bus 75512	: V=1.0103924, theta=22.286669 -> V=1.0, theta=0.0
% INFO    : Bus 75513	: V=1.0108363, theta=22.133364 -> V=1.0, theta=0.0
% INFO    : Bus 75514	: V=1.0235229, theta=3.93865 -> V=1.0, theta=0.0
% INFO    : Bus 75515	: V=1.0231438, theta=3.27366 -> V=1.0, theta=0.0
% INFO    : Bus 75516	: V=1.024161, theta=19.554016 -> V=1.0, theta=0.0
% INFO    : Bus 75517	: V=1.0256816, theta=19.696412 -> V=1.0, theta=0.0
% INFO    : Bus 75518	: V=1.0100007, theta=-0.022382 -> V=1.0, theta=0.0
% INFO    : Bus 75519	: V=1.0101734, theta=-0.551881 -> V=1.0, theta=0.0
% INFO    : Bus 75520	: V=1.0193347, theta=2.670589 -> V=1.0, theta=0.0
% INFO    : Bus 75521	: V=1.0194977, theta=2.191093 -> V=1.0, theta=0.0
% INFO    : Bus 75522	: V=1.0126799, theta=20.552131 -> V=1.0, theta=0.0
% INFO    : Bus 75523	: V=1.010513, theta=-0.711674 -> V=1.0, theta=0.0
% INFO    : Bus 75524	: V=1.0101568, theta=0.66804 -> V=1.0, theta=0.0
% INFO    : Bus 75525	: V=1.022923, theta=22.168229 -> V=1.0, theta=0.0
% INFO    : Bus 75526	: V=1.0247374, theta=22.059276 -> V=1.0, theta=0.0
% INFO    : Bus 75527	: V=1.0299926, theta=-1.962671 -> V=1.0, theta=0.0
% INFO    : Bus 75528	: V=1.0292784, theta=-2.014986 -> V=1.0, theta=0.0
% INFO    : Bus 75529	: V=1.0200007, theta=16.909394 -> V=1.0, theta=0.0
% INFO    : Bus 75530	: V=1.0197766, theta=22.427101 -> V=1.0, theta=0.0
% INFO    : Bus 75531	: V=1.0192741, theta=22.524111 -> V=1.0, theta=0.0
% INFO    : Bus 75532	: V=1.0172323, theta=2.198589 -> V=1.0, theta=0.0
% INFO    : Bus 75533	: V=1.0180142, theta=2.260676 -> V=1.0, theta=0.0
% INFO    : Bus 75534	: V=1.0200006, theta=21.698334 -> V=1.0, theta=0.0
% INFO    : Bus 75535	: V=1.0148225, theta=16.818796 -> V=1.0, theta=0.0
% INFO    : Bus 75536	: V=1.0219899, theta=23.264673 -> V=1.0, theta=0.0
% INFO    : Bus 75537	: V=1.0248853, theta=24.136579 -> V=1.0, theta=0.0
% INFO    : Bus 75538	: V=1.0261479, theta=23.936866 -> V=1.0, theta=0.0
% INFO    : Bus 75539	: V=1.0157758, theta=20.758305 -> V=1.0, theta=0.0
% INFO    : Bus 75540	: V=1.0242269, theta=14.78163 -> V=1.0, theta=0.0
% INFO    : Bus 75541	: V=1.020852, theta=15.032542 -> V=1.0, theta=0.0
% INFO    : Bus 75542	: V=1.0212, theta=14.864564 -> V=1.0, theta=0.0
% INFO    : Bus 75543	: V=1.0116471, theta=15.16759 -> V=1.0, theta=0.0
% INFO    : Bus 75544	: V=1.0247352, theta=22.736678 -> V=1.0, theta=0.0
% INFO    : Bus 75545	: V=1.022345, theta=22.581149 -> V=1.0, theta=0.0
% INFO    : Bus 75546	: V=1.010016, theta=3.719693 -> V=1.0, theta=0.0
% INFO    : Bus 75547	: V=1.0241933, theta=20.786384 -> V=1.0, theta=0.0
% INFO    : Bus 75548	: V=1.0223155, theta=20.461939 -> V=1.0, theta=0.0
% INFO    : Bus 75549	: V=1.0215398, theta=20.282614 -> V=1.0, theta=0.0
% INFO    : Bus 75550	: V=1.0176261, theta=22.358645 -> V=1.0, theta=0.0
% INFO    : Bus 75551	: V=1.0190003, theta=22.125308 -> V=1.0, theta=0.0
% INFO    : Bus 75552	: V=1.0246631, theta=10.715192 -> V=1.0, theta=0.0
% INFO    : Bus 75553	: V=1.0118391, theta=18.500678 -> V=1.0, theta=0.0
% INFO    : Bus 75554	: V=1.0290563, theta=22.665035 -> V=1.0, theta=0.0
% INFO    : Bus 75555	: V=1.0071753, theta=2.121666 -> V=1.0, theta=0.0
% INFO    : Bus 75556	: V=1.0238332, theta=22.173063 -> V=1.0, theta=0.0
% INFO    : Bus 75557	: V=1.0212398, theta=21.963477 -> V=1.0, theta=0.0
% INFO    : Bus 75558	: V=1.0207083, theta=21.93501 -> V=1.0, theta=0.0
% INFO    : Bus 75559	: V=1.0200006, theta=20.779811 -> V=1.0, theta=0.0
% INFO    : Bus 75560	: V=1.0194945, theta=20.657084 -> V=1.0, theta=0.0
% INFO    : Bus 75561	: V=1.0120495, theta=25.523605 -> V=1.0, theta=0.0
% INFO    : Bus 75562	: V=1.011402, theta=0.716095 -> V=1.0, theta=0.0
% INFO    : Bus 75563	: V=1.0080918, theta=0.028074 -> V=1.0, theta=0.0
% INFO    : Bus 75564	: V=1.0118702, theta=2.391984 -> V=1.0, theta=0.0
% INFO    : Bus 75565	: V=1.0063601, theta=22.755307 -> V=1.0, theta=0.0
% INFO    : Bus 75566	: V=1.0147153, theta=3.649244 -> V=1.0, theta=0.0
% INFO    : Bus 75567	: V=1.0134996, theta=3.341934 -> V=1.0, theta=0.0
% INFO    : Bus 75568	: V=1.0146603, theta=28.19126 -> V=1.0, theta=0.0
% INFO    : Bus 75569	: V=1.0098194, theta=0.480852 -> V=1.0, theta=0.0
% INFO    : Bus 75570	: V=1.0138054, theta=1.947924 -> V=1.0, theta=0.0
% INFO    : Bus 75571	: V=1.0133285, theta=2.008779 -> V=1.0, theta=0.0
% INFO    : Bus 75572	: V=1.0200007, theta=8.335698 -> V=1.0, theta=0.0
% INFO    : Bus 75573	: V=1.0192973, theta=7.815827 -> V=1.0, theta=0.0
% INFO    : Bus 75574	: V=1.0186509, theta=7.644674 -> V=1.0, theta=0.0
% INFO    : Bus 75575	: V=1.0092331, theta=1.899109 -> V=1.0, theta=0.0
% INFO    : Bus 75576	: V=1.010735, theta=2.199983 -> V=1.0, theta=0.0
% INFO    : Bus 75577	: V=1.0135225, theta=26.670351 -> V=1.0, theta=0.0
% INFO    : Bus 75578	: V=1.0140607, theta=26.900602 -> V=1.0, theta=0.0
% INFO    : Bus 75579	: V=1.0160094, theta=5.337804 -> V=1.0, theta=0.0
% INFO    : Bus 75580	: V=1.0103821, theta=4.306936 -> V=1.0, theta=0.0
% INFO    : Bus 75581	: V=1.0102281, theta=4.23753 -> V=1.0, theta=0.0
% INFO    : Bus 75582	: V=1.0053691, theta=-1.804925 -> V=1.0, theta=0.0
% INFO    : Bus 75583	: V=1.0120013, theta=22.165594 -> V=1.0, theta=0.0
% INFO    : Bus 75584	: V=1.0116163, theta=22.020181 -> V=1.0, theta=0.0
% INFO    : Bus 75585	: V=1.0173113, theta=4.483389 -> V=1.0, theta=0.0
% INFO    : Bus 75586	: V=1.009467, theta=21.969533 -> V=1.0, theta=0.0
% INFO    : Bus 75587	: V=1.0116134, theta=15.980546 -> V=1.0, theta=0.0
% INFO    : Bus 75588	: V=1.0111064, theta=1.057039 -> V=1.0, theta=0.0
% INFO    : Bus 75589	: V=1.0292508, theta=29.445351 -> V=1.0, theta=0.0
% INFO    : Bus 75590	: V=1.0297916, theta=29.279678 -> V=1.0, theta=0.0
% INFO    : Bus 75591	: V=1.0295437, theta=33.365978 -> V=1.0, theta=0.0
% INFO    : Bus 75592	: V=1.0293004, theta=33.207616 -> V=1.0, theta=0.0
% INFO    : Bus 75593	: V=1.0200005, theta=27.683083 -> V=1.0, theta=0.0
% INFO    : Bus 75594	: V=1.0172454, theta=26.841186 -> V=1.0, theta=0.0
% INFO    : Bus 75595	: V=1.0220491, theta=20.41608 -> V=1.0, theta=0.0
% INFO    : Bus 75596	: V=1.0239542, theta=30.723486 -> V=1.0, theta=0.0
% INFO    : Bus 75597	: V=1.0236448, theta=30.82525 -> V=1.0, theta=0.0
% INFO    : Bus 75598	: V=1.0169896, theta=24.468022 -> V=1.0, theta=0.0
% INFO    : Bus 75599	: V=1.0154275, theta=24.54107 -> V=1.0, theta=0.0
% INFO    : Bus 75600	: V=1.010562, theta=27.837889 -> V=1.0, theta=0.0
% INFO    : Bus 75601	: V=1.0171325, theta=26.920692 -> V=1.0, theta=0.0
% INFO    : Bus 75602	: V=1.0111299, theta=27.767779 -> V=1.0, theta=0.0
% INFO    : Bus 75603	: V=1.0030049, theta=24.24182 -> V=1.0, theta=0.0
% INFO    : Bus 75604	: V=1.0299079, theta=31.727144 -> V=1.0, theta=0.0
% INFO    : Bus 75605	: V=1.0293872, theta=22.975821 -> V=1.0, theta=0.0
% INFO    : Bus 75606	: V=1.0174871, theta=27.420473 -> V=1.0, theta=0.0
% INFO    : Bus 75607	: V=1.0216094, theta=23.143959 -> V=1.0, theta=0.0
% INFO    : Bus 75608	: V=1.0151563, theta=23.127565 -> V=1.0, theta=0.0
% INFO    : Bus 75609	: V=1.0117555, theta=19.640537 -> V=1.0, theta=0.0
% INFO    : Bus 75610	: V=1.0226312, theta=1.909348 -> V=1.0, theta=0.0
% INFO    : Bus 75611	: V=1.0228643, theta=1.714291 -> V=1.0, theta=0.0
% INFO    : Bus 75612	: V=1.0137798, theta=4.558193 -> V=1.0, theta=0.0
% INFO    : Bus 75613	: V=1.0219935, theta=10.670705 -> V=1.0, theta=0.0
% INFO    : Bus 75614	: V=1.0231592, theta=10.501298 -> V=1.0, theta=0.0
% INFO    : Bus 75615	: V=1.0229038, theta=10.444305 -> V=1.0, theta=0.0
% INFO    : Bus 75616	: V=1.0200122, theta=18.965046 -> V=1.0, theta=0.0
% INFO    : Bus 75617	: V=1.0190751, theta=18.333946 -> V=1.0, theta=0.0
% INFO    : Bus 75618	: V=1.0177799, theta=18.113567 -> V=1.0, theta=0.0
% INFO    : Bus 75619	: V=1.0100006, theta=19.431536 -> V=1.0, theta=0.0
% INFO    : Bus 75620	: V=1.0104117, theta=19.406251 -> V=1.0, theta=0.0
% INFO    : Bus 75621	: V=1.0075431, theta=-4.072175 -> V=1.0, theta=0.0
% INFO    : Bus 75622	: V=1.0100223, theta=19.905847 -> V=1.0, theta=0.0
% INFO    : Bus 75623	: V=1.0115706, theta=2.300452 -> V=1.0, theta=0.0
% INFO    : Bus 75624	: V=1.0177173, theta=8.043411 -> V=1.0, theta=0.0
% INFO    : Bus 75625	: V=1.0163842, theta=6.004475 -> V=1.0, theta=0.0
% INFO    : Bus 75626	: V=1.022811, theta=-0.090898 -> V=1.0, theta=0.0
% INFO    : Bus 75627	: V=1.005934, theta=3.467413 -> V=1.0, theta=0.0
% INFO    : Bus 75628	: V=1.0252878, theta=-2.559091 -> V=1.0, theta=0.0
% INFO    : Bus 75629	: V=1.010291, theta=0.494327 -> V=1.0, theta=0.0
% INFO    : Bus 75630	: V=1.0083427, theta=-3.886658 -> V=1.0, theta=0.0
% INFO    : Bus 75631	: V=1.0046575, theta=-3.144022 -> V=1.0, theta=0.0
% INFO    : Bus 75632	: V=1.0200006, theta=19.259331 -> V=1.0, theta=0.0
% INFO    : Bus 75633	: V=1.0002601, theta=-1.157374 -> V=1.0, theta=0.0
% INFO    : Bus 75634	: V=1.0075611, theta=0.105282 -> V=1.0, theta=0.0
% INFO    : Bus 75635	: V=1.0022689, theta=-1.020134 -> V=1.0, theta=0.0
% INFO    : Bus 75636	: V=1.0003931, theta=-1.209367 -> V=1.0, theta=0.0
% INFO    : Bus 75637	: V=1.0067176, theta=-0.090064 -> V=1.0, theta=0.0
% INFO    : Bus 75638	: V=1.0054878, theta=-0.501783 -> V=1.0, theta=0.0
% INFO    : Bus 75639	: V=1.0021944, theta=-0.948032 -> V=1.0, theta=0.0
% INFO    : Bus 75640	: V=1.0026091, theta=-1.074611 -> V=1.0, theta=0.0
% INFO    : Bus 75641	: V=1.0017877, theta=-0.920351 -> V=1.0, theta=0.0
% INFO    : Bus 75642	: V=1.0153699, theta=0.933523 -> V=1.0, theta=0.0
% INFO    : Bus 75643	: V=1.0107785, theta=0.214257 -> V=1.0, theta=0.0
% INFO    : Bus 75644	: V=1.0104836, theta=-0.174041 -> V=1.0, theta=0.0
% INFO    : Bus 75645	: V=0.9963184, theta=-1.471086 -> V=1.0, theta=0.0
% INFO    : Bus 75646	: V=1.004319, theta=-0.488605 -> V=1.0, theta=0.0
% INFO    : Bus 75647	: V=1.0000561, theta=-1.007244 -> V=1.0, theta=0.0
% INFO    : Bus 75648	: V=1.0094829, theta=1.328442 -> V=1.0, theta=0.0
% INFO    : Bus 75649	: V=1.0074667, theta=0.155074 -> V=1.0, theta=0.0
% INFO    : Bus 75650	: V=1.0106534, theta=0.96129 -> V=1.0, theta=0.0
% INFO    : Bus 75651	: V=1.0073173, theta=0.180877 -> V=1.0, theta=0.0
% INFO    : Bus 75652	: V=1.0058566, theta=-0.298733 -> V=1.0, theta=0.0
% INFO    : Bus 75653	: V=0.9945693, theta=-1.57565 -> V=1.0, theta=0.0
% INFO    : Bus 75654	: V=0.9915756, theta=-1.702818 -> V=1.0, theta=0.0
% INFO    : Bus 75655	: V=1.0100097, theta=0.504245 -> V=1.0, theta=0.0
% INFO    : Bus 75656	: V=1.0080356, theta=-0.018531 -> V=1.0, theta=0.0
% INFO    : Bus 75657	: V=1.0231897, theta=11.112329 -> V=1.0, theta=0.0
% INFO    : Bus 75658	: V=1.0226239, theta=10.562172 -> V=1.0, theta=0.0
% INFO    : Bus 75659	: V=1.0201757, theta=10.095 -> V=1.0, theta=0.0
% INFO    : Bus 75660	: V=1.0090373, theta=0.724395 -> V=1.0, theta=0.0
% INFO    : Bus 75661	: V=1.0109496, theta=0.889013 -> V=1.0, theta=0.0
% INFO    : Bus 75662	: V=1.0082194, theta=0.370796 -> V=1.0, theta=0.0
% INFO    : Bus 75663	: V=1.0078332, theta=0.275746 -> V=1.0, theta=0.0
% INFO    : Bus 75664	: V=1.0113738, theta=0.681636 -> V=1.0, theta=0.0
% INFO    : Bus 75665	: V=1.0088722, theta=0.357036 -> V=1.0, theta=0.0
% INFO    : Bus 75666	: V=1.00962, theta=0.976605 -> V=1.0, theta=0.0
% INFO    : Bus 75667	: V=1.0146068, theta=7.239726 -> V=1.0, theta=0.0
% INFO    : Bus 75668	: V=0.9749513, theta=15.500788 -> V=1.0, theta=0.0
% INFO    : Bus 75669	: V=0.9991188, theta=1.645872 -> V=1.0, theta=0.0
% INFO    : Bus 75670	: V=0.9955992, theta=0.972675 -> V=1.0, theta=0.0
% INFO    : Bus 75671	: V=1.010793, theta=19.710525 -> V=1.0, theta=0.0
% INFO    : Bus 75672	: V=1.0010449, theta=18.085091 -> V=1.0, theta=0.0
% INFO    : Bus 75673	: V=1.0163834, theta=20.640038 -> V=1.0, theta=0.0
% INFO    : Bus 75674	: V=1.0162293, theta=20.471742 -> V=1.0, theta=0.0
% INFO    : Bus 75675	: V=1.0161687, theta=19.809725 -> V=1.0, theta=0.0
% INFO    : Bus 75676	: V=1.0168938, theta=19.883085 -> V=1.0, theta=0.0
% INFO    : Bus 75677	: V=1.0023598, theta=3.518668 -> V=1.0, theta=0.0
% INFO    : Bus 75678	: V=1.0024173, theta=3.63118 -> V=1.0, theta=0.0
% INFO    : Bus 75679	: V=1.0018761, theta=3.46239 -> V=1.0, theta=0.0
% INFO    : Bus 75680	: V=1.005944, theta=3.664451 -> V=1.0, theta=0.0
% INFO    : Bus 75681	: V=1.0029598, theta=3.244941 -> V=1.0, theta=0.0
% INFO    : Bus 75682	: V=1.0012892, theta=20.908206 -> V=1.0, theta=0.0
% INFO    : Bus 75683	: V=1.0104114, theta=20.941012 -> V=1.0, theta=0.0
% INFO    : Bus 75684	: V=0.9903026, theta=-2.287934 -> V=1.0, theta=0.0
% INFO    : Bus 75685	: V=0.9893893, theta=-1.962317 -> V=1.0, theta=0.0
% INFO    : Bus 75686	: V=0.993984, theta=-0.919405 -> V=1.0, theta=0.0
% INFO    : Bus 75687	: V=0.9798598, theta=-1.61787 -> V=1.0, theta=0.0
% INFO    : Bus 75688	: V=0.9868485, theta=-0.692211 -> V=1.0, theta=0.0
% INFO    : Bus 75689	: V=0.9981298, theta=1.090445 -> V=1.0, theta=0.0
% INFO    : Bus 75690	: V=1.0113514, theta=4.347968 -> V=1.0, theta=0.0
% INFO    : Bus 75691	: V=1.0175282, theta=7.655159 -> V=1.0, theta=0.0
% INFO    : Bus 75692	: V=1.0174542, theta=7.439614 -> V=1.0, theta=0.0
% INFO    : Bus 75693	: V=0.9971637, theta=-6.68959 -> V=1.0, theta=0.0
% INFO    : Bus 75694	: V=1.0162585, theta=5.825821 -> V=1.0, theta=0.0
% INFO    : Bus 75695	: V=1.0249963, theta=5.78807 -> V=1.0, theta=0.0
% INFO    : Bus 75696	: V=1.0083739, theta=0.551019 -> V=1.0, theta=0.0
% INFO    : Bus 75697	: V=1.0068216, theta=0.094406 -> V=1.0, theta=0.0
% INFO    : Bus 75698	: V=0.9583457, theta=-2.121882 -> V=1.0, theta=0.0
% INFO    : Bus 75699	: V=0.9645771, theta=-1.776106 -> V=1.0, theta=0.0
% INFO    : Bus 75700	: V=1.0204186, theta=4.4947 -> V=1.0, theta=0.0
% INFO    : Bus 75701	: V=1.0161494, theta=3.850544 -> V=1.0, theta=0.0
% INFO    : Bus 75702	: V=1.0125588, theta=3.283404 -> V=1.0, theta=0.0
% INFO    : Bus 75703	: V=1.0112389, theta=3.015292 -> V=1.0, theta=0.0
% INFO    : Bus 75704	: V=1.0054757, theta=-3.448655 -> V=1.0, theta=0.0
% INFO    : Bus 75705	: V=0.9985927, theta=-5.447119 -> V=1.0, theta=0.0
% INFO    : Bus 75706	: V=0.9914194, theta=12.888488 -> V=1.0, theta=0.0
% INFO    : Bus 75707	: V=1.0286787, theta=13.468037 -> V=1.0, theta=0.0
% INFO    : Bus 75708	: V=1.028497, theta=13.367915 -> V=1.0, theta=0.0
% INFO    : Bus 75709	: V=1.0173653, theta=5.606379 -> V=1.0, theta=0.0
% INFO    : Bus 75710	: V=1.0168659, theta=5.459339 -> V=1.0, theta=0.0
% INFO    : Bus 75711	: V=1.0027092, theta=3.571401 -> V=1.0, theta=0.0
% INFO    : Bus 75712	: V=0.997753, theta=2.998578 -> V=1.0, theta=0.0
% INFO    : Bus 75713	: V=0.9900593, theta=2.360962 -> V=1.0, theta=0.0
% INFO    : Bus 75714	: V=0.985558, theta=-6.41803 -> V=1.0, theta=0.0
% INFO    : Bus 75715	: V=0.9875105, theta=-7.475466 -> V=1.0, theta=0.0
% INFO    : Bus 75716	: V=0.9975928, theta=17.704289 -> V=1.0, theta=0.0
% INFO    : Bus 75717	: V=1.0063142, theta=18.719605 -> V=1.0, theta=0.0
% INFO    : Bus 75718	: V=1.0062588, theta=18.473378 -> V=1.0, theta=0.0
% INFO    : Bus 75719	: V=1.0075571, theta=19.16659 -> V=1.0, theta=0.0
% INFO    : Bus 75720	: V=1.0017749, theta=17.928814 -> V=1.0, theta=0.0
% INFO    : Bus 75721	: V=0.9987633, theta=17.617561 -> V=1.0, theta=0.0
% INFO    : Bus 75722	: V=1.004804, theta=18.427144 -> V=1.0, theta=0.0
% INFO    : Bus 75723	: V=0.9949056, theta=17.189733 -> V=1.0, theta=0.0
% INFO    : Bus 75724	: V=0.9840803, theta=12.427142 -> V=1.0, theta=0.0
% INFO    : Bus 75725	: V=1.0072511, theta=6.956443 -> V=1.0, theta=0.0
% INFO    : Bus 75726	: V=0.9784182, theta=0.870857 -> V=1.0, theta=0.0
% INFO    : Bus 75727	: V=0.9938743, theta=-6.880258 -> V=1.0, theta=0.0
% INFO    : Bus 75728	: V=1.0110652, theta=-4.202809 -> V=1.0, theta=0.0
% INFO    : Bus 75729	: V=1.0067026, theta=-5.500685 -> V=1.0, theta=0.0
% INFO    : Bus 75730	: V=1.0272673, theta=19.908384 -> V=1.0, theta=0.0
% INFO    : Bus 75731	: V=1.024198, theta=19.543563 -> V=1.0, theta=0.0
% INFO    : Bus 75732	: V=1.0240999, theta=19.462367 -> V=1.0, theta=0.0
% INFO    : Bus 75733	: V=1.0135958, theta=17.925362 -> V=1.0, theta=0.0
% INFO    : Bus 75734	: V=1.0125228, theta=18.889868 -> V=1.0, theta=0.0
% INFO    : Bus 75735	: V=1.0125643, theta=18.694844 -> V=1.0, theta=0.0
% INFO    : Bus 75736	: V=1.0103513, theta=16.239559 -> V=1.0, theta=0.0
% INFO    : Bus 75737	: V=1.0186778, theta=5.966186 -> V=1.0, theta=0.0
% INFO    : Bus 75738	: V=1.0190109, theta=5.884641 -> V=1.0, theta=0.0
% INFO    : Bus 75739	: V=1.0076489, theta=3.660434 -> V=1.0, theta=0.0
% INFO    : Bus 75740	: V=1.025487, theta=0.113625 -> V=1.0, theta=0.0
% INFO    : Bus 75741	: V=1.0247687, theta=-0.13538 -> V=1.0, theta=0.0
% INFO    : Bus 75742	: V=1.027721, theta=-0.124943 -> V=1.0, theta=0.0
% INFO    : Bus 75743	: V=0.986408, theta=15.585168 -> V=1.0, theta=0.0
% INFO    : Bus 75744	: V=1.0117162, theta=6.523189 -> V=1.0, theta=0.0
% INFO    : Bus 75745	: V=1.0107284, theta=6.032973 -> V=1.0, theta=0.0
% INFO    : Bus 75746	: V=0.9949061, theta=-6.765862 -> V=1.0, theta=0.0
% INFO    : Bus 75747	: V=0.9914528, theta=-7.220417 -> V=1.0, theta=0.0
% INFO    : Bus 75748	: V=0.9892541, theta=-8.094067 -> V=1.0, theta=0.0
% INFO    : Bus 75749	: V=0.9884067, theta=-8.183798 -> V=1.0, theta=0.0
% INFO    : Bus 75750	: V=1.0209137, theta=8.016366 -> V=1.0, theta=0.0
% INFO    : Bus 75751	: V=1.0215037, theta=7.861865 -> V=1.0, theta=0.0
% INFO    : Bus 75752	: V=1.0191307, theta=6.66682 -> V=1.0, theta=0.0
% INFO    : Bus 75753	: V=1.0180107, theta=6.41273 -> V=1.0, theta=0.0
% INFO    : Bus 75754	: V=1.0140317, theta=7.974514 -> V=1.0, theta=0.0
% INFO    : Bus 75755	: V=1.0153925, theta=14.269235 -> V=1.0, theta=0.0
% INFO    : Bus 75756	: V=1.0112139, theta=16.633538 -> V=1.0, theta=0.0
% INFO    : Bus 75757	: V=1.0284978, theta=15.108518 -> V=1.0, theta=0.0
% INFO    : Bus 75758	: V=1.0288161, theta=18.423643 -> V=1.0, theta=0.0
% INFO    : Bus 75759	: V=1.0292276, theta=18.185465 -> V=1.0, theta=0.0
% INFO    : Bus 75760	: V=1.01443, theta=9.507354 -> V=1.0, theta=0.0
% INFO    : Bus 75761	: V=1.017812, theta=10.095194 -> V=1.0, theta=0.0
% INFO    : Bus 75762	: V=1.0266551, theta=9.252922 -> V=1.0, theta=0.0
% INFO    : Bus 75763	: V=1.0130069, theta=13.402428 -> V=1.0, theta=0.0
% INFO    : Bus 75764	: V=1.0016525, theta=12.508851 -> V=1.0, theta=0.0
% INFO    : Bus 75765	: V=1.0109099, theta=10.819514 -> V=1.0, theta=0.0
% INFO    : Bus 75766	: V=1.0101785, theta=10.382236 -> V=1.0, theta=0.0
% INFO    : Bus 75767	: V=1.0149938, theta=10.849767 -> V=1.0, theta=0.0
% INFO    : Bus 75768	: V=1.0148192, theta=10.810655 -> V=1.0, theta=0.0
% INFO    : Bus 75769	: V=1.0157084, theta=11.975822 -> V=1.0, theta=0.0
% INFO    : Bus 75770	: V=1.0125984, theta=9.909687 -> V=1.0, theta=0.0
% INFO    : Bus 75771	: V=1.01978, theta=11.571925 -> V=1.0, theta=0.0
% INFO    : Bus 75772	: V=1.0179753, theta=11.25653 -> V=1.0, theta=0.0
% INFO    : Bus 75773	: V=1.0263648, theta=12.152817 -> V=1.0, theta=0.0
% INFO    : Bus 75774	: V=1.0391509, theta=14.015538 -> V=1.0, theta=0.0
% INFO    : Bus 75775	: V=1.0291418, theta=12.908913 -> V=1.0, theta=0.0
% INFO    : Bus 75776	: V=1.037449, theta=17.968731 -> V=1.0, theta=0.0
% INFO    : Bus 75777	: V=1.0317594, theta=18.297663 -> V=1.0, theta=0.0
% INFO    : Bus 75778	: V=1.0146014, theta=11.700164 -> V=1.0, theta=0.0
% INFO    : Bus 75779	: V=1.0264665, theta=12.369327 -> V=1.0, theta=0.0
% INFO    : Bus 75780	: V=1.0287494, theta=18.340882 -> V=1.0, theta=0.0
% INFO    : Bus 75781	: V=1.0283095, theta=17.991761 -> V=1.0, theta=0.0
% INFO    : Bus 75782	: V=1.0186582, theta=15.080553 -> V=1.0, theta=0.0
% INFO    : Bus 75783	: V=1.0112554, theta=15.083127 -> V=1.0, theta=0.0
% INFO    : Bus 75784	: V=1.0130236, theta=15.275672 -> V=1.0, theta=0.0
% INFO    : Bus 75785	: V=1.0139458, theta=15.33741 -> V=1.0, theta=0.0
% INFO    : Bus 75786	: V=1.0133132, theta=15.257982 -> V=1.0, theta=0.0
% INFO    : Bus 75787	: V=1.0176422, theta=16.893759 -> V=1.0, theta=0.0
% INFO    : Bus 75788	: V=1.0184393, theta=9.697266 -> V=1.0, theta=0.0
% INFO    : Bus 75789	: V=1.0323191, theta=11.262066 -> V=1.0, theta=0.0
% INFO    : Bus 75790	: V=1.0314339, theta=11.101847 -> V=1.0, theta=0.0
% INFO    : Bus 75791	: V=1.0312281, theta=11.289663 -> V=1.0, theta=0.0
% INFO    : Bus 75792	: V=1.0331108, theta=11.230385 -> V=1.0, theta=0.0
% INFO    : Bus 75793	: V=1.0343839, theta=10.993299 -> V=1.0, theta=0.0
% INFO    : Bus 75794	: V=1.0325477, theta=10.699805 -> V=1.0, theta=0.0
% INFO    : Bus 75795	: V=1.0317849, theta=10.359183 -> V=1.0, theta=0.0
% INFO    : Bus 75796	: V=1.0238672, theta=9.583238 -> V=1.0, theta=0.0
% INFO    : Bus 75797	: V=1.0233216, theta=9.455706 -> V=1.0, theta=0.0
% INFO    : Bus 75798	: V=1.023152, theta=15.418225 -> V=1.0, theta=0.0
% INFO    : Bus 75799	: V=1.0114879, theta=10.990446 -> V=1.0, theta=0.0
% INFO    : Bus 75800	: V=1.0059488, theta=9.387902 -> V=1.0, theta=0.0
% INFO    : Bus 75801	: V=1.0409523, theta=11.27815 -> V=1.0, theta=0.0
% INFO    : Bus 75802	: V=1.0392267, theta=10.597915 -> V=1.0, theta=0.0
% INFO    : Bus 75803	: V=1.005257, theta=14.506955 -> V=1.0, theta=0.0
% INFO    : Bus 75804	: V=1.0055189, theta=9.240003 -> V=1.0, theta=0.0
% INFO    : Bus 75805	: V=1.0038474, theta=7.833417 -> V=1.0, theta=0.0
% INFO    : Bus 75806	: V=1.0040668, theta=8.43176 -> V=1.0, theta=0.0
% INFO    : Bus 75807	: V=1.0038983, theta=7.759715 -> V=1.0, theta=0.0
% INFO    : Bus 75808	: V=1.021546, theta=9.64838 -> V=1.0, theta=0.0
% INFO    : Bus 75809	: V=1.0346368, theta=13.332959 -> V=1.0, theta=0.0
% INFO    : Bus 75810	: V=1.0480349, theta=9.054729 -> V=1.0, theta=0.0
% INFO    : Bus 75811	: V=1.0482316, theta=10.743953 -> V=1.0, theta=0.0
% INFO    : Bus 75812	: V=1.0465859, theta=10.177818 -> V=1.0, theta=0.0
% INFO    : Bus 75813	: V=1.0470242, theta=10.032572 -> V=1.0, theta=0.0
% INFO    : Bus 75814	: V=1.0310574, theta=12.40475 -> V=1.0, theta=0.0
% INFO    : Bus 75815	: V=1.0218086, theta=13.039924 -> V=1.0, theta=0.0
% INFO    : Bus 75816	: V=1.0188578, theta=12.468848 -> V=1.0, theta=0.0
% INFO    : Bus 75817	: V=1.0310559, theta=14.983819 -> V=1.0, theta=0.0
% INFO    : Bus 75818	: V=1.0276821, theta=14.167118 -> V=1.0, theta=0.0
% INFO    : Bus 75819	: V=1.0174186, theta=12.345994 -> V=1.0, theta=0.0
% INFO    : Bus 75820	: V=1.011113, theta=11.607601 -> V=1.0, theta=0.0
% INFO    : Bus 75821	: V=1.0343286, theta=15.554509 -> V=1.0, theta=0.0
% INFO    : Bus 75822	: V=1.0329455, theta=15.193827 -> V=1.0, theta=0.0
% INFO    : Bus 75823	: V=1.0322378, theta=14.964413 -> V=1.0, theta=0.0
% INFO    : Bus 75824	: V=1.0329994, theta=11.904705 -> V=1.0, theta=0.0
% INFO    : Bus 75825	: V=1.0324472, theta=11.734454 -> V=1.0, theta=0.0
% INFO    : Bus 75826	: V=1.0282005, theta=11.996655 -> V=1.0, theta=0.0
% INFO    : Bus 75827	: V=1.0274887, theta=11.751232 -> V=1.0, theta=0.0
% INFO    : Bus 75828	: V=1.0140207, theta=10.661197 -> V=1.0, theta=0.0
% INFO    : Bus 75829	: V=1.0178147, theta=13.791219 -> V=1.0, theta=0.0
% INFO    : Bus 75830	: V=1.0015779, theta=6.852812 -> V=1.0, theta=0.0
% INFO    : Bus 75831	: V=1.0484072, theta=13.471396 -> V=1.0, theta=0.0
% INFO    : Bus 75832	: V=1.0473744, theta=13.394169 -> V=1.0, theta=0.0
% INFO    : Bus 75833	: V=0.9906262, theta=8.698866 -> V=1.0, theta=0.0
% INFO    : Bus 75834	: V=0.989845, theta=7.578472 -> V=1.0, theta=0.0
% INFO    : Bus 75835	: V=1.0109908, theta=12.31042 -> V=1.0, theta=0.0
% INFO    : Bus 75836	: V=0.9708975, theta=4.816813 -> V=1.0, theta=0.0
% INFO    : Bus 75837	: V=1.013377, theta=9.04117 -> V=1.0, theta=0.0
% INFO    : Bus 75838	: V=1.0149388, theta=17.397644 -> V=1.0, theta=0.0
% INFO    : Bus 75839	: V=0.9935314, theta=6.072789 -> V=1.0, theta=0.0
% INFO    : Bus 75840	: V=1.0352569, theta=13.93617 -> V=1.0, theta=0.0
% INFO    : Bus 75841	: V=1.0341171, theta=13.602263 -> V=1.0, theta=0.0
% INFO    : Bus 75842	: V=1.0329651, theta=12.756364 -> V=1.0, theta=0.0
% INFO    : Bus 75843	: V=1.0337764, theta=14.194052 -> V=1.0, theta=0.0
% INFO    : Bus 75844	: V=1.029889, theta=13.10354 -> V=1.0, theta=0.0
% INFO    : Bus 75845	: V=1.0342266, theta=13.161544 -> V=1.0, theta=0.0
% INFO    : Bus 75846	: V=1.0062964, theta=12.207884 -> V=1.0, theta=0.0
% INFO    : Bus 75847	: V=1.0044062, theta=12.065522 -> V=1.0, theta=0.0
% INFO    : Bus 75848	: V=1.0000567, theta=11.651092 -> V=1.0, theta=0.0
% INFO    : Bus 75849	: V=1.0031085, theta=11.744286 -> V=1.0, theta=0.0
% INFO    : Bus 75850	: V=1.0028792, theta=11.758506 -> V=1.0, theta=0.0
% INFO    : Bus 75851	: V=1.0156967, theta=12.36915 -> V=1.0, theta=0.0
% INFO    : Bus 75852	: V=1.0106368, theta=12.371359 -> V=1.0, theta=0.0
% INFO    : Bus 75853	: V=1.0105834, theta=12.233176 -> V=1.0, theta=0.0
% INFO    : Bus 75854	: V=0.997706, theta=11.105297 -> V=1.0, theta=0.0
% INFO    : Bus 75855	: V=1.0201109, theta=12.343366 -> V=1.0, theta=0.0
% INFO    : Bus 75856	: V=1.0188795, theta=12.152795 -> V=1.0, theta=0.0
% INFO    : Bus 75857	: V=1.0046063, theta=12.00635 -> V=1.0, theta=0.0
% INFO    : Bus 75858	: V=0.996403, theta=11.248907 -> V=1.0, theta=0.0
% INFO    : Bus 75859	: V=0.9973864, theta=11.279236 -> V=1.0, theta=0.0
% INFO    : Bus 75860	: V=1.0224598, theta=12.287297 -> V=1.0, theta=0.0
% INFO    : Bus 75861	: V=1.0278516, theta=13.543476 -> V=1.0, theta=0.0
% INFO    : Bus 75862	: V=1.0043904, theta=-14.127293 -> V=1.0, theta=0.0
% INFO    : Bus 75863	: V=0.98839, theta=-16.300495 -> V=1.0, theta=0.0
% INFO    : Bus 75864	: V=0.9930236, theta=-4.229783 -> V=1.0, theta=0.0
% INFO    : Bus 75865	: V=0.9937456, theta=-4.275115 -> V=1.0, theta=0.0
% INFO    : Bus 75866	: V=0.9945492, theta=-4.159254 -> V=1.0, theta=0.0
% INFO    : Bus 75867	: V=0.9961411, theta=-4.449267 -> V=1.0, theta=0.0
% INFO    : Bus 75868	: V=0.994364, theta=-3.851507 -> V=1.0, theta=0.0
% INFO    : Bus 75869	: V=0.9968458, theta=-3.657377 -> V=1.0, theta=0.0
% INFO    : Bus 75870	: V=1.0000464, theta=-3.536365 -> V=1.0, theta=0.0
% INFO    : Bus 75871	: V=1.005097, theta=-2.725928 -> V=1.0, theta=0.0
% INFO    : Bus 75872	: V=0.9998449, theta=-3.64995 -> V=1.0, theta=0.0
% INFO    : Bus 75873	: V=0.9993432, theta=-3.398094 -> V=1.0, theta=0.0
% INFO    : Bus 75874	: V=1.0043903, theta=-3.501634 -> V=1.0, theta=0.0
% INFO    : Bus 75875	: V=0.9976107, theta=-4.438157 -> V=1.0, theta=0.0
% INFO    : Bus 75876	: V=0.9950809, theta=-4.483937 -> V=1.0, theta=0.0
% INFO    : Bus 75877	: V=0.9882776, theta=-6.074388 -> V=1.0, theta=0.0
% INFO    : Bus 75878	: V=0.9864155, theta=-6.359355 -> V=1.0, theta=0.0
% INFO    : Bus 75879	: V=1.0066927, theta=-0.502438 -> V=1.0, theta=0.0
% INFO    : Bus 75880	: V=0.9911911, theta=-6.747721 -> V=1.0, theta=0.0
% INFO    : Bus 75881	: V=0.9985429, theta=-3.583159 -> V=1.0, theta=0.0
% INFO    : Bus 75882	: V=1.0135437, theta=0.132425 -> V=1.0, theta=0.0
% INFO    : Bus 75883	: V=1.0109318, theta=0.354921 -> V=1.0, theta=0.0
% INFO    : Bus 75884	: V=1.017439, theta=5.215455 -> V=1.0, theta=0.0
% INFO    : Bus 75885	: V=0.9865844, theta=-6.418469 -> V=1.0, theta=0.0
% INFO    : Bus 75886	: V=1.0059744, theta=-2.549322 -> V=1.0, theta=0.0
% INFO    : Bus 75887	: V=0.9961126, theta=-4.147601 -> V=1.0, theta=0.0
% INFO    : Bus 75888	: V=1.0082331, theta=-0.369575 -> V=1.0, theta=0.0
% INFO    : Bus 75889	: V=0.9788214, theta=-36.918335 -> V=1.0, theta=0.0
% INFO    : Bus 75890	: V=0.9825498, theta=-41.436457 -> V=1.0, theta=0.0
% INFO    : Bus 75891	: V=0.9889514, theta=-5.203099 -> V=1.0, theta=0.0
% INFO    : Bus 75892	: V=1.017235, theta=1.070364 -> V=1.0, theta=0.0
% INFO    : Bus 75893	: V=0.9883897, theta=-54.647989 -> V=1.0, theta=0.0
% INFO    : Bus 75894	: V=0.9913598, theta=-11.810532 -> V=1.0, theta=0.0
% INFO    : Bus 75895	: V=0.9966512, theta=-16.339488 -> V=1.0, theta=0.0
% INFO    : Bus 75896	: V=0.9944537, theta=-16.58223 -> V=1.0, theta=0.0
% INFO    : Bus 75897	: V=0.9952684, theta=-16.658429 -> V=1.0, theta=0.0
% INFO    : Bus 75898	: V=1.0005714, theta=-29.608446 -> V=1.0, theta=0.0
% INFO    : Bus 75899	: V=1.0007522, theta=-32.335975 -> V=1.0, theta=0.0
% INFO    : Bus 75900	: V=1.0019038, theta=-33.349872 -> V=1.0, theta=0.0
% INFO    : Bus 75901	: V=1.0073298, theta=-32.556148 -> V=1.0, theta=0.0
% INFO    : Bus 75902	: V=1.0057336, theta=-33.427814 -> V=1.0, theta=0.0
% INFO    : Bus 75903	: V=0.9949453, theta=-48.161943 -> V=1.0, theta=0.0
% INFO    : Bus 75904	: V=1.0179397, theta=17.168758 -> V=1.0, theta=0.0
% INFO    : Bus 75905	: V=1.0136593, theta=17.628234 -> V=1.0, theta=0.0
% INFO    : Bus 75906	: V=1.0067101, theta=11.202797 -> V=1.0, theta=0.0
% INFO    : Bus 75907	: V=1.000008, theta=-15.911421 -> V=1.0, theta=0.0
% INFO    : Bus 75908	: V=1.0300006, theta=-15.411497 -> V=1.0, theta=0.0
% INFO    : Bus 75909	: V=1.0175203, theta=9.094634 -> V=1.0, theta=0.0
% INFO    : Bus 75910	: V=1.0145925, theta=11.25289 -> V=1.0, theta=0.0
% INFO    : Bus 75911	: V=1.0162248, theta=11.227977 -> V=1.0, theta=0.0
% INFO    : Bus 75912	: V=1.0133336, theta=11.203286 -> V=1.0, theta=0.0
% INFO    : Bus 75913	: V=1.0051584, theta=-61.830568 -> V=1.0, theta=0.0
% INFO    : Bus 75914	: V=1.0049633, theta=-61.286153 -> V=1.0, theta=0.0
% INFO    : Bus 75915	: V=1.0047279, theta=-62.170891 -> V=1.0, theta=0.0
% INFO    : Bus 75916	: V=1.0110368, theta=-61.34485 -> V=1.0, theta=0.0
% INFO    : Bus 75917	: V=1.0085461, theta=-61.218502 -> V=1.0, theta=0.0
% INFO    : Bus 75918	: V=1.0102232, theta=-58.915464 -> V=1.0, theta=0.0
% INFO    : Bus 75919	: V=1.0054093, theta=-61.182516 -> V=1.0, theta=0.0
% INFO    : Bus 75920	: V=1.0026482, theta=-62.688656 -> V=1.0, theta=0.0
% INFO    : Bus 75921	: V=1.0068663, theta=-62.404572 -> V=1.0, theta=0.0
% INFO    : Bus 75922	: V=0.9873738, theta=-50.333846 -> V=1.0, theta=0.0
% INFO    : Bus 75923	: V=1.0087274, theta=-6.724408 -> V=1.0, theta=0.0
% INFO    : Bus 75924	: V=1.0054053, theta=-11.034437 -> V=1.0, theta=0.0
% INFO    : Bus 75925	: V=0.9848779, theta=-49.927997 -> V=1.0, theta=0.0
% INFO    : Bus 75926	: V=0.9884063, theta=-51.553347 -> V=1.0, theta=0.0
% INFO    : Bus 75927	: V=0.9919169, theta=-35.424979 -> V=1.0, theta=0.0
% INFO    : Bus 75928	: V=1.0169405, theta=-60.487552 -> V=1.0, theta=0.0
% INFO    : Bus 75929	: V=1.0139786, theta=-60.161688 -> V=1.0, theta=0.0
% INFO    : Bus 75930	: V=1.018749, theta=-59.571528 -> V=1.0, theta=0.0
% INFO    : Bus 75931	: V=1.0176472, theta=-60.032294 -> V=1.0, theta=0.0
% INFO    : Bus 75932	: V=1.0158725, theta=-59.699975 -> V=1.0, theta=0.0
% INFO    : Bus 75933	: V=1.0150626, theta=-59.306486 -> V=1.0, theta=0.0
% INFO    : Bus 75934	: V=1.017139, theta=-18.233068 -> V=1.0, theta=0.0
% INFO    : Bus 75935	: V=1.0003455, theta=-17.96114 -> V=1.0, theta=0.0
% INFO    : Bus 75936	: V=1.000827, theta=-20.205147 -> V=1.0, theta=0.0
% INFO    : Bus 75937	: V=1.0051143, theta=-23.596684 -> V=1.0, theta=0.0
% INFO    : Bus 75938	: V=1.0019536, theta=-24.150837 -> V=1.0, theta=0.0
% INFO    : Bus 75939	: V=1.0075622, theta=-20.368524 -> V=1.0, theta=0.0
% INFO    : Bus 75940	: V=1.0082299, theta=-19.973978 -> V=1.0, theta=0.0
% INFO    : Bus 75941	: V=1.0047568, theta=-20.259693 -> V=1.0, theta=0.0
% INFO    : Bus 75942	: V=1.0010643, theta=-19.861679 -> V=1.0, theta=0.0
% INFO    : Bus 75943	: V=1.0042318, theta=-20.260661 -> V=1.0, theta=0.0
% INFO    : Bus 75944	: V=1.0004542, theta=-19.887424 -> V=1.0, theta=0.0
% INFO    : Bus 75945	: V=1.0067433, theta=-17.963194 -> V=1.0, theta=0.0
% INFO    : Bus 75946	: V=1.0027395, theta=-19.371654 -> V=1.0, theta=0.0
% INFO    : Bus 75947	: V=1.0012534, theta=-20.160904 -> V=1.0, theta=0.0
% INFO    : Bus 75948	: V=0.9738324, theta=-18.720826 -> V=1.0, theta=0.0
% INFO    : Bus 75949	: V=1.025341, theta=-9.269389 -> V=1.0, theta=0.0
% INFO    : Bus 75950	: V=1.0200114, theta=-10.109447 -> V=1.0, theta=0.0
% INFO    : Bus 75951	: V=1.0159593, theta=-11.137735 -> V=1.0, theta=0.0
% INFO    : Bus 75952	: V=1.0131417, theta=-11.712023 -> V=1.0, theta=0.0
% INFO    : Bus 75953	: V=1.0097858, theta=-12.542932 -> V=1.0, theta=0.0
% INFO    : Bus 75954	: V=1.0114193, theta=-12.347973 -> V=1.0, theta=0.0
% INFO    : Bus 75955	: V=1.0085207, theta=-12.75417 -> V=1.0, theta=0.0
% INFO    : Bus 75956	: V=1.0156302, theta=-9.824949 -> V=1.0, theta=0.0
% INFO    : Bus 75957	: V=1.0015207, theta=-15.493149 -> V=1.0, theta=0.0
% INFO    : Bus 75958	: V=1.0002789, theta=-17.780593 -> V=1.0, theta=0.0
% INFO    : Bus 75959	: V=1.0019161, theta=-13.551895 -> V=1.0, theta=0.0
% INFO    : Bus 75960	: V=1.0164317, theta=5.375724 -> V=1.0, theta=0.0
% INFO    : Bus 75961	: V=1.0148679, theta=4.915385 -> V=1.0, theta=0.0
% INFO    : Bus 75962	: V=1.0128119, theta=5.259294 -> V=1.0, theta=0.0
% INFO    : Bus 75963	: V=1.0128788, theta=4.958777 -> V=1.0, theta=0.0
% INFO    : Bus 75964	: V=1.0106191, theta=4.262804 -> V=1.0, theta=0.0
% INFO    : Bus 75965	: V=0.9665756, theta=-13.769682 -> V=1.0, theta=0.0
% INFO    : Bus 75966	: V=0.966458, theta=-13.440926 -> V=1.0, theta=0.0
% INFO    : Bus 75967	: V=0.9674628, theta=-13.661218 -> V=1.0, theta=0.0
% INFO    : Bus 75968	: V=0.9679012, theta=-13.715141 -> V=1.0, theta=0.0
% INFO    : Bus 75969	: V=0.9673836, theta=-14.196422 -> V=1.0, theta=0.0
% INFO    : Bus 75970	: V=0.9642664, theta=-13.005467 -> V=1.0, theta=0.0
% INFO    : Bus 75971	: V=0.9654262, theta=-13.405071 -> V=1.0, theta=0.0
% INFO    : Bus 75972	: V=0.9687123, theta=-13.729819 -> V=1.0, theta=0.0
% INFO    : Bus 75973	: V=0.9650564, theta=-13.10138 -> V=1.0, theta=0.0
% INFO    : Bus 75974	: V=0.9694727, theta=-11.661371 -> V=1.0, theta=0.0
% INFO    : Bus 75975	: V=0.9710256, theta=-13.852774 -> V=1.0, theta=0.0
% INFO    : Bus 75976	: V=0.9728071, theta=-9.671442 -> V=1.0, theta=0.0
% INFO    : Bus 75977	: V=0.9753503, theta=-9.208281 -> V=1.0, theta=0.0
% INFO    : Bus 75978	: V=0.9789339, theta=-9.616792 -> V=1.0, theta=0.0
% INFO    : Bus 75979	: V=0.9795739, theta=-10.803729 -> V=1.0, theta=0.0
% INFO    : Bus 75980	: V=0.9835417, theta=-13.391389 -> V=1.0, theta=0.0
% INFO    : Bus 75981	: V=0.9883107, theta=-11.86913 -> V=1.0, theta=0.0
% INFO    : Bus 75982	: V=0.9996546, theta=-12.337952 -> V=1.0, theta=0.0
% INFO    : Bus 75983	: V=1.0117901, theta=22.926389 -> V=1.0, theta=0.0
% INFO    : Bus 75984	: V=1.0274061, theta=23.358681 -> V=1.0, theta=0.0
% INFO    : Bus 75985	: V=1.0274052, theta=23.357588 -> V=1.0, theta=0.0
% INFO    : Bus 75986	: V=0.9980808, theta=-3.285912 -> V=1.0, theta=0.0
% INFO    : Bus 75987	: V=0.9989797, theta=-3.030705 -> V=1.0, theta=0.0
% INFO    : Bus 75988	: V=0.9974739, theta=-3.191312 -> V=1.0, theta=0.0
% INFO    : Bus 75989	: V=0.9994815, theta=-2.930255 -> V=1.0, theta=0.0
% INFO    : Bus 75990	: V=0.9999848, theta=-2.850258 -> V=1.0, theta=0.0
% INFO    : Bus 75991	: V=1.0011509, theta=-2.88584 -> V=1.0, theta=0.0
% INFO    : Bus 75992	: V=1.0014567, theta=-2.240134 -> V=1.0, theta=0.0
% INFO    : Bus 75993	: V=1.0017117, theta=-2.156721 -> V=1.0, theta=0.0
% INFO    : Bus 75994	: V=1.001004, theta=-2.330831 -> V=1.0, theta=0.0
% INFO    : Bus 75995	: V=1.0013649, theta=-2.452747 -> V=1.0, theta=0.0
% INFO    : Bus 75996	: V=1.0059513, theta=-1.82966 -> V=1.0, theta=0.0
% INFO    : Bus 75997	: V=1.0028373, theta=-2.286275 -> V=1.0, theta=0.0
% INFO    : Bus 75998	: V=1.0038143, theta=-2.088461 -> V=1.0, theta=0.0
% INFO    : Bus 75999	: V=1.0040754, theta=-2.033905 -> V=1.0, theta=0.0
% INFO    : Bus 76000	: V=1.0025991, theta=-2.25403 -> V=1.0, theta=0.0
% INFO    : Bus 76001	: V=1.0042459, theta=-2.042378 -> V=1.0, theta=0.0
% INFO    : Bus 76002	: V=1.0068932, theta=-1.656331 -> V=1.0, theta=0.0
% INFO    : Bus 76003	: V=1.0098174, theta=-1.277191 -> V=1.0, theta=0.0
% INFO    : Bus 76004	: V=1.010507, theta=-0.433864 -> V=1.0, theta=0.0
% INFO    : Bus 76005	: V=1.0089176, theta=-1.190528 -> V=1.0, theta=0.0
% INFO    : Bus 76006	: V=1.0114492, theta=-0.454357 -> V=1.0, theta=0.0
% INFO    : Bus 76007	: V=1.0118034, theta=-0.615415 -> V=1.0, theta=0.0
% INFO    : Bus 76008	: V=1.0102436, theta=-1.060709 -> V=1.0, theta=0.0
% INFO    : Bus 76009	: V=1.0220725, theta=0.425995 -> V=1.0, theta=0.0
% INFO    : Bus 76010	: V=1.0226062, theta=0.515001 -> V=1.0, theta=0.0
% INFO    : Bus 76011	: V=1.0145231, theta=-0.837126 -> V=1.0, theta=0.0
% INFO    : Bus 76012	: V=1.0224917, theta=0.508817 -> V=1.0, theta=0.0
% INFO    : Bus 76013	: V=1.0145368, theta=-0.452034 -> V=1.0, theta=0.0
% INFO    : Bus 76014	: V=1.0137733, theta=-1.043485 -> V=1.0, theta=0.0
% INFO    : Bus 76015	: V=1.0107142, theta=-1.19793 -> V=1.0, theta=0.0
% INFO    : Bus 76016	: V=1.0072648, theta=-1.847158 -> V=1.0, theta=0.0
% INFO    : Bus 76017	: V=1.0023625, theta=-2.95097 -> V=1.0, theta=0.0
% INFO    : Bus 76018	: V=1.0013395, theta=-2.986176 -> V=1.0, theta=0.0
% INFO    : Bus 76019	: V=1.0054017, theta=-1.988348 -> V=1.0, theta=0.0
% INFO    : Bus 76020	: V=0.9992072, theta=-3.071457 -> V=1.0, theta=0.0
% INFO    : Bus 76021	: V=1.0002962, theta=-3.135542 -> V=1.0, theta=0.0
% INFO    : Bus 76022	: V=0.9975926, theta=-3.402861 -> V=1.0, theta=0.0
% INFO    : Bus 76023	: V=0.9996067, theta=-3.302709 -> V=1.0, theta=0.0
% INFO    : Bus 76024	: V=0.9982527, theta=-3.445137 -> V=1.0, theta=0.0
% INFO    : Bus 76025	: V=0.9990161, theta=-3.320831 -> V=1.0, theta=0.0
% INFO    : Bus 76026	: V=0.9998514, theta=-3.164938 -> V=1.0, theta=0.0
% INFO    : Bus 76027	: V=1.0022511, theta=-2.919146 -> V=1.0, theta=0.0
% INFO    : Bus 76028	: V=1.0115189, theta=-0.952638 -> V=1.0, theta=0.0
% INFO    : Bus 76029	: V=1.0212755, theta=0.678088 -> V=1.0, theta=0.0
% INFO    : Bus 76030	: V=1.0142514, theta=-0.07899 -> V=1.0, theta=0.0
% INFO    : Bus 76031	: V=1.0089461, theta=-0.97612 -> V=1.0, theta=0.0
% INFO    : Bus 76032	: V=1.0084815, theta=-1.037714 -> V=1.0, theta=0.0
% INFO    : Bus 76033	: V=1.0047961, theta=-1.807149 -> V=1.0, theta=0.0
% INFO    : Bus 76034	: V=1.0047078, theta=-1.741247 -> V=1.0, theta=0.0
% INFO    : Bus 76035	: V=1.0064107, theta=-1.351557 -> V=1.0, theta=0.0
% INFO    : Bus 76036	: V=1.0044127, theta=-1.69624 -> V=1.0, theta=0.0
% INFO    : Bus 76037	: V=1.0010945, theta=-2.324469 -> V=1.0, theta=0.0
% INFO    : Bus 76038	: V=1.0005297, theta=-2.36476 -> V=1.0, theta=0.0
% INFO    : Bus 76039	: V=1.0010072, theta=-2.905862 -> V=1.0, theta=0.0
% INFO    : Bus 76040	: V=1.0001497, theta=-3.066435 -> V=1.0, theta=0.0
% INFO    : Bus 76041	: V=1.0019076, theta=-1.929481 -> V=1.0, theta=0.0
% INFO    : Bus 76042	: V=1.0065497, theta=-1.243969 -> V=1.0, theta=0.0
% INFO    : Bus 76043	: V=1.0117268, theta=0.958738 -> V=1.0, theta=0.0
% INFO    : Bus 76044	: V=1.0092797, theta=-0.270576 -> V=1.0, theta=0.0
% INFO    : Bus 76045	: V=1.0084722, theta=-0.497512 -> V=1.0, theta=0.0
% INFO    : Bus 76046	: V=1.0045955, theta=-1.11611 -> V=1.0, theta=0.0
% INFO    : Bus 76047	: V=1.0057655, theta=-0.78463 -> V=1.0, theta=0.0
% INFO    : Bus 76048	: V=1.0071968, theta=-0.364595 -> V=1.0, theta=0.0
% INFO    : Bus 76049	: V=1.0078059, theta=-0.294125 -> V=1.0, theta=0.0
% INFO    : Bus 76050	: V=1.0113588, theta=1.133374 -> V=1.0, theta=0.0
% INFO    : Bus 76051	: V=1.0100714, theta=0.032251 -> V=1.0, theta=0.0
% INFO    : Bus 76052	: V=1.0086797, theta=-0.236469 -> V=1.0, theta=0.0
% INFO    : Bus 76053	: V=1.0114393, theta=0.877191 -> V=1.0, theta=0.0
% INFO    : Bus 76054	: V=1.0110579, theta=0.603937 -> V=1.0, theta=0.0
% INFO    : Bus 76055	: V=1.0081251, theta=0.034714 -> V=1.0, theta=0.0
% INFO    : Bus 76056	: V=1.008261, theta=-0.192675 -> V=1.0, theta=0.0
% INFO    : Bus 76057	: V=1.0083413, theta=-0.071606 -> V=1.0, theta=0.0
% INFO    : Bus 76058	: V=1.0121988, theta=3.850569 -> V=1.0, theta=0.0
% INFO    : Bus 76059	: V=1.0120774, theta=-0.663313 -> V=1.0, theta=0.0
% INFO    : Bus 76060	: V=1.0085822, theta=-1.563226 -> V=1.0, theta=0.0
% INFO    : Bus 76061	: V=1.0079082, theta=-1.531978 -> V=1.0, theta=0.0
% INFO    : Bus 76062	: V=0.965086, theta=-13.179886 -> V=1.0, theta=0.0
% INFO    : Bus 76063	: V=1.0206462, theta=16.668734 -> V=1.0, theta=0.0
% INFO    : Bus 76064	: V=1.0140478, theta=-5.636728 -> V=1.0, theta=0.0
% INFO    : Bus 76065	: V=1.0105883, theta=-6.443456 -> V=1.0, theta=0.0
% INFO    : Bus 76066	: V=1.0165027, theta=19.297482 -> V=1.0, theta=0.0
% INFO    : Bus 76067	: V=1.0168688, theta=19.284834 -> V=1.0, theta=0.0
% INFO    : Bus 76068	: V=1.0102629, theta=21.166691 -> V=1.0, theta=0.0
% INFO    : Bus 76069	: V=1.0092556, theta=21.068945 -> V=1.0, theta=0.0
% INFO    : Bus 76070	: V=1.010383, theta=17.64689 -> V=1.0, theta=0.0
% INFO    : Bus 76071	: V=1.0210843, theta=23.712094 -> V=1.0, theta=0.0
% INFO    : Bus 76072	: V=1.0180577, theta=23.387299 -> V=1.0, theta=0.0
% INFO    : Bus 76073	: V=1.0267965, theta=15.696637 -> V=1.0, theta=0.0
% INFO    : Bus 76074	: V=1.0263103, theta=15.56789 -> V=1.0, theta=0.0
% INFO    : Bus 76075	: V=1.0260299, theta=15.51081 -> V=1.0, theta=0.0
% INFO    : Bus 76076	: V=1.0033438, theta=12.063971 -> V=1.0, theta=0.0
% INFO    : Bus 76077	: V=1.0283026, theta=12.79534 -> V=1.0, theta=0.0
% INFO    : Bus 76078	: V=1.0189069, theta=15.655958 -> V=1.0, theta=0.0
% INFO    : Bus 76079	: V=1.0193496, theta=15.447042 -> V=1.0, theta=0.0
% INFO    : Bus 76080	: V=1.018329, theta=14.53263 -> V=1.0, theta=0.0
% INFO    : Bus 76081	: V=1.0173936, theta=14.618656 -> V=1.0, theta=0.0
% INFO    : Bus 76082	: V=1.022669, theta=15.103565 -> V=1.0, theta=0.0
% INFO    : Bus 76083	: V=1.020411, theta=15.054145 -> V=1.0, theta=0.0
% INFO    : Bus 76084	: V=1.0055127, theta=-2.504284 -> V=1.0, theta=0.0
% INFO    : Bus 76085	: V=0.9958526, theta=-4.177576 -> V=1.0, theta=0.0
% INFO    : Bus 76086	: V=0.9967239, theta=-4.091795 -> V=1.0, theta=0.0
% INFO    : Bus 76087	: V=0.9905592, theta=-4.7759 -> V=1.0, theta=0.0
% INFO    : Bus 76088	: V=0.9931598, theta=-4.378296 -> V=1.0, theta=0.0
% INFO    : Bus 76089	: V=0.9939051, theta=-4.496776 -> V=1.0, theta=0.0
% INFO    : Bus 76090	: V=0.9952931, theta=-4.18963 -> V=1.0, theta=0.0
% INFO    : Bus 76091	: V=0.9955535, theta=-4.202041 -> V=1.0, theta=0.0
% INFO    : Bus 76092	: V=1.0012788, theta=-3.113059 -> V=1.0, theta=0.0
% INFO    : Bus 76093	: V=1.0000741, theta=-3.670102 -> V=1.0, theta=0.0
% INFO    : Bus 76094	: V=0.9979367, theta=-4.081811 -> V=1.0, theta=0.0
% INFO    : Bus 76095	: V=0.9992884, theta=-3.929296 -> V=1.0, theta=0.0
% INFO    : Bus 76096	: V=0.9976971, theta=-4.076858 -> V=1.0, theta=0.0
% INFO    : Bus 76097	: V=0.9963254, theta=-4.310674 -> V=1.0, theta=0.0
% INFO    : Bus 76098	: V=0.9920089, theta=-4.739766 -> V=1.0, theta=0.0
% INFO    : Bus 76099	: V=0.9900321, theta=-4.904252 -> V=1.0, theta=0.0
% INFO    : Bus 76100	: V=0.9927882, theta=-4.648946 -> V=1.0, theta=0.0
% INFO    : Bus 76101	: V=0.9917167, theta=-4.668773 -> V=1.0, theta=0.0
% INFO    : Bus 76102	: V=0.9913614, theta=-4.790996 -> V=1.0, theta=0.0
% INFO    : Bus 76103	: V=0.9875197, theta=-5.736879 -> V=1.0, theta=0.0
% INFO    : Bus 76104	: V=0.9866925, theta=-5.964225 -> V=1.0, theta=0.0
% INFO    : Bus 76105	: V=0.985105, theta=-6.2326 -> V=1.0, theta=0.0
% INFO    : Bus 76106	: V=0.9860739, theta=-6.009321 -> V=1.0, theta=0.0
% INFO    : Bus 76107	: V=0.9919997, theta=-4.858275 -> V=1.0, theta=0.0
% INFO    : Bus 76108	: V=0.9930943, theta=-4.775576 -> V=1.0, theta=0.0
% INFO    : Bus 76109	: V=0.9886071, theta=-5.509725 -> V=1.0, theta=0.0
% INFO    : Bus 76110	: V=0.9932598, theta=-4.769327 -> V=1.0, theta=0.0
% INFO    : Bus 76111	: V=0.9918397, theta=-5.032257 -> V=1.0, theta=0.0
% INFO    : Bus 76112	: V=0.9909643, theta=-6.108137 -> V=1.0, theta=0.0
% INFO    : Bus 76113	: V=0.9995073, theta=-4.826421 -> V=1.0, theta=0.0
% INFO    : Bus 76114	: V=0.9948956, theta=-6.993844 -> V=1.0, theta=0.0
% INFO    : Bus 76115	: V=0.9841493, theta=-7.729845 -> V=1.0, theta=0.0
% INFO    : Bus 76116	: V=0.9850463, theta=-8.409016 -> V=1.0, theta=0.0
% INFO    : Bus 76117	: V=0.9762051, theta=-12.415013 -> V=1.0, theta=0.0
% INFO    : Bus 76118	: V=0.9729703, theta=-10.576171 -> V=1.0, theta=0.0
% INFO    : Bus 76119	: V=0.9703292, theta=-10.848778 -> V=1.0, theta=0.0
% INFO    : Bus 76120	: V=1.0153215, theta=27.53211 -> V=1.0, theta=0.0
% INFO    : Bus 76121	: V=1.025544, theta=24.943748 -> V=1.0, theta=0.0
% INFO    : Bus 76122	: V=1.0119296, theta=22.288543 -> V=1.0, theta=0.0
% INFO    : Bus 76123	: V=1.0092218, theta=21.356838 -> V=1.0, theta=0.0
% INFO    : Bus 76124	: V=1.0170738, theta=18.873017 -> V=1.0, theta=0.0
% INFO    : Bus 76125	: V=0.9965888, theta=19.575356 -> V=1.0, theta=0.0
% INFO    : Bus 76126	: V=0.9996143, theta=19.729356 -> V=1.0, theta=0.0
% INFO    : Bus 76127	: V=0.9965092, theta=19.440438 -> V=1.0, theta=0.0
% INFO    : Bus 76128	: V=0.9966338, theta=19.533082 -> V=1.0, theta=0.0
% INFO    : Bus 76129	: V=0.9966512, theta=19.743878 -> V=1.0, theta=0.0
% INFO    : Bus 76130	: V=1.0019793, theta=19.993432 -> V=1.0, theta=0.0
% INFO    : Bus 76131	: V=1.0190459, theta=21.808988 -> V=1.0, theta=0.0
% INFO    : Bus 76132	: V=1.0185276, theta=22.195854 -> V=1.0, theta=0.0
% INFO    : Bus 76133	: V=1.0184794, theta=22.663814 -> V=1.0, theta=0.0
% INFO    : Bus 76134	: V=0.9943983, theta=17.093198 -> V=1.0, theta=0.0
% INFO    : Bus 76135	: V=1.0003204, theta=18.790511 -> V=1.0, theta=0.0
% INFO    : Bus 76136	: V=1.0102613, theta=17.070767 -> V=1.0, theta=0.0
% INFO    : Bus 76137	: V=1.0101678, theta=19.293622 -> V=1.0, theta=0.0
% INFO    : Bus 76138	: V=1.0093295, theta=14.625349 -> V=1.0, theta=0.0
% INFO    : Bus 76139	: V=1.0074184, theta=14.088539 -> V=1.0, theta=0.0
% INFO    : Bus 76140	: V=1.0152546, theta=15.968465 -> V=1.0, theta=0.0
% INFO    : Bus 76141	: V=0.9698937, theta=-9.817717 -> V=1.0, theta=0.0
% INFO    : Bus 76142	: V=0.9544968, theta=-9.045071 -> V=1.0, theta=0.0
% INFO    : Bus 76143	: V=0.9716223, theta=-5.667552 -> V=1.0, theta=0.0
% INFO    : Bus 76144	: V=1.006884, theta=0.567577 -> V=1.0, theta=0.0
% INFO    : Bus 76145	: V=1.006357, theta=-0.23337 -> V=1.0, theta=0.0
% INFO    : Bus 76146	: V=1.0164864, theta=0.410535 -> V=1.0, theta=0.0
% INFO    : Bus 76147	: V=1.0149571, theta=0.305181 -> V=1.0, theta=0.0
% INFO    : Bus 76148	: V=1.0128359, theta=0.027641 -> V=1.0, theta=0.0
% INFO    : Bus 76149	: V=1.0108627, theta=-0.530048 -> V=1.0, theta=0.0
% INFO    : Bus 76150	: V=1.0018754, theta=-0.830288 -> V=1.0, theta=0.0
% INFO    : Bus 76151	: V=1.0195928, theta=2.512034 -> V=1.0, theta=0.0
% INFO    : Bus 76152	: V=1.019491, theta=2.26748 -> V=1.0, theta=0.0
% INFO    : Bus 76153	: V=1.0074023, theta=-0.123319 -> V=1.0, theta=0.0
% INFO    : Bus 76154	: V=1.0154701, theta=0.755161 -> V=1.0, theta=0.0
% INFO    : Bus 76155	: V=1.0014721, theta=-1.074329 -> V=1.0, theta=0.0
% INFO    : Bus 76156	: V=0.9993338, theta=-1.345316 -> V=1.0, theta=0.0
% INFO    : Bus 76157	: V=1.0061541, theta=-0.801126 -> V=1.0, theta=0.0
% INFO    : Bus 76158	: V=1.0014696, theta=-1.296029 -> V=1.0, theta=0.0
% INFO    : Bus 76159	: V=1.0061659, theta=-0.779535 -> V=1.0, theta=0.0
% INFO    : Bus 76160	: V=1.0087258, theta=-0.458875 -> V=1.0, theta=0.0
% INFO    : Bus 76161	: V=1.0087459, theta=-0.605269 -> V=1.0, theta=0.0
% INFO    : Bus 76162	: V=1.0108759, theta=-0.080861 -> V=1.0, theta=0.0
% INFO    : Bus 76163	: V=1.0080119, theta=-0.479213 -> V=1.0, theta=0.0
% INFO    : Bus 76164	: V=1.0072253, theta=-0.660522 -> V=1.0, theta=0.0
% INFO    : Bus 76165	: V=1.0063296, theta=-0.843721 -> V=1.0, theta=0.0
% INFO    : Bus 76166	: V=1.00598, theta=-0.873043 -> V=1.0, theta=0.0
% INFO    : Bus 76167	: V=1.0059886, theta=-0.906956 -> V=1.0, theta=0.0
% INFO    : Bus 76168	: V=1.0026787, theta=-1.199958 -> V=1.0, theta=0.0
% INFO    : Bus 76169	: V=1.003245, theta=-1.191161 -> V=1.0, theta=0.0
% INFO    : Bus 76170	: V=1.0004552, theta=-1.294372 -> V=1.0, theta=0.0
% INFO    : Bus 76171	: V=1.0074491, theta=-0.85683 -> V=1.0, theta=0.0
% INFO    : Bus 76172	: V=1.0085407, theta=-0.258092 -> V=1.0, theta=0.0
% INFO    : Bus 76173	: V=1.0090807, theta=-0.544143 -> V=1.0, theta=0.0
% INFO    : Bus 76174	: V=1.0110043, theta=-0.632059 -> V=1.0, theta=0.0
% INFO    : Bus 76175	: V=1.0100999, theta=-0.317463 -> V=1.0, theta=0.0
% INFO    : Bus 76176	: V=1.009262, theta=-0.242908 -> V=1.0, theta=0.0
% INFO    : Bus 76177	: V=1.0041711, theta=-0.327312 -> V=1.0, theta=0.0
% INFO    : Bus 76178	: V=1.0116529, theta=0.810412 -> V=1.0, theta=0.0
% INFO    : Bus 76179	: V=1.0109124, theta=-0.090642 -> V=1.0, theta=0.0
% INFO    : Bus 76180	: V=1.0098046, theta=-0.139134 -> V=1.0, theta=0.0
% INFO    : Bus 76181	: V=1.0130828, theta=0.901304 -> V=1.0, theta=0.0
% INFO    : Bus 76182	: V=1.002767, theta=-1.15777 -> V=1.0, theta=0.0
% INFO    : Bus 76183	: V=1.0038779, theta=-1.066354 -> V=1.0, theta=0.0
% INFO    : Bus 76184	: V=1.0167772, theta=1.540472 -> V=1.0, theta=0.0
% INFO    : Bus 76185	: V=1.015438, theta=1.364448 -> V=1.0, theta=0.0
% INFO    : Bus 76186	: V=1.0159319, theta=1.001762 -> V=1.0, theta=0.0
% INFO    : Bus 76187	: V=1.0050541, theta=-1.092895 -> V=1.0, theta=0.0
% INFO    : Bus 76188	: V=1.0058274, theta=-1.009067 -> V=1.0, theta=0.0
% INFO    : Bus 76189	: V=1.0057896, theta=-1.095644 -> V=1.0, theta=0.0
% INFO    : Bus 76190	: V=1.0050526, theta=-1.060843 -> V=1.0, theta=0.0
% INFO    : Bus 76191	: V=1.0075447, theta=0.047323 -> V=1.0, theta=0.0
% INFO    : Bus 76192	: V=1.0079465, theta=0.058561 -> V=1.0, theta=0.0
% INFO    : Bus 76193	: V=1.0065661, theta=-0.081918 -> V=1.0, theta=0.0
% INFO    : Bus 76194	: V=1.0099694, theta=0.690647 -> V=1.0, theta=0.0
% INFO    : Bus 76195	: V=1.008649, theta=0.29991 -> V=1.0, theta=0.0
% INFO    : Bus 76196	: V=1.0156078, theta=0.348086 -> V=1.0, theta=0.0
% INFO    : Bus 76197	: V=1.0106684, theta=-0.524245 -> V=1.0, theta=0.0
% INFO    : Bus 76198	: V=1.0152978, theta=0.670606 -> V=1.0, theta=0.0
% INFO    : Bus 76199	: V=1.0138209, theta=0.455813 -> V=1.0, theta=0.0
% INFO    : Bus 76200	: V=1.009481, theta=0.26942 -> V=1.0, theta=0.0
% INFO    : Bus 76201	: V=1.0095289, theta=0.362438 -> V=1.0, theta=0.0
% INFO    : Bus 76202	: V=1.0030721, theta=-0.177609 -> V=1.0, theta=0.0
% INFO    : Bus 76203	: V=1.0229698, theta=24.658112 -> V=1.0, theta=0.0
% INFO    : Bus 76204	: V=1.0205557, theta=24.739604 -> V=1.0, theta=0.0
% INFO    : Bus 76205	: V=1.0057971, theta=14.155942 -> V=1.0, theta=0.0
% INFO    : Bus 76206	: V=1.0046828, theta=14.209868 -> V=1.0, theta=0.0
% INFO    : Bus 76207	: V=1.0128307, theta=21.527026 -> V=1.0, theta=0.0
% INFO    : Bus 76208	: V=1.0025437, theta=20.911851 -> V=1.0, theta=0.0
% INFO    : Bus 76209	: V=1.0015027, theta=20.313891 -> V=1.0, theta=0.0
% INFO    : Bus 76210	: V=0.9835319, theta=17.739354 -> V=1.0, theta=0.0
% INFO    : Bus 76211	: V=1.016435, theta=23.652167 -> V=1.0, theta=0.0
% INFO    : Bus 76212	: V=1.013355, theta=20.461806 -> V=1.0, theta=0.0
% INFO    : Bus 76213	: V=1.0138646, theta=33.286027 -> V=1.0, theta=0.0
% INFO    : Bus 76214	: V=0.9950907, theta=16.197335 -> V=1.0, theta=0.0
% INFO    : Bus 76215	: V=1.0016995, theta=19.372948 -> V=1.0, theta=0.0
% INFO    : Bus 76216	: V=0.9980703, theta=21.721128 -> V=1.0, theta=0.0
% INFO    : Bus 76217	: V=0.9959172, theta=21.380829 -> V=1.0, theta=0.0
% INFO    : Bus 76218	: V=0.9961829, theta=21.173416 -> V=1.0, theta=0.0
% INFO    : Bus 76219	: V=1.0212733, theta=-3.337141 -> V=1.0, theta=0.0
% INFO    : Bus 76220	: V=1.0183146, theta=-2.843617 -> V=1.0, theta=0.0
% INFO    : Bus 76221	: V=1.0122998, theta=-4.82266 -> V=1.0, theta=0.0
% INFO    : Bus 76222	: V=1.0030338, theta=-5.69727 -> V=1.0, theta=0.0
% INFO    : Bus 76223	: V=0.9968144, theta=-0.682344 -> V=1.0, theta=0.0
% INFO    : Bus 76224	: V=0.9972442, theta=-1.042092 -> V=1.0, theta=0.0
% INFO    : Bus 76225	: V=0.9949893, theta=-0.972576 -> V=1.0, theta=0.0
% INFO    : Bus 76226	: V=0.9983658, theta=-0.49984 -> V=1.0, theta=0.0
% INFO    : Bus 76227	: V=0.9948181, theta=-0.582428 -> V=1.0, theta=0.0
% INFO    : Bus 76228	: V=0.9897108, theta=-2.00004 -> V=1.0, theta=0.0
% INFO    : Bus 76229	: V=0.9886565, theta=-2.500174 -> V=1.0, theta=0.0
% INFO    : Bus 76230	: V=0.9899277, theta=-2.503506 -> V=1.0, theta=0.0
% INFO    : Bus 76231	: V=0.9847352, theta=-2.659581 -> V=1.0, theta=0.0
% INFO    : Bus 76232	: V=0.9756536, theta=-5.005983 -> V=1.0, theta=0.0
% INFO    : Bus 76233	: V=0.982872, theta=-3.189288 -> V=1.0, theta=0.0
% INFO    : Bus 76234	: V=0.9991758, theta=-1.131624 -> V=1.0, theta=0.0
% INFO    : Bus 76235	: V=0.9948786, theta=-1.798407 -> V=1.0, theta=0.0
% INFO    : Bus 76236	: V=0.9987303, theta=-1.170333 -> V=1.0, theta=0.0
% INFO    : Bus 76237	: V=0.9973128, theta=-1.17011 -> V=1.0, theta=0.0
% INFO    : Bus 76238	: V=0.9996948, theta=-1.098482 -> V=1.0, theta=0.0
% INFO    : Bus 76239	: V=0.9990143, theta=-1.069665 -> V=1.0, theta=0.0
% INFO    : Bus 76240	: V=0.9996047, theta=-0.907903 -> V=1.0, theta=0.0
% INFO    : Bus 76241	: V=0.9991644, theta=-1.076813 -> V=1.0, theta=0.0
% INFO    : Bus 76242	: V=0.9995255, theta=-1.166126 -> V=1.0, theta=0.0
% INFO    : Bus 76243	: V=1.0002022, theta=-0.812031 -> V=1.0, theta=0.0
% INFO    : Bus 76244	: V=0.9982726, theta=-1.499775 -> V=1.0, theta=0.0
% INFO    : Bus 76245	: V=1.0005158, theta=-0.789042 -> V=1.0, theta=0.0
% INFO    : Bus 76246	: V=0.9993461, theta=-0.822253 -> V=1.0, theta=0.0
% INFO    : Bus 76247	: V=1.0018971, theta=-0.995631 -> V=1.0, theta=0.0
% INFO    : Bus 76248	: V=0.9974727, theta=-1.152339 -> V=1.0, theta=0.0
% INFO    : Bus 76249	: V=0.9969271, theta=-1.636845 -> V=1.0, theta=0.0
% INFO    : Bus 76250	: V=1.0008837, theta=-0.753106 -> V=1.0, theta=0.0
% INFO    : Bus 76251	: V=1.0009883, theta=-0.74921 -> V=1.0, theta=0.0
% INFO    : Bus 76252	: V=1.0071594, theta=0.304244 -> V=1.0, theta=0.0
% INFO    : Bus 76253	: V=0.9967789, theta=-1.768132 -> V=1.0, theta=0.0
% INFO    : Bus 76254	: V=0.9995622, theta=-0.926073 -> V=1.0, theta=0.0
% INFO    : Bus 76255	: V=0.9998297, theta=-0.931186 -> V=1.0, theta=0.0
% INFO    : Bus 76256	: V=1.0048551, theta=0.074352 -> V=1.0, theta=0.0
% INFO    : Bus 76257	: V=1.0043033, theta=-0.196454 -> V=1.0, theta=0.0
% INFO    : Bus 76258	: V=0.9947594, theta=-1.789439 -> V=1.0, theta=0.0
% INFO    : Bus 76259	: V=1.0034715, theta=-0.023722 -> V=1.0, theta=0.0
% INFO    : Bus 76260	: V=0.9888541, theta=-2.374469 -> V=1.0, theta=0.0
% INFO    : Bus 76261	: V=0.9966291, theta=-1.666444 -> V=1.0, theta=0.0
% INFO    : Bus 76262	: V=0.9979137, theta=-1.177403 -> V=1.0, theta=0.0
% INFO    : Bus 76263	: V=0.9969715, theta=-1.039604 -> V=1.0, theta=0.0
% INFO    : Bus 76264	: V=1.0040551, theta=0.07525 -> V=1.0, theta=0.0
% INFO    : Bus 76265	: V=1.0061031, theta=0.436073 -> V=1.0, theta=0.0
% INFO    : Bus 76266	: V=1.0047593, theta=0.15279 -> V=1.0, theta=0.0
% INFO    : Bus 76267	: V=0.9994994, theta=-0.770901 -> V=1.0, theta=0.0
% INFO    : Bus 76268	: V=1.0036983, theta=-0.259059 -> V=1.0, theta=0.0
% INFO    : Bus 76269	: V=1.0034025, theta=-0.025087 -> V=1.0, theta=0.0
% INFO    : Bus 76270	: V=1.0210715, theta=2.902474 -> V=1.0, theta=0.0
% INFO    : Bus 76271	: V=1.0135488, theta=1.963281 -> V=1.0, theta=0.0
% INFO    : Bus 76272	: V=1.0093565, theta=0.954692 -> V=1.0, theta=0.0
% INFO    : Bus 76273	: V=1.0090888, theta=0.892786 -> V=1.0, theta=0.0
% INFO    : Bus 76274	: V=0.9983588, theta=-1.112007 -> V=1.0, theta=0.0
% INFO    : Bus 76275	: V=0.9953851, theta=-1.454117 -> V=1.0, theta=0.0
% INFO    : Bus 76276	: V=1.0030898, theta=0.165718 -> V=1.0, theta=0.0
% INFO    : Bus 76277	: V=1.0069082, theta=0.733567 -> V=1.0, theta=0.0
% INFO    : Bus 76278	: V=1.0053743, theta=0.372727 -> V=1.0, theta=0.0
% INFO    : Bus 76279	: V=1.0206835, theta=2.97104 -> V=1.0, theta=0.0
% INFO    : Bus 76280	: V=1.0136076, theta=2.058098 -> V=1.0, theta=0.0
% INFO    : Bus 76281	: V=1.0102001, theta=1.195797 -> V=1.0, theta=0.0
% INFO    : Bus 76282	: V=1.0129011, theta=2.014871 -> V=1.0, theta=0.0
% INFO    : Bus 76283	: V=1.0100958, theta=1.023814 -> V=1.0, theta=0.0
% INFO    : Bus 76284	: V=1.009071, theta=1.11337 -> V=1.0, theta=0.0
% INFO    : Bus 76285	: V=0.9997367, theta=-0.771629 -> V=1.0, theta=0.0
% INFO    : Bus 76286	: V=1.0100855, theta=1.027472 -> V=1.0, theta=0.0
% INFO    : Bus 76287	: V=1.0078395, theta=0.259036 -> V=1.0, theta=0.0
% INFO    : Bus 76288	: V=1.0122487, theta=1.969287 -> V=1.0, theta=0.0
% INFO    : Bus 76289	: V=0.9941889, theta=-1.801292 -> V=1.0, theta=0.0
% INFO    : Bus 76290	: V=0.9955985, theta=-1.616933 -> V=1.0, theta=0.0
% INFO    : Bus 76291	: V=0.9929784, theta=-1.859228 -> V=1.0, theta=0.0
% INFO    : Bus 76292	: V=0.9947101, theta=-1.662357 -> V=1.0, theta=0.0
% INFO    : Bus 76293	: V=0.9844493, theta=-2.797872 -> V=1.0, theta=0.0
% INFO    : Bus 76294	: V=0.9885437, theta=-2.393313 -> V=1.0, theta=0.0
% INFO    : Bus 76295	: V=0.9900309, theta=-1.928369 -> V=1.0, theta=0.0
% INFO    : Bus 76296	: V=0.9834679, theta=-2.928993 -> V=1.0, theta=0.0
% INFO    : Bus 76297	: V=1.000945, theta=-0.396895 -> V=1.0, theta=0.0
% INFO    : Bus 76298	: V=0.99977, theta=-0.368811 -> V=1.0, theta=0.0
% INFO    : Bus 76299	: V=1.0052106, theta=0.763778 -> V=1.0, theta=0.0
% INFO    : Bus 76300	: V=0.9983481, theta=-0.581143 -> V=1.0, theta=0.0
% INFO    : Bus 76301	: V=0.9977088, theta=-0.376091 -> V=1.0, theta=0.0
% INFO    : Bus 76302	: V=0.9993138, theta=-0.598073 -> V=1.0, theta=0.0
% INFO    : Bus 76303	: V=0.9972147, theta=-0.574682 -> V=1.0, theta=0.0
% INFO    : Bus 76304	: V=0.9955773, theta=-1.260562 -> V=1.0, theta=0.0
% INFO    : Bus 76305	: V=1.0040769, theta=0.333964 -> V=1.0, theta=0.0
% INFO    : Bus 76306	: V=1.0007785, theta=0.112013 -> V=1.0, theta=0.0
% INFO    : Bus 76307	: V=1.0032794, theta=0.527947 -> V=1.0, theta=0.0
% INFO    : Bus 76308	: V=0.999952, theta=-0.184975 -> V=1.0, theta=0.0
% INFO    : Bus 76309	: V=1.0025086, theta=0.037103 -> V=1.0, theta=0.0
% INFO    : Bus 76310	: V=1.0129041, theta=1.84609 -> V=1.0, theta=0.0
% INFO    : Bus 76311	: V=1.0116256, theta=1.1199 -> V=1.0, theta=0.0
% INFO    : Bus 76312	: V=1.0069963, theta=0.042651 -> V=1.0, theta=0.0
% INFO    : Bus 76313	: V=1.0078963, theta=0.743824 -> V=1.0, theta=0.0
% INFO    : Bus 76314	: V=1.0071961, theta=0.821467 -> V=1.0, theta=0.0
% INFO    : Bus 76315	: V=1.0040374, theta=-0.088583 -> V=1.0, theta=0.0
% INFO    : Bus 76316	: V=1.0106416, theta=1.988974 -> V=1.0, theta=0.0
% INFO    : Bus 76317	: V=1.0087301, theta=0.952232 -> V=1.0, theta=0.0
% INFO    : Bus 76318	: V=1.0036682, theta=-0.086944 -> V=1.0, theta=0.0
% INFO    : Bus 76319	: V=1.0041789, theta=-0.134068 -> V=1.0, theta=0.0
% INFO    : Bus 76320	: V=1.0004957, theta=-0.945855 -> V=1.0, theta=0.0
% INFO    : Bus 76321	: V=0.9995202, theta=-1.161258 -> V=1.0, theta=0.0
% INFO    : Bus 76322	: V=1.0077303, theta=0.662146 -> V=1.0, theta=0.0
% INFO    : Bus 76323	: V=1.0029884, theta=-0.426031 -> V=1.0, theta=0.0
% INFO    : Bus 76324	: V=0.9977209, theta=-2.15984 -> V=1.0, theta=0.0
% INFO    : Bus 76325	: V=0.9943396, theta=-2.06165 -> V=1.0, theta=0.0
% INFO    : Bus 76326	: V=1.0002957, theta=-1.241005 -> V=1.0, theta=0.0
% INFO    : Bus 76327	: V=1.0134282, theta=1.276829 -> V=1.0, theta=0.0
% INFO    : Bus 76328	: V=1.0078963, theta=0.363142 -> V=1.0, theta=0.0
% INFO    : Bus 76329	: V=1.0079713, theta=0.274564 -> V=1.0, theta=0.0
% INFO    : Bus 76330	: V=0.9970412, theta=-1.50955 -> V=1.0, theta=0.0
% INFO    : Bus 76331	: V=0.9933089, theta=-1.739172 -> V=1.0, theta=0.0
% INFO    : Bus 76332	: V=1.0001155, theta=-1.109526 -> V=1.0, theta=0.0
% INFO    : Bus 76333	: V=0.999128, theta=-1.355673 -> V=1.0, theta=0.0
% INFO    : Bus 76334	: V=1.0009431, theta=-1.223254 -> V=1.0, theta=0.0
% INFO    : Bus 76335	: V=1.0001537, theta=-1.350305 -> V=1.0, theta=0.0
% INFO    : Bus 76336	: V=1.002663, theta=-1.170593 -> V=1.0, theta=0.0
% INFO    : Bus 76337	: V=1.0023097, theta=-1.188269 -> V=1.0, theta=0.0
% INFO    : Bus 76338	: V=1.0002492, theta=-1.449496 -> V=1.0, theta=0.0
% INFO    : Bus 76339	: V=1.0004694, theta=-1.150405 -> V=1.0, theta=0.0
% INFO    : Bus 76340	: V=1.0010227, theta=-1.172615 -> V=1.0, theta=0.0
% INFO    : Bus 76341	: V=0.9980376, theta=-1.322467 -> V=1.0, theta=0.0
% INFO    : Bus 76342	: V=1.0036836, theta=-1.096739 -> V=1.0, theta=0.0
% INFO    : Bus 76343	: V=1.0037324, theta=-0.659529 -> V=1.0, theta=0.0
% INFO    : Bus 76344	: V=1.001026, theta=-1.273191 -> V=1.0, theta=0.0
% INFO    : Bus 76345	: V=0.9970246, theta=-2.026361 -> V=1.0, theta=0.0
% INFO    : Bus 76346	: V=0.9974166, theta=-1.960971 -> V=1.0, theta=0.0
% INFO    : Bus 76347	: V=0.9955128, theta=-2.049379 -> V=1.0, theta=0.0
% INFO    : Bus 76348	: V=0.9991844, theta=-0.030711 -> V=1.0, theta=0.0
% INFO    : Bus 76349	: V=0.995764, theta=-0.802783 -> V=1.0, theta=0.0
% INFO    : Bus 76350	: V=0.9939616, theta=-0.918219 -> V=1.0, theta=0.0
% INFO    : Bus 76351	: V=1.0153586, theta=2.562173 -> V=1.0, theta=0.0
% INFO    : Bus 76352	: V=1.0139074, theta=1.997852 -> V=1.0, theta=0.0
% INFO    : Bus 76353	: V=1.0112521, theta=1.723326 -> V=1.0, theta=0.0
% INFO    : Bus 76354	: V=1.0078921, theta=1.094694 -> V=1.0, theta=0.0
% INFO    : Bus 76355	: V=1.0142485, theta=2.958042 -> V=1.0, theta=0.0
% INFO    : Bus 76356	: V=1.0031497, theta=0.506196 -> V=1.0, theta=0.0
% INFO    : Bus 76357	: V=1.0082893, theta=1.155272 -> V=1.0, theta=0.0
% INFO    : Bus 76358	: V=0.9964295, theta=-1.125126 -> V=1.0, theta=0.0
% INFO    : Bus 76359	: V=1.0026041, theta=0.328129 -> V=1.0, theta=0.0
% INFO    : Bus 76360	: V=1.0027248, theta=0.216035 -> V=1.0, theta=0.0
% INFO    : Bus 76361	: V=1.005868, theta=0.119106 -> V=1.0, theta=0.0
% INFO    : Bus 76362	: V=1.0097459, theta=1.032291 -> V=1.0, theta=0.0
% INFO    : Bus 76363	: V=0.9852015, theta=-2.609271 -> V=1.0, theta=0.0
% INFO    : Bus 76364	: V=0.996097, theta=-1.151678 -> V=1.0, theta=0.0
% INFO    : Bus 76365	: V=0.9892934, theta=-0.493813 -> V=1.0, theta=0.0
% INFO    : Bus 76366	: V=1.0172933, theta=4.650216 -> V=1.0, theta=0.0
% INFO    : Bus 76367	: V=1.0176872, theta=4.711872 -> V=1.0, theta=0.0
% INFO    : Bus 76368	: V=1.0220095, theta=4.434252 -> V=1.0, theta=0.0
% INFO    : Bus 76369	: V=1.021193, theta=4.251812 -> V=1.0, theta=0.0
% INFO    : Bus 76370	: V=0.9951283, theta=-1.583553 -> V=1.0, theta=0.0
% INFO    : Bus 76371	: V=1.0119389, theta=2.487036 -> V=1.0, theta=0.0
% INFO    : Bus 76372	: V=1.0205202, theta=4.334473 -> V=1.0, theta=0.0
% INFO    : Bus 76373	: V=1.0159917, theta=2.671763 -> V=1.0, theta=0.0
% INFO    : Bus 76374	: V=1.0128783, theta=1.512426 -> V=1.0, theta=0.0
% INFO    : Bus 76375	: V=1.0121705, theta=1.287542 -> V=1.0, theta=0.0
% INFO    : Bus 76376	: V=0.9933502, theta=-2.55178 -> V=1.0, theta=0.0
% INFO    : Bus 76377	: V=1.0027391, theta=-1.109806 -> V=1.0, theta=0.0
% INFO    : Bus 76378	: V=1.0002189, theta=-1.613041 -> V=1.0, theta=0.0
% INFO    : Bus 76379	: V=1.0176884, theta=2.694783 -> V=1.0, theta=0.0
% INFO    : Bus 76380	: V=1.0243933, theta=3.922185 -> V=1.0, theta=0.0
% INFO    : Bus 76381	: V=1.0232744, theta=3.676577 -> V=1.0, theta=0.0
% INFO    : Bus 76382	: V=1.0225879, theta=3.638436 -> V=1.0, theta=0.0
% INFO    : Bus 76383	: V=1.0240554, theta=4.369183 -> V=1.0, theta=0.0
% INFO    : Bus 76384	: V=1.0004905, theta=-1.017682 -> V=1.0, theta=0.0
% INFO    : Bus 76385	: V=1.0067172, theta=0.165404 -> V=1.0, theta=0.0
% INFO    : Bus 76386	: V=1.0071617, theta=0.162461 -> V=1.0, theta=0.0
% INFO    : Bus 76387	: V=1.0078081, theta=0.23087 -> V=1.0, theta=0.0
% INFO    : Bus 76388	: V=0.9942676, theta=-2.815381 -> V=1.0, theta=0.0
% INFO    : Bus 76389	: V=1.0112952, theta=16.389518 -> V=1.0, theta=0.0
% INFO    : Bus 76390	: V=1.0167115, theta=1.172544 -> V=1.0, theta=0.0
% INFO    : Bus 76391	: V=1.0201001, theta=2.77671 -> V=1.0, theta=0.0
% INFO    : Bus 76392	: V=1.0149813, theta=1.265336 -> V=1.0, theta=0.0
% INFO    : Bus 76393	: V=1.0128159, theta=2.061794 -> V=1.0, theta=0.0
% INFO    : Bus 76394	: V=1.0168289, theta=2.345369 -> V=1.0, theta=0.0
% INFO    : Bus 76395	: V=1.0154181, theta=1.845509 -> V=1.0, theta=0.0
% INFO    : Bus 76396	: V=1.016359, theta=1.469983 -> V=1.0, theta=0.0
% INFO    : Bus 76397	: V=1.0150081, theta=1.335976 -> V=1.0, theta=0.0
% INFO    : Bus 76398	: V=1.0100363, theta=1.657935 -> V=1.0, theta=0.0
% INFO    : Bus 76399	: V=1.0078576, theta=30.062358 -> V=1.0, theta=0.0
% INFO    : Bus 76400	: V=1.0203356, theta=39.57265 -> V=1.0, theta=0.0
% INFO    : Bus 76401	: V=1.0064638, theta=-2.468409 -> V=1.0, theta=0.0
% INFO    : Bus 76402	: V=0.9980671, theta=-1.404523 -> V=1.0, theta=0.0
% INFO    : Bus 76403	: V=0.9979084, theta=-3.611644 -> V=1.0, theta=0.0
% INFO    : Bus 76404	: V=1.0217236, theta=34.090089 -> V=1.0, theta=0.0
% INFO    : Bus 76405	: V=1.0093418, theta=25.515943 -> V=1.0, theta=0.0
% INFO    : Bus 76406	: V=1.0202097, theta=-4.228786 -> V=1.0, theta=0.0
% INFO    : Bus 76407	: V=1.0166206, theta=21.890873 -> V=1.0, theta=0.0
% INFO    : Bus 76408	: V=1.0150119, theta=22.059408 -> V=1.0, theta=0.0
% INFO    : Bus 76409	: V=0.9990049, theta=21.941546 -> V=1.0, theta=0.0
% INFO    : Bus 76410	: V=1.0136299, theta=0.89333 -> V=1.0, theta=0.0
% INFO    : Bus 76411	: V=1.009594, theta=-0.012043 -> V=1.0, theta=0.0
% INFO    : Bus 76412	: V=1.0031169, theta=-1.272508 -> V=1.0, theta=0.0
% INFO    : Bus 76413	: V=0.9995789, theta=-1.493499 -> V=1.0, theta=0.0
% INFO    : Bus 76414	: V=1.0026407, theta=-1.282334 -> V=1.0, theta=0.0
% INFO    : Bus 76415	: V=1.0038556, theta=-1.260816 -> V=1.0, theta=0.0
% INFO    : Bus 76416	: V=1.0034129, theta=-1.285375 -> V=1.0, theta=0.0
% INFO    : Bus 76417	: V=1.0062912, theta=-0.613618 -> V=1.0, theta=0.0
% INFO    : Bus 76418	: V=1.0052852, theta=-0.690402 -> V=1.0, theta=0.0
% INFO    : Bus 76419	: V=1.00417, theta=-1.152911 -> V=1.0, theta=0.0
% INFO    : Bus 76420	: V=1.0029239, theta=-1.244878 -> V=1.0, theta=0.0
% INFO    : Bus 76421	: V=1.0026705, theta=-1.425743 -> V=1.0, theta=0.0
% INFO    : Bus 76422	: V=1.0012786, theta=-1.476917 -> V=1.0, theta=0.0
% INFO    : Bus 76423	: V=0.9982298, theta=-1.8119 -> V=1.0, theta=0.0
% INFO    : Bus 76424	: V=0.9998215, theta=-2.00603 -> V=1.0, theta=0.0
% INFO    : Bus 76425	: V=0.9981552, theta=-2.320958 -> V=1.0, theta=0.0
% INFO    : Bus 76426	: V=1.0004276, theta=-1.788009 -> V=1.0, theta=0.0
% INFO    : Bus 76427	: V=0.9959254, theta=-2.189483 -> V=1.0, theta=0.0
% INFO    : Bus 76428	: V=0.9998007, theta=-1.867617 -> V=1.0, theta=0.0
% INFO    : Bus 76429	: V=1.0016541, theta=-1.664372 -> V=1.0, theta=0.0
% INFO    : Bus 76430	: V=1.0027871, theta=-1.625174 -> V=1.0, theta=0.0
% INFO    : Bus 76431	: V=1.0023493, theta=-1.740669 -> V=1.0, theta=0.0
% INFO    : Bus 76432	: V=1.0060322, theta=-1.508437 -> V=1.0, theta=0.0
% INFO    : Bus 76433	: V=1.0027557, theta=-1.591429 -> V=1.0, theta=0.0
% INFO    : Bus 76434	: V=1.0047052, theta=-2.012795 -> V=1.0, theta=0.0
% INFO    : Bus 76435	: V=1.0041835, theta=-1.486836 -> V=1.0, theta=0.0
% INFO    : Bus 76436	: V=1.002787, theta=-1.490791 -> V=1.0, theta=0.0
% INFO    : Bus 76437	: V=1.0012098, theta=-1.511729 -> V=1.0, theta=0.0
% INFO    : Bus 76438	: V=1.0110707, theta=0.08792 -> V=1.0, theta=0.0
% INFO    : Bus 76439	: V=1.0069461, theta=-0.737953 -> V=1.0, theta=0.0
% INFO    : Bus 76440	: V=0.9957085, theta=-1.874429 -> V=1.0, theta=0.0
% INFO    : Bus 76441	: V=1.0006431, theta=-1.415822 -> V=1.0, theta=0.0
% INFO    : Bus 76442	: V=1.0010055, theta=-1.336773 -> V=1.0, theta=0.0
% INFO    : Bus 76443	: V=1.0015873, theta=-1.312629 -> V=1.0, theta=0.0
% INFO    : Bus 76444	: V=1.0035036, theta=-0.388831 -> V=1.0, theta=0.0
% INFO    : Bus 76445	: V=1.0056191, theta=-0.923447 -> V=1.0, theta=0.0
% INFO    : Bus 76446	: V=1.0038569, theta=-1.097918 -> V=1.0, theta=0.0
% INFO    : Bus 76447	: V=1.0239125, theta=2.205696 -> V=1.0, theta=0.0
% INFO    : Bus 76448	: V=1.0178142, theta=0.718658 -> V=1.0, theta=0.0
% INFO    : Bus 76449	: V=1.017203, theta=0.382656 -> V=1.0, theta=0.0
% INFO    : Bus 76450	: V=1.0047372, theta=-0.234168 -> V=1.0, theta=0.0
% INFO    : Bus 76451	: V=1.0042428, theta=-0.134741 -> V=1.0, theta=0.0
% INFO    : Bus 76452	: V=1.0077859, theta=-0.898427 -> V=1.0, theta=0.0
% INFO    : Bus 76453	: V=1.0060522, theta=-1.511315 -> V=1.0, theta=0.0
% INFO    : Bus 76454	: V=1.0045269, theta=-1.58621 -> V=1.0, theta=0.0
% INFO    : Bus 76455	: V=1.0062223, theta=-1.479224 -> V=1.0, theta=0.0
% INFO    : Bus 76456	: V=0.9997709, theta=-1.976449 -> V=1.0, theta=0.0
% INFO    : Bus 76457	: V=0.9959815, theta=-2.174885 -> V=1.0, theta=0.0
% INFO    : Bus 76458	: V=0.997225, theta=-2.034972 -> V=1.0, theta=0.0
% INFO    : Bus 76459	: V=1.0053079, theta=-0.597274 -> V=1.0, theta=0.0
% INFO    : Bus 76460	: V=1.0049864, theta=-0.811261 -> V=1.0, theta=0.0
% INFO    : Bus 76461	: V=1.0063717, theta=-0.430851 -> V=1.0, theta=0.0
% INFO    : Bus 76462	: V=1.0061307, theta=-0.845416 -> V=1.0, theta=0.0
% INFO    : Bus 76463	: V=1.0052187, theta=-0.69437 -> V=1.0, theta=0.0
% INFO    : Bus 76464	: V=1.0064729, theta=-0.589446 -> V=1.0, theta=0.0
% INFO    : Bus 76465	: V=1.0025826, theta=-1.360197 -> V=1.0, theta=0.0
% INFO    : Bus 76466	: V=0.9955607, theta=-2.569843 -> V=1.0, theta=0.0
% INFO    : Bus 76467	: V=0.9982117, theta=0.953041 -> V=1.0, theta=0.0
% INFO    : Bus 76468	: V=1.0052587, theta=0.745476 -> V=1.0, theta=0.0
% INFO    : Bus 76469	: V=1.004136, theta=0.865698 -> V=1.0, theta=0.0
% INFO    : Bus 76470	: V=1.0069147, theta=2.026841 -> V=1.0, theta=0.0
% INFO    : Bus 76471	: V=1.002612, theta=2.35324 -> V=1.0, theta=0.0
% INFO    : Bus 76472	: V=1.001701, theta=2.404504 -> V=1.0, theta=0.0
% INFO    : Bus 76473	: V=0.9927474, theta=0.38389 -> V=1.0, theta=0.0
% INFO    : Bus 76474	: V=1.0040034, theta=2.472593 -> V=1.0, theta=0.0
% INFO    : Bus 76475	: V=1.0017823, theta=2.360285 -> V=1.0, theta=0.0
% INFO    : Bus 76476	: V=1.0027366, theta=2.471081 -> V=1.0, theta=0.0
% INFO    : Bus 76477	: V=1.007666, theta=3.378899 -> V=1.0, theta=0.0
% INFO    : Bus 76478	: V=1.0079728, theta=3.060846 -> V=1.0, theta=0.0
% INFO    : Bus 76479	: V=1.0024579, theta=1.479515 -> V=1.0, theta=0.0
% INFO    : Bus 76480	: V=0.9892589, theta=-1.991417 -> V=1.0, theta=0.0
% INFO    : Bus 76481	: V=0.9847314, theta=-2.249222 -> V=1.0, theta=0.0
% INFO    : Bus 76482	: V=0.9899546, theta=-1.995691 -> V=1.0, theta=0.0
% INFO    : Bus 76483	: V=0.9970864, theta=-3.036164 -> V=1.0, theta=0.0
% INFO    : Bus 76484	: V=0.9876786, theta=-2.872599 -> V=1.0, theta=0.0
% INFO    : Bus 76485	: V=0.9902318, theta=-2.894773 -> V=1.0, theta=0.0
% INFO    : Bus 76486	: V=0.9912788, theta=-1.696856 -> V=1.0, theta=0.0
% INFO    : Bus 76487	: V=0.9868724, theta=-2.468823 -> V=1.0, theta=0.0
% INFO    : Bus 76488	: V=0.9822037, theta=-2.935875 -> V=1.0, theta=0.0
% INFO    : Bus 76489	: V=0.9824604, theta=-3.26033 -> V=1.0, theta=0.0
% INFO    : Bus 76490	: V=0.9942528, theta=-1.508522 -> V=1.0, theta=0.0
% INFO    : Bus 76491	: V=0.9885204, theta=-2.488086 -> V=1.0, theta=0.0
% INFO    : Bus 76492	: V=0.9854852, theta=-3.203977 -> V=1.0, theta=0.0
% INFO    : Bus 76493	: V=0.9814769, theta=-3.371842 -> V=1.0, theta=0.0
% INFO    : Bus 76494	: V=0.9873055, theta=-2.742266 -> V=1.0, theta=0.0
% INFO    : Bus 76495	: V=0.988225, theta=-2.61429 -> V=1.0, theta=0.0
% INFO    : Bus 76496	: V=0.9876118, theta=-2.71514 -> V=1.0, theta=0.0
% INFO    : Bus 76497	: V=0.9864178, theta=-2.84149 -> V=1.0, theta=0.0
% INFO    : Bus 76498	: V=0.9829362, theta=-3.402727 -> V=1.0, theta=0.0
% INFO    : Bus 76499	: V=0.9816254, theta=-2.857706 -> V=1.0, theta=0.0
% INFO    : Bus 76500	: V=0.9916908, theta=-1.716311 -> V=1.0, theta=0.0
% INFO    : Bus 76501	: V=0.9929813, theta=-1.70021 -> V=1.0, theta=0.0
% INFO    : Bus 76502	: V=0.9911853, theta=-1.533479 -> V=1.0, theta=0.0
% INFO    : Bus 76503	: V=0.9904764, theta=-1.351241 -> V=1.0, theta=0.0
% INFO    : Bus 76504	: V=0.9895559, theta=-2.131688 -> V=1.0, theta=0.0
% INFO    : Bus 76505	: V=0.9913684, theta=-1.829567 -> V=1.0, theta=0.0
% INFO    : Bus 76506	: V=1.0125603, theta=2.732218 -> V=1.0, theta=0.0
% INFO    : Bus 76507	: V=1.0084315, theta=1.814812 -> V=1.0, theta=0.0
% INFO    : Bus 76508	: V=1.0007396, theta=-0.001 -> V=1.0, theta=0.0
% INFO    : Bus 76509	: V=0.9843309, theta=-2.463452 -> V=1.0, theta=0.0
% INFO    : Bus 76510	: V=0.9920081, theta=-1.438352 -> V=1.0, theta=0.0
% INFO    : Bus 76511	: V=0.9937779, theta=-1.32975 -> V=1.0, theta=0.0
% INFO    : Bus 76512	: V=0.9933092, theta=-1.291062 -> V=1.0, theta=0.0
% INFO    : Bus 76513	: V=0.9895865, theta=-1.889722 -> V=1.0, theta=0.0
% INFO    : Bus 76514	: V=0.9858926, theta=-2.388663 -> V=1.0, theta=0.0
% INFO    : Bus 76515	: V=0.9908027, theta=-1.82 -> V=1.0, theta=0.0
% INFO    : Bus 76516	: V=0.9865797, theta=-2.283001 -> V=1.0, theta=0.0
% INFO    : Bus 76517	: V=0.9906811, theta=-1.400273 -> V=1.0, theta=0.0
% INFO    : Bus 76518	: V=0.9909251, theta=-1.581688 -> V=1.0, theta=0.0
% INFO    : Bus 76519	: V=0.9957739, theta=-0.375325 -> V=1.0, theta=0.0
% INFO    : Bus 76520	: V=0.9985572, theta=-0.677869 -> V=1.0, theta=0.0
% INFO    : Bus 76521	: V=1.0038742, theta=0.765595 -> V=1.0, theta=0.0
% INFO    : Bus 76522	: V=0.9886847, theta=-1.617152 -> V=1.0, theta=0.0
% INFO    : Bus 76523	: V=0.9815993, theta=-3.372807 -> V=1.0, theta=0.0
% INFO    : Bus 76524	: V=0.9889944, theta=-1.884372 -> V=1.0, theta=0.0
% INFO    : Bus 76525	: V=1.0016772, theta=18.503461 -> V=1.0, theta=0.0
% INFO    : Bus 76526	: V=1.007442, theta=19.637851 -> V=1.0, theta=0.0
% INFO    : Bus 76527	: V=1.0044965, theta=19.322531 -> V=1.0, theta=0.0
% INFO    : Bus 76528	: V=1.0008831, theta=18.606504 -> V=1.0, theta=0.0
% INFO    : Bus 76529	: V=1.0011258, theta=17.496109 -> V=1.0, theta=0.0
% INFO    : Bus 76530	: V=1.0020352, theta=18.489418 -> V=1.0, theta=0.0
% INFO    : Bus 76531	: V=0.9974847, theta=18.32779 -> V=1.0, theta=0.0
% INFO    : Bus 76532	: V=0.9984386, theta=18.283991 -> V=1.0, theta=0.0
% INFO    : Bus 76533	: V=1.0046206, theta=18.97804 -> V=1.0, theta=0.0
% INFO    : Bus 76534	: V=1.0111301, theta=21.256082 -> V=1.0, theta=0.0
% INFO    : Bus 76535	: V=1.0093933, theta=20.261191 -> V=1.0, theta=0.0
% INFO    : Bus 76536	: V=1.009033, theta=20.095905 -> V=1.0, theta=0.0
% INFO    : Bus 76537	: V=1.0044898, theta=18.745407 -> V=1.0, theta=0.0
% INFO    : Bus 76538	: V=1.0060464, theta=18.705495 -> V=1.0, theta=0.0
% INFO    : Bus 76539	: V=0.9960734, theta=17.13643 -> V=1.0, theta=0.0
% INFO    : Bus 76540	: V=1.0037764, theta=17.700866 -> V=1.0, theta=0.0
% INFO    : Bus 76541	: V=1.0104082, theta=19.021008 -> V=1.0, theta=0.0
% INFO    : Bus 76542	: V=1.0078479, theta=18.840329 -> V=1.0, theta=0.0
% INFO    : Bus 76543	: V=1.0068105, theta=18.730275 -> V=1.0, theta=0.0
% INFO    : Bus 76544	: V=1.0045472, theta=17.908479 -> V=1.0, theta=0.0
% INFO    : Bus 76545	: V=1.0041527, theta=17.92046 -> V=1.0, theta=0.0
% INFO    : Bus 76546	: V=1.0129698, theta=19.121277 -> V=1.0, theta=0.0
% INFO    : Bus 76547	: V=1.0123359, theta=18.88105 -> V=1.0, theta=0.0
% INFO    : Bus 76548	: V=1.0032993, theta=17.871289 -> V=1.0, theta=0.0
% INFO    : Bus 76549	: V=0.9955773, theta=17.355449 -> V=1.0, theta=0.0
% INFO    : Bus 76550	: V=0.996174, theta=19.474976 -> V=1.0, theta=0.0
% INFO    : Bus 76551	: V=0.9940462, theta=19.520544 -> V=1.0, theta=0.0
% INFO    : Bus 76552	: V=0.9988066, theta=20.818722 -> V=1.0, theta=0.0
% INFO    : Bus 76553	: V=1.0010995, theta=17.410596 -> V=1.0, theta=0.0
% INFO    : Bus 76554	: V=1.0004084, theta=17.199581 -> V=1.0, theta=0.0
% INFO    : Bus 76555	: V=0.9965292, theta=16.881575 -> V=1.0, theta=0.0
% INFO    : Bus 76556	: V=0.9948024, theta=20.368406 -> V=1.0, theta=0.0
% INFO    : Bus 76557	: V=0.9924639, theta=21.404375 -> V=1.0, theta=0.0
% INFO    : Bus 76558	: V=0.9982516, theta=27.296118 -> V=1.0, theta=0.0
% INFO    : Bus 76559	: V=1.0110993, theta=25.173299 -> V=1.0, theta=0.0
% INFO    : Bus 76560	: V=0.9919269, theta=-2.632027 -> V=1.0, theta=0.0
% INFO    : Bus 76561	: V=0.9923713, theta=-2.124313 -> V=1.0, theta=0.0
% INFO    : Bus 76562	: V=0.9923145, theta=-2.516119 -> V=1.0, theta=0.0
% INFO    : Bus 76563	: V=0.9985456, theta=-1.869165 -> V=1.0, theta=0.0
% INFO    : Bus 76564	: V=0.9980287, theta=-1.662784 -> V=1.0, theta=0.0
% INFO    : Bus 76565	: V=0.9998452, theta=-1.588004 -> V=1.0, theta=0.0
% INFO    : Bus 76566	: V=1.0016041, theta=-1.062131 -> V=1.0, theta=0.0
% INFO    : Bus 76567	: V=0.9939184, theta=-2.274117 -> V=1.0, theta=0.0
% INFO    : Bus 76568	: V=1.0077057, theta=-0.15754 -> V=1.0, theta=0.0
% INFO    : Bus 76569	: V=1.00692, theta=-0.387918 -> V=1.0, theta=0.0
% INFO    : Bus 76570	: V=1.0085772, theta=0.023765 -> V=1.0, theta=0.0
% INFO    : Bus 76571	: V=1.0085385, theta=-0.124417 -> V=1.0, theta=0.0
% INFO    : Bus 76572	: V=1.0145069, theta=20.193108 -> V=1.0, theta=0.0
% INFO    : Bus 76573	: V=1.0119029, theta=19.832099 -> V=1.0, theta=0.0
% INFO    : Bus 76574	: V=1.0079961, theta=18.455119 -> V=1.0, theta=0.0
% INFO    : Bus 76575	: V=1.01362, theta=20.493786 -> V=1.0, theta=0.0
% INFO    : Bus 76576	: V=1.0174393, theta=19.976177 -> V=1.0, theta=0.0
% INFO    : Bus 76577	: V=1.0019958, theta=2.735209 -> V=1.0, theta=0.0
% INFO    : Bus 76578	: V=1.0146115, theta=4.328815 -> V=1.0, theta=0.0
% INFO    : Bus 76579	: V=1.0136643, theta=4.121723 -> V=1.0, theta=0.0
% INFO    : Bus 76580	: V=1.0037444, theta=2.686327 -> V=1.0, theta=0.0
% INFO    : Bus 76581	: V=1.0027226, theta=2.225941 -> V=1.0, theta=0.0
% INFO    : Bus 76582	: V=1.0065676, theta=2.496945 -> V=1.0, theta=0.0
% INFO    : Bus 76583	: V=1.0086671, theta=3.602029 -> V=1.0, theta=0.0
% INFO    : Bus 76584	: V=0.9981981, theta=1.099911 -> V=1.0, theta=0.0
% INFO    : Bus 76585	: V=1.0058423, theta=2.077354 -> V=1.0, theta=0.0
% INFO    : Bus 76586	: V=1.0110279, theta=20.215529 -> V=1.0, theta=0.0
% INFO    : Bus 76587	: V=1.0112011, theta=19.724816 -> V=1.0, theta=0.0
% INFO    : Bus 76588	: V=1.0104717, theta=19.367698 -> V=1.0, theta=0.0
% INFO    : Bus 76589	: V=1.012025, theta=20.211472 -> V=1.0, theta=0.0
% INFO    : Bus 76590	: V=1.0034637, theta=18.280192 -> V=1.0, theta=0.0
% INFO    : Bus 76591	: V=1.001404, theta=18.956042 -> V=1.0, theta=0.0
% INFO    : Bus 76592	: V=1.0175391, theta=21.551539 -> V=1.0, theta=0.0
% INFO    : Bus 76593	: V=1.0115569, theta=16.046176 -> V=1.0, theta=0.0
% INFO    : Bus 76594	: V=1.0179244, theta=17.15758 -> V=1.0, theta=0.0
% INFO    : Bus 76595	: V=1.0151182, theta=17.006968 -> V=1.0, theta=0.0
% INFO    : Bus 76596	: V=1.0110691, theta=16.000049 -> V=1.0, theta=0.0
% INFO    : Bus 76597	: V=1.0068426, theta=15.521423 -> V=1.0, theta=0.0
% INFO    : Bus 76598	: V=1.0143891, theta=16.580224 -> V=1.0, theta=0.0
% INFO    : Bus 76599	: V=1.0120218, theta=15.774726 -> V=1.0, theta=0.0
% INFO    : Bus 76600	: V=1.0086339, theta=15.873568 -> V=1.0, theta=0.0
% INFO    : Bus 76601	: V=1.0068395, theta=15.779889 -> V=1.0, theta=0.0
% INFO    : Bus 76602	: V=1.0183371, theta=17.283239 -> V=1.0, theta=0.0
% INFO    : Bus 76603	: V=1.0177579, theta=17.074066 -> V=1.0, theta=0.0
% INFO    : Bus 76604	: V=1.0152301, theta=16.804225 -> V=1.0, theta=0.0
% INFO    : Bus 76605	: V=1.0122619, theta=16.119549 -> V=1.0, theta=0.0
% INFO    : Bus 76606	: V=1.0257104, theta=20.408843 -> V=1.0, theta=0.0
% INFO    : Bus 76607	: V=1.0254157, theta=19.942629 -> V=1.0, theta=0.0
% INFO    : Bus 76608	: V=1.0011919, theta=17.679725 -> V=1.0, theta=0.0
% INFO    : Bus 76609	: V=0.9995293, theta=17.748795 -> V=1.0, theta=0.0
% INFO    : Bus 76610	: V=1.0090719, theta=17.14464 -> V=1.0, theta=0.0
% INFO    : Bus 76611	: V=1.0145173, theta=15.761361 -> V=1.0, theta=0.0
% INFO    : Bus 76612	: V=1.0173748, theta=13.617054 -> V=1.0, theta=0.0
% INFO    : Bus 76613	: V=1.0054834, theta=15.500839 -> V=1.0, theta=0.0
% INFO    : Bus 76614	: V=0.9976479, theta=15.714847 -> V=1.0, theta=0.0
% INFO    : Bus 76615	: V=0.9961184, theta=13.657943 -> V=1.0, theta=0.0
% INFO    : Bus 76616	: V=1.0236378, theta=21.002723 -> V=1.0, theta=0.0
% INFO    : Bus 76617	: V=1.0231318, theta=20.948596 -> V=1.0, theta=0.0
% INFO    : Bus 76618	: V=1.0191311, theta=20.699888 -> V=1.0, theta=0.0
% INFO    : Bus 76619	: V=1.0173031, theta=20.50583 -> V=1.0, theta=0.0
% INFO    : Bus 76620	: V=1.028602, theta=16.287919 -> V=1.0, theta=0.0
% INFO    : Bus 76621	: V=1.0279747, theta=15.958372 -> V=1.0, theta=0.0
% INFO    : Bus 76622	: V=0.9990612, theta=26.750363 -> V=1.0, theta=0.0
% INFO    : Bus 76623	: V=1.005764, theta=26.740903 -> V=1.0, theta=0.0
% INFO    : Bus 76624	: V=0.9971991, theta=24.876115 -> V=1.0, theta=0.0
% INFO    : Bus 76625	: V=1.0204778, theta=28.385783 -> V=1.0, theta=0.0
% INFO    : Bus 76626	: V=0.9954211, theta=24.874509 -> V=1.0, theta=0.0
% INFO    : Bus 76627	: V=1.0239463, theta=31.43567 -> V=1.0, theta=0.0
% INFO    : Bus 76628	: V=1.0228388, theta=31.303851 -> V=1.0, theta=0.0
% INFO    : Bus 76629	: V=1.00985, theta=30.680194 -> V=1.0, theta=0.0
% INFO    : Bus 76630	: V=1.0124592, theta=30.256944 -> V=1.0, theta=0.0
% INFO    : Bus 76631	: V=1.0067708, theta=23.540134 -> V=1.0, theta=0.0
% INFO    : Bus 76632	: V=1.0259827, theta=25.986943 -> V=1.0, theta=0.0
% INFO    : Bus 76633	: V=1.0254255, theta=25.787622 -> V=1.0, theta=0.0
% INFO    : Bus 76634	: V=1.0088245, theta=23.355485 -> V=1.0, theta=0.0
% INFO    : Bus 76635	: V=1.0100981, theta=29.672177 -> V=1.0, theta=0.0
% INFO    : Bus 76636	: V=1.0071376, theta=28.882132 -> V=1.0, theta=0.0
% INFO    : Bus 76637	: V=0.9940927, theta=22.267207 -> V=1.0, theta=0.0
% INFO    : Bus 76638	: V=1.0161277, theta=24.339886 -> V=1.0, theta=0.0
% INFO    : Bus 76639	: V=1.0092433, theta=23.190918 -> V=1.0, theta=0.0
% INFO    : Bus 76640	: V=1.0079838, theta=22.773121 -> V=1.0, theta=0.0
% INFO    : Bus 76641	: V=1.0018659, theta=21.636772 -> V=1.0, theta=0.0
% INFO    : Bus 76642	: V=1.0161199, theta=24.348226 -> V=1.0, theta=0.0
% INFO    : Bus 76643	: V=1.0100667, theta=23.234068 -> V=1.0, theta=0.0
% INFO    : Bus 76644	: V=1.0081978, theta=22.916395 -> V=1.0, theta=0.0
% INFO    : Bus 76645	: V=1.0030457, theta=21.481959 -> V=1.0, theta=0.0
% INFO    : Bus 76646	: V=1.0080729, theta=22.930152 -> V=1.0, theta=0.0
% INFO    : Bus 76647	: V=1.010517, theta=23.142605 -> V=1.0, theta=0.0
% INFO    : Bus 76648	: V=0.9926493, theta=23.853419 -> V=1.0, theta=0.0
% INFO    : Bus 76649	: V=0.9954508, theta=10.816597 -> V=1.0, theta=0.0
% INFO    : Bus 76650	: V=0.9939954, theta=8.808749 -> V=1.0, theta=0.0
% INFO    : Bus 76651	: V=1.0256931, theta=20.880476 -> V=1.0, theta=0.0
% INFO    : Bus 76652	: V=0.9951458, theta=27.545943 -> V=1.0, theta=0.0
% INFO    : Bus 76653	: V=0.9939405, theta=27.524813 -> V=1.0, theta=0.0
% INFO    : Bus 76654	: V=0.9941898, theta=27.427679 -> V=1.0, theta=0.0
% INFO    : Bus 76655	: V=0.9980022, theta=27.961839 -> V=1.0, theta=0.0
% INFO    : Bus 76656	: V=0.9973548, theta=27.590227 -> V=1.0, theta=0.0
% INFO    : Bus 76657	: V=0.9952384, theta=27.497203 -> V=1.0, theta=0.0
% INFO    : Bus 76658	: V=0.9961355, theta=27.693012 -> V=1.0, theta=0.0
% INFO    : Bus 76659	: V=0.9976736, theta=27.716921 -> V=1.0, theta=0.0
% INFO    : Bus 76660	: V=0.9971685, theta=27.581366 -> V=1.0, theta=0.0
% INFO    : Bus 76661	: V=1.0105019, theta=12.877043 -> V=1.0, theta=0.0
% INFO    : Bus 76662	: V=1.0061399, theta=11.816345 -> V=1.0, theta=0.0
% INFO    : Bus 76663	: V=1.01533, theta=10.307219 -> V=1.0, theta=0.0
% INFO    : Bus 76664	: V=1.02948, theta=32.60838 -> V=1.0, theta=0.0
% INFO    : Bus 76665	: V=1.0164753, theta=19.16322 -> V=1.0, theta=0.0
% INFO    : Bus 76666	: V=1.013208, theta=18.506203 -> V=1.0, theta=0.0
% INFO    : Bus 76667	: V=1.0241147, theta=19.671646 -> V=1.0, theta=0.0
% INFO    : Bus 76668	: V=1.0229944, theta=18.006231 -> V=1.0, theta=0.0
% INFO    : Bus 76669	: V=1.0205599, theta=17.836276 -> V=1.0, theta=0.0
% INFO    : Bus 76670	: V=1.0085461, theta=18.505673 -> V=1.0, theta=0.0
% INFO    : Bus 76671	: V=1.0288807, theta=22.775924 -> V=1.0, theta=0.0
% INFO    : Bus 76672	: V=1.0285377, theta=22.803673 -> V=1.0, theta=0.0
% INFO    : Bus 76673	: V=1.0200747, theta=24.732894 -> V=1.0, theta=0.0
% INFO    : Bus 76674	: V=1.0208176, theta=24.110626 -> V=1.0, theta=0.0
% INFO    : Bus 76675	: V=1.0200269, theta=24.481334 -> V=1.0, theta=0.0
% INFO    : Bus 76676	: V=1.0186654, theta=24.848093 -> V=1.0, theta=0.0
% INFO    : Bus 76677	: V=1.0109423, theta=24.264955 -> V=1.0, theta=0.0
% INFO    : Bus 76678	: V=1.0211607, theta=25.659325 -> V=1.0, theta=0.0
% INFO    : Bus 76679	: V=1.0189113, theta=25.467478 -> V=1.0, theta=0.0
% INFO    : Bus 76680	: V=1.0168622, theta=24.981126 -> V=1.0, theta=0.0
% INFO    : Bus 76681	: V=1.0213298, theta=8.17506 -> V=1.0, theta=0.0
% INFO    : Bus 76682	: V=1.018964, theta=7.403251 -> V=1.0, theta=0.0
% INFO    : Bus 76683	: V=1.008703, theta=19.549278 -> V=1.0, theta=0.0
% INFO    : Bus 76684	: V=1.0091316, theta=15.680627 -> V=1.0, theta=0.0
% INFO    : Bus 76685	: V=0.9834938, theta=14.47359 -> V=1.0, theta=0.0
% INFO    : Bus 76686	: V=1.0136934, theta=27.724334 -> V=1.0, theta=0.0
% INFO    : Bus 76687	: V=1.0170983, theta=27.731065 -> V=1.0, theta=0.0
% INFO    : Bus 76688	: V=1.0135624, theta=27.126278 -> V=1.0, theta=0.0
% INFO    : Bus 76689	: V=1.0220848, theta=11.205903 -> V=1.0, theta=0.0
% INFO    : Bus 76690	: V=1.0219126, theta=10.348669 -> V=1.0, theta=0.0
% INFO    : Bus 76691	: V=1.0223756, theta=9.752492 -> V=1.0, theta=0.0
% INFO    : Bus 76692	: V=1.0219834, theta=9.184784 -> V=1.0, theta=0.0
% INFO    : Bus 76693	: V=1.023438, theta=49.852937 -> V=1.0, theta=0.0
% INFO    : Bus 76694	: V=1.0222872, theta=49.63587 -> V=1.0, theta=0.0
% INFO    : Bus 76695	: V=1.0240824, theta=49.947464 -> V=1.0, theta=0.0
% INFO    : Bus 76696	: V=1.0315653, theta=30.942029 -> V=1.0, theta=0.0
% INFO    : Bus 76697	: V=1.0332389, theta=30.638166 -> V=1.0, theta=0.0
% INFO    : Bus 76698	: V=1.0235006, theta=32.635143 -> V=1.0, theta=0.0
% INFO    : Bus 76699	: V=1.016765, theta=8.098086 -> V=1.0, theta=0.0
% INFO    : Bus 76700	: V=1.0160195, theta=7.331553 -> V=1.0, theta=0.0
% INFO    : Bus 76701	: V=1.0172076, theta=-18.206723 -> V=1.0, theta=0.0
% INFO    : Bus 76702	: V=1.0189496, theta=-18.280774 -> V=1.0, theta=0.0
% INFO    : Bus 76703	: V=1.0096191, theta=4.996493 -> V=1.0, theta=0.0
% INFO    : Bus 76704	: V=1.0160578, theta=10.104495 -> V=1.0, theta=0.0
% INFO    : Bus 76705	: V=1.0201082, theta=9.66011 -> V=1.0, theta=0.0
% INFO    : Bus 76706	: V=1.0120277, theta=0.467524 -> V=1.0, theta=0.0
% INFO    : Bus 76707	: V=1.0230334, theta=9.988079 -> V=1.0, theta=0.0
% INFO    : Bus 76708	: V=1.0204997, theta=-14.043558 -> V=1.0, theta=0.0
% INFO    : Bus 76709	: V=1.0176001, theta=7.949523 -> V=1.0, theta=0.0
% INFO    : Bus 76710	: V=1.0200254, theta=8.322771 -> V=1.0, theta=0.0
% INFO    : Bus 76711	: V=1.0208242, theta=7.967502 -> V=1.0, theta=0.0
% INFO    : Bus 76712	: V=1.0208021, theta=7.943496 -> V=1.0, theta=0.0
% INFO    : Bus 76713	: V=1.0053524, theta=-7.590013 -> V=1.0, theta=0.0
% INFO    : Bus 76714	: V=1.0061549, theta=-7.83179 -> V=1.0, theta=0.0
% INFO    : Bus 76715	: V=1.0046911, theta=-2.516248 -> V=1.0, theta=0.0
% INFO    : Bus 76716	: V=1.0188026, theta=48.45017 -> V=1.0, theta=0.0
% INFO    : Bus 76717	: V=1.0056413, theta=-3.259969 -> V=1.0, theta=0.0
% INFO    : Bus 76718	: V=1.0271428, theta=25.942135 -> V=1.0, theta=0.0
% INFO    : Bus 76719	: V=1.01, theta=-4.063831 -> V=1.0, theta=0.0
% INFO    : Bus 76720	: V=1.0110327, theta=-4.779447 -> V=1.0, theta=0.0
% INFO    : Bus 76721	: V=1.0115455, theta=1.341226 -> V=1.0, theta=0.0
% INFO    : Bus 76722	: V=0.9857195, theta=-10.125872 -> V=1.0, theta=0.0
% INFO    : Bus 76723	: V=1.0052961, theta=-0.458271 -> V=1.0, theta=0.0
% INFO    : Bus 76724	: V=1.0093612, theta=20.765684 -> V=1.0, theta=0.0
% INFO    : Bus 76725	: V=1.0000001, theta=-20.110367 -> V=1.0, theta=0.0
% INFO    : Bus 76726	: V=1.007271, theta=0.264121 -> V=1.0, theta=0.0
% INFO    : Bus 76727	: V=1.0175963, theta=-13.636503 -> V=1.0, theta=0.0
% INFO    : Bus 76728	: V=1.0165459, theta=-14.156216 -> V=1.0, theta=0.0
% INFO    : Bus 76729	: V=1.003942, theta=-2.10594 -> V=1.0, theta=0.0
% INFO    : Bus 76730	: V=1.0076397, theta=-2.459308 -> V=1.0, theta=0.0
% INFO    : Bus 76731	: V=1.0155145, theta=-3.597027 -> V=1.0, theta=0.0
% INFO    : Bus 76732	: V=1.0141477, theta=-4.400936 -> V=1.0, theta=0.0
% INFO    : Bus 76733	: V=1.0218218, theta=-19.939438 -> V=1.0, theta=0.0
% INFO    : Bus 76734	: V=1.0201761, theta=-19.849193 -> V=1.0, theta=0.0
% INFO    : Bus 76735	: V=1.0189267, theta=-19.68058 -> V=1.0, theta=0.0
% INFO    : Bus 76736	: V=0.9866365, theta=-2.632182 -> V=1.0, theta=0.0
% INFO    : Bus 76737	: V=1.0034275, theta=0.864939 -> V=1.0, theta=0.0
% INFO    : Bus 76738	: V=1.0, theta=19.277519 -> V=1.0, theta=0.0
% INFO    : Bus 76739	: V=1.0, theta=-7.45637 -> V=1.0, theta=0.0
% INFO    : Bus 76740	: V=1.0066293, theta=-19.988468 -> V=1.0, theta=0.0
% INFO    : Bus 76741	: V=1.0076859, theta=-19.965122 -> V=1.0, theta=0.0
% INFO    : Bus 76742	: V=1.017694, theta=27.90425 -> V=1.0, theta=0.0
% INFO    : Bus 76743	: V=1.0108775, theta=27.796073 -> V=1.0, theta=0.0
% INFO    : Bus 76744	: V=1.0118595, theta=27.9065 -> V=1.0, theta=0.0
% INFO    : Bus 76745	: V=1.0236862, theta=31.789256 -> V=1.0, theta=0.0
% INFO    : Bus 76746	: V=1.0212746, theta=31.196989 -> V=1.0, theta=0.0
% INFO    : Bus 76747	: V=1.0139456, theta=27.337547 -> V=1.0, theta=0.0
% INFO    : Bus 76748	: V=1.0140253, theta=26.919651 -> V=1.0, theta=0.0
% INFO    : Bus 76749	: V=1.0143105, theta=24.294826 -> V=1.0, theta=0.0
% INFO    : Bus 76750	: V=1.0102251, theta=21.772117 -> V=1.0, theta=0.0
% INFO    : Bus 76751	: V=1.0075597, theta=9.849578 -> V=1.0, theta=0.0
% INFO    : Bus 76752	: V=1.0121687, theta=13.39145 -> V=1.0, theta=0.0
% INFO    : Bus 76753	: V=1.0123162, theta=13.117465 -> V=1.0, theta=0.0
% INFO    : Bus 76754	: V=1.0266298, theta=28.683604 -> V=1.0, theta=0.0
% INFO    : Bus 76755	: V=1.0225059, theta=27.452589 -> V=1.0, theta=0.0
% INFO    : Bus 76756	: V=1.0132095, theta=14.427855 -> V=1.0, theta=0.0
% INFO    : Bus 76757	: V=1.0049575, theta=13.289533 -> V=1.0, theta=0.0
% INFO    : Bus 76758	: V=1.0035125, theta=13.15924 -> V=1.0, theta=0.0
% INFO    : Bus 76759	: V=1.0107181, theta=14.665948 -> V=1.0, theta=0.0
% INFO    : Bus 76760	: V=1.0091275, theta=24.227205 -> V=1.0, theta=0.0
% INFO    : Bus 76761	: V=1.0200003, theta=24.06649 -> V=1.0, theta=0.0
% INFO    : Bus 76762	: V=1.0145001, theta=23.857609 -> V=1.0, theta=0.0
% INFO    : Bus 76763	: V=1.0239812, theta=18.943959 -> V=1.0, theta=0.0
% INFO    : Bus 76764	: V=1.0215504, theta=17.786584 -> V=1.0, theta=0.0
% INFO    : Bus 76765	: V=1.0218436, theta=17.699976 -> V=1.0, theta=0.0
% INFO    : Bus 76766	: V=1.0114347, theta=12.027248 -> V=1.0, theta=0.0
% INFO    : Bus 76767	: V=1.0076924, theta=31.22652 -> V=1.0, theta=0.0
% INFO    : Bus 76768	: V=1.0098967, theta=21.815769 -> V=1.0, theta=0.0
% INFO    : Bus 76769	: V=1.0087936, theta=26.23665 -> V=1.0, theta=0.0
% INFO    : Bus 76770	: V=1.0077619, theta=25.181649 -> V=1.0, theta=0.0
% INFO    : Bus 76771	: V=1.0088454, theta=21.962492 -> V=1.0, theta=0.0
% INFO    : Bus 76772	: V=1.007511, theta=10.926058 -> V=1.0, theta=0.0
% INFO    : Bus 76773	: V=1.0068791, theta=21.97153 -> V=1.0, theta=0.0
% INFO    : Bus 76774	: V=1.0121726, theta=26.622039 -> V=1.0, theta=0.0
% INFO    : Bus 76775	: V=1.0012118, theta=13.105708 -> V=1.0, theta=0.0
% INFO    : Bus 76776	: V=1.0059217, theta=16.022542 -> V=1.0, theta=0.0
% INFO    : Bus 76777	: V=1.0099915, theta=24.005374 -> V=1.0, theta=0.0
% INFO    : Bus 76778	: V=0.997026, theta=11.457997 -> V=1.0, theta=0.0
% INFO    : Bus 76779	: V=1.0080578, theta=24.751738 -> V=1.0, theta=0.0
% INFO    : Bus 76780	: V=1.0081506, theta=25.941006 -> V=1.0, theta=0.0
% INFO    : Bus 76781	: V=1.0108757, theta=15.797306 -> V=1.0, theta=0.0
% INFO    : Bus 76782	: V=1.0027816, theta=17.348013 -> V=1.0, theta=0.0
% INFO    : Bus 76783	: V=1.0063944, theta=24.092685 -> V=1.0, theta=0.0
% INFO    : Bus 76784	: V=1.01418, theta=28.638523 -> V=1.0, theta=0.0
% INFO    : Bus 76785	: V=1.0143981, theta=28.187069 -> V=1.0, theta=0.0
% INFO    : Bus 76786	: V=1.0023442, theta=40.503298 -> V=1.0, theta=0.0
% INFO    : Bus 76787	: V=1.0197243, theta=45.767143 -> V=1.0, theta=0.0
% INFO    : Bus 76788	: V=1.0192863, theta=45.300836 -> V=1.0, theta=0.0
% INFO    : Bus 76789	: V=1.0083154, theta=21.765916 -> V=1.0, theta=0.0
% INFO    : Bus 76790	: V=1.0096889, theta=2.926822 -> V=1.0, theta=0.0
% INFO    : Bus 76791	: V=1.009212, theta=2.78406 -> V=1.0, theta=0.0
% INFO    : Bus 76792	: V=1.0257144, theta=46.689519 -> V=1.0, theta=0.0
% INFO    : Bus 76793	: V=1.0248589, theta=46.182207 -> V=1.0, theta=0.0
% INFO    : Bus 76794	: V=1.0228738, theta=45.790777 -> V=1.0, theta=0.0
% INFO    : Bus 76795	: V=1.0217874, theta=45.19428 -> V=1.0, theta=0.0
% INFO    : Bus 76796	: V=1.0055047, theta=1.137688 -> V=1.0, theta=0.0
% INFO    : Bus 76797	: V=1.0052169, theta=0.910664 -> V=1.0, theta=0.0
% INFO    : Bus 76798	: V=1.0158136, theta=8.925844 -> V=1.0, theta=0.0
% INFO    : Bus 76799	: V=1.0176364, theta=9.041079 -> V=1.0, theta=0.0
% INFO    : Bus 76800	: V=1.0079285, theta=5.322585 -> V=1.0, theta=0.0
% INFO    : Bus 76801	: V=1.0071597, theta=2.568523 -> V=1.0, theta=0.0
% INFO    : Bus 76802	: V=1.0077884, theta=-1.217008 -> V=1.0, theta=0.0
% INFO    : Bus 76803	: V=1.0047309, theta=10.626304 -> V=1.0, theta=0.0
% INFO    : Bus 76804	: V=1.0100001, theta=1.601089 -> V=1.0, theta=0.0
% INFO    : Bus 76805	: V=1.002424, theta=7.304796 -> V=1.0, theta=0.0
% INFO    : Bus 76806	: V=1.0082115, theta=1.298075 -> V=1.0, theta=0.0
% INFO    : Bus 76807	: V=1.0100345, theta=12.168796 -> V=1.0, theta=0.0
% INFO    : Bus 76808	: V=1.0100254, theta=11.136631 -> V=1.0, theta=0.0
% INFO    : Bus 76809	: V=0.9919052, theta=37.158804 -> V=1.0, theta=0.0
% INFO    : Bus 76810	: V=1.0260419, theta=-21.714395 -> V=1.0, theta=0.0
% INFO    : Bus 76811	: V=1.0223267, theta=-20.446108 -> V=1.0, theta=0.0
% INFO    : Bus 76812	: V=1.0207013, theta=-20.160216 -> V=1.0, theta=0.0
% INFO    : Bus 76813	: V=1.0200616, theta=-20.13718 -> V=1.0, theta=0.0
% INFO    : Bus 76814	: V=1.0050191, theta=-15.902738 -> V=1.0, theta=0.0
% INFO    : Bus 76815	: V=1.0066994, theta=-15.745528 -> V=1.0, theta=0.0
% INFO    : Bus 76816	: V=0.9985351, theta=-11.134502 -> V=1.0, theta=0.0
% INFO    : Bus 76817	: V=1.0096232, theta=-17.997895 -> V=1.0, theta=0.0
% INFO    : Bus 76818	: V=1.02098, theta=-13.890944 -> V=1.0, theta=0.0
% INFO    : Bus 76819	: V=1.013157, theta=-14.211115 -> V=1.0, theta=0.0
% INFO    : Bus 76820	: V=1.0194464, theta=-14.477287 -> V=1.0, theta=0.0
% INFO    : Bus 76821	: V=1.0179334, theta=-14.749746 -> V=1.0, theta=0.0
% INFO    : Bus 76822	: V=1.015491, theta=-17.124083 -> V=1.0, theta=0.0
% INFO    : Bus 76823	: V=1.0196456, theta=-14.523776 -> V=1.0, theta=0.0
% INFO    : Bus 76824	: V=1.0134421, theta=-16.150673 -> V=1.0, theta=0.0
% INFO    : Bus 76825	: V=1.0186552, theta=-13.300463 -> V=1.0, theta=0.0
% INFO    : Bus 76826	: V=1.018051, theta=-13.644077 -> V=1.0, theta=0.0
% INFO    : Bus 76827	: V=1.020829, theta=-11.203111 -> V=1.0, theta=0.0
% INFO    : Bus 76828	: V=1.0204219, theta=-10.845205 -> V=1.0, theta=0.0
% INFO    : Bus 76829	: V=1.016624, theta=-14.424462 -> V=1.0, theta=0.0
% INFO    : Bus 76830	: V=1.0141607, theta=-14.952403 -> V=1.0, theta=0.0
% INFO    : Bus 76831	: V=1.0145436, theta=-15.981736 -> V=1.0, theta=0.0
% INFO    : Bus 76832	: V=1.0118216, theta=-15.806198 -> V=1.0, theta=0.0
% INFO    : Bus 76833	: V=1.0205081, theta=-68.630793 -> V=1.0, theta=0.0
% INFO    : Bus 76834	: V=1.0134875, theta=-67.577572 -> V=1.0, theta=0.0
% INFO    : Bus 76835	: V=0.9902395, theta=-43.540255 -> V=1.0, theta=0.0
% INFO    : Bus 76836	: V=1.0156688, theta=-15.999229 -> V=1.0, theta=0.0
% INFO    : Bus 76837	: V=0.9920195, theta=-53.676037 -> V=1.0, theta=0.0
% INFO    : Bus 76838	: V=1.009146, theta=-15.546416 -> V=1.0, theta=0.0
% INFO    : Bus 76839	: V=1.0000004, theta=-56.522849 -> V=1.0, theta=0.0
% INFO    : Bus 76840	: V=1.0130397, theta=-68.062045 -> V=1.0, theta=0.0
% INFO    : Bus 76841	: V=1.0000003, theta=-13.239236 -> V=1.0, theta=0.0
% INFO    : Bus 76842	: V=1.0239027, theta=22.732497 -> V=1.0, theta=0.0
% INFO    : Bus 76843	: V=1.0255094, theta=23.005569 -> V=1.0, theta=0.0
% INFO    : Bus 76844	: V=1.0267967, theta=36.314241 -> V=1.0, theta=0.0
% INFO    : Bus 76845	: V=1.0280421, theta=37.131625 -> V=1.0, theta=0.0
% INFO    : Bus 76846	: V=1.0196711, theta=34.077769 -> V=1.0, theta=0.0
% INFO    : Bus 76847	: V=1.0198132, theta=33.50349 -> V=1.0, theta=0.0
% INFO    : Bus 76848	: V=1.0111897, theta=16.476641 -> V=1.0, theta=0.0
% INFO    : Bus 76849	: V=1.0105136, theta=15.48452 -> V=1.0, theta=0.0
% INFO    : Bus 76850	: V=1.0219213, theta=22.026271 -> V=1.0, theta=0.0
% INFO    : Bus 76851	: V=1.0225931, theta=21.609099 -> V=1.0, theta=0.0
% INFO    : Bus 76852	: V=1.0239203, theta=21.625024 -> V=1.0, theta=0.0
% INFO    : Bus 76853	: V=1.0076635, theta=26.700722 -> V=1.0, theta=0.0
% INFO    : Bus 76854	: V=1.0102945, theta=9.760952 -> V=1.0, theta=0.0
% INFO    : Bus 76855	: V=1.0080904, theta=9.303334 -> V=1.0, theta=0.0
% INFO    : Bus 76856	: V=1.0100004, theta=10.621812 -> V=1.0, theta=0.0
% INFO    : Bus 76857	: V=1.0054206, theta=9.921199 -> V=1.0, theta=0.0
% INFO    : Bus 76858	: V=0.9953011, theta=9.379011 -> V=1.0, theta=0.0
% INFO    : Bus 76859	: V=0.9848197, theta=4.426773 -> V=1.0, theta=0.0
% INFO    : Bus 76860	: V=0.984839, theta=3.609509 -> V=1.0, theta=0.0
% INFO    : Bus 76861	: V=1.0131357, theta=25.936272 -> V=1.0, theta=0.0
% INFO    : Bus 76862	: V=1.0009933, theta=35.50909 -> V=1.0, theta=0.0
% INFO    : Bus 76863	: V=0.9941696, theta=26.043937 -> V=1.0, theta=0.0
% INFO    : Bus 76864	: V=0.9986411, theta=30.065715 -> V=1.0, theta=0.0
% INFO    : Bus 76865	: V=1.0004611, theta=29.586396 -> V=1.0, theta=0.0
% INFO    : Bus 76866	: V=1.0015094, theta=24.002862 -> V=1.0, theta=0.0
% INFO    : Bus 76867	: V=0.9975031, theta=21.561164 -> V=1.0, theta=0.0
% INFO    : Bus 76868	: V=1.0114807, theta=26.039603 -> V=1.0, theta=0.0
% INFO    : Bus 76869	: V=0.9922369, theta=-1.97105 -> V=1.0, theta=0.0
% INFO    : Bus 76870	: V=0.9804202, theta=-2.81209 -> V=1.0, theta=0.0
% INFO    : Bus 76871	: V=0.9760372, theta=-3.660955 -> V=1.0, theta=0.0
% INFO    : Bus 76872	: V=0.9832507, theta=-4.208643 -> V=1.0, theta=0.0
% INFO    : Bus 76873	: V=0.9654367, theta=-5.403894 -> V=1.0, theta=0.0
% INFO    : Bus 76874	: V=0.9689647, theta=-4.962703 -> V=1.0, theta=0.0
% INFO    : Bus 76875	: V=0.9713499, theta=-4.657233 -> V=1.0, theta=0.0
% INFO    : Bus 76876	: V=0.9640474, theta=-5.393106 -> V=1.0, theta=0.0
% INFO    : Bus 76877	: V=0.9802841, theta=2.103824 -> V=1.0, theta=0.0
% INFO    : Bus 76878	: V=0.9803307, theta=3.004017 -> V=1.0, theta=0.0
% INFO    : Bus 76879	: V=0.9808232, theta=2.403596 -> V=1.0, theta=0.0
% INFO    : Bus 76880	: V=0.9800749, theta=1.78074 -> V=1.0, theta=0.0
% INFO    : Bus 76881	: V=0.9839985, theta=-1.190098 -> V=1.0, theta=0.0
% INFO    : Bus 76882	: V=1.0161763, theta=47.760051 -> V=1.0, theta=0.0
% INFO    : Bus 76883	: V=1.0067591, theta=46.015408 -> V=1.0, theta=0.0
% INFO    : Bus 76884	: V=1.009796, theta=46.729378 -> V=1.0, theta=0.0
% INFO    : Bus 76885	: V=0.9625415, theta=31.624943 -> V=1.0, theta=0.0
% INFO    : Bus 76886	: V=0.9728133, theta=6.058833 -> V=1.0, theta=0.0
% INFO    : Bus 76887	: V=0.9904982, theta=8.62169 -> V=1.0, theta=0.0
% INFO    : Bus 76888	: V=0.9916896, theta=5.620834 -> V=1.0, theta=0.0
% INFO    : Bus 76889	: V=0.9926438, theta=2.842827 -> V=1.0, theta=0.0
% INFO    : Bus 76890	: V=0.9905536, theta=2.459542 -> V=1.0, theta=0.0
% INFO    : Bus 76891	: V=0.9810615, theta=13.207987 -> V=1.0, theta=0.0
% INFO    : Bus 76892	: V=0.9796618, theta=4.662662 -> V=1.0, theta=0.0
% INFO    : Bus 76893	: V=0.9847477, theta=7.863954 -> V=1.0, theta=0.0
% INFO    : Bus 76894	: V=0.9806407, theta=-12.199795 -> V=1.0, theta=0.0
% INFO    : Bus 76895	: V=0.9923568, theta=-16.439927 -> V=1.0, theta=0.0
% INFO    : Bus 76896	: V=0.9807845, theta=-18.440866 -> V=1.0, theta=0.0
% INFO    : Bus 76897	: V=0.9877521, theta=-20.525914 -> V=1.0, theta=0.0
% INFO    : Bus 76898	: V=0.9911192, theta=-18.532089 -> V=1.0, theta=0.0
% INFO    : Bus 76899	: V=0.9753882, theta=-0.221986 -> V=1.0, theta=0.0
% INFO    : Bus 76900	: V=1.0054673, theta=-1.11029 -> V=1.0, theta=0.0
% INFO    : Bus 76901	: V=0.9952254, theta=0.255266 -> V=1.0, theta=0.0
% INFO    : Bus 76902	: V=0.9958666, theta=0.424629 -> V=1.0, theta=0.0
% INFO    : Bus 76903	: V=0.9898791, theta=-0.600906 -> V=1.0, theta=0.0
% INFO    : Bus 76904	: V=0.988681, theta=-1.409741 -> V=1.0, theta=0.0
% INFO    : Bus 76905	: V=0.9930198, theta=0.078863 -> V=1.0, theta=0.0
% INFO    : Bus 76906	: V=0.9925098, theta=-0.170005 -> V=1.0, theta=0.0
% INFO    : Bus 76907	: V=0.9940467, theta=0.384068 -> V=1.0, theta=0.0
% INFO    : Bus 76908	: V=0.9956559, theta=0.152823 -> V=1.0, theta=0.0
% INFO    : Bus 76909	: V=1.0214614, theta=6.940441 -> V=1.0, theta=0.0
% INFO    : Bus 76910	: V=1.0200955, theta=7.643436 -> V=1.0, theta=0.0
% INFO    : Bus 76911	: V=1.0235137, theta=5.54572 -> V=1.0, theta=0.0
% INFO    : Bus 76912	: V=1.0230885, theta=5.503252 -> V=1.0, theta=0.0
% INFO    : Bus 76913	: V=1.0207322, theta=5.33933 -> V=1.0, theta=0.0
% INFO    : Bus 76914	: V=1.0206992, theta=4.657415 -> V=1.0, theta=0.0
% INFO    : Bus 76915	: V=1.0198483, theta=5.078532 -> V=1.0, theta=0.0
% INFO    : Bus 76916	: V=1.0209592, theta=5.471905 -> V=1.0, theta=0.0
% INFO    : Bus 76917	: V=0.9958891, theta=-0.145471 -> V=1.0, theta=0.0
% INFO    : Bus 76918	: V=0.997135, theta=-0.239125 -> V=1.0, theta=0.0
% INFO    : Bus 76919	: V=1.0119475, theta=2.925948 -> V=1.0, theta=0.0
% INFO    : Bus 76920	: V=1.010057, theta=2.307823 -> V=1.0, theta=0.0
% INFO    : Bus 76921	: V=1.0090067, theta=1.815118 -> V=1.0, theta=0.0
% INFO    : Bus 76922	: V=1.009633, theta=2.03002 -> V=1.0, theta=0.0
% INFO    : Bus 76923	: V=1.0151627, theta=3.127734 -> V=1.0, theta=0.0
% INFO    : Bus 76924	: V=1.01352, theta=3.366099 -> V=1.0, theta=0.0
% INFO    : Bus 76925	: V=1.0120938, theta=2.887273 -> V=1.0, theta=0.0
% INFO    : Bus 76926	: V=1.0103723, theta=2.333915 -> V=1.0, theta=0.0
% INFO    : Bus 76927	: V=1.0158686, theta=3.842231 -> V=1.0, theta=0.0
% INFO    : Bus 76928	: V=1.0142223, theta=3.471229 -> V=1.0, theta=0.0
% INFO    : Bus 76929	: V=0.9945776, theta=-0.086082 -> V=1.0, theta=0.0
% INFO    : Bus 76930	: V=0.9955034, theta=-0.083547 -> V=1.0, theta=0.0
% INFO    : Bus 76931	: V=0.9978873, theta=0.665258 -> V=1.0, theta=0.0
% INFO    : Bus 76932	: V=0.9941587, theta=-0.146675 -> V=1.0, theta=0.0
% INFO    : Bus 76933	: V=0.9957476, theta=-0.243734 -> V=1.0, theta=0.0
% INFO    : Bus 76934	: V=1.0040474, theta=0.879448 -> V=1.0, theta=0.0
% INFO    : Bus 76935	: V=1.0060082, theta=1.5043 -> V=1.0, theta=0.0
% INFO    : Bus 76936	: V=0.99985, theta=-0.232862 -> V=1.0, theta=0.0
% INFO    : Bus 76937	: V=1.0114971, theta=2.508057 -> V=1.0, theta=0.0
% INFO    : Bus 76938	: V=1.0106741, theta=1.944137 -> V=1.0, theta=0.0
% INFO    : Bus 76939	: V=1.0080252, theta=1.692709 -> V=1.0, theta=0.0
% INFO    : Bus 76940	: V=1.0125405, theta=2.560434 -> V=1.0, theta=0.0
% INFO    : Bus 76941	: V=1.010584, theta=2.120729 -> V=1.0, theta=0.0
% INFO    : Bus 76942	: V=1.0099108, theta=2.066195 -> V=1.0, theta=0.0
% INFO    : Bus 76943	: V=0.9954811, theta=-1.255088 -> V=1.0, theta=0.0
% INFO    : Bus 76944	: V=0.9940265, theta=-1.439591 -> V=1.0, theta=0.0
% INFO    : Bus 76945	: V=0.9906835, theta=-1.702186 -> V=1.0, theta=0.0
% INFO    : Bus 76946	: V=0.9946597, theta=-1.409007 -> V=1.0, theta=0.0
% INFO    : Bus 76947	: V=0.999993, theta=-0.315132 -> V=1.0, theta=0.0
% INFO    : Bus 76948	: V=1.0025915, theta=-0.116554 -> V=1.0, theta=0.0
% INFO    : Bus 76949	: V=0.9991334, theta=-0.326301 -> V=1.0, theta=0.0
% INFO    : Bus 76950	: V=0.9960752, theta=-1.34385 -> V=1.0, theta=0.0
% INFO    : Bus 76951	: V=1.0012493, theta=-0.468502 -> V=1.0, theta=0.0
% INFO    : Bus 76952	: V=0.9978449, theta=-1.080944 -> V=1.0, theta=0.0
% INFO    : Bus 76953	: V=1.002213, theta=-0.729258 -> V=1.0, theta=0.0
% INFO    : Bus 76954	: V=1.0065644, theta=0.242465 -> V=1.0, theta=0.0
% INFO    : Bus 76955	: V=1.007234, theta=1.388459 -> V=1.0, theta=0.0
% INFO    : Bus 76956	: V=1.0068314, theta=0.267348 -> V=1.0, theta=0.0
% INFO    : Bus 76957	: V=1.0085888, theta=1.597357 -> V=1.0, theta=0.0
% INFO    : Bus 76958	: V=1.0057875, theta=1.132548 -> V=1.0, theta=0.0
% INFO    : Bus 76959	: V=1.0116861, theta=2.442565 -> V=1.0, theta=0.0
% INFO    : Bus 76960	: V=1.0026174, theta=0.183371 -> V=1.0, theta=0.0
% INFO    : Bus 76961	: V=1.0098642, theta=1.740829 -> V=1.0, theta=0.0
% INFO    : Bus 76962	: V=1.0081233, theta=1.730272 -> V=1.0, theta=0.0
% INFO    : Bus 76963	: V=1.0046927, theta=0.978853 -> V=1.0, theta=0.0
% INFO    : Bus 76964	: V=1.0020114, theta=-0.769398 -> V=1.0, theta=0.0
% INFO    : Bus 76965	: V=0.9994421, theta=-1.143056 -> V=1.0, theta=0.0
% INFO    : Bus 76966	: V=0.9993732, theta=-1.146624 -> V=1.0, theta=0.0
% INFO    : Bus 76967	: V=0.9967039, theta=-1.426234 -> V=1.0, theta=0.0
% INFO    : Bus 76968	: V=0.9979255, theta=-1.200476 -> V=1.0, theta=0.0
% INFO    : Bus 76969	: V=1.0035378, theta=-0.706114 -> V=1.0, theta=0.0
% INFO    : Bus 76970	: V=1.0020418, theta=-0.394169 -> V=1.0, theta=0.0
% INFO    : Bus 76971	: V=1.0032551, theta=-0.504219 -> V=1.0, theta=0.0
% INFO    : Bus 76972	: V=1.0035787, theta=0.073098 -> V=1.0, theta=0.0
% INFO    : Bus 76973	: V=1.0006487, theta=-0.72545 -> V=1.0, theta=0.0
% INFO    : Bus 76974	: V=1.0025614, theta=-0.634396 -> V=1.0, theta=0.0
% INFO    : Bus 76975	: V=0.9750039, theta=-4.218405 -> V=1.0, theta=0.0
% INFO    : Bus 76976	: V=0.9773317, theta=-3.964737 -> V=1.0, theta=0.0
% INFO    : Bus 76977	: V=0.9845202, theta=-3.132676 -> V=1.0, theta=0.0
% INFO    : Bus 76978	: V=0.9806612, theta=-3.425556 -> V=1.0, theta=0.0
% INFO    : Bus 76979	: V=0.982039, theta=-3.367416 -> V=1.0, theta=0.0
% INFO    : Bus 76980	: V=0.9832402, theta=-3.18274 -> V=1.0, theta=0.0
% INFO    : Bus 76981	: V=0.9876852, theta=-2.549311 -> V=1.0, theta=0.0
% INFO    : Bus 76982	: V=0.9946358, theta=-1.704049 -> V=1.0, theta=0.0
% INFO    : Bus 76983	: V=0.9902957, theta=-2.303154 -> V=1.0, theta=0.0
% INFO    : Bus 76984	: V=0.9918795, theta=-1.976303 -> V=1.0, theta=0.0
% INFO    : Bus 76985	: V=0.9868299, theta=-2.506663 -> V=1.0, theta=0.0
% INFO    : Bus 76986	: V=1.0015012, theta=-0.786397 -> V=1.0, theta=0.0
% INFO    : Bus 76987	: V=0.9947279, theta=-1.802408 -> V=1.0, theta=0.0
% INFO    : Bus 76988	: V=0.9934923, theta=-1.888601 -> V=1.0, theta=0.0
% INFO    : Bus 76989	: V=0.9871613, theta=-2.582296 -> V=1.0, theta=0.0
% INFO    : Bus 76990	: V=0.9904349, theta=-2.330298 -> V=1.0, theta=0.0
% INFO    : Bus 76991	: V=0.9902055, theta=-2.405473 -> V=1.0, theta=0.0
% INFO    : Bus 76992	: V=0.990056, theta=-2.370205 -> V=1.0, theta=0.0
% INFO    : Bus 76993	: V=0.989665, theta=-2.401959 -> V=1.0, theta=0.0
% INFO    : Bus 76994	: V=0.9845894, theta=-3.080471 -> V=1.0, theta=0.0
% INFO    : Bus 76995	: V=0.986727, theta=-3.02477 -> V=1.0, theta=0.0
% INFO    : Bus 76996	: V=0.9938598, theta=-2.01108 -> V=1.0, theta=0.0
% INFO    : Bus 76997	: V=0.9978871, theta=-1.279666 -> V=1.0, theta=0.0
% INFO    : Bus 76998	: V=0.9978116, theta=-1.320763 -> V=1.0, theta=0.0
% INFO    : Bus 76999	: V=0.9920976, theta=-2.211944 -> V=1.0, theta=0.0
% INFO    : Bus 77000	: V=0.989692, theta=-2.434411 -> V=1.0, theta=0.0
% INFO    : Bus 77001	: V=0.9955924, theta=-1.879689 -> V=1.0, theta=0.0
% INFO    : Bus 77002	: V=0.995562, theta=-1.812922 -> V=1.0, theta=0.0
% INFO    : Bus 77003	: V=0.9996711, theta=-0.943295 -> V=1.0, theta=0.0
% INFO    : Bus 77004	: V=0.9993029, theta=-1.108403 -> V=1.0, theta=0.0
% INFO    : Bus 77005	: V=0.9966862, theta=-1.70382 -> V=1.0, theta=0.0
% INFO    : Bus 77006	: V=0.9953836, theta=-1.82447 -> V=1.0, theta=0.0
% INFO    : Bus 77007	: V=0.99586, theta=-1.826614 -> V=1.0, theta=0.0
% INFO    : Bus 77008	: V=0.9938628, theta=-2.0254 -> V=1.0, theta=0.0
% INFO    : Bus 77009	: V=0.9941491, theta=-2.043015 -> V=1.0, theta=0.0
% INFO    : Bus 77010	: V=0.9921238, theta=-2.897086 -> V=1.0, theta=0.0
% INFO    : Bus 77011	: V=0.9900831, theta=-2.517854 -> V=1.0, theta=0.0
% INFO    : Bus 77012	: V=0.9943215, theta=-2.072898 -> V=1.0, theta=0.0
% INFO    : Bus 77013	: V=0.9948461, theta=-1.974392 -> V=1.0, theta=0.0
% INFO    : Bus 77014	: V=1.0031254, theta=-0.264904 -> V=1.0, theta=0.0
% INFO    : Bus 77015	: V=1.0023976, theta=-0.565674 -> V=1.0, theta=0.0
% INFO    : Bus 77016	: V=1.0053795, theta=0.249943 -> V=1.0, theta=0.0
% INFO    : Bus 77017	: V=1.0047625, theta=-0.050157 -> V=1.0, theta=0.0
% INFO    : Bus 77018	: V=1.0048329, theta=0.095634 -> V=1.0, theta=0.0
% INFO    : Bus 77019	: V=1.0055558, theta=0.118986 -> V=1.0, theta=0.0
% INFO    : Bus 77020	: V=1.0024631, theta=-0.650507 -> V=1.0, theta=0.0
% INFO    : Bus 77021	: V=0.9972682, theta=-1.646902 -> V=1.0, theta=0.0
% INFO    : Bus 77022	: V=0.9971974, theta=-1.776172 -> V=1.0, theta=0.0
% INFO    : Bus 77023	: V=0.9974457, theta=-1.811295 -> V=1.0, theta=0.0
% INFO    : Bus 77024	: V=0.9956126, theta=-1.907583 -> V=1.0, theta=0.0
% INFO    : Bus 77025	: V=0.9945388, theta=-2.102207 -> V=1.0, theta=0.0
% INFO    : Bus 77026	: V=0.9952345, theta=-2.643414 -> V=1.0, theta=0.0
% INFO    : Bus 77027	: V=0.9930385, theta=-2.795586 -> V=1.0, theta=0.0
% INFO    : Bus 77028	: V=0.9948686, theta=-2.845442 -> V=1.0, theta=0.0
% INFO    : Bus 77029	: V=0.996889, theta=-1.988682 -> V=1.0, theta=0.0
% INFO    : Bus 77030	: V=0.996517, theta=-1.836207 -> V=1.0, theta=0.0
% INFO    : Bus 77031	: V=0.9958946, theta=-1.983535 -> V=1.0, theta=0.0
% INFO    : Bus 77032	: V=1.0034247, theta=-0.623591 -> V=1.0, theta=0.0
% INFO    : Bus 77033	: V=1.0060508, theta=0.084617 -> V=1.0, theta=0.0
% INFO    : Bus 77034	: V=1.0067348, theta=0.199547 -> V=1.0, theta=0.0
% INFO    : Bus 77035	: V=1.0036502, theta=-0.102671 -> V=1.0, theta=0.0
% INFO    : Bus 77036	: V=1.0073648, theta=0.438144 -> V=1.0, theta=0.0
% INFO    : Bus 77037	: V=1.0062013, theta=0.249803 -> V=1.0, theta=0.0
% INFO    : Bus 77038	: V=1.006962, theta=0.374751 -> V=1.0, theta=0.0
% INFO    : Bus 77039	: V=1.0016674, theta=0.082592 -> V=1.0, theta=0.0
% INFO    : Bus 77040	: V=1.0205548, theta=3.79929 -> V=1.0, theta=0.0
% INFO    : Bus 77041	: V=1.0144232, theta=2.583546 -> V=1.0, theta=0.0
% INFO    : Bus 77042	: V=1.0101034, theta=1.313422 -> V=1.0, theta=0.0
% INFO    : Bus 77043	: V=1.0094121, theta=0.722601 -> V=1.0, theta=0.0
% INFO    : Bus 77044	: V=1.0062628, theta=-0.848481 -> V=1.0, theta=0.0
% INFO    : Bus 77045	: V=1.0038126, theta=-0.523312 -> V=1.0, theta=0.0
% INFO    : Bus 77046	: V=0.9982769, theta=-1.762397 -> V=1.0, theta=0.0
% INFO    : Bus 77047	: V=0.9984652, theta=-1.728315 -> V=1.0, theta=0.0
% INFO    : Bus 77048	: V=0.9974517, theta=-1.935726 -> V=1.0, theta=0.0
% INFO    : Bus 77049	: V=0.9972549, theta=-2.060788 -> V=1.0, theta=0.0
% INFO    : Bus 77050	: V=0.9962926, theta=-2.583089 -> V=1.0, theta=0.0
% INFO    : Bus 77051	: V=0.9988868, theta=-2.560149 -> V=1.0, theta=0.0
% INFO    : Bus 77052	: V=0.9978075, theta=-1.838345 -> V=1.0, theta=0.0
% INFO    : Bus 77053	: V=0.9979791, theta=-1.714309 -> V=1.0, theta=0.0
% INFO    : Bus 77054	: V=0.9994348, theta=-1.616939 -> V=1.0, theta=0.0
% INFO    : Bus 77055	: V=1.0027478, theta=-1.337356 -> V=1.0, theta=0.0
% INFO    : Bus 77056	: V=1.0050105, theta=-0.491049 -> V=1.0, theta=0.0
% INFO    : Bus 77057	: V=0.9944754, theta=-1.774726 -> V=1.0, theta=0.0
% INFO    : Bus 77058	: V=0.9965086, theta=-1.944692 -> V=1.0, theta=0.0
% INFO    : Bus 77059	: V=0.9991835, theta=-1.955107 -> V=1.0, theta=0.0
% INFO    : Bus 77060	: V=0.997553, theta=-2.05954 -> V=1.0, theta=0.0
% INFO    : Bus 77061	: V=1.000253, theta=-1.59024 -> V=1.0, theta=0.0
% INFO    : Bus 77062	: V=1.0001706, theta=-1.767182 -> V=1.0, theta=0.0
% INFO    : Bus 77063	: V=1.0026998, theta=-1.673228 -> V=1.0, theta=0.0
% INFO    : Bus 77064	: V=1.0030298, theta=-1.614011 -> V=1.0, theta=0.0
% INFO    : Bus 77065	: V=0.9998829, theta=-2.006632 -> V=1.0, theta=0.0
% INFO    : Bus 77066	: V=0.9992714, theta=-2.407729 -> V=1.0, theta=0.0
% INFO    : Bus 77067	: V=1.0025642, theta=-2.183449 -> V=1.0, theta=0.0
% INFO    : Bus 77068	: V=1.0017935, theta=-2.090643 -> V=1.0, theta=0.0
% INFO    : Bus 77069	: V=1.0007152, theta=-2.376761 -> V=1.0, theta=0.0
% INFO    : Bus 77070	: V=1.0039023, theta=-0.892598 -> V=1.0, theta=0.0
% INFO    : Bus 77071	: V=1.0010957, theta=-2.747022 -> V=1.0, theta=0.0
% INFO    : Bus 77072	: V=1.0015503, theta=-2.68487 -> V=1.0, theta=0.0
% INFO    : Bus 77073	: V=0.9991477, theta=-2.961129 -> V=1.0, theta=0.0
% INFO    : Bus 77074	: V=0.9932309, theta=-3.270437 -> V=1.0, theta=0.0
% INFO    : Bus 77075	: V=0.9953112, theta=-2.12147 -> V=1.0, theta=0.0
% INFO    : Bus 77076	: V=1.0034332, theta=-0.625084 -> V=1.0, theta=0.0
% INFO    : Bus 77077	: V=1.0034286, theta=-0.624363 -> V=1.0, theta=0.0
% INFO    : Bus 77078	: V=1.0012051, theta=-0.870165 -> V=1.0, theta=0.0
% INFO    : Bus 77079	: V=0.9999439, theta=-1.844993 -> V=1.0, theta=0.0
% INFO    : Bus 77080	: V=1.0063141, theta=-0.739645 -> V=1.0, theta=0.0
% INFO    : Bus 77081	: V=1.0043004, theta=-1.246485 -> V=1.0, theta=0.0
% INFO    : Bus 77082	: V=0.9737314, theta=-4.301589 -> V=1.0, theta=0.0
% INFO    : Bus 77083	: V=0.9775748, theta=-3.959222 -> V=1.0, theta=0.0
% INFO    : Bus 77084	: V=0.9711646, theta=-3.285988 -> V=1.0, theta=0.0
% INFO    : Bus 77085	: V=0.9750027, theta=-3.869264 -> V=1.0, theta=0.0
% INFO    : Bus 77086	: V=0.9769856, theta=-3.812978 -> V=1.0, theta=0.0
% INFO    : Bus 77087	: V=0.9699221, theta=-4.620469 -> V=1.0, theta=0.0
% INFO    : Bus 77088	: V=0.9891494, theta=-3.39587 -> V=1.0, theta=0.0
% INFO    : Bus 77089	: V=0.990735, theta=-3.34463 -> V=1.0, theta=0.0
% INFO    : Bus 77090	: V=0.9993431, theta=-2.859438 -> V=1.0, theta=0.0
% INFO    : Bus 77091	: V=1.0028245, theta=-2.369196 -> V=1.0, theta=0.0
% INFO    : Bus 77092	: V=1.0013583, theta=-2.689766 -> V=1.0, theta=0.0
% INFO    : Bus 77093	: V=1.0007396, theta=-2.83576 -> V=1.0, theta=0.0
% INFO    : Bus 77094	: V=1.0039356, theta=-2.737824 -> V=1.0, theta=0.0
% INFO    : Bus 77095	: V=1.0020947, theta=-2.689393 -> V=1.0, theta=0.0
% INFO    : Bus 77096	: V=1.0198352, theta=3.150021 -> V=1.0, theta=0.0
% INFO    : Bus 77097	: V=1.005561, theta=-1.416939 -> V=1.0, theta=0.0
% INFO    : Bus 77098	: V=1.002985, theta=-1.996644 -> V=1.0, theta=0.0
% INFO    : Bus 77099	: V=1.0070586, theta=-1.464 -> V=1.0, theta=0.0
% INFO    : Bus 77100	: V=1.0044983, theta=-2.290284 -> V=1.0, theta=0.0
% INFO    : Bus 77101	: V=1.001502, theta=-2.652881 -> V=1.0, theta=0.0
% INFO    : Bus 77102	: V=1.003338, theta=-2.618776 -> V=1.0, theta=0.0
% INFO    : Bus 77103	: V=1.0027971, theta=-2.876764 -> V=1.0, theta=0.0
% INFO    : Bus 77104	: V=1.0046073, theta=-2.682713 -> V=1.0, theta=0.0
% INFO    : Bus 77105	: V=0.9997986, theta=-3.254739 -> V=1.0, theta=0.0
% INFO    : Bus 77106	: V=0.9988486, theta=-2.592499 -> V=1.0, theta=0.0
% INFO    : Bus 77107	: V=0.9922888, theta=-4.483466 -> V=1.0, theta=0.0
% INFO    : Bus 77108	: V=0.9923495, theta=-3.968553 -> V=1.0, theta=0.0
% INFO    : Bus 77109	: V=0.9949774, theta=-3.761654 -> V=1.0, theta=0.0
% INFO    : Bus 77110	: V=0.9942614, theta=-3.820247 -> V=1.0, theta=0.0
% INFO    : Bus 77111	: V=1.0014331, theta=-2.516368 -> V=1.0, theta=0.0
% INFO    : Bus 77112	: V=0.9998374, theta=-3.442795 -> V=1.0, theta=0.0
% INFO    : Bus 77113	: V=0.993048, theta=-3.963221 -> V=1.0, theta=0.0
% INFO    : Bus 77114	: V=0.9995427, theta=-3.307092 -> V=1.0, theta=0.0
% INFO    : Bus 77115	: V=0.9932643, theta=-3.963824 -> V=1.0, theta=0.0
% INFO    : Bus 77116	: V=0.9955002, theta=-3.788869 -> V=1.0, theta=0.0
% INFO    : Bus 77117	: V=0.9986716, theta=-3.706628 -> V=1.0, theta=0.0
% INFO    : Bus 77118	: V=1.0003689, theta=-3.614771 -> V=1.0, theta=0.0
% INFO    : Bus 77119	: V=0.9943281, theta=-4.291385 -> V=1.0, theta=0.0
% INFO    : Bus 77120	: V=0.9950229, theta=-4.140261 -> V=1.0, theta=0.0
% INFO    : Bus 77121	: V=1.0005216, theta=-3.649213 -> V=1.0, theta=0.0
% INFO    : Bus 77122	: V=1.0020557, theta=-3.661561 -> V=1.0, theta=0.0
% INFO    : Bus 77123	: V=0.990205, theta=-4.728403 -> V=1.0, theta=0.0
% INFO    : Bus 77124	: V=0.9930077, theta=-4.533898 -> V=1.0, theta=0.0
% INFO    : Bus 77125	: V=0.994951, theta=-4.319457 -> V=1.0, theta=0.0
% INFO    : Bus 77126	: V=0.9986438, theta=-4.192969 -> V=1.0, theta=0.0
% INFO    : Bus 77127	: V=0.9914511, theta=-4.697691 -> V=1.0, theta=0.0
% INFO    : Bus 77128	: V=0.9727061, theta=-4.713225 -> V=1.0, theta=0.0
% INFO    : Bus 77129	: V=0.9845031, theta=-2.420055 -> V=1.0, theta=0.0
% INFO    : Bus 77130	: V=0.9801317, theta=-3.500221 -> V=1.0, theta=0.0
% INFO    : Bus 77131	: V=0.9780968, theta=-3.646168 -> V=1.0, theta=0.0
% INFO    : Bus 77132	: V=0.9784627, theta=-3.637122 -> V=1.0, theta=0.0
% INFO    : Bus 77133	: V=0.9699084, theta=-4.85568 -> V=1.0, theta=0.0
% INFO    : Bus 77134	: V=0.9877688, theta=-2.102781 -> V=1.0, theta=0.0
% INFO    : Bus 77135	: V=0.9802898, theta=-3.485827 -> V=1.0, theta=0.0
% INFO    : Bus 77136	: V=0.9760257, theta=-4.105964 -> V=1.0, theta=0.0
% INFO    : Bus 77137	: V=0.9882512, theta=-2.255564 -> V=1.0, theta=0.0
% INFO    : Bus 77138	: V=0.985587, theta=-2.632065 -> V=1.0, theta=0.0
% INFO    : Bus 77139	: V=0.9829166, theta=-3.273771 -> V=1.0, theta=0.0
% INFO    : Bus 77140	: V=0.9892871, theta=-2.095065 -> V=1.0, theta=0.0
% INFO    : Bus 77141	: V=0.9811568, theta=-3.413296 -> V=1.0, theta=0.0
% INFO    : Bus 77142	: V=0.9743185, theta=-4.214695 -> V=1.0, theta=0.0
% INFO    : Bus 77143	: V=0.9906455, theta=-1.065261 -> V=1.0, theta=0.0
% INFO    : Bus 77144	: V=0.9894887, theta=-1.840169 -> V=1.0, theta=0.0
% INFO    : Bus 77145	: V=0.9877644, theta=-2.375957 -> V=1.0, theta=0.0
% INFO    : Bus 77146	: V=0.9898186, theta=-2.072034 -> V=1.0, theta=0.0
% INFO    : Bus 77147	: V=0.9891, theta=-2.263831 -> V=1.0, theta=0.0
% INFO    : Bus 77148	: V=0.979378, theta=-3.637758 -> V=1.0, theta=0.0
% INFO    : Bus 77149	: V=1.0105539, theta=3.494304 -> V=1.0, theta=0.0
% INFO    : Bus 77150	: V=1.0014937, theta=-3.076565 -> V=1.0, theta=0.0
% INFO    : Bus 77151	: V=1.0015134, theta=-2.971822 -> V=1.0, theta=0.0
% INFO    : Bus 77152	: V=0.9991213, theta=-3.380104 -> V=1.0, theta=0.0
% INFO    : Bus 77153	: V=0.9982997, theta=-3.622965 -> V=1.0, theta=0.0
% INFO    : Bus 77154	: V=0.9946866, theta=-4.050262 -> V=1.0, theta=0.0
% INFO    : Bus 77155	: V=1.0000454, theta=-3.661729 -> V=1.0, theta=0.0
% INFO    : Bus 77156	: V=0.999461, theta=-3.759217 -> V=1.0, theta=0.0
% INFO    : Bus 77157	: V=0.9997279, theta=-3.739834 -> V=1.0, theta=0.0
% INFO    : Bus 77158	: V=0.9919397, theta=-4.359454 -> V=1.0, theta=0.0
% INFO    : Bus 77159	: V=1.0001508, theta=-1.796313 -> V=1.0, theta=0.0
% INFO    : Bus 77160	: V=0.9843572, theta=-4.276317 -> V=1.0, theta=0.0
% INFO    : Bus 77161	: V=1.0011139, theta=-2.99594 -> V=1.0, theta=0.0
% INFO    : Bus 77162	: V=0.9953359, theta=-3.942773 -> V=1.0, theta=0.0
% INFO    : Bus 77163	: V=1.0198675, theta=-11.610661 -> V=1.0, theta=0.0
% INFO    : Bus 77164	: V=1.0170301, theta=-18.93439 -> V=1.0, theta=0.0
% INFO    : Bus 77165	: V=1.0191589, theta=-13.768402 -> V=1.0, theta=0.0
% INFO    : Bus 77166	: V=1.0187969, theta=-13.649317 -> V=1.0, theta=0.0
% INFO    : Bus 77167	: V=1.012393, theta=-16.698877 -> V=1.0, theta=0.0
% INFO    : Bus 77168	: V=1.014914, theta=-15.334587 -> V=1.0, theta=0.0
% INFO    : Bus 77169	: V=1.0181207, theta=-18.467911 -> V=1.0, theta=0.0
% INFO    : Bus 77170	: V=1.0182591, theta=-18.758126 -> V=1.0, theta=0.0
% INFO    : Bus 77171	: V=1.01953, theta=-19.723609 -> V=1.0, theta=0.0
% INFO    : Bus 77172	: V=1.0182177, theta=-19.688127 -> V=1.0, theta=0.0
% INFO    : Bus 77173	: V=1.0198739, theta=-20.068916 -> V=1.0, theta=0.0
% INFO    : Bus 77174	: V=1.0192067, theta=-20.595459 -> V=1.0, theta=0.0
% INFO    : Bus 77175	: V=0.993324, theta=-19.644379 -> V=1.0, theta=0.0
% INFO    : Bus 77176	: V=0.9942625, theta=-19.583244 -> V=1.0, theta=0.0
% INFO    : Bus 77177	: V=0.9949656, theta=-19.361076 -> V=1.0, theta=0.0
% INFO    : Bus 77178	: V=1.0131464, theta=-15.244577 -> V=1.0, theta=0.0
% INFO    : Bus 77179	: V=1.0171827, theta=-14.341631 -> V=1.0, theta=0.0
% INFO    : Bus 77180	: V=1.0159464, theta=-14.762541 -> V=1.0, theta=0.0
% INFO    : Bus 77181	: V=1.015184, theta=-15.014318 -> V=1.0, theta=0.0
% INFO    : Bus 77182	: V=1.0049129, theta=-12.640661 -> V=1.0, theta=0.0
% INFO    : Bus 77183	: V=1.0113769, theta=26.62375 -> V=1.0, theta=0.0
% INFO    : Bus 77184	: V=1.0034452, theta=41.181368 -> V=1.0, theta=0.0
% INFO    : Bus 77185	: V=1.0156315, theta=23.698119 -> V=1.0, theta=0.0
% INFO    : Bus 77186	: V=1.0165515, theta=24.254942 -> V=1.0, theta=0.0
% INFO    : Bus 77187	: V=0.9964422, theta=20.477907 -> V=1.0, theta=0.0
% INFO    : Bus 77188	: V=0.9951587, theta=17.881139 -> V=1.0, theta=0.0
% INFO    : Bus 77189	: V=0.9961139, theta=18.130594 -> V=1.0, theta=0.0
% INFO    : Bus 77190	: V=1.0068261, theta=20.281764 -> V=1.0, theta=0.0
% INFO    : Bus 77191	: V=0.9953876, theta=18.028222 -> V=1.0, theta=0.0
% INFO    : Bus 77192	: V=0.9932306, theta=18.035153 -> V=1.0, theta=0.0
% INFO    : Bus 77193	: V=0.9832363, theta=-10.373399 -> V=1.0, theta=0.0
% INFO    : Bus 77194	: V=0.985216, theta=-10.169471 -> V=1.0, theta=0.0
% INFO    : Bus 77195	: V=0.9815139, theta=-10.474761 -> V=1.0, theta=0.0
% INFO    : Bus 77196	: V=0.9844652, theta=-10.216426 -> V=1.0, theta=0.0
% INFO    : Bus 77197	: V=0.9974646, theta=-8.184131 -> V=1.0, theta=0.0
% INFO    : Bus 77198	: V=0.9934953, theta=-8.893924 -> V=1.0, theta=0.0
% INFO    : Bus 77199	: V=0.9888345, theta=-9.782993 -> V=1.0, theta=0.0
% INFO    : Bus 77200	: V=0.9881837, theta=-9.553868 -> V=1.0, theta=0.0
% INFO    : Bus 77201	: V=0.9818491, theta=-10.478698 -> V=1.0, theta=0.0
% INFO    : Bus 77202	: V=0.9825902, theta=-10.350548 -> V=1.0, theta=0.0
% INFO    : Bus 77203	: V=0.9857847, theta=-10.169861 -> V=1.0, theta=0.0
% INFO    : Bus 77204	: V=0.990681, theta=-9.385491 -> V=1.0, theta=0.0
% INFO    : Bus 77205	: V=0.986383, theta=-9.864978 -> V=1.0, theta=0.0
% INFO    : Bus 77206	: V=0.993588, theta=-8.948052 -> V=1.0, theta=0.0
% INFO    : Bus 77207	: V=0.9958991, theta=-8.722881 -> V=1.0, theta=0.0
% INFO    : Bus 77208	: V=0.9843166, theta=-10.032904 -> V=1.0, theta=0.0
% INFO    : Bus 77209	: V=0.9837076, theta=-10.131875 -> V=1.0, theta=0.0
% INFO    : Bus 77210	: V=0.9844459, theta=-9.824546 -> V=1.0, theta=0.0
% INFO    : Bus 77211	: V=0.9905541, theta=-8.322781 -> V=1.0, theta=0.0
% INFO    : Bus 77212	: V=0.982563, theta=-10.292204 -> V=1.0, theta=0.0
% INFO    : Bus 77213	: V=0.9932789, theta=-8.279025 -> V=1.0, theta=0.0
% INFO    : Bus 77214	: V=0.9982466, theta=-8.388191 -> V=1.0, theta=0.0
% INFO    : Bus 77215	: V=0.9828689, theta=-8.960958 -> V=1.0, theta=0.0
% INFO    : Bus 77216	: V=0.9910081, theta=-8.66626 -> V=1.0, theta=0.0
% INFO    : Bus 77217	: V=0.9845111, theta=-8.983939 -> V=1.0, theta=0.0
% INFO    : Bus 77218	: V=0.9980724, theta=-6.365228 -> V=1.0, theta=0.0
% INFO    : Bus 77219	: V=0.9929277, theta=-8.373374 -> V=1.0, theta=0.0
% INFO    : Bus 77220	: V=0.9980202, theta=-7.58345 -> V=1.0, theta=0.0
% INFO    : Bus 77221	: V=0.9948782, theta=-7.68201 -> V=1.0, theta=0.0
% INFO    : Bus 77222	: V=1.0016492, theta=-6.872387 -> V=1.0, theta=0.0
% INFO    : Bus 77223	: V=1.0021408, theta=-6.747527 -> V=1.0, theta=0.0
% INFO    : Bus 77224	: V=0.9850771, theta=-10.037222 -> V=1.0, theta=0.0
% INFO    : Bus 77225	: V=0.9843702, theta=-9.962054 -> V=1.0, theta=0.0
% INFO    : Bus 77226	: V=0.9878142, theta=-9.360604 -> V=1.0, theta=0.0
% INFO    : Bus 77227	: V=0.9834675, theta=-9.732771 -> V=1.0, theta=0.0
% INFO    : Bus 77228	: V=0.9895369, theta=-9.122787 -> V=1.0, theta=0.0
% INFO    : Bus 77229	: V=0.989882, theta=-9.136124 -> V=1.0, theta=0.0
% INFO    : Bus 77230	: V=0.9855516, theta=-9.569859 -> V=1.0, theta=0.0
% INFO    : Bus 77231	: V=0.9879311, theta=-9.376481 -> V=1.0, theta=0.0
% INFO    : Bus 77232	: V=0.9868671, theta=-9.09111 -> V=1.0, theta=0.0
% INFO    : Bus 77233	: V=0.9861811, theta=-8.089892 -> V=1.0, theta=0.0
% INFO    : Bus 77234	: V=0.9897615, theta=-8.855653 -> V=1.0, theta=0.0
% INFO    : Bus 77235	: V=0.9897198, theta=-8.891555 -> V=1.0, theta=0.0
% INFO    : Bus 77236	: V=0.9900544, theta=-9.051998 -> V=1.0, theta=0.0
% INFO    : Bus 77237	: V=1.0172871, theta=-6.138987 -> V=1.0, theta=0.0
% INFO    : Bus 77238	: V=1.0019188, theta=-7.597372 -> V=1.0, theta=0.0
% INFO    : Bus 77239	: V=1.0007493, theta=-8.16646 -> V=1.0, theta=0.0
% INFO    : Bus 77240	: V=1.0204115, theta=-4.153097 -> V=1.0, theta=0.0
% INFO    : Bus 77241	: V=1.0044738, theta=-7.173997 -> V=1.0, theta=0.0
% INFO    : Bus 77242	: V=1.0036218, theta=-7.578845 -> V=1.0, theta=0.0
% INFO    : Bus 77243	: V=0.9903529, theta=-8.437878 -> V=1.0, theta=0.0
% INFO    : Bus 77244	: V=1.0177987, theta=6.559564 -> V=1.0, theta=0.0
% INFO    : Bus 77245	: V=0.9929208, theta=-3.110548 -> V=1.0, theta=0.0
% INFO    : Bus 77246	: V=0.9911352, theta=-3.662495 -> V=1.0, theta=0.0
% INFO    : Bus 77247	: V=0.9889635, theta=-4.637651 -> V=1.0, theta=0.0
% INFO    : Bus 77248	: V=1.0029594, theta=-0.560206 -> V=1.0, theta=0.0
% INFO    : Bus 77249	: V=1.0068543, theta=0.038296 -> V=1.0, theta=0.0
% INFO    : Bus 77250	: V=1.0081971, theta=-0.360916 -> V=1.0, theta=0.0
% INFO    : Bus 77251	: V=1.0077943, theta=-0.385379 -> V=1.0, theta=0.0
% INFO    : Bus 77252	: V=1.0063142, theta=-0.47622 -> V=1.0, theta=0.0
% INFO    : Bus 77253	: V=1.0062932, theta=-0.485603 -> V=1.0, theta=0.0
% INFO    : Bus 77254	: V=1.0070825, theta=-0.377525 -> V=1.0, theta=0.0
% INFO    : Bus 77255	: V=1.0064339, theta=-0.412693 -> V=1.0, theta=0.0
% INFO    : Bus 77256	: V=1.0008888, theta=-0.844193 -> V=1.0, theta=0.0
% INFO    : Bus 77257	: V=0.9897774, theta=-1.844363 -> V=1.0, theta=0.0
% INFO    : Bus 77258	: V=1.0012989, theta=-1.520309 -> V=1.0, theta=0.0
% INFO    : Bus 77259	: V=1.0038988, theta=-1.734778 -> V=1.0, theta=0.0
% INFO    : Bus 77260	: V=0.9980484, theta=-2.360875 -> V=1.0, theta=0.0
% INFO    : Bus 77261	: V=1.010275, theta=-5.13419 -> V=1.0, theta=0.0
% INFO    : Bus 77262	: V=0.978862, theta=-8.963406 -> V=1.0, theta=0.0
% INFO    : Bus 77263	: V=0.9797417, theta=-8.715758 -> V=1.0, theta=0.0
% INFO    : Bus 77264	: V=0.9776948, theta=-8.629511 -> V=1.0, theta=0.0
% INFO    : Bus 77265	: V=0.9824624, theta=-8.942833 -> V=1.0, theta=0.0
% INFO    : Bus 77266	: V=0.9764664, theta=-8.58812 -> V=1.0, theta=0.0
% INFO    : Bus 77267	: V=0.9790287, theta=-8.30204 -> V=1.0, theta=0.0
% INFO    : Bus 77268	: V=0.9793605, theta=-8.232726 -> V=1.0, theta=0.0
% INFO    : Bus 77269	: V=0.983697, theta=-8.588254 -> V=1.0, theta=0.0
% INFO    : Bus 77270	: V=0.9910595, theta=-4.935491 -> V=1.0, theta=0.0
% INFO    : Bus 77271	: V=0.9790946, theta=-5.736214 -> V=1.0, theta=0.0
% INFO    : Bus 77272	: V=0.9920037, theta=-6.603667 -> V=1.0, theta=0.0
% INFO    : Bus 77273	: V=0.9886656, theta=-4.867973 -> V=1.0, theta=0.0
% INFO    : Bus 77274	: V=0.9868085, theta=-3.207262 -> V=1.0, theta=0.0
% INFO    : Bus 77275	: V=0.9831326, theta=-3.347335 -> V=1.0, theta=0.0
% INFO    : Bus 77276	: V=0.9843642, theta=-7.55894 -> V=1.0, theta=0.0
% INFO    : Bus 77277	: V=0.9973063, theta=-20.274408 -> V=1.0, theta=0.0
% INFO    : Bus 77278	: V=0.9986274, theta=-20.2349 -> V=1.0, theta=0.0
% INFO    : Bus 77279	: V=0.9999329, theta=-20.206056 -> V=1.0, theta=0.0
% INFO    : Bus 77280	: V=0.9999002, theta=-20.170553 -> V=1.0, theta=0.0
% INFO    : Bus 77281	: V=0.9990378, theta=-20.205161 -> V=1.0, theta=0.0
% INFO    : Bus 77282	: V=0.9985668, theta=-20.249444 -> V=1.0, theta=0.0
% INFO    : Bus 77283	: V=0.9989613, theta=-20.277815 -> V=1.0, theta=0.0
% INFO    : Bus 77284	: V=1.0043681, theta=-20.007347 -> V=1.0, theta=0.0
% INFO    : Bus 77285	: V=1.0018868, theta=-20.816817 -> V=1.0, theta=0.0
% INFO    : Bus 77286	: V=0.9987825, theta=-19.567828 -> V=1.0, theta=0.0
% INFO    : Bus 77287	: V=0.9975014, theta=-19.965583 -> V=1.0, theta=0.0
% INFO    : Bus 77288	: V=0.9965371, theta=-19.986968 -> V=1.0, theta=0.0
% INFO    : Bus 77289	: V=0.9963961, theta=-17.327068 -> V=1.0, theta=0.0
% INFO    : Bus 77290	: V=0.9869538, theta=-13.070194 -> V=1.0, theta=0.0
% INFO    : Bus 77291	: V=0.9947229, theta=-21.163927 -> V=1.0, theta=0.0
% INFO    : Bus 77292	: V=1.0024357, theta=-5.528085 -> V=1.0, theta=0.0
% INFO    : Bus 77293	: V=0.9892639, theta=7.817323 -> V=1.0, theta=0.0
% INFO    : Bus 77294	: V=0.9902155, theta=7.968605 -> V=1.0, theta=0.0
% INFO    : Bus 77295	: V=0.989698, theta=8.100631 -> V=1.0, theta=0.0
% INFO    : Bus 77296	: V=1.0011216, theta=10.289125 -> V=1.0, theta=0.0
% INFO    : Bus 77297	: V=1.0007044, theta=10.174542 -> V=1.0, theta=0.0
% INFO    : Bus 77298	: V=0.9900791, theta=9.096657 -> V=1.0, theta=0.0
% INFO    : Bus 77299	: V=0.9935623, theta=10.353189 -> V=1.0, theta=0.0
% INFO    : Bus 77300	: V=0.9917585, theta=10.242458 -> V=1.0, theta=0.0
% INFO    : Bus 77301	: V=0.9888098, theta=9.113731 -> V=1.0, theta=0.0
% INFO    : Bus 77302	: V=0.9872687, theta=8.980376 -> V=1.0, theta=0.0
% INFO    : Bus 77303	: V=0.9958438, theta=10.082978 -> V=1.0, theta=0.0
% INFO    : Bus 77304	: V=0.9997845, theta=10.360904 -> V=1.0, theta=0.0
% INFO    : Bus 77305	: V=1.0037994, theta=11.133948 -> V=1.0, theta=0.0
% INFO    : Bus 77306	: V=1.0041909, theta=11.299086 -> V=1.0, theta=0.0
% INFO    : Bus 77307	: V=0.9958189, theta=10.23453 -> V=1.0, theta=0.0
% INFO    : Bus 77308	: V=0.9962019, theta=10.239611 -> V=1.0, theta=0.0
% INFO    : Bus 77309	: V=0.9957083, theta=10.085607 -> V=1.0, theta=0.0
% INFO    : Bus 77310	: V=0.9934692, theta=9.999723 -> V=1.0, theta=0.0
% INFO    : Bus 77311	: V=0.9876067, theta=8.467502 -> V=1.0, theta=0.0
% INFO    : Bus 77312	: V=0.993377, theta=9.623395 -> V=1.0, theta=0.0
% INFO    : Bus 77313	: V=0.9760662, theta=6.932492 -> V=1.0, theta=0.0
% INFO    : Bus 77314	: V=0.9902116, theta=8.935191 -> V=1.0, theta=0.0
% INFO    : Bus 77315	: V=0.9862273, theta=8.392481 -> V=1.0, theta=0.0
% INFO    : Bus 77316	: V=0.9905731, theta=8.848626 -> V=1.0, theta=0.0
% INFO    : Bus 77317	: V=0.9907215, theta=8.857604 -> V=1.0, theta=0.0
% INFO    : Bus 77318	: V=0.9860364, theta=8.87233 -> V=1.0, theta=0.0
% INFO    : Bus 77319	: V=0.9889949, theta=9.183131 -> V=1.0, theta=0.0
% INFO    : Bus 77320	: V=0.9870322, theta=9.088083 -> V=1.0, theta=0.0
% INFO    : Bus 77321	: V=0.9879924, theta=8.451902 -> V=1.0, theta=0.0
% INFO    : Bus 77322	: V=0.9895272, theta=8.573082 -> V=1.0, theta=0.0
% INFO    : Bus 77323	: V=0.9911705, theta=9.096506 -> V=1.0, theta=0.0
% INFO    : Bus 77324	: V=0.9889658, theta=9.178202 -> V=1.0, theta=0.0
% INFO    : Bus 77325	: V=0.9879073, theta=9.037484 -> V=1.0, theta=0.0
% INFO    : Bus 77326	: V=0.9941548, theta=9.681721 -> V=1.0, theta=0.0
% INFO    : Bus 77327	: V=0.993388, theta=9.123594 -> V=1.0, theta=0.0
% INFO    : Bus 77328	: V=1.00368, theta=8.992043 -> V=1.0, theta=0.0
% INFO    : Bus 77329	: V=1.0008616, theta=8.535632 -> V=1.0, theta=0.0
% INFO    : Bus 77330	: V=0.9876296, theta=7.612486 -> V=1.0, theta=0.0
% INFO    : Bus 77331	: V=0.9986303, theta=9.584324 -> V=1.0, theta=0.0
% INFO    : Bus 77332	: V=0.9972486, theta=9.094668 -> V=1.0, theta=0.0
% INFO    : Bus 77333	: V=0.9849815, theta=7.482367 -> V=1.0, theta=0.0
% INFO    : Bus 77334	: V=0.988767, theta=7.847647 -> V=1.0, theta=0.0
% INFO    : Bus 77335	: V=0.9883027, theta=7.694049 -> V=1.0, theta=0.0
% INFO    : Bus 77336	: V=0.9900868, theta=7.325877 -> V=1.0, theta=0.0
% INFO    : Bus 77337	: V=0.9884975, theta=6.693949 -> V=1.0, theta=0.0
% INFO    : Bus 77338	: V=0.9882454, theta=7.071698 -> V=1.0, theta=0.0
% INFO    : Bus 77339	: V=0.9877365, theta=7.013828 -> V=1.0, theta=0.0
% INFO    : Bus 77340	: V=0.9959612, theta=8.33746 -> V=1.0, theta=0.0
% INFO    : Bus 77341	: V=0.9877993, theta=7.558619 -> V=1.0, theta=0.0
% INFO    : Bus 77342	: V=0.9919689, theta=7.868498 -> V=1.0, theta=0.0
% INFO    : Bus 77343	: V=0.9912504, theta=7.720554 -> V=1.0, theta=0.0
% INFO    : Bus 77344	: V=0.9829694, theta=7.122003 -> V=1.0, theta=0.0
% INFO    : Bus 77345	: V=0.9822918, theta=6.995252 -> V=1.0, theta=0.0
% INFO    : Bus 77346	: V=0.996771, theta=8.955544 -> V=1.0, theta=0.0
% INFO    : Bus 77347	: V=0.9967354, theta=8.719176 -> V=1.0, theta=0.0
% INFO    : Bus 77348	: V=0.9867959, theta=7.332752 -> V=1.0, theta=0.0
% INFO    : Bus 77349	: V=0.9891647, theta=7.858423 -> V=1.0, theta=0.0
% INFO    : Bus 77350	: V=0.9898708, theta=7.91197 -> V=1.0, theta=0.0
% INFO    : Bus 77351	: V=0.9863538, theta=7.417903 -> V=1.0, theta=0.0
% INFO    : Bus 77352	: V=0.9822071, theta=6.937525 -> V=1.0, theta=0.0
% INFO    : Bus 77353	: V=0.9904582, theta=7.899087 -> V=1.0, theta=0.0
% INFO    : Bus 77354	: V=0.9896592, theta=7.771457 -> V=1.0, theta=0.0
% INFO    : Bus 77355	: V=0.9885477, theta=7.778665 -> V=1.0, theta=0.0
% INFO    : Bus 77356	: V=0.9879984, theta=7.714599 -> V=1.0, theta=0.0
% INFO    : Bus 77357	: V=0.9877222, theta=7.898802 -> V=1.0, theta=0.0
% INFO    : Bus 77358	: V=0.9888582, theta=7.825135 -> V=1.0, theta=0.0
% INFO    : Bus 77359	: V=0.9879696, theta=7.932326 -> V=1.0, theta=0.0
% INFO    : Bus 77360	: V=0.9879064, theta=7.916906 -> V=1.0, theta=0.0
% INFO    : Bus 77361	: V=0.9863944, theta=7.811837 -> V=1.0, theta=0.0
% INFO    : Bus 77362	: V=0.9873733, theta=7.889446 -> V=1.0, theta=0.0
% INFO    : Bus 77363	: V=0.981327, theta=6.875527 -> V=1.0, theta=0.0
% INFO    : Bus 77364	: V=0.9799483, theta=7.299787 -> V=1.0, theta=0.0
% INFO    : Bus 77365	: V=0.9862403, theta=7.890364 -> V=1.0, theta=0.0
% INFO    : Bus 77366	: V=0.9864328, theta=7.973984 -> V=1.0, theta=0.0
% INFO    : Bus 77367	: V=0.9867513, theta=7.956525 -> V=1.0, theta=0.0
% INFO    : Bus 77368	: V=0.9809183, theta=7.372816 -> V=1.0, theta=0.0
% INFO    : Bus 77369	: V=0.9812026, theta=6.764789 -> V=1.0, theta=0.0
% INFO    : Bus 77370	: V=0.9861307, theta=27.39115 -> V=1.0, theta=0.0
% INFO    : Bus 77371	: V=1.0007465, theta=20.724035 -> V=1.0, theta=0.0
% INFO    : Bus 77372	: V=1.0232006, theta=16.770695 -> V=1.0, theta=0.0
% INFO    : Bus 77373	: V=1.0127831, theta=14.450769 -> V=1.0, theta=0.0
% INFO    : Bus 77374	: V=1.010524, theta=13.983212 -> V=1.0, theta=0.0
% INFO    : Bus 77375	: V=1.0072869, theta=13.601417 -> V=1.0, theta=0.0
% INFO    : Bus 77376	: V=1.0069928, theta=13.590581 -> V=1.0, theta=0.0
% INFO    : Bus 77377	: V=0.9990813, theta=11.71688 -> V=1.0, theta=0.0
% INFO    : Bus 77378	: V=1.0066429, theta=13.170899 -> V=1.0, theta=0.0
% INFO    : Bus 77379	: V=0.9994797, theta=12.081822 -> V=1.0, theta=0.0
% INFO    : Bus 77380	: V=1.0014006, theta=12.526833 -> V=1.0, theta=0.0
% INFO    : Bus 77381	: V=1.0017657, theta=12.546137 -> V=1.0, theta=0.0
% INFO    : Bus 77382	: V=1.0021008, theta=12.608873 -> V=1.0, theta=0.0
% INFO    : Bus 77383	: V=0.9909513, theta=11.27205 -> V=1.0, theta=0.0
% INFO    : Bus 77384	: V=0.9968104, theta=11.771527 -> V=1.0, theta=0.0
% INFO    : Bus 77385	: V=0.9928743, theta=11.285094 -> V=1.0, theta=0.0
% INFO    : Bus 77386	: V=0.9944899, theta=11.447485 -> V=1.0, theta=0.0
% INFO    : Bus 77387	: V=0.9882524, theta=11.003562 -> V=1.0, theta=0.0
% INFO    : Bus 77388	: V=0.9992972, theta=11.987895 -> V=1.0, theta=0.0
% INFO    : Bus 77389	: V=0.9985426, theta=11.959195 -> V=1.0, theta=0.0
% INFO    : Bus 77390	: V=0.9910695, theta=10.881918 -> V=1.0, theta=0.0
% INFO    : Bus 77391	: V=0.9993279, theta=11.40161 -> V=1.0, theta=0.0
% INFO    : Bus 77392	: V=0.9918798, theta=9.787698 -> V=1.0, theta=0.0
% INFO    : Bus 77393	: V=0.9926689, theta=10.692028 -> V=1.0, theta=0.0
% INFO    : Bus 77394	: V=0.9905346, theta=9.610318 -> V=1.0, theta=0.0
% INFO    : Bus 77395	: V=0.9972964, theta=11.268096 -> V=1.0, theta=0.0
% INFO    : Bus 77396	: V=0.9966947, theta=11.177631 -> V=1.0, theta=0.0
% INFO    : Bus 77397	: V=0.9918872, theta=17.700623 -> V=1.0, theta=0.0
% INFO    : Bus 77398	: V=1.0025209, theta=19.844215 -> V=1.0, theta=0.0
% INFO    : Bus 77399	: V=1.0047585, theta=19.823398 -> V=1.0, theta=0.0
% INFO    : Bus 77400	: V=1.0020187, theta=23.077778 -> V=1.0, theta=0.0
% INFO    : Bus 77401	: V=1.0091088, theta=15.268822 -> V=1.0, theta=0.0
% INFO    : Bus 77402	: V=1.0119513, theta=15.698271 -> V=1.0, theta=0.0
% INFO    : Bus 77403	: V=0.9982886, theta=20.658966 -> V=1.0, theta=0.0
% INFO    : Bus 77404	: V=0.9816426, theta=23.928155 -> V=1.0, theta=0.0
% INFO    : Bus 77405	: V=0.992294, theta=23.667758 -> V=1.0, theta=0.0
% INFO    : Bus 77406	: V=0.9865644, theta=7.547668 -> V=1.0, theta=0.0
% INFO    : Bus 77407	: V=0.9895842, theta=8.346725 -> V=1.0, theta=0.0
% INFO    : Bus 77408	: V=0.9898409, theta=7.396216 -> V=1.0, theta=0.0
% INFO    : Bus 77409	: V=0.987532, theta=7.537894 -> V=1.0, theta=0.0
% INFO    : Bus 77410	: V=0.9892183, theta=7.152792 -> V=1.0, theta=0.0
% INFO    : Bus 77411	: V=0.9873223, theta=6.811057 -> V=1.0, theta=0.0
% INFO    : Bus 77412	: V=0.9880249, theta=6.719596 -> V=1.0, theta=0.0
% INFO    : Bus 77413	: V=0.9905516, theta=7.796875 -> V=1.0, theta=0.0
% INFO    : Bus 77414	: V=0.992014, theta=8.414209 -> V=1.0, theta=0.0
% INFO    : Bus 77415	: V=0.9887587, theta=7.204506 -> V=1.0, theta=0.0
% INFO    : Bus 77416	: V=0.990353, theta=7.072126 -> V=1.0, theta=0.0
% INFO    : Bus 77417	: V=0.9905376, theta=8.016991 -> V=1.0, theta=0.0
% INFO    : Bus 77418	: V=0.9915241, theta=8.367352 -> V=1.0, theta=0.0
% INFO    : Bus 77419	: V=0.9894778, theta=7.388424 -> V=1.0, theta=0.0
% INFO    : Bus 77420	: V=0.9901791, theta=7.972563 -> V=1.0, theta=0.0
% INFO    : Bus 77421	: V=0.9878556, theta=7.062604 -> V=1.0, theta=0.0
% INFO    : Bus 77422	: V=0.9897351, theta=7.939102 -> V=1.0, theta=0.0
% INFO    : Bus 77423	: V=0.9956317, theta=8.92551 -> V=1.0, theta=0.0
% INFO    : Bus 77424	: V=0.989102, theta=7.684496 -> V=1.0, theta=0.0
% INFO    : Bus 77425	: V=0.9902779, theta=7.973199 -> V=1.0, theta=0.0
% INFO    : Bus 77426	: V=0.9874318, theta=7.277242 -> V=1.0, theta=0.0
% INFO    : Bus 77427	: V=0.9846452, theta=6.714199 -> V=1.0, theta=0.0
% INFO    : Bus 77428	: V=0.9906179, theta=7.76721 -> V=1.0, theta=0.0
% INFO    : Bus 77429	: V=0.9897783, theta=7.822619 -> V=1.0, theta=0.0
% INFO    : Bus 77430	: V=0.9975847, theta=9.262415 -> V=1.0, theta=0.0
% INFO    : Bus 77431	: V=0.9981872, theta=9.215927 -> V=1.0, theta=0.0
% INFO    : Bus 77432	: V=0.9859607, theta=7.158203 -> V=1.0, theta=0.0
% INFO    : Bus 77433	: V=0.9874202, theta=7.603515 -> V=1.0, theta=0.0
% INFO    : Bus 77434	: V=0.9845129, theta=7.018605 -> V=1.0, theta=0.0
% INFO    : Bus 77435	: V=0.9947128, theta=8.482656 -> V=1.0, theta=0.0
% INFO    : Bus 77436	: V=0.9863263, theta=8.27489 -> V=1.0, theta=0.0
% INFO    : Bus 77437	: V=0.9812618, theta=6.949931 -> V=1.0, theta=0.0
% INFO    : Bus 77438	: V=1.0114913, theta=11.293076 -> V=1.0, theta=0.0
% INFO    : Bus 77439	: V=1.0048344, theta=10.279972 -> V=1.0, theta=0.0
% INFO    : Bus 77440	: V=1.0040477, theta=10.183535 -> V=1.0, theta=0.0
% INFO    : Bus 77441	: V=0.9782311, theta=7.862274 -> V=1.0, theta=0.0
% INFO    : Bus 77442	: V=0.9814788, theta=8.692132 -> V=1.0, theta=0.0
% INFO    : Bus 77443	: V=0.9837818, theta=9.252621 -> V=1.0, theta=0.0
% INFO    : Bus 77444	: V=0.9796321, theta=8.61235 -> V=1.0, theta=0.0
% INFO    : Bus 77445	: V=0.9849051, theta=10.377418 -> V=1.0, theta=0.0
% INFO    : Bus 77446	: V=0.9748825, theta=7.873918 -> V=1.0, theta=0.0
% INFO    : Bus 77447	: V=0.9831113, theta=8.810015 -> V=1.0, theta=0.0
% INFO    : Bus 77448	: V=0.9820787, theta=8.427459 -> V=1.0, theta=0.0
% INFO    : Bus 77449	: V=0.9865864, theta=9.530057 -> V=1.0, theta=0.0
% INFO    : Bus 77450	: V=0.9881853, theta=9.193535 -> V=1.0, theta=0.0
% INFO    : Bus 77451	: V=0.9889769, theta=8.06298 -> V=1.0, theta=0.0
% INFO    : Bus 77452	: V=0.9845596, theta=7.921116 -> V=1.0, theta=0.0
% INFO    : Bus 77453	: V=0.9820202, theta=8.375683 -> V=1.0, theta=0.0
% INFO    : Bus 77454	: V=0.9830664, theta=8.269946 -> V=1.0, theta=0.0
% INFO    : Bus 77455	: V=0.9987857, theta=12.172397 -> V=1.0, theta=0.0
% INFO    : Bus 77456	: V=0.989646, theta=9.338367 -> V=1.0, theta=0.0
% INFO    : Bus 77457	: V=0.9952888, theta=11.366669 -> V=1.0, theta=0.0
% INFO    : Bus 77458	: V=0.9943853, theta=11.364525 -> V=1.0, theta=0.0
% INFO    : Bus 77459	: V=0.989514, theta=12.043855 -> V=1.0, theta=0.0
% INFO    : Bus 77460	: V=0.990711, theta=20.01616 -> V=1.0, theta=0.0
% INFO    : Bus 77461	: V=0.9919485, theta=21.486454 -> V=1.0, theta=0.0
% INFO    : Bus 77462	: V=0.9839922, theta=9.416092 -> V=1.0, theta=0.0
% INFO    : Bus 77463	: V=0.982571, theta=11.784263 -> V=1.0, theta=0.0
% INFO    : Bus 77464	: V=0.9821938, theta=12.531728 -> V=1.0, theta=0.0
% INFO    : Bus 77465	: V=0.9972437, theta=15.219737 -> V=1.0, theta=0.0
% INFO    : Bus 77466	: V=1.0151059, theta=17.473256 -> V=1.0, theta=0.0
% INFO    : Bus 77467	: V=1.0057899, theta=16.232879 -> V=1.0, theta=0.0
% INFO    : Bus 77468	: V=1.0009209, theta=15.611589 -> V=1.0, theta=0.0
% INFO    : Bus 77469	: V=1.0001673, theta=15.734173 -> V=1.0, theta=0.0
% INFO    : Bus 77470	: V=0.998708, theta=15.180145 -> V=1.0, theta=0.0
% INFO    : Bus 77471	: V=1.0001642, theta=15.779704 -> V=1.0, theta=0.0
% INFO    : Bus 77472	: V=1.0027329, theta=15.910667 -> V=1.0, theta=0.0
% INFO    : Bus 77473	: V=1.0005286, theta=15.805325 -> V=1.0, theta=0.0
% INFO    : Bus 77474	: V=1.0009508, theta=15.660007 -> V=1.0, theta=0.0
% INFO    : Bus 77475	: V=1.0036432, theta=15.631079 -> V=1.0, theta=0.0
% INFO    : Bus 77476	: V=1.0035709, theta=15.921668 -> V=1.0, theta=0.0
% INFO    : Bus 77477	: V=1.0018067, theta=15.707284 -> V=1.0, theta=0.0
% INFO    : Bus 77478	: V=1.0014233, theta=15.585907 -> V=1.0, theta=0.0
% INFO    : Bus 77479	: V=1.0026085, theta=16.078698 -> V=1.0, theta=0.0
% INFO    : Bus 77480	: V=1.0070631, theta=15.499344 -> V=1.0, theta=0.0
% INFO    : Bus 77481	: V=1.0078882, theta=15.98907 -> V=1.0, theta=0.0
% INFO    : Bus 77482	: V=1.0047739, theta=15.495607 -> V=1.0, theta=0.0
% INFO    : Bus 77483	: V=0.9955052, theta=13.979678 -> V=1.0, theta=0.0
% INFO    : Bus 77484	: V=0.9919121, theta=14.836828 -> V=1.0, theta=0.0
% INFO    : Bus 77485	: V=0.995504, theta=14.60494 -> V=1.0, theta=0.0
% INFO    : Bus 77486	: V=0.9970777, theta=14.847436 -> V=1.0, theta=0.0
% INFO    : Bus 77487	: V=1.0000938, theta=16.46081 -> V=1.0, theta=0.0
% INFO    : Bus 77488	: V=1.0209228, theta=20.279882 -> V=1.0, theta=0.0
% INFO    : Bus 77489	: V=1.0086959, theta=17.674675 -> V=1.0, theta=0.0
% INFO    : Bus 77490	: V=1.0071061, theta=17.296131 -> V=1.0, theta=0.0
% INFO    : Bus 77491	: V=1.0030564, theta=17.175956 -> V=1.0, theta=0.0
% INFO    : Bus 77492	: V=1.0064867, theta=19.20063 -> V=1.0, theta=0.0
% INFO    : Bus 77493	: V=1.0032027, theta=19.144656 -> V=1.0, theta=0.0
% INFO    : Bus 77494	: V=1.0014126, theta=18.131042 -> V=1.0, theta=0.0
% INFO    : Bus 77495	: V=0.994662, theta=14.745646 -> V=1.0, theta=0.0
% INFO    : Bus 77496	: V=0.9977421, theta=15.341241 -> V=1.0, theta=0.0
% INFO    : Bus 77497	: V=0.9940207, theta=14.905572 -> V=1.0, theta=0.0
% INFO    : Bus 77498	: V=0.9928483, theta=14.838573 -> V=1.0, theta=0.0
% INFO    : Bus 77499	: V=1.0012517, theta=16.26393 -> V=1.0, theta=0.0
% INFO    : Bus 77500	: V=1.0029257, theta=16.495502 -> V=1.0, theta=0.0
% INFO    : Bus 77501	: V=0.996532, theta=15.166396 -> V=1.0, theta=0.0
% INFO    : Bus 77502	: V=0.9989075, theta=15.683562 -> V=1.0, theta=0.0
% INFO    : Bus 77503	: V=0.9993508, theta=16.233658 -> V=1.0, theta=0.0
% INFO    : Bus 77504	: V=0.9911564, theta=14.422459 -> V=1.0, theta=0.0
% INFO    : Bus 77505	: V=0.9906839, theta=13.782424 -> V=1.0, theta=0.0
% INFO    : Bus 77506	: V=0.9890278, theta=14.414149 -> V=1.0, theta=0.0
% INFO    : Bus 77507	: V=0.9986641, theta=15.004974 -> V=1.0, theta=0.0
% INFO    : Bus 77508	: V=0.9813236, theta=18.033354 -> V=1.0, theta=0.0
% INFO    : Bus 77509	: V=0.9915605, theta=16.544789 -> V=1.0, theta=0.0
% INFO    : Bus 77510	: V=0.9867254, theta=16.827686 -> V=1.0, theta=0.0
% INFO    : Bus 77511	: V=0.9868543, theta=16.731402 -> V=1.0, theta=0.0
% INFO    : Bus 77512	: V=0.9932281, theta=21.807526 -> V=1.0, theta=0.0
% INFO    : Bus 77513	: V=0.9905577, theta=21.348788 -> V=1.0, theta=0.0
% INFO    : Bus 77514	: V=0.9980963, theta=23.079238 -> V=1.0, theta=0.0
% INFO    : Bus 77515	: V=1.0026004, theta=24.601555 -> V=1.0, theta=0.0
% INFO    : Bus 77516	: V=1.0181157, theta=15.219022 -> V=1.0, theta=0.0
% INFO    : Bus 77517	: V=0.9987538, theta=20.238074 -> V=1.0, theta=0.0
% INFO    : Bus 77518	: V=1.0120135, theta=20.350164 -> V=1.0, theta=0.0
% INFO    : Bus 77519	: V=1.0244608, theta=16.433316 -> V=1.0, theta=0.0
% INFO    : Bus 77520	: V=1.0211433, theta=15.387586 -> V=1.0, theta=0.0
% INFO    : Bus 77521	: V=1.0205783, theta=15.200706 -> V=1.0, theta=0.0
% INFO    : Bus 77522	: V=0.9954155, theta=10.826859 -> V=1.0, theta=0.0
% INFO    : Bus 77523	: V=0.9935743, theta=10.541018 -> V=1.0, theta=0.0
% INFO    : Bus 77524	: V=0.9916811, theta=9.541302 -> V=1.0, theta=0.0
% INFO    : Bus 77525	: V=0.9901823, theta=9.289103 -> V=1.0, theta=0.0
% INFO    : Bus 77526	: V=0.997014, theta=9.976869 -> V=1.0, theta=0.0
% INFO    : Bus 77527	: V=0.9898989, theta=8.098141 -> V=1.0, theta=0.0
% INFO    : Bus 77528	: V=0.9923236, theta=10.627843 -> V=1.0, theta=0.0
% INFO    : Bus 77529	: V=0.9987376, theta=12.304884 -> V=1.0, theta=0.0
% INFO    : Bus 77530	: V=0.990365, theta=9.125523 -> V=1.0, theta=0.0
% INFO    : Bus 77531	: V=0.997412, theta=9.981573 -> V=1.0, theta=0.0
% INFO    : Bus 77532	: V=1.0007895, theta=10.897739 -> V=1.0, theta=0.0
% INFO    : Bus 77533	: V=0.9999027, theta=10.710307 -> V=1.0, theta=0.0
% INFO    : Bus 77534	: V=0.9926587, theta=9.173333 -> V=1.0, theta=0.0
% INFO    : Bus 77535	: V=0.9897338, theta=9.034952 -> V=1.0, theta=0.0
% INFO    : Bus 77536	: V=0.9923255, theta=9.179506 -> V=1.0, theta=0.0
% INFO    : Bus 77537	: V=0.9848753, theta=8.122789 -> V=1.0, theta=0.0
% INFO    : Bus 77538	: V=0.9887377, theta=8.160228 -> V=1.0, theta=0.0
% INFO    : Bus 77539	: V=0.9923185, theta=8.732404 -> V=1.0, theta=0.0
% INFO    : Bus 77540	: V=0.9887392, theta=8.157588 -> V=1.0, theta=0.0
% INFO    : Bus 77541	: V=0.990094, theta=8.343088 -> V=1.0, theta=0.0
% INFO    : Bus 77542	: V=0.9853287, theta=7.922226 -> V=1.0, theta=0.0
% INFO    : Bus 77543	: V=0.9842658, theta=7.929839 -> V=1.0, theta=0.0
% INFO    : Bus 77544	: V=0.9924891, theta=9.953704 -> V=1.0, theta=0.0
% INFO    : Bus 77545	: V=0.9837405, theta=7.474509 -> V=1.0, theta=0.0
% INFO    : Bus 77546	: V=0.9849145, theta=8.612172 -> V=1.0, theta=0.0
% INFO    : Bus 77547	: V=0.9886256, theta=10.975769 -> V=1.0, theta=0.0
% INFO    : Bus 77548	: V=0.9888767, theta=9.815895 -> V=1.0, theta=0.0
% INFO    : Bus 77549	: V=0.9895119, theta=9.783838 -> V=1.0, theta=0.0
% INFO    : Bus 77550	: V=0.9847647, theta=8.709682 -> V=1.0, theta=0.0
% INFO    : Bus 77551	: V=0.9944911, theta=11.481177 -> V=1.0, theta=0.0
% INFO    : Bus 77552	: V=0.9873417, theta=8.283474 -> V=1.0, theta=0.0
% INFO    : Bus 77553	: V=0.987277, theta=8.494413 -> V=1.0, theta=0.0
% INFO    : Bus 77554	: V=0.9920705, theta=8.555266 -> V=1.0, theta=0.0
% INFO    : Bus 77555	: V=0.9865271, theta=8.157764 -> V=1.0, theta=0.0
% INFO    : Bus 77556	: V=0.9932847, theta=10.518505 -> V=1.0, theta=0.0
% INFO    : Bus 77557	: V=0.9989953, theta=11.311032 -> V=1.0, theta=0.0
% INFO    : Bus 77558	: V=1.0123077, theta=26.196589 -> V=1.0, theta=0.0
% INFO    : Bus 77559	: V=1.0355663, theta=25.204048 -> V=1.0, theta=0.0
% INFO    : Bus 77560	: V=1.0311631, theta=24.048981 -> V=1.0, theta=0.0
% INFO    : Bus 77561	: V=1.0308353, theta=23.949847 -> V=1.0, theta=0.0
% INFO    : Bus 77562	: V=0.9870054, theta=29.896829 -> V=1.0, theta=0.0
% INFO    : Bus 77563	: V=0.9867255, theta=29.550682 -> V=1.0, theta=0.0
% INFO    : Bus 77564	: V=0.9837694, theta=32.944879 -> V=1.0, theta=0.0
% INFO    : Bus 77565	: V=0.9814398, theta=32.62878 -> V=1.0, theta=0.0
% INFO    : Bus 77566	: V=0.9998796, theta=16.30186 -> V=1.0, theta=0.0
% INFO    : Bus 77567	: V=0.9952739, theta=14.963417 -> V=1.0, theta=0.0
% INFO    : Bus 77568	: V=0.9938577, theta=14.823365 -> V=1.0, theta=0.0
% INFO    : Bus 77569	: V=0.9900237, theta=14.257937 -> V=1.0, theta=0.0
% INFO    : Bus 77570	: V=0.9934613, theta=14.525799 -> V=1.0, theta=0.0
% INFO    : Bus 77571	: V=0.989536, theta=13.976444 -> V=1.0, theta=0.0
% INFO    : Bus 77572	: V=0.9905611, theta=14.497494 -> V=1.0, theta=0.0
% INFO    : Bus 77573	: V=0.9886577, theta=13.558514 -> V=1.0, theta=0.0
% INFO    : Bus 77574	: V=0.9867303, theta=10.91977 -> V=1.0, theta=0.0
% INFO    : Bus 77575	: V=0.9994482, theta=12.623447 -> V=1.0, theta=0.0
% INFO    : Bus 77576	: V=0.9963279, theta=12.438409 -> V=1.0, theta=0.0
% INFO    : Bus 77577	: V=0.9858762, theta=10.856432 -> V=1.0, theta=0.0
% INFO    : Bus 77578	: V=1.0031773, theta=23.011352 -> V=1.0, theta=0.0
% INFO    : Bus 77579	: V=1.0076449, theta=12.001727 -> V=1.0, theta=0.0
% INFO    : Bus 77580	: V=0.9916412, theta=21.953323 -> V=1.0, theta=0.0
% INFO    : Bus 77581	: V=1.0002095, theta=40.426091 -> V=1.0, theta=0.0
% INFO    : Bus 77582	: V=0.9826941, theta=35.231954 -> V=1.0, theta=0.0
% INFO    : Bus 77583	: V=0.9592538, theta=22.055146 -> V=1.0, theta=0.0
% INFO    : Bus 77584	: V=0.9595151, theta=22.052576 -> V=1.0, theta=0.0
% INFO    : Bus 77585	: V=0.9655944, theta=22.494786 -> V=1.0, theta=0.0
% INFO    : Bus 77586	: V=0.9617429, theta=21.997013 -> V=1.0, theta=0.0
% INFO    : Bus 77587	: V=0.9621706, theta=22.242303 -> V=1.0, theta=0.0
% INFO    : Bus 77588	: V=1.0005382, theta=36.827517 -> V=1.0, theta=0.0
% INFO    : Bus 77589	: V=1.0001543, theta=36.717321 -> V=1.0, theta=0.0
% INFO    : Bus 77590	: V=0.9998126, theta=36.901725 -> V=1.0, theta=0.0
% INFO    : Bus 77591	: V=0.9941324, theta=26.07845 -> V=1.0, theta=0.0
% INFO    : Bus 77592	: V=0.9821759, theta=24.311135 -> V=1.0, theta=0.0
% INFO    : Bus 77593	: V=0.9836016, theta=24.895301 -> V=1.0, theta=0.0
% INFO    : Bus 77594	: V=1.0058919, theta=25.771395 -> V=1.0, theta=0.0
% INFO    : Bus 77595	: V=1.0041904, theta=26.482868 -> V=1.0, theta=0.0
% INFO    : Bus 77596	: V=0.9973963, theta=23.569189 -> V=1.0, theta=0.0
% INFO    : Bus 77597	: V=0.9848892, theta=17.482277 -> V=1.0, theta=0.0
% INFO    : Bus 77598	: V=0.9846959, theta=17.23341 -> V=1.0, theta=0.0
% INFO    : Bus 77599	: V=0.9907236, theta=26.481288 -> V=1.0, theta=0.0
% INFO    : Bus 77600	: V=1.0057795, theta=14.831762 -> V=1.0, theta=0.0
% INFO    : Bus 77601	: V=1.016015, theta=20.733009 -> V=1.0, theta=0.0
% INFO    : Bus 77602	: V=0.9837764, theta=36.981234 -> V=1.0, theta=0.0
% INFO    : Bus 77603	: V=0.9943542, theta=21.040864 -> V=1.0, theta=0.0
% INFO    : Bus 77604	: V=1.0046183, theta=25.104894 -> V=1.0, theta=0.0
% INFO    : Bus 77605	: V=1.0048425, theta=25.105917 -> V=1.0, theta=0.0
% INFO    : Bus 77606	: V=1.0039576, theta=24.956427 -> V=1.0, theta=0.0
% INFO    : Bus 77607	: V=1.0017497, theta=24.880202 -> V=1.0, theta=0.0
% INFO    : Bus 77608	: V=0.9986633, theta=21.976874 -> V=1.0, theta=0.0
% INFO    : Bus 77609	: V=1.0063471, theta=25.845583 -> V=1.0, theta=0.0
% INFO    : Bus 77610	: V=1.0061136, theta=25.420918 -> V=1.0, theta=0.0
% INFO    : Bus 77611	: V=1.0013023, theta=24.983044 -> V=1.0, theta=0.0
% INFO    : Bus 77612	: V=0.9989427, theta=23.733302 -> V=1.0, theta=0.0
% INFO    : Bus 77613	: V=1.0046888, theta=27.717991 -> V=1.0, theta=0.0
% INFO    : Bus 77614	: V=1.0006533, theta=18.517055 -> V=1.0, theta=0.0
% INFO    : Bus 77615	: V=0.992862, theta=19.516259 -> V=1.0, theta=0.0
% INFO    : Bus 77616	: V=0.9917474, theta=27.454498 -> V=1.0, theta=0.0
% INFO    : Bus 77617	: V=0.9953738, theta=33.186202 -> V=1.0, theta=0.0
% INFO    : Bus 77618	: V=1.0028632, theta=17.430016 -> V=1.0, theta=0.0
% INFO    : Bus 77619	: V=1.0103519, theta=19.081264 -> V=1.0, theta=0.0
% INFO    : Bus 77620	: V=1.012259, theta=19.650801 -> V=1.0, theta=0.0
% INFO    : Bus 77621	: V=0.999593, theta=14.797161 -> V=1.0, theta=0.0
% INFO    : Bus 77622	: V=1.0031103, theta=16.132097 -> V=1.0, theta=0.0
% INFO    : Bus 77623	: V=0.9862381, theta=13.865498 -> V=1.0, theta=0.0
% INFO    : Bus 77624	: V=0.984611, theta=14.575978 -> V=1.0, theta=0.0
% INFO    : Bus 77625	: V=0.9890886, theta=13.674806 -> V=1.0, theta=0.0
% INFO    : Bus 77626	: V=0.9870724, theta=14.322657 -> V=1.0, theta=0.0
% INFO    : Bus 77627	: V=0.9846601, theta=14.100215 -> V=1.0, theta=0.0
% INFO    : Bus 77628	: V=0.9860229, theta=13.64708 -> V=1.0, theta=0.0
% INFO    : Bus 77629	: V=0.9869035, theta=13.503388 -> V=1.0, theta=0.0
% INFO    : Bus 77630	: V=0.9855487, theta=13.56314 -> V=1.0, theta=0.0
% INFO    : Bus 77631	: V=0.987535, theta=13.691153 -> V=1.0, theta=0.0
% INFO    : Bus 77632	: V=0.9936648, theta=15.42265 -> V=1.0, theta=0.0
% INFO    : Bus 77633	: V=0.9947258, theta=15.231143 -> V=1.0, theta=0.0
% INFO    : Bus 77634	: V=1.0067745, theta=12.853802 -> V=1.0, theta=0.0
% INFO    : Bus 77635	: V=1.0021619, theta=11.641757 -> V=1.0, theta=0.0
% INFO    : Bus 77636	: V=1.0076961, theta=12.526774 -> V=1.0, theta=0.0
% INFO    : Bus 77637	: V=1.0008849, theta=12.196079 -> V=1.0, theta=0.0
% INFO    : Bus 77638	: V=0.9997265, theta=12.063524 -> V=1.0, theta=0.0
% INFO    : Bus 77639	: V=1.0036626, theta=12.618494 -> V=1.0, theta=0.0
% INFO    : Bus 77640	: V=1.0005352, theta=12.261452 -> V=1.0, theta=0.0
% INFO    : Bus 77641	: V=1.0028351, theta=12.376845 -> V=1.0, theta=0.0
% INFO    : Bus 77642	: V=1.0077843, theta=12.93748 -> V=1.0, theta=0.0
% INFO    : Bus 77643	: V=1.0096612, theta=12.95976 -> V=1.0, theta=0.0
% INFO    : Bus 77644	: V=1.0068244, theta=12.866731 -> V=1.0, theta=0.0
% INFO    : Bus 77645	: V=1.0084003, theta=13.276687 -> V=1.0, theta=0.0
% INFO    : Bus 77646	: V=1.0074565, theta=12.928342 -> V=1.0, theta=0.0
% INFO    : Bus 77647	: V=0.9882296, theta=12.901451 -> V=1.0, theta=0.0
% INFO    : Bus 77648	: V=0.9945612, theta=11.416806 -> V=1.0, theta=0.0
% INFO    : Bus 77649	: V=0.985421, theta=12.08182 -> V=1.0, theta=0.0
% INFO    : Bus 77650	: V=0.9888683, theta=13.748921 -> V=1.0, theta=0.0
% INFO    : Bus 77651	: V=0.9862905, theta=13.042759 -> V=1.0, theta=0.0
% INFO    : Bus 77652	: V=0.9879808, theta=23.968007 -> V=1.0, theta=0.0
% INFO    : Bus 77653	: V=0.9838212, theta=25.670093 -> V=1.0, theta=0.0
% INFO    : Bus 77654	: V=0.9819862, theta=27.734256 -> V=1.0, theta=0.0
% INFO    : Bus 77655	: V=0.9574152, theta=-49.825944 -> V=1.0, theta=0.0
% INFO    : Bus 77656	: V=0.9941059, theta=-58.849207 -> V=1.0, theta=0.0
% INFO    : Bus 77657	: V=0.9967172, theta=-59.271755 -> V=1.0, theta=0.0
% INFO    : Bus 77659	: V=1.0115157, theta=-63.238151 -> V=1.0, theta=0.0
% INFO    : Bus 77660	: V=0.9921032, theta=-17.880424 -> V=1.0, theta=0.0
% INFO    : Bus 77661	: V=0.9991841, theta=-16.913018 -> V=1.0, theta=0.0
% INFO    : Bus 77662	: V=1.0028704, theta=-16.387818 -> V=1.0, theta=0.0
% INFO    : Bus 77663	: V=1.0031294, theta=-16.436959 -> V=1.0, theta=0.0
% INFO    : Bus 77664	: V=1.0052223, theta=-16.308797 -> V=1.0, theta=0.0
% INFO    : Bus 77665	: V=1.0095536, theta=-15.694579 -> V=1.0, theta=0.0
% INFO    : Bus 77666	: V=1.00725, theta=-16.152265 -> V=1.0, theta=0.0
% INFO    : Bus 77667	: V=0.9904613, theta=-18.127989 -> V=1.0, theta=0.0
% INFO    : Bus 77668	: V=0.9950104, theta=-17.504847 -> V=1.0, theta=0.0
% INFO    : Bus 77669	: V=1.0062292, theta=-16.210533 -> V=1.0, theta=0.0
% INFO    : Bus 77670	: V=1.0059695, theta=-16.273381 -> V=1.0, theta=0.0
% INFO    : Bus 77671	: V=1.0021812, theta=-16.778702 -> V=1.0, theta=0.0
% INFO    : Bus 77672	: V=1.0080615, theta=-15.991145 -> V=1.0, theta=0.0
% INFO    : Bus 77673	: V=0.9935248, theta=-17.652143 -> V=1.0, theta=0.0
% INFO    : Bus 77674	: V=0.9944501, theta=-17.721218 -> V=1.0, theta=0.0
% INFO    : Bus 77675	: V=1.0002755, theta=-16.940102 -> V=1.0, theta=0.0
% INFO    : Bus 77676	: V=1.0019688, theta=-16.833471 -> V=1.0, theta=0.0
% INFO    : Bus 77677	: V=1.0083475, theta=-15.959984 -> V=1.0, theta=0.0
% INFO    : Bus 77678	: V=1.0071489, theta=-15.993266 -> V=1.0, theta=0.0
% INFO    : Bus 77679	: V=0.998039, theta=-17.042631 -> V=1.0, theta=0.0
% INFO    : Bus 77680	: V=0.9984924, theta=-16.791182 -> V=1.0, theta=0.0
% INFO    : Bus 77681	: V=1.0003185, theta=-16.897987 -> V=1.0, theta=0.0
% INFO    : Bus 77682	: V=0.9986158, theta=-17.003022 -> V=1.0, theta=0.0
% INFO    : Bus 77683	: V=0.9894573, theta=-18.496771 -> V=1.0, theta=0.0
% INFO    : Bus 77684	: V=0.9899622, theta=-18.234331 -> V=1.0, theta=0.0
% INFO    : Bus 77685	: V=0.9934166, theta=-17.831126 -> V=1.0, theta=0.0
% INFO    : Bus 77686	: V=0.9926696, theta=-17.931639 -> V=1.0, theta=0.0
% INFO    : Bus 77687	: V=0.9890346, theta=-18.518059 -> V=1.0, theta=0.0
% INFO    : Bus 77688	: V=0.9950908, theta=-17.692928 -> V=1.0, theta=0.0
% INFO    : Bus 77689	: V=0.9963471, theta=-17.52706 -> V=1.0, theta=0.0
% INFO    : Bus 77690	: V=0.997776, theta=-17.226833 -> V=1.0, theta=0.0
% INFO    : Bus 77691	: V=0.999836, theta=-17.110063 -> V=1.0, theta=0.0
% INFO    : Bus 77692	: V=0.9998661, theta=-17.083776 -> V=1.0, theta=0.0
% INFO    : Bus 77693	: V=0.9952566, theta=-17.666221 -> V=1.0, theta=0.0
% INFO    : Bus 77694	: V=0.9958217, theta=-17.589472 -> V=1.0, theta=0.0
% INFO    : Bus 77695	: V=0.9962383, theta=-17.57996 -> V=1.0, theta=0.0
% INFO    : Bus 77696	: V=0.9893329, theta=-18.298683 -> V=1.0, theta=0.0
% INFO    : Bus 77697	: V=0.9899622, theta=-18.483066 -> V=1.0, theta=0.0
% INFO    : Bus 77698	: V=0.9894953, theta=-18.379755 -> V=1.0, theta=0.0
% INFO    : Bus 77699	: V=0.9873019, theta=-18.518816 -> V=1.0, theta=0.0
% INFO    : Bus 77700	: V=0.9854952, theta=-18.826707 -> V=1.0, theta=0.0
% INFO    : Bus 77701	: V=0.9898801, theta=-18.512259 -> V=1.0, theta=0.0
% INFO    : Bus 77702	: V=0.9893069, theta=-18.121461 -> V=1.0, theta=0.0
% INFO    : Bus 77703	: V=0.9939854, theta=-17.511861 -> V=1.0, theta=0.0
% INFO    : Bus 77704	: V=0.9922286, theta=-17.766644 -> V=1.0, theta=0.0
% INFO    : Bus 77705	: V=0.9959376, theta=-17.435854 -> V=1.0, theta=0.0
% INFO    : Bus 77706	: V=0.9985182, theta=-17.120127 -> V=1.0, theta=0.0
% INFO    : Bus 77707	: V=0.9908805, theta=-17.452302 -> V=1.0, theta=0.0
% INFO    : Bus 77708	: V=0.9965104, theta=-16.988197 -> V=1.0, theta=0.0
% INFO    : Bus 77709	: V=0.9978397, theta=-17.200951 -> V=1.0, theta=0.0
% INFO    : Bus 77710	: V=0.999696, theta=-16.655088 -> V=1.0, theta=0.0
% INFO    : Bus 77711	: V=1.0037762, theta=-16.361204 -> V=1.0, theta=0.0
% INFO    : Bus 77712	: V=1.0016771, theta=-16.375877 -> V=1.0, theta=0.0
% INFO    : Bus 77713	: V=1.0096854, theta=-15.954048 -> V=1.0, theta=0.0
% INFO    : Bus 77714	: V=1.0052214, theta=-16.225167 -> V=1.0, theta=0.0
% INFO    : Bus 77715	: V=1.0099256, theta=-15.908289 -> V=1.0, theta=0.0
% INFO    : Bus 77716	: V=1.01191, theta=-15.550324 -> V=1.0, theta=0.0
% INFO    : Bus 77717	: V=1.0111411, theta=-15.899487 -> V=1.0, theta=0.0
% INFO    : Bus 77718	: V=1.0092852, theta=-15.853574 -> V=1.0, theta=0.0
% INFO    : Bus 77719	: V=1.0126436, theta=-15.081362 -> V=1.0, theta=0.0
% INFO    : Bus 77720	: V=1.0093909, theta=-15.758326 -> V=1.0, theta=0.0
% INFO    : Bus 77721	: V=1.0101202, theta=-15.31037 -> V=1.0, theta=0.0
% INFO    : Bus 77722	: V=1.0085665, theta=-15.662019 -> V=1.0, theta=0.0
% INFO    : Bus 77723	: V=1.0047373, theta=-16.125816 -> V=1.0, theta=0.0
% INFO    : Bus 77724	: V=1.0065073, theta=-15.637526 -> V=1.0, theta=0.0
% INFO    : Bus 77725	: V=1.004528, theta=-16.140317 -> V=1.0, theta=0.0
% INFO    : Bus 77726	: V=1.0040214, theta=-16.158526 -> V=1.0, theta=0.0
% INFO    : Bus 77727	: V=1.0055664, theta=-15.970467 -> V=1.0, theta=0.0
% INFO    : Bus 77728	: V=1.0058083, theta=-15.848687 -> V=1.0, theta=0.0
% INFO    : Bus 77729	: V=1.0031281, theta=-16.521377 -> V=1.0, theta=0.0
% INFO    : Bus 77730	: V=1.0065072, theta=-15.792549 -> V=1.0, theta=0.0
% INFO    : Bus 77731	: V=1.0041432, theta=-16.230996 -> V=1.0, theta=0.0
% INFO    : Bus 77732	: V=1.0068559, theta=-15.699186 -> V=1.0, theta=0.0
% INFO    : Bus 77733	: V=1.0062195, theta=-15.547575 -> V=1.0, theta=0.0
% INFO    : Bus 77734	: V=1.0088167, theta=-15.190286 -> V=1.0, theta=0.0
% INFO    : Bus 77735	: V=1.0112034, theta=-14.953898 -> V=1.0, theta=0.0
% INFO    : Bus 77736	: V=1.0208819, theta=-7.426996 -> V=1.0, theta=0.0
% INFO    : Bus 77737	: V=1.0230987, theta=-13.452393 -> V=1.0, theta=0.0
% INFO    : Bus 77738	: V=1.021662, theta=-13.408239 -> V=1.0, theta=0.0
% INFO    : Bus 77739	: V=1.0210855, theta=-13.445412 -> V=1.0, theta=0.0
% INFO    : Bus 77740	: V=1.0207199, theta=-7.367178 -> V=1.0, theta=0.0
% INFO    : Bus 77741	: V=1.0186939, theta=-20.835897 -> V=1.0, theta=0.0
% INFO    : Bus 77742	: V=1.0157046, theta=-18.885861 -> V=1.0, theta=0.0
% INFO    : Bus 77743	: V=1.0086538, theta=-15.726648 -> V=1.0, theta=0.0
% INFO    : Bus 77744	: V=1.00513, theta=-16.446206 -> V=1.0, theta=0.0
% INFO    : Bus 77745	: V=1.0061593, theta=-16.311897 -> V=1.0, theta=0.0
% INFO    : Bus 77746	: V=0.9894039, theta=-18.496259 -> V=1.0, theta=0.0
% INFO    : Bus 77747	: V=0.9913601, theta=-18.089443 -> V=1.0, theta=0.0
% INFO    : Bus 77748	: V=0.9849133, theta=-18.984727 -> V=1.0, theta=0.0
% INFO    : Bus 77749	: V=0.9933227, theta=-18.979286 -> V=1.0, theta=0.0
% INFO    : Bus 77750	: V=0.99909, theta=-17.430133 -> V=1.0, theta=0.0
% INFO    : Bus 77751	: V=0.9979636, theta=-17.518854 -> V=1.0, theta=0.0
% INFO    : Bus 77752	: V=1.0024726, theta=-16.868408 -> V=1.0, theta=0.0
% INFO    : Bus 77753	: V=0.9990421, theta=-17.37997 -> V=1.0, theta=0.0
% INFO    : Bus 77754	: V=0.9973586, theta=-17.270115 -> V=1.0, theta=0.0
% INFO    : Bus 77755	: V=0.9861878, theta=-18.910214 -> V=1.0, theta=0.0
% INFO    : Bus 77756	: V=0.9912906, theta=-18.104255 -> V=1.0, theta=0.0
% INFO    : Bus 77757	: V=0.9918005, theta=-18.071417 -> V=1.0, theta=0.0
% INFO    : Bus 77758	: V=0.9934242, theta=-17.946842 -> V=1.0, theta=0.0
% INFO    : Bus 77759	: V=0.9932957, theta=-17.948445 -> V=1.0, theta=0.0
% INFO    : Bus 77760	: V=0.9934388, theta=-17.856862 -> V=1.0, theta=0.0
% INFO    : Bus 77761	: V=0.9961678, theta=-17.65217 -> V=1.0, theta=0.0
% INFO    : Bus 77762	: V=1.0084571, theta=-5.379308 -> V=1.0, theta=0.0
% INFO    : Bus 77763	: V=1.002994, theta=-16.058235 -> V=1.0, theta=0.0
% INFO    : Bus 77764	: V=1.0005975, theta=-16.860249 -> V=1.0, theta=0.0
% INFO    : Bus 77765	: V=0.9978252, theta=-17.254008 -> V=1.0, theta=0.0
% INFO    : Bus 77766	: V=1.0023195, theta=-16.287866 -> V=1.0, theta=0.0
% INFO    : Bus 77767	: V=0.9771935, theta=-23.414868 -> V=1.0, theta=0.0
% INFO    : Bus 77768	: V=1.0012201, theta=-15.725019 -> V=1.0, theta=0.0
% INFO    : Bus 77769	: V=0.989281, theta=-79.442632 -> V=1.0, theta=0.0
% INFO    : Bus 77770	: V=0.9700072, theta=-22.240879 -> V=1.0, theta=0.0
% INFO    : Bus 77771	: V=0.9797281, theta=-31.891662 -> V=1.0, theta=0.0
% INFO    : Bus 77772	: V=0.9759987, theta=-29.69036 -> V=1.0, theta=0.0
% INFO    : Bus 77773	: V=0.9727089, theta=-29.35043 -> V=1.0, theta=0.0
% INFO    : Bus 77774	: V=0.9739329, theta=-30.54946 -> V=1.0, theta=0.0
% INFO    : Bus 77775	: V=0.9731758, theta=-28.987142 -> V=1.0, theta=0.0
% INFO    : Bus 77776	: V=0.9914034, theta=-36.472866 -> V=1.0, theta=0.0
% INFO    : Bus 77777	: V=0.9469318, theta=-25.932648 -> V=1.0, theta=0.0
% INFO    : Bus 77778	: V=0.9481611, theta=-34.147921 -> V=1.0, theta=0.0
% INFO    : Bus 77779	: V=1.0201526, theta=-4.483703 -> V=1.0, theta=0.0
% INFO    : Bus 77780	: V=1.0141262, theta=-56.568066 -> V=1.0, theta=0.0
% INFO    : Bus 77781	: V=1.0143503, theta=-68.629213 -> V=1.0, theta=0.0
% INFO    : Bus 77782	: V=1.0119562, theta=-75.863083 -> V=1.0, theta=0.0
% INFO    : Bus 77783	: V=1.0043135, theta=-75.707003 -> V=1.0, theta=0.0
% INFO    : Bus 77784	: V=0.9858154, theta=-77.753977 -> V=1.0, theta=0.0
% INFO    : Bus 77785	: V=0.9897994, theta=-72.837751 -> V=1.0, theta=0.0
% INFO    : Bus 77786	: V=1.0252442, theta=-76.050629 -> V=1.0, theta=0.0
% INFO    : Bus 77787	: V=1.0167402, theta=-76.486996 -> V=1.0, theta=0.0
% INFO    : Bus 77788	: V=1.0052108, theta=-41.451181 -> V=1.0, theta=0.0
% INFO    : Bus 77789	: V=0.9708075, theta=-27.385515 -> V=1.0, theta=0.0
% INFO    : Bus 77790	: V=1.0233441, theta=-70.538635 -> V=1.0, theta=0.0
% INFO    : Bus 77791	: V=1.0126798, theta=-70.184138 -> V=1.0, theta=0.0
% INFO    : Bus 77792	: V=1.0122763, theta=-70.356069 -> V=1.0, theta=0.0
% INFO    : Bus 77793	: V=0.9793717, theta=-77.55509 -> V=1.0, theta=0.0
% INFO    : Bus 77794	: V=0.9824468, theta=-75.935861 -> V=1.0, theta=0.0
% INFO    : Bus 77795	: V=0.9848851, theta=-75.771518 -> V=1.0, theta=0.0
% INFO    : Bus 77796	: V=0.985314, theta=-75.608724 -> V=1.0, theta=0.0
% INFO    : Bus 77797	: V=0.9848614, theta=-76.902364 -> V=1.0, theta=0.0
% INFO    : Bus 77798	: V=0.9755539, theta=-77.251883 -> V=1.0, theta=0.0
% INFO    : Bus 77799	: V=0.9792442, theta=-74.528969 -> V=1.0, theta=0.0
% INFO    : Bus 77800	: V=0.9859242, theta=-74.629381 -> V=1.0, theta=0.0
% INFO    : Bus 77801	: V=0.9846832, theta=-75.717054 -> V=1.0, theta=0.0
% INFO    : Bus 77802	: V=0.9904357, theta=-75.423826 -> V=1.0, theta=0.0
% INFO    : Bus 77803	: V=0.9854427, theta=-74.315714 -> V=1.0, theta=0.0
% INFO    : Bus 77804	: V=0.9730255, theta=-75.174455 -> V=1.0, theta=0.0
% INFO    : Bus 77805	: V=0.9831822, theta=-75.845363 -> V=1.0, theta=0.0
% INFO    : Bus 77806	: V=0.993886, theta=-74.262213 -> V=1.0, theta=0.0
% INFO    : Bus 77807	: V=0.9922941, theta=-74.641444 -> V=1.0, theta=0.0
% INFO    : Bus 77808	: V=0.9815857, theta=-74.017892 -> V=1.0, theta=0.0
% INFO    : Bus 77809	: V=0.983735, theta=-72.192067 -> V=1.0, theta=0.0
% INFO    : Bus 77810	: V=0.9833861, theta=-73.702209 -> V=1.0, theta=0.0
% INFO    : Bus 77811	: V=0.9866178, theta=-75.541165 -> V=1.0, theta=0.0
% INFO    : Bus 77812	: V=0.9693903, theta=-78.035425 -> V=1.0, theta=0.0
% INFO    : Bus 77813	: V=0.9589712, theta=-22.879427 -> V=1.0, theta=0.0
% INFO    : Bus 77814	: V=0.9483907, theta=-23.695448 -> V=1.0, theta=0.0
% INFO    : Bus 77815	: V=0.9935959, theta=-77.823815 -> V=1.0, theta=0.0
% INFO    : Bus 77816	: V=0.9894543, theta=-78.504595 -> V=1.0, theta=0.0
% INFO    : Bus 77817	: V=1.0005277, theta=-76.860597 -> V=1.0, theta=0.0
% INFO    : Bus 77818	: V=0.9947901, theta=-77.790081 -> V=1.0, theta=0.0
% INFO    : Bus 77819	: V=0.9965113, theta=-77.317814 -> V=1.0, theta=0.0
% INFO    : Bus 77820	: V=1.003713, theta=-76.002748 -> V=1.0, theta=0.0
% INFO    : Bus 77821	: V=1.002656, theta=-76.472162 -> V=1.0, theta=0.0
% INFO    : Bus 77822	: V=0.9857541, theta=2.75593 -> V=1.0, theta=0.0
% INFO    : Bus 77823	: V=0.981452, theta=2.107909 -> V=1.0, theta=0.0
% INFO    : Bus 77824	: V=0.987492, theta=2.865188 -> V=1.0, theta=0.0
% INFO    : Bus 77825	: V=0.9800233, theta=1.722019 -> V=1.0, theta=0.0
% INFO    : Bus 77826	: V=0.9879108, theta=3.168056 -> V=1.0, theta=0.0
% INFO    : Bus 77827	: V=0.9879324, theta=2.828244 -> V=1.0, theta=0.0
% INFO    : Bus 77828	: V=0.9883073, theta=2.978059 -> V=1.0, theta=0.0
% INFO    : Bus 77829	: V=0.9834808, theta=2.081316 -> V=1.0, theta=0.0
% INFO    : Bus 77830	: V=0.988604, theta=3.201352 -> V=1.0, theta=0.0
% INFO    : Bus 77831	: V=0.9830072, theta=2.037612 -> V=1.0, theta=0.0
% INFO    : Bus 77832	: V=0.9828636, theta=1.952429 -> V=1.0, theta=0.0
% INFO    : Bus 77833	: V=0.9846494, theta=2.003415 -> V=1.0, theta=0.0
% INFO    : Bus 77834	: V=0.988326, theta=2.936715 -> V=1.0, theta=0.0
% INFO    : Bus 77835	: V=0.9908062, theta=3.298897 -> V=1.0, theta=0.0
% INFO    : Bus 77836	: V=0.9971681, theta=4.405614 -> V=1.0, theta=0.0
% INFO    : Bus 77837	: V=0.9888986, theta=2.905351 -> V=1.0, theta=0.0
% INFO    : Bus 77838	: V=0.990337, theta=3.063181 -> V=1.0, theta=0.0
% INFO    : Bus 77839	: V=0.9862895, theta=2.688954 -> V=1.0, theta=0.0
% INFO    : Bus 77840	: V=0.9837882, theta=1.844812 -> V=1.0, theta=0.0
% INFO    : Bus 77841	: V=0.9799486, theta=1.362993 -> V=1.0, theta=0.0
% INFO    : Bus 77842	: V=0.9820824, theta=2.10164 -> V=1.0, theta=0.0
% INFO    : Bus 77843	: V=0.9862805, theta=2.57275 -> V=1.0, theta=0.0
% INFO    : Bus 77844	: V=0.9754161, theta=1.374404 -> V=1.0, theta=0.0
% INFO    : Bus 77845	: V=0.9804439, theta=2.234606 -> V=1.0, theta=0.0
% INFO    : Bus 77846	: V=0.9852437, theta=2.351258 -> V=1.0, theta=0.0
% INFO    : Bus 77847	: V=0.9839907, theta=2.26203 -> V=1.0, theta=0.0
% INFO    : Bus 77848	: V=0.9864557, theta=2.571116 -> V=1.0, theta=0.0
% INFO    : Bus 77849	: V=0.9927727, theta=3.858184 -> V=1.0, theta=0.0
% INFO    : Bus 77850	: V=0.991069, theta=3.400812 -> V=1.0, theta=0.0
% INFO    : Bus 77851	: V=0.9878664, theta=1.580479 -> V=1.0, theta=0.0
% INFO    : Bus 77852	: V=1.0238041, theta=9.637717 -> V=1.0, theta=0.0
% INFO    : Bus 77853	: V=1.0103882, theta=6.183657 -> V=1.0, theta=0.0
% INFO    : Bus 77854	: V=1.0105455, theta=6.076128 -> V=1.0, theta=0.0
% INFO    : Bus 77855	: V=0.9909834, theta=3.016797 -> V=1.0, theta=0.0
% INFO    : Bus 77856	: V=0.9947595, theta=3.958526 -> V=1.0, theta=0.0
% INFO    : Bus 77857	: V=0.9966807, theta=4.056808 -> V=1.0, theta=0.0
% INFO    : Bus 77858	: V=0.9952184, theta=3.864337 -> V=1.0, theta=0.0
% INFO    : Bus 77859	: V=1.0002216, theta=4.410745 -> V=1.0, theta=0.0
% INFO    : Bus 77860	: V=0.9780558, theta=1.869363 -> V=1.0, theta=0.0
% INFO    : Bus 77861	: V=0.9797536, theta=1.691193 -> V=1.0, theta=0.0
% INFO    : Bus 77862	: V=0.9834999, theta=2.541876 -> V=1.0, theta=0.0
% INFO    : Bus 77863	: V=0.9865566, theta=2.872074 -> V=1.0, theta=0.0
% INFO    : Bus 77864	: V=0.9842608, theta=2.673154 -> V=1.0, theta=0.0
% INFO    : Bus 77865	: V=0.976905, theta=2.108274 -> V=1.0, theta=0.0
% INFO    : Bus 77866	: V=0.9737657, theta=1.721292 -> V=1.0, theta=0.0
% INFO    : Bus 77867	: V=0.9901125, theta=5.98328 -> V=1.0, theta=0.0
% INFO    : Bus 77868	: V=0.9780448, theta=-5.842468 -> V=1.0, theta=0.0
% INFO    : Bus 77869	: V=0.9839732, theta=-4.741439 -> V=1.0, theta=0.0
% INFO    : Bus 77870	: V=0.9927886, theta=-4.481741 -> V=1.0, theta=0.0
% INFO    : Bus 77871	: V=0.9917352, theta=-4.839363 -> V=1.0, theta=0.0
% INFO    : Bus 77872	: V=0.9990461, theta=11.542229 -> V=1.0, theta=0.0
% INFO    : Bus 77873	: V=0.9950825, theta=8.76439 -> V=1.0, theta=0.0
% INFO    : Bus 77874	: V=0.9973636, theta=16.66442 -> V=1.0, theta=0.0
% INFO    : Bus 77875	: V=0.9980277, theta=16.939575 -> V=1.0, theta=0.0
% INFO    : Bus 77876	: V=1.0111607, theta=12.302845 -> V=1.0, theta=0.0
% INFO    : Bus 77877	: V=1.0120588, theta=11.919805 -> V=1.0, theta=0.0
% INFO    : Bus 77878	: V=0.950512, theta=-1.127781 -> V=1.0, theta=0.0
% INFO    : Bus 77879	: V=0.9785594, theta=2.775465 -> V=1.0, theta=0.0
% INFO    : Bus 77880	: V=0.9593372, theta=-0.411735 -> V=1.0, theta=0.0
% INFO    : Bus 77881	: V=0.9746454, theta=-1.409361 -> V=1.0, theta=0.0
% INFO    : Bus 77882	: V=0.9804797, theta=-0.504435 -> V=1.0, theta=0.0
% INFO    : Bus 77883	: V=0.9769343, theta=-1.217147 -> V=1.0, theta=0.0
% INFO    : Bus 77884	: V=0.9744299, theta=-1.401033 -> V=1.0, theta=0.0
% INFO    : Bus 77885	: V=0.9719306, theta=-1.675937 -> V=1.0, theta=0.0
% INFO    : Bus 77886	: V=0.9786552, theta=-1.424191 -> V=1.0, theta=0.0
% INFO    : Bus 77887	: V=0.9623401, theta=-3.70334 -> V=1.0, theta=0.0
% INFO    : Bus 77888	: V=0.9726328, theta=-1.690323 -> V=1.0, theta=0.0
% INFO    : Bus 77889	: V=0.9925049, theta=-0.394333 -> V=1.0, theta=0.0
% INFO    : Bus 77890	: V=0.9900801, theta=1.114852 -> V=1.0, theta=0.0
% INFO    : Bus 77891	: V=1.0001973, theta=0.432943 -> V=1.0, theta=0.0
% INFO    : Bus 77892	: V=0.9851101, theta=-0.875261 -> V=1.0, theta=0.0
% INFO    : Bus 77893	: V=0.9867711, theta=-0.965382 -> V=1.0, theta=0.0
% INFO    : Bus 77894	: V=0.9754736, theta=-4.312416 -> V=1.0, theta=0.0
% INFO    : Bus 77895	: V=0.9828217, theta=-3.860027 -> V=1.0, theta=0.0
% INFO    : Bus 77896	: V=0.9812489, theta=-3.91628 -> V=1.0, theta=0.0
% INFO    : Bus 77897	: V=0.9687195, theta=-4.043401 -> V=1.0, theta=0.0
% INFO    : Bus 77898	: V=1.0185216, theta=2.289174 -> V=1.0, theta=0.0
% INFO    : Bus 77899	: V=1.0152753, theta=1.411737 -> V=1.0, theta=0.0
% INFO    : Bus 77900	: V=1.0183746, theta=2.228999 -> V=1.0, theta=0.0
% INFO    : Bus 77901	: V=1.0140227, theta=0.914655 -> V=1.0, theta=0.0
% INFO    : Bus 77902	: V=1.0119638, theta=9.721649 -> V=1.0, theta=0.0
% INFO    : Bus 77903	: V=0.9903917, theta=8.182335 -> V=1.0, theta=0.0
% INFO    : Bus 77904	: V=0.9827277, theta=-1.868127 -> V=1.0, theta=0.0
% INFO    : Bus 77905	: V=0.998324, theta=1.551459 -> V=1.0, theta=0.0
% INFO    : Bus 77906	: V=0.9974512, theta=0.413482 -> V=1.0, theta=0.0
% INFO    : Bus 77907	: V=0.9972823, theta=0.380943 -> V=1.0, theta=0.0
% INFO    : Bus 77908	: V=0.9932403, theta=-1.696252 -> V=1.0, theta=0.0
% INFO    : Bus 77909	: V=0.9772899, theta=-5.387655 -> V=1.0, theta=0.0
% INFO    : Bus 77910	: V=0.9764028, theta=-6.164015 -> V=1.0, theta=0.0
% INFO    : Bus 77911	: V=1.0059065, theta=11.717845 -> V=1.0, theta=0.0
% INFO    : Bus 77912	: V=0.9870003, theta=5.593082 -> V=1.0, theta=0.0
% INFO    : Bus 77913	: V=0.9828758, theta=3.891585 -> V=1.0, theta=0.0
% INFO    : Bus 77914	: V=1.012504, theta=7.821059 -> V=1.0, theta=0.0
% INFO    : Bus 77915	: V=1.0029243, theta=23.129828 -> V=1.0, theta=0.0
% INFO    : Bus 77916	: V=1.0023001, theta=22.47447 -> V=1.0, theta=0.0
% INFO    : Bus 77917	: V=0.9820712, theta=20.984797 -> V=1.0, theta=0.0
% INFO    : Bus 77918	: V=0.9768251, theta=23.534035 -> V=1.0, theta=0.0
% INFO    : Bus 77919	: V=0.9847255, theta=21.5519 -> V=1.0, theta=0.0
% INFO    : Bus 77920	: V=0.9759738, theta=16.852178 -> V=1.0, theta=0.0
% INFO    : Bus 77921	: V=0.9744007, theta=20.529752 -> V=1.0, theta=0.0
% INFO    : Bus 77922	: V=0.9808983, theta=21.004579 -> V=1.0, theta=0.0
% INFO    : Bus 77923	: V=0.9740911, theta=20.142005 -> V=1.0, theta=0.0
% INFO    : Bus 77924	: V=1.004102, theta=19.99532 -> V=1.0, theta=0.0
% INFO    : Bus 77925	: V=0.9849703, theta=4.707895 -> V=1.0, theta=0.0
% INFO    : Bus 77926	: V=0.9656827, theta=-10.004884 -> V=1.0, theta=0.0
% INFO    : Bus 77927	: V=1.0031227, theta=9.945452 -> V=1.0, theta=0.0
% INFO    : Bus 77928	: V=0.9522938, theta=27.519725 -> V=1.0, theta=0.0
% INFO    : Bus 77929	: V=0.9777689, theta=-0.432304 -> V=1.0, theta=0.0
% INFO    : Bus 77930	: V=0.9740908, theta=-1.070855 -> V=1.0, theta=0.0
% INFO    : Bus 77931	: V=0.977557, theta=2.938764 -> V=1.0, theta=0.0
% INFO    : Bus 77932	: V=0.9757454, theta=2.261531 -> V=1.0, theta=0.0
% INFO    : Bus 77933	: V=0.9774391, theta=2.309168 -> V=1.0, theta=0.0
% INFO    : Bus 77934	: V=0.9797467, theta=2.42858 -> V=1.0, theta=0.0
% INFO    : Bus 77935	: V=0.9768758, theta=3.448573 -> V=1.0, theta=0.0
% INFO    : Bus 77936	: V=0.9757053, theta=3.866964 -> V=1.0, theta=0.0
% INFO    : Bus 77937	: V=0.9693039, theta=10.634441 -> V=1.0, theta=0.0
% INFO    : Bus 77938	: V=0.9763941, theta=4.109047 -> V=1.0, theta=0.0
% INFO    : Bus 77939	: V=0.9711868, theta=6.778039 -> V=1.0, theta=0.0
% INFO    : Bus 77940	: V=0.9622048, theta=18.721013 -> V=1.0, theta=0.0
% INFO    : Bus 77941	: V=1.0105106, theta=41.675306 -> V=1.0, theta=0.0
% INFO    : Bus 77942	: V=1.0202716, theta=45.240249 -> V=1.0, theta=0.0
% INFO    : Bus 77943	: V=1.0184063, theta=44.833003 -> V=1.0, theta=0.0
% INFO    : Bus 77944	: V=1.0152671, theta=43.327503 -> V=1.0, theta=0.0
% INFO    : Bus 77945	: V=1.0198681, theta=45.795872 -> V=1.0, theta=0.0
% INFO    : Bus 77946	: V=1.0190689, theta=45.257686 -> V=1.0, theta=0.0
% INFO    : Bus 77947	: V=1.0079293, theta=41.175089 -> V=1.0, theta=0.0
% INFO    : Bus 77948	: V=0.9990746, theta=39.766042 -> V=1.0, theta=0.0
% INFO    : Bus 77949	: V=0.9963932, theta=38.952095 -> V=1.0, theta=0.0
% INFO    : Bus 77950	: V=0.979616, theta=37.906316 -> V=1.0, theta=0.0
% INFO    : Bus 77951	: V=0.9981854, theta=39.231515 -> V=1.0, theta=0.0
% INFO    : Bus 77952	: V=0.9999337, theta=39.842769 -> V=1.0, theta=0.0
% INFO    : Bus 77953	: V=0.9878927, theta=36.757499 -> V=1.0, theta=0.0
% INFO    : Bus 77954	: V=1.0146566, theta=43.129958 -> V=1.0, theta=0.0
% INFO    : Bus 77955	: V=1.0109222, theta=8.26613 -> V=1.0, theta=0.0
% INFO    : Bus 77956	: V=0.9775922, theta=3.24997 -> V=1.0, theta=0.0
% INFO    : Bus 77957	: V=1.0034996, theta=8.534394 -> V=1.0, theta=0.0
% INFO    : Bus 77958	: V=0.9669015, theta=0.513566 -> V=1.0, theta=0.0
% INFO    : Bus 77959	: V=0.9677783, theta=0.548898 -> V=1.0, theta=0.0
% INFO    : Bus 77960	: V=0.9653905, theta=0.295043 -> V=1.0, theta=0.0
% INFO    : Bus 77961	: V=0.9675165, theta=0.431839 -> V=1.0, theta=0.0
% INFO    : Bus 77962	: V=0.9691084, theta=1.081885 -> V=1.0, theta=0.0
% INFO    : Bus 77963	: V=1.0174165, theta=7.724775 -> V=1.0, theta=0.0
% INFO    : Bus 77964	: V=1.007566, theta=8.926477 -> V=1.0, theta=0.0
% INFO    : Bus 77965	: V=1.0045662, theta=4.854861 -> V=1.0, theta=0.0
% INFO    : Bus 77966	: V=0.9850064, theta=6.848183 -> V=1.0, theta=0.0
% INFO    : Bus 77967	: V=0.9842409, theta=1.132982 -> V=1.0, theta=0.0
% INFO    : Bus 77968	: V=0.9891002, theta=0.880006 -> V=1.0, theta=0.0
% INFO    : Bus 77969	: V=0.9985607, theta=4.826262 -> V=1.0, theta=0.0
% INFO    : Bus 77970	: V=0.9970687, theta=4.376399 -> V=1.0, theta=0.0
% INFO    : Bus 77971	: V=0.9994706, theta=5.033157 -> V=1.0, theta=0.0
% INFO    : Bus 77972	: V=0.9987911, theta=4.91137 -> V=1.0, theta=0.0
% INFO    : Bus 77973	: V=0.9619629, theta=-1.830563 -> V=1.0, theta=0.0
% INFO    : Bus 77974	: V=0.9729995, theta=1.191737 -> V=1.0, theta=0.0
% INFO    : Bus 77975	: V=0.9645418, theta=-1.427476 -> V=1.0, theta=0.0
% INFO    : Bus 77976	: V=0.9542967, theta=-2.121852 -> V=1.0, theta=0.0
% INFO    : Bus 77977	: V=0.9537185, theta=-2.41074 -> V=1.0, theta=0.0
% INFO    : Bus 77978	: V=0.9579214, theta=-1.414573 -> V=1.0, theta=0.0
% INFO    : Bus 77979	: V=0.9608588, theta=0.100639 -> V=1.0, theta=0.0
% INFO    : Bus 77980	: V=0.9564705, theta=-1.255194 -> V=1.0, theta=0.0
% INFO    : Bus 77981	: V=1.0019426, theta=5.660904 -> V=1.0, theta=0.0
% INFO    : Bus 77982	: V=0.9984065, theta=5.26284 -> V=1.0, theta=0.0
% INFO    : Bus 77983	: V=0.9941618, theta=4.808261 -> V=1.0, theta=0.0
% INFO    : Bus 77984	: V=0.9916098, theta=4.558319 -> V=1.0, theta=0.0
% INFO    : Bus 77985	: V=0.9929891, theta=4.783371 -> V=1.0, theta=0.0
% INFO    : Bus 77986	: V=0.9928136, theta=4.907583 -> V=1.0, theta=0.0
% INFO    : Bus 77987	: V=0.9950863, theta=5.6063 -> V=1.0, theta=0.0
% INFO    : Bus 77988	: V=0.9950421, theta=5.416071 -> V=1.0, theta=0.0
% INFO    : Bus 77989	: V=0.9945092, theta=5.338455 -> V=1.0, theta=0.0
% INFO    : Bus 77990	: V=0.9953848, theta=5.738879 -> V=1.0, theta=0.0
% INFO    : Bus 77991	: V=0.9988169, theta=6.043514 -> V=1.0, theta=0.0
% INFO    : Bus 77992	: V=1.0037219, theta=7.691481 -> V=1.0, theta=0.0
% INFO    : Bus 77993	: V=1.0095189, theta=9.010258 -> V=1.0, theta=0.0
% INFO    : Bus 77994	: V=1.0103886, theta=9.080132 -> V=1.0, theta=0.0
% INFO    : Bus 77995	: V=1.0072571, theta=8.719215 -> V=1.0, theta=0.0
% INFO    : Bus 77996	: V=1.0223394, theta=11.147291 -> V=1.0, theta=0.0
% INFO    : Bus 77997	: V=1.0154518, theta=10.0571 -> V=1.0, theta=0.0
% INFO    : Bus 77998	: V=1.0074752, theta=7.821906 -> V=1.0, theta=0.0
% INFO    : Bus 77999	: V=1.0094422, theta=8.777788 -> V=1.0, theta=0.0
% INFO    : Bus 78000	: V=0.9953848, theta=24.181837 -> V=1.0, theta=0.0
% INFO    : Bus 78001	: V=0.9852913, theta=25.473566 -> V=1.0, theta=0.0
% INFO    : Bus 78002	: V=1.0147602, theta=28.778368 -> V=1.0, theta=0.0
% INFO    : Bus 78003	: V=1.023962, theta=35.629187 -> V=1.0, theta=0.0
% INFO    : Bus 78004	: V=1.0193738, theta=34.937478 -> V=1.0, theta=0.0
% INFO    : Bus 78005	: V=1.0011195, theta=21.126395 -> V=1.0, theta=0.0
% INFO    : Bus 78006	: V=0.9991958, theta=20.719053 -> V=1.0, theta=0.0
% INFO    : Bus 78007	: V=1.0106892, theta=20.694366 -> V=1.0, theta=0.0
% INFO    : Bus 78008	: V=0.9809515, theta=6.486695 -> V=1.0, theta=0.0
% INFO    : Bus 78009	: V=1.0068676, theta=9.315369 -> V=1.0, theta=0.0
% INFO    : Bus 78010	: V=1.0090852, theta=9.221838 -> V=1.0, theta=0.0
% INFO    : Bus 78011	: V=1.0071893, theta=9.205019 -> V=1.0, theta=0.0
% INFO    : Bus 78012	: V=1.0108224, theta=9.799107 -> V=1.0, theta=0.0
% INFO    : Bus 78013	: V=1.002884, theta=8.960219 -> V=1.0, theta=0.0
% INFO    : Bus 78014	: V=1.0042243, theta=9.128818 -> V=1.0, theta=0.0
% INFO    : Bus 78015	: V=1.0079591, theta=9.635338 -> V=1.0, theta=0.0
% INFO    : Bus 78016	: V=1.0016556, theta=8.98482 -> V=1.0, theta=0.0
% INFO    : Bus 78017	: V=0.993246, theta=8.924489 -> V=1.0, theta=0.0
% INFO    : Bus 78018	: V=0.9922024, theta=9.092977 -> V=1.0, theta=0.0
% INFO    : Bus 78019	: V=0.991141, theta=9.160868 -> V=1.0, theta=0.0
% INFO    : Bus 78020	: V=0.9939223, theta=9.662893 -> V=1.0, theta=0.0
% INFO    : Bus 78021	: V=0.9915374, theta=9.495781 -> V=1.0, theta=0.0
% INFO    : Bus 78022	: V=0.9967654, theta=9.062665 -> V=1.0, theta=0.0
% INFO    : Bus 78023	: V=0.9946956, theta=9.186661 -> V=1.0, theta=0.0
% INFO    : Bus 78024	: V=0.9932837, theta=9.08417 -> V=1.0, theta=0.0
% INFO    : Bus 78025	: V=0.9924515, theta=9.330646 -> V=1.0, theta=0.0
% INFO    : Bus 78026	: V=0.9918492, theta=9.214951 -> V=1.0, theta=0.0
% INFO    : Bus 78027	: V=0.9928617, theta=9.134752 -> V=1.0, theta=0.0
% INFO    : Bus 78028	: V=0.9907406, theta=9.186503 -> V=1.0, theta=0.0
% INFO    : Bus 78029	: V=0.9912201, theta=9.742961 -> V=1.0, theta=0.0
% INFO    : Bus 78030	: V=0.9922988, theta=10.16233 -> V=1.0, theta=0.0
% INFO    : Bus 78031	: V=0.9908117, theta=9.746185 -> V=1.0, theta=0.0
% INFO    : Bus 78032	: V=0.9909963, theta=10.062881 -> V=1.0, theta=0.0
% INFO    : Bus 78033	: V=0.9902579, theta=9.768074 -> V=1.0, theta=0.0
% INFO    : Bus 78034	: V=0.9900244, theta=9.81403 -> V=1.0, theta=0.0
% INFO    : Bus 78035	: V=0.9881424, theta=10.41381 -> V=1.0, theta=0.0
% INFO    : Bus 78036	: V=0.9918467, theta=10.885856 -> V=1.0, theta=0.0
% INFO    : Bus 78037	: V=0.9904431, theta=11.959713 -> V=1.0, theta=0.0
% INFO    : Bus 78038	: V=0.9899206, theta=10.541963 -> V=1.0, theta=0.0
% INFO    : Bus 78039	: V=0.9918415, theta=11.855887 -> V=1.0, theta=0.0
% INFO    : Bus 78040	: V=0.9980174, theta=9.802536 -> V=1.0, theta=0.0
% INFO    : Bus 78041	: V=0.9993501, theta=10.486758 -> V=1.0, theta=0.0
% INFO    : Bus 78042	: V=0.994756, theta=9.976345 -> V=1.0, theta=0.0
% INFO    : Bus 78043	: V=0.995844, theta=9.994414 -> V=1.0, theta=0.0
% INFO    : Bus 78044	: V=0.9891714, theta=11.018618 -> V=1.0, theta=0.0
% INFO    : Bus 78045	: V=0.9935989, theta=9.865655 -> V=1.0, theta=0.0
% INFO    : Bus 78046	: V=0.9971229, theta=9.952485 -> V=1.0, theta=0.0
% INFO    : Bus 78047	: V=0.9906153, theta=9.899358 -> V=1.0, theta=0.0
% INFO    : Bus 78048	: V=1.0012527, theta=9.319725 -> V=1.0, theta=0.0
% INFO    : Bus 78049	: V=0.9987096, theta=9.225759 -> V=1.0, theta=0.0
% INFO    : Bus 78050	: V=0.999587, theta=9.207401 -> V=1.0, theta=0.0
% INFO    : Bus 78051	: V=1.0046253, theta=9.864361 -> V=1.0, theta=0.0
% INFO    : Bus 78052	: V=1.0039426, theta=9.817882 -> V=1.0, theta=0.0
% INFO    : Bus 78053	: V=0.9973182, theta=9.305701 -> V=1.0, theta=0.0
% INFO    : Bus 78054	: V=0.9933616, theta=9.110676 -> V=1.0, theta=0.0
% INFO    : Bus 78055	: V=0.99913, theta=9.420281 -> V=1.0, theta=0.0
% INFO    : Bus 78056	: V=0.9985019, theta=9.46245 -> V=1.0, theta=0.0
% INFO    : Bus 78057	: V=0.99929, theta=9.620463 -> V=1.0, theta=0.0
% INFO    : Bus 78058	: V=1.0109232, theta=10.664535 -> V=1.0, theta=0.0
% INFO    : Bus 78059	: V=1.0022884, theta=9.752091 -> V=1.0, theta=0.0
% INFO    : Bus 78060	: V=1.0034824, theta=9.650367 -> V=1.0, theta=0.0
% INFO    : Bus 78061	: V=1.0097028, theta=10.587553 -> V=1.0, theta=0.0
% INFO    : Bus 78062	: V=1.0060059, theta=9.983485 -> V=1.0, theta=0.0
% INFO    : Bus 78063	: V=1.0021585, theta=8.996228 -> V=1.0, theta=0.0
% INFO    : Bus 78064	: V=0.9993471, theta=9.676605 -> V=1.0, theta=0.0
% INFO    : Bus 78065	: V=1.0047533, theta=9.185945 -> V=1.0, theta=0.0
% INFO    : Bus 78066	: V=0.9980942, theta=10.126864 -> V=1.0, theta=0.0
% INFO    : Bus 78067	: V=1.004323, theta=35.623539 -> V=1.0, theta=0.0
% INFO    : Bus 78068	: V=1.0167038, theta=39.908802 -> V=1.0, theta=0.0
% INFO    : Bus 78069	: V=1.0066547, theta=25.825887 -> V=1.0, theta=0.0
% INFO    : Bus 78070	: V=1.0184284, theta=29.568481 -> V=1.0, theta=0.0
% INFO    : Bus 78071	: V=1.0128102, theta=27.761084 -> V=1.0, theta=0.0
% INFO    : Bus 78072	: V=1.0076454, theta=27.354261 -> V=1.0, theta=0.0
% INFO    : Bus 78073	: V=0.9691603, theta=11.17221 -> V=1.0, theta=0.0
% INFO    : Bus 78074	: V=0.9810923, theta=9.82499 -> V=1.0, theta=0.0
% INFO    : Bus 78075	: V=0.9814293, theta=11.083484 -> V=1.0, theta=0.0
% INFO    : Bus 78076	: V=0.9784781, theta=11.358574 -> V=1.0, theta=0.0
% INFO    : Bus 78077	: V=1.0250772, theta=12.59628 -> V=1.0, theta=0.0
% INFO    : Bus 78078	: V=1.0213169, theta=11.437481 -> V=1.0, theta=0.0
% INFO    : Bus 78079	: V=1.007659, theta=10.05542 -> V=1.0, theta=0.0
% INFO    : Bus 78080	: V=1.0099619, theta=11.908662 -> V=1.0, theta=0.0
% INFO    : Bus 78081	: V=1.0182072, theta=11.668961 -> V=1.0, theta=0.0
% INFO    : Bus 78082	: V=1.0134954, theta=11.48195 -> V=1.0, theta=0.0
% INFO    : Bus 78083	: V=1.0131217, theta=11.279532 -> V=1.0, theta=0.0
% INFO    : Bus 78084	: V=1.0074626, theta=10.096698 -> V=1.0, theta=0.0
% INFO    : Bus 78085	: V=0.9795361, theta=27.55527 -> V=1.0, theta=0.0
% INFO    : Bus 78086	: V=0.9966914, theta=12.730479 -> V=1.0, theta=0.0
% INFO    : Bus 78087	: V=1.000853, theta=13.865015 -> V=1.0, theta=0.0
% INFO    : Bus 78088	: V=1.0002017, theta=13.479964 -> V=1.0, theta=0.0
% INFO    : Bus 78089	: V=0.9999117, theta=13.489625 -> V=1.0, theta=0.0
% INFO    : Bus 78090	: V=1.0036161, theta=14.488132 -> V=1.0, theta=0.0
% INFO    : Bus 78091	: V=1.0024656, theta=14.370181 -> V=1.0, theta=0.0
% INFO    : Bus 78092	: V=1.0030943, theta=15.957599 -> V=1.0, theta=0.0
% INFO    : Bus 78093	: V=1.0032529, theta=15.962601 -> V=1.0, theta=0.0
% INFO    : Bus 78094	: V=1.0032656, theta=16.01306 -> V=1.0, theta=0.0
% INFO    : Bus 78095	: V=1.0026138, theta=15.980402 -> V=1.0, theta=0.0
% INFO    : Bus 78096	: V=1.0053362, theta=16.14696 -> V=1.0, theta=0.0
% INFO    : Bus 78097	: V=1.0035666, theta=16.087847 -> V=1.0, theta=0.0
% INFO    : Bus 78098	: V=1.0067272, theta=16.646353 -> V=1.0, theta=0.0
% INFO    : Bus 78099	: V=1.0057314, theta=16.429889 -> V=1.0, theta=0.0
% INFO    : Bus 78100	: V=1.0061873, theta=16.802841 -> V=1.0, theta=0.0
% INFO    : Bus 78101	: V=1.0069195, theta=16.659368 -> V=1.0, theta=0.0
% INFO    : Bus 78102	: V=1.0066307, theta=16.454906 -> V=1.0, theta=0.0
% INFO    : Bus 78103	: V=1.0033558, theta=15.883967 -> V=1.0, theta=0.0
% INFO    : Bus 78104	: V=1.0078443, theta=16.598878 -> V=1.0, theta=0.0
% INFO    : Bus 78105	: V=1.0095527, theta=17.328797 -> V=1.0, theta=0.0
% INFO    : Bus 78106	: V=1.008337, theta=16.834747 -> V=1.0, theta=0.0
% INFO    : Bus 78107	: V=1.0102758, theta=17.60207 -> V=1.0, theta=0.0
% INFO    : Bus 78108	: V=1.0058041, theta=17.330137 -> V=1.0, theta=0.0
% INFO    : Bus 78109	: V=1.0020561, theta=17.372774 -> V=1.0, theta=0.0
% INFO    : Bus 78110	: V=1.0035549, theta=17.459382 -> V=1.0, theta=0.0
% INFO    : Bus 78111	: V=1.0043798, theta=17.53033 -> V=1.0, theta=0.0
% INFO    : Bus 78112	: V=1.0019162, theta=17.560638 -> V=1.0, theta=0.0
% INFO    : Bus 78113	: V=1.0041569, theta=17.824109 -> V=1.0, theta=0.0
% INFO    : Bus 78114	: V=1.0062701, theta=17.986935 -> V=1.0, theta=0.0
% INFO    : Bus 78115	: V=1.0069865, theta=18.06985 -> V=1.0, theta=0.0
% INFO    : Bus 78116	: V=0.9930933, theta=12.16827 -> V=1.0, theta=0.0
% INFO    : Bus 78117	: V=1.0002178, theta=13.670194 -> V=1.0, theta=0.0
% INFO    : Bus 78118	: V=0.9962404, theta=12.897263 -> V=1.0, theta=0.0
% INFO    : Bus 78119	: V=0.9956599, theta=12.490408 -> V=1.0, theta=0.0
% INFO    : Bus 78120	: V=1.000739, theta=13.762258 -> V=1.0, theta=0.0
% INFO    : Bus 78121	: V=0.995313, theta=12.383652 -> V=1.0, theta=0.0
% INFO    : Bus 78122	: V=0.9982378, theta=13.507819 -> V=1.0, theta=0.0
% INFO    : Bus 78123	: V=1.0043282, theta=17.780076 -> V=1.0, theta=0.0
% INFO    : Bus 78124	: V=1.0032969, theta=17.739115 -> V=1.0, theta=0.0
% INFO    : Bus 78125	: V=1.0083876, theta=18.214336 -> V=1.0, theta=0.0
% INFO    : Bus 78126	: V=1.0026569, theta=17.680645 -> V=1.0, theta=0.0
% INFO    : Bus 78127	: V=1.0098423, theta=18.406187 -> V=1.0, theta=0.0
% INFO    : Bus 78128	: V=1.0020296, theta=20.027208 -> V=1.0, theta=0.0
% INFO    : Bus 78129	: V=0.9887553, theta=12.765166 -> V=1.0, theta=0.0
% INFO    : Bus 78130	: V=0.9834142, theta=2.734499 -> V=1.0, theta=0.0
% INFO    : Bus 78131	: V=0.9862506, theta=3.704089 -> V=1.0, theta=0.0
% INFO    : Bus 78132	: V=0.9849069, theta=3.771323 -> V=1.0, theta=0.0
% INFO    : Bus 78133	: V=0.9839978, theta=2.962021 -> V=1.0, theta=0.0
% INFO    : Bus 78134	: V=0.9851639, theta=3.352578 -> V=1.0, theta=0.0
% INFO    : Bus 78135	: V=0.9844836, theta=2.665465 -> V=1.0, theta=0.0
% INFO    : Bus 78136	: V=0.9898447, theta=1.636769 -> V=1.0, theta=0.0
% INFO    : Bus 78137	: V=0.9902808, theta=1.123563 -> V=1.0, theta=0.0
% INFO    : Bus 78138	: V=0.9856295, theta=3.397932 -> V=1.0, theta=0.0
% INFO    : Bus 78139	: V=0.9923648, theta=4.016409 -> V=1.0, theta=0.0
% INFO    : Bus 78140	: V=0.9961756, theta=4.566075 -> V=1.0, theta=0.0
% INFO    : Bus 78141	: V=0.9950262, theta=4.320099 -> V=1.0, theta=0.0
% INFO    : Bus 78142	: V=0.9978492, theta=4.910562 -> V=1.0, theta=0.0
% INFO    : Bus 78143	: V=0.9975826, theta=4.889192 -> V=1.0, theta=0.0
% INFO    : Bus 78144	: V=1.0022913, theta=5.504611 -> V=1.0, theta=0.0
% INFO    : Bus 78145	: V=0.9996282, theta=4.990992 -> V=1.0, theta=0.0
% INFO    : Bus 78146	: V=1.002742, theta=5.47022 -> V=1.0, theta=0.0
% INFO    : Bus 78147	: V=0.9998009, theta=4.904638 -> V=1.0, theta=0.0
% INFO    : Bus 78148	: V=0.9956707, theta=4.784754 -> V=1.0, theta=0.0
% INFO    : Bus 78149	: V=0.9962997, theta=4.794521 -> V=1.0, theta=0.0
% INFO    : Bus 78150	: V=0.996896, theta=4.896596 -> V=1.0, theta=0.0
% INFO    : Bus 78151	: V=0.9938834, theta=4.907969 -> V=1.0, theta=0.0
% INFO    : Bus 78152	: V=1.0208296, theta=-77.115633 -> V=1.0, theta=0.0
% INFO    : Bus 78153	: V=1.0173798, theta=-78.981793 -> V=1.0, theta=0.0
% INFO    : Bus 78154	: V=1.0158806, theta=-79.516548 -> V=1.0, theta=0.0
% INFO    : Bus 78155	: V=1.0193774, theta=-64.586517 -> V=1.0, theta=0.0
% INFO    : Bus 78156	: V=1.0229229, theta=-64.962677 -> V=1.0, theta=0.0
% INFO    : Bus 78157	: V=1.016628, theta=-83.130702 -> V=1.0, theta=0.0
% INFO    : Bus 78158	: V=1.0092882, theta=-83.653345 -> V=1.0, theta=0.0
% INFO    : Bus 78159	: V=1.0046866, theta=-83.887299 -> V=1.0, theta=0.0
% INFO    : Bus 78160	: V=1.0072012, theta=-65.420948 -> V=1.0, theta=0.0
% INFO    : Bus 78161	: V=1.0139242, theta=-104.277729 -> V=1.0, theta=0.0
% INFO    : Bus 78162	: V=1.0197742, theta=-83.007411 -> V=1.0, theta=0.0
% INFO    : Bus 78163	: V=1.013566, theta=-82.548371 -> V=1.0, theta=0.0
% INFO    : Bus 78164	: V=1.0137592, theta=-82.664418 -> V=1.0, theta=0.0
% INFO    : Bus 78165	: V=1.012082, theta=-81.386863 -> V=1.0, theta=0.0
% INFO    : Bus 78166	: V=1.0104224, theta=-81.632241 -> V=1.0, theta=0.0
% INFO    : Bus 78167	: V=1.0061562, theta=-70.535029 -> V=1.0, theta=0.0
% INFO    : Bus 78168	: V=1.0171845, theta=-106.168565 -> V=1.0, theta=0.0
% INFO    : Bus 78169	: V=1.017599, theta=-106.511954 -> V=1.0, theta=0.0
% INFO    : Bus 78170	: V=1.0196237, theta=-103.73803 -> V=1.0, theta=0.0
% INFO    : Bus 78171	: V=1.0130281, theta=-104.546257 -> V=1.0, theta=0.0
% INFO    : Bus 78172	: V=1.0237276, theta=-72.333033 -> V=1.0, theta=0.0
% INFO    : Bus 78173	: V=1.0234112, theta=-72.626592 -> V=1.0, theta=0.0
% INFO    : Bus 78174	: V=1.0035749, theta=-105.582853 -> V=1.0, theta=0.0
% INFO    : Bus 78175	: V=1.0162343, theta=-103.15127 -> V=1.0, theta=0.0
% INFO    : Bus 78176	: V=1.0062911, theta=-104.99752 -> V=1.0, theta=0.0
% INFO    : Bus 78177	: V=1.00257, theta=-104.796901 -> V=1.0, theta=0.0
% INFO    : Bus 78178	: V=1.00393, theta=-74.673624 -> V=1.0, theta=0.0
% INFO    : Bus 78179	: V=1.0157291, theta=-92.555038 -> V=1.0, theta=0.0
% INFO    : Bus 78180	: V=1.0181127, theta=-92.61996 -> V=1.0, theta=0.0
% INFO    : Bus 78181	: V=1.0203321, theta=-103.688167 -> V=1.0, theta=0.0
% INFO    : Bus 78182	: V=1.0140145, theta=-104.304089 -> V=1.0, theta=0.0
% INFO    : Bus 78183	: V=1.0146725, theta=-104.430608 -> V=1.0, theta=0.0
% INFO    : Bus 78184	: V=1.0134288, theta=-104.444508 -> V=1.0, theta=0.0
% INFO    : Bus 78185	: V=1.0137145, theta=-104.394332 -> V=1.0, theta=0.0
% INFO    : Bus 78186	: V=1.0098817, theta=-109.030606 -> V=1.0, theta=0.0
% INFO    : Bus 78187	: V=1.015639, theta=-73.843864 -> V=1.0, theta=0.0
% INFO    : Bus 78188	: V=1.0134822, theta=-104.353031 -> V=1.0, theta=0.0
% INFO    : Bus 78189	: V=1.0132593, theta=-104.413874 -> V=1.0, theta=0.0
% INFO    : Bus 78190	: V=1.0152325, theta=-61.2681 -> V=1.0, theta=0.0
% INFO    : Bus 78191	: V=1.0156923, theta=-61.238454 -> V=1.0, theta=0.0
% INFO    : Bus 78192	: V=1.01448, theta=-83.101158 -> V=1.0, theta=0.0
% INFO    : Bus 78193	: V=1.0105368, theta=-74.840298 -> V=1.0, theta=0.0
% INFO    : Bus 78194	: V=1.0073672, theta=-75.899087 -> V=1.0, theta=0.0
% INFO    : Bus 78195	: V=1.0168922, theta=-82.955325 -> V=1.0, theta=0.0
% INFO    : Bus 78196	: V=1.0197599, theta=-83.058363 -> V=1.0, theta=0.0
% INFO    : Bus 78197	: V=1.0084567, theta=-22.446092 -> V=1.0, theta=0.0
% INFO    : Bus 78198	: V=1.0295712, theta=-83.855295 -> V=1.0, theta=0.0
% INFO    : Bus 78199	: V=1.0278491, theta=-84.050346 -> V=1.0, theta=0.0
% INFO    : Bus 78200	: V=1.0274006, theta=-84.355887 -> V=1.0, theta=0.0
% INFO    : Bus 78201	: V=1.0113082, theta=-62.235618 -> V=1.0, theta=0.0
% INFO    : Bus 78202	: V=1.0141764, theta=-61.885061 -> V=1.0, theta=0.0
% INFO    : Bus 78203	: V=1.0166344, theta=-97.514922 -> V=1.0, theta=0.0
% INFO    : Bus 78204	: V=1.0230035, theta=-76.811377 -> V=1.0, theta=0.0
% INFO    : Bus 78205	: V=1.0206922, theta=-76.845763 -> V=1.0, theta=0.0
% INFO    : Bus 78206	: V=1.0185617, theta=-76.821197 -> V=1.0, theta=0.0
% INFO    : Bus 78207	: V=1.0234034, theta=-73.285667 -> V=1.0, theta=0.0
% INFO    : Bus 78208	: V=1.0138673, theta=-61.797375 -> V=1.0, theta=0.0
% INFO    : Bus 78209	: V=1.0120064, theta=-61.948944 -> V=1.0, theta=0.0
% INFO    : Bus 78210	: V=1.015203, theta=-65.484348 -> V=1.0, theta=0.0
% INFO    : Bus 78211	: V=1.0087542, theta=-65.917876 -> V=1.0, theta=0.0
% INFO    : Bus 78212	: V=1.0064935, theta=-66.534931 -> V=1.0, theta=0.0
% INFO    : Bus 78213	: V=1.011586, theta=-80.832297 -> V=1.0, theta=0.0
% INFO    : Bus 78214	: V=1.0127637, theta=-80.599276 -> V=1.0, theta=0.0
% INFO    : Bus 78215	: V=1.0125826, theta=-88.944502 -> V=1.0, theta=0.0
% INFO    : Bus 78216	: V=1.0097212, theta=-75.088866 -> V=1.0, theta=0.0
% INFO    : Bus 78217	: V=1.0060638, theta=-76.306386 -> V=1.0, theta=0.0
% INFO    : Bus 78218	: V=1.0044624, theta=-76.423981 -> V=1.0, theta=0.0
% INFO    : Bus 78219	: V=1.0137278, theta=-72.492471 -> V=1.0, theta=0.0
% INFO    : Bus 78220	: V=1.0120538, theta=-72.329738 -> V=1.0, theta=0.0
% INFO    : Bus 78221	: V=1.0117341, theta=-72.38779 -> V=1.0, theta=0.0
% INFO    : Bus 78222	: V=1.0128058, theta=-86.089186 -> V=1.0, theta=0.0
% INFO    : Bus 78223	: V=1.0095911, theta=-83.867959 -> V=1.0, theta=0.0
% INFO    : Bus 78224	: V=1.0094951, theta=-83.927369 -> V=1.0, theta=0.0
% INFO    : Bus 78225	: V=1.0014215, theta=-66.164509 -> V=1.0, theta=0.0
% INFO    : Bus 78226	: V=1.0099357, theta=-89.642494 -> V=1.0, theta=0.0
% INFO    : Bus 78227	: V=1.0113324, theta=-89.974504 -> V=1.0, theta=0.0
% INFO    : Bus 78228	: V=1.0109313, theta=-94.946136 -> V=1.0, theta=0.0
% INFO    : Bus 78229	: V=1.0090114, theta=-95.161518 -> V=1.0, theta=0.0
% INFO    : Bus 78230	: V=1.0091365, theta=-100.690761 -> V=1.0, theta=0.0
% INFO    : Bus 78231	: V=1.0103461, theta=-79.107089 -> V=1.0, theta=0.0
% INFO    : Bus 78232	: V=1.0171184, theta=-83.658347 -> V=1.0, theta=0.0
% INFO    : Bus 78233	: V=1.0180911, theta=-83.269994 -> V=1.0, theta=0.0
% INFO    : Bus 78234	: V=1.0255363, theta=-61.393815 -> V=1.0, theta=0.0
% INFO    : Bus 78235	: V=1.0333561, theta=-90.161032 -> V=1.0, theta=0.0
% INFO    : Bus 78236	: V=1.0063865, theta=-78.40511 -> V=1.0, theta=0.0
% INFO    : Bus 78237	: V=1.0121147, theta=-68.1536 -> V=1.0, theta=0.0
% INFO    : Bus 78238	: V=1.0048843, theta=-84.982823 -> V=1.0, theta=0.0
% INFO    : Bus 78239	: V=1.0100214, theta=-105.490465 -> V=1.0, theta=0.0
% INFO    : Bus 78240	: V=1.007969, theta=-54.605589 -> V=1.0, theta=0.0
% INFO    : Bus 78241	: V=1.0072801, theta=-89.0033 -> V=1.0, theta=0.0
% INFO    : Bus 78242	: V=1.0002048, theta=-88.327775 -> V=1.0, theta=0.0
% INFO    : Bus 78243	: V=1.0109692, theta=-72.876622 -> V=1.0, theta=0.0
% INFO    : Bus 78244	: V=1.0108112, theta=-72.828429 -> V=1.0, theta=0.0
% INFO    : Bus 78245	: V=1.00991, theta=-30.247011 -> V=1.0, theta=0.0
% INFO    : Bus 78246	: V=1.0113351, theta=-86.225429 -> V=1.0, theta=0.0
% INFO    : Bus 78247	: V=1.0124373, theta=-86.123837 -> V=1.0, theta=0.0
% INFO    : Bus 78248	: V=1.0057628, theta=-78.689443 -> V=1.0, theta=0.0
% INFO    : Bus 78249	: V=1.0002523, theta=-79.734885 -> V=1.0, theta=0.0
% INFO    : Bus 78250	: V=1.0122127, theta=-55.843162 -> V=1.0, theta=0.0
% INFO    : Bus 78251	: V=1.0084637, theta=-107.108288 -> V=1.0, theta=0.0
% INFO    : Bus 78252	: V=1.0060508, theta=-67.880612 -> V=1.0, theta=0.0
% INFO    : Bus 78253	: V=1.0035033, theta=-79.172806 -> V=1.0, theta=0.0
% INFO    : Bus 78254	: V=1.0052793, theta=-86.018625 -> V=1.0, theta=0.0
% INFO    : Bus 78255	: V=1.0051531, theta=-86.082275 -> V=1.0, theta=0.0
% INFO    : Bus 78256	: V=1.0068036, theta=-92.48243 -> V=1.0, theta=0.0
% INFO    : Bus 78257	: V=1.0104944, theta=-71.850888 -> V=1.0, theta=0.0
% INFO    : Bus 78258	: V=1.0015293, theta=-98.723496 -> V=1.0, theta=0.0
% INFO    : Bus 78259	: V=1.0077249, theta=-67.311368 -> V=1.0, theta=0.0
% INFO    : Bus 78260	: V=1.0035423, theta=-83.155702 -> V=1.0, theta=0.0
% INFO    : Bus 78261	: V=1.0111414, theta=-75.154331 -> V=1.0, theta=0.0
% INFO    : Bus 78262	: V=1.0103575, theta=-75.282868 -> V=1.0, theta=0.0
% INFO    : Bus 78263	: V=1.0129259, theta=-110.089435 -> V=1.0, theta=0.0
% INFO    : Bus 78264	: V=1.009414, theta=-100.937518 -> V=1.0, theta=0.0
% INFO    : Bus 78265	: V=1.0116159, theta=-83.576491 -> V=1.0, theta=0.0
% INFO    : Bus 78266	: V=1.0053059, theta=-107.322716 -> V=1.0, theta=0.0
% INFO    : Bus 78267	: V=1.0088175, theta=-72.297588 -> V=1.0, theta=0.0
% INFO    : Bus 78268	: V=1.0167001, theta=-90.529005 -> V=1.0, theta=0.0
% INFO    : Bus 78269	: V=1.0083504, theta=-83.96448 -> V=1.0, theta=0.0
% INFO    : Bus 78270	: V=1.0106244, theta=-84.767495 -> V=1.0, theta=0.0
% INFO    : Bus 78271	: V=1.0034672, theta=-96.547447 -> V=1.0, theta=0.0
% INFO    : Bus 78272	: V=1.0125189, theta=-106.25415 -> V=1.0, theta=0.0
% INFO    : Bus 78273	: V=1.011055, theta=-83.004042 -> V=1.0, theta=0.0
% INFO    : Bus 78274	: V=0.9999731, theta=-105.173825 -> V=1.0, theta=0.0
% INFO    : Bus 78275	: V=0.9978788, theta=-91.638072 -> V=1.0, theta=0.0
% INFO    : Bus 78276	: V=0.9829961, theta=-33.329747 -> V=1.0, theta=0.0
% INFO    : Bus 78277	: V=0.9989686, theta=-31.382915 -> V=1.0, theta=0.0
% INFO    : Bus 78278	: V=1.0000004, theta=-89.763283 -> V=1.0, theta=0.0
% INFO    : Bus 78279	: V=1.0054011, theta=-81.847441 -> V=1.0, theta=0.0
% INFO    : Bus 78280	: V=1.0144456, theta=-67.862683 -> V=1.0, theta=0.0
% INFO    : Bus 78281	: V=1.0000003, theta=-69.181246 -> V=1.0, theta=0.0
% INFO    : Bus 78282	: V=1.0080371, theta=-61.999127 -> V=1.0, theta=0.0
% INFO    : Bus 78283	: V=1.0000001, theta=-27.228347 -> V=1.0, theta=0.0
% INFO    : Bus 78284	: V=1.0092468, theta=-76.95723 -> V=1.0, theta=0.0
% INFO    : Bus 78285	: V=1.0239375, theta=-79.439452 -> V=1.0, theta=0.0
% INFO    : Bus 78286	: V=1.0231186, theta=-79.395665 -> V=1.0, theta=0.0
% INFO    : Bus 78287	: V=1.0159442, theta=-44.794347 -> V=1.0, theta=0.0
% INFO    : Bus 78288	: V=1.004078, theta=-62.898692 -> V=1.0, theta=0.0
% INFO    : Bus 78289	: V=1.0074267, theta=-63.434529 -> V=1.0, theta=0.0
% INFO    : Bus 78290	: V=1.0121538, theta=-86.1644 -> V=1.0, theta=0.0
% INFO    : Bus 78291	: V=1.0111362, theta=-86.499446 -> V=1.0, theta=0.0
% INFO    : Bus 78292	: V=1.0111421, theta=-86.52281 -> V=1.0, theta=0.0
% INFO    : Bus 78293	: V=1.0099103, theta=-84.285507 -> V=1.0, theta=0.0
% INFO    : Bus 78294	: V=1.0077863, theta=-84.459436 -> V=1.0, theta=0.0
% INFO    : Bus 78295	: V=1.0107203, theta=-86.250309 -> V=1.0, theta=0.0
% INFO    : Bus 78296	: V=1.0089143, theta=-89.287037 -> V=1.0, theta=0.0
% INFO    : Bus 78297	: V=1.008293, theta=-89.458432 -> V=1.0, theta=0.0
% INFO    : Bus 78298	: V=1.0089185, theta=-88.731124 -> V=1.0, theta=0.0
% INFO    : Bus 78299	: V=1.0023298, theta=-88.842816 -> V=1.0, theta=0.0
% INFO    : Bus 78300	: V=1.0001909, theta=-105.688574 -> V=1.0, theta=0.0
% INFO    : Bus 78301	: V=1.0117064, theta=-104.43836 -> V=1.0, theta=0.0
% INFO    : Bus 78302	: V=1.0113882, theta=-104.938704 -> V=1.0, theta=0.0
% INFO    : Bus 78303	: V=1.0000002, theta=-62.283848 -> V=1.0, theta=0.0
% INFO    : Bus 78304	: V=1.0112737, theta=-67.634965 -> V=1.0, theta=0.0
% INFO    : Bus 78305	: V=1.008941, theta=-83.085178 -> V=1.0, theta=0.0
% INFO    : Bus 78306	: V=1.0267027, theta=-53.315164 -> V=1.0, theta=0.0
% INFO    : Bus 78307	: V=1.0000002, theta=-60.173649 -> V=1.0, theta=0.0
% INFO    : Bus 78308	: V=1.0147584, theta=-100.678069 -> V=1.0, theta=0.0
% INFO    : Bus 78309	: V=1.0000003, theta=-70.329544 -> V=1.0, theta=0.0
% INFO    : Bus 78310	: V=0.9935123, theta=-76.867233 -> V=1.0, theta=0.0
% INFO    : Bus 78311	: V=1.0000003, theta=-79.526387 -> V=1.0, theta=0.0
% INFO    : Bus 78312	: V=1.0002151, theta=-99.844688 -> V=1.0, theta=0.0
% INFO    : Bus 78313	: V=1.0066604, theta=-105.559502 -> V=1.0, theta=0.0
% INFO    : Bus 78314	: V=1.0010916, theta=-88.102604 -> V=1.0, theta=0.0
% INFO    : Bus 78315	: V=1.0048047, theta=-62.139601 -> V=1.0, theta=0.0
% INFO    : Bus 78316	: V=1.0035683, theta=-61.966483 -> V=1.0, theta=0.0
% INFO    : Bus 78317	: V=1.0066949, theta=-84.343139 -> V=1.0, theta=0.0
% INFO    : Bus 78318	: V=1.0102352, theta=-84.635913 -> V=1.0, theta=0.0
% INFO    : Bus 78319	: V=1.0089876, theta=-84.571748 -> V=1.0, theta=0.0
% INFO    : Bus 78320	: V=1.0016603, theta=-83.506871 -> V=1.0, theta=0.0
% INFO    : Bus 78321	: V=0.9968434, theta=-59.268848 -> V=1.0, theta=0.0
% INFO    : Bus 78322	: V=1.0000004, theta=-88.334809 -> V=1.0, theta=0.0
% INFO    : Bus 78323	: V=1.0140945, theta=-90.855071 -> V=1.0, theta=0.0
% INFO    : Bus 78324	: V=1.0122179, theta=-102.977102 -> V=1.0, theta=0.0
% INFO    : Bus 78325	: V=1.0098789, theta=-91.428129 -> V=1.0, theta=0.0
% INFO    : Bus 78326	: V=1.0047042, theta=-104.644011 -> V=1.0, theta=0.0
% INFO    : Bus 78327	: V=1.007188, theta=-104.901886 -> V=1.0, theta=0.0
% INFO    : Bus 78328	: V=1.0000004, theta=-85.110806 -> V=1.0, theta=0.0
% INFO    : Bus 78329	: V=0.9947684, theta=-90.545168 -> V=1.0, theta=0.0
% INFO    : Bus 78330	: V=1.0224603, theta=-73.899932 -> V=1.0, theta=0.0
% INFO    : Bus 78331	: V=0.990841, theta=-105.935468 -> V=1.0, theta=0.0
% INFO    : Bus 78332	: V=1.0189346, theta=-74.114738 -> V=1.0, theta=0.0
% INFO    : Bus 78333	: V=1.0067964, theta=-109.389415 -> V=1.0, theta=0.0
% INFO    : Bus 78334	: V=1.0068347, theta=-109.539467 -> V=1.0, theta=0.0
% INFO    : Bus 78335	: V=1.0092246, theta=-65.297114 -> V=1.0, theta=0.0
% INFO    : Bus 78336	: V=1.0049099, theta=-89.786425 -> V=1.0, theta=0.0
% INFO    : Bus 78337	: V=1.0069078, theta=-96.855418 -> V=1.0, theta=0.0
% INFO    : Bus 78338	: V=1.0100107, theta=-85.583266 -> V=1.0, theta=0.0
% INFO    : Bus 78339	: V=1.0187631, theta=-57.605861 -> V=1.0, theta=0.0
% INFO    : Bus 78340	: V=1.0075498, theta=-76.613074 -> V=1.0, theta=0.0
% INFO    : Bus 78341	: V=1.0144522, theta=-73.564793 -> V=1.0, theta=0.0
% INFO    : Bus 78342	: V=1.0153929, theta=-73.61153 -> V=1.0, theta=0.0
% INFO    : Bus 78343	: V=1.0044782, theta=-106.290631 -> V=1.0, theta=0.0
% INFO    : Bus 78344	: V=1.0155674, theta=-56.299905 -> V=1.0, theta=0.0
% INFO    : Bus 78345	: V=1.009727, theta=-73.21874 -> V=1.0, theta=0.0
% INFO    : Bus 78346	: V=1.0091445, theta=-84.828264 -> V=1.0, theta=0.0
% INFO    : Bus 78347	: V=1.0186384, theta=-73.564709 -> V=1.0, theta=0.0
% INFO    : Bus 78348	: V=0.9892462, theta=-85.961947 -> V=1.0, theta=0.0
% INFO    : Bus 78349	: V=1.0147411, theta=-84.391136 -> V=1.0, theta=0.0
% INFO    : Bus 78350	: V=1.0137788, theta=-84.548807 -> V=1.0, theta=0.0
% INFO    : Bus 78351	: V=0.981338, theta=-74.8727 -> V=1.0, theta=0.0
% INFO    : Bus 78352	: V=1.0128917, theta=-82.734884 -> V=1.0, theta=0.0
% INFO    : Bus 78353	: V=1.0081729, theta=-92.35902 -> V=1.0, theta=0.0
% INFO    : Bus 78354	: V=1.0000001, theta=-27.201485 -> V=1.0, theta=0.0
% INFO    : Bus 78355	: V=0.9998366, theta=-56.785031 -> V=1.0, theta=0.0
% INFO    : Bus 78356	: V=1.0109949, theta=-68.216733 -> V=1.0, theta=0.0
% INFO    : Bus 78357	: V=1.006759, theta=-101.083753 -> V=1.0, theta=0.0
% INFO    : Bus 78358	: V=1.0098514, theta=-85.075367 -> V=1.0, theta=0.0
% INFO    : Bus 78359	: V=1.0000001, theta=-20.085153 -> V=1.0, theta=0.0
% INFO    : Bus 78360	: V=1.0046796, theta=-63.676631 -> V=1.0, theta=0.0
% INFO    : Bus 78361	: V=1.0101386, theta=-80.859399 -> V=1.0, theta=0.0
% INFO    : Bus 78362	: V=1.0100314, theta=-81.164672 -> V=1.0, theta=0.0
% INFO    : Bus 78363	: V=1.0099527, theta=-66.230458 -> V=1.0, theta=0.0
% INFO    : Bus 78364	: V=1.0050305, theta=-96.509521 -> V=1.0, theta=0.0
% INFO    : Bus 78365	: V=0.9945872, theta=-110.057431 -> V=1.0, theta=0.0
% INFO    : Bus 78366	: V=1.0102946, theta=-68.077111 -> V=1.0, theta=0.0
% INFO    : Bus 78367	: V=1.0000003, theta=-83.680415 -> V=1.0, theta=0.0
% INFO    : Bus 78368	: V=0.9993099, theta=-78.7486 -> V=1.0, theta=0.0
% INFO    : Bus 78369	: V=1.0006549, theta=-27.23958 -> V=1.0, theta=0.0
% INFO    : Bus 78370	: V=1.0069214, theta=-81.671741 -> V=1.0, theta=0.0
% INFO    : Bus 78371	: V=1.0125666, theta=-77.216723 -> V=1.0, theta=0.0
% INFO    : Bus 78372	: V=0.9983704, theta=-18.15141 -> V=1.0, theta=0.0
% INFO    : Bus 78373	: V=1.0075825, theta=-54.262529 -> V=1.0, theta=0.0
% INFO    : Bus 78374	: V=1.0057577, theta=-69.068095 -> V=1.0, theta=0.0
% INFO    : Bus 78375	: V=1.0051353, theta=-83.115577 -> V=1.0, theta=0.0
% INFO    : Bus 78376	: V=0.9989228, theta=-63.750552 -> V=1.0, theta=0.0
% INFO    : Bus 78377	: V=1.0028467, theta=-110.557048 -> V=1.0, theta=0.0
% INFO    : Bus 78378	: V=1.0011917, theta=-81.263097 -> V=1.0, theta=0.0
% INFO    : Bus 78379	: V=1.011367, theta=-67.56291 -> V=1.0, theta=0.0
% INFO    : Bus 78380	: V=1.009461, theta=-67.584919 -> V=1.0, theta=0.0
% INFO    : Bus 78381	: V=1.0064212, theta=-80.371014 -> V=1.0, theta=0.0
% INFO    : Bus 78382	: V=1.0034717, theta=-78.97588 -> V=1.0, theta=0.0
% INFO    : Bus 78383	: V=1.002149, theta=-69.876819 -> V=1.0, theta=0.0
% INFO    : Bus 78384	: V=1.0231791, theta=-28.562136 -> V=1.0, theta=0.0
% INFO    : Bus 78385	: V=1.000591, theta=-74.157453 -> V=1.0, theta=0.0
% INFO    : Bus 78386	: V=1.0099079, theta=-103.624092 -> V=1.0, theta=0.0
% INFO    : Bus 78387	: V=1.0092783, theta=-76.948947 -> V=1.0, theta=0.0
% INFO    : Bus 78388	: V=1.018803, theta=-50.687726 -> V=1.0, theta=0.0
% INFO    : Bus 78389	: V=1.0023595, theta=-70.11336 -> V=1.0, theta=0.0
% INFO    : Bus 78390	: V=1.0247682, theta=-53.699481 -> V=1.0, theta=0.0
% INFO    : Bus 78391	: V=0.9897882, theta=-77.247065 -> V=1.0, theta=0.0
% INFO    : Bus 78392	: V=0.996338, theta=-23.02695 -> V=1.0, theta=0.0
% INFO    : Bus 78393	: V=1.0084994, theta=-109.27438 -> V=1.0, theta=0.0
% INFO    : Bus 78394	: V=1.0096079, theta=-109.269492 -> V=1.0, theta=0.0
% INFO    : Bus 78395	: V=1.0096084, theta=-109.273735 -> V=1.0, theta=0.0
% INFO    : Bus 78396	: V=1.0075061, theta=-110.303345 -> V=1.0, theta=0.0
% INFO    : Bus 78397	: V=1.0075805, theta=-110.506784 -> V=1.0, theta=0.0
% INFO    : Bus 78398	: V=1.0056567, theta=-110.562445 -> V=1.0, theta=0.0
% INFO    : Bus 78399	: V=1.0052941, theta=-110.402264 -> V=1.0, theta=0.0
% INFO    : Bus 78400	: V=1.0051981, theta=-110.463454 -> V=1.0, theta=0.0
% INFO    : Bus 78401	: V=1.0047934, theta=-110.623109 -> V=1.0, theta=0.0
% INFO    : Bus 78402	: V=1.0039313, theta=-110.704065 -> V=1.0, theta=0.0
% INFO    : Bus 78403	: V=1.0036805, theta=-110.723664 -> V=1.0, theta=0.0
% INFO    : Bus 78404	: V=1.0038879, theta=-110.50682 -> V=1.0, theta=0.0
% INFO    : Bus 78405	: V=1.0081124, theta=-110.168631 -> V=1.0, theta=0.0
% INFO    : Bus 78406	: V=1.0103598, theta=-108.633214 -> V=1.0, theta=0.0
% INFO    : Bus 78407	: V=1.010015, theta=-108.394466 -> V=1.0, theta=0.0
% INFO    : Bus 78408	: V=1.010629, theta=-108.737262 -> V=1.0, theta=0.0
% INFO    : Bus 78409	: V=1.0091933, theta=-109.299679 -> V=1.0, theta=0.0
% INFO    : Bus 78410	: V=1.0077934, theta=-110.08493 -> V=1.0, theta=0.0
% INFO    : Bus 78411	: V=1.0075836, theta=-110.39094 -> V=1.0, theta=0.0
% INFO    : Bus 78412	: V=1.0075233, theta=-110.242047 -> V=1.0, theta=0.0
% INFO    : Bus 78413	: V=1.0030317, theta=-110.866459 -> V=1.0, theta=0.0
% INFO    : Bus 78414	: V=1.0019631, theta=-110.937118 -> V=1.0, theta=0.0
% INFO    : Bus 78415	: V=1.0016173, theta=-111.100309 -> V=1.0, theta=0.0
% INFO    : Bus 78416	: V=1.0025809, theta=-110.923684 -> V=1.0, theta=0.0
% INFO    : Bus 78417	: V=1.0017947, theta=-111.059741 -> V=1.0, theta=0.0
% INFO    : Bus 78418	: V=1.0018244, theta=-111.040195 -> V=1.0, theta=0.0
% INFO    : Bus 78419	: V=1.0017163, theta=-111.166605 -> V=1.0, theta=0.0
% INFO    : Bus 78420	: V=1.0026808, theta=-110.877274 -> V=1.0, theta=0.0
% INFO    : Bus 78421	: V=1.0029036, theta=-110.9173 -> V=1.0, theta=0.0
% INFO    : Bus 78422	: V=1.0124246, theta=-108.588213 -> V=1.0, theta=0.0
% INFO    : Bus 78423	: V=1.0052716, theta=-109.841773 -> V=1.0, theta=0.0
% INFO    : Bus 78424	: V=1.0051539, theta=-110.32954 -> V=1.0, theta=0.0
% INFO    : Bus 78425	: V=1.0010143, theta=-110.676676 -> V=1.0, theta=0.0
% INFO    : Bus 78426	: V=1.0033443, theta=-110.849216 -> V=1.0, theta=0.0
% INFO    : Bus 78427	: V=1.0035249, theta=-110.1224 -> V=1.0, theta=0.0
% INFO    : Bus 78428	: V=0.9958513, theta=-110.479648 -> V=1.0, theta=0.0
% INFO    : Bus 78429	: V=1.001339, theta=-110.659836 -> V=1.0, theta=0.0
% INFO    : Bus 78430	: V=1.0009524, theta=-109.890144 -> V=1.0, theta=0.0
% INFO    : Bus 78431	: V=0.9960044, theta=-110.209713 -> V=1.0, theta=0.0
% INFO    : Bus 78432	: V=0.9974524, theta=-110.312243 -> V=1.0, theta=0.0
% INFO    : Bus 78433	: V=0.9981337, theta=-110.544139 -> V=1.0, theta=0.0
% INFO    : Bus 78434	: V=0.994954, theta=-110.259886 -> V=1.0, theta=0.0
% INFO    : Bus 78435	: V=0.992749, theta=-110.330626 -> V=1.0, theta=0.0
% INFO    : Bus 78436	: V=0.9952391, theta=-110.263835 -> V=1.0, theta=0.0
% INFO    : Bus 78437	: V=0.9996167, theta=-109.800675 -> V=1.0, theta=0.0
% INFO    : Bus 78438	: V=0.9813728, theta=-110.655546 -> V=1.0, theta=0.0
% INFO    : Bus 78439	: V=0.9972423, theta=-110.30217 -> V=1.0, theta=0.0
% INFO    : Bus 78440	: V=0.9947096, theta=-110.272495 -> V=1.0, theta=0.0
% INFO    : Bus 78441	: V=0.9922068, theta=-110.438079 -> V=1.0, theta=0.0
% INFO    : Bus 78442	: V=0.9874821, theta=-110.723028 -> V=1.0, theta=0.0
% INFO    : Bus 78443	: V=0.9935305, theta=-110.318258 -> V=1.0, theta=0.0
% INFO    : Bus 78444	: V=0.9959448, theta=-110.263405 -> V=1.0, theta=0.0
% INFO    : Bus 78445	: V=1.0019467, theta=-109.635678 -> V=1.0, theta=0.0
% INFO    : Bus 78446	: V=1.0000678, theta=-110.105422 -> V=1.0, theta=0.0
% INFO    : Bus 78447	: V=0.9966985, theta=-110.246979 -> V=1.0, theta=0.0
% INFO    : Bus 78448	: V=0.9903145, theta=-110.433202 -> V=1.0, theta=0.0
% INFO    : Bus 78449	: V=0.9903437, theta=-110.47164 -> V=1.0, theta=0.0
% INFO    : Bus 78450	: V=1.0013861, theta=-109.852535 -> V=1.0, theta=0.0
% INFO    : Bus 78451	: V=1.0021247, theta=-110.093214 -> V=1.0, theta=0.0
% INFO    : Bus 78452	: V=1.0041524, theta=-109.611042 -> V=1.0, theta=0.0
% INFO    : Bus 78453	: V=1.0052476, theta=-109.600605 -> V=1.0, theta=0.0
% INFO    : Bus 78454	: V=1.0027528, theta=-109.696524 -> V=1.0, theta=0.0
% INFO    : Bus 78455	: V=1.0041976, theta=-109.633888 -> V=1.0, theta=0.0
% INFO    : Bus 78456	: V=0.9883778, theta=-110.848096 -> V=1.0, theta=0.0
% INFO    : Bus 78457	: V=0.9830054, theta=-110.919378 -> V=1.0, theta=0.0
% INFO    : Bus 78458	: V=0.9827015, theta=-110.957831 -> V=1.0, theta=0.0
% INFO    : Bus 78459	: V=0.9999128, theta=-109.333155 -> V=1.0, theta=0.0
% INFO    : Bus 78460	: V=0.9994971, theta=-109.595126 -> V=1.0, theta=0.0
% INFO    : Bus 78461	: V=0.9983424, theta=-109.496585 -> V=1.0, theta=0.0
% INFO    : Bus 78462	: V=0.99948, theta=-109.325503 -> V=1.0, theta=0.0
% INFO    : Bus 78463	: V=1.0006723, theta=-109.230877 -> V=1.0, theta=0.0
% INFO    : Bus 78464	: V=1.0013578, theta=-108.929248 -> V=1.0, theta=0.0
% INFO    : Bus 78465	: V=1.0052954, theta=-107.55653 -> V=1.0, theta=0.0
% INFO    : Bus 78466	: V=1.0078513, theta=-107.629764 -> V=1.0, theta=0.0
% INFO    : Bus 78467	: V=1.0055766, theta=-109.628007 -> V=1.0, theta=0.0
% INFO    : Bus 78468	: V=0.9918922, theta=-82.833033 -> V=1.0, theta=0.0
% INFO    : Bus 78469	: V=1.0132063, theta=-85.90025 -> V=1.0, theta=0.0
% INFO    : Bus 78470	: V=1.0128006, theta=-85.385007 -> V=1.0, theta=0.0
% INFO    : Bus 78471	: V=1.0133833, theta=-85.830382 -> V=1.0, theta=0.0
% INFO    : Bus 78472	: V=1.0123338, theta=-83.424284 -> V=1.0, theta=0.0
% INFO    : Bus 78473	: V=1.0126508, theta=-84.311176 -> V=1.0, theta=0.0
% INFO    : Bus 78474	: V=1.012917, theta=-84.914359 -> V=1.0, theta=0.0
% INFO    : Bus 78475	: V=1.0112415, theta=-84.972499 -> V=1.0, theta=0.0
% INFO    : Bus 78476	: V=1.002937, theta=-96.733909 -> V=1.0, theta=0.0
% INFO    : Bus 78477	: V=0.9974826, theta=-106.053698 -> V=1.0, theta=0.0
% INFO    : Bus 78478	: V=1.0115797, theta=-104.471446 -> V=1.0, theta=0.0
% INFO    : Bus 78479	: V=1.0021302, theta=-105.193418 -> V=1.0, theta=0.0
% INFO    : Bus 78480	: V=1.0085863, theta=-104.821548 -> V=1.0, theta=0.0
% INFO    : Bus 78481	: V=1.0106687, theta=-104.538244 -> V=1.0, theta=0.0
% INFO    : Bus 78482	: V=1.0128124, theta=-104.566463 -> V=1.0, theta=0.0
% INFO    : Bus 78483	: V=1.0106235, theta=-105.002455 -> V=1.0, theta=0.0
% INFO    : Bus 78484	: V=1.0070338, theta=-105.04622 -> V=1.0, theta=0.0
% INFO    : Bus 78485	: V=1.0075807, theta=-105.228769 -> V=1.0, theta=0.0
% INFO    : Bus 78486	: V=1.0062949, theta=-105.818831 -> V=1.0, theta=0.0
% INFO    : Bus 78487	: V=1.0068092, theta=-105.288259 -> V=1.0, theta=0.0
% INFO    : Bus 78488	: V=1.002376, theta=-105.482998 -> V=1.0, theta=0.0
% INFO    : Bus 78489	: V=1.0014236, theta=-105.553868 -> V=1.0, theta=0.0
% INFO    : Bus 78490	: V=1.0162661, theta=-104.568049 -> V=1.0, theta=0.0
% INFO    : Bus 78491	: V=1.0100375, theta=-105.218865 -> V=1.0, theta=0.0
% INFO    : Bus 78492	: V=1.0051918, theta=-106.135164 -> V=1.0, theta=0.0
% INFO    : Bus 78493	: V=1.0050429, theta=-106.148462 -> V=1.0, theta=0.0
% INFO    : Bus 78494	: V=1.0046921, theta=-106.582145 -> V=1.0, theta=0.0
% INFO    : Bus 78495	: V=1.0017511, theta=-106.780921 -> V=1.0, theta=0.0
% INFO    : Bus 78496	: V=1.004639, theta=-107.06657 -> V=1.0, theta=0.0
% INFO    : Bus 78497	: V=0.9989672, theta=-107.172451 -> V=1.0, theta=0.0
% INFO    : Bus 78498	: V=1.0067896, theta=-105.762529 -> V=1.0, theta=0.0
% INFO    : Bus 78499	: V=1.0043927, theta=-105.966894 -> V=1.0, theta=0.0
% INFO    : Bus 78500	: V=0.9979703, theta=-106.903021 -> V=1.0, theta=0.0
% INFO    : Bus 78501	: V=0.9996763, theta=-106.625884 -> V=1.0, theta=0.0
% INFO    : Bus 78502	: V=0.9997893, theta=-106.806822 -> V=1.0, theta=0.0
% INFO    : Bus 78503	: V=1.0023759, theta=-108.528093 -> V=1.0, theta=0.0
% INFO    : Bus 78504	: V=0.9946603, theta=-107.326729 -> V=1.0, theta=0.0
% INFO    : Bus 78505	: V=0.9996225, theta=-108.773047 -> V=1.0, theta=0.0
% INFO    : Bus 78506	: V=1.000487, theta=-108.128139 -> V=1.0, theta=0.0
% INFO    : Bus 78507	: V=1.0003773, theta=-108.681166 -> V=1.0, theta=0.0
% INFO    : Bus 78508	: V=1.0042827, theta=-108.761935 -> V=1.0, theta=0.0
% INFO    : Bus 78509	: V=1.0053679, theta=-109.087946 -> V=1.0, theta=0.0
% INFO    : Bus 78510	: V=1.0065035, theta=-109.791228 -> V=1.0, theta=0.0
% INFO    : Bus 78511	: V=1.0057928, theta=-106.553141 -> V=1.0, theta=0.0
% INFO    : Bus 78512	: V=1.0033555, theta=-105.998185 -> V=1.0, theta=0.0
% INFO    : Bus 78513	: V=1.0153842, theta=-104.880832 -> V=1.0, theta=0.0
% INFO    : Bus 78514	: V=1.0138772, theta=-105.778423 -> V=1.0, theta=0.0
% INFO    : Bus 78515	: V=1.013736, theta=-106.000917 -> V=1.0, theta=0.0
% INFO    : Bus 78516	: V=1.0083057, theta=-108.113354 -> V=1.0, theta=0.0
% INFO    : Bus 78517	: V=1.009536, theta=-107.266317 -> V=1.0, theta=0.0
% INFO    : Bus 78518	: V=1.0104536, theta=-108.577742 -> V=1.0, theta=0.0
% INFO    : Bus 78519	: V=1.0065379, theta=-106.637331 -> V=1.0, theta=0.0
% INFO    : Bus 78520	: V=0.9919753, theta=-59.398924 -> V=1.0, theta=0.0
% INFO    : Bus 78521	: V=0.9874136, theta=-81.463459 -> V=1.0, theta=0.0
% INFO    : Bus 78522	: V=0.988204, theta=-82.463823 -> V=1.0, theta=0.0
% INFO    : Bus 78523	: V=1.0060041, theta=-95.061221 -> V=1.0, theta=0.0
% INFO    : Bus 78524	: V=1.0054037, theta=-93.341647 -> V=1.0, theta=0.0
% INFO    : Bus 78525	: V=1.0055196, theta=-93.988391 -> V=1.0, theta=0.0
% INFO    : Bus 78526	: V=1.0052593, theta=-93.86213 -> V=1.0, theta=0.0
% INFO    : Bus 78527	: V=1.006145, theta=-91.64905 -> V=1.0, theta=0.0
% INFO    : Bus 78528	: V=0.9945255, theta=-92.555025 -> V=1.0, theta=0.0
% INFO    : Bus 78529	: V=0.9935855, theta=-92.563803 -> V=1.0, theta=0.0
% INFO    : Bus 78530	: V=0.9980161, theta=-91.005496 -> V=1.0, theta=0.0
% INFO    : Bus 78531	: V=0.9975293, theta=-91.829259 -> V=1.0, theta=0.0
% INFO    : Bus 78532	: V=0.9975779, theta=-91.885301 -> V=1.0, theta=0.0
% INFO    : Bus 78533	: V=0.9999025, theta=-91.356659 -> V=1.0, theta=0.0
% INFO    : Bus 78534	: V=0.9895573, theta=-93.228507 -> V=1.0, theta=0.0
% INFO    : Bus 78535	: V=0.989703, theta=-93.207688 -> V=1.0, theta=0.0
% INFO    : Bus 78536	: V=0.9876326, theta=-93.596368 -> V=1.0, theta=0.0
% INFO    : Bus 78537	: V=0.9901012, theta=-93.205344 -> V=1.0, theta=0.0
% INFO    : Bus 78538	: V=0.9874135, theta=-91.061531 -> V=1.0, theta=0.0
% INFO    : Bus 78539	: V=0.9929648, theta=-92.544664 -> V=1.0, theta=0.0
% INFO    : Bus 78540	: V=0.9837458, theta=-91.365942 -> V=1.0, theta=0.0
% INFO    : Bus 78541	: V=0.9928023, theta=-92.905381 -> V=1.0, theta=0.0
% INFO    : Bus 78542	: V=0.9907306, theta=-93.119844 -> V=1.0, theta=0.0
% INFO    : Bus 78543	: V=0.9992377, theta=-90.824317 -> V=1.0, theta=0.0
% INFO    : Bus 78544	: V=0.991966, theta=-92.857796 -> V=1.0, theta=0.0
% INFO    : Bus 78545	: V=0.9890371, theta=-90.398416 -> V=1.0, theta=0.0
% INFO    : Bus 78546	: V=1.009195, theta=-86.500198 -> V=1.0, theta=0.0
% INFO    : Bus 78547	: V=0.9861844, theta=-90.755359 -> V=1.0, theta=0.0
% INFO    : Bus 78548	: V=0.9869936, theta=-90.900992 -> V=1.0, theta=0.0
% INFO    : Bus 78549	: V=0.9861198, theta=-90.28945 -> V=1.0, theta=0.0
% INFO    : Bus 78550	: V=0.9964102, theta=-87.847051 -> V=1.0, theta=0.0
% INFO    : Bus 78551	: V=0.9971181, theta=-89.89493 -> V=1.0, theta=0.0
% INFO    : Bus 78552	: V=0.9973005, theta=-95.527851 -> V=1.0, theta=0.0
% INFO    : Bus 78553	: V=1.0146033, theta=-84.55519 -> V=1.0, theta=0.0
% INFO    : Bus 78554	: V=1.0251034, theta=-83.621615 -> V=1.0, theta=0.0
% INFO    : Bus 78555	: V=1.007761, theta=-67.283355 -> V=1.0, theta=0.0
% INFO    : Bus 78556	: V=1.0085226, theta=-67.393542 -> V=1.0, theta=0.0
% INFO    : Bus 78557	: V=1.007271, theta=-70.315119 -> V=1.0, theta=0.0
% INFO    : Bus 78558	: V=1.0067097, theta=-69.532527 -> V=1.0, theta=0.0
% INFO    : Bus 78559	: V=1.0057545, theta=-67.026153 -> V=1.0, theta=0.0
% INFO    : Bus 78560	: V=1.0088546, theta=-68.2118 -> V=1.0, theta=0.0
% INFO    : Bus 78561	: V=1.0057568, theta=-75.18019 -> V=1.0, theta=0.0
% INFO    : Bus 78562	: V=1.0114159, theta=-30.202559 -> V=1.0, theta=0.0
% INFO    : Bus 78563	: V=1.0092346, theta=-30.815842 -> V=1.0, theta=0.0
% INFO    : Bus 78564	: V=0.9639863, theta=-68.134411 -> V=1.0, theta=0.0
% INFO    : Bus 78565	: V=0.9988713, theta=-75.720669 -> V=1.0, theta=0.0
% INFO    : Bus 78566	: V=0.9990086, theta=-75.989057 -> V=1.0, theta=0.0
% INFO    : Bus 78567	: V=1.0008506, theta=-76.325254 -> V=1.0, theta=0.0
% INFO    : Bus 78568	: V=0.9919821, theta=-76.527815 -> V=1.0, theta=0.0
% INFO    : Bus 78569	: V=0.9970727, theta=-75.94501 -> V=1.0, theta=0.0
% INFO    : Bus 78570	: V=1.0025255, theta=-75.958793 -> V=1.0, theta=0.0
% INFO    : Bus 78571	: V=0.9975949, theta=-76.128805 -> V=1.0, theta=0.0
% INFO    : Bus 78572	: V=0.9955417, theta=-76.215013 -> V=1.0, theta=0.0
% INFO    : Bus 78573	: V=0.988625, theta=-76.676462 -> V=1.0, theta=0.0
% INFO    : Bus 78574	: V=0.9896362, theta=-76.496632 -> V=1.0, theta=0.0
% INFO    : Bus 78575	: V=0.9877523, theta=-76.708023 -> V=1.0, theta=0.0
% INFO    : Bus 78576	: V=0.9835839, theta=-77.018674 -> V=1.0, theta=0.0
% INFO    : Bus 78577	: V=0.9866588, theta=-76.764931 -> V=1.0, theta=0.0
% INFO    : Bus 78578	: V=0.9839859, theta=-76.991499 -> V=1.0, theta=0.0
% INFO    : Bus 78579	: V=0.987344, theta=-76.744113 -> V=1.0, theta=0.0
% INFO    : Bus 78580	: V=0.9848396, theta=-76.905876 -> V=1.0, theta=0.0
% INFO    : Bus 78581	: V=0.9870034, theta=-76.837547 -> V=1.0, theta=0.0
% INFO    : Bus 78582	: V=0.9803377, theta=-77.198233 -> V=1.0, theta=0.0
% INFO    : Bus 78583	: V=1.0020717, theta=-77.738346 -> V=1.0, theta=0.0
% INFO    : Bus 78584	: V=1.0202909, theta=-73.42301 -> V=1.0, theta=0.0
% INFO    : Bus 78585	: V=1.0207274, theta=-73.520942 -> V=1.0, theta=0.0
% INFO    : Bus 78586	: V=0.9941061, theta=-76.775012 -> V=1.0, theta=0.0
% INFO    : Bus 78587	: V=0.9939735, theta=-78.084087 -> V=1.0, theta=0.0
% INFO    : Bus 78588	: V=0.9935692, theta=-78.270995 -> V=1.0, theta=0.0
% INFO    : Bus 78589	: V=0.990994, theta=-80.755466 -> V=1.0, theta=0.0
% INFO    : Bus 78590	: V=0.9947053, theta=-80.929938 -> V=1.0, theta=0.0
% INFO    : Bus 78591	: V=0.9981056, theta=-75.741388 -> V=1.0, theta=0.0
% INFO    : Bus 78592	: V=0.9978645, theta=-66.583695 -> V=1.0, theta=0.0
% INFO    : Bus 78593	: V=0.9641746, theta=-61.172022 -> V=1.0, theta=0.0
% INFO    : Bus 78594	: V=0.9670907, theta=-61.092833 -> V=1.0, theta=0.0
% INFO    : Bus 78595	: V=0.9823754, theta=-66.945954 -> V=1.0, theta=0.0
% INFO    : Bus 78596	: V=1.0006729, theta=-69.555279 -> V=1.0, theta=0.0
% INFO    : Bus 78597	: V=1.0000996, theta=-75.862771 -> V=1.0, theta=0.0
% INFO    : Bus 78598	: V=0.9969794, theta=-76.04472 -> V=1.0, theta=0.0
% INFO    : Bus 78599	: V=0.9803142, theta=-76.249409 -> V=1.0, theta=0.0
% INFO    : Bus 78600	: V=0.9930616, theta=-90.519833 -> V=1.0, theta=0.0
% INFO    : Bus 78601	: V=0.9777212, theta=-84.07858 -> V=1.0, theta=0.0
% INFO    : Bus 78602	: V=1.0049618, theta=-87.697034 -> V=1.0, theta=0.0
% INFO    : Bus 78603	: V=1.0079319, theta=-75.002753 -> V=1.0, theta=0.0
% INFO    : Bus 78604	: V=1.0042063, theta=-77.047175 -> V=1.0, theta=0.0
% INFO    : Bus 78605	: V=0.9999901, theta=-76.666085 -> V=1.0, theta=0.0
% INFO    : Bus 78606	: V=1.009548, theta=-83.763444 -> V=1.0, theta=0.0
% INFO    : Bus 78607	: V=1.0099188, theta=-83.812518 -> V=1.0, theta=0.0
% INFO    : Bus 78608	: V=1.0083352, theta=-82.921152 -> V=1.0, theta=0.0
% INFO    : Bus 78609	: V=1.0118311, theta=-83.317399 -> V=1.0, theta=0.0
% INFO    : Bus 78610	: V=1.0119321, theta=-83.453774 -> V=1.0, theta=0.0
% INFO    : Bus 78611	: V=1.0121825, theta=-83.442427 -> V=1.0, theta=0.0
% INFO    : Bus 78612	: V=1.0122233, theta=-83.535868 -> V=1.0, theta=0.0
% INFO    : Bus 78613	: V=1.0124621, theta=-83.473903 -> V=1.0, theta=0.0
% INFO    : Bus 78614	: V=1.0162606, theta=-82.995147 -> V=1.0, theta=0.0
% INFO    : Bus 78615	: V=1.0159598, theta=-83.429341 -> V=1.0, theta=0.0
% INFO    : Bus 78616	: V=1.0107424, theta=-83.213916 -> V=1.0, theta=0.0
% INFO    : Bus 78617	: V=1.0112205, theta=-83.151682 -> V=1.0, theta=0.0
% INFO    : Bus 78618	: V=1.0112837, theta=-83.101141 -> V=1.0, theta=0.0
% INFO    : Bus 78619	: V=1.0091772, theta=-82.81797 -> V=1.0, theta=0.0
% INFO    : Bus 78620	: V=1.0100036, theta=-83.143577 -> V=1.0, theta=0.0
% INFO    : Bus 78621	: V=1.0109999, theta=-83.17035 -> V=1.0, theta=0.0
% INFO    : Bus 78622	: V=1.0110648, theta=-83.527297 -> V=1.0, theta=0.0
% INFO    : Bus 78623	: V=1.0132094, theta=-82.739387 -> V=1.0, theta=0.0
% INFO    : Bus 78624	: V=1.0074868, theta=-83.570585 -> V=1.0, theta=0.0
% INFO    : Bus 78625	: V=1.0053863, theta=-84.126952 -> V=1.0, theta=0.0
% INFO    : Bus 78626	: V=1.0075773, theta=-83.605108 -> V=1.0, theta=0.0
% INFO    : Bus 78627	: V=1.0056825, theta=-83.734078 -> V=1.0, theta=0.0
% INFO    : Bus 78628	: V=1.0064835, theta=-83.704848 -> V=1.0, theta=0.0
% INFO    : Bus 78629	: V=1.0118008, theta=-83.827118 -> V=1.0, theta=0.0
% INFO    : Bus 78630	: V=1.0162506, theta=-83.005454 -> V=1.0, theta=0.0
% INFO    : Bus 78631	: V=1.0176745, theta=-83.357833 -> V=1.0, theta=0.0
% INFO    : Bus 78632	: V=1.015553, theta=-83.431189 -> V=1.0, theta=0.0
% INFO    : Bus 78633	: V=1.0112009, theta=-83.683965 -> V=1.0, theta=0.0
% INFO    : Bus 78634	: V=1.0107207, theta=-83.665345 -> V=1.0, theta=0.0
% INFO    : Bus 78635	: V=1.0102853, theta=-83.7002 -> V=1.0, theta=0.0
% INFO    : Bus 78636	: V=1.0097821, theta=-83.715617 -> V=1.0, theta=0.0
% INFO    : Bus 78637	: V=1.0103446, theta=-83.937042 -> V=1.0, theta=0.0
% INFO    : Bus 78638	: V=1.0085557, theta=-83.70401 -> V=1.0, theta=0.0
% INFO    : Bus 78639	: V=1.0102042, theta=-83.671358 -> V=1.0, theta=0.0
% INFO    : Bus 78640	: V=1.009445, theta=-83.641673 -> V=1.0, theta=0.0
% INFO    : Bus 78641	: V=1.0092466, theta=-83.639965 -> V=1.0, theta=0.0
% INFO    : Bus 78642	: V=1.0082972, theta=-83.876573 -> V=1.0, theta=0.0
% INFO    : Bus 78643	: V=1.0066351, theta=-83.841562 -> V=1.0, theta=0.0
% INFO    : Bus 78644	: V=1.0081739, theta=-83.686797 -> V=1.0, theta=0.0
% INFO    : Bus 78645	: V=1.009371, theta=-83.492635 -> V=1.0, theta=0.0
% INFO    : Bus 78646	: V=1.0094801, theta=-84.037072 -> V=1.0, theta=0.0
% INFO    : Bus 78647	: V=1.0127601, theta=-83.396091 -> V=1.0, theta=0.0
% INFO    : Bus 78648	: V=1.010906, theta=-83.929819 -> V=1.0, theta=0.0
% INFO    : Bus 78649	: V=1.0091587, theta=-83.967699 -> V=1.0, theta=0.0
% INFO    : Bus 78650	: V=1.0092118, theta=-84.034526 -> V=1.0, theta=0.0
% INFO    : Bus 78651	: V=1.0090541, theta=-83.476859 -> V=1.0, theta=0.0
% INFO    : Bus 78652	: V=1.0102657, theta=-83.741303 -> V=1.0, theta=0.0
% INFO    : Bus 78653	: V=1.0083748, theta=-83.833728 -> V=1.0, theta=0.0
% INFO    : Bus 78654	: V=1.005882, theta=-84.19328 -> V=1.0, theta=0.0
% INFO    : Bus 78655	: V=1.0060883, theta=-84.204926 -> V=1.0, theta=0.0
% INFO    : Bus 78656	: V=1.0057097, theta=-84.209065 -> V=1.0, theta=0.0
% INFO    : Bus 78657	: V=1.0064083, theta=-84.171066 -> V=1.0, theta=0.0
% INFO    : Bus 78658	: V=1.0047588, theta=-84.191537 -> V=1.0, theta=0.0
% INFO    : Bus 78659	: V=1.0046855, theta=-84.129022 -> V=1.0, theta=0.0
% INFO    : Bus 78660	: V=1.0049508, theta=-84.134713 -> V=1.0, theta=0.0
% INFO    : Bus 78661	: V=1.0040024, theta=-84.058661 -> V=1.0, theta=0.0
% INFO    : Bus 78662	: V=1.0047942, theta=-84.16164 -> V=1.0, theta=0.0
% INFO    : Bus 78663	: V=1.0037288, theta=-84.204483 -> V=1.0, theta=0.0
% INFO    : Bus 78664	: V=1.0038179, theta=-84.189216 -> V=1.0, theta=0.0
% INFO    : Bus 78665	: V=1.0025073, theta=-84.266146 -> V=1.0, theta=0.0
% INFO    : Bus 78666	: V=1.0021388, theta=-84.289057 -> V=1.0, theta=0.0
% INFO    : Bus 78667	: V=1.0039039, theta=-84.198151 -> V=1.0, theta=0.0
% INFO    : Bus 78668	: V=1.0029362, theta=-84.233331 -> V=1.0, theta=0.0
% INFO    : Bus 78669	: V=1.0059269, theta=-84.170271 -> V=1.0, theta=0.0
% INFO    : Bus 78670	: V=1.0053009, theta=-84.146249 -> V=1.0, theta=0.0
% INFO    : Bus 78671	: V=1.0056745, theta=-83.970609 -> V=1.0, theta=0.0
% INFO    : Bus 78672	: V=1.0031204, theta=-83.956026 -> V=1.0, theta=0.0
% INFO    : Bus 78673	: V=1.0064393, theta=-83.838986 -> V=1.0, theta=0.0
% INFO    : Bus 78674	: V=1.0065118, theta=-83.856251 -> V=1.0, theta=0.0
% INFO    : Bus 78675	: V=1.0068198, theta=-83.874973 -> V=1.0, theta=0.0
% INFO    : Bus 78676	: V=1.0066568, theta=-83.853969 -> V=1.0, theta=0.0
% INFO    : Bus 78677	: V=1.0051208, theta=-83.993165 -> V=1.0, theta=0.0
% INFO    : Bus 78678	: V=1.0076757, theta=-83.566036 -> V=1.0, theta=0.0
% INFO    : Bus 78679	: V=1.0069526, theta=-83.782009 -> V=1.0, theta=0.0
% INFO    : Bus 78680	: V=1.005943, theta=-83.846204 -> V=1.0, theta=0.0
% INFO    : Bus 78681	: V=1.004182, theta=-83.617334 -> V=1.0, theta=0.0
% INFO    : Bus 78682	: V=1.0062618, theta=-83.608169 -> V=1.0, theta=0.0
% INFO    : Bus 78683	: V=1.005601, theta=-83.605385 -> V=1.0, theta=0.0
% INFO    : Bus 78684	: V=1.0059618, theta=-83.633413 -> V=1.0, theta=0.0
% INFO    : Bus 78685	: V=1.004183, theta=-83.772541 -> V=1.0, theta=0.0
% INFO    : Bus 78686	: V=1.0003006, theta=-83.916819 -> V=1.0, theta=0.0
% INFO    : Bus 78687	: V=1.0038074, theta=-83.810481 -> V=1.0, theta=0.0
% INFO    : Bus 78688	: V=1.0026054, theta=-83.853686 -> V=1.0, theta=0.0
% INFO    : Bus 78689	: V=1.0035667, theta=-83.833005 -> V=1.0, theta=0.0
% INFO    : Bus 78690	: V=1.0032644, theta=-83.816988 -> V=1.0, theta=0.0
% INFO    : Bus 78691	: V=1.0032219, theta=-83.825017 -> V=1.0, theta=0.0
% INFO    : Bus 78692	: V=1.0031115, theta=-83.710335 -> V=1.0, theta=0.0
% INFO    : Bus 78693	: V=1.0029045, theta=-83.770514 -> V=1.0, theta=0.0
% INFO    : Bus 78694	: V=1.0042955, theta=-83.85052 -> V=1.0, theta=0.0
% INFO    : Bus 78695	: V=1.0118727, theta=-80.221859 -> V=1.0, theta=0.0
% INFO    : Bus 78696	: V=1.0081005, theta=-81.822561 -> V=1.0, theta=0.0
% INFO    : Bus 78697	: V=1.0058327, theta=-81.964419 -> V=1.0, theta=0.0
% INFO    : Bus 78698	: V=1.005909, theta=-82.43302 -> V=1.0, theta=0.0
% INFO    : Bus 78699	: V=1.0030347, theta=-83.387847 -> V=1.0, theta=0.0
% INFO    : Bus 78700	: V=1.0034246, theta=-83.467661 -> V=1.0, theta=0.0
% INFO    : Bus 78701	: V=1.002587, theta=-83.634328 -> V=1.0, theta=0.0
% INFO    : Bus 78702	: V=1.0024701, theta=-83.615136 -> V=1.0, theta=0.0
% INFO    : Bus 78703	: V=1.0028936, theta=-83.575096 -> V=1.0, theta=0.0
% INFO    : Bus 78704	: V=1.0033431, theta=-83.53279 -> V=1.0, theta=0.0
% INFO    : Bus 78705	: V=1.0029794, theta=-83.492584 -> V=1.0, theta=0.0
% INFO    : Bus 78706	: V=1.0033445, theta=-83.534967 -> V=1.0, theta=0.0
% INFO    : Bus 78707	: V=1.0024787, theta=-83.686629 -> V=1.0, theta=0.0
% INFO    : Bus 78708	: V=1.0024388, theta=-83.69875 -> V=1.0, theta=0.0
% INFO    : Bus 78709	: V=1.0025466, theta=-83.637078 -> V=1.0, theta=0.0
% INFO    : Bus 78710	: V=1.0025385, theta=-83.64899 -> V=1.0, theta=0.0
% INFO    : Bus 78711	: V=1.0016254, theta=-83.752356 -> V=1.0, theta=0.0
% INFO    : Bus 78712	: V=1.002421, theta=-83.632168 -> V=1.0, theta=0.0
% INFO    : Bus 78713	: V=1.001665, theta=-83.67279 -> V=1.0, theta=0.0
% INFO    : Bus 78714	: V=1.0027925, theta=-83.504378 -> V=1.0, theta=0.0
% INFO    : Bus 78715	: V=1.0033209, theta=-83.452755 -> V=1.0, theta=0.0
% INFO    : Bus 78716	: V=1.0028166, theta=-83.457314 -> V=1.0, theta=0.0
% INFO    : Bus 78717	: V=1.002348, theta=-83.571911 -> V=1.0, theta=0.0
% INFO    : Bus 78718	: V=1.0031363, theta=-83.301754 -> V=1.0, theta=0.0
% INFO    : Bus 78719	: V=1.0031552, theta=-83.185699 -> V=1.0, theta=0.0
% INFO    : Bus 78720	: V=1.0028049, theta=-83.260703 -> V=1.0, theta=0.0
% INFO    : Bus 78721	: V=1.0027062, theta=-83.417415 -> V=1.0, theta=0.0
% INFO    : Bus 78722	: V=1.0024667, theta=-83.557824 -> V=1.0, theta=0.0
% INFO    : Bus 78723	: V=1.003152, theta=-83.419329 -> V=1.0, theta=0.0
% INFO    : Bus 78724	: V=1.0030059, theta=-83.388525 -> V=1.0, theta=0.0
% INFO    : Bus 78725	: V=1.003114, theta=-83.256731 -> V=1.0, theta=0.0
% INFO    : Bus 78726	: V=1.0033339, theta=-83.149604 -> V=1.0, theta=0.0
% INFO    : Bus 78727	: V=1.0033138, theta=-83.219582 -> V=1.0, theta=0.0
% INFO    : Bus 78728	: V=1.0038492, theta=-82.921572 -> V=1.0, theta=0.0
% INFO    : Bus 78729	: V=1.0036895, theta=-82.951895 -> V=1.0, theta=0.0
% INFO    : Bus 78730	: V=1.0054953, theta=-82.293986 -> V=1.0, theta=0.0
% INFO    : Bus 78731	: V=1.0034642, theta=-82.564388 -> V=1.0, theta=0.0
% INFO    : Bus 78732	: V=1.0050344, theta=-82.464346 -> V=1.0, theta=0.0
% INFO    : Bus 78733	: V=1.0032773, theta=-83.107176 -> V=1.0, theta=0.0
% INFO    : Bus 78734	: V=1.003354, theta=-82.950406 -> V=1.0, theta=0.0
% INFO    : Bus 78735	: V=1.0031973, theta=-82.700851 -> V=1.0, theta=0.0
% INFO    : Bus 78736	: V=1.0027424, theta=-82.898057 -> V=1.0, theta=0.0
% INFO    : Bus 78737	: V=1.0030444, theta=-83.118658 -> V=1.0, theta=0.0
% INFO    : Bus 78738	: V=1.0025799, theta=-83.037168 -> V=1.0, theta=0.0
% INFO    : Bus 78739	: V=1.0030607, theta=-82.90879 -> V=1.0, theta=0.0
% INFO    : Bus 78740	: V=1.0034473, theta=-82.888238 -> V=1.0, theta=0.0
% INFO    : Bus 78741	: V=1.002578, theta=-83.232261 -> V=1.0, theta=0.0
% INFO    : Bus 78742	: V=1.0019903, theta=-83.26592 -> V=1.0, theta=0.0
% INFO    : Bus 78743	: V=1.0024537, theta=-83.088689 -> V=1.0, theta=0.0
% INFO    : Bus 78744	: V=1.0034508, theta=-82.62125 -> V=1.0, theta=0.0
% INFO    : Bus 78745	: V=1.0032638, theta=-82.741577 -> V=1.0, theta=0.0
% INFO    : Bus 78746	: V=1.0035884, theta=-82.776594 -> V=1.0, theta=0.0
% INFO    : Bus 78747	: V=1.0017218, theta=-82.566642 -> V=1.0, theta=0.0
% INFO    : Bus 78748	: V=1.0013687, theta=-82.554645 -> V=1.0, theta=0.0
% INFO    : Bus 78749	: V=1.0035216, theta=-82.500448 -> V=1.0, theta=0.0
% INFO    : Bus 78750	: V=1.0017276, theta=-82.556502 -> V=1.0, theta=0.0
% INFO    : Bus 78751	: V=1.0021244, theta=-82.511201 -> V=1.0, theta=0.0
% INFO    : Bus 78752	: V=1.0035081, theta=-82.602818 -> V=1.0, theta=0.0
% INFO    : Bus 78753	: V=1.003306, theta=-82.486615 -> V=1.0, theta=0.0
% INFO    : Bus 78754	: V=1.0032267, theta=-82.29966 -> V=1.0, theta=0.0
% INFO    : Bus 78755	: V=1.001616, theta=-82.270155 -> V=1.0, theta=0.0
% INFO    : Bus 78756	: V=1.0013381, theta=-82.162566 -> V=1.0, theta=0.0
% INFO    : Bus 78757	: V=1.0007055, theta=-82.134205 -> V=1.0, theta=0.0
% INFO    : Bus 78758	: V=1.0014707, theta=-82.146292 -> V=1.0, theta=0.0
% INFO    : Bus 78759	: V=0.9993679, theta=-81.811606 -> V=1.0, theta=0.0
% INFO    : Bus 78760	: V=0.9965313, theta=-81.624695 -> V=1.0, theta=0.0
% INFO    : Bus 78761	: V=0.9999049, theta=-81.905891 -> V=1.0, theta=0.0
% INFO    : Bus 78762	: V=1.0002165, theta=-82.096438 -> V=1.0, theta=0.0
% INFO    : Bus 78763	: V=1.0010944, theta=-81.871933 -> V=1.0, theta=0.0
% INFO    : Bus 78764	: V=1.0013417, theta=-81.969606 -> V=1.0, theta=0.0
% INFO    : Bus 78765	: V=1.0055141, theta=-83.820895 -> V=1.0, theta=0.0
% INFO    : Bus 78766	: V=1.0019491, theta=-83.647256 -> V=1.0, theta=0.0
% INFO    : Bus 78767	: V=1.0032822, theta=-83.726036 -> V=1.0, theta=0.0
% INFO    : Bus 78768	: V=1.004419, theta=-83.561753 -> V=1.0, theta=0.0
% INFO    : Bus 78769	: V=1.0050484, theta=-83.306421 -> V=1.0, theta=0.0
% INFO    : Bus 78770	: V=1.0034428, theta=-83.371917 -> V=1.0, theta=0.0
% INFO    : Bus 78771	: V=1.0068694, theta=-82.983016 -> V=1.0, theta=0.0
% INFO    : Bus 78772	: V=1.0058927, theta=-83.209572 -> V=1.0, theta=0.0
% INFO    : Bus 78773	: V=1.0020251, theta=-83.687125 -> V=1.0, theta=0.0
% INFO    : Bus 78774	: V=1.0022895, theta=-83.685999 -> V=1.0, theta=0.0
% INFO    : Bus 78775	: V=1.0022587, theta=-83.686467 -> V=1.0, theta=0.0
% INFO    : Bus 78776	: V=1.0018679, theta=-83.623928 -> V=1.0, theta=0.0
% INFO    : Bus 78777	: V=1.0015387, theta=-83.63188 -> V=1.0, theta=0.0
% INFO    : Bus 78778	: V=1.003453, theta=-83.591232 -> V=1.0, theta=0.0
% INFO    : Bus 78779	: V=1.0023401, theta=-83.631394 -> V=1.0, theta=0.0
% INFO    : Bus 78780	: V=1.0025582, theta=-83.595292 -> V=1.0, theta=0.0
% INFO    : Bus 78781	: V=1.0037779, theta=-83.537336 -> V=1.0, theta=0.0
% INFO    : Bus 78782	: V=1.0042176, theta=-83.44115 -> V=1.0, theta=0.0
% INFO    : Bus 78783	: V=1.0030354, theta=-83.528117 -> V=1.0, theta=0.0
% INFO    : Bus 78784	: V=1.0038904, theta=-83.517135 -> V=1.0, theta=0.0
% INFO    : Bus 78785	: V=1.0039338, theta=-83.284311 -> V=1.0, theta=0.0
% INFO    : Bus 78786	: V=1.0046948, theta=-82.970907 -> V=1.0, theta=0.0
% INFO    : Bus 78787	: V=1.0075751, theta=-82.398481 -> V=1.0, theta=0.0
% INFO    : Bus 78788	: V=1.0039727, theta=-83.05336 -> V=1.0, theta=0.0
% INFO    : Bus 78789	: V=1.0041444, theta=-82.947677 -> V=1.0, theta=0.0
% INFO    : Bus 78790	: V=1.0044527, theta=-83.024482 -> V=1.0, theta=0.0
% INFO    : Bus 78791	: V=1.0068902, theta=-82.542077 -> V=1.0, theta=0.0
% INFO    : Bus 78792	: V=1.0064628, theta=-82.631955 -> V=1.0, theta=0.0
% INFO    : Bus 78793	: V=1.0061316, theta=-82.475496 -> V=1.0, theta=0.0
% INFO    : Bus 78794	: V=1.0082432, theta=-82.188493 -> V=1.0, theta=0.0
% INFO    : Bus 78795	: V=1.0086641, theta=-82.203975 -> V=1.0, theta=0.0
% INFO    : Bus 78796	: V=1.0042031, theta=-82.717621 -> V=1.0, theta=0.0
% INFO    : Bus 78797	: V=1.0080496, theta=-82.211097 -> V=1.0, theta=0.0
% INFO    : Bus 78798	: V=0.9968413, theta=-81.658693 -> V=1.0, theta=0.0
% INFO    : Bus 78799	: V=0.9869605, theta=-81.14172 -> V=1.0, theta=0.0
% INFO    : Bus 78800	: V=1.0077846, theta=-83.823745 -> V=1.0, theta=0.0
% INFO    : Bus 78801	: V=1.0101144, theta=-83.208138 -> V=1.0, theta=0.0
% INFO    : Bus 78802	: V=1.0077893, theta=-83.520701 -> V=1.0, theta=0.0
% INFO    : Bus 78803	: V=1.0072602, theta=-83.558732 -> V=1.0, theta=0.0
% INFO    : Bus 78804	: V=1.0072872, theta=-83.589164 -> V=1.0, theta=0.0
% INFO    : Bus 78805	: V=1.0059906, theta=-83.63898 -> V=1.0, theta=0.0
% INFO    : Bus 78806	: V=1.0068338, theta=-83.624018 -> V=1.0, theta=0.0
% INFO    : Bus 78807	: V=1.0065883, theta=-83.662208 -> V=1.0, theta=0.0
% INFO    : Bus 78808	: V=1.0064172, theta=-83.628915 -> V=1.0, theta=0.0
% INFO    : Bus 78809	: V=1.0101319, theta=-83.423529 -> V=1.0, theta=0.0
% INFO    : Bus 78810	: V=1.0113537, theta=-83.446344 -> V=1.0, theta=0.0
% INFO    : Bus 78811	: V=1.0111874, theta=-83.463593 -> V=1.0, theta=0.0
% INFO    : Bus 78812	: V=1.014571, theta=-83.127888 -> V=1.0, theta=0.0
% INFO    : Bus 78813	: V=1.0098188, theta=-83.128213 -> V=1.0, theta=0.0
% INFO    : Bus 78814	: V=1.0092864, theta=-83.355622 -> V=1.0, theta=0.0
% INFO    : Bus 78815	: V=1.0079522, theta=-83.461421 -> V=1.0, theta=0.0
% INFO    : Bus 78816	: V=1.0050565, theta=-83.814084 -> V=1.0, theta=0.0
% INFO    : Bus 78817	: V=1.011199, theta=-83.300498 -> V=1.0, theta=0.0
% INFO    : Bus 78818	: V=1.0100649, theta=-83.473672 -> V=1.0, theta=0.0
% INFO    : Bus 78819	: V=0.9919128, theta=-79.569307 -> V=1.0, theta=0.0
% INFO    : Bus 78820	: V=0.9917916, theta=-76.55226 -> V=1.0, theta=0.0
% INFO    : Bus 78821	: V=0.993413, theta=-76.91885 -> V=1.0, theta=0.0
% INFO    : Bus 78822	: V=0.9934549, theta=-77.71032 -> V=1.0, theta=0.0
% INFO    : Bus 78823	: V=0.993867, theta=-76.81473 -> V=1.0, theta=0.0
% INFO    : Bus 78824	: V=0.9946212, theta=-76.81557 -> V=1.0, theta=0.0
% INFO    : Bus 78825	: V=0.9932526, theta=-77.919819 -> V=1.0, theta=0.0
% INFO    : Bus 78826	: V=0.9946283, theta=-78.013427 -> V=1.0, theta=0.0
% INFO    : Bus 78827	: V=0.9908891, theta=-79.678258 -> V=1.0, theta=0.0
% INFO    : Bus 78828	: V=0.9966229, theta=-79.794731 -> V=1.0, theta=0.0
% INFO    : Bus 78829	: V=0.9944384, theta=-81.194161 -> V=1.0, theta=0.0
% INFO    : Bus 78830	: V=0.9973162, theta=-80.807697 -> V=1.0, theta=0.0
% INFO    : Bus 78831	: V=0.9973794, theta=-80.61158 -> V=1.0, theta=0.0
% INFO    : Bus 78832	: V=0.9931407, theta=-80.018193 -> V=1.0, theta=0.0
% INFO    : Bus 78833	: V=0.9995708, theta=-79.902741 -> V=1.0, theta=0.0
% INFO    : Bus 78834	: V=0.9988559, theta=-80.613246 -> V=1.0, theta=0.0
% INFO    : Bus 78835	: V=0.9986438, theta=-79.940223 -> V=1.0, theta=0.0
% INFO    : Bus 78836	: V=0.9979098, theta=-79.808438 -> V=1.0, theta=0.0
% INFO    : Bus 78837	: V=0.9979711, theta=-79.486739 -> V=1.0, theta=0.0
% INFO    : Bus 78838	: V=0.9955782, theta=-79.172709 -> V=1.0, theta=0.0
% INFO    : Bus 78839	: V=0.9964926, theta=-78.964011 -> V=1.0, theta=0.0
% INFO    : Bus 78840	: V=0.9949684, theta=-78.361911 -> V=1.0, theta=0.0
% INFO    : Bus 78841	: V=1.0090456, theta=-78.897169 -> V=1.0, theta=0.0
% INFO    : Bus 78842	: V=0.9988543, theta=-79.155781 -> V=1.0, theta=0.0
% INFO    : Bus 78843	: V=1.0000243, theta=-79.671768 -> V=1.0, theta=0.0
% INFO    : Bus 78844	: V=0.9957675, theta=-78.436566 -> V=1.0, theta=0.0
% INFO    : Bus 78845	: V=0.9951182, theta=-78.20733 -> V=1.0, theta=0.0
% INFO    : Bus 78846	: V=0.999711, theta=-80.322047 -> V=1.0, theta=0.0
% INFO    : Bus 78847	: V=0.9936465, theta=-78.974263 -> V=1.0, theta=0.0
% INFO    : Bus 78848	: V=0.9946358, theta=-78.825572 -> V=1.0, theta=0.0
% INFO    : Bus 78849	: V=0.9955543, theta=-78.672109 -> V=1.0, theta=0.0
% INFO    : Bus 78850	: V=0.9938394, theta=-78.923262 -> V=1.0, theta=0.0
% INFO    : Bus 78851	: V=1.0003399, theta=-77.392814 -> V=1.0, theta=0.0
% INFO    : Bus 78852	: V=0.9973466, theta=-77.62325 -> V=1.0, theta=0.0
% INFO    : Bus 78853	: V=0.9991605, theta=-78.140595 -> V=1.0, theta=0.0
% INFO    : Bus 78854	: V=0.9979467, theta=-77.924728 -> V=1.0, theta=0.0
% INFO    : Bus 78855	: V=0.9969216, theta=-80.826146 -> V=1.0, theta=0.0
% INFO    : Bus 78856	: V=0.9974116, theta=-81.377589 -> V=1.0, theta=0.0
% INFO    : Bus 78857	: V=0.9992062, theta=-81.431906 -> V=1.0, theta=0.0
% INFO    : Bus 78858	: V=0.9994411, theta=-81.046017 -> V=1.0, theta=0.0
% INFO    : Bus 78859	: V=0.9991372, theta=-80.934432 -> V=1.0, theta=0.0
% INFO    : Bus 78860	: V=1.0031479, theta=-83.818699 -> V=1.0, theta=0.0
% INFO    : Bus 78861	: V=1.0043902, theta=-83.823905 -> V=1.0, theta=0.0
% INFO    : Bus 78862	: V=1.0011559, theta=-83.390275 -> V=1.0, theta=0.0
% INFO    : Bus 78863	: V=1.0027608, theta=-83.467531 -> V=1.0, theta=0.0
% INFO    : Bus 78864	: V=1.0046088, theta=-82.909901 -> V=1.0, theta=0.0
% INFO    : Bus 78865	: V=1.0027403, theta=-82.784349 -> V=1.0, theta=0.0
% INFO    : Bus 78866	: V=1.0010866, theta=-82.514607 -> V=1.0, theta=0.0
% INFO    : Bus 78867	: V=1.0025089, theta=-82.42655 -> V=1.0, theta=0.0
% INFO    : Bus 78868	: V=1.0012351, theta=-82.152346 -> V=1.0, theta=0.0
% INFO    : Bus 78869	: V=0.9979309, theta=-80.611968 -> V=1.0, theta=0.0
% INFO    : Bus 78870	: V=0.993171, theta=-79.953983 -> V=1.0, theta=0.0
% INFO    : Bus 78871	: V=0.9925213, theta=-79.8884 -> V=1.0, theta=0.0
% INFO    : Bus 78872	: V=0.9924809, theta=-79.958428 -> V=1.0, theta=0.0
% INFO    : Bus 78873	: V=0.9923882, theta=-79.743334 -> V=1.0, theta=0.0
% INFO    : Bus 78874	: V=0.990992, theta=-79.608711 -> V=1.0, theta=0.0
% INFO    : Bus 78875	: V=0.9923424, theta=-80.166677 -> V=1.0, theta=0.0
% INFO    : Bus 78876	: V=0.9933698, theta=-80.456804 -> V=1.0, theta=0.0
% INFO    : Bus 78877	: V=0.9957718, theta=-80.626521 -> V=1.0, theta=0.0
% INFO    : Bus 78878	: V=0.993225, theta=-79.844397 -> V=1.0, theta=0.0
% INFO    : Bus 78879	: V=0.9987272, theta=-79.360326 -> V=1.0, theta=0.0
% INFO    : Bus 78880	: V=0.9951856, theta=-79.668853 -> V=1.0, theta=0.0
% INFO    : Bus 78881	: V=0.9986059, theta=-79.565472 -> V=1.0, theta=0.0
% INFO    : Bus 78882	: V=0.9877651, theta=-79.36671 -> V=1.0, theta=0.0
% INFO    : Bus 78883	: V=0.9942691, theta=-78.878082 -> V=1.0, theta=0.0
% INFO    : Bus 78884	: V=0.9905917, theta=-79.115381 -> V=1.0, theta=0.0
% INFO    : Bus 78885	: V=0.9904678, theta=-78.888714 -> V=1.0, theta=0.0
% INFO    : Bus 78886	: V=0.9922759, theta=-78.815283 -> V=1.0, theta=0.0
% INFO    : Bus 78887	: V=0.9908551, theta=-78.504569 -> V=1.0, theta=0.0
% INFO    : Bus 78888	: V=0.9888834, theta=-77.950953 -> V=1.0, theta=0.0
% INFO    : Bus 78889	: V=0.9906937, theta=-77.851789 -> V=1.0, theta=0.0
% INFO    : Bus 78890	: V=0.9923925, theta=-78.535104 -> V=1.0, theta=0.0
% INFO    : Bus 78891	: V=0.992258, theta=-78.57102 -> V=1.0, theta=0.0
% INFO    : Bus 78892	: V=0.9990775, theta=-78.170333 -> V=1.0, theta=0.0
% INFO    : Bus 78893	: V=0.9953249, theta=-78.40208 -> V=1.0, theta=0.0
% INFO    : Bus 78894	: V=1.0061122, theta=-81.709662 -> V=1.0, theta=0.0
% INFO    : Bus 78895	: V=1.005199, theta=-82.664032 -> V=1.0, theta=0.0
% INFO    : Bus 78896	: V=1.0025178, theta=-80.112556 -> V=1.0, theta=0.0
% INFO    : Bus 78897	: V=1.0008, theta=-81.235252 -> V=1.0, theta=0.0
% INFO    : Bus 78898	: V=1.0044462, theta=-81.935865 -> V=1.0, theta=0.0
% INFO    : Bus 78899	: V=0.9964564, theta=-80.338738 -> V=1.0, theta=0.0
% INFO    : Bus 78900	: V=1.0121136, theta=-78.954183 -> V=1.0, theta=0.0
% INFO    : Bus 78901	: V=1.0059952, theta=-80.064408 -> V=1.0, theta=0.0
% INFO    : Bus 78902	: V=1.0040865, theta=-80.645082 -> V=1.0, theta=0.0
% INFO    : Bus 78903	: V=1.0110862, theta=-79.91873 -> V=1.0, theta=0.0
% INFO    : Bus 78904	: V=1.0054399, theta=-81.001633 -> V=1.0, theta=0.0
% INFO    : Bus 78905	: V=1.0059317, theta=-81.358239 -> V=1.0, theta=0.0
% INFO    : Bus 78906	: V=1.0045236, theta=-81.668834 -> V=1.0, theta=0.0
% INFO    : Bus 78907	: V=1.0063123, theta=-81.736452 -> V=1.0, theta=0.0
% INFO    : Bus 78908	: V=1.0018833, theta=-81.871732 -> V=1.0, theta=0.0
% INFO    : Bus 78909	: V=1.0022544, theta=-82.039766 -> V=1.0, theta=0.0
% INFO    : Bus 78910	: V=1.0019633, theta=-81.971826 -> V=1.0, theta=0.0
% INFO    : Bus 78911	: V=1.0047646, theta=-81.640749 -> V=1.0, theta=0.0
% INFO    : Bus 78912	: V=1.0025423, theta=-81.638827 -> V=1.0, theta=0.0
% INFO    : Bus 78913	: V=1.0039134, theta=-81.372434 -> V=1.0, theta=0.0
% INFO    : Bus 78914	: V=1.0033325, theta=-81.343728 -> V=1.0, theta=0.0
% INFO    : Bus 78915	: V=1.0028461, theta=-81.546492 -> V=1.0, theta=0.0
% INFO    : Bus 78916	: V=1.0029182, theta=-81.030395 -> V=1.0, theta=0.0
% INFO    : Bus 78917	: V=1.0009344, theta=-80.787273 -> V=1.0, theta=0.0
% INFO    : Bus 78918	: V=0.999515, theta=-80.716815 -> V=1.0, theta=0.0
% INFO    : Bus 78919	: V=1.0025962, theta=-81.595281 -> V=1.0, theta=0.0
% INFO    : Bus 78920	: V=1.0022919, theta=-82.208465 -> V=1.0, theta=0.0
% INFO    : Bus 78921	: V=1.0022995, theta=-82.126252 -> V=1.0, theta=0.0
% INFO    : Bus 78922	: V=1.0023902, theta=-82.118715 -> V=1.0, theta=0.0
% INFO    : Bus 78923	: V=1.0013204, theta=-81.977831 -> V=1.0, theta=0.0
% INFO    : Bus 78924	: V=1.0013526, theta=-81.996979 -> V=1.0, theta=0.0
% INFO    : Bus 78925	: V=1.0006892, theta=-81.828765 -> V=1.0, theta=0.0
% INFO    : Bus 78926	: V=1.0023079, theta=-81.67087 -> V=1.0, theta=0.0
% INFO    : Bus 78927	: V=1.0005413, theta=-81.933006 -> V=1.0, theta=0.0
% INFO    : Bus 78928	: V=1.0002163, theta=-81.256949 -> V=1.0, theta=0.0
% INFO    : Bus 78929	: V=1.0008831, theta=-81.529829 -> V=1.0, theta=0.0
% INFO    : Bus 78930	: V=1.0008259, theta=-81.397604 -> V=1.0, theta=0.0
% INFO    : Bus 78931	: V=1.0024179, theta=-79.994981 -> V=1.0, theta=0.0
% INFO    : Bus 78932	: V=0.9987419, theta=-80.683285 -> V=1.0, theta=0.0
% INFO    : Bus 78933	: V=0.9982616, theta=-81.082519 -> V=1.0, theta=0.0
% INFO    : Bus 78934	: V=1.0006487, theta=-81.640668 -> V=1.0, theta=0.0
% INFO    : Bus 78935	: V=0.9977238, theta=-81.146717 -> V=1.0, theta=0.0
% INFO    : Bus 78936	: V=0.9986865, theta=-81.484429 -> V=1.0, theta=0.0
% INFO    : Bus 78937	: V=0.999829, theta=-82.057369 -> V=1.0, theta=0.0
% INFO    : Bus 78938	: V=0.995218, theta=-81.293201 -> V=1.0, theta=0.0
% INFO    : Bus 78939	: V=0.9962614, theta=-81.507558 -> V=1.0, theta=0.0
% INFO    : Bus 78940	: V=0.9967176, theta=-81.371703 -> V=1.0, theta=0.0
% INFO    : Bus 78941	: V=0.9960001, theta=-81.05183 -> V=1.0, theta=0.0
% INFO    : Bus 78942	: V=0.9968034, theta=-80.976048 -> V=1.0, theta=0.0
% INFO    : Bus 78943	: V=0.9982669, theta=-80.959939 -> V=1.0, theta=0.0
% INFO    : Bus 78944	: V=0.9965244, theta=-80.739244 -> V=1.0, theta=0.0
% INFO    : Bus 78945	: V=0.9958595, theta=-80.655364 -> V=1.0, theta=0.0
% INFO    : Bus 78946	: V=0.9962899, theta=-81.00306 -> V=1.0, theta=0.0
% INFO    : Bus 78947	: V=0.996461, theta=-81.168069 -> V=1.0, theta=0.0
% INFO    : Bus 78948	: V=0.9933487, theta=-80.999685 -> V=1.0, theta=0.0
% INFO    : Bus 78949	: V=0.9986849, theta=-79.49567 -> V=1.0, theta=0.0
% INFO    : Bus 78950	: V=0.9903476, theta=-80.248012 -> V=1.0, theta=0.0
% INFO    : Bus 78951	: V=0.9871192, theta=-80.774379 -> V=1.0, theta=0.0
% INFO    : Bus 78952	: V=0.9938397, theta=-80.194383 -> V=1.0, theta=0.0
% INFO    : Bus 78953	: V=0.9938853, theta=-80.115224 -> V=1.0, theta=0.0
% INFO    : Bus 78954	: V=0.9897939, theta=-80.162516 -> V=1.0, theta=0.0
% INFO    : Bus 78955	: V=0.9964856, theta=-79.737633 -> V=1.0, theta=0.0
% INFO    : Bus 78956	: V=0.9910698, theta=-79.272756 -> V=1.0, theta=0.0
% INFO    : Bus 78957	: V=1.0010907, theta=-79.405263 -> V=1.0, theta=0.0
% INFO    : Bus 78958	: V=0.998077, theta=-80.601814 -> V=1.0, theta=0.0
% INFO    : Bus 78959	: V=0.9978154, theta=-81.027181 -> V=1.0, theta=0.0
% INFO    : Bus 78960	: V=0.9997202, theta=-80.090296 -> V=1.0, theta=0.0
% INFO    : Bus 78961	: V=1.0025093, theta=-79.655573 -> V=1.0, theta=0.0
% INFO    : Bus 78962	: V=0.998425, theta=-80.213539 -> V=1.0, theta=0.0
% INFO    : Bus 78963	: V=0.9995139, theta=-80.149842 -> V=1.0, theta=0.0
% INFO    : Bus 78964	: V=1.0015948, theta=-79.789078 -> V=1.0, theta=0.0
% INFO    : Bus 78965	: V=1.001404, theta=-79.326545 -> V=1.0, theta=0.0
% INFO    : Bus 78966	: V=0.9959015, theta=-78.328199 -> V=1.0, theta=0.0
% INFO    : Bus 78967	: V=0.9956496, theta=-78.373782 -> V=1.0, theta=0.0
% INFO    : Bus 78968	: V=1.0049661, theta=-78.453905 -> V=1.0, theta=0.0
% INFO    : Bus 78969	: V=1.0040029, theta=-79.10154 -> V=1.0, theta=0.0
% INFO    : Bus 78970	: V=1.0029643, theta=-78.921405 -> V=1.0, theta=0.0
% INFO    : Bus 78971	: V=0.9970203, theta=-79.577855 -> V=1.0, theta=0.0
% INFO    : Bus 78972	: V=0.9955215, theta=-79.812909 -> V=1.0, theta=0.0
% INFO    : Bus 78973	: V=0.9951006, theta=-80.117212 -> V=1.0, theta=0.0
% INFO    : Bus 78974	: V=0.9947024, theta=-80.1651 -> V=1.0, theta=0.0
% INFO    : Bus 78975	: V=0.9959806, theta=-80.534179 -> V=1.0, theta=0.0
% INFO    : Bus 78976	: V=0.9940005, theta=-79.912165 -> V=1.0, theta=0.0
% INFO    : Bus 78977	: V=0.9975693, theta=-79.389876 -> V=1.0, theta=0.0
% INFO    : Bus 78978	: V=1.0008913, theta=-79.258984 -> V=1.0, theta=0.0
% INFO    : Bus 78979	: V=1.0024381, theta=-78.889312 -> V=1.0, theta=0.0
% INFO    : Bus 78980	: V=1.0015307, theta=-79.231046 -> V=1.0, theta=0.0
% INFO    : Bus 78981	: V=1.0006643, theta=-79.22999 -> V=1.0, theta=0.0
% INFO    : Bus 78982	: V=0.9980261, theta=-78.903972 -> V=1.0, theta=0.0
% INFO    : Bus 78983	: V=0.9996769, theta=-79.182216 -> V=1.0, theta=0.0
% INFO    : Bus 78984	: V=0.9991489, theta=-78.537794 -> V=1.0, theta=0.0
% INFO    : Bus 78985	: V=0.9963711, theta=-77.980408 -> V=1.0, theta=0.0
% INFO    : Bus 78986	: V=1.0020702, theta=-77.537265 -> V=1.0, theta=0.0
% INFO    : Bus 78987	: V=1.0023214, theta=-77.521358 -> V=1.0, theta=0.0
% INFO    : Bus 78988	: V=0.9935808, theta=-77.907751 -> V=1.0, theta=0.0
% INFO    : Bus 78989	: V=1.0036397, theta=-77.163272 -> V=1.0, theta=0.0
% INFO    : Bus 78990	: V=1.0047926, theta=-78.290564 -> V=1.0, theta=0.0
% INFO    : Bus 78991	: V=1.0005629, theta=-78.073505 -> V=1.0, theta=0.0
% INFO    : Bus 78992	: V=0.9973306, theta=-78.109625 -> V=1.0, theta=0.0
% INFO    : Bus 78993	: V=1.0019907, theta=-77.375793 -> V=1.0, theta=0.0
% INFO    : Bus 78994	: V=1.0021366, theta=-77.292938 -> V=1.0, theta=0.0
% INFO    : Bus 78995	: V=1.0041249, theta=-77.069571 -> V=1.0, theta=0.0
% INFO    : Bus 78996	: V=1.0044498, theta=-76.795281 -> V=1.0, theta=0.0
% INFO    : Bus 78997	: V=1.0030788, theta=-76.993529 -> V=1.0, theta=0.0
% INFO    : Bus 78998	: V=0.9965783, theta=-79.21225 -> V=1.0, theta=0.0
% INFO    : Bus 78999	: V=0.9964021, theta=-79.314628 -> V=1.0, theta=0.0
% INFO    : Bus 79000	: V=0.9933642, theta=-80.354034 -> V=1.0, theta=0.0
% INFO    : Bus 79001	: V=0.9956794, theta=-80.474068 -> V=1.0, theta=0.0
% INFO    : Bus 79002	: V=0.9957386, theta=-79.421466 -> V=1.0, theta=0.0
% INFO    : Bus 79003	: V=0.9957445, theta=-79.430619 -> V=1.0, theta=0.0
% INFO    : Bus 79004	: V=0.9933352, theta=-78.966008 -> V=1.0, theta=0.0
% INFO    : Bus 79005	: V=0.9944743, theta=-78.727512 -> V=1.0, theta=0.0
% INFO    : Bus 79006	: V=0.9975702, theta=-78.285339 -> V=1.0, theta=0.0
% INFO    : Bus 79007	: V=0.9984313, theta=-78.137076 -> V=1.0, theta=0.0
% INFO    : Bus 79008	: V=0.9987106, theta=-77.806057 -> V=1.0, theta=0.0
% INFO    : Bus 79009	: V=0.9955557, theta=-78.458636 -> V=1.0, theta=0.0
% INFO    : Bus 79010	: V=0.9929416, theta=-78.990307 -> V=1.0, theta=0.0
% INFO    : Bus 79011	: V=0.9980891, theta=-78.193962 -> V=1.0, theta=0.0
% INFO    : Bus 79012	: V=0.9971274, theta=-77.619345 -> V=1.0, theta=0.0
% INFO    : Bus 79013	: V=0.9968571, theta=-78.046235 -> V=1.0, theta=0.0
% INFO    : Bus 79014	: V=1.0042364, theta=-77.040282 -> V=1.0, theta=0.0
% INFO    : Bus 79015	: V=1.0028531, theta=-77.16596 -> V=1.0, theta=0.0
% INFO    : Bus 79016	: V=0.9992747, theta=-77.535415 -> V=1.0, theta=0.0
% INFO    : Bus 79017	: V=0.9999201, theta=-77.443228 -> V=1.0, theta=0.0
% INFO    : Bus 79018	: V=1.0036756, theta=-76.607279 -> V=1.0, theta=0.0
% INFO    : Bus 79019	: V=1.0019864, theta=-76.915633 -> V=1.0, theta=0.0
% INFO    : Bus 79020	: V=0.9987359, theta=-77.57719 -> V=1.0, theta=0.0
% INFO    : Bus 79021	: V=0.9974214, theta=-78.360883 -> V=1.0, theta=0.0
% INFO    : Bus 79022	: V=0.9977319, theta=-78.486733 -> V=1.0, theta=0.0
% INFO    : Bus 79023	: V=1.0062127, theta=-78.095414 -> V=1.0, theta=0.0
% INFO    : Bus 79024	: V=1.0008271, theta=-78.543789 -> V=1.0, theta=0.0
% INFO    : Bus 79025	: V=0.9989788, theta=-78.367753 -> V=1.0, theta=0.0
% INFO    : Bus 79026	: V=0.999153, theta=-78.069154 -> V=1.0, theta=0.0
% INFO    : Bus 79027	: V=0.9991037, theta=-77.769446 -> V=1.0, theta=0.0
% INFO    : Bus 79028	: V=0.9997534, theta=-77.796945 -> V=1.0, theta=0.0
% INFO    : Bus 79029	: V=0.9991715, theta=-77.33249 -> V=1.0, theta=0.0
% INFO    : Bus 79030	: V=1.0039204, theta=-76.742381 -> V=1.0, theta=0.0
% INFO    : Bus 79031	: V=1.0051187, theta=-76.248446 -> V=1.0, theta=0.0
% INFO    : Bus 79032	: V=1.0021697, theta=-82.482281 -> V=1.0, theta=0.0
% INFO    : Bus 79033	: V=1.0021173, theta=-82.4987 -> V=1.0, theta=0.0
% INFO    : Bus 79034	: V=1.0012296, theta=-82.175652 -> V=1.0, theta=0.0
% INFO    : Bus 79035	: V=1.0007401, theta=-82.112436 -> V=1.0, theta=0.0
% INFO    : Bus 79036	: V=1.0007201, theta=-82.10841 -> V=1.0, theta=0.0
% INFO    : Bus 79037	: V=1.0025648, theta=-82.361064 -> V=1.0, theta=0.0
% INFO    : Bus 79038	: V=1.0025441, theta=-82.671699 -> V=1.0, theta=0.0
% INFO    : Bus 79039	: V=1.0025706, theta=-82.669318 -> V=1.0, theta=0.0
% INFO    : Bus 79040	: V=1.0031776, theta=-82.914626 -> V=1.0, theta=0.0
% INFO    : Bus 79041	: V=1.0032931, theta=-82.929997 -> V=1.0, theta=0.0
% INFO    : Bus 79042	: V=1.003145, theta=-82.88219 -> V=1.0, theta=0.0
% INFO    : Bus 79043	: V=1.0023879, theta=-82.752386 -> V=1.0, theta=0.0
% INFO    : Bus 79044	: V=1.0033643, theta=-83.051682 -> V=1.0, theta=0.0
% INFO    : Bus 79045	: V=1.0024583, theta=-82.991412 -> V=1.0, theta=0.0
% INFO    : Bus 79046	: V=1.0028489, theta=-82.495973 -> V=1.0, theta=0.0
% INFO    : Bus 79047	: V=1.0028188, theta=-82.409001 -> V=1.0, theta=0.0
% INFO    : Bus 79048	: V=0.9993463, theta=-82.121854 -> V=1.0, theta=0.0
% INFO    : Bus 79049	: V=0.9994138, theta=-82.121975 -> V=1.0, theta=0.0
% INFO    : Bus 79050	: V=1.0038002, theta=-82.763289 -> V=1.0, theta=0.0
% INFO    : Bus 79051	: V=1.0004464, theta=-81.974434 -> V=1.0, theta=0.0
% INFO    : Bus 79052	: V=1.0000764, theta=-82.054921 -> V=1.0, theta=0.0
% INFO    : Bus 79053	: V=1.0006491, theta=-82.014284 -> V=1.0, theta=0.0
% INFO    : Bus 79054	: V=1.0005275, theta=-82.015735 -> V=1.0, theta=0.0
% INFO    : Bus 79055	: V=0.9984012, theta=-82.013623 -> V=1.0, theta=0.0
% INFO    : Bus 79056	: V=0.997611, theta=-82.116388 -> V=1.0, theta=0.0
% INFO    : Bus 79057	: V=0.9967992, theta=-82.135402 -> V=1.0, theta=0.0
% INFO    : Bus 79058	: V=1.0014337, theta=-82.173767 -> V=1.0, theta=0.0
% INFO    : Bus 79059	: V=0.9971309, theta=-81.636827 -> V=1.0, theta=0.0
% INFO    : Bus 79060	: V=0.9967662, theta=-81.620365 -> V=1.0, theta=0.0
% INFO    : Bus 79061	: V=0.9962629, theta=-81.584432 -> V=1.0, theta=0.0
% INFO    : Bus 79062	: V=0.9942053, theta=-81.436781 -> V=1.0, theta=0.0
% INFO    : Bus 79063	: V=0.9936199, theta=-81.427033 -> V=1.0, theta=0.0
% INFO    : Bus 79064	: V=0.9960662, theta=-81.578542 -> V=1.0, theta=0.0
% INFO    : Bus 79065	: V=0.9994334, theta=-81.782058 -> V=1.0, theta=0.0
% INFO    : Bus 79066	: V=1.0000315, theta=-81.898485 -> V=1.0, theta=0.0
% INFO    : Bus 79067	: V=0.9996245, theta=-81.975794 -> V=1.0, theta=0.0
% INFO    : Bus 79068	: V=1.001625, theta=-81.638195 -> V=1.0, theta=0.0
% INFO    : Bus 79069	: V=1.0020005, theta=-81.628194 -> V=1.0, theta=0.0
% INFO    : Bus 79070	: V=1.0030091, theta=-81.536485 -> V=1.0, theta=0.0
% INFO    : Bus 79071	: V=0.9988211, theta=-81.573787 -> V=1.0, theta=0.0
% INFO    : Bus 79072	: V=1.0028689, theta=-81.807924 -> V=1.0, theta=0.0
% INFO    : Bus 79073	: V=1.0050003, theta=-81.696933 -> V=1.0, theta=0.0
% INFO    : Bus 79074	: V=1.0088877, theta=-81.638487 -> V=1.0, theta=0.0
% INFO    : Bus 79075	: V=1.0078852, theta=-81.48921 -> V=1.0, theta=0.0
% INFO    : Bus 79076	: V=1.005805, theta=-81.408847 -> V=1.0, theta=0.0
% INFO    : Bus 79077	: V=0.9989803, theta=-81.510294 -> V=1.0, theta=0.0
% INFO    : Bus 79078	: V=1.0074271, theta=-81.585536 -> V=1.0, theta=0.0
% INFO    : Bus 79079	: V=1.0078289, theta=-81.402818 -> V=1.0, theta=0.0
% INFO    : Bus 79080	: V=1.0115853, theta=-80.944995 -> V=1.0, theta=0.0
% INFO    : Bus 79081	: V=1.007301, theta=-81.401403 -> V=1.0, theta=0.0
% INFO    : Bus 79082	: V=1.0057903, theta=-81.41235 -> V=1.0, theta=0.0
% INFO    : Bus 79083	: V=1.0025857, theta=-80.790398 -> V=1.0, theta=0.0
% INFO    : Bus 79084	: V=0.9959182, theta=-81.265719 -> V=1.0, theta=0.0
% INFO    : Bus 79085	: V=0.9968432, theta=-81.401666 -> V=1.0, theta=0.0
% INFO    : Bus 79086	: V=1.0005779, theta=-80.504685 -> V=1.0, theta=0.0
% INFO    : Bus 79087	: V=0.9924562, theta=-80.844105 -> V=1.0, theta=0.0
% INFO    : Bus 79088	: V=0.9916238, theta=-80.628657 -> V=1.0, theta=0.0
% INFO    : Bus 79089	: V=1.0016957, theta=-83.744633 -> V=1.0, theta=0.0
% INFO    : Bus 79090	: V=1.0007637, theta=-83.851333 -> V=1.0, theta=0.0
% INFO    : Bus 79091	: V=1.0014607, theta=-83.784234 -> V=1.0, theta=0.0
% INFO    : Bus 79092	: V=1.0016469, theta=-83.779664 -> V=1.0, theta=0.0
% INFO    : Bus 79093	: V=1.0024212, theta=-83.377045 -> V=1.0, theta=0.0
% INFO    : Bus 79094	: V=1.0012817, theta=-83.385605 -> V=1.0, theta=0.0
% INFO    : Bus 79095	: V=0.9999899, theta=-83.448922 -> V=1.0, theta=0.0
% INFO    : Bus 79096	: V=1.0065277, theta=-82.771061 -> V=1.0, theta=0.0
% INFO    : Bus 79097	: V=1.0039738, theta=-83.53466 -> V=1.0, theta=0.0
% INFO    : Bus 79098	: V=1.0027282, theta=-83.446246 -> V=1.0, theta=0.0
% INFO    : Bus 79099	: V=1.0041136, theta=-83.104521 -> V=1.0, theta=0.0
% INFO    : Bus 79100	: V=1.005254, theta=-82.633263 -> V=1.0, theta=0.0
% INFO    : Bus 79101	: V=1.0025783, theta=-83.077662 -> V=1.0, theta=0.0
% INFO    : Bus 79102	: V=1.0068097, theta=-83.295369 -> V=1.0, theta=0.0
% INFO    : Bus 79103	: V=1.001364, theta=-84.510869 -> V=1.0, theta=0.0
% INFO    : Bus 79104	: V=1.0041872, theta=-83.624861 -> V=1.0, theta=0.0
% INFO    : Bus 79105	: V=1.0024959, theta=-83.876773 -> V=1.0, theta=0.0
% INFO    : Bus 79106	: V=1.0009537, theta=-83.916792 -> V=1.0, theta=0.0
% INFO    : Bus 79107	: V=0.9996712, theta=-83.934761 -> V=1.0, theta=0.0
% INFO    : Bus 79108	: V=0.9995748, theta=-83.923341 -> V=1.0, theta=0.0
% INFO    : Bus 79109	: V=0.9992182, theta=-84.031353 -> V=1.0, theta=0.0
% INFO    : Bus 79110	: V=1.0007635, theta=-83.953503 -> V=1.0, theta=0.0
% INFO    : Bus 79111	: V=0.9912746, theta=-76.817821 -> V=1.0, theta=0.0
% INFO    : Bus 79112	: V=0.9944433, theta=-75.706802 -> V=1.0, theta=0.0
% INFO    : Bus 79113	: V=0.9914458, theta=-76.971892 -> V=1.0, theta=0.0
% INFO    : Bus 79114	: V=0.9961653, theta=-77.011995 -> V=1.0, theta=0.0
% INFO    : Bus 79115	: V=1.0110817, theta=-76.812369 -> V=1.0, theta=0.0
% INFO    : Bus 79116	: V=1.0105882, theta=-77.873204 -> V=1.0, theta=0.0
% INFO    : Bus 79117	: V=0.989054, theta=-75.567321 -> V=1.0, theta=0.0
% INFO    : Bus 79118	: V=0.9898226, theta=-77.037984 -> V=1.0, theta=0.0
% INFO    : Bus 79119	: V=0.9908034, theta=-76.989079 -> V=1.0, theta=0.0
% INFO    : Bus 79120	: V=0.9892233, theta=-77.132839 -> V=1.0, theta=0.0
% INFO    : Bus 79121	: V=0.9925117, theta=-78.63735 -> V=1.0, theta=0.0
% INFO    : Bus 79122	: V=0.9863279, theta=-73.905066 -> V=1.0, theta=0.0
% INFO    : Bus 79123	: V=1.0040025, theta=-81.002808 -> V=1.0, theta=0.0
% INFO    : Bus 79124	: V=1.0015922, theta=-81.038664 -> V=1.0, theta=0.0
% INFO    : Bus 79125	: V=1.0109317, theta=-79.034095 -> V=1.0, theta=0.0
% INFO    : Bus 79126	: V=1.0139324, theta=-80.78948 -> V=1.0, theta=0.0
% INFO    : Bus 79127	: V=1.0167755, theta=-80.906901 -> V=1.0, theta=0.0
% INFO    : Bus 79128	: V=1.0121777, theta=-81.297724 -> V=1.0, theta=0.0
% INFO    : Bus 79129	: V=1.0087605, theta=-81.467264 -> V=1.0, theta=0.0
% INFO    : Bus 79130	: V=1.0077938, theta=-81.532306 -> V=1.0, theta=0.0
% INFO    : Bus 79131	: V=1.0039414, theta=-81.716748 -> V=1.0, theta=0.0
% INFO    : Bus 79132	: V=1.0069525, theta=-82.078984 -> V=1.0, theta=0.0
% INFO    : Bus 79133	: V=1.0060102, theta=-82.017548 -> V=1.0, theta=0.0
% INFO    : Bus 79134	: V=1.006701, theta=-82.015266 -> V=1.0, theta=0.0
% INFO    : Bus 79135	: V=1.0026939, theta=-79.154461 -> V=1.0, theta=0.0
% INFO    : Bus 79136	: V=0.9863302, theta=-79.724633 -> V=1.0, theta=0.0
% INFO    : Bus 79137	: V=0.9888193, theta=-76.429219 -> V=1.0, theta=0.0
% INFO    : Bus 79138	: V=1.0059915, theta=-81.888467 -> V=1.0, theta=0.0
% INFO    : Bus 79139	: V=1.0008875, theta=-81.891284 -> V=1.0, theta=0.0
% INFO    : Bus 79140	: V=1.0003312, theta=-78.982724 -> V=1.0, theta=0.0
% INFO    : Bus 79141	: V=0.9956052, theta=-77.917676 -> V=1.0, theta=0.0
% INFO    : Bus 79142	: V=1.0114862, theta=-80.867387 -> V=1.0, theta=0.0
% INFO    : Bus 79143	: V=1.0076659, theta=-81.966741 -> V=1.0, theta=0.0
% INFO    : Bus 79144	: V=1.003606, theta=-82.243819 -> V=1.0, theta=0.0
% INFO    : Bus 79145	: V=1.0022972, theta=-79.910075 -> V=1.0, theta=0.0
% INFO    : Bus 79146	: V=1.0014395, theta=-78.038152 -> V=1.0, theta=0.0
% INFO    : Bus 79147	: V=0.9873786, theta=-89.770389 -> V=1.0, theta=0.0
% INFO    : Bus 79148	: V=0.9885482, theta=-97.418552 -> V=1.0, theta=0.0
% INFO    : Bus 79149	: V=0.9829358, theta=-95.731359 -> V=1.0, theta=0.0
% INFO    : Bus 79150	: V=0.9800286, theta=-95.59131 -> V=1.0, theta=0.0
% INFO    : Bus 79151	: V=0.9979393, theta=-103.0393 -> V=1.0, theta=0.0
% INFO    : Bus 79152	: V=1.0036895, theta=-104.628781 -> V=1.0, theta=0.0
% INFO    : Bus 79153	: V=1.0004729, theta=-104.82662 -> V=1.0, theta=0.0
% INFO    : Bus 79154	: V=1.0035234, theta=-105.346822 -> V=1.0, theta=0.0
% INFO    : Bus 79155	: V=0.9995481, theta=-105.146015 -> V=1.0, theta=0.0
% INFO    : Bus 79156	: V=1.0043345, theta=-105.841236 -> V=1.0, theta=0.0
% INFO    : Bus 79157	: V=1.0042536, theta=-105.162898 -> V=1.0, theta=0.0
% INFO    : Bus 79158	: V=1.0063695, theta=-105.942669 -> V=1.0, theta=0.0
% INFO    : Bus 79159	: V=1.0062863, theta=-106.680824 -> V=1.0, theta=0.0
% INFO    : Bus 79160	: V=1.0058527, theta=-106.900858 -> V=1.0, theta=0.0
% INFO    : Bus 79161	: V=1.0031336, theta=-90.473008 -> V=1.0, theta=0.0
% INFO    : Bus 79162	: V=1.0095023, theta=-84.395955 -> V=1.0, theta=0.0
% INFO    : Bus 79163	: V=1.0028117, theta=-85.587769 -> V=1.0, theta=0.0
% INFO    : Bus 79164	: V=1.0035747, theta=-105.37005 -> V=1.0, theta=0.0
% INFO    : Bus 79165	: V=1.0001668, theta=-103.864894 -> V=1.0, theta=0.0
% INFO    : Bus 79166	: V=1.0013379, theta=-105.33739 -> V=1.0, theta=0.0
% INFO    : Bus 79167	: V=1.0045236, theta=-103.068557 -> V=1.0, theta=0.0
% INFO    : Bus 79168	: V=1.0011746, theta=-103.557436 -> V=1.0, theta=0.0
% INFO    : Bus 79169	: V=0.998722, theta=-103.27417 -> V=1.0, theta=0.0
% INFO    : Bus 79170	: V=0.9992734, theta=-103.477459 -> V=1.0, theta=0.0
% INFO    : Bus 79171	: V=1.0058894, theta=-104.894612 -> V=1.0, theta=0.0
% INFO    : Bus 79172	: V=1.0091879, theta=-104.574179 -> V=1.0, theta=0.0
% INFO    : Bus 79173	: V=0.9910539, theta=-99.801222 -> V=1.0, theta=0.0
% INFO    : Bus 79174	: V=1.0111607, theta=-101.129257 -> V=1.0, theta=0.0
% INFO    : Bus 79175	: V=0.9764728, theta=-61.157237 -> V=1.0, theta=0.0
% INFO    : Bus 79176	: V=1.0010376, theta=-65.49807 -> V=1.0, theta=0.0
% INFO    : Bus 79177	: V=1.013531, theta=-99.588326 -> V=1.0, theta=0.0
% INFO    : Bus 79178	: V=1.0144279, theta=-99.376474 -> V=1.0, theta=0.0
% INFO    : Bus 79179	: V=1.0149291, theta=-99.25657 -> V=1.0, theta=0.0
% INFO    : Bus 79180	: V=1.0121225, theta=-101.182974 -> V=1.0, theta=0.0
% INFO    : Bus 79181	: V=1.0021672, theta=-100.637927 -> V=1.0, theta=0.0
% INFO    : Bus 79182	: V=0.9940656, theta=-98.883786 -> V=1.0, theta=0.0
% INFO    : Bus 79183	: V=0.9944825, theta=-96.923089 -> V=1.0, theta=0.0
% INFO    : Bus 79184	: V=0.9899354, theta=-91.498128 -> V=1.0, theta=0.0
% INFO    : Bus 79185	: V=1.0113585, theta=-89.580417 -> V=1.0, theta=0.0
% INFO    : Bus 79186	: V=1.0075879, theta=-106.195686 -> V=1.0, theta=0.0
% INFO    : Bus 79187	: V=1.0015429, theta=-104.317065 -> V=1.0, theta=0.0
% INFO    : Bus 79188	: V=1.0111851, theta=-99.326618 -> V=1.0, theta=0.0
% INFO    : Bus 79189	: V=0.992926, theta=-102.147892 -> V=1.0, theta=0.0
% INFO    : Bus 79190	: V=0.9966481, theta=-102.974226 -> V=1.0, theta=0.0
% INFO    : Bus 79191	: V=0.9959089, theta=-102.386508 -> V=1.0, theta=0.0
% INFO    : Bus 79192	: V=0.9932581, theta=-101.631929 -> V=1.0, theta=0.0
% INFO    : Bus 79193	: V=0.9993559, theta=-104.859283 -> V=1.0, theta=0.0
% INFO    : Bus 79194	: V=0.9984225, theta=-104.198067 -> V=1.0, theta=0.0
% INFO    : Bus 79195	: V=1.0018437, theta=-94.509253 -> V=1.0, theta=0.0
% INFO    : Bus 79196	: V=1.0085268, theta=-89.879123 -> V=1.0, theta=0.0
% INFO    : Bus 79197	: V=1.0029951, theta=-89.257955 -> V=1.0, theta=0.0
% INFO    : Bus 79198	: V=0.9895352, theta=-78.634431 -> V=1.0, theta=0.0
% INFO    : Bus 79199	: V=0.9918392, theta=-78.15223 -> V=1.0, theta=0.0
% INFO    : Bus 79200	: V=0.9887639, theta=-78.309663 -> V=1.0, theta=0.0
% INFO    : Bus 79201	: V=0.9989084, theta=-77.029162 -> V=1.0, theta=0.0
% INFO    : Bus 79202	: V=0.9936119, theta=-77.606475 -> V=1.0, theta=0.0
% INFO    : Bus 79203	: V=0.9909719, theta=-78.042352 -> V=1.0, theta=0.0
% INFO    : Bus 79204	: V=0.9882099, theta=-77.338671 -> V=1.0, theta=0.0
% INFO    : Bus 79205	: V=0.9890017, theta=-77.303604 -> V=1.0, theta=0.0
% INFO    : Bus 79206	: V=0.996113, theta=-76.756956 -> V=1.0, theta=0.0
% INFO    : Bus 79207	: V=0.9928383, theta=-77.289467 -> V=1.0, theta=0.0
% INFO    : Bus 79208	: V=0.9902958, theta=-76.589092 -> V=1.0, theta=0.0
% INFO    : Bus 79209	: V=0.9905839, theta=-76.661102 -> V=1.0, theta=0.0
% INFO    : Bus 79210	: V=0.9923678, theta=-75.610165 -> V=1.0, theta=0.0
% INFO    : Bus 79211	: V=0.990692, theta=-76.236734 -> V=1.0, theta=0.0
% INFO    : Bus 79212	: V=0.9915396, theta=-76.094379 -> V=1.0, theta=0.0
% INFO    : Bus 79213	: V=0.9913265, theta=-75.982534 -> V=1.0, theta=0.0
% INFO    : Bus 79214	: V=1.0089467, theta=-69.212353 -> V=1.0, theta=0.0
% INFO    : Bus 79215	: V=1.0075574, theta=-69.319497 -> V=1.0, theta=0.0
% INFO    : Bus 79216	: V=1.0057678, theta=-71.319022 -> V=1.0, theta=0.0
% INFO    : Bus 79217	: V=1.012384, theta=-67.200095 -> V=1.0, theta=0.0
% INFO    : Bus 79218	: V=1.0126396, theta=-67.076967 -> V=1.0, theta=0.0
% INFO    : Bus 79219	: V=1.0093543, theta=-68.265721 -> V=1.0, theta=0.0
% INFO    : Bus 79220	: V=1.0092206, theta=-68.431836 -> V=1.0, theta=0.0
% INFO    : Bus 79221	: V=1.0063749, theta=-69.536403 -> V=1.0, theta=0.0
% INFO    : Bus 79222	: V=1.0075938, theta=-69.209155 -> V=1.0, theta=0.0
% INFO    : Bus 79223	: V=1.0059967, theta=-70.627245 -> V=1.0, theta=0.0
% INFO    : Bus 79224	: V=1.0060343, theta=-70.395862 -> V=1.0, theta=0.0
% INFO    : Bus 79225	: V=1.0009504, theta=-72.727358 -> V=1.0, theta=0.0
% INFO    : Bus 79226	: V=0.9926592, theta=-75.3117 -> V=1.0, theta=0.0
% INFO    : Bus 79227	: V=0.9969126, theta=-74.03464 -> V=1.0, theta=0.0
% INFO    : Bus 79228	: V=0.9907784, theta=-75.062071 -> V=1.0, theta=0.0
% INFO    : Bus 79229	: V=0.9983304, theta=-72.724917 -> V=1.0, theta=0.0
% INFO    : Bus 79230	: V=0.992536, theta=-74.858342 -> V=1.0, theta=0.0
% INFO    : Bus 79231	: V=0.9922729, theta=-74.912083 -> V=1.0, theta=0.0
% INFO    : Bus 79232	: V=0.9937509, theta=-74.882221 -> V=1.0, theta=0.0
% INFO    : Bus 79233	: V=0.9953015, theta=-75.158461 -> V=1.0, theta=0.0
% INFO    : Bus 79234	: V=0.9952701, theta=-75.140868 -> V=1.0, theta=0.0
% INFO    : Bus 79235	: V=1.0011827, theta=-74.634449 -> V=1.0, theta=0.0
% INFO    : Bus 79236	: V=0.9979947, theta=-74.962274 -> V=1.0, theta=0.0
% INFO    : Bus 79237	: V=0.9954215, theta=-75.137914 -> V=1.0, theta=0.0
% INFO    : Bus 79238	: V=0.9979802, theta=-75.030923 -> V=1.0, theta=0.0
% INFO    : Bus 79239	: V=0.9934773, theta=-75.305761 -> V=1.0, theta=0.0
% INFO    : Bus 79240	: V=0.9957354, theta=-75.154892 -> V=1.0, theta=0.0
% INFO    : Bus 79241	: V=0.994979, theta=-75.302545 -> V=1.0, theta=0.0
% INFO    : Bus 79242	: V=1.0033227, theta=-74.663802 -> V=1.0, theta=0.0
% INFO    : Bus 79243	: V=0.9947179, theta=-75.307325 -> V=1.0, theta=0.0
% INFO    : Bus 79244	: V=0.9938001, theta=-75.694241 -> V=1.0, theta=0.0
% INFO    : Bus 79245	: V=0.9943754, theta=-75.413261 -> V=1.0, theta=0.0
% INFO    : Bus 79246	: V=0.9909573, theta=-75.519895 -> V=1.0, theta=0.0
% INFO    : Bus 79247	: V=0.9953252, theta=-75.471071 -> V=1.0, theta=0.0
% INFO    : Bus 79248	: V=0.99011, theta=-75.918108 -> V=1.0, theta=0.0
% INFO    : Bus 79249	: V=0.9944768, theta=-75.663561 -> V=1.0, theta=0.0
% INFO    : Bus 79250	: V=0.993194, theta=-75.474526 -> V=1.0, theta=0.0
% INFO    : Bus 79251	: V=0.98912, theta=-76.031725 -> V=1.0, theta=0.0
% INFO    : Bus 79252	: V=0.9915097, theta=-75.664569 -> V=1.0, theta=0.0
% INFO    : Bus 79253	: V=0.9899945, theta=-75.808287 -> V=1.0, theta=0.0
% INFO    : Bus 79254	: V=1.0077641, theta=-73.933965 -> V=1.0, theta=0.0
% INFO    : Bus 79255	: V=1.0046204, theta=-74.196547 -> V=1.0, theta=0.0
% INFO    : Bus 79256	: V=0.990832, theta=-76.174398 -> V=1.0, theta=0.0
% INFO    : Bus 79257	: V=0.9937726, theta=-75.820811 -> V=1.0, theta=0.0
% INFO    : Bus 79258	: V=0.9877559, theta=-76.105201 -> V=1.0, theta=0.0
% INFO    : Bus 79259	: V=0.9887033, theta=-76.142017 -> V=1.0, theta=0.0
% INFO    : Bus 79260	: V=0.9878584, theta=-76.458613 -> V=1.0, theta=0.0
% INFO    : Bus 79261	: V=0.9862852, theta=-76.501774 -> V=1.0, theta=0.0
% INFO    : Bus 79262	: V=0.9860645, theta=-76.912284 -> V=1.0, theta=0.0
% INFO    : Bus 79263	: V=0.9849137, theta=-76.982301 -> V=1.0, theta=0.0
% INFO    : Bus 79264	: V=0.9855544, theta=-76.793462 -> V=1.0, theta=0.0
% INFO    : Bus 79265	: V=0.985542, theta=-76.569773 -> V=1.0, theta=0.0
% INFO    : Bus 79266	: V=0.9875734, theta=-76.544008 -> V=1.0, theta=0.0
% INFO    : Bus 79267	: V=0.9976859, theta=-75.705143 -> V=1.0, theta=0.0
% INFO    : Bus 79268	: V=0.9928469, theta=-76.256162 -> V=1.0, theta=0.0
% INFO    : Bus 79269	: V=0.9929733, theta=-75.858894 -> V=1.0, theta=0.0
% INFO    : Bus 79270	: V=0.9960028, theta=-75.412585 -> V=1.0, theta=0.0
% INFO    : Bus 79271	: V=0.9937311, theta=-75.843694 -> V=1.0, theta=0.0
% INFO    : Bus 79272	: V=1.0017735, theta=-74.988539 -> V=1.0, theta=0.0
% INFO    : Bus 79273	: V=0.9952976, theta=-75.560583 -> V=1.0, theta=0.0
% INFO    : Bus 79274	: V=0.9956426, theta=-75.634369 -> V=1.0, theta=0.0
% INFO    : Bus 79275	: V=1.0016931, theta=-74.999909 -> V=1.0, theta=0.0
% INFO    : Bus 79276	: V=0.9994935, theta=-75.127458 -> V=1.0, theta=0.0
% INFO    : Bus 79277	: V=0.9912395, theta=-75.914758 -> V=1.0, theta=0.0
% INFO    : Bus 79278	: V=0.9924465, theta=-75.894745 -> V=1.0, theta=0.0
% INFO    : Bus 79279	: V=0.9965837, theta=-75.694234 -> V=1.0, theta=0.0
% INFO    : Bus 79280	: V=1.003438, theta=-74.908756 -> V=1.0, theta=0.0
% INFO    : Bus 79281	: V=1.0003599, theta=-75.25064 -> V=1.0, theta=0.0
% INFO    : Bus 79282	: V=1.0000303, theta=-75.229006 -> V=1.0, theta=0.0
% INFO    : Bus 79283	: V=1.0001999, theta=-75.264243 -> V=1.0, theta=0.0
% INFO    : Bus 79284	: V=0.9890186, theta=-75.758237 -> V=1.0, theta=0.0
% INFO    : Bus 79285	: V=1.0009963, theta=-75.246404 -> V=1.0, theta=0.0
% INFO    : Bus 79286	: V=1.0000748, theta=-75.574612 -> V=1.0, theta=0.0
% INFO    : Bus 79287	: V=1.0120596, theta=-74.159626 -> V=1.0, theta=0.0
% INFO    : Bus 79288	: V=1.006486, theta=-74.787018 -> V=1.0, theta=0.0
% INFO    : Bus 79289	: V=1.0012834, theta=-75.433298 -> V=1.0, theta=0.0
% INFO    : Bus 79290	: V=1.0003641, theta=-75.441375 -> V=1.0, theta=0.0
% INFO    : Bus 79291	: V=0.9953471, theta=-75.783912 -> V=1.0, theta=0.0
% INFO    : Bus 79292	: V=0.9945531, theta=-75.976968 -> V=1.0, theta=0.0
% INFO    : Bus 79293	: V=0.9948882, theta=-76.0033 -> V=1.0, theta=0.0
% INFO    : Bus 79294	: V=1.002726, theta=-76.180847 -> V=1.0, theta=0.0
% INFO    : Bus 79295	: V=0.9980431, theta=-76.232662 -> V=1.0, theta=0.0
% INFO    : Bus 79296	: V=1.0033612, theta=-76.901633 -> V=1.0, theta=0.0
% INFO    : Bus 79297	: V=0.9992547, theta=-76.234487 -> V=1.0, theta=0.0
% INFO    : Bus 79298	: V=0.995588, theta=-77.46395 -> V=1.0, theta=0.0
% INFO    : Bus 79299	: V=1.0022995, theta=-76.994557 -> V=1.0, theta=0.0
% INFO    : Bus 79300	: V=1.0134176, theta=-74.977211 -> V=1.0, theta=0.0
% INFO    : Bus 79301	: V=1.0075411, theta=-76.318836 -> V=1.0, theta=0.0
% INFO    : Bus 79302	: V=1.006022, theta=-76.532402 -> V=1.0, theta=0.0
% INFO    : Bus 79303	: V=0.9939691, theta=-77.221357 -> V=1.0, theta=0.0
% INFO    : Bus 79304	: V=1.0037996, theta=-76.9404 -> V=1.0, theta=0.0
% INFO    : Bus 79305	: V=1.0055702, theta=-76.885905 -> V=1.0, theta=0.0
% INFO    : Bus 79306	: V=0.9935619, theta=-77.213173 -> V=1.0, theta=0.0
% INFO    : Bus 79307	: V=0.9911896, theta=-77.570905 -> V=1.0, theta=0.0
% INFO    : Bus 79308	: V=0.9903922, theta=-77.807002 -> V=1.0, theta=0.0
% INFO    : Bus 79309	: V=0.9888203, theta=-77.738428 -> V=1.0, theta=0.0
% INFO    : Bus 79310	: V=0.9900186, theta=-77.78626 -> V=1.0, theta=0.0
% INFO    : Bus 79311	: V=1.0029212, theta=-92.252802 -> V=1.0, theta=0.0
% INFO    : Bus 79312	: V=1.0022969, theta=-92.681563 -> V=1.0, theta=0.0
% INFO    : Bus 79313	: V=1.0039973, theta=-97.472177 -> V=1.0, theta=0.0
% INFO    : Bus 79314	: V=1.0069631, theta=-97.034331 -> V=1.0, theta=0.0
% INFO    : Bus 79315	: V=1.0069553, theta=-97.038641 -> V=1.0, theta=0.0
% INFO    : Bus 79316	: V=1.0090054, theta=-95.131573 -> V=1.0, theta=0.0
% INFO    : Bus 79317	: V=1.0093331, theta=-95.100538 -> V=1.0, theta=0.0
% INFO    : Bus 79318	: V=1.0016546, theta=-92.502692 -> V=1.0, theta=0.0
% INFO    : Bus 79319	: V=1.0034466, theta=-91.261881 -> V=1.0, theta=0.0
% INFO    : Bus 79320	: V=1.0051057, theta=-97.707484 -> V=1.0, theta=0.0
% INFO    : Bus 79321	: V=0.9978169, theta=-77.545987 -> V=1.0, theta=0.0
% INFO    : Bus 79322	: V=1.001564, theta=-66.898971 -> V=1.0, theta=0.0
% INFO    : Bus 79323	: V=0.997019, theta=-67.629226 -> V=1.0, theta=0.0
% INFO    : Bus 79324	: V=0.9987218, theta=-67.793305 -> V=1.0, theta=0.0
% INFO    : Bus 79325	: V=0.9976852, theta=-68.896112 -> V=1.0, theta=0.0
% INFO    : Bus 79326	: V=0.9931847, theta=-70.967431 -> V=1.0, theta=0.0
% INFO    : Bus 79327	: V=0.9885812, theta=-70.052718 -> V=1.0, theta=0.0
% INFO    : Bus 79328	: V=0.9851947, theta=-71.76827 -> V=1.0, theta=0.0
% INFO    : Bus 79329	: V=0.9838422, theta=-72.226171 -> V=1.0, theta=0.0
% INFO    : Bus 79330	: V=0.999856, theta=-66.911077 -> V=1.0, theta=0.0
% INFO    : Bus 79331	: V=1.0044829, theta=-67.196879 -> V=1.0, theta=0.0
% INFO    : Bus 79332	: V=1.0052001, theta=-66.958606 -> V=1.0, theta=0.0
% INFO    : Bus 79333	: V=1.0052979, theta=-66.656824 -> V=1.0, theta=0.0
% INFO    : Bus 79334	: V=1.0032535, theta=-66.449372 -> V=1.0, theta=0.0
% INFO    : Bus 79335	: V=1.0004919, theta=-67.519352 -> V=1.0, theta=0.0
% INFO    : Bus 79336	: V=1.0022218, theta=-65.729845 -> V=1.0, theta=0.0
% INFO    : Bus 79337	: V=1.0004059, theta=-65.437597 -> V=1.0, theta=0.0
% INFO    : Bus 79338	: V=1.0031519, theta=-64.706393 -> V=1.0, theta=0.0
% INFO    : Bus 79339	: V=1.0146571, theta=-59.988965 -> V=1.0, theta=0.0
% INFO    : Bus 79340	: V=1.0106431, theta=-60.413112 -> V=1.0, theta=0.0
% INFO    : Bus 79341	: V=1.0114342, theta=-61.176968 -> V=1.0, theta=0.0
% INFO    : Bus 79342	: V=1.0195125, theta=-55.210654 -> V=1.0, theta=0.0
% INFO    : Bus 79343	: V=1.023034, theta=-54.273045 -> V=1.0, theta=0.0
% INFO    : Bus 79344	: V=0.9987036, theta=-22.837582 -> V=1.0, theta=0.0
% INFO    : Bus 79345	: V=0.9955501, theta=-22.593798 -> V=1.0, theta=0.0
% INFO    : Bus 79346	: V=1.0022915, theta=-67.503743 -> V=1.0, theta=0.0
% INFO    : Bus 79347	: V=1.0074667, theta=-66.71236 -> V=1.0, theta=0.0
% INFO    : Bus 79348	: V=1.0032212, theta=-65.424732 -> V=1.0, theta=0.0
% INFO    : Bus 79349	: V=1.0006643, theta=-65.553761 -> V=1.0, theta=0.0
% INFO    : Bus 79350	: V=1.0232536, theta=-54.171325 -> V=1.0, theta=0.0
% INFO    : Bus 79351	: V=1.0065097, theta=-100.811185 -> V=1.0, theta=0.0
% INFO    : Bus 79352	: V=1.0086804, theta=-100.838338 -> V=1.0, theta=0.0
% INFO    : Bus 79353	: V=1.0090763, theta=-100.801752 -> V=1.0, theta=0.0
% INFO    : Bus 79354	: V=1.0058528, theta=-100.137639 -> V=1.0, theta=0.0
% INFO    : Bus 79355	: V=1.0042257, theta=-99.667663 -> V=1.0, theta=0.0
% INFO    : Bus 79356	: V=1.0043092, theta=-99.652007 -> V=1.0, theta=0.0
% INFO    : Bus 79357	: V=1.0043215, theta=-99.397646 -> V=1.0, theta=0.0
% INFO    : Bus 79358	: V=1.0020422, theta=-98.675817 -> V=1.0, theta=0.0
% INFO    : Bus 79359	: V=1.0041149, theta=-98.445737 -> V=1.0, theta=0.0
% INFO    : Bus 79360	: V=1.0039303, theta=-98.341663 -> V=1.0, theta=0.0
% INFO    : Bus 79361	: V=1.00566, theta=-97.664203 -> V=1.0, theta=0.0
% INFO    : Bus 79362	: V=1.0094817, theta=-97.143151 -> V=1.0, theta=0.0
% INFO    : Bus 79363	: V=1.0104756, theta=-97.164924 -> V=1.0, theta=0.0
% INFO    : Bus 79364	: V=1.0104653, theta=-99.045158 -> V=1.0, theta=0.0
% INFO    : Bus 79365	: V=1.0108155, theta=-99.261073 -> V=1.0, theta=0.0
% INFO    : Bus 79366	: V=1.0095436, theta=-100.697186 -> V=1.0, theta=0.0
% INFO    : Bus 79367	: V=1.0071331, theta=-101.352169 -> V=1.0, theta=0.0
% INFO    : Bus 79368	: V=1.0084532, theta=-101.147621 -> V=1.0, theta=0.0
% INFO    : Bus 79369	: V=1.0069954, theta=-100.238184 -> V=1.0, theta=0.0
% INFO    : Bus 79370	: V=1.0055117, theta=-99.464372 -> V=1.0, theta=0.0
% INFO    : Bus 79371	: V=1.0144113, theta=-97.596536 -> V=1.0, theta=0.0
% INFO    : Bus 79372	: V=1.0027977, theta=-102.10082 -> V=1.0, theta=0.0
% INFO    : Bus 79373	: V=1.0083872, theta=-101.277899 -> V=1.0, theta=0.0
% INFO    : Bus 79374	: V=1.0080762, theta=-101.365272 -> V=1.0, theta=0.0
% INFO    : Bus 79375	: V=1.0072478, theta=-101.462087 -> V=1.0, theta=0.0
% INFO    : Bus 79376	: V=1.0058017, theta=-101.758275 -> V=1.0, theta=0.0
% INFO    : Bus 79377	: V=1.0084287, theta=-104.063895 -> V=1.0, theta=0.0
% INFO    : Bus 79378	: V=1.003746, theta=-92.062826 -> V=1.0, theta=0.0
% INFO    : Bus 79379	: V=0.9932476, theta=-75.042116 -> V=1.0, theta=0.0
% INFO    : Bus 79380	: V=0.9965042, theta=-74.982314 -> V=1.0, theta=0.0
% INFO    : Bus 79381	: V=0.9962553, theta=-72.795632 -> V=1.0, theta=0.0
% INFO    : Bus 79382	: V=0.9961466, theta=-73.086164 -> V=1.0, theta=0.0
% INFO    : Bus 79383	: V=1.0001357, theta=-72.047656 -> V=1.0, theta=0.0
% INFO    : Bus 79384	: V=0.9974024, theta=-72.887232 -> V=1.0, theta=0.0
% INFO    : Bus 79385	: V=0.9932487, theta=-72.850125 -> V=1.0, theta=0.0
% INFO    : Bus 79386	: V=0.9986653, theta=-72.656919 -> V=1.0, theta=0.0
% INFO    : Bus 79387	: V=0.9944465, theta=-73.399113 -> V=1.0, theta=0.0
% INFO    : Bus 79388	: V=0.9962923, theta=-71.422538 -> V=1.0, theta=0.0
% INFO    : Bus 79389	: V=0.9968094, theta=-70.633545 -> V=1.0, theta=0.0
% INFO    : Bus 79390	: V=0.9951417, theta=-71.974893 -> V=1.0, theta=0.0
% INFO    : Bus 79391	: V=0.9932559, theta=-73.273892 -> V=1.0, theta=0.0
% INFO    : Bus 79392	: V=1.0030303, theta=-71.323576 -> V=1.0, theta=0.0
% INFO    : Bus 79393	: V=1.0011889, theta=-71.572445 -> V=1.0, theta=0.0
% INFO    : Bus 79394	: V=1.0039842, theta=-69.196111 -> V=1.0, theta=0.0
% INFO    : Bus 79395	: V=0.9990276, theta=-69.445851 -> V=1.0, theta=0.0
% INFO    : Bus 79396	: V=0.9996733, theta=-70.403409 -> V=1.0, theta=0.0
% INFO    : Bus 79397	: V=0.9971418, theta=-69.18464 -> V=1.0, theta=0.0
% INFO    : Bus 79398	: V=1.0001056, theta=-68.041894 -> V=1.0, theta=0.0
% INFO    : Bus 79399	: V=0.9976046, theta=-68.388777 -> V=1.0, theta=0.0
% INFO    : Bus 79400	: V=1.0004886, theta=-69.068146 -> V=1.0, theta=0.0
% INFO    : Bus 79401	: V=1.0019439, theta=-68.042228 -> V=1.0, theta=0.0
% INFO    : Bus 79402	: V=1.0014255, theta=-66.996799 -> V=1.0, theta=0.0
% INFO    : Bus 79403	: V=1.0130661, theta=-64.684557 -> V=1.0, theta=0.0
% INFO    : Bus 79404	: V=1.0118008, theta=-65.093576 -> V=1.0, theta=0.0
% INFO    : Bus 79405	: V=0.9994363, theta=-66.724266 -> V=1.0, theta=0.0
% INFO    : Bus 79406	: V=1.0000713, theta=-66.762404 -> V=1.0, theta=0.0
% INFO    : Bus 79407	: V=1.0009998, theta=-66.703291 -> V=1.0, theta=0.0
% INFO    : Bus 79408	: V=1.0069835, theta=-66.790789 -> V=1.0, theta=0.0
% INFO    : Bus 79409	: V=1.0016583, theta=-66.667561 -> V=1.0, theta=0.0
% INFO    : Bus 79410	: V=1.006238, theta=-66.660305 -> V=1.0, theta=0.0
% INFO    : Bus 79411	: V=1.000029, theta=-67.834915 -> V=1.0, theta=0.0
% INFO    : Bus 79412	: V=1.0055777, theta=-65.486653 -> V=1.0, theta=0.0
% INFO    : Bus 79413	: V=1.005047, theta=-64.019967 -> V=1.0, theta=0.0
% INFO    : Bus 79414	: V=1.0024681, theta=-63.162108 -> V=1.0, theta=0.0
% INFO    : Bus 79415	: V=1.0027697, theta=-65.834222 -> V=1.0, theta=0.0
% INFO    : Bus 79416	: V=1.0036422, theta=-65.036085 -> V=1.0, theta=0.0
% INFO    : Bus 79417	: V=1.0058884, theta=-65.52647 -> V=1.0, theta=0.0
% INFO    : Bus 79418	: V=1.0046546, theta=-65.213742 -> V=1.0, theta=0.0
% INFO    : Bus 79419	: V=0.9928275, theta=-57.17324 -> V=1.0, theta=0.0
% INFO    : Bus 79420	: V=1.0098045, theta=-62.769186 -> V=1.0, theta=0.0
% INFO    : Bus 79421	: V=1.0025371, theta=-70.546954 -> V=1.0, theta=0.0
% INFO    : Bus 79422	: V=0.9987038, theta=-70.959194 -> V=1.0, theta=0.0
% INFO    : Bus 79423	: V=0.9927818, theta=-19.010721 -> V=1.0, theta=0.0
% INFO    : Bus 79424	: V=1.0065622, theta=-66.968588 -> V=1.0, theta=0.0
% INFO    : Bus 79425	: V=0.9978071, theta=-63.7027 -> V=1.0, theta=0.0
% INFO    : Bus 79426	: V=0.9992648, theta=-63.639908 -> V=1.0, theta=0.0
% INFO    : Bus 79427	: V=0.9987311, theta=-63.597458 -> V=1.0, theta=0.0
% INFO    : Bus 79428	: V=0.9985563, theta=-63.667939 -> V=1.0, theta=0.0
% INFO    : Bus 79429	: V=1.0005349, theta=-63.673581 -> V=1.0, theta=0.0
% INFO    : Bus 79430	: V=1.0000249, theta=-63.746889 -> V=1.0, theta=0.0
% INFO    : Bus 79431	: V=0.9980012, theta=-63.78014 -> V=1.0, theta=0.0
% INFO    : Bus 79432	: V=0.9947736, theta=-63.839244 -> V=1.0, theta=0.0
% INFO    : Bus 79433	: V=0.9964974, theta=-63.785042 -> V=1.0, theta=0.0
% INFO    : Bus 79434	: V=1.0029119, theta=-63.248301 -> V=1.0, theta=0.0
% INFO    : Bus 79435	: V=0.9996083, theta=-63.24002 -> V=1.0, theta=0.0
% INFO    : Bus 79436	: V=0.9990065, theta=-63.626465 -> V=1.0, theta=0.0
% INFO    : Bus 79437	: V=0.99546, theta=-63.293116 -> V=1.0, theta=0.0
% INFO    : Bus 79438	: V=1.0016022, theta=-62.959314 -> V=1.0, theta=0.0
% INFO    : Bus 79439	: V=1.0017502, theta=-63.519036 -> V=1.0, theta=0.0
% INFO    : Bus 79440	: V=1.0043548, theta=-62.232874 -> V=1.0, theta=0.0
% INFO    : Bus 79441	: V=0.9967541, theta=-62.861194 -> V=1.0, theta=0.0
% INFO    : Bus 79442	: V=1.0034553, theta=-62.855674 -> V=1.0, theta=0.0
% INFO    : Bus 79443	: V=1.0006083, theta=-63.172215 -> V=1.0, theta=0.0
% INFO    : Bus 79444	: V=1.0035281, theta=-62.886098 -> V=1.0, theta=0.0
% INFO    : Bus 79445	: V=1.0035134, theta=-62.977106 -> V=1.0, theta=0.0
% INFO    : Bus 79446	: V=1.0034751, theta=-63.394491 -> V=1.0, theta=0.0
% INFO    : Bus 79447	: V=1.0005085, theta=-62.971059 -> V=1.0, theta=0.0
% INFO    : Bus 79448	: V=0.99655, theta=-63.584572 -> V=1.0, theta=0.0
% INFO    : Bus 79449	: V=0.9967896, theta=-63.598208 -> V=1.0, theta=0.0
% INFO    : Bus 79450	: V=1.003464, theta=-62.947035 -> V=1.0, theta=0.0
% INFO    : Bus 79451	: V=1.0011282, theta=-63.461789 -> V=1.0, theta=0.0
% INFO    : Bus 79452	: V=1.0040657, theta=-62.910954 -> V=1.0, theta=0.0
% INFO    : Bus 79453	: V=1.0011717, theta=-62.236271 -> V=1.0, theta=0.0
% INFO    : Bus 79454	: V=0.9995544, theta=-60.5308 -> V=1.0, theta=0.0
% INFO    : Bus 79455	: V=0.9942166, theta=-62.951551 -> V=1.0, theta=0.0
% INFO    : Bus 79456	: V=0.9919586, theta=-63.332428 -> V=1.0, theta=0.0
% INFO    : Bus 79457	: V=0.9960378, theta=-62.681189 -> V=1.0, theta=0.0
% INFO    : Bus 79458	: V=1.0065775, theta=-61.6125 -> V=1.0, theta=0.0
% INFO    : Bus 79459	: V=0.998294, theta=-63.053019 -> V=1.0, theta=0.0
% INFO    : Bus 79460	: V=0.999434, theta=-63.595437 -> V=1.0, theta=0.0
% INFO    : Bus 79461	: V=1.0002831, theta=-63.565374 -> V=1.0, theta=0.0
% INFO    : Bus 79462	: V=1.0060564, theta=-62.458094 -> V=1.0, theta=0.0
% INFO    : Bus 79463	: V=1.0164842, theta=-59.582266 -> V=1.0, theta=0.0
% INFO    : Bus 79464	: V=1.0110408, theta=-61.164398 -> V=1.0, theta=0.0
% INFO    : Bus 79465	: V=1.00729, theta=-62.243296 -> V=1.0, theta=0.0
% INFO    : Bus 79466	: V=1.0043041, theta=-62.379952 -> V=1.0, theta=0.0
% INFO    : Bus 79467	: V=1.0032252, theta=-63.391843 -> V=1.0, theta=0.0
% INFO    : Bus 79468	: V=1.0007792, theta=-63.597159 -> V=1.0, theta=0.0
% INFO    : Bus 79469	: V=0.9958401, theta=-63.799415 -> V=1.0, theta=0.0
% INFO    : Bus 79470	: V=1.0112354, theta=-62.836321 -> V=1.0, theta=0.0
% INFO    : Bus 79471	: V=1.008258, theta=-63.022446 -> V=1.0, theta=0.0
% INFO    : Bus 79472	: V=1.0060199, theta=-63.163062 -> V=1.0, theta=0.0
% INFO    : Bus 79473	: V=1.0094995, theta=-62.996027 -> V=1.0, theta=0.0
% INFO    : Bus 79474	: V=1.0100846, theta=-62.917664 -> V=1.0, theta=0.0
% INFO    : Bus 79475	: V=1.0099081, theta=-62.601554 -> V=1.0, theta=0.0
% INFO    : Bus 79476	: V=1.0128069, theta=-62.484665 -> V=1.0, theta=0.0
% INFO    : Bus 79477	: V=1.0132821, theta=-62.373055 -> V=1.0, theta=0.0
% INFO    : Bus 79478	: V=1.0126848, theta=-62.584649 -> V=1.0, theta=0.0
% INFO    : Bus 79479	: V=1.0183897, theta=-63.10739 -> V=1.0, theta=0.0
% INFO    : Bus 79480	: V=1.0175714, theta=-63.22733 -> V=1.0, theta=0.0
% INFO    : Bus 79481	: V=1.0176754, theta=-63.355647 -> V=1.0, theta=0.0
% INFO    : Bus 79482	: V=1.0193165, theta=-62.639696 -> V=1.0, theta=0.0
% INFO    : Bus 79483	: V=1.0167894, theta=-63.463656 -> V=1.0, theta=0.0
% INFO    : Bus 79484	: V=1.0089943, theta=-64.246429 -> V=1.0, theta=0.0
% INFO    : Bus 79485	: V=1.0032845, theta=-64.934737 -> V=1.0, theta=0.0
% INFO    : Bus 79486	: V=1.0155414, theta=-63.516906 -> V=1.0, theta=0.0
% INFO    : Bus 79487	: V=1.0143028, theta=-63.362121 -> V=1.0, theta=0.0
% INFO    : Bus 79488	: V=1.0124737, theta=-63.700555 -> V=1.0, theta=0.0
% INFO    : Bus 79489	: V=1.0114278, theta=-63.207013 -> V=1.0, theta=0.0
% INFO    : Bus 79490	: V=1.0130159, theta=-62.871529 -> V=1.0, theta=0.0
% INFO    : Bus 79491	: V=1.0111985, theta=-62.720537 -> V=1.0, theta=0.0
% INFO    : Bus 79492	: V=1.0039684, theta=-62.707218 -> V=1.0, theta=0.0
% INFO    : Bus 79493	: V=1.0108093, theta=-63.198673 -> V=1.0, theta=0.0
% INFO    : Bus 79494	: V=1.0121337, theta=-63.096414 -> V=1.0, theta=0.0
% INFO    : Bus 79495	: V=1.0076758, theta=-62.469654 -> V=1.0, theta=0.0
% INFO    : Bus 79496	: V=0.9914082, theta=-63.84076 -> V=1.0, theta=0.0
% INFO    : Bus 79497	: V=1.0262693, theta=-61.110563 -> V=1.0, theta=0.0
% INFO    : Bus 79498	: V=1.0209932, theta=-61.788536 -> V=1.0, theta=0.0
% INFO    : Bus 79499	: V=1.0171954, theta=-62.24805 -> V=1.0, theta=0.0
% INFO    : Bus 79500	: V=1.0090664, theta=-110.406127 -> V=1.0, theta=0.0
% INFO    : Bus 79501	: V=1.0096806, theta=-109.107988 -> V=1.0, theta=0.0
% INFO    : Bus 79502	: V=1.0098658, theta=-110.167531 -> V=1.0, theta=0.0
% INFO    : Bus 79503	: V=1.0084739, theta=-110.512055 -> V=1.0, theta=0.0
% INFO    : Bus 79504	: V=1.0088708, theta=-110.453486 -> V=1.0, theta=0.0
% INFO    : Bus 79505	: V=1.0082836, theta=-110.551328 -> V=1.0, theta=0.0
% INFO    : Bus 79506	: V=1.0074739, theta=-111.325425 -> V=1.0, theta=0.0
% INFO    : Bus 79507	: V=1.0082549, theta=-110.616847 -> V=1.0, theta=0.0
% INFO    : Bus 79508	: V=1.0079177, theta=-110.319463 -> V=1.0, theta=0.0
% INFO    : Bus 79509	: V=1.0073211, theta=-110.952264 -> V=1.0, theta=0.0
% INFO    : Bus 79510	: V=1.0064777, theta=-110.903454 -> V=1.0, theta=0.0
% INFO    : Bus 79511	: V=1.0079881, theta=-110.703346 -> V=1.0, theta=0.0
% INFO    : Bus 79512	: V=1.0064695, theta=-110.658082 -> V=1.0, theta=0.0
% INFO    : Bus 79513	: V=1.0081887, theta=-110.354267 -> V=1.0, theta=0.0
% INFO    : Bus 79514	: V=1.0064253, theta=-110.901596 -> V=1.0, theta=0.0
% INFO    : Bus 79515	: V=1.0056054, theta=-111.126327 -> V=1.0, theta=0.0
% INFO    : Bus 79516	: V=1.0055764, theta=-111.074796 -> V=1.0, theta=0.0
% INFO    : Bus 79517	: V=1.009571, theta=-109.279413 -> V=1.0, theta=0.0
% INFO    : Bus 79518	: V=1.009292, theta=-109.659136 -> V=1.0, theta=0.0
% INFO    : Bus 79519	: V=1.017678, theta=-109.965049 -> V=1.0, theta=0.0
% INFO    : Bus 79520	: V=1.0129514, theta=-107.62043 -> V=1.0, theta=0.0
% INFO    : Bus 79521	: V=1.0098712, theta=-109.232275 -> V=1.0, theta=0.0
% INFO    : Bus 79522	: V=1.0097918, theta=-109.521032 -> V=1.0, theta=0.0
% INFO    : Bus 79523	: V=1.0070825, theta=-110.694013 -> V=1.0, theta=0.0
% INFO    : Bus 79524	: V=0.9974378, theta=-105.009504 -> V=1.0, theta=0.0
% INFO    : Bus 79525	: V=0.9939762, theta=-105.680437 -> V=1.0, theta=0.0
% INFO    : Bus 79526	: V=0.9899612, theta=-106.050239 -> V=1.0, theta=0.0
% INFO    : Bus 79527	: V=0.9900853, theta=-106.023098 -> V=1.0, theta=0.0
% INFO    : Bus 79528	: V=0.9889796, theta=-105.956728 -> V=1.0, theta=0.0
% INFO    : Bus 79529	: V=0.9914416, theta=-106.456432 -> V=1.0, theta=0.0
% INFO    : Bus 79530	: V=0.988623, theta=-105.637624 -> V=1.0, theta=0.0
% INFO    : Bus 79531	: V=0.9918759, theta=-105.96502 -> V=1.0, theta=0.0
% INFO    : Bus 79532	: V=0.9799403, theta=-106.010389 -> V=1.0, theta=0.0
% INFO    : Bus 79533	: V=0.9914935, theta=-105.957256 -> V=1.0, theta=0.0
% INFO    : Bus 79534	: V=0.9888332, theta=-105.590367 -> V=1.0, theta=0.0
% INFO    : Bus 79535	: V=0.9819064, theta=-106.344045 -> V=1.0, theta=0.0
% INFO    : Bus 79536	: V=0.9920969, theta=-105.680192 -> V=1.0, theta=0.0
% INFO    : Bus 79537	: V=0.9977776, theta=-104.324918 -> V=1.0, theta=0.0
% INFO    : Bus 79538	: V=0.998543, theta=-105.187796 -> V=1.0, theta=0.0
% INFO    : Bus 79539	: V=0.9891343, theta=-105.67403 -> V=1.0, theta=0.0
% INFO    : Bus 79540	: V=0.9874351, theta=-105.951662 -> V=1.0, theta=0.0
% INFO    : Bus 79541	: V=0.9902183, theta=-105.644346 -> V=1.0, theta=0.0
% INFO    : Bus 79542	: V=1.0058786, theta=-107.116385 -> V=1.0, theta=0.0
% INFO    : Bus 79543	: V=1.0062175, theta=-107.055993 -> V=1.0, theta=0.0
% INFO    : Bus 79544	: V=1.0059169, theta=-107.219888 -> V=1.0, theta=0.0
% INFO    : Bus 79545	: V=1.0075925, theta=-107.002358 -> V=1.0, theta=0.0
% INFO    : Bus 79546	: V=1.0118885, theta=-80.6342 -> V=1.0, theta=0.0
% INFO    : Bus 79547	: V=0.9882533, theta=-81.842359 -> V=1.0, theta=0.0
% INFO    : Bus 79548	: V=0.9922944, theta=-81.309001 -> V=1.0, theta=0.0
% INFO    : Bus 79549	: V=0.9953997, theta=-81.294175 -> V=1.0, theta=0.0
% INFO    : Bus 79550	: V=0.9956254, theta=-81.15335 -> V=1.0, theta=0.0
% INFO    : Bus 79551	: V=1.0045868, theta=-80.872002 -> V=1.0, theta=0.0
% INFO    : Bus 79552	: V=0.9996619, theta=-81.354388 -> V=1.0, theta=0.0
% INFO    : Bus 79553	: V=0.9988061, theta=-81.705506 -> V=1.0, theta=0.0
% INFO    : Bus 79554	: V=1.0092688, theta=-80.32368 -> V=1.0, theta=0.0
% INFO    : Bus 79555	: V=1.0079847, theta=-81.826004 -> V=1.0, theta=0.0
% INFO    : Bus 79556	: V=1.0183394, theta=-79.089369 -> V=1.0, theta=0.0
% INFO    : Bus 79557	: V=1.0055566, theta=-110.928744 -> V=1.0, theta=0.0
% INFO    : Bus 79558	: V=1.0042845, theta=-111.395298 -> V=1.0, theta=0.0
% INFO    : Bus 79559	: V=1.001112, theta=-112.307938 -> V=1.0, theta=0.0
% INFO    : Bus 79560	: V=1.0009236, theta=-112.47533 -> V=1.0, theta=0.0
% INFO    : Bus 79561	: V=1.0016716, theta=-111.807248 -> V=1.0, theta=0.0
% INFO    : Bus 79562	: V=1.0047372, theta=-110.530548 -> V=1.0, theta=0.0
% INFO    : Bus 79563	: V=1.0036365, theta=-110.935155 -> V=1.0, theta=0.0
% INFO    : Bus 79564	: V=1.0027627, theta=-111.363212 -> V=1.0, theta=0.0
% INFO    : Bus 79565	: V=1.0023987, theta=-111.527785 -> V=1.0, theta=0.0
% INFO    : Bus 79566	: V=1.0016186, theta=-111.533317 -> V=1.0, theta=0.0
% INFO    : Bus 79567	: V=1.0001394, theta=-112.272629 -> V=1.0, theta=0.0
% INFO    : Bus 79568	: V=1.0010503, theta=-111.551748 -> V=1.0, theta=0.0
% INFO    : Bus 79569	: V=1.0010656, theta=-111.558714 -> V=1.0, theta=0.0
% INFO    : Bus 79570	: V=1.0001481, theta=-112.125174 -> V=1.0, theta=0.0
% INFO    : Bus 79571	: V=1.0002092, theta=-111.960947 -> V=1.0, theta=0.0
% INFO    : Bus 79572	: V=1.0000965, theta=-111.971507 -> V=1.0, theta=0.0
% INFO    : Bus 79573	: V=1.0004566, theta=-111.562834 -> V=1.0, theta=0.0
% INFO    : Bus 79574	: V=0.9985119, theta=-111.702536 -> V=1.0, theta=0.0
% INFO    : Bus 79575	: V=0.9982601, theta=-111.800152 -> V=1.0, theta=0.0
% INFO    : Bus 79576	: V=0.9982165, theta=-111.78416 -> V=1.0, theta=0.0
% INFO    : Bus 79577	: V=1.0004223, theta=-111.574556 -> V=1.0, theta=0.0
% INFO    : Bus 79578	: V=1.0001941, theta=-111.590807 -> V=1.0, theta=0.0
% INFO    : Bus 79579	: V=1.000071, theta=-111.493951 -> V=1.0, theta=0.0
% INFO    : Bus 79580	: V=1.0004646, theta=-111.476038 -> V=1.0, theta=0.0
% INFO    : Bus 79581	: V=1.0004797, theta=-111.475483 -> V=1.0, theta=0.0
% INFO    : Bus 79582	: V=0.9968852, theta=-112.004468 -> V=1.0, theta=0.0
% INFO    : Bus 79583	: V=1.0013962, theta=-111.084618 -> V=1.0, theta=0.0
% INFO    : Bus 79584	: V=0.9976979, theta=-111.572872 -> V=1.0, theta=0.0
% INFO    : Bus 79585	: V=0.9952382, theta=-111.660055 -> V=1.0, theta=0.0
% INFO    : Bus 79586	: V=0.9991242, theta=-112.148655 -> V=1.0, theta=0.0
% INFO    : Bus 79587	: V=0.998718, theta=-112.131091 -> V=1.0, theta=0.0
% INFO    : Bus 79588	: V=0.9980836, theta=-111.555703 -> V=1.0, theta=0.0
% INFO    : Bus 79589	: V=0.9970197, theta=-111.665694 -> V=1.0, theta=0.0
% INFO    : Bus 79590	: V=0.9959194, theta=-111.666104 -> V=1.0, theta=0.0
% INFO    : Bus 79591	: V=0.9986454, theta=-111.393867 -> V=1.0, theta=0.0
% INFO    : Bus 79592	: V=0.9945891, theta=-111.72556 -> V=1.0, theta=0.0
% INFO    : Bus 79593	: V=0.9963437, theta=-111.565102 -> V=1.0, theta=0.0
% INFO    : Bus 79594	: V=0.9963614, theta=-111.448882 -> V=1.0, theta=0.0
% INFO    : Bus 79595	: V=0.996217, theta=-111.456732 -> V=1.0, theta=0.0
% INFO    : Bus 79596	: V=0.9950804, theta=-111.984088 -> V=1.0, theta=0.0
% INFO    : Bus 79597	: V=0.9979075, theta=-111.401766 -> V=1.0, theta=0.0
% INFO    : Bus 79598	: V=1.0061923, theta=-83.130719 -> V=1.0, theta=0.0
% INFO    : Bus 79599	: V=1.007208, theta=-82.856495 -> V=1.0, theta=0.0
% INFO    : Bus 79600	: V=1.005557, theta=-83.563464 -> V=1.0, theta=0.0
% INFO    : Bus 79601	: V=1.0039769, theta=-83.798699 -> V=1.0, theta=0.0
% INFO    : Bus 79602	: V=1.0010418, theta=-83.916477 -> V=1.0, theta=0.0
% INFO    : Bus 79603	: V=1.0000817, theta=-84.035627 -> V=1.0, theta=0.0
% INFO    : Bus 79604	: V=1.0053747, theta=-83.560794 -> V=1.0, theta=0.0
% INFO    : Bus 79605	: V=1.0002021, theta=-83.991844 -> V=1.0, theta=0.0
% INFO    : Bus 79606	: V=1.0039361, theta=-83.862778 -> V=1.0, theta=0.0
% INFO    : Bus 79607	: V=1.0010584, theta=-84.145735 -> V=1.0, theta=0.0
% INFO    : Bus 79608	: V=1.0090521, theta=-80.292492 -> V=1.0, theta=0.0
% INFO    : Bus 79609	: V=0.9932429, theta=-82.687684 -> V=1.0, theta=0.0
% INFO    : Bus 79610	: V=1.0015456, theta=-82.633113 -> V=1.0, theta=0.0
% INFO    : Bus 79611	: V=1.0079847, theta=-82.404777 -> V=1.0, theta=0.0
% INFO    : Bus 79612	: V=0.9830477, theta=-82.635425 -> V=1.0, theta=0.0
% INFO    : Bus 79613	: V=0.9866329, theta=-82.455743 -> V=1.0, theta=0.0
% INFO    : Bus 79614	: V=0.9980546, theta=-81.624613 -> V=1.0, theta=0.0
% INFO    : Bus 79615	: V=0.9792416, theta=-82.739108 -> V=1.0, theta=0.0
% INFO    : Bus 79616	: V=0.9890628, theta=-83.312111 -> V=1.0, theta=0.0
% INFO    : Bus 79617	: V=0.9999333, theta=-82.40487 -> V=1.0, theta=0.0
% INFO    : Bus 79618	: V=1.0000734, theta=-82.466182 -> V=1.0, theta=0.0
% INFO    : Bus 79619	: V=0.994678, theta=-83.066244 -> V=1.0, theta=0.0
% INFO    : Bus 79620	: V=1.0019788, theta=-83.511387 -> V=1.0, theta=0.0
% INFO    : Bus 79621	: V=1.001567, theta=-83.345421 -> V=1.0, theta=0.0
% INFO    : Bus 79622	: V=1.002761, theta=-83.257877 -> V=1.0, theta=0.0
% INFO    : Bus 79623	: V=1.00282, theta=-83.217103 -> V=1.0, theta=0.0
% INFO    : Bus 79624	: V=0.9977482, theta=-83.696405 -> V=1.0, theta=0.0
% INFO    : Bus 79625	: V=0.9960187, theta=-83.055028 -> V=1.0, theta=0.0
% INFO    : Bus 79626	: V=0.9969317, theta=-111.873928 -> V=1.0, theta=0.0
% INFO    : Bus 79627	: V=0.9991948, theta=-111.526834 -> V=1.0, theta=0.0
% INFO    : Bus 79628	: V=0.9962107, theta=-111.948084 -> V=1.0, theta=0.0
% INFO    : Bus 79629	: V=0.9985348, theta=-111.667258 -> V=1.0, theta=0.0
% INFO    : Bus 79630	: V=1.0004161, theta=-111.477136 -> V=1.0, theta=0.0
% INFO    : Bus 79631	: V=0.9985265, theta=-110.488931 -> V=1.0, theta=0.0
% INFO    : Bus 79632	: V=1.0045202, theta=-111.120483 -> V=1.0, theta=0.0
% INFO    : Bus 79633	: V=0.9976869, theta=-110.354682 -> V=1.0, theta=0.0
% INFO    : Bus 79634	: V=0.9971327, theta=-111.776545 -> V=1.0, theta=0.0
% INFO    : Bus 79635	: V=1.001811, theta=-109.925503 -> V=1.0, theta=0.0
% INFO    : Bus 79636	: V=0.9949143, theta=-111.122592 -> V=1.0, theta=0.0
% INFO    : Bus 79637	: V=0.9980754, theta=-110.091053 -> V=1.0, theta=0.0
% INFO    : Bus 79638	: V=0.9952707, theta=-110.636338 -> V=1.0, theta=0.0
% INFO    : Bus 79639	: V=1.00367, theta=-109.641119 -> V=1.0, theta=0.0
% INFO    : Bus 79640	: V=0.9993655, theta=-110.720597 -> V=1.0, theta=0.0
% INFO    : Bus 79641	: V=0.9926092, theta=-111.475065 -> V=1.0, theta=0.0
% INFO    : Bus 79642	: V=0.9850419, theta=-111.190222 -> V=1.0, theta=0.0
% INFO    : Bus 79643	: V=0.9983704, theta=-110.586807 -> V=1.0, theta=0.0
% INFO    : Bus 79644	: V=1.0025589, theta=-109.820254 -> V=1.0, theta=0.0
% INFO    : Bus 79645	: V=0.9925218, theta=-110.048611 -> V=1.0, theta=0.0
% INFO    : Bus 79646	: V=1.0108509, theta=-108.67136 -> V=1.0, theta=0.0
% INFO    : Bus 79647	: V=1.003998, theta=-109.924703 -> V=1.0, theta=0.0
% INFO    : Bus 79648	: V=1.0033575, theta=-110.218472 -> V=1.0, theta=0.0
% INFO    : Bus 79649	: V=1.0010874, theta=-109.671 -> V=1.0, theta=0.0
% INFO    : Bus 79650	: V=0.9985049, theta=-111.723693 -> V=1.0, theta=0.0
% INFO    : Bus 79651	: V=1.0025677, theta=-110.530025 -> V=1.0, theta=0.0
% INFO    : Bus 79652	: V=1.0020505, theta=-110.169447 -> V=1.0, theta=0.0
% INFO    : Bus 79653	: V=1.0009449, theta=-110.380705 -> V=1.0, theta=0.0
% INFO    : Bus 79654	: V=0.9972752, theta=-111.557357 -> V=1.0, theta=0.0
% INFO    : Bus 79655	: V=0.9952145, theta=-111.923967 -> V=1.0, theta=0.0
% INFO    : Bus 79656	: V=0.9975293, theta=-111.684483 -> V=1.0, theta=0.0
% INFO    : Bus 79657	: V=0.9979106, theta=-111.21757 -> V=1.0, theta=0.0
% INFO    : Bus 79658	: V=0.9923882, theta=-110.993246 -> V=1.0, theta=0.0
% INFO    : Bus 79659	: V=0.9947332, theta=-111.78507 -> V=1.0, theta=0.0
% INFO    : Bus 79660	: V=0.9924417, theta=-110.938821 -> V=1.0, theta=0.0
% INFO    : Bus 79661	: V=0.9939168, theta=-111.107272 -> V=1.0, theta=0.0
% INFO    : Bus 79662	: V=0.9950753, theta=-110.740658 -> V=1.0, theta=0.0
% INFO    : Bus 79663	: V=0.99294, theta=-110.914936 -> V=1.0, theta=0.0
% INFO    : Bus 79664	: V=0.9946723, theta=-110.744017 -> V=1.0, theta=0.0
% INFO    : Bus 79665	: V=1.0001824, theta=-110.292232 -> V=1.0, theta=0.0
% INFO    : Bus 79666	: V=0.9941538, theta=-110.566764 -> V=1.0, theta=0.0
% INFO    : Bus 79667	: V=0.9902246, theta=-110.921929 -> V=1.0, theta=0.0
% INFO    : Bus 79668	: V=0.9900572, theta=-111.062913 -> V=1.0, theta=0.0
% INFO    : Bus 79669	: V=0.9938538, theta=-111.75991 -> V=1.0, theta=0.0
% INFO    : Bus 79670	: V=0.9955471, theta=-111.194382 -> V=1.0, theta=0.0
% INFO    : Bus 79671	: V=0.9949004, theta=-111.449743 -> V=1.0, theta=0.0
% INFO    : Bus 79672	: V=0.9954549, theta=-111.192146 -> V=1.0, theta=0.0
% INFO    : Bus 79673	: V=0.9948959, theta=-111.469485 -> V=1.0, theta=0.0
% INFO    : Bus 79674	: V=0.995295, theta=-111.190859 -> V=1.0, theta=0.0
% INFO    : Bus 79675	: V=0.993644, theta=-111.524445 -> V=1.0, theta=0.0
% INFO    : Bus 79676	: V=0.9944266, theta=-111.6125 -> V=1.0, theta=0.0
% INFO    : Bus 79677	: V=0.9935913, theta=-111.723472 -> V=1.0, theta=0.0
% INFO    : Bus 79678	: V=0.9913507, theta=-111.241464 -> V=1.0, theta=0.0
% INFO    : Bus 79679	: V=0.9937383, theta=-111.621984 -> V=1.0, theta=0.0
% INFO    : Bus 79680	: V=0.9901724, theta=-111.358691 -> V=1.0, theta=0.0
% INFO    : Bus 79681	: V=0.9947083, theta=-111.449952 -> V=1.0, theta=0.0
% INFO    : Bus 79682	: V=0.9948933, theta=-111.387462 -> V=1.0, theta=0.0
% INFO    : Bus 79683	: V=0.9960229, theta=-111.445452 -> V=1.0, theta=0.0
% INFO    : Bus 79684	: V=0.9907948, theta=-111.420786 -> V=1.0, theta=0.0
% INFO    : Bus 79685	: V=1.0017555, theta=-110.54872 -> V=1.0, theta=0.0
% INFO    : Bus 79686	: V=1.0021625, theta=-111.163392 -> V=1.0, theta=0.0
% INFO    : Bus 79687	: V=1.001192, theta=-111.319254 -> V=1.0, theta=0.0
% INFO    : Bus 79688	: V=1.0065539, theta=-109.818129 -> V=1.0, theta=0.0
% INFO    : Bus 79689	: V=1.0031681, theta=-110.598577 -> V=1.0, theta=0.0
% INFO    : Bus 79690	: V=1.0055314, theta=-110.187084 -> V=1.0, theta=0.0
% INFO    : Bus 79691	: V=1.0059019, theta=-110.296446 -> V=1.0, theta=0.0
% INFO    : Bus 79692	: V=1.0015073, theta=-111.232756 -> V=1.0, theta=0.0
% INFO    : Bus 79693	: V=1.0077896, theta=-108.376215 -> V=1.0, theta=0.0
% INFO    : Bus 79694	: V=1.0048143, theta=-108.499702 -> V=1.0, theta=0.0
% INFO    : Bus 79695	: V=1.0069033, theta=-107.306494 -> V=1.0, theta=0.0
% INFO    : Bus 79696	: V=1.0089321, theta=-105.367289 -> V=1.0, theta=0.0
% INFO    : Bus 79697	: V=1.010235, theta=-105.624377 -> V=1.0, theta=0.0
% INFO    : Bus 79698	: V=1.007262, theta=-107.00107 -> V=1.0, theta=0.0
% INFO    : Bus 79699	: V=0.9977724, theta=-110.265578 -> V=1.0, theta=0.0
% INFO    : Bus 79700	: V=1.0005698, theta=-106.400765 -> V=1.0, theta=0.0
% INFO    : Bus 79701	: V=1.0009252, theta=-106.977411 -> V=1.0, theta=0.0
% INFO    : Bus 79702	: V=0.9960798, theta=-110.507343 -> V=1.0, theta=0.0
% INFO    : Bus 79703	: V=0.9964495, theta=-110.551148 -> V=1.0, theta=0.0
% INFO    : Bus 79704	: V=0.9991477, theta=-110.011439 -> V=1.0, theta=0.0
% INFO    : Bus 79705	: V=0.999901, theta=-108.893562 -> V=1.0, theta=0.0
% INFO    : Bus 79706	: V=1.0001399, theta=-109.352343 -> V=1.0, theta=0.0
% INFO    : Bus 79707	: V=1.0089932, theta=-73.205286 -> V=1.0, theta=0.0
% INFO    : Bus 79708	: V=1.0090928, theta=-73.181892 -> V=1.0, theta=0.0
% INFO    : Bus 79709	: V=1.0077603, theta=-73.36335 -> V=1.0, theta=0.0
% INFO    : Bus 79710	: V=1.0061485, theta=-73.489616 -> V=1.0, theta=0.0
% INFO    : Bus 79711	: V=1.0042678, theta=-73.247549 -> V=1.0, theta=0.0
% INFO    : Bus 79712	: V=1.0117547, theta=-72.999582 -> V=1.0, theta=0.0
% INFO    : Bus 79713	: V=1.0105984, theta=-73.024157 -> V=1.0, theta=0.0
% INFO    : Bus 79714	: V=1.0073926, theta=-73.47391 -> V=1.0, theta=0.0
% INFO    : Bus 79715	: V=1.0071153, theta=-73.577815 -> V=1.0, theta=0.0
% INFO    : Bus 79716	: V=1.0031038, theta=-73.415354 -> V=1.0, theta=0.0
% INFO    : Bus 79717	: V=1.0066252, theta=-73.470958 -> V=1.0, theta=0.0
% INFO    : Bus 79718	: V=1.0110375, theta=-72.749637 -> V=1.0, theta=0.0
% INFO    : Bus 79719	: V=1.0089385, theta=-72.347121 -> V=1.0, theta=0.0
% INFO    : Bus 79720	: V=1.0093227, theta=-70.348808 -> V=1.0, theta=0.0
% INFO    : Bus 79721	: V=0.9983846, theta=-67.793447 -> V=1.0, theta=0.0
% INFO    : Bus 79722	: V=1.0031614, theta=-105.525737 -> V=1.0, theta=0.0
% INFO    : Bus 79723	: V=1.0014204, theta=-105.616797 -> V=1.0, theta=0.0
% INFO    : Bus 79724	: V=1.0014031, theta=-105.448301 -> V=1.0, theta=0.0
% INFO    : Bus 79725	: V=1.0011788, theta=-105.546369 -> V=1.0, theta=0.0
% INFO    : Bus 79726	: V=1.0003919, theta=-105.658786 -> V=1.0, theta=0.0
% INFO    : Bus 79727	: V=1.0051976, theta=-105.822586 -> V=1.0, theta=0.0
% INFO    : Bus 79728	: V=1.0024063, theta=-105.789234 -> V=1.0, theta=0.0
% INFO    : Bus 79729	: V=1.0033347, theta=-105.645476 -> V=1.0, theta=0.0
% INFO    : Bus 79730	: V=1.0032675, theta=-105.659811 -> V=1.0, theta=0.0
% INFO    : Bus 79731	: V=1.0042076, theta=-105.741813 -> V=1.0, theta=0.0
% INFO    : Bus 79732	: V=1.0030613, theta=-104.658791 -> V=1.0, theta=0.0
% INFO    : Bus 79733	: V=1.0018283, theta=-104.911745 -> V=1.0, theta=0.0
% INFO    : Bus 79734	: V=1.0026175, theta=-104.814539 -> V=1.0, theta=0.0
% INFO    : Bus 79735	: V=1.0089667, theta=-103.943202 -> V=1.0, theta=0.0
% INFO    : Bus 79736	: V=1.0076294, theta=-104.100124 -> V=1.0, theta=0.0
% INFO    : Bus 79737	: V=1.0081189, theta=-104.002298 -> V=1.0, theta=0.0
% INFO    : Bus 79738	: V=1.0089065, theta=-104.012172 -> V=1.0, theta=0.0
% INFO    : Bus 79739	: V=1.0080866, theta=-104.114446 -> V=1.0, theta=0.0
% INFO    : Bus 79740	: V=1.0071951, theta=-103.299067 -> V=1.0, theta=0.0
% INFO    : Bus 79741	: V=0.9959748, theta=-103.425603 -> V=1.0, theta=0.0
% INFO    : Bus 79742	: V=0.9946558, theta=-100.691717 -> V=1.0, theta=0.0
% INFO    : Bus 79743	: V=0.9963093, theta=-98.898118 -> V=1.0, theta=0.0
% INFO    : Bus 79744	: V=0.9963959, theta=-102.845168 -> V=1.0, theta=0.0
% INFO    : Bus 79745	: V=0.9960271, theta=-100.481277 -> V=1.0, theta=0.0
% INFO    : Bus 79746	: V=0.9960227, theta=-100.069399 -> V=1.0, theta=0.0
% INFO    : Bus 79747	: V=0.9993589, theta=-97.478881 -> V=1.0, theta=0.0
% INFO    : Bus 79748	: V=0.9999793, theta=-97.743654 -> V=1.0, theta=0.0
% INFO    : Bus 79749	: V=0.9965609, theta=-99.016747 -> V=1.0, theta=0.0
% INFO    : Bus 79750	: V=0.9977842, theta=-98.605559 -> V=1.0, theta=0.0
% INFO    : Bus 79751	: V=0.997171, theta=-98.91459 -> V=1.0, theta=0.0
% INFO    : Bus 79752	: V=0.9987082, theta=-96.59181 -> V=1.0, theta=0.0
% INFO    : Bus 79753	: V=0.9990131, theta=-96.611299 -> V=1.0, theta=0.0
% INFO    : Bus 79754	: V=0.9982859, theta=-96.799843 -> V=1.0, theta=0.0
% INFO    : Bus 79755	: V=0.9969533, theta=-97.125148 -> V=1.0, theta=0.0
% INFO    : Bus 79756	: V=0.9991899, theta=-94.333442 -> V=1.0, theta=0.0
% INFO    : Bus 79757	: V=0.9979998, theta=-96.7499 -> V=1.0, theta=0.0
% INFO    : Bus 79758	: V=0.9976351, theta=-97.079918 -> V=1.0, theta=0.0
% INFO    : Bus 79759	: V=0.9956638, theta=-97.490304 -> V=1.0, theta=0.0
% INFO    : Bus 79760	: V=1.0006757, theta=-94.38429 -> V=1.0, theta=0.0
% INFO    : Bus 79761	: V=0.9985349, theta=-107.210393 -> V=1.0, theta=0.0
% INFO    : Bus 79762	: V=1.0006558, theta=-106.421338 -> V=1.0, theta=0.0
% INFO    : Bus 79763	: V=1.0040592, theta=-107.301357 -> V=1.0, theta=0.0
% INFO    : Bus 79764	: V=1.0102165, theta=-107.499926 -> V=1.0, theta=0.0
% INFO    : Bus 79765	: V=1.0055807, theta=-107.372889 -> V=1.0, theta=0.0
% INFO    : Bus 79766	: V=1.0048591, theta=-106.890067 -> V=1.0, theta=0.0
% INFO    : Bus 79767	: V=1.0052862, theta=-107.188026 -> V=1.0, theta=0.0
% INFO    : Bus 79768	: V=1.0049796, theta=-106.325525 -> V=1.0, theta=0.0
% INFO    : Bus 79769	: V=1.0070289, theta=-106.340211 -> V=1.0, theta=0.0
% INFO    : Bus 79770	: V=1.0070432, theta=-106.497759 -> V=1.0, theta=0.0
% INFO    : Bus 79771	: V=1.006937, theta=-106.255897 -> V=1.0, theta=0.0
% INFO    : Bus 79772	: V=1.0076291, theta=-106.411391 -> V=1.0, theta=0.0
% INFO    : Bus 79773	: V=1.0049082, theta=-105.81565 -> V=1.0, theta=0.0
% INFO    : Bus 79774	: V=1.0032861, theta=-106.294275 -> V=1.0, theta=0.0
% INFO    : Bus 79775	: V=1.0105125, theta=-91.457521 -> V=1.0, theta=0.0
% INFO    : Bus 79776	: V=1.0107601, theta=-91.205429 -> V=1.0, theta=0.0
% INFO    : Bus 79777	: V=1.0097473, theta=-88.818399 -> V=1.0, theta=0.0
% INFO    : Bus 79778	: V=1.0064491, theta=-95.482516 -> V=1.0, theta=0.0
% INFO    : Bus 79779	: V=1.0105195, theta=-76.188263 -> V=1.0, theta=0.0
% INFO    : Bus 79780	: V=1.0128786, theta=-78.631085 -> V=1.0, theta=0.0
% INFO    : Bus 79781	: V=1.030484, theta=-81.087063 -> V=1.0, theta=0.0
% INFO    : Bus 79782	: V=1.0051584, theta=-72.723653 -> V=1.0, theta=0.0
% INFO    : Bus 79783	: V=1.0044798, theta=-76.250879 -> V=1.0, theta=0.0
% INFO    : Bus 79784	: V=0.985866, theta=-80.269348 -> V=1.0, theta=0.0
% INFO    : Bus 79785	: V=0.9865036, theta=-90.661774 -> V=1.0, theta=0.0
% INFO    : Bus 79786	: V=0.9841776, theta=-90.436396 -> V=1.0, theta=0.0
% INFO    : Bus 79787	: V=0.9954073, theta=-88.988777 -> V=1.0, theta=0.0
% INFO    : Bus 79788	: V=0.9879414, theta=-89.388581 -> V=1.0, theta=0.0
% INFO    : Bus 79789	: V=0.9866053, theta=-89.639194 -> V=1.0, theta=0.0
% INFO    : Bus 79790	: V=0.9657449, theta=-87.660708 -> V=1.0, theta=0.0
% INFO    : Bus 79791	: V=0.9757763, theta=-90.076072 -> V=1.0, theta=0.0
% INFO    : Bus 79792	: V=0.9670005, theta=-88.597058 -> V=1.0, theta=0.0
% INFO    : Bus 79793	: V=0.9654945, theta=-88.784319 -> V=1.0, theta=0.0
% INFO    : Bus 79794	: V=0.9843351, theta=-88.403675 -> V=1.0, theta=0.0
% INFO    : Bus 79795	: V=0.9771876, theta=-89.45902 -> V=1.0, theta=0.0
% INFO    : Bus 79796	: V=0.9810161, theta=-85.398899 -> V=1.0, theta=0.0
% INFO    : Bus 79797	: V=0.9797961, theta=-86.11379 -> V=1.0, theta=0.0
% INFO    : Bus 79798	: V=0.9831183, theta=-83.510162 -> V=1.0, theta=0.0
% INFO    : Bus 79799	: V=0.9897055, theta=-84.762778 -> V=1.0, theta=0.0
% INFO    : Bus 79800	: V=0.9887054, theta=-84.771902 -> V=1.0, theta=0.0
% INFO    : Bus 79801	: V=0.9919794, theta=-84.744259 -> V=1.0, theta=0.0
% INFO    : Bus 79802	: V=0.9942536, theta=-84.597808 -> V=1.0, theta=0.0
% INFO    : Bus 79803	: V=0.994992, theta=-84.5588 -> V=1.0, theta=0.0
% INFO    : Bus 79804	: V=0.9923545, theta=-84.660612 -> V=1.0, theta=0.0
% INFO    : Bus 79805	: V=1.0007153, theta=-84.093659 -> V=1.0, theta=0.0
% INFO    : Bus 79806	: V=0.9928079, theta=-84.521127 -> V=1.0, theta=0.0
% INFO    : Bus 79807	: V=0.9949464, theta=-84.319304 -> V=1.0, theta=0.0
% INFO    : Bus 79808	: V=1.0072817, theta=-83.836967 -> V=1.0, theta=0.0
% INFO    : Bus 79809	: V=1.0073941, theta=-83.948324 -> V=1.0, theta=0.0
% INFO    : Bus 79810	: V=0.9989046, theta=-84.066549 -> V=1.0, theta=0.0
% INFO    : Bus 79811	: V=0.998134, theta=-83.958664 -> V=1.0, theta=0.0
% INFO    : Bus 79812	: V=1.0043078, theta=-84.018333 -> V=1.0, theta=0.0
% INFO    : Bus 79813	: V=1.0011913, theta=-83.976934 -> V=1.0, theta=0.0
% INFO    : Bus 79814	: V=1.0019595, theta=-83.930493 -> V=1.0, theta=0.0
% INFO    : Bus 79815	: V=0.9911558, theta=-84.725199 -> V=1.0, theta=0.0
% INFO    : Bus 79816	: V=0.9906173, theta=-84.728916 -> V=1.0, theta=0.0
% INFO    : Bus 79817	: V=0.9935239, theta=-84.173465 -> V=1.0, theta=0.0
% INFO    : Bus 79818	: V=0.9947107, theta=-84.36224 -> V=1.0, theta=0.0
% INFO    : Bus 79819	: V=1.0022482, theta=-83.759594 -> V=1.0, theta=0.0
% INFO    : Bus 79820	: V=0.9983327, theta=-84.095926 -> V=1.0, theta=0.0
% INFO    : Bus 79821	: V=1.001476, theta=-83.859156 -> V=1.0, theta=0.0
% INFO    : Bus 79822	: V=0.9986827, theta=-84.140347 -> V=1.0, theta=0.0
% INFO    : Bus 79823	: V=0.9967686, theta=-84.226618 -> V=1.0, theta=0.0
% INFO    : Bus 79824	: V=0.9957376, theta=-83.988708 -> V=1.0, theta=0.0
% INFO    : Bus 79825	: V=0.9991551, theta=-84.010738 -> V=1.0, theta=0.0
% INFO    : Bus 79826	: V=0.9942693, theta=-84.07929 -> V=1.0, theta=0.0
% INFO    : Bus 79827	: V=1.0126013, theta=-82.961566 -> V=1.0, theta=0.0
% INFO    : Bus 79828	: V=1.0051813, theta=-83.540332 -> V=1.0, theta=0.0
% INFO    : Bus 79829	: V=0.9989836, theta=-84.023022 -> V=1.0, theta=0.0
% INFO    : Bus 79830	: V=0.9973934, theta=-84.099972 -> V=1.0, theta=0.0
% INFO    : Bus 79831	: V=0.9980589, theta=-84.100975 -> V=1.0, theta=0.0
% INFO    : Bus 79832	: V=0.9956504, theta=-84.135474 -> V=1.0, theta=0.0
% INFO    : Bus 79833	: V=1.0033179, theta=-83.667413 -> V=1.0, theta=0.0
% INFO    : Bus 79834	: V=0.9971907, theta=-84.101237 -> V=1.0, theta=0.0
% INFO    : Bus 79835	: V=0.9981977, theta=-84.057659 -> V=1.0, theta=0.0
% INFO    : Bus 79836	: V=0.9965266, theta=-84.057326 -> V=1.0, theta=0.0
% INFO    : Bus 79837	: V=1.0036356, theta=-83.466066 -> V=1.0, theta=0.0
% INFO    : Bus 79838	: V=0.9993498, theta=-83.880221 -> V=1.0, theta=0.0
% INFO    : Bus 79839	: V=0.9962127, theta=-84.137768 -> V=1.0, theta=0.0
% INFO    : Bus 79840	: V=0.9970028, theta=-84.173778 -> V=1.0, theta=0.0
% INFO    : Bus 79841	: V=0.9945277, theta=-83.999527 -> V=1.0, theta=0.0
% INFO    : Bus 79842	: V=0.995165, theta=-83.944979 -> V=1.0, theta=0.0
% INFO    : Bus 79843	: V=0.9959075, theta=-83.92725 -> V=1.0, theta=0.0
% INFO    : Bus 79844	: V=0.9979198, theta=-83.94309 -> V=1.0, theta=0.0
% INFO    : Bus 79845	: V=0.9955203, theta=-84.120657 -> V=1.0, theta=0.0
% INFO    : Bus 79846	: V=1.0029266, theta=-99.838741 -> V=1.0, theta=0.0
% INFO    : Bus 79847	: V=1.0085975, theta=-99.254443 -> V=1.0, theta=0.0
% INFO    : Bus 79848	: V=1.008451, theta=-99.826096 -> V=1.0, theta=0.0
% INFO    : Bus 79849	: V=1.0090225, theta=-99.485086 -> V=1.0, theta=0.0
% INFO    : Bus 79850	: V=1.0090506, theta=-99.977233 -> V=1.0, theta=0.0
% INFO    : Bus 79851	: V=1.0079525, theta=-100.536375 -> V=1.0, theta=0.0
% INFO    : Bus 79852	: V=1.0022398, theta=-101.505154 -> V=1.0, theta=0.0
% INFO    : Bus 79853	: V=1.004105, theta=-99.827561 -> V=1.0, theta=0.0
% INFO    : Bus 79854	: V=1.0009803, theta=-99.554629 -> V=1.0, theta=0.0
% INFO    : Bus 79855	: V=1.00427, theta=-99.73828 -> V=1.0, theta=0.0
% INFO    : Bus 79856	: V=1.0013031, theta=-96.453703 -> V=1.0, theta=0.0
% INFO    : Bus 79857	: V=1.0104542, theta=-91.218492 -> V=1.0, theta=0.0
% INFO    : Bus 79858	: V=1.0095956, theta=-91.656785 -> V=1.0, theta=0.0
% INFO    : Bus 79859	: V=1.0090212, theta=-91.632842 -> V=1.0, theta=0.0
% INFO    : Bus 79860	: V=1.0094243, theta=-93.078038 -> V=1.0, theta=0.0
% INFO    : Bus 79861	: V=1.0083869, theta=-87.606421 -> V=1.0, theta=0.0
% INFO    : Bus 79862	: V=1.0300003, theta=-41.645083 -> V=1.0, theta=0.0
% INFO    : Bus 79863	: V=1.0000003, theta=-33.597129 -> V=1.0, theta=0.0
% INFO    : Bus 79865	: V=1.0300002, theta=38.687694 -> V=1.0, theta=0.0
% INFO    : Bus 79866	: V=1.0178734, theta=-43.125293 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 58576	: Pg=108.0, Qg=-59.5 -> Pg=108.0, Qg=0.0
% INFO    : Gen at bus 58576	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58577	: Pg=89.26, Qg=-38.6 -> Pg=102.35, Qg=16.55
% INFO    : Gen at bus 58577	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58578	: Pg=21.64, Qg=-35.2 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 58578	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58578	: Pg=21.64, Qg=-35.2 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 58578	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58578	: Pg=21.64, Qg=-35.2 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 58578	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58578	: Pg=21.64, Qg=-35.2 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 58578	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58580	: Pg=105.0, Qg=-34.5 -> Pg=105.0, Qg=0.0
% INFO    : Gen at bus 58580	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58580	: Pg=105.0, Qg=-34.5 -> Pg=105.0, Qg=0.0
% INFO    : Gen at bus 58580	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58580	: Pg=105.0, Qg=-34.5 -> Pg=105.0, Qg=0.0
% INFO    : Gen at bus 58580	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58580	: Pg=105.0, Qg=-34.5 -> Pg=105.0, Qg=0.0
% INFO    : Gen at bus 58580	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58580	: Pg=105.0, Qg=-34.5 -> Pg=105.0, Qg=0.0
% INFO    : Gen at bus 58580	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58581	: Pg=82.8, Qg=-45.6 -> Pg=82.8, Qg=0.0
% INFO    : Gen at bus 58581	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58582	: Pg=46.3, Qg=-30.3 -> Pg=68.55, Qg=13.05
% INFO    : Gen at bus 58582	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=10.13, Qg=0.58 -> Pg=33.55, Qg=4.35
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=12.42, Qg=0.58 -> Pg=7.365, Qg=1.53
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=12.42, Qg=0.58 -> Pg=7.365, Qg=1.53
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=12.42, Qg=0.58 -> Pg=7.365, Qg=1.53
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=12.42, Qg=0.58 -> Pg=7.365, Qg=1.53
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=12.42, Qg=0.58 -> Pg=7.365, Qg=1.53
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=12.42, Qg=0.58 -> Pg=7.365, Qg=1.53
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58583	: Pg=12.42, Qg=0.58 -> Pg=7.365, Qg=1.53
% INFO    : Gen at bus 58583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58584	: Pg=40.25, Qg=-11.53 -> Pg=77.0, Qg=0.0
% INFO    : Gen at bus 58584	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58584	: Pg=30.17, Qg=-11.53 -> Pg=53.4, Qg=5.8
% INFO    : Gen at bus 58584	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58584	: Pg=30.25, Qg=-11.53 -> Pg=71.9, Qg=8.6
% INFO    : Gen at bus 58584	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58584	: Pg=30.25, Qg=-11.53 -> Pg=71.95, Qg=8.6
% INFO    : Gen at bus 58584	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58584	: Pg=30.25, Qg=-11.53 -> Pg=71.95, Qg=8.6
% INFO    : Gen at bus 58584	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58585	: Pg=22.15, Qg=-15.14 -> Pg=45.0, Qg=5.1
% INFO    : Gen at bus 58585	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58586	: Pg=12.64, Qg=-13.44 -> Pg=31.25, Qg=0.0
% INFO    : Gen at bus 58586	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58586	: Pg=12.64, Qg=-13.44 -> Pg=31.25, Qg=0.0
% INFO    : Gen at bus 58586	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58586	: Pg=12.64, Qg=-13.44 -> Pg=31.25, Qg=0.0
% INFO    : Gen at bus 58586	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58586	: Pg=12.64, Qg=-13.44 -> Pg=31.25, Qg=0.0
% INFO    : Gen at bus 58586	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58587	: Pg=2.01, Qg=2.14 -> Pg=4.05, Qg=1.275
% INFO    : Gen at bus 58587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58589	: Pg=10.99, Qg=-7.52 -> Pg=25.7, Qg=3.8
% INFO    : Gen at bus 58589	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58589	: Pg=29.0, Qg=-7.52 -> Pg=35.8, Qg=5.35
% INFO    : Gen at bus 58589	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58589	: Pg=35.43, Qg=-7.52 -> Pg=43.8, Qg=6.5
% INFO    : Gen at bus 58589	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58590	: Pg=19.11, Qg=-10.2 -> Pg=34.5, Qg=0.0
% INFO    : Gen at bus 58590	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58592	: Pg=23.1, Qg=-15.4 -> Pg=34.55, Qg=3.45
% INFO    : Gen at bus 58592	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58593	: Pg=8.09, Qg=-13.1 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 58593	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58593	: Pg=8.09, Qg=-13.1 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 58593	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58593	: Pg=8.8, Qg=-14.3 -> Pg=21.75, Qg=0.0
% INFO    : Gen at bus 58593	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58593	: Pg=8.8, Qg=-14.3 -> Pg=21.75, Qg=0.0
% INFO    : Gen at bus 58593	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58594	: Pg=9.59, Qg=-3.2 -> Pg=5.3, Qg=2.0
% INFO    : Gen at bus 58594	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58594	: Pg=9.59, Qg=-3.2 -> Pg=5.3, Qg=2.0
% INFO    : Gen at bus 58594	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58594	: Pg=9.59, Qg=-3.2 -> Pg=5.3, Qg=2.0
% INFO    : Gen at bus 58594	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58594	: Pg=9.59, Qg=-3.2 -> Pg=5.3, Qg=2.0
% INFO    : Gen at bus 58594	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58595	: Pg=4.57, Qg=-2.01 -> Pg=3.11, Qg=0.0
% INFO    : Gen at bus 58595	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58598	: Pg=24.0, Qg=-11.9 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 58598	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58599	: Pg=7.99, Qg=-2.67 -> Pg=4.5, Qg=1.665
% INFO    : Gen at bus 58599	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58599	: Pg=7.99, Qg=-2.67 -> Pg=4.5, Qg=1.665
% INFO    : Gen at bus 58599	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58599	: Pg=7.99, Qg=-2.67 -> Pg=4.5, Qg=1.665
% INFO    : Gen at bus 58599	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=29.19, Qg=6.27 -> Pg=57.5, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=24.97, Qg=6.27 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=25.0, Qg=6.27 -> Pg=57.25, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58601	: Pg=75.71, Qg=6.27 -> Pg=50.56, Qg=0.0
% INFO    : Gen at bus 58601	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.32, Qg=11.75 -> Pg=33.35, Qg=4.05
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.34, Qg=11.75 -> Pg=37.65, Qg=4.7
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=58.01, Qg=11.75 -> Pg=37.645, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=23.35, Qg=11.75 -> Pg=44.85, Qg=0.0
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58602	: Pg=13.32, Qg=11.75 -> Pg=33.35, Qg=4.05
% INFO    : Gen at bus 58602	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58603	: Pg=641.24, Qg=17.26 -> Pg=366.1, Qg=0.0
% INFO    : Gen at bus 58603	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58604	: Pg=94.88, Qg=-57.0 -> Pg=132.75, Qg=12.9
% INFO    : Gen at bus 58604	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58604	: Pg=159.69, Qg=-104.0 -> Pg=235.5, Qg=23.55
% INFO    : Gen at bus 58604	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58605	: Pg=90.59, Qg=-21.12 -> Pg=177.2, Qg=37.9
% INFO    : Gen at bus 58605	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58605	: Pg=80.47, Qg=-21.12 -> Pg=146.25, Qg=30.45
% INFO    : Gen at bus 58605	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58605	: Pg=80.47, Qg=-21.12 -> Pg=146.25, Qg=30.45
% INFO    : Gen at bus 58605	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58606	: Pg=99.45, Qg=-4.97 -> Pg=151.75, Qg=0.0
% INFO    : Gen at bus 58606	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58606	: Pg=99.45, Qg=-4.97 -> Pg=151.75, Qg=0.0
% INFO    : Gen at bus 58606	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58606	: Pg=65.24, Qg=-4.97 -> Pg=85.55, Qg=0.0
% INFO    : Gen at bus 58606	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58606	: Pg=65.24, Qg=-4.97 -> Pg=85.55, Qg=0.0
% INFO    : Gen at bus 58606	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58607	: Pg=90.41, Qg=2.48 -> Pg=137.85, Qg=0.0
% INFO    : Gen at bus 58607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58607	: Pg=48.18, Qg=2.48 -> Pg=64.3, Qg=0.0
% INFO    : Gen at bus 58607	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58608	: Pg=102.38, Qg=2.48 -> Pg=127.5, Qg=24.35
% INFO    : Gen at bus 58608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58608	: Pg=67.26, Qg=2.48 -> Pg=92.0, Qg=8.85
% INFO    : Gen at bus 58608	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58609	: Pg=118.96, Qg=45.58 -> Pg=125.75, Qg=23.15
% INFO    : Gen at bus 58609	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58609	: Pg=118.96, Qg=45.58 -> Pg=125.75, Qg=23.15
% INFO    : Gen at bus 58609	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58609	: Pg=101.8, Qg=45.58 -> Pg=114.25, Qg=25.55
% INFO    : Gen at bus 58609	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58610	: Pg=52.3, Qg=9.75 -> Pg=93.5, Qg=0.0
% INFO    : Gen at bus 58610	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58611	: Pg=26.39, Qg=-18.12 -> Pg=65.25, Qg=9.85
% INFO    : Gen at bus 58611	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58611	: Pg=26.39, Qg=-18.12 -> Pg=65.25, Qg=9.85
% INFO    : Gen at bus 58611	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58611	: Pg=26.39, Qg=-18.12 -> Pg=65.25, Qg=9.85
% INFO    : Gen at bus 58611	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58614	: Pg=23.55, Qg=12.62 -> Pg=56.75, Qg=8.5
% INFO    : Gen at bus 58614	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58614	: Pg=27.09, Qg=12.62 -> Pg=65.5, Qg=9.85
% INFO    : Gen at bus 58614	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58614	: Pg=27.09, Qg=12.62 -> Pg=65.5, Qg=9.85
% INFO    : Gen at bus 58614	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58615	: Pg=86.4, Qg=-12.89 -> Pg=86.4, Qg=0.0
% INFO    : Gen at bus 58615	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58616	: Pg=41.32, Qg=-33.44 -> Pg=41.32, Qg=0.0
% INFO    : Gen at bus 58616	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58617	: Pg=40.28, Qg=-39.65 -> Pg=40.28, Qg=0.0
% INFO    : Gen at bus 58617	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58618	: Pg=80.4, Qg=22.57 -> Pg=80.4, Qg=7.6
% INFO    : Gen at bus 58618	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58619	: Pg=41.52, Qg=-18.08 -> Pg=41.52, Qg=0.0
% INFO    : Gen at bus 58619	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58620	: Pg=39.48, Qg=-7.56 -> Pg=39.48, Qg=0.0
% INFO    : Gen at bus 58620	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58621	: Pg=78.96, Qg=-6.33 -> Pg=78.96, Qg=0.0
% INFO    : Gen at bus 58621	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58622	: Pg=77.6, Qg=-42.8 -> Pg=77.6, Qg=0.0
% INFO    : Gen at bus 58622	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58624	: Pg=30.0, Qg=-2.16 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 58624	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58625	: Pg=28.8, Qg=-11.43 -> Pg=28.8, Qg=0.0
% INFO    : Gen at bus 58625	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.98, Qg=0.25 -> Pg=52.15, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58626	: Pg=23.96, Qg=0.25 -> Pg=46.9, Qg=0.0
% INFO    : Gen at bus 58626	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58627	: Pg=110.23, Qg=13.3 -> Pg=93.2, Qg=13.3
% INFO    : Gen at bus 58627	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58627	: Pg=5.15, Qg=13.3 -> Pg=36.65, Qg=5.15
% INFO    : Gen at bus 58627	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58627	: Pg=5.15, Qg=13.3 -> Pg=36.65, Qg=5.15
% INFO    : Gen at bus 58627	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58627	: Pg=5.15, Qg=13.3 -> Pg=36.65, Qg=5.15
% INFO    : Gen at bus 58627	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58627	: Pg=5.15, Qg=13.3 -> Pg=36.65, Qg=5.15
% INFO    : Gen at bus 58627	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58627	: Pg=5.15, Qg=13.3 -> Pg=36.65, Qg=5.15
% INFO    : Gen at bus 58627	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58627	: Pg=5.15, Qg=13.3 -> Pg=36.65, Qg=5.15
% INFO    : Gen at bus 58627	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58628	: Pg=3.41, Qg=12.2 -> Pg=9.815, Qg=12.2
% INFO    : Gen at bus 58628	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 58628	: Pg=3.41, Qg=12.2 -> Pg=9.815, Qg=12.2
% INFO    : Gen at bus 58628	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 58628	: Pg=3.41, Qg=12.2 -> Pg=9.815, Qg=12.2
% INFO    : Gen at bus 58628	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 58628	: Pg=3.41, Qg=12.2 -> Pg=9.815, Qg=12.2
% INFO    : Gen at bus 58628	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 58628	: Pg=8.09, Qg=30.0 -> Pg=24.0, Qg=30.0
% INFO    : Gen at bus 58628	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 58629	: Pg=12.12, Qg=17.2 -> Pg=32.1, Qg=17.2
% INFO    : Gen at bus 58629	: Vg=1.0159 -> Vg=1.0
% INFO    : Gen at bus 58629	: Pg=12.12, Qg=17.2 -> Pg=32.1, Qg=17.2
% INFO    : Gen at bus 58629	: Vg=1.0159 -> Vg=1.0
% INFO    : Gen at bus 58631	: Pg=50.0, Qg=-5.16 -> Pg=50.0, Qg=3.75
% INFO    : Gen at bus 58631	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58631	: Pg=50.0, Qg=-5.16 -> Pg=50.0, Qg=3.75
% INFO    : Gen at bus 58631	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58632	: Pg=19.47, Qg=-7.56 -> Pg=24.2, Qg=0.0
% INFO    : Gen at bus 58632	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58632	: Pg=20.23, Qg=-7.56 -> Pg=25.15, Qg=0.0
% INFO    : Gen at bus 58632	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58634	: Pg=2.1, Qg=19.5 -> Pg=22.4, Qg=19.5
% INFO    : Gen at bus 58634	: Vg=0.9854 -> Vg=1.0
% INFO    : Gen at bus 58635	: Pg=14.18, Qg=8.8 -> Pg=7.1, Qg=8.8
% INFO    : Gen at bus 58635	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 58635	: Pg=14.18, Qg=8.8 -> Pg=7.1, Qg=8.8
% INFO    : Gen at bus 58635	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 58635	: Pg=14.18, Qg=8.8 -> Pg=7.1, Qg=8.8
% INFO    : Gen at bus 58635	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 58636	: Pg=16.8, Qg=-4.07 -> Pg=16.8, Qg=0.0
% INFO    : Gen at bus 58636	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58636	: Pg=25.6, Qg=-4.07 -> Pg=25.6, Qg=0.0
% INFO    : Gen at bus 58636	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58637	: Pg=5.36, Qg=10.0 -> Pg=9.33, Qg=10.0
% INFO    : Gen at bus 58637	: Vg=1.0067 -> Vg=1.0
% INFO    : Gen at bus 58637	: Pg=5.36, Qg=10.0 -> Pg=9.33, Qg=10.0
% INFO    : Gen at bus 58637	: Vg=1.0067 -> Vg=1.0
% INFO    : Gen at bus 58637	: Pg=5.36, Qg=10.0 -> Pg=9.33, Qg=10.0
% INFO    : Gen at bus 58637	: Vg=1.0067 -> Vg=1.0
% INFO    : Gen at bus 58638	: Pg=40.0, Qg=13.1 -> Pg=40.0, Qg=13.1
% INFO    : Gen at bus 58638	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 58638	: Pg=40.0, Qg=13.1 -> Pg=40.0, Qg=13.1
% INFO    : Gen at bus 58638	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 58639	: Pg=40.0, Qg=13.1 -> Pg=40.0, Qg=13.1
% INFO    : Gen at bus 58639	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 58639	: Pg=40.0, Qg=13.1 -> Pg=40.0, Qg=13.1
% INFO    : Gen at bus 58639	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 58639	: Pg=40.0, Qg=13.1 -> Pg=40.0, Qg=13.1
% INFO    : Gen at bus 58639	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 58640	: Pg=15.49, Qg=12.7 -> Pg=19.25, Qg=12.7
% INFO    : Gen at bus 58640	: Vg=1.0148 -> Vg=1.0
% INFO    : Gen at bus 58641	: Pg=2.04, Qg=4.65 -> Pg=10.325, Qg=4.65
% INFO    : Gen at bus 58641	: Vg=0.976 -> Vg=1.0
% INFO    : Gen at bus 58641	: Pg=2.04, Qg=4.65 -> Pg=10.325, Qg=4.65
% INFO    : Gen at bus 58641	: Vg=0.976 -> Vg=1.0
% INFO    : Gen at bus 58642	: Pg=6.09, Qg=3.85 -> Pg=4.385, Qg=3.85
% INFO    : Gen at bus 58642	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 58642	: Pg=6.09, Qg=3.85 -> Pg=4.385, Qg=3.85
% INFO    : Gen at bus 58642	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 58642	: Pg=6.09, Qg=3.85 -> Pg=4.385, Qg=3.85
% INFO    : Gen at bus 58642	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 58642	: Pg=6.09, Qg=3.85 -> Pg=4.385, Qg=3.85
% INFO    : Gen at bus 58642	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 58642	: Pg=6.09, Qg=3.85 -> Pg=4.385, Qg=3.85
% INFO    : Gen at bus 58642	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 58642	: Pg=6.09, Qg=3.85 -> Pg=4.385, Qg=3.85
% INFO    : Gen at bus 58642	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 58643	: Pg=4.08, Qg=22.3 -> Pg=20.0, Qg=22.3
% INFO    : Gen at bus 58643	: Vg=1.0146 -> Vg=1.0
% INFO    : Gen at bus 58644	: Pg=10.07, Qg=15.7 -> Pg=21.2, Qg=15.7
% INFO    : Gen at bus 58644	: Vg=1.0126 -> Vg=1.0
% INFO    : Gen at bus 58644	: Pg=10.07, Qg=15.7 -> Pg=21.2, Qg=15.7
% INFO    : Gen at bus 58644	: Vg=1.0126 -> Vg=1.0
% INFO    : Gen at bus 58644	: Pg=10.1, Qg=21.8 -> Pg=27.5, Qg=21.8
% INFO    : Gen at bus 58644	: Vg=1.0126 -> Vg=1.0
% INFO    : Gen at bus 58645	: Pg=12.84, Qg=-5.35 -> Pg=8.0, Qg=3.325
% INFO    : Gen at bus 58645	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58645	: Pg=12.84, Qg=-5.35 -> Pg=8.0, Qg=3.325
% INFO    : Gen at bus 58645	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58646	: Pg=15.0, Qg=-2.84 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 58646	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58646	: Pg=15.0, Qg=-2.84 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 58646	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58647	: Pg=29.36, Qg=-5.77 -> Pg=18.7, Qg=4.2
% INFO    : Gen at bus 58647	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58647	: Pg=29.36, Qg=-5.77 -> Pg=18.7, Qg=4.2
% INFO    : Gen at bus 58647	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58647	: Pg=29.36, Qg=-5.77 -> Pg=18.7, Qg=4.2
% INFO    : Gen at bus 58647	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58647	: Pg=29.36, Qg=-5.77 -> Pg=18.7, Qg=4.2
% INFO    : Gen at bus 58647	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58648	: Pg=12.53, Qg=4.25 -> Pg=12.75, Qg=4.25
% INFO    : Gen at bus 58648	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 58648	: Pg=12.53, Qg=4.25 -> Pg=12.75, Qg=4.25
% INFO    : Gen at bus 58648	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 58649	: Pg=15.66, Qg=16.1 -> Pg=13.0, Qg=16.1
% INFO    : Gen at bus 58649	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 58650	: Pg=8.36, Qg=-6.09 -> Pg=14.75, Qg=3.65
% INFO    : Gen at bus 58650	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58650	: Pg=8.36, Qg=-6.09 -> Pg=14.75, Qg=3.65
% INFO    : Gen at bus 58650	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58651	: Pg=10.48, Qg=-9.9 -> Pg=10.48, Qg=0.0
% INFO    : Gen at bus 58651	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58652	: Pg=19.68, Qg=-9.7 -> Pg=19.68, Qg=0.0
% INFO    : Gen at bus 58652	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58652	: Pg=20.16, Qg=-10.0 -> Pg=20.16, Qg=0.0
% INFO    : Gen at bus 58652	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58653	: Pg=24.45, Qg=8.1 -> Pg=24.45, Qg=8.1
% INFO    : Gen at bus 58653	: Vg=1.0223 -> Vg=1.0
% INFO    : Gen at bus 58653	: Pg=24.45, Qg=8.1 -> Pg=24.45, Qg=8.1
% INFO    : Gen at bus 58653	: Vg=1.0223 -> Vg=1.0
% INFO    : Gen at bus 58654	: Pg=9.8, Qg=-9.7 -> Pg=9.8, Qg=0.0
% INFO    : Gen at bus 58654	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58655	: Pg=12.05, Qg=-7.8 -> Pg=17.85, Qg=0.0
% INFO    : Gen at bus 58655	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58656	: Pg=11.09, Qg=10.5 -> Pg=12.8, Qg=10.5
% INFO    : Gen at bus 58656	: Vg=1.0111 -> Vg=1.0
% INFO    : Gen at bus 58657	: Pg=0.55, Qg=13.0 -> Pg=10.75, Qg=13.0
% INFO    : Gen at bus 58657	: Vg=1.0038 -> Vg=1.0
% INFO    : Gen at bus 58658	: Pg=10.0, Qg=-1.21 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 58658	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58658	: Pg=10.0, Qg=-1.21 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 58658	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=121.33, Qg=29.16 -> Pg=300.0, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=121.33, Qg=29.16 -> Pg=300.0, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=121.33, Qg=29.16 -> Pg=300.0, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=162.79, Qg=29.16 -> Pg=402.5, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=162.79, Qg=29.16 -> Pg=402.5, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=162.79, Qg=29.16 -> Pg=402.5, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58659	: Pg=240.2, Qg=29.16 -> Pg=120.28, Qg=0.0
% INFO    : Gen at bus 58659	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58660	: Pg=1200.0, Qg=-28.82 -> Pg=660.0, Qg=0.0
% INFO    : Gen at bus 58660	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58661	: Pg=28.93, Qg=9.43 -> Pg=44.65, Qg=8.65
% INFO    : Gen at bus 58661	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58661	: Pg=28.93, Qg=9.43 -> Pg=44.65, Qg=8.65
% INFO    : Gen at bus 58661	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58661	: Pg=28.93, Qg=9.43 -> Pg=44.65, Qg=8.65
% INFO    : Gen at bus 58661	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58661	: Pg=28.93, Qg=9.43 -> Pg=44.65, Qg=8.65
% INFO    : Gen at bus 58661	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58661	: Pg=728.81, Qg=9.43 -> Pg=489.95, Qg=0.0
% INFO    : Gen at bus 58661	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58661	: Pg=728.81, Qg=9.43 -> Pg=482.45, Qg=0.0
% INFO    : Gen at bus 58661	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58661	: Pg=42.58, Qg=9.43 -> Pg=61.2, Qg=11.45
% INFO    : Gen at bus 58661	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58664	: Pg=100.51, Qg=1.21 -> Pg=165.0, Qg=32.9
% INFO    : Gen at bus 58664	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58664	: Pg=100.52, Qg=1.21 -> Pg=167.0, Qg=33.5
% INFO    : Gen at bus 58664	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58664	: Pg=100.52, Qg=1.21 -> Pg=167.0, Qg=33.5
% INFO    : Gen at bus 58664	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58665	: Pg=151.73, Qg=-38.64 -> Pg=151.73, Qg=15.4
% INFO    : Gen at bus 58665	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58666	: Pg=111.44, Qg=-35.5 -> Pg=111.44, Qg=15.05
% INFO    : Gen at bus 58666	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58667	: Pg=95.43, Qg=119.0 -> Pg=143.5, Qg=119.0
% INFO    : Gen at bus 58667	: Vg=1.0201 -> Vg=1.0
% INFO    : Gen at bus 58667	: Pg=65.28, Qg=41.5 -> Pg=95.65, Qg=41.5
% INFO    : Gen at bus 58667	: Vg=1.0201 -> Vg=1.0
% INFO    : Gen at bus 58668	: Pg=125.41, Qg=0.0 -> Pg=155.5, Qg=0.0
% INFO    : Gen at bus 58668	: Vg=1.0107 -> Vg=1.0
% INFO    : Gen at bus 58668	: Pg=65.3, Qg=0.0 -> Pg=99.0, Qg=0.0
% INFO    : Gen at bus 58668	: Vg=1.0107 -> Vg=1.0
% INFO    : Gen at bus 58670	: Pg=100.39, Qg=38.45 -> Pg=137.5, Qg=25.1
% INFO    : Gen at bus 58670	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58670	: Pg=100.39, Qg=38.45 -> Pg=137.5, Qg=25.1
% INFO    : Gen at bus 58670	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58670	: Pg=100.67, Qg=38.45 -> Pg=200.0, Qg=42.95
% INFO    : Gen at bus 58670	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58672	: Pg=32.03, Qg=-1.82 -> Pg=79.2, Qg=0.0
% INFO    : Gen at bus 58672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58672	: Pg=32.03, Qg=-1.82 -> Pg=79.2, Qg=0.0
% INFO    : Gen at bus 58672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58672	: Pg=32.66, Qg=-1.82 -> Pg=80.75, Qg=0.0
% INFO    : Gen at bus 58672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58672	: Pg=32.66, Qg=-1.82 -> Pg=80.75, Qg=0.0
% INFO    : Gen at bus 58672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58672	: Pg=48.41, Qg=-1.82 -> Pg=119.7, Qg=0.0
% INFO    : Gen at bus 58672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58672	: Pg=48.41, Qg=-1.82 -> Pg=119.7, Qg=0.0
% INFO    : Gen at bus 58672	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58673	: Pg=100.33, Qg=0.0 -> Pg=125.0, Qg=0.0
% INFO    : Gen at bus 58673	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58673	: Pg=85.33, Qg=0.0 -> Pg=117.5, Qg=0.0
% INFO    : Gen at bus 58673	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58675	: Pg=109.04, Qg=18.01 -> Pg=109.04, Qg=0.0
% INFO    : Gen at bus 58675	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58676	: Pg=60.0, Qg=-13.25 -> Pg=97.35, Qg=0.0
% INFO    : Gen at bus 58676	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58676	: Pg=60.0, Qg=-13.25 -> Pg=97.35, Qg=0.0
% INFO    : Gen at bus 58676	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58676	: Pg=60.0, Qg=-13.25 -> Pg=97.35, Qg=0.0
% INFO    : Gen at bus 58676	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58676	: Pg=51.6, Qg=-13.25 -> Pg=93.15, Qg=0.0
% INFO    : Gen at bus 58676	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58676	: Pg=51.6, Qg=-13.25 -> Pg=93.15, Qg=0.0
% INFO    : Gen at bus 58676	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58676	: Pg=51.6, Qg=-13.25 -> Pg=93.15, Qg=0.0
% INFO    : Gen at bus 58676	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58677	: Pg=119.3, Qg=3.04 -> Pg=127.0, Qg=0.0
% INFO    : Gen at bus 58677	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58677	: Pg=63.6, Qg=3.04 -> Pg=99.15, Qg=0.0
% INFO    : Gen at bus 58677	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58677	: Pg=63.6, Qg=3.04 -> Pg=99.15, Qg=0.0
% INFO    : Gen at bus 58677	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58677	: Pg=63.6, Qg=3.04 -> Pg=99.15, Qg=0.0
% INFO    : Gen at bus 58677	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58677	: Pg=54.1, Qg=3.04 -> Pg=94.4, Qg=0.0
% INFO    : Gen at bus 58677	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58677	: Pg=54.1, Qg=3.04 -> Pg=94.4, Qg=0.0
% INFO    : Gen at bus 58677	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58678	: Pg=110.3, Qg=0.28 -> Pg=122.5, Qg=0.0
% INFO    : Gen at bus 58678	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58678	: Pg=57.8, Qg=0.28 -> Pg=96.25, Qg=0.0
% INFO    : Gen at bus 58678	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58678	: Pg=57.8, Qg=0.28 -> Pg=96.25, Qg=0.0
% INFO    : Gen at bus 58678	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58678	: Pg=57.8, Qg=0.28 -> Pg=96.25, Qg=0.0
% INFO    : Gen at bus 58678	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58678	: Pg=46.7, Qg=0.28 -> Pg=90.7, Qg=0.0
% INFO    : Gen at bus 58678	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58678	: Pg=46.7, Qg=0.28 -> Pg=90.7, Qg=0.0
% INFO    : Gen at bus 58678	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.25, Qg=12.58 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.28, Qg=12.58 -> Pg=80.2, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.28, Qg=12.58 -> Pg=80.2, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.25, Qg=12.58 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.25, Qg=12.58 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.25, Qg=12.58 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.25, Qg=12.58 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.25, Qg=12.58 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.25, Qg=12.58 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.28, Qg=12.58 -> Pg=80.2, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58679	: Pg=35.28, Qg=12.58 -> Pg=80.2, Qg=0.0
% INFO    : Gen at bus 58679	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58680	: Pg=22.75, Qg=3.66 -> Pg=56.25, Qg=8.5
% INFO    : Gen at bus 58680	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58680	: Pg=22.75, Qg=3.66 -> Pg=56.25, Qg=8.5
% INFO    : Gen at bus 58680	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58680	: Pg=22.75, Qg=3.66 -> Pg=56.25, Qg=8.5
% INFO    : Gen at bus 58680	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58680	: Pg=22.75, Qg=3.66 -> Pg=56.25, Qg=8.5
% INFO    : Gen at bus 58680	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58681	: Pg=80.56, Qg=44.4 -> Pg=80.56, Qg=44.4
% INFO    : Gen at bus 58681	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 58682	: Pg=63.3, Qg=-43.6 -> Pg=63.3, Qg=0.0
% INFO    : Gen at bus 58682	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58683	: Pg=78.24, Qg=-32.6 -> Pg=78.24, Qg=7.4
% INFO    : Gen at bus 58683	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58685	: Pg=35.21, Qg=46.4 -> Pg=65.45, Qg=46.4
% INFO    : Gen at bus 58685	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 58685	: Pg=35.21, Qg=46.4 -> Pg=65.45, Qg=46.4
% INFO    : Gen at bus 58685	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 58685	: Pg=30.21, Qg=45.4 -> Pg=61.85, Qg=45.4
% INFO    : Gen at bus 58685	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.22, Qg=-1.26 -> Pg=73.9, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.21, Qg=-1.26 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58686	: Pg=50.22, Qg=-1.26 -> Pg=73.9, Qg=0.0
% INFO    : Gen at bus 58686	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58687	: Pg=70.2, Qg=0.43 -> Pg=80.0, Qg=0.0
% INFO    : Gen at bus 58687	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58687	: Pg=35.9, Qg=0.43 -> Pg=62.85, Qg=0.0
% INFO    : Gen at bus 58687	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58687	: Pg=35.9, Qg=0.43 -> Pg=62.85, Qg=0.0
% INFO    : Gen at bus 58687	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58687	: Pg=42.45, Qg=0.43 -> Pg=76.6, Qg=0.0
% INFO    : Gen at bus 58687	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58687	: Pg=42.45, Qg=0.43 -> Pg=76.6, Qg=0.0
% INFO    : Gen at bus 58687	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58687	: Pg=42.45, Qg=0.43 -> Pg=76.6, Qg=0.0
% INFO    : Gen at bus 58687	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58689	: Pg=72.0, Qg=-29.02 -> Pg=72.0, Qg=0.0
% INFO    : Gen at bus 58689	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58690	: Pg=5.2, Qg=6.11 -> Pg=46.95, Qg=6.75
% INFO    : Gen at bus 58690	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58690	: Pg=5.2, Qg=6.11 -> Pg=46.95, Qg=6.75
% INFO    : Gen at bus 58690	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=47.8, Qg=-6.17 -> Pg=67.9, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58691	: Pg=95.0, Qg=-6.17 -> Pg=95.0, Qg=0.0
% INFO    : Gen at bus 58691	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58692	: Pg=20.08, Qg=1.53 -> Pg=28.85, Qg=2.85
% INFO    : Gen at bus 58692	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58692	: Pg=50.19, Qg=1.53 -> Pg=68.9, Qg=6.6
% INFO    : Gen at bus 58692	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58693	: Pg=5.19, Qg=-12.49 -> Pg=44.8, Qg=6.4
% INFO    : Gen at bus 58693	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58693	: Pg=5.19, Qg=-12.49 -> Pg=44.8, Qg=6.4
% INFO    : Gen at bus 58693	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58694	: Pg=33.7, Qg=0.0 -> Pg=41.4, Qg=0.0
% INFO    : Gen at bus 58694	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58695	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58695	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58695	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58696	: Pg=55.17, Qg=25.4 -> Pg=66.2, Qg=25.4
% INFO    : Gen at bus 58696	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 58699	: Pg=8.09, Qg=0.0 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 58699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58699	: Pg=8.67, Qg=0.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 58699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58699	: Pg=8.67, Qg=0.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 58699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58699	: Pg=8.67, Qg=0.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 58699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58699	: Pg=8.67, Qg=0.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 58699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58699	: Pg=8.67, Qg=0.0 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 58699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58700	: Pg=15.14, Qg=0.0 -> Pg=39.5, Qg=0.0
% INFO    : Gen at bus 58700	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58701	: Pg=5.14, Qg=-20.5 -> Pg=33.25, Qg=8.8
% INFO    : Gen at bus 58701	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58702	: Pg=3.18, Qg=0.22 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 58702	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58702	: Pg=3.18, Qg=0.22 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 58702	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58702	: Pg=3.18, Qg=0.22 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 58702	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58702	: Pg=3.18, Qg=0.22 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 58702	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58702	: Pg=6.07, Qg=0.22 -> Pg=18.7, Qg=2.35
% INFO    : Gen at bus 58702	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58703	: Pg=51.25, Qg=28.5 -> Pg=39.45, Qg=28.5
% INFO    : Gen at bus 58703	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 58703	: Pg=51.25, Qg=28.5 -> Pg=39.45, Qg=28.5
% INFO    : Gen at bus 58703	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 58703	: Pg=40.29, Qg=62.5 -> Pg=84.55, Qg=62.5
% INFO    : Gen at bus 58703	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 58703	: Pg=40.29, Qg=62.5 -> Pg=84.55, Qg=62.5
% INFO    : Gen at bus 58703	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 58704	: Pg=12.11, Qg=16.7 -> Pg=31.35, Qg=16.7
% INFO    : Gen at bus 58704	: Vg=1.0114 -> Vg=1.0
% INFO    : Gen at bus 58705	: Pg=40.0, Qg=0.0 -> Pg=40.0, Qg=0.0
% INFO    : Gen at bus 58705	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58707	: Pg=14.1, Qg=15.1 -> Pg=30.0, Qg=15.1
% INFO    : Gen at bus 58707	: Vg=1.0128 -> Vg=1.0
% INFO    : Gen at bus 58707	: Pg=14.1, Qg=15.1 -> Pg=30.0, Qg=15.1
% INFO    : Gen at bus 58707	: Vg=1.0128 -> Vg=1.0
% INFO    : Gen at bus 58708	: Pg=11.38, Qg=0.0 -> Pg=9.7, Qg=0.0
% INFO    : Gen at bus 58708	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58708	: Pg=11.38, Qg=0.0 -> Pg=9.7, Qg=0.0
% INFO    : Gen at bus 58708	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58708	: Pg=11.38, Qg=0.0 -> Pg=9.7, Qg=0.0
% INFO    : Gen at bus 58708	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58708	: Pg=11.38, Qg=0.0 -> Pg=9.7, Qg=0.0
% INFO    : Gen at bus 58708	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58709	: Pg=9.1, Qg=0.55 -> Pg=22.5, Qg=9.4
% INFO    : Gen at bus 58709	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58709	: Pg=9.1, Qg=0.55 -> Pg=22.5, Qg=9.4
% INFO    : Gen at bus 58709	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58709	: Pg=9.1, Qg=0.55 -> Pg=22.5, Qg=9.4
% INFO    : Gen at bus 58709	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58710	: Pg=35.2, Qg=-17.4 -> Pg=35.2, Qg=0.0
% INFO    : Gen at bus 58710	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58710	: Pg=182.88, Qg=-26.74 -> Pg=182.88, Qg=17.25
% INFO    : Gen at bus 58710	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58711	: Pg=11.01, Qg=23.6 -> Pg=26.46, Qg=23.6
% INFO    : Gen at bus 58711	: Vg=0.9987 -> Vg=1.0
% INFO    : Gen at bus 58712	: Pg=8.09, Qg=0.0 -> Pg=24.25, Qg=0.0
% INFO    : Gen at bus 58712	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58712	: Pg=8.09, Qg=0.0 -> Pg=24.25, Qg=0.0
% INFO    : Gen at bus 58712	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58712	: Pg=8.09, Qg=0.0 -> Pg=24.25, Qg=0.0
% INFO    : Gen at bus 58712	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58712	: Pg=8.09, Qg=0.0 -> Pg=24.25, Qg=0.0
% INFO    : Gen at bus 58712	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58713	: Pg=22.09, Qg=-3.54 -> Pg=30.7, Qg=3.0
% INFO    : Gen at bus 58713	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58713	: Pg=21.09, Qg=-3.54 -> Pg=30.2, Qg=3.0
% INFO    : Gen at bus 58713	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58713	: Pg=21.09, Qg=-3.54 -> Pg=30.2, Qg=3.0
% INFO    : Gen at bus 58713	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58713	: Pg=30.13, Qg=-3.54 -> Pg=44.1, Qg=4.4
% INFO    : Gen at bus 58713	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58715	: Pg=7.28, Qg=5.03 -> Pg=18.0, Qg=2.7
% INFO    : Gen at bus 58715	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58715	: Pg=7.28, Qg=5.03 -> Pg=18.0, Qg=2.7
% INFO    : Gen at bus 58715	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58716	: Pg=12.08, Qg=-6.09 -> Pg=23.5, Qg=2.65
% INFO    : Gen at bus 58716	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58716	: Pg=12.08, Qg=-6.09 -> Pg=23.5, Qg=2.65
% INFO    : Gen at bus 58716	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58719	: Pg=23.07, Qg=-9.9 -> Pg=26.3, Qg=6.15
% INFO    : Gen at bus 58719	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58719	: Pg=23.07, Qg=-9.9 -> Pg=26.3, Qg=6.15
% INFO    : Gen at bus 58719	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58720	: Pg=13.06, Qg=17.4 -> Pg=20.5, Qg=17.4
% INFO    : Gen at bus 58720	: Vg=1.0119 -> Vg=1.0
% INFO    : Gen at bus 58721	: Pg=7.96, Qg=-9.0 -> Pg=15.25, Qg=0.0
% INFO    : Gen at bus 58721	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58722	: Pg=8.06, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 58722	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58722	: Pg=8.06, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 58722	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58722	: Pg=8.06, Qg=0.0 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 58722	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58723	: Pg=46.53, Qg=22.6 -> Pg=41.8, Qg=22.6
% INFO    : Gen at bus 58723	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 58723	: Pg=46.53, Qg=22.6 -> Pg=41.8, Qg=22.6
% INFO    : Gen at bus 58723	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 58723	: Pg=46.53, Qg=22.6 -> Pg=41.8, Qg=22.6
% INFO    : Gen at bus 58723	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 58723	: Pg=11.06, Qg=13.1 -> Pg=17.0, Qg=13.1
% INFO    : Gen at bus 58723	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 58724	: Pg=7.82, Qg=8.8 -> Pg=14.9, Qg=8.8
% INFO    : Gen at bus 58724	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 58726	: Pg=25.96, Qg=-2.92 -> Pg=15.0, Qg=3.7
% INFO    : Gen at bus 58726	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58727	: Pg=8.26, Qg=0.0 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 58727	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58727	: Pg=8.26, Qg=0.0 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 58727	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58728	: Pg=4.1, Qg=-0.04 -> Pg=4.1, Qg=0.855
% INFO    : Gen at bus 58728	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58728	: Pg=4.1, Qg=-0.04 -> Pg=4.1, Qg=0.855
% INFO    : Gen at bus 58728	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58728	: Pg=4.1, Qg=-0.04 -> Pg=4.1, Qg=0.855
% INFO    : Gen at bus 58728	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58728	: Pg=4.1, Qg=-0.04 -> Pg=4.1, Qg=0.855
% INFO    : Gen at bus 58728	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58728	: Pg=4.1, Qg=-0.04 -> Pg=4.1, Qg=0.855
% INFO    : Gen at bus 58728	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58728	: Pg=4.1, Qg=-0.04 -> Pg=4.1, Qg=0.855
% INFO    : Gen at bus 58728	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58730	: Pg=9.65, Qg=0.0 -> Pg=6.05, Qg=0.0
% INFO    : Gen at bus 58730	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58730	: Pg=9.65, Qg=0.0 -> Pg=6.05, Qg=0.0
% INFO    : Gen at bus 58730	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58731	: Pg=5.69, Qg=3.08 -> Pg=3.015, Qg=3.08
% INFO    : Gen at bus 58731	: Vg=1.0094 -> Vg=1.0
% INFO    : Gen at bus 58731	: Pg=5.69, Qg=3.08 -> Pg=3.015, Qg=3.08
% INFO    : Gen at bus 58731	: Vg=1.0094 -> Vg=1.0
% INFO    : Gen at bus 58731	: Pg=5.69, Qg=3.08 -> Pg=3.015, Qg=3.08
% INFO    : Gen at bus 58731	: Vg=1.0094 -> Vg=1.0
% INFO    : Gen at bus 58731	: Pg=5.69, Qg=3.08 -> Pg=3.015, Qg=3.08
% INFO    : Gen at bus 58731	: Vg=1.0094 -> Vg=1.0
% INFO    : Gen at bus 58732	: Pg=9.05, Qg=-5.96 -> Pg=11.25, Qg=1.7
% INFO    : Gen at bus 58732	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58732	: Pg=9.05, Qg=-5.96 -> Pg=11.25, Qg=1.7
% INFO    : Gen at bus 58732	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58732	: Pg=9.05, Qg=-5.96 -> Pg=11.25, Qg=1.7
% INFO    : Gen at bus 58732	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58732	: Pg=9.05, Qg=-5.96 -> Pg=11.25, Qg=1.7
% INFO    : Gen at bus 58732	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=15.35, Qg=1.55
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=15.35, Qg=1.55
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=15.35, Qg=1.55
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=16.25, Qg=1.7
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=16.25, Qg=1.7
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=16.25, Qg=1.7
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=16.25, Qg=1.7
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=16.25, Qg=1.7
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=16.25, Qg=1.7
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.11, Qg=1.68 -> Pg=30.65, Qg=0.0
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58733	: Pg=10.05, Qg=1.68 -> Pg=15.35, Qg=1.55
% INFO    : Gen at bus 58733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58735	: Pg=607.39, Qg=-45.5 -> Pg=344.15, Qg=0.0
% INFO    : Gen at bus 58735	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58735	: Pg=607.39, Qg=-45.5 -> Pg=344.15, Qg=0.0
% INFO    : Gen at bus 58735	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58735	: Pg=607.39, Qg=-45.5 -> Pg=344.15, Qg=0.0
% INFO    : Gen at bus 58735	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58735	: Pg=616.08, Qg=-45.5 -> Pg=348.5, Qg=0.0
% INFO    : Gen at bus 58735	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58736	: Pg=569.15, Qg=-11.0 -> Pg=400.0, Qg=43.05
% INFO    : Gen at bus 58736	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58736	: Pg=569.15, Qg=-11.0 -> Pg=385.0, Qg=43.05
% INFO    : Gen at bus 58736	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58736	: Pg=569.15, Qg=-11.0 -> Pg=385.0, Qg=43.05
% INFO    : Gen at bus 58736	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58738	: Pg=160.0, Qg=32.94 -> Pg=160.0, Qg=15.1
% INFO    : Gen at bus 58738	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58740	: Pg=71.02, Qg=12.4 -> Pg=94.3, Qg=19.15
% INFO    : Gen at bus 58740	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58740	: Pg=71.02, Qg=12.4 -> Pg=94.3, Qg=19.15
% INFO    : Gen at bus 58740	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58740	: Pg=228.57, Qg=12.4 -> Pg=187.5, Qg=19.25
% INFO    : Gen at bus 58740	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58740	: Pg=399.4, Qg=12.4 -> Pg=290.0, Qg=30.2
% INFO    : Gen at bus 58740	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58741	: Pg=71.76, Qg=-38.7 -> Pg=93.75, Qg=8.75
% INFO    : Gen at bus 58741	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58742	: Pg=92.64, Qg=-9.65 -> Pg=92.64, Qg=8.75
% INFO    : Gen at bus 58742	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58743	: Pg=82.64, Qg=-12.8 -> Pg=82.64, Qg=7.8
% INFO    : Gen at bus 58743	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58744	: Pg=82.64, Qg=26.28 -> Pg=82.64, Qg=7.8
% INFO    : Gen at bus 58744	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58745	: Pg=79.2, Qg=-5.17 -> Pg=79.2, Qg=0.0
% INFO    : Gen at bus 58745	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58746	: Pg=62.21, Qg=-31.7 -> Pg=78.5, Qg=7.15
% INFO    : Gen at bus 58746	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58748	: Pg=57.4, Qg=30.55 -> Pg=73.6, Qg=6.8
% INFO    : Gen at bus 58748	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58749	: Pg=64.0, Qg=-31.6 -> Pg=64.0, Qg=0.0
% INFO    : Gen at bus 58749	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58750	: Pg=48.8, Qg=-24.1 -> Pg=48.8, Qg=0.0
% INFO    : Gen at bus 58750	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58751	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58751	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58751	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58752	: Pg=40.0, Qg=-19.8 -> Pg=40.0, Qg=0.0
% INFO    : Gen at bus 58752	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58753	: Pg=33.6, Qg=10.65 -> Pg=33.6, Qg=0.0
% INFO    : Gen at bus 58753	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58754	: Pg=33.12, Qg=-7.17 -> Pg=33.12, Qg=0.0
% INFO    : Gen at bus 58754	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58755	: Pg=1.77, Qg=-2.28 -> Pg=4.29, Qg=1.21
% INFO    : Gen at bus 58755	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58755	: Pg=1.77, Qg=-2.28 -> Pg=4.29, Qg=1.21
% INFO    : Gen at bus 58755	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58755	: Pg=1.77, Qg=-2.28 -> Pg=4.29, Qg=1.21
% INFO    : Gen at bus 58755	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58755	: Pg=1.77, Qg=-2.28 -> Pg=4.29, Qg=1.21
% INFO    : Gen at bus 58755	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58755	: Pg=1.77, Qg=-2.28 -> Pg=4.29, Qg=1.21
% INFO    : Gen at bus 58755	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58755	: Pg=1.77, Qg=-2.28 -> Pg=4.29, Qg=1.21
% INFO    : Gen at bus 58755	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58756	: Pg=32.56, Qg=-4.01 -> Pg=32.56, Qg=3.05
% INFO    : Gen at bus 58756	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58756	: Pg=82.64, Qg=-4.01 -> Pg=82.64, Qg=7.8
% INFO    : Gen at bus 58756	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58757	: Pg=39.94, Qg=-13.3 -> Pg=32.35, Qg=3.05
% INFO    : Gen at bus 58757	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58759	: Pg=9.63, Qg=-2.12 -> Pg=6.0, Qg=0.9
% INFO    : Gen at bus 58759	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58759	: Pg=9.63, Qg=-2.12 -> Pg=6.0, Qg=0.9
% INFO    : Gen at bus 58759	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58759	: Pg=9.63, Qg=-2.12 -> Pg=6.0, Qg=0.9
% INFO    : Gen at bus 58759	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58760	: Pg=30.08, Qg=-8.54 -> Pg=33.0, Qg=5.15
% INFO    : Gen at bus 58760	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58760	: Pg=30.08, Qg=-8.54 -> Pg=33.0, Qg=5.15
% INFO    : Gen at bus 58760	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58760	: Pg=30.08, Qg=-8.54 -> Pg=33.0, Qg=5.15
% INFO    : Gen at bus 58760	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58762	: Pg=6.75, Qg=5.94 -> Pg=16.7, Qg=0.0
% INFO    : Gen at bus 58762	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58762	: Pg=6.75, Qg=5.94 -> Pg=16.7, Qg=0.0
% INFO    : Gen at bus 58762	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58764	: Pg=23.76, Qg=-9.9 -> Pg=23.76, Qg=2.25
% INFO    : Gen at bus 58764	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58765	: Pg=23.52, Qg=-11.6 -> Pg=23.52, Qg=0.0
% INFO    : Gen at bus 58765	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58766	: Pg=19.84, Qg=-9.4 -> Pg=19.84, Qg=0.0
% INFO    : Gen at bus 58766	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58767	: Pg=7.49, Qg=-2.37 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58767	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58767	: Pg=7.49, Qg=-2.37 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58767	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58767	: Pg=7.49, Qg=-2.37 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58767	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58768	: Pg=7.49, Qg=-2.5 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58768	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58768	: Pg=7.49, Qg=-2.5 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58768	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58768	: Pg=7.49, Qg=-2.5 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58768	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58769	: Pg=7.49, Qg=-2.5 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58769	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58769	: Pg=7.49, Qg=-2.5 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58769	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58769	: Pg=7.49, Qg=-2.5 -> Pg=4.0, Qg=1.565
% INFO    : Gen at bus 58769	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58770	: Pg=9.05, Qg=-7.2 -> Pg=15.35, Qg=1.65
% INFO    : Gen at bus 58770	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58771	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58771	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58772	: Pg=16.24, Qg=-6.8 -> Pg=16.24, Qg=1.5
% INFO    : Gen at bus 58772	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58772	: Pg=82.64, Qg=-23.73 -> Pg=82.64, Qg=7.8
% INFO    : Gen at bus 58772	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58773	: Pg=115.4, Qg=111.2 -> Pg=147.2, Qg=111.2
% INFO    : Gen at bus 58773	: Vg=1.0174 -> Vg=1.0
% INFO    : Gen at bus 58773	: Pg=65.27, Qg=75.7 -> Pg=93.55, Qg=75.7
% INFO    : Gen at bus 58773	: Vg=1.0174 -> Vg=1.0
% INFO    : Gen at bus 58775	: Pg=92.72, Qg=-5.31 -> Pg=92.72, Qg=0.0
% INFO    : Gen at bus 58775	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58776	: Pg=18.22, Qg=-23.69 -> Pg=45.05, Qg=6.8
% INFO    : Gen at bus 58776	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58776	: Pg=18.22, Qg=-23.69 -> Pg=45.05, Qg=6.8
% INFO    : Gen at bus 58776	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58776	: Pg=18.22, Qg=-23.69 -> Pg=45.05, Qg=6.8
% INFO    : Gen at bus 58776	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58776	: Pg=18.22, Qg=-23.69 -> Pg=45.05, Qg=6.8
% INFO    : Gen at bus 58776	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58776	: Pg=45.5, Qg=-23.69 -> Pg=112.5, Qg=17.0
% INFO    : Gen at bus 58776	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 58777	: Pg=90.0, Qg=-29.6 -> Pg=90.0, Qg=0.0
% INFO    : Gen at bus 58777	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58777	: Pg=90.0, Qg=-29.6 -> Pg=90.0, Qg=0.0
% INFO    : Gen at bus 58777	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58777	: Pg=220.0, Qg=-47.04 -> Pg=220.0, Qg=0.0
% INFO    : Gen at bus 58777	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58779	: Pg=51.6, Qg=-11.67 -> Pg=51.6, Qg=0.0
% INFO    : Gen at bus 58779	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58780	: Pg=9.03, Qg=5.33 -> Pg=7.5, Qg=1.95
% INFO    : Gen at bus 58780	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58780	: Pg=9.03, Qg=5.33 -> Pg=7.5, Qg=1.95
% INFO    : Gen at bus 58780	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58780	: Pg=9.03, Qg=5.33 -> Pg=7.5, Qg=1.95
% INFO    : Gen at bus 58780	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58780	: Pg=9.03, Qg=5.33 -> Pg=7.5, Qg=1.95
% INFO    : Gen at bus 58780	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58781	: Pg=20.13, Qg=-9.85 -> Pg=39.7, Qg=4.5
% INFO    : Gen at bus 58781	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58781	: Pg=18.13, Qg=-9.85 -> Pg=38.7, Qg=4.5
% INFO    : Gen at bus 58781	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58781	: Pg=30.16, Qg=-9.85 -> Pg=51.6, Qg=5.55
% INFO    : Gen at bus 58781	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58781	: Pg=30.16, Qg=-9.85 -> Pg=51.6, Qg=5.55
% INFO    : Gen at bus 58781	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58782	: Pg=9.42, Qg=5.81 -> Pg=23.3, Qg=0.0
% INFO    : Gen at bus 58782	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58784	: Pg=8.96, Qg=14.6 -> Pg=22.15, Qg=14.6
% INFO    : Gen at bus 58784	: Vg=0.9992 -> Vg=1.0
% INFO    : Gen at bus 58786	: Pg=14.0, Qg=0.82 -> Pg=14.0, Qg=1.05
% INFO    : Gen at bus 58786	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58786	: Pg=14.0, Qg=0.82 -> Pg=14.0, Qg=1.05
% INFO    : Gen at bus 58786	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58786	: Pg=14.0, Qg=0.82 -> Pg=14.0, Qg=1.05
% INFO    : Gen at bus 58786	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58787	: Pg=8.98, Qg=-2.08 -> Pg=8.015, Qg=0.97
% INFO    : Gen at bus 58787	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58787	: Pg=8.98, Qg=-2.08 -> Pg=8.015, Qg=0.97
% INFO    : Gen at bus 58787	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58787	: Pg=8.98, Qg=-2.08 -> Pg=8.015, Qg=0.97
% INFO    : Gen at bus 58787	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58790	: Pg=9.99, Qg=1.92 -> Pg=5.0, Qg=0.75
% INFO    : Gen at bus 58790	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58790	: Pg=9.99, Qg=1.92 -> Pg=5.0, Qg=0.75
% INFO    : Gen at bus 58790	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58790	: Pg=9.99, Qg=1.92 -> Pg=5.0, Qg=0.75
% INFO    : Gen at bus 58790	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58791	: Pg=6.91, Qg=1.84 -> Pg=3.465, Qg=0.65
% INFO    : Gen at bus 58791	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58791	: Pg=6.91, Qg=1.84 -> Pg=3.465, Qg=0.65
% INFO    : Gen at bus 58791	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58791	: Pg=6.91, Qg=1.84 -> Pg=3.465, Qg=0.65
% INFO    : Gen at bus 58791	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58791	: Pg=6.91, Qg=1.84 -> Pg=3.465, Qg=0.65
% INFO    : Gen at bus 58791	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 58792	: Pg=11.1, Qg=1.62 -> Pg=13.8, Qg=0.0
% INFO    : Gen at bus 58792	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58792	: Pg=11.1, Qg=1.62 -> Pg=13.8, Qg=0.0
% INFO    : Gen at bus 58792	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58792	: Pg=11.1, Qg=1.62 -> Pg=13.8, Qg=0.0
% INFO    : Gen at bus 58792	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58793	: Pg=10.03, Qg=-0.79 -> Pg=6.25, Qg=0.0
% INFO    : Gen at bus 58793	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58793	: Pg=10.03, Qg=-0.79 -> Pg=6.25, Qg=0.0
% INFO    : Gen at bus 58793	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58794	: Pg=10.06, Qg=-1.97 -> Pg=12.5, Qg=2.95
% INFO    : Gen at bus 58794	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58794	: Pg=10.06, Qg=-1.97 -> Pg=12.5, Qg=2.95
% INFO    : Gen at bus 58794	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58794	: Pg=10.06, Qg=-1.97 -> Pg=12.5, Qg=2.95
% INFO    : Gen at bus 58794	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58795	: Pg=23.4, Qg=11.3 -> Pg=23.4, Qg=11.3
% INFO    : Gen at bus 58795	: Vg=1.0059 -> Vg=1.0
% INFO    : Gen at bus 58796	: Pg=14.6, Qg=-8.9 -> Pg=14.6, Qg=0.0
% INFO    : Gen at bus 58796	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 58797	: Pg=8.44, Qg=-8.3 -> Pg=8.44, Qg=0.0
% INFO    : Gen at bus 58797	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58798	: Pg=8.44, Qg=-8.3 -> Pg=8.44, Qg=0.0
% INFO    : Gen at bus 58798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58799	: Pg=14.0, Qg=8.3 -> Pg=14.0, Qg=8.3
% INFO    : Gen at bus 58799	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58800	: Pg=14.0, Qg=8.3 -> Pg=14.0, Qg=8.3
% INFO    : Gen at bus 58800	: Vg=1.0089 -> Vg=1.0
% INFO    : Gen at bus 58802	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 58802	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61780	: Pg=1399.67, Qg=78.52 -> Pg=756.6, Qg=105.95
% INFO    : Gen at bus 61780	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61780	: Pg=1399.67, Qg=78.52 -> Pg=756.6, Qg=105.95
% INFO    : Gen at bus 61780	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61780	: Pg=1399.67, Qg=78.52 -> Pg=756.6, Qg=105.95
% INFO    : Gen at bus 61780	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61781	: Pg=801.9, Qg=-44.64 -> Pg=564.05, Qg=60.65
% INFO    : Gen at bus 61781	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61781	: Pg=801.9, Qg=-44.64 -> Pg=564.05, Qg=60.65
% INFO    : Gen at bus 61781	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61781	: Pg=801.9, Qg=-44.64 -> Pg=564.05, Qg=60.65
% INFO    : Gen at bus 61781	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61782	: Pg=424.17, Qg=-141.6 -> Pg=339.9, Qg=32.05
% INFO    : Gen at bus 61782	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61782	: Pg=457.42, Qg=-152.7 -> Pg=364.05, Qg=34.6
% INFO    : Gen at bus 61782	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61782	: Pg=457.42, Qg=-152.7 -> Pg=359.05, Qg=34.6
% INFO    : Gen at bus 61782	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61782	: Pg=424.17, Qg=-141.6 -> Pg=317.4, Qg=32.05
% INFO    : Gen at bus 61782	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61783	: Pg=410.29, Qg=-70.73 -> Pg=230.45, Qg=31.0
% INFO    : Gen at bus 61783	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61783	: Pg=410.29, Qg=-70.73 -> Pg=230.45, Qg=31.0
% INFO    : Gen at bus 61783	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61784	: Pg=103.4, Qg=9.95 -> Pg=124.4, Qg=12.1
% INFO    : Gen at bus 61784	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61784	: Pg=102.04, Qg=9.95 -> Pg=123.55, Qg=12.1
% INFO    : Gen at bus 61784	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61784	: Pg=101.08, Qg=9.95 -> Pg=122.95, Qg=12.1
% INFO    : Gen at bus 61784	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61784	: Pg=138.03, Qg=9.95 -> Pg=209.55, Qg=21.25
% INFO    : Gen at bus 61784	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61784	: Pg=136.03, Qg=9.95 -> Pg=208.55, Qg=21.25
% INFO    : Gen at bus 61784	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61784	: Pg=135.93, Qg=9.95 -> Pg=208.5, Qg=21.25
% INFO    : Gen at bus 61784	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61785	: Pg=105.52, Qg=-0.62 -> Pg=170.5, Qg=33.8
% INFO    : Gen at bus 61785	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61785	: Pg=105.52, Qg=-0.62 -> Pg=170.5, Qg=33.8
% INFO    : Gen at bus 61785	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61785	: Pg=60.52, Qg=-0.62 -> Pg=148.0, Qg=33.8
% INFO    : Gen at bus 61785	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61786	: Pg=173.65, Qg=6.97 -> Pg=127.0, Qg=29.2
% INFO    : Gen at bus 61786	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61786	: Pg=173.65, Qg=6.97 -> Pg=127.0, Qg=29.2
% INFO    : Gen at bus 61786	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61786	: Pg=20.37, Qg=6.97 -> Pg=11.2, Qg=1.55
% INFO    : Gen at bus 61786	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61786	: Pg=49.53, Qg=6.97 -> Pg=32.75, Qg=8.65
% INFO    : Gen at bus 61786	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61786	: Pg=20.18, Qg=6.97 -> Pg=50.8, Qg=11.7
% INFO    : Gen at bus 61786	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61786	: Pg=7.17, Qg=6.97 -> Pg=42.85, Qg=5.95
% INFO    : Gen at bus 61786	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61787	: Pg=116.1, Qg=6.22 -> Pg=191.0, Qg=45.4
% INFO    : Gen at bus 61787	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61787	: Pg=85.44, Qg=6.22 -> Pg=141.5, Qg=28.35
% INFO    : Gen at bus 61787	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61787	: Pg=85.44, Qg=6.22 -> Pg=141.5, Qg=28.35
% INFO    : Gen at bus 61787	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61788	: Pg=113.42, Qg=26.65 -> Pg=150.0, Qg=26.8
% INFO    : Gen at bus 61788	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61788	: Pg=113.42, Qg=26.65 -> Pg=150.0, Qg=26.8
% INFO    : Gen at bus 61788	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61788	: Pg=111.02, Qg=26.65 -> Pg=171.05, Qg=38.95
% INFO    : Gen at bus 61788	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61789	: Pg=100.41, Qg=-52.81 -> Pg=142.65, Qg=26.5
% INFO    : Gen at bus 61789	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61789	: Pg=100.41, Qg=-52.81 -> Pg=142.65, Qg=26.5
% INFO    : Gen at bus 61789	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61789	: Pg=104.91, Qg=-52.81 -> Pg=185.5, Qg=45.95
% INFO    : Gen at bus 61789	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61790	: Pg=100.41, Qg=-52.81 -> Pg=142.65, Qg=26.5
% INFO    : Gen at bus 61790	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61790	: Pg=100.41, Qg=-52.81 -> Pg=142.65, Qg=26.5
% INFO    : Gen at bus 61790	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61790	: Pg=104.91, Qg=-52.81 -> Pg=185.5, Qg=45.95
% INFO    : Gen at bus 61790	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61791	: Pg=96.72, Qg=-10.78 -> Pg=128.3, Qg=26.0
% INFO    : Gen at bus 61791	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61791	: Pg=96.72, Qg=-10.78 -> Pg=128.3, Qg=26.0
% INFO    : Gen at bus 61791	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61791	: Pg=96.72, Qg=-10.78 -> Pg=128.3, Qg=26.0
% INFO    : Gen at bus 61791	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61791	: Pg=97.92, Qg=-10.78 -> Pg=131.25, Qg=26.85
% INFO    : Gen at bus 61791	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61791	: Pg=0.45, Qg=-10.78 -> Pg=102.0, Qg=29.2
% INFO    : Gen at bus 61791	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61791	: Pg=0.45, Qg=-10.78 -> Pg=102.0, Qg=29.2
% INFO    : Gen at bus 61791	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61792	: Pg=95.39, Qg=-9.8 -> Pg=135.5, Qg=25.2
% INFO    : Gen at bus 61792	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61792	: Pg=95.39, Qg=-9.8 -> Pg=135.8, Qg=25.25
% INFO    : Gen at bus 61792	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61792	: Pg=113.03, Qg=-9.8 -> Pg=183.4, Qg=43.2
% INFO    : Gen at bus 61792	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61793	: Pg=111.99, Qg=-46.74 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61793	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61793	: Pg=111.99, Qg=-46.74 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61793	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61793	: Pg=111.99, Qg=-46.74 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61793	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61793	: Pg=111.99, Qg=-46.74 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61793	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61793	: Pg=91.6, Qg=-46.74 -> Pg=158.5, Qg=38.85
% INFO    : Gen at bus 61793	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61793	: Pg=91.6, Qg=-46.74 -> Pg=158.5, Qg=38.85
% INFO    : Gen at bus 61793	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61794	: Pg=111.99, Qg=18.99 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61794	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61794	: Pg=111.99, Qg=18.99 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61794	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61794	: Pg=111.99, Qg=18.99 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61794	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61794	: Pg=111.99, Qg=18.99 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 61794	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61794	: Pg=91.6, Qg=18.99 -> Pg=158.5, Qg=38.85
% INFO    : Gen at bus 61794	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61794	: Pg=91.6, Qg=18.99 -> Pg=158.5, Qg=38.85
% INFO    : Gen at bus 61794	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61795	: Pg=20.24, Qg=67.4 -> Pg=64.4, Qg=15.55
% INFO    : Gen at bus 61795	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61795	: Pg=20.24, Qg=67.4 -> Pg=64.4, Qg=15.55
% INFO    : Gen at bus 61795	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61795	: Pg=20.25, Qg=70.4 -> Pg=66.8, Qg=16.25
% INFO    : Gen at bus 61795	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61795	: Pg=147.02, Qg=107.4 -> Pg=106.65, Qg=24.8
% INFO    : Gen at bus 61795	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61795	: Pg=26.96, Qg=16.7 -> Pg=16.0, Qg=3.85
% INFO    : Gen at bus 61795	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61795	: Pg=26.96, Qg=16.7 -> Pg=16.0, Qg=3.85
% INFO    : Gen at bus 61795	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61796	: Pg=49.57, Qg=29.2 -> Pg=33.15, Qg=4.55
% INFO    : Gen at bus 61796	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61796	: Pg=49.57, Qg=29.2 -> Pg=33.15, Qg=4.55
% INFO    : Gen at bus 61796	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61796	: Pg=53.02, Qg=32.9 -> Pg=29.55, Qg=7.6
% INFO    : Gen at bus 61796	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61796	: Pg=106.38, Qg=45.42 -> Pg=130.0, Qg=24.35
% INFO    : Gen at bus 61796	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61796	: Pg=4.08, Qg=21.4 -> Pg=19.25, Qg=4.95
% INFO    : Gen at bus 61796	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61796	: Pg=4.16, Qg=45.42 -> Pg=38.75, Qg=10.55
% INFO    : Gen at bus 61796	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61796	: Pg=90.27, Qg=45.42 -> Pg=106.0, Qg=17.45
% INFO    : Gen at bus 61796	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=31.75, Qg=14.43 -> Pg=78.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=33.37, Qg=14.43 -> Pg=82.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=33.37, Qg=14.43 -> Pg=82.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=33.37, Qg=14.43 -> Pg=82.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=33.37, Qg=14.43 -> Pg=82.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=33.37, Qg=14.43 -> Pg=82.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=33.37, Qg=14.43 -> Pg=82.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61797	: Pg=33.37, Qg=14.43 -> Pg=82.5, Qg=0.0
% INFO    : Gen at bus 61797	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=103.1, Qg=35.73 -> Pg=121.9, Qg=22.0
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=103.1, Qg=35.73 -> Pg=121.9, Qg=22.0
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=103.1, Qg=35.73 -> Pg=121.9, Qg=22.0
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=99.96, Qg=35.73 -> Pg=90.55, Qg=19.45
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=111.6, Qg=35.73 -> Pg=187.25, Qg=45.05
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=40.23, Qg=35.73 -> Pg=71.75, Qg=7.8
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=40.23, Qg=35.73 -> Pg=71.75, Qg=7.8
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=40.23, Qg=35.73 -> Pg=71.75, Qg=7.8
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61798	: Pg=40.23, Qg=35.73 -> Pg=71.75, Qg=7.8
% INFO    : Gen at bus 61798	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61799	: Pg=46.97, Qg=14.11 -> Pg=71.8, Qg=16.25
% INFO    : Gen at bus 61799	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61799	: Pg=311.84, Qg=14.11 -> Pg=193.65, Qg=0.0
% INFO    : Gen at bus 61799	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61799	: Pg=288.47, Qg=14.11 -> Pg=181.95, Qg=21.8
% INFO    : Gen at bus 61799	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61799	: Pg=413.38, Qg=14.11 -> Pg=254.5, Qg=31.25
% INFO    : Gen at bus 61799	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=53.02, Qg=2.04 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=40.2, Qg=2.04 -> Pg=65.5, Qg=13.05
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=53.02, Qg=2.04 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=105.31, Qg=2.04 -> Pg=134.75, Qg=26.4
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=105.31, Qg=2.04 -> Pg=134.75, Qg=26.4
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=9.02, Qg=2.04 -> Pg=22.3, Qg=6.35
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=0.45, Qg=2.04 -> Pg=100.3, Qg=28.7
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=50.29, Qg=2.04 -> Pg=91.0, Qg=9.95
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=10.29, Qg=2.04 -> Pg=71.0, Qg=9.95
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61801	: Pg=10.29, Qg=2.04 -> Pg=71.0, Qg=9.95
% INFO    : Gen at bus 61801	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61802	: Pg=40.19, Qg=52.7 -> Pg=62.5, Qg=12.2
% INFO    : Gen at bus 61802	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61803	: Pg=113.25, Qg=70.4 -> Pg=113.3, Qg=16.25
% INFO    : Gen at bus 61803	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61803	: Pg=113.25, Qg=70.4 -> Pg=113.3, Qg=16.25
% INFO    : Gen at bus 61803	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61803	: Pg=160.9, Qg=84.32 -> Pg=161.87, Qg=23.35
% INFO    : Gen at bus 61803	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61803	: Pg=72.18, Qg=39.0 -> Pg=76.25, Qg=6.1
% INFO    : Gen at bus 61803	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61803	: Pg=62.68, Qg=34.5 -> Pg=66.86, Qg=5.4
% INFO    : Gen at bus 61803	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61803	: Pg=62.68, Qg=34.5 -> Pg=66.86, Qg=5.4
% INFO    : Gen at bus 61803	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61804	: Pg=52.08, Qg=-1.72 -> Pg=52.08, Qg=0.0
% INFO    : Gen at bus 61804	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61805	: Pg=50.4, Qg=-3.59 -> Pg=50.4, Qg=0.0
% INFO    : Gen at bus 61805	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61807	: Pg=52.53, Qg=0.06 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61807	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61809	: Pg=10.12, Qg=23.43 -> Pg=32.15, Qg=4.1
% INFO    : Gen at bus 61809	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61810	: Pg=25.25, Qg=56.16 -> Pg=69.3, Qg=16.25
% INFO    : Gen at bus 61810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61810	: Pg=25.25, Qg=56.16 -> Pg=69.3, Qg=16.25
% INFO    : Gen at bus 61810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61810	: Pg=53.02, Qg=32.9 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 61810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61810	: Pg=53.02, Qg=32.9 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 61810	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61811	: Pg=31.53, Qg=14.93 -> Pg=78.125, Qg=17.9
% INFO    : Gen at bus 61811	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61811	: Pg=31.53, Qg=14.93 -> Pg=78.125, Qg=17.9
% INFO    : Gen at bus 61811	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61811	: Pg=53.02, Qg=14.93 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 61811	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61811	: Pg=53.02, Qg=14.93 -> Pg=28.55, Qg=7.6
% INFO    : Gen at bus 61811	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61811	: Pg=40.17, Qg=14.93 -> Pg=59.15, Qg=5.9
% INFO    : Gen at bus 61811	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61813	: Pg=10.0, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 61813	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61813	: Pg=10.0, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 61813	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61813	: Pg=10.0, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 61813	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61813	: Pg=10.0, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 61813	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61814	: Pg=10.08, Qg=17.4 -> Pg=23.0, Qg=2.7
% INFO    : Gen at bus 61814	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61815	: Pg=9.89, Qg=4.8 -> Pg=6.45, Qg=0.75
% INFO    : Gen at bus 61815	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61815	: Pg=9.89, Qg=4.8 -> Pg=6.45, Qg=0.75
% INFO    : Gen at bus 61815	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61815	: Pg=9.89, Qg=4.8 -> Pg=6.45, Qg=0.75
% INFO    : Gen at bus 61815	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61815	: Pg=80.22, Qg=32.32 -> Pg=89.9, Qg=7.5
% INFO    : Gen at bus 61815	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61818	: Pg=2.06, Qg=12.6 -> Pg=14.05, Qg=1.95
% INFO    : Gen at bus 61818	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=23.56, Qg=11.4 -> Pg=12.8, Qg=1.75
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=23.56, Qg=11.4 -> Pg=12.8, Qg=1.75
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=52.53, Qg=18.4 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=52.53, Qg=18.4 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=2.19, Qg=18.4 -> Pg=44.35, Qg=6.55
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=5.16, Qg=18.4 -> Pg=38.7, Qg=5.5
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=5.16, Qg=18.4 -> Pg=38.7, Qg=5.5
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61819	: Pg=2.06, Qg=12.3 -> Pg=13.65, Qg=1.95
% INFO    : Gen at bus 61819	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61820	: Pg=551.48, Qg=26.93 -> Pg=428.65, Qg=41.7
% INFO    : Gen at bus 61820	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61821	: Pg=445.74, Qg=-66.34 -> Pg=288.2, Qg=33.7
% INFO    : Gen at bus 61821	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61821	: Pg=445.74, Qg=-66.34 -> Pg=288.2, Qg=33.7
% INFO    : Gen at bus 61821	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61821	: Pg=534.0, Qg=-66.34 -> Pg=332.4, Qg=0.0
% INFO    : Gen at bus 61821	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61822	: Pg=855.52, Qg=7.24 -> Pg=653.4, Qg=122.7
% INFO    : Gen at bus 61822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61822	: Pg=395.41, Qg=7.24 -> Pg=298.0, Qg=29.9
% INFO    : Gen at bus 61822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61822	: Pg=381.93, Qg=7.24 -> Pg=291.25, Qg=54.8
% INFO    : Gen at bus 61822	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61823	: Pg=225.66, Qg=27.65 -> Pg=225.66, Qg=22.65
% INFO    : Gen at bus 61823	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61824	: Pg=44.2, Qg=2.97 -> Pg=66.65, Qg=12.75
% INFO    : Gen at bus 61824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61824	: Pg=44.2, Qg=2.97 -> Pg=66.65, Qg=12.75
% INFO    : Gen at bus 61824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61824	: Pg=44.2, Qg=2.97 -> Pg=66.65, Qg=12.75
% INFO    : Gen at bus 61824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61824	: Pg=44.2, Qg=2.97 -> Pg=66.65, Qg=12.75
% INFO    : Gen at bus 61824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61824	: Pg=65.33, Qg=2.97 -> Pg=107.3, Qg=21.4
% INFO    : Gen at bus 61824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61824	: Pg=293.16, Qg=2.97 -> Pg=214.3, Qg=42.05
% INFO    : Gen at bus 61824	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61825	: Pg=164.66, Qg=-69.0 -> Pg=153.5, Qg=15.65
% INFO    : Gen at bus 61825	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61825	: Pg=37.74, Qg=-12.6 -> Pg=28.9, Qg=5.4
% INFO    : Gen at bus 61825	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61825	: Pg=37.74, Qg=-12.6 -> Pg=28.9, Qg=5.4
% INFO    : Gen at bus 61825	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61826	: Pg=160.8, Qg=0.33 -> Pg=160.8, Qg=15.15
% INFO    : Gen at bus 61826	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61827	: Pg=151.78, Qg=21.23 -> Pg=151.78, Qg=15.05
% INFO    : Gen at bus 61827	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61828	: Pg=70.44, Qg=123.3 -> Pg=134.45, Qg=123.3
% INFO    : Gen at bus 61828	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 61828	: Pg=69.44, Qg=123.3 -> Pg=133.95, Qg=123.3
% INFO    : Gen at bus 61828	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 61829	: Pg=80.44, Qg=79.21 -> Pg=138.5, Qg=28.2
% INFO    : Gen at bus 61829	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61829	: Pg=80.44, Qg=79.21 -> Pg=138.5, Qg=28.2
% INFO    : Gen at bus 61829	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61830	: Pg=161.45, Qg=-3.24 -> Pg=153.35, Qg=27.45
% INFO    : Gen at bus 61830	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61830	: Pg=51.17, Qg=-3.24 -> Pg=38.65, Qg=4.45
% INFO    : Gen at bus 61830	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61831	: Pg=152.42, Qg=-69.0 -> Pg=142.5, Qg=0.0
% INFO    : Gen at bus 61831	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61831	: Pg=245.93, Qg=-91.8 -> Pg=200.2, Qg=20.8
% INFO    : Gen at bus 61831	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61832	: Pg=109.43, Qg=11.62 -> Pg=120.05, Qg=25.05
% INFO    : Gen at bus 61832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61832	: Pg=109.43, Qg=11.62 -> Pg=120.05, Qg=25.05
% INFO    : Gen at bus 61832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61832	: Pg=109.43, Qg=11.62 -> Pg=120.05, Qg=25.05
% INFO    : Gen at bus 61832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61832	: Pg=55.31, Qg=11.62 -> Pg=97.65, Qg=20.1
% INFO    : Gen at bus 61832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61832	: Pg=52.31, Qg=11.62 -> Pg=96.15, Qg=20.1
% INFO    : Gen at bus 61832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61832	: Pg=100.48, Qg=11.62 -> Pg=190.8, Qg=49.05
% INFO    : Gen at bus 61832	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61833	: Pg=101.01, Qg=5.56 -> Pg=128.55, Qg=25.05
% INFO    : Gen at bus 61833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61833	: Pg=101.01, Qg=5.56 -> Pg=128.55, Qg=25.05
% INFO    : Gen at bus 61833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61833	: Pg=64.74, Qg=5.56 -> Pg=199.45, Qg=48.0
% INFO    : Gen at bus 61833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61834	: Pg=103.68, Qg=-2.88 -> Pg=103.68, Qg=0.0
% INFO    : Gen at bus 61834	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61837	: Pg=80.33, Qg=-16.62 -> Pg=115.0, Qg=11.3
% INFO    : Gen at bus 61837	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61837	: Pg=80.33, Qg=-16.62 -> Pg=115.0, Qg=11.3
% INFO    : Gen at bus 61837	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61838	: Pg=130.98, Qg=10.31 -> Pg=137.25, Qg=24.45
% INFO    : Gen at bus 61838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61838	: Pg=64.28, Qg=10.31 -> Pg=86.875, Qg=23.4
% INFO    : Gen at bus 61838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61838	: Pg=64.28, Qg=10.31 -> Pg=86.875, Qg=23.4
% INFO    : Gen at bus 61838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61838	: Pg=380.23, Qg=10.31 -> Pg=297.9, Qg=54.55
% INFO    : Gen at bus 61838	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61839	: Pg=4.22, Qg=4.19 -> Pg=6.3, Qg=1.75
% INFO    : Gen at bus 61839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61840	: Pg=3.61, Qg=-1.32 -> Pg=4.65, Qg=1.19
% INFO    : Gen at bus 61840	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61841	: Pg=28.41, Qg=5.39 -> Pg=20.45, Qg=0.0
% INFO    : Gen at bus 61841	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61841	: Pg=28.41, Qg=5.39 -> Pg=20.45, Qg=0.0
% INFO    : Gen at bus 61841	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61841	: Pg=28.41, Qg=5.39 -> Pg=20.45, Qg=0.0
% INFO    : Gen at bus 61841	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61841	: Pg=28.41, Qg=5.39 -> Pg=20.45, Qg=0.0
% INFO    : Gen at bus 61841	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61842	: Pg=40.22, Qg=-18.42 -> Pg=50.0, Qg=0.0
% INFO    : Gen at bus 61842	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61842	: Pg=40.22, Qg=-18.42 -> Pg=50.0, Qg=0.0
% INFO    : Gen at bus 61842	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61843	: Pg=34.83, Qg=7.05 -> Pg=43.3, Qg=6.5
% INFO    : Gen at bus 61843	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61843	: Pg=34.83, Qg=7.05 -> Pg=43.3, Qg=6.5
% INFO    : Gen at bus 61843	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61844	: Pg=24.09, Qg=2.46 -> Pg=31.5, Qg=5.6
% INFO    : Gen at bus 61844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61844	: Pg=61.39, Qg=2.46 -> Pg=72.6, Qg=12.05
% INFO    : Gen at bus 61844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61845	: Pg=40.17, Qg=8.44 -> Pg=58.55, Qg=11.05
% INFO    : Gen at bus 61845	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61845	: Pg=40.17, Qg=8.44 -> Pg=58.55, Qg=11.05
% INFO    : Gen at bus 61845	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61846	: Pg=40.17, Qg=20.53 -> Pg=58.55, Qg=11.05
% INFO    : Gen at bus 61846	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61846	: Pg=40.17, Qg=20.53 -> Pg=58.55, Qg=11.05
% INFO    : Gen at bus 61846	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61847	: Pg=32.46, Qg=7.38 -> Pg=32.46, Qg=0.0
% INFO    : Gen at bus 61847	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61848	: Pg=15.12, Qg=32.1 -> Pg=33.4, Qg=32.1
% INFO    : Gen at bus 61848	: Vg=1.0063 -> Vg=1.0
% INFO    : Gen at bus 61848	: Pg=15.16, Qg=44.1 -> Pg=43.05, Qg=44.1
% INFO    : Gen at bus 61848	: Vg=1.0063 -> Vg=1.0
% INFO    : Gen at bus 61848	: Pg=15.16, Qg=44.1 -> Pg=43.05, Qg=44.1
% INFO    : Gen at bus 61848	: Vg=1.0063 -> Vg=1.0
% INFO    : Gen at bus 61849	: Pg=15.16, Qg=13.92 -> Pg=43.05, Qg=10.2
% INFO    : Gen at bus 61849	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61849	: Pg=15.16, Qg=13.92 -> Pg=43.05, Qg=10.2
% INFO    : Gen at bus 61849	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61850	: Pg=25.14, Qg=-6.32 -> Pg=44.85, Qg=4.85
% INFO    : Gen at bus 61850	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61850	: Pg=25.14, Qg=-6.32 -> Pg=44.85, Qg=4.85
% INFO    : Gen at bus 61850	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61851	: Pg=48.0, Qg=-17.55 -> Pg=48.0, Qg=0.0
% INFO    : Gen at bus 61851	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61852	: Pg=5.38, Qg=-4.24 -> Pg=12.6, Qg=2.835
% INFO    : Gen at bus 61852	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61852	: Pg=5.38, Qg=-4.24 -> Pg=12.6, Qg=2.835
% INFO    : Gen at bus 61852	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61852	: Pg=5.38, Qg=-4.24 -> Pg=12.6, Qg=2.835
% INFO    : Gen at bus 61852	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61853	: Pg=30.12, Qg=0.0 -> Pg=41.1, Qg=0.0
% INFO    : Gen at bus 61853	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61853	: Pg=30.12, Qg=0.0 -> Pg=41.1, Qg=0.0
% INFO    : Gen at bus 61853	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61853	: Pg=30.13, Qg=4.03 -> Pg=44.25, Qg=8.4
% INFO    : Gen at bus 61853	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61853	: Pg=30.13, Qg=4.03 -> Pg=44.25, Qg=8.4
% INFO    : Gen at bus 61853	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61853	: Pg=30.13, Qg=4.03 -> Pg=44.25, Qg=8.4
% INFO    : Gen at bus 61853	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61853	: Pg=30.13, Qg=4.03 -> Pg=44.25, Qg=8.4
% INFO    : Gen at bus 61853	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61853	: Pg=30.13, Qg=4.03 -> Pg=44.25, Qg=8.4
% INFO    : Gen at bus 61853	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61854	: Pg=40.8, Qg=0.0 -> Pg=40.8, Qg=0.0
% INFO    : Gen at bus 61854	: Vg=1.0166 -> Vg=1.0
% INFO    : Gen at bus 61855	: Pg=50.32, Qg=-4.52 -> Pg=30.2, Qg=3.8
% INFO    : Gen at bus 61855	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61855	: Pg=50.32, Qg=-4.52 -> Pg=30.2, Qg=3.8
% INFO    : Gen at bus 61855	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61856	: Pg=73.09, Qg=24.71 -> Pg=95.0, Qg=9.95
% INFO    : Gen at bus 61856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61856	: Pg=28.11, Qg=24.71 -> Pg=39.0, Qg=7.15
% INFO    : Gen at bus 61856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61856	: Pg=38.17, Qg=24.71 -> Pg=56.5, Qg=10.75
% INFO    : Gen at bus 61856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61857	: Pg=9.03, Qg=0.51 -> Pg=7.5, Qg=1.135
% INFO    : Gen at bus 61857	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61857	: Pg=9.03, Qg=0.51 -> Pg=7.5, Qg=1.135
% INFO    : Gen at bus 61857	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61857	: Pg=9.03, Qg=0.51 -> Pg=7.5, Qg=1.135
% INFO    : Gen at bus 61857	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61858	: Pg=8.74, Qg=6.39 -> Pg=21.6, Qg=3.25
% INFO    : Gen at bus 61858	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61858	: Pg=8.74, Qg=6.39 -> Pg=21.6, Qg=3.25
% INFO    : Gen at bus 61858	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61859	: Pg=8.7, Qg=15.6 -> Pg=21.5, Qg=15.6
% INFO    : Gen at bus 61859	: Vg=1.0008 -> Vg=1.0
% INFO    : Gen at bus 61859	: Pg=8.7, Qg=15.6 -> Pg=21.5, Qg=15.6
% INFO    : Gen at bus 61859	: Vg=1.0008 -> Vg=1.0
% INFO    : Gen at bus 61860	: Pg=24.17, Qg=46.5 -> Pg=49.5, Qg=46.5
% INFO    : Gen at bus 61860	: Vg=0.999 -> Vg=1.0
% INFO    : Gen at bus 61860	: Pg=11.55, Qg=24.9 -> Pg=25.83, Qg=24.9
% INFO    : Gen at bus 61860	: Vg=0.999 -> Vg=1.0
% INFO    : Gen at bus 61861	: Pg=14.09, Qg=24.3 -> Pg=27.0, Qg=24.3
% INFO    : Gen at bus 61861	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 61861	: Pg=54.25, Qg=68.2 -> Pg=75.94, Qg=68.2
% INFO    : Gen at bus 61861	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 61862	: Pg=7.72, Qg=9.29 -> Pg=19.1, Qg=0.0
% INFO    : Gen at bus 61862	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61863	: Pg=37.94, Qg=-8.89 -> Pg=26.5, Qg=5.45
% INFO    : Gen at bus 61863	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61863	: Pg=37.94, Qg=-8.89 -> Pg=26.5, Qg=5.45
% INFO    : Gen at bus 61863	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61863	: Pg=37.94, Qg=-8.89 -> Pg=26.5, Qg=5.45
% INFO    : Gen at bus 61863	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61863	: Pg=37.94, Qg=-8.89 -> Pg=26.5, Qg=5.45
% INFO    : Gen at bus 61863	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61863	: Pg=37.94, Qg=-8.89 -> Pg=26.5, Qg=5.45
% INFO    : Gen at bus 61863	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61863	: Pg=37.94, Qg=-8.89 -> Pg=26.5, Qg=5.45
% INFO    : Gen at bus 61863	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61864	: Pg=36.94, Qg=22.9 -> Pg=25.0, Qg=22.9
% INFO    : Gen at bus 61864	: Vg=0.997 -> Vg=1.0
% INFO    : Gen at bus 61865	: Pg=11.47, Qg=0.0 -> Pg=19.5, Qg=0.0
% INFO    : Gen at bus 61865	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61866	: Pg=23.76, Qg=-9.63 -> Pg=23.76, Qg=0.0
% INFO    : Gen at bus 61866	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61867	: Pg=11.26, Qg=13.6 -> Pg=14.0, Qg=13.6
% INFO    : Gen at bus 61867	: Vg=1.0094 -> Vg=1.0
% INFO    : Gen at bus 61869	: Pg=26.56, Qg=12.9 -> Pg=15.8, Qg=12.9
% INFO    : Gen at bus 61869	: Vg=1.0067 -> Vg=1.0
% INFO    : Gen at bus 61869	: Pg=26.56, Qg=12.9 -> Pg=15.8, Qg=12.9
% INFO    : Gen at bus 61869	: Vg=1.0067 -> Vg=1.0
% INFO    : Gen at bus 61870	: Pg=26.56, Qg=12.9 -> Pg=15.8, Qg=12.9
% INFO    : Gen at bus 61870	: Vg=0.9874 -> Vg=1.0
% INFO    : Gen at bus 61871	: Pg=10.6, Qg=-4.4 -> Pg=10.6, Qg=1.375
% INFO    : Gen at bus 61871	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61871	: Pg=10.6, Qg=-4.4 -> Pg=10.6, Qg=1.375
% INFO    : Gen at bus 61871	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61872	: Pg=10.43, Qg=1.67 -> Pg=6.5, Qg=0.975
% INFO    : Gen at bus 61872	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61872	: Pg=10.43, Qg=1.67 -> Pg=6.5, Qg=0.975
% INFO    : Gen at bus 61872	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61873	: Pg=10.06, Qg=15.5 -> Pg=17.5, Qg=15.5
% INFO    : Gen at bus 61873	: Vg=0.9891 -> Vg=1.0
% INFO    : Gen at bus 61875	: Pg=4.06, Qg=6.83 -> Pg=14.5, Qg=1.9
% INFO    : Gen at bus 61875	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=23.05, Qg=8.78 -> Pg=23.4, Qg=3.4
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=23.05, Qg=8.78 -> Pg=23.4, Qg=3.4
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=32.08, Qg=8.78 -> Pg=34.5, Qg=5.3
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=19.89, Qg=8.78 -> Pg=21.815, Qg=3.4
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=19.89, Qg=8.78 -> Pg=21.815, Qg=3.4
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=15.08, Qg=8.78 -> Pg=26.0, Qg=5.3
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=10.08, Qg=8.78 -> Pg=24.0, Qg=7.9
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61876	: Pg=30.2, Qg=8.78 -> Pg=60.0, Qg=18.75
% INFO    : Gen at bus 61876	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61877	: Pg=6.02, Qg=-3.75 -> Pg=8.625, Qg=1.6
% INFO    : Gen at bus 61877	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61877	: Pg=6.02, Qg=-3.75 -> Pg=8.625, Qg=1.6
% INFO    : Gen at bus 61877	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61878	: Pg=18.0, Qg=2.8 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 61878	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61878	: Pg=121.44, Qg=2.8 -> Pg=121.44, Qg=0.0
% INFO    : Gen at bus 61878	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61879	: Pg=3.04, Qg=15.0 -> Pg=11.5, Qg=15.0
% INFO    : Gen at bus 61879	: Vg=0.9958 -> Vg=1.0
% INFO    : Gen at bus 61880	: Pg=368.45, Qg=-61.73 -> Pg=259.5, Qg=27.85
% INFO    : Gen at bus 61880	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61880	: Pg=368.45, Qg=-61.73 -> Pg=259.5, Qg=27.85
% INFO    : Gen at bus 61880	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61880	: Pg=554.17, Qg=-61.73 -> Pg=352.5, Qg=41.9
% INFO    : Gen at bus 61880	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61880	: Pg=554.17, Qg=-61.73 -> Pg=352.5, Qg=41.9
% INFO    : Gen at bus 61880	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61881	: Pg=224.17, Qg=39.74 -> Pg=173.5, Qg=19.4
% INFO    : Gen at bus 61881	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61882	: Pg=163.2, Qg=20.72 -> Pg=163.2, Qg=15.4
% INFO    : Gen at bus 61882	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61883	: Pg=96.71, Qg=-13.8 -> Pg=159.3, Qg=37.9
% INFO    : Gen at bus 61883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61883	: Pg=110.44, Qg=-13.8 -> Pg=153.45, Qg=14.9
% INFO    : Gen at bus 61883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61883	: Pg=110.44, Qg=-13.8 -> Pg=153.45, Qg=14.9
% INFO    : Gen at bus 61883	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61884	: Pg=144.06, Qg=9.52 -> Pg=132.05, Qg=14.35
% INFO    : Gen at bus 61884	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61884	: Pg=144.06, Qg=9.52 -> Pg=132.05, Qg=14.35
% INFO    : Gen at bus 61884	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61884	: Pg=816.88, Qg=9.52 -> Pg=591.05, Qg=61.75
% INFO    : Gen at bus 61884	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61884	: Pg=816.88, Qg=9.52 -> Pg=591.05, Qg=61.75
% INFO    : Gen at bus 61884	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61884	: Pg=223.05, Qg=9.52 -> Pg=176.115, Qg=19.1
% INFO    : Gen at bus 61884	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61885	: Pg=99.79, Qg=-59.0 -> Pg=128.5, Qg=13.35
% INFO    : Gen at bus 61885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61885	: Pg=50.24, Qg=-36.7 -> Pg=80.0, Qg=15.75
% INFO    : Gen at bus 61885	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61886	: Pg=130.39, Qg=22.39 -> Pg=152.5, Qg=25.1
% INFO    : Gen at bus 61886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61886	: Pg=130.39, Qg=22.39 -> Pg=152.5, Qg=25.1
% INFO    : Gen at bus 61886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61886	: Pg=130.67, Qg=22.39 -> Pg=215.0, Qg=42.95
% INFO    : Gen at bus 61886	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61887	: Pg=80.35, Qg=23.28 -> Pg=119.75, Qg=0.0
% INFO    : Gen at bus 61887	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61888	: Pg=80.33, Qg=93.0 -> Pg=115.0, Qg=93.0
% INFO    : Gen at bus 61888	: Vg=1.0061 -> Vg=1.0
% INFO    : Gen at bus 61889	: Pg=87.28, Qg=11.32 -> Pg=106.95, Qg=9.6
% INFO    : Gen at bus 61889	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61889	: Pg=87.28, Qg=11.32 -> Pg=106.95, Qg=9.6
% INFO    : Gen at bus 61889	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61890	: Pg=96.0, Qg=26.6 -> Pg=96.0, Qg=0.0
% INFO    : Gen at bus 61890	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61891	: Pg=81.92, Qg=9.14 -> Pg=81.92, Qg=0.0
% INFO    : Gen at bus 61891	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61893	: Pg=72.0, Qg=-21.41 -> Pg=72.0, Qg=0.0
% INFO    : Gen at bus 61893	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61894	: Pg=35.25, Qg=10.08 -> Pg=74.3, Qg=16.25
% INFO    : Gen at bus 61894	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61894	: Pg=60.19, Qg=10.08 -> Pg=73.45, Qg=6.55
% INFO    : Gen at bus 61894	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61895	: Pg=11.18, Qg=-6.12 -> Pg=21.0, Qg=2.85
% INFO    : Gen at bus 61895	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61895	: Pg=16.12, Qg=-6.12 -> Pg=30.25, Qg=5.25
% INFO    : Gen at bus 61895	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61896	: Pg=46.37, Qg=11.19 -> Pg=106.25, Qg=12.55
% INFO    : Gen at bus 61896	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61896	: Pg=20.11, Qg=11.19 -> Pg=35.0, Qg=7.15
% INFO    : Gen at bus 61896	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61896	: Pg=20.11, Qg=11.19 -> Pg=35.0, Qg=7.15
% INFO    : Gen at bus 61896	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61897	: Pg=46.43, Qg=-7.42 -> Pg=35.75, Qg=6.65
% INFO    : Gen at bus 61897	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61897	: Pg=46.43, Qg=-7.42 -> Pg=35.75, Qg=6.65
% INFO    : Gen at bus 61897	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61897	: Pg=46.43, Qg=-7.42 -> Pg=35.75, Qg=6.65
% INFO    : Gen at bus 61897	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61897	: Pg=46.43, Qg=-7.42 -> Pg=35.75, Qg=6.65
% INFO    : Gen at bus 61897	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61898	: Pg=0.51, Qg=0.32 -> Pg=1.765, Qg=0.63
% INFO    : Gen at bus 61898	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61899	: Pg=15.0, Qg=7.27 -> Pg=15.0, Qg=7.27
% INFO    : Gen at bus 61899	: Vg=0.9872 -> Vg=1.0
% INFO    : Gen at bus 61899	: Pg=15.0, Qg=7.27 -> Pg=15.0, Qg=7.27
% INFO    : Gen at bus 61899	: Vg=0.9872 -> Vg=1.0
% INFO    : Gen at bus 61899	: Pg=15.0, Qg=7.27 -> Pg=15.0, Qg=7.27
% INFO    : Gen at bus 61899	: Vg=0.9872 -> Vg=1.0
% INFO    : Gen at bus 61900	: Pg=12.1, Qg=27.3 -> Pg=28.0, Qg=27.3
% INFO    : Gen at bus 61900	: Vg=0.9937 -> Vg=1.0
% INFO    : Gen at bus 61900	: Pg=12.1, Qg=27.3 -> Pg=28.0, Qg=27.3
% INFO    : Gen at bus 61900	: Vg=0.9937 -> Vg=1.0
% INFO    : Gen at bus 61900	: Pg=17.15, Qg=40.9 -> Pg=41.5, Qg=40.9
% INFO    : Gen at bus 61900	: Vg=0.9937 -> Vg=1.0
% INFO    : Gen at bus 61901	: Pg=10.86, Qg=16.7 -> Pg=13.5, Qg=3.85
% INFO    : Gen at bus 61901	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61901	: Pg=12.09, Qg=20.3 -> Pg=26.0, Qg=8.35
% INFO    : Gen at bus 61901	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61902	: Pg=30.6, Qg=-9.28 -> Pg=15.3, Qg=2.3
% INFO    : Gen at bus 61902	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61903	: Pg=30.35, Qg=2.82 -> Pg=28.2, Qg=2.3
% INFO    : Gen at bus 61903	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61903	: Pg=30.35, Qg=2.82 -> Pg=28.2, Qg=2.3
% INFO    : Gen at bus 61903	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61903	: Pg=30.35, Qg=2.82 -> Pg=28.2, Qg=2.3
% INFO    : Gen at bus 61903	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61903	: Pg=30.35, Qg=2.82 -> Pg=28.2, Qg=2.3
% INFO    : Gen at bus 61903	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61904	: Pg=9.63, Qg=7.25 -> Pg=10.5, Qg=7.25
% INFO    : Gen at bus 61904	: Vg=0.9944 -> Vg=1.0
% INFO    : Gen at bus 61904	: Pg=9.63, Qg=7.25 -> Pg=10.5, Qg=7.25
% INFO    : Gen at bus 61904	: Vg=0.9944 -> Vg=1.0
% INFO    : Gen at bus 61905	: Pg=9.29, Qg=-2.94 -> Pg=4.65, Qg=0.0
% INFO    : Gen at bus 61905	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61905	: Pg=9.29, Qg=-2.94 -> Pg=4.65, Qg=0.0
% INFO    : Gen at bus 61905	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61905	: Pg=9.29, Qg=-2.94 -> Pg=4.65, Qg=0.0
% INFO    : Gen at bus 61905	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61906	: Pg=3.66, Qg=-3.62 -> Pg=8.19, Qg=1.55
% INFO    : Gen at bus 61906	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61906	: Pg=3.66, Qg=-3.62 -> Pg=8.19, Qg=1.55
% INFO    : Gen at bus 61906	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61906	: Pg=12.28, Qg=-3.62 -> Pg=9.15, Qg=2.575
% INFO    : Gen at bus 61906	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61906	: Pg=12.28, Qg=-3.62 -> Pg=9.15, Qg=2.575
% INFO    : Gen at bus 61906	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61907	: Pg=20.0, Qg=9.7 -> Pg=20.0, Qg=9.7
% INFO    : Gen at bus 61907	: Vg=0.9813 -> Vg=1.0
% INFO    : Gen at bus 61908	: Pg=16.0, Qg=-4.23 -> Pg=16.0, Qg=0.0
% INFO    : Gen at bus 61908	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61908	: Pg=48.0, Qg=-4.23 -> Pg=48.0, Qg=0.0
% INFO    : Gen at bus 61908	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61909	: Pg=816.88, Qg=269.38 -> Pg=582.08, Qg=66.35
% INFO    : Gen at bus 61909	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61909	: Pg=816.88, Qg=269.38 -> Pg=582.08, Qg=66.35
% INFO    : Gen at bus 61909	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=13.06, Qg=13.5 -> Pg=20.4, Qg=13.5
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=119.46, Qg=57.93 -> Pg=80.48, Qg=57.93
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=13.06, Qg=13.5 -> Pg=20.4, Qg=13.5
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=21.11, Qg=24.1 -> Pg=35.4, Qg=24.1
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=18.13, Qg=29.3 -> Pg=39.25, Qg=29.3
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=18.13, Qg=29.3 -> Pg=39.25, Qg=29.3
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=18.13, Qg=29.3 -> Pg=39.25, Qg=29.3
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=18.13, Qg=29.3 -> Pg=39.25, Qg=29.3
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=119.46, Qg=57.93 -> Pg=80.48, Qg=57.93
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61910	: Pg=119.46, Qg=57.93 -> Pg=80.48, Qg=57.93
% INFO    : Gen at bus 61910	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 61911	: Pg=276.79, Qg=33.0 -> Pg=183.6, Qg=20.95
% INFO    : Gen at bus 61911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61911	: Pg=289.37, Qg=33.0 -> Pg=189.9, Qg=21.9
% INFO    : Gen at bus 61911	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61912	: Pg=210.14, Qg=27.38 -> Pg=161.0, Qg=18.25
% INFO    : Gen at bus 61912	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61913	: Pg=102.69, Qg=46.66 -> Pg=187.4, Qg=47.25
% INFO    : Gen at bus 61913	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61913	: Pg=102.69, Qg=46.66 -> Pg=187.4, Qg=47.25
% INFO    : Gen at bus 61913	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61913	: Pg=90.45, Qg=46.66 -> Pg=145.75, Qg=28.85
% INFO    : Gen at bus 61913	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61913	: Pg=90.45, Qg=46.66 -> Pg=145.75, Qg=28.85
% INFO    : Gen at bus 61913	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61913	: Pg=90.45, Qg=46.66 -> Pg=145.75, Qg=28.85
% INFO    : Gen at bus 61913	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61913	: Pg=90.45, Qg=46.66 -> Pg=145.75, Qg=28.85
% INFO    : Gen at bus 61913	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61914	: Pg=90.66, Qg=-31.43 -> Pg=157.65, Qg=38.7
% INFO    : Gen at bus 61914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61914	: Pg=90.44, Qg=-31.43 -> Pg=143.6, Qg=28.25
% INFO    : Gen at bus 61914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61914	: Pg=90.44, Qg=-31.43 -> Pg=143.6, Qg=28.25
% INFO    : Gen at bus 61914	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61915	: Pg=100.4, Qg=-4.79 -> Pg=139.0, Qg=25.5
% INFO    : Gen at bus 61915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61915	: Pg=100.4, Qg=-4.79 -> Pg=139.0, Qg=25.5
% INFO    : Gen at bus 61915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61915	: Pg=110.74, Qg=-4.79 -> Pg=221.2, Qg=47.6
% INFO    : Gen at bus 61915	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61916	: Pg=107.19, Qg=43.97 -> Pg=132.0, Qg=24.9
% INFO    : Gen at bus 61916	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61916	: Pg=107.19, Qg=43.97 -> Pg=132.0, Qg=24.9
% INFO    : Gen at bus 61916	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61916	: Pg=95.08, Qg=43.97 -> Pg=153.8, Qg=19.05
% INFO    : Gen at bus 61916	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61917	: Pg=106.38, Qg=27.07 -> Pg=130.0, Qg=24.35
% INFO    : Gen at bus 61917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61917	: Pg=106.38, Qg=27.07 -> Pg=130.0, Qg=24.35
% INFO    : Gen at bus 61917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61917	: Pg=110.44, Qg=27.07 -> Pg=153.0, Qg=28.1
% INFO    : Gen at bus 61917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=12.44, Qg=-0.24 -> Pg=30.75, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=25.68, Qg=-0.24 -> Pg=63.5, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=25.68, Qg=-0.24 -> Pg=63.5, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=27.1
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=13.85, Qg=-0.24 -> Pg=34.25, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61918	: Pg=26.29, Qg=-0.24 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 61918	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61919	: Pg=7.02, Qg=-2.8 -> Pg=7.7, Qg=1.75
% INFO    : Gen at bus 61919	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61920	: Pg=18.26, Qg=25.0 -> Pg=66.5, Qg=16.5
% INFO    : Gen at bus 61920	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61920	: Pg=18.26, Qg=25.0 -> Pg=66.5, Qg=16.5
% INFO    : Gen at bus 61920	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=51.91, Qg=8.65 -> Pg=54.45, Qg=8.45
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=5.16, Qg=8.65 -> Pg=38.7, Qg=5.5
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=45.21, Qg=8.65 -> Pg=68.75, Qg=7.0
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=45.21, Qg=8.65 -> Pg=68.75, Qg=7.0
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=45.21, Qg=8.65 -> Pg=68.75, Qg=7.0
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=45.21, Qg=8.65 -> Pg=68.75, Qg=7.0
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=32.23, Qg=8.65 -> Pg=68.2, Qg=7.9
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=32.23, Qg=8.65 -> Pg=68.2, Qg=7.9
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61922	: Pg=52.23, Qg=8.65 -> Pg=55.25, Qg=8.65
% INFO    : Gen at bus 61922	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61923	: Pg=23.44, Qg=46.9 -> Pg=52.43, Qg=46.9
% INFO    : Gen at bus 61923	: Vg=1.0229 -> Vg=1.0
% INFO    : Gen at bus 61923	: Pg=42.69, Qg=48.2 -> Pg=63.75, Qg=48.2
% INFO    : Gen at bus 61923	: Vg=1.0229 -> Vg=1.0
% INFO    : Gen at bus 61924	: Pg=30.23, Qg=-10.11 -> Pg=65.75, Qg=7.7
% INFO    : Gen at bus 61924	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61924	: Pg=30.19, Qg=-10.11 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 61924	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61925	: Pg=75.7, Qg=46.9 -> Pg=40.73, Qg=46.9
% INFO    : Gen at bus 61925	: Vg=1.0185 -> Vg=1.0
% INFO    : Gen at bus 61926	: Pg=70.16, Qg=35.8 -> Pg=72.0, Qg=35.8
% INFO    : Gen at bus 61926	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 61926	: Pg=70.16, Qg=35.8 -> Pg=72.0, Qg=35.8
% INFO    : Gen at bus 61926	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 61926	: Pg=70.16, Qg=35.8 -> Pg=72.0, Qg=35.8
% INFO    : Gen at bus 61926	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 61928	: Pg=60.41, Qg=16.9 -> Pg=32.75, Qg=16.9
% INFO    : Gen at bus 61928	: Vg=0.9936 -> Vg=1.0
% INFO    : Gen at bus 61929	: Pg=9.6, Qg=4.64 -> Pg=4.8, Qg=4.64
% INFO    : Gen at bus 61929	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 61929	: Pg=9.6, Qg=4.64 -> Pg=4.8, Qg=4.64
% INFO    : Gen at bus 61929	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 61929	: Pg=9.6, Qg=4.64 -> Pg=4.8, Qg=4.64
% INFO    : Gen at bus 61929	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 61929	: Pg=9.6, Qg=4.64 -> Pg=4.8, Qg=4.64
% INFO    : Gen at bus 61929	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 61929	: Pg=9.6, Qg=4.64 -> Pg=4.8, Qg=4.64
% INFO    : Gen at bus 61929	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 61931	: Pg=33.1, Qg=1.23 -> Pg=39.05, Qg=6.5
% INFO    : Gen at bus 61931	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61931	: Pg=33.1, Qg=1.23 -> Pg=39.05, Qg=6.5
% INFO    : Gen at bus 61931	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61931	: Pg=22.08, Qg=1.23 -> Pg=29.5, Qg=5.3
% INFO    : Gen at bus 61931	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61932	: Pg=8.21, Qg=4.43 -> Pg=7.46, Qg=4.43
% INFO    : Gen at bus 61932	: Vg=0.9943 -> Vg=1.0
% INFO    : Gen at bus 61932	: Pg=8.21, Qg=4.43 -> Pg=7.46, Qg=4.43
% INFO    : Gen at bus 61932	: Vg=0.9943 -> Vg=1.0
% INFO    : Gen at bus 61932	: Pg=8.21, Qg=4.43 -> Pg=7.46, Qg=4.43
% INFO    : Gen at bus 61932	: Vg=0.9943 -> Vg=1.0
% INFO    : Gen at bus 61932	: Pg=8.21, Qg=4.43 -> Pg=7.46, Qg=4.43
% INFO    : Gen at bus 61932	: Vg=0.9943 -> Vg=1.0
% INFO    : Gen at bus 61933	: Pg=14.98, Qg=0.19 -> Pg=11.4, Qg=3.125
% INFO    : Gen at bus 61933	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61933	: Pg=14.98, Qg=0.19 -> Pg=11.4, Qg=3.125
% INFO    : Gen at bus 61933	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61934	: Pg=14.98, Qg=-1.66 -> Pg=11.45, Qg=3.125
% INFO    : Gen at bus 61934	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61934	: Pg=14.98, Qg=-1.66 -> Pg=11.45, Qg=3.125
% INFO    : Gen at bus 61934	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61936	: Pg=12.98, Qg=9.75 -> Pg=10.875, Qg=9.75
% INFO    : Gen at bus 61936	: Vg=0.9992 -> Vg=1.0
% INFO    : Gen at bus 61936	: Pg=12.98, Qg=9.75 -> Pg=10.875, Qg=9.75
% INFO    : Gen at bus 61936	: Vg=0.9992 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=32.27, Qg=13.32 -> Pg=75.9, Qg=9.05
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=103.09, Qg=13.32 -> Pg=181.0, Qg=44.7
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=5.53, Qg=7.6 -> Pg=9.0, Qg=1.725
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=5.53, Qg=7.6 -> Pg=9.0, Qg=1.725
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=111.47, Qg=13.32 -> Pg=127.8, Qg=22.25
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=111.47, Qg=13.32 -> Pg=127.8, Qg=22.25
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=18.81, Qg=13.32 -> Pg=34.35, Qg=7.15
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=24.57, Qg=13.32 -> Pg=49.7, Qg=10.75
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=35.15, Qg=13.32 -> Pg=52.35, Qg=10.0
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61937	: Pg=17.11, Qg=13.32 -> Pg=33.6, Qg=7.2
% INFO    : Gen at bus 61937	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61938	: Pg=11.78, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 61938	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61938	: Pg=11.78, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 61938	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61939	: Pg=11.73, Qg=2.57 -> Pg=9.0, Qg=2.45
% INFO    : Gen at bus 61939	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61939	: Pg=11.73, Qg=2.57 -> Pg=9.0, Qg=2.45
% INFO    : Gen at bus 61939	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61941	: Pg=19.05, Qg=-6.9 -> Pg=20.6, Qg=1.7
% INFO    : Gen at bus 61941	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61941	: Pg=19.05, Qg=-6.9 -> Pg=20.6, Qg=1.7
% INFO    : Gen at bus 61941	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61941	: Pg=19.05, Qg=-6.9 -> Pg=20.6, Qg=1.7
% INFO    : Gen at bus 61941	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61941	: Pg=14.95, Qg=-6.9 -> Pg=17.35, Qg=2.25
% INFO    : Gen at bus 61941	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61942	: Pg=21.27, Qg=7.0 -> Pg=11.15, Qg=7.0
% INFO    : Gen at bus 61942	: Vg=0.9435 -> Vg=1.0
% INFO    : Gen at bus 61942	: Pg=21.27, Qg=7.0 -> Pg=11.15, Qg=7.0
% INFO    : Gen at bus 61942	: Vg=0.9435 -> Vg=1.0
% INFO    : Gen at bus 61942	: Pg=21.27, Qg=7.0 -> Pg=11.15, Qg=7.0
% INFO    : Gen at bus 61942	: Vg=0.9435 -> Vg=1.0
% INFO    : Gen at bus 61943	: Pg=10.04, Qg=-0.07 -> Pg=6.925, Qg=2.1
% INFO    : Gen at bus 61943	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61943	: Pg=10.04, Qg=-0.07 -> Pg=6.925, Qg=2.1
% INFO    : Gen at bus 61943	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61944	: Pg=818.78, Qg=-68.92 -> Pg=570.0, Qg=61.9
% INFO    : Gen at bus 61944	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61944	: Pg=818.78, Qg=-68.92 -> Pg=570.0, Qg=61.9
% INFO    : Gen at bus 61944	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61945	: Pg=526.42, Qg=2.63 -> Pg=373.6, Qg=0.0
% INFO    : Gen at bus 61945	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61945	: Pg=524.22, Qg=2.63 -> Pg=347.0, Qg=0.0
% INFO    : Gen at bus 61945	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61945	: Pg=524.22, Qg=2.63 -> Pg=317.0, Qg=0.0
% INFO    : Gen at bus 61945	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 61946	: Pg=498.76, Qg=-15.07 -> Pg=354.75, Qg=0.0
% INFO    : Gen at bus 61946	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61947	: Pg=540.49, Qg=-16.56 -> Pg=330.65, Qg=0.0
% INFO    : Gen at bus 61947	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61947	: Pg=495.26, Qg=-16.56 -> Pg=308.0, Qg=37.45
% INFO    : Gen at bus 61947	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61948	: Pg=130.24, Qg=-65.81 -> Pg=130.24, Qg=15.4
% INFO    : Gen at bus 61948	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61949	: Pg=140.56, Qg=66.39 -> Pg=195.5, Qg=18.95
% INFO    : Gen at bus 61949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61949	: Pg=120.45, Qg=66.39 -> Pg=161.5, Qg=15.3
% INFO    : Gen at bus 61949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61949	: Pg=120.45, Qg=66.39 -> Pg=161.5, Qg=15.3
% INFO    : Gen at bus 61949	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61951	: Pg=58.97, Qg=4.61 -> Pg=79.3, Qg=16.25
% INFO    : Gen at bus 61951	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61951	: Pg=25.17, Qg=4.61 -> Pg=50.0, Qg=10.75
% INFO    : Gen at bus 61951	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61952	: Pg=25.3, Qg=6.94 -> Pg=79.3, Qg=19.15
% INFO    : Gen at bus 61952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61952	: Pg=25.16, Qg=6.94 -> Pg=47.75, Qg=10.1
% INFO    : Gen at bus 61952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61952	: Pg=20.17, Qg=6.94 -> Pg=47.5, Qg=15.65
% INFO    : Gen at bus 61952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61952	: Pg=10.16, Qg=6.94 -> Pg=40.5, Qg=10.15
% INFO    : Gen at bus 61952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61952	: Pg=10.16, Qg=6.94 -> Pg=40.5, Qg=10.15
% INFO    : Gen at bus 61952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61952	: Pg=10.16, Qg=6.94 -> Pg=40.5, Qg=10.15
% INFO    : Gen at bus 61952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 61953	: Pg=10.23, Qg=1.68 -> Pg=25.3, Qg=3.8
% INFO    : Gen at bus 61953	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61953	: Pg=10.23, Qg=1.68 -> Pg=25.3, Qg=3.8
% INFO    : Gen at bus 61953	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61953	: Pg=10.23, Qg=1.68 -> Pg=25.3, Qg=3.8
% INFO    : Gen at bus 61953	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61954	: Pg=15.98, Qg=-3.91 -> Pg=9.0, Qg=2.285
% INFO    : Gen at bus 61954	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61954	: Pg=15.98, Qg=-3.91 -> Pg=9.0, Qg=2.285
% INFO    : Gen at bus 61954	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61954	: Pg=15.98, Qg=-3.91 -> Pg=9.0, Qg=2.285
% INFO    : Gen at bus 61954	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61956	: Pg=13.98, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 61956	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61956	: Pg=13.98, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 61956	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61956	: Pg=13.98, Qg=0.0 -> Pg=10.5, Qg=0.0
% INFO    : Gen at bus 61956	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61958	: Pg=55.18, Qg=3.19 -> Pg=68.5, Qg=11.75
% INFO    : Gen at bus 61958	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61958	: Pg=17.06, Qg=3.19 -> Pg=21.0, Qg=5.25
% INFO    : Gen at bus 61958	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61958	: Pg=17.06, Qg=3.19 -> Pg=21.0, Qg=5.25
% INFO    : Gen at bus 61958	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61958	: Pg=27.11, Qg=3.19 -> Pg=38.5, Qg=10.4
% INFO    : Gen at bus 61958	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61958	: Pg=8.91, Qg=3.19 -> Pg=17.45, Qg=4.55
% INFO    : Gen at bus 61958	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 61960	: Pg=9.03, Qg=11.25 -> Pg=7.5, Qg=11.25
% INFO    : Gen at bus 61960	: Vg=0.9752 -> Vg=1.0
% INFO    : Gen at bus 61960	: Pg=9.03, Qg=11.25 -> Pg=7.5, Qg=11.25
% INFO    : Gen at bus 61960	: Vg=0.9752 -> Vg=1.0
% INFO    : Gen at bus 61961	: Pg=4.76, Qg=-2.17 -> Pg=5.625, Qg=1.35
% INFO    : Gen at bus 61961	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61961	: Pg=4.76, Qg=-2.17 -> Pg=5.625, Qg=1.35
% INFO    : Gen at bus 61961	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61961	: Pg=4.76, Qg=-2.17 -> Pg=5.625, Qg=1.35
% INFO    : Gen at bus 61961	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61961	: Pg=4.76, Qg=-2.17 -> Pg=5.625, Qg=1.35
% INFO    : Gen at bus 61961	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61962	: Pg=12.48, Qg=-4.15 -> Pg=9.75, Qg=2.625
% INFO    : Gen at bus 61962	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 61962	: Pg=12.48, Qg=-4.15 -> Pg=9.75, Qg=2.625
% INFO    : Gen at bus 61962	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66499	: Pg=1159.0, Qg=13.75 -> Pg=579.5, Qg=87.5
% INFO    : Gen at bus 66499	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66499	: Pg=1164.0, Qg=13.75 -> Pg=582.0, Qg=87.9
% INFO    : Gen at bus 66499	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66500	: Pg=1127.0, Qg=529.8 -> Pg=822.71, Qg=529.8
% INFO    : Gen at bus 66500	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66500	: Pg=1127.0, Qg=-136.43 -> Pg=822.71, Qg=0.0
% INFO    : Gen at bus 66500	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66501	: Pg=101.79, Qg=50.52 -> Pg=453.0, Qg=115.4
% INFO    : Gen at bus 66501	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66501	: Pg=51.79, Qg=50.52 -> Pg=428.0, Qg=115.4
% INFO    : Gen at bus 66501	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66502	: Pg=170.91, Qg=30.33 -> Pg=289.75, Qg=30.9
% INFO    : Gen at bus 66502	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66502	: Pg=170.91, Qg=30.33 -> Pg=289.75, Qg=30.9
% INFO    : Gen at bus 66502	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66503	: Pg=61.83, Qg=10.86 -> Pg=210.015, Qg=33.6
% INFO    : Gen at bus 66503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66503	: Pg=61.83, Qg=10.86 -> Pg=210.015, Qg=33.6
% INFO    : Gen at bus 66503	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66504	: Pg=83.78, Qg=19.86 -> Pg=217.0, Qg=26.5
% INFO    : Gen at bus 66504	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66504	: Pg=83.78, Qg=19.86 -> Pg=217.0, Qg=26.5
% INFO    : Gen at bus 66504	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66504	: Pg=83.78, Qg=19.86 -> Pg=217.0, Qg=26.5
% INFO    : Gen at bus 66504	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66505	: Pg=20.76, Qg=165.6 -> Pg=181.0, Qg=165.6
% INFO    : Gen at bus 66505	: Vg=1.0139 -> Vg=1.0
% INFO    : Gen at bus 66505	: Pg=20.76, Qg=178.0 -> Pg=181.0, Qg=178.0
% INFO    : Gen at bus 66505	: Vg=1.0139 -> Vg=1.0
% INFO    : Gen at bus 66506	: Pg=25.74, Qg=161.3 -> Pg=179.0, Qg=161.3
% INFO    : Gen at bus 66506	: Vg=1.0129 -> Vg=1.0
% INFO    : Gen at bus 66506	: Pg=25.74, Qg=161.3 -> Pg=179.0, Qg=161.3
% INFO    : Gen at bus 66506	: Vg=1.0129 -> Vg=1.0
% INFO    : Gen at bus 66507	: Pg=266.0, Qg=161.0 -> Pg=266.0, Qg=161.0
% INFO    : Gen at bus 66507	: Vg=1.0284 -> Vg=1.0
% INFO    : Gen at bus 66508	: Pg=86.67, Qg=6.66 -> Pg=418.05, Qg=56.7
% INFO    : Gen at bus 66508	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66508	: Pg=45.72, Qg=6.66 -> Pg=185.7, Qg=46.75
% INFO    : Gen at bus 66508	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66508	: Pg=45.72, Qg=6.66 -> Pg=185.7, Qg=46.75
% INFO    : Gen at bus 66508	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66509	: Pg=140.67, Qg=-14.93 -> Pg=220.0, Qg=0.0
% INFO    : Gen at bus 66509	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66509	: Pg=140.67, Qg=-14.93 -> Pg=220.0, Qg=0.0
% INFO    : Gen at bus 66509	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66509	: Pg=140.67, Qg=-14.93 -> Pg=220.0, Qg=0.0
% INFO    : Gen at bus 66509	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66509	: Pg=140.67, Qg=-14.93 -> Pg=220.0, Qg=0.0
% INFO    : Gen at bus 66509	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66510	: Pg=120.55, Qg=0.0 -> Pg=183.7, Qg=0.0
% INFO    : Gen at bus 66510	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=53.56, Qg=17.75 -> Pg=377.0, Qg=53.0
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=53.56, Qg=17.75 -> Pg=377.0, Qg=53.0
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=80.52, Qg=17.75 -> Pg=156.5, Qg=33.35
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=80.52, Qg=17.75 -> Pg=156.5, Qg=33.35
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=80.52, Qg=17.75 -> Pg=156.5, Qg=33.35
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=80.52, Qg=17.75 -> Pg=156.5, Qg=33.35
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=60.52, Qg=17.75 -> Pg=146.5, Qg=33.35
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66511	: Pg=60.52, Qg=17.75 -> Pg=146.5, Qg=33.35
% INFO    : Gen at bus 66511	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66512	: Pg=56.75, Qg=0.0 -> Pg=140.625, Qg=0.0
% INFO    : Gen at bus 66512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66512	: Pg=57.25, Qg=0.0 -> Pg=141.875, Qg=0.0
% INFO    : Gen at bus 66512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66512	: Pg=20.48, Qg=0.0 -> Pg=119.0, Qg=0.0
% INFO    : Gen at bus 66512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66512	: Pg=20.48, Qg=0.0 -> Pg=119.0, Qg=0.0
% INFO    : Gen at bus 66512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66513	: Pg=110.47, Qg=28.01 -> Pg=161.0, Qg=0.0
% INFO    : Gen at bus 66513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66513	: Pg=110.47, Qg=28.01 -> Pg=161.0, Qg=0.0
% INFO    : Gen at bus 66513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66513	: Pg=55.47, Qg=28.01 -> Pg=133.5, Qg=0.0
% INFO    : Gen at bus 66513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66514	: Pg=80.68, Qg=5.56 -> Pg=193.0, Qg=43.8
% INFO    : Gen at bus 66514	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66514	: Pg=125.47, Qg=5.56 -> Pg=168.5, Qg=30.35
% INFO    : Gen at bus 66514	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66514	: Pg=115.47, Qg=5.56 -> Pg=163.5, Qg=30.35
% INFO    : Gen at bus 66514	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66514	: Pg=115.47, Qg=5.56 -> Pg=164.25, Qg=30.55
% INFO    : Gen at bus 66514	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66515	: Pg=75.45, Qg=45.9 -> Pg=139.1, Qg=29.1
% INFO    : Gen at bus 66515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66515	: Pg=75.45, Qg=45.9 -> Pg=139.1, Qg=29.1
% INFO    : Gen at bus 66515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66515	: Pg=55.47, Qg=45.9 -> Pg=134.15, Qg=30.55
% INFO    : Gen at bus 66515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66516	: Pg=115.44, Qg=123.9 -> Pg=157.5, Qg=123.9
% INFO    : Gen at bus 66516	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 66516	: Pg=115.44, Qg=123.9 -> Pg=157.5, Qg=123.9
% INFO    : Gen at bus 66516	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 66516	: Pg=60.52, Qg=145.6 -> Pg=147.5, Qg=145.6
% INFO    : Gen at bus 66516	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 66517	: Pg=92.36, Qg=-6.63 -> Pg=109.9, Qg=15.1
% INFO    : Gen at bus 66517	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66518	: Pg=40.5, Qg=2.19 -> Pg=132.5, Qg=17.0
% INFO    : Gen at bus 66518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66518	: Pg=90.44, Qg=2.19 -> Pg=144.5, Qg=28.5
% INFO    : Gen at bus 66518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66518	: Pg=90.44, Qg=2.19 -> Pg=144.5, Qg=28.5
% INFO    : Gen at bus 66518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66519	: Pg=120.72, Qg=27.09 -> Pg=180.25, Qg=40.15
% INFO    : Gen at bus 66519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66519	: Pg=105.44, Qg=27.09 -> Pg=151.95, Qg=28.5
% INFO    : Gen at bus 66519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66519	: Pg=105.44, Qg=27.09 -> Pg=151.95, Qg=28.5
% INFO    : Gen at bus 66519	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66520	: Pg=98.79, Qg=140.8 -> Pg=170.35, Qg=140.8
% INFO    : Gen at bus 66520	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 66520	: Pg=85.44, Qg=123.3 -> Pg=141.95, Qg=123.3
% INFO    : Gen at bus 66520	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 66520	: Pg=85.44, Qg=123.3 -> Pg=141.95, Qg=123.3
% INFO    : Gen at bus 66520	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 66521	: Pg=111.9, Qg=-19.39 -> Pg=124.35, Qg=27.0
% INFO    : Gen at bus 66521	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66521	: Pg=104.44, Qg=-19.39 -> Pg=151.45, Qg=28.5
% INFO    : Gen at bus 66521	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66522	: Pg=50.51, Qg=142.5 -> Pg=140.0, Qg=142.5
% INFO    : Gen at bus 66522	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 66522	: Pg=50.51, Qg=142.5 -> Pg=140.0, Qg=142.5
% INFO    : Gen at bus 66522	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 66522	: Pg=105.41, Qg=113.3 -> Pg=143.9, Qg=113.3
% INFO    : Gen at bus 66522	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 66522	: Pg=105.41, Qg=113.3 -> Pg=143.9, Qg=113.3
% INFO    : Gen at bus 66522	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 66522	: Pg=111.85, Qg=163.8 -> Pg=168.65, Qg=163.8
% INFO    : Gen at bus 66522	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 66522	: Pg=59.07, Qg=178.6 -> Pg=200.655, Qg=178.6
% INFO    : Gen at bus 66522	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 66522	: Pg=59.07, Qg=178.6 -> Pg=200.655, Qg=178.6
% INFO    : Gen at bus 66522	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 66523	: Pg=60.41, Qg=37.5 -> Pg=32.75, Qg=37.5
% INFO    : Gen at bus 66523	: Vg=1.0287 -> Vg=1.0
% INFO    : Gen at bus 66523	: Pg=100.41, Qg=113.3 -> Pg=141.4, Qg=113.3
% INFO    : Gen at bus 66523	: Vg=1.0287 -> Vg=1.0
% INFO    : Gen at bus 66523	: Pg=100.41, Qg=113.3 -> Pg=141.4, Qg=113.3
% INFO    : Gen at bus 66523	: Vg=1.0287 -> Vg=1.0
% INFO    : Gen at bus 66523	: Pg=101.47, Qg=163.9 -> Pg=162.2, Qg=163.9
% INFO    : Gen at bus 66523	: Vg=1.0287 -> Vg=1.0
% INFO    : Gen at bus 66524	: Pg=110.4, Qg=0.0 -> Pg=146.0, Qg=0.0
% INFO    : Gen at bus 66524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66524	: Pg=110.4, Qg=0.0 -> Pg=146.0, Qg=0.0
% INFO    : Gen at bus 66524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66524	: Pg=60.5, Qg=0.0 -> Pg=143.5, Qg=0.0
% INFO    : Gen at bus 66524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66525	: Pg=110.4, Qg=112.5 -> Pg=145.75, Qg=112.5
% INFO    : Gen at bus 66525	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 66525	: Pg=110.4, Qg=112.5 -> Pg=145.75, Qg=112.5
% INFO    : Gen at bus 66525	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 66525	: Pg=102.66, Qg=216.5 -> Pg=194.7, Qg=216.5
% INFO    : Gen at bus 66525	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 66526	: Pg=110.38, Qg=83.8 -> Pg=141.5, Qg=83.8
% INFO    : Gen at bus 66526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66526	: Pg=110.38, Qg=83.8 -> Pg=141.5, Qg=83.8
% INFO    : Gen at bus 66526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66526	: Pg=110.38, Qg=83.8 -> Pg=141.5, Qg=83.8
% INFO    : Gen at bus 66526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66526	: Pg=115.34, Qg=-88.87 -> Pg=196.5, Qg=25.15
% INFO    : Gen at bus 66526	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66527	: Pg=160.38, Qg=23.6 -> Pg=165.0, Qg=24.35
% INFO    : Gen at bus 66527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66527	: Pg=160.38, Qg=23.6 -> Pg=165.0, Qg=24.35
% INFO    : Gen at bus 66527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66527	: Pg=160.42, Qg=23.6 -> Pg=175.0, Qg=27.25
% INFO    : Gen at bus 66527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66528	: Pg=105.97, Qg=-13.02 -> Pg=129.0, Qg=24.05
% INFO    : Gen at bus 66528	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66528	: Pg=105.97, Qg=-13.02 -> Pg=129.0, Qg=24.05
% INFO    : Gen at bus 66528	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66528	: Pg=115.57, Qg=-13.02 -> Pg=124.0, Qg=24.05
% INFO    : Gen at bus 66528	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66528	: Pg=104.41, Qg=-13.02 -> Pg=117.5, Qg=26.5
% INFO    : Gen at bus 66528	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66528	: Pg=50.2, Qg=-13.02 -> Pg=70.0, Qg=12.9
% INFO    : Gen at bus 66528	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66529	: Pg=105.91, Qg=0.0 -> Pg=128.85, Qg=0.0
% INFO    : Gen at bus 66529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66529	: Pg=105.91, Qg=0.0 -> Pg=128.85, Qg=0.0
% INFO    : Gen at bus 66529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66529	: Pg=95.16, Qg=0.0 -> Pg=160.35, Qg=0.0
% INFO    : Gen at bus 66529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66530	: Pg=105.37, Qg=32.43 -> Pg=115.0, Qg=23.65
% INFO    : Gen at bus 66530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66530	: Pg=105.37, Qg=32.43 -> Pg=115.0, Qg=23.65
% INFO    : Gen at bus 66530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66530	: Pg=70.51, Qg=32.43 -> Pg=149.5, Qg=32.8
% INFO    : Gen at bus 66530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66531	: Pg=102.21, Qg=35.36 -> Pg=112.3, Qg=34.3
% INFO    : Gen at bus 66531	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66531	: Pg=102.21, Qg=35.36 -> Pg=112.3, Qg=34.3
% INFO    : Gen at bus 66531	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66531	: Pg=102.21, Qg=35.36 -> Pg=112.3, Qg=34.3
% INFO    : Gen at bus 66531	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66531	: Pg=102.21, Qg=35.36 -> Pg=112.3, Qg=34.3
% INFO    : Gen at bus 66531	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66531	: Pg=112.1, Qg=35.36 -> Pg=124.6, Qg=39.4
% INFO    : Gen at bus 66531	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66531	: Pg=112.1, Qg=35.36 -> Pg=124.6, Qg=39.4
% INFO    : Gen at bus 66531	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66532	: Pg=10.36, Qg=0.0 -> Pg=86.6, Qg=0.0
% INFO    : Gen at bus 66532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66532	: Pg=10.36, Qg=0.0 -> Pg=86.6, Qg=0.0
% INFO    : Gen at bus 66532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66532	: Pg=131.1, Qg=0.0 -> Pg=312.5, Qg=0.0
% INFO    : Gen at bus 66532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66532	: Pg=131.1, Qg=0.0 -> Pg=312.5, Qg=0.0
% INFO    : Gen at bus 66532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66533	: Pg=45.36, Qg=101.1 -> Pg=104.1, Qg=101.1
% INFO    : Gen at bus 66533	: Vg=1.0335 -> Vg=1.0
% INFO    : Gen at bus 66533	: Pg=45.36, Qg=101.1 -> Pg=104.1, Qg=101.1
% INFO    : Gen at bus 66533	: Vg=1.0335 -> Vg=1.0
% INFO    : Gen at bus 66533	: Pg=64.1, Qg=240.6 -> Pg=279.9, Qg=240.6
% INFO    : Gen at bus 66533	: Vg=1.0335 -> Vg=1.0
% INFO    : Gen at bus 66534	: Pg=32.65, Qg=16.18 -> Pg=79.25, Qg=11.9
% INFO    : Gen at bus 66534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66534	: Pg=32.65, Qg=16.18 -> Pg=79.25, Qg=11.9
% INFO    : Gen at bus 66534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66535	: Pg=10.35, Qg=0.0 -> Pg=83.0, Qg=0.0
% INFO    : Gen at bus 66535	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66535	: Pg=10.35, Qg=0.0 -> Pg=83.0, Qg=0.0
% INFO    : Gen at bus 66535	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66535	: Pg=71.1, Qg=0.0 -> Pg=282.5, Qg=0.0
% INFO    : Gen at bus 66535	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66535	: Pg=71.1, Qg=0.0 -> Pg=282.5, Qg=0.0
% INFO    : Gen at bus 66535	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66535	: Pg=20.69, Qg=0.0 -> Pg=165.0, Qg=0.0
% INFO    : Gen at bus 66535	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66535	: Pg=10.69, Qg=0.0 -> Pg=160.0, Qg=0.0
% INFO    : Gen at bus 66535	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=3.11, Qg=-0.27 -> Pg=27.1, Qg=3.85
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=3.11, Qg=-0.27 -> Pg=27.1, Qg=3.85
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66536	: Pg=14.64, Qg=-0.27 -> Pg=15.65, Qg=3.475
% INFO    : Gen at bus 66536	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66537	: Pg=120.0, Qg=-13.35 -> Pg=120.0, Qg=0.0
% INFO    : Gen at bus 66537	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66538	: Pg=120.0, Qg=21.93 -> Pg=120.0, Qg=0.0
% INFO    : Gen at bus 66538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66539	: Pg=116.64, Qg=-22.56 -> Pg=116.64, Qg=0.0
% INFO    : Gen at bus 66539	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66540	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66540	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66540	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66540	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66540	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66541	: Pg=32.21, Qg=25.73 -> Pg=72.25, Qg=10.55
% INFO    : Gen at bus 66541	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66542	: Pg=20.48, Qg=135.1 -> Pg=119.0, Qg=135.1
% INFO    : Gen at bus 66542	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 66542	: Pg=20.48, Qg=135.1 -> Pg=119.0, Qg=135.1
% INFO    : Gen at bus 66542	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 66542	: Pg=10.31, Qg=85.5 -> Pg=74.0, Qg=85.5
% INFO    : Gen at bus 66542	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 66543	: Pg=108.0, Qg=0.99 -> Pg=108.0, Qg=0.0
% INFO    : Gen at bus 66543	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66544	: Pg=30.09, Qg=26.3 -> Pg=36.2, Qg=26.3
% INFO    : Gen at bus 66544	: Vg=1.013 -> Vg=1.0
% INFO    : Gen at bus 66544	: Pg=30.09, Qg=26.3 -> Pg=36.2, Qg=26.3
% INFO    : Gen at bus 66544	: Vg=1.013 -> Vg=1.0
% INFO    : Gen at bus 66544	: Pg=20.09, Qg=25.0 -> Pg=30.15, Qg=25.0
% INFO    : Gen at bus 66544	: Vg=1.013 -> Vg=1.0
% INFO    : Gen at bus 66544	: Pg=82.3, Qg=83.2 -> Pg=108.1, Qg=83.2
% INFO    : Gen at bus 66544	: Vg=1.013 -> Vg=1.0
% INFO    : Gen at bus 66545	: Pg=54.1, Qg=43.7 -> Pg=67.0, Qg=43.7
% INFO    : Gen at bus 66545	: Vg=1.0137 -> Vg=1.0
% INFO    : Gen at bus 66545	: Pg=54.1, Qg=43.7 -> Pg=67.0, Qg=43.7
% INFO    : Gen at bus 66545	: Vg=1.0137 -> Vg=1.0
% INFO    : Gen at bus 66546	: Pg=52.68, Qg=41.6 -> Pg=64.75, Qg=41.6
% INFO    : Gen at bus 66546	: Vg=1.0237 -> Vg=1.0
% INFO    : Gen at bus 66546	: Pg=52.68, Qg=41.6 -> Pg=64.75, Qg=41.6
% INFO    : Gen at bus 66546	: Vg=1.0237 -> Vg=1.0
% INFO    : Gen at bus 66547	: Pg=36.12, Qg=3.78 -> Pg=45.6, Qg=7.9
% INFO    : Gen at bus 66547	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66547	: Pg=55.26, Qg=3.78 -> Pg=86.85, Qg=8.95
% INFO    : Gen at bus 66547	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66548	: Pg=47.42, Qg=-3.67 -> Pg=58.95, Qg=8.9
% INFO    : Gen at bus 66548	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66549	: Pg=115.26, Qg=2.8 -> Pg=116.0, Qg=0.0
% INFO    : Gen at bus 66549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66549	: Pg=115.26, Qg=2.8 -> Pg=116.0, Qg=0.0
% INFO    : Gen at bus 66549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66549	: Pg=115.26, Qg=2.8 -> Pg=116.0, Qg=0.0
% INFO    : Gen at bus 66549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66549	: Pg=97.22, Qg=2.8 -> Pg=97.35, Qg=13.95
% INFO    : Gen at bus 66549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66549	: Pg=97.22, Qg=2.8 -> Pg=97.35, Qg=13.95
% INFO    : Gen at bus 66549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66549	: Pg=97.22, Qg=2.8 -> Pg=97.35, Qg=13.95
% INFO    : Gen at bus 66549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66550	: Pg=20.24, Qg=68.2 -> Pg=65.0, Qg=68.2
% INFO    : Gen at bus 66550	: Vg=1.0414 -> Vg=1.0
% INFO    : Gen at bus 66550	: Pg=20.24, Qg=68.2 -> Pg=65.0, Qg=68.2
% INFO    : Gen at bus 66550	: Vg=1.0414 -> Vg=1.0
% INFO    : Gen at bus 66550	: Pg=20.24, Qg=68.2 -> Pg=65.0, Qg=68.2
% INFO    : Gen at bus 66550	: Vg=1.0414 -> Vg=1.0
% INFO    : Gen at bus 66550	: Pg=20.68, Qg=148.2 -> Pg=163.0, Qg=148.2
% INFO    : Gen at bus 66550	: Vg=1.0414 -> Vg=1.0
% INFO    : Gen at bus 66550	: Pg=20.77, Qg=167.4 -> Pg=182.8, Qg=167.4
% INFO    : Gen at bus 66550	: Vg=1.0414 -> Vg=1.0
% INFO    : Gen at bus 66551	: Pg=50.24, Qg=52.3 -> Pg=79.0, Qg=52.3
% INFO    : Gen at bus 66551	: Vg=1.0343 -> Vg=1.0
% INFO    : Gen at bus 66551	: Pg=50.24, Qg=52.3 -> Pg=79.0, Qg=52.3
% INFO    : Gen at bus 66551	: Vg=1.0343 -> Vg=1.0
% INFO    : Gen at bus 66551	: Pg=50.24, Qg=52.3 -> Pg=79.0, Qg=52.3
% INFO    : Gen at bus 66551	: Vg=1.0343 -> Vg=1.0
% INFO    : Gen at bus 66551	: Pg=50.24, Qg=52.3 -> Pg=79.0, Qg=52.3
% INFO    : Gen at bus 66551	: Vg=1.0343 -> Vg=1.0
% INFO    : Gen at bus 66552	: Pg=65.18, Qg=0.0 -> Pg=73.65, Qg=0.0
% INFO    : Gen at bus 66552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66552	: Pg=32.62, Qg=0.0 -> Pg=43.1, Qg=0.0
% INFO    : Gen at bus 66552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66552	: Pg=32.62, Qg=0.0 -> Pg=43.1, Qg=0.0
% INFO    : Gen at bus 66552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66553	: Pg=80.96, Qg=-30.02 -> Pg=80.96, Qg=0.0
% INFO    : Gen at bus 66553	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66554	: Pg=43.91, Qg=0.0 -> Pg=52.25, Qg=0.0
% INFO    : Gen at bus 66554	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66554	: Pg=43.91, Qg=0.0 -> Pg=52.25, Qg=0.0
% INFO    : Gen at bus 66554	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66555	: Pg=42.21, Qg=9.97 -> Pg=68.45, Qg=13.6
% INFO    : Gen at bus 66555	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66555	: Pg=42.21, Qg=9.97 -> Pg=68.45, Qg=13.6
% INFO    : Gen at bus 66555	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66555	: Pg=38.25, Qg=9.97 -> Pg=74.4, Qg=15.9
% INFO    : Gen at bus 66555	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66556	: Pg=38.07, Qg=-6.2 -> Pg=47.3, Qg=7.15
% INFO    : Gen at bus 66556	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66557	: Pg=92.0, Qg=-18.59 -> Pg=49.5, Qg=13.15
% INFO    : Gen at bus 66557	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66558	: Pg=92.0, Qg=15.39 -> Pg=49.5, Qg=13.15
% INFO    : Gen at bus 66558	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66560	: Pg=54.2, Qg=29.6 -> Pg=45.0, Qg=29.6
% INFO    : Gen at bus 66560	: Vg=1.0116 -> Vg=1.0
% INFO    : Gen at bus 66560	: Pg=49.29, Qg=29.6 -> Pg=45.0, Qg=29.6
% INFO    : Gen at bus 66560	: Vg=1.0116 -> Vg=1.0
% INFO    : Gen at bus 66561	: Pg=20.09, Qg=0.0 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 66561	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66561	: Pg=85.2, Qg=0.0 -> Pg=87.5, Qg=0.0
% INFO    : Gen at bus 66561	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66562	: Pg=14.36, Qg=31.0 -> Pg=32.125, Qg=31.0
% INFO    : Gen at bus 66562	: Vg=1.0224 -> Vg=1.0
% INFO    : Gen at bus 66562	: Pg=20.18, Qg=50.6 -> Pg=50.8, Qg=50.6
% INFO    : Gen at bus 66562	: Vg=1.0224 -> Vg=1.0
% INFO    : Gen at bus 66562	: Pg=22.08, Qg=21.4 -> Pg=28.25, Qg=21.4
% INFO    : Gen at bus 66562	: Vg=1.0224 -> Vg=1.0
% INFO    : Gen at bus 66562	: Pg=48.2, Qg=-30.0 -> Pg=68.95, Qg=12.85
% INFO    : Gen at bus 66562	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66563	: Pg=22.07, Qg=-8.35 -> Pg=12.165, Qg=0.0
% INFO    : Gen at bus 66563	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66563	: Pg=22.07, Qg=-8.35 -> Pg=12.165, Qg=0.0
% INFO    : Gen at bus 66563	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66563	: Pg=22.07, Qg=-8.35 -> Pg=12.165, Qg=0.0
% INFO    : Gen at bus 66563	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66563	: Pg=22.07, Qg=-8.35 -> Pg=12.165, Qg=0.0
% INFO    : Gen at bus 66563	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66564	: Pg=88.07, Qg=0.0 -> Pg=51.6, Qg=0.0
% INFO    : Gen at bus 66564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66564	: Pg=88.07, Qg=0.0 -> Pg=51.6, Qg=0.0
% INFO    : Gen at bus 66564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=51.53, Qg=37.5 -> Pg=37.75, Qg=37.5
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=51.53, Qg=37.5 -> Pg=37.75, Qg=37.5
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=51.53, Qg=37.5 -> Pg=37.75, Qg=37.5
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=51.53, Qg=37.5 -> Pg=37.75, Qg=37.5
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=51.53, Qg=37.5 -> Pg=37.75, Qg=37.5
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=36.19, Qg=52.9 -> Pg=60.65, Qg=52.9
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=36.19, Qg=52.9 -> Pg=60.65, Qg=52.9
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66565	: Pg=14.17, Qg=56.3 -> Pg=44.5, Qg=56.3
% INFO    : Gen at bus 66565	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=17.15, Qg=2.54 -> Pg=41.15, Qg=9.35
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=19.18, Qg=2.54 -> Pg=50.5, Qg=11.75
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=73.19, Qg=2.54 -> Pg=79.0, Qg=6.45
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=80.27, Qg=2.54 -> Pg=100.0, Qg=9.05
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=80.27, Qg=2.54 -> Pg=100.0, Qg=9.05
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=40.19, Qg=2.54 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=40.19, Qg=2.54 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66566	: Pg=40.19, Qg=2.54 -> Pg=62.5, Qg=6.45
% INFO    : Gen at bus 66566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66567	: Pg=58.19, Qg=52.3 -> Pg=71.2, Qg=52.3
% INFO    : Gen at bus 66567	: Vg=1.0181 -> Vg=1.0
% INFO    : Gen at bus 66567	: Pg=58.19, Qg=52.3 -> Pg=71.2, Qg=52.3
% INFO    : Gen at bus 66567	: Vg=1.0181 -> Vg=1.0
% INFO    : Gen at bus 66568	: Pg=50.29, Qg=-15.89 -> Pg=41.75, Qg=6.3
% INFO    : Gen at bus 66568	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66568	: Pg=51.25, Qg=-15.89 -> Pg=42.55, Qg=6.4
% INFO    : Gen at bus 66568	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66569	: Pg=15.79, Qg=18.6 -> Pg=24.25, Qg=18.6
% INFO    : Gen at bus 66569	: Vg=1.0149 -> Vg=1.0
% INFO    : Gen at bus 66569	: Pg=15.79, Qg=18.6 -> Pg=24.25, Qg=18.6
% INFO    : Gen at bus 66569	: Vg=1.0149 -> Vg=1.0
% INFO    : Gen at bus 66569	: Pg=68.18, Qg=39.7 -> Pg=75.0, Qg=39.7
% INFO    : Gen at bus 66569	: Vg=1.0149 -> Vg=1.0
% INFO    : Gen at bus 66569	: Pg=68.18, Qg=39.7 -> Pg=75.0, Qg=39.7
% INFO    : Gen at bus 66569	: Vg=1.0149 -> Vg=1.0
% INFO    : Gen at bus 66569	: Pg=68.18, Qg=39.7 -> Pg=75.0, Qg=39.7
% INFO    : Gen at bus 66569	: Vg=1.0149 -> Vg=1.0
% INFO    : Gen at bus 66569	: Pg=68.18, Qg=39.7 -> Pg=75.0, Qg=39.7
% INFO    : Gen at bus 66569	: Vg=1.0149 -> Vg=1.0
% INFO    : Gen at bus 66570	: Pg=49.32, Qg=-27.3 -> Pg=40.95, Qg=6.2
% INFO    : Gen at bus 66570	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66571	: Pg=49.06, Qg=-2.43 -> Pg=40.9, Qg=0.0
% INFO    : Gen at bus 66571	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66571	: Pg=49.06, Qg=-2.43 -> Pg=40.9, Qg=0.0
% INFO    : Gen at bus 66571	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66572	: Pg=5.71, Qg=-1.54 -> Pg=4.81, Qg=1.19
% INFO    : Gen at bus 66572	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66573	: Pg=47.7, Qg=13.88 -> Pg=39.6, Qg=6.0
% INFO    : Gen at bus 66573	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66574	: Pg=47.92, Qg=-2.67 -> Pg=39.95, Qg=0.0
% INFO    : Gen at bus 66574	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66574	: Pg=47.92, Qg=-2.67 -> Pg=39.95, Qg=0.0
% INFO    : Gen at bus 66574	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66575	: Pg=47.21, Qg=-10.35 -> Pg=39.2, Qg=0.0
% INFO    : Gen at bus 66575	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66575	: Pg=47.21, Qg=-10.35 -> Pg=39.2, Qg=0.0
% INFO    : Gen at bus 66575	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66576	: Pg=77.88, Qg=0.0 -> Pg=44.0, Qg=0.0
% INFO    : Gen at bus 66576	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66577	: Pg=46.49, Qg=-10.89 -> Pg=38.6, Qg=0.0
% INFO    : Gen at bus 66577	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66577	: Pg=46.49, Qg=-10.89 -> Pg=38.6, Qg=0.0
% INFO    : Gen at bus 66577	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66579	: Pg=61.52, Qg=3.05 -> Pg=61.52, Qg=0.0
% INFO    : Gen at bus 66579	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66581	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66581	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66581	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66581	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66582	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66582	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66582	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66582	: Pg=70.17, Qg=0.0 -> Pg=72.5, Qg=0.0
% INFO    : Gen at bus 66582	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66583	: Pg=15.17, Qg=14.6 -> Pg=44.75, Qg=5.65
% INFO    : Gen at bus 66583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66583	: Pg=15.17, Qg=14.6 -> Pg=44.75, Qg=5.65
% INFO    : Gen at bus 66583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66583	: Pg=15.17, Qg=14.6 -> Pg=44.75, Qg=5.65
% INFO    : Gen at bus 66583	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66584	: Pg=45.02, Qg=24.4 -> Pg=37.55, Qg=24.4
% INFO    : Gen at bus 66584	: Vg=1.0048 -> Vg=1.0
% INFO    : Gen at bus 66585	: Pg=15.16, Qg=44.6 -> Pg=43.5, Qg=44.6
% INFO    : Gen at bus 66585	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 66585	: Pg=14.16, Qg=44.6 -> Pg=43.0, Qg=44.6
% INFO    : Gen at bus 66585	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 66586	: Pg=45.36, Qg=-11.03 -> Pg=38.5, Qg=5.45
% INFO    : Gen at bus 66586	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66587	: Pg=21.12, Qg=7.31 -> Pg=37.5, Qg=4.1
% INFO    : Gen at bus 66587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66587	: Pg=20.12, Qg=7.31 -> Pg=37.0, Qg=4.1
% INFO    : Gen at bus 66587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66587	: Pg=23.16, Qg=7.31 -> Pg=47.25, Qg=6.65
% INFO    : Gen at bus 66587	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66588	: Pg=43.0, Qg=-21.26 -> Pg=35.7, Qg=5.4
% INFO    : Gen at bus 66588	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66588	: Pg=43.0, Qg=-21.26 -> Pg=35.7, Qg=5.4
% INFO    : Gen at bus 66588	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66589	: Pg=20.16, Qg=34.5 -> Pg=45.6, Qg=34.5
% INFO    : Gen at bus 66589	: Vg=1.0112 -> Vg=1.0
% INFO    : Gen at bus 66589	: Pg=20.16, Qg=34.5 -> Pg=45.6, Qg=34.5
% INFO    : Gen at bus 66589	: Vg=1.0112 -> Vg=1.0
% INFO    : Gen at bus 66590	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66590	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66592	: Pg=13.65, Qg=7.61 -> Pg=33.75, Qg=5.1
% INFO    : Gen at bus 66592	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66592	: Pg=13.65, Qg=7.61 -> Pg=33.75, Qg=5.1
% INFO    : Gen at bus 66592	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66593	: Pg=13.7, Qg=0.0 -> Pg=9.175, Qg=0.0
% INFO    : Gen at bus 66593	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 66593	: Pg=13.7, Qg=0.0 -> Pg=9.175, Qg=0.0
% INFO    : Gen at bus 66593	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 66593	: Pg=13.7, Qg=0.0 -> Pg=9.175, Qg=0.0
% INFO    : Gen at bus 66593	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 66593	: Pg=13.7, Qg=0.0 -> Pg=9.175, Qg=0.0
% INFO    : Gen at bus 66593	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 66594	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66594	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66594	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66595	: Pg=16.0, Qg=-5.32 -> Pg=16.0, Qg=3.34
% INFO    : Gen at bus 66595	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66595	: Pg=16.0, Qg=-5.32 -> Pg=16.0, Qg=3.34
% INFO    : Gen at bus 66595	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66595	: Pg=16.0, Qg=-5.32 -> Pg=16.0, Qg=3.34
% INFO    : Gen at bus 66595	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66595	: Pg=16.0, Qg=-5.32 -> Pg=16.0, Qg=3.34
% INFO    : Gen at bus 66595	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66596	: Pg=12.74, Qg=-4.63 -> Pg=31.5, Qg=4.75
% INFO    : Gen at bus 66596	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66596	: Pg=12.74, Qg=-4.63 -> Pg=31.5, Qg=4.75
% INFO    : Gen at bus 66596	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66597	: Pg=56.74, Qg=30.5 -> Pg=55.0, Qg=30.5
% INFO    : Gen at bus 66597	: Vg=1.0083 -> Vg=1.0
% INFO    : Gen at bus 66597	: Pg=56.74, Qg=30.5 -> Pg=55.0, Qg=30.5
% INFO    : Gen at bus 66597	: Vg=1.0083 -> Vg=1.0
% INFO    : Gen at bus 66597	: Pg=56.74, Qg=30.5 -> Pg=55.0, Qg=30.5
% INFO    : Gen at bus 66597	: Vg=1.0083 -> Vg=1.0
% INFO    : Gen at bus 66597	: Pg=56.74, Qg=30.5 -> Pg=55.0, Qg=30.5
% INFO    : Gen at bus 66597	: Vg=1.0083 -> Vg=1.0
% INFO    : Gen at bus 66598	: Pg=18.91, Qg=0.0 -> Pg=15.95, Qg=0.0
% INFO    : Gen at bus 66598	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 66598	: Pg=25.14, Qg=0.0 -> Pg=43.8, Qg=0.0
% INFO    : Gen at bus 66598	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 66598	: Pg=25.14, Qg=0.0 -> Pg=43.8, Qg=0.0
% INFO    : Gen at bus 66598	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 66599	: Pg=20.14, Qg=46.5 -> Pg=41.0, Qg=46.5
% INFO    : Gen at bus 66599	: Vg=1.0159 -> Vg=1.0
% INFO    : Gen at bus 66600	: Pg=29.41, Qg=8.95 -> Pg=45.385, Qg=6.85
% INFO    : Gen at bus 66600	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66600	: Pg=15.11, Qg=8.95 -> Pg=32.0, Qg=7.05
% INFO    : Gen at bus 66600	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66601	: Pg=49.2, Qg=-24.3 -> Pg=49.2, Qg=0.0
% INFO    : Gen at bus 66601	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66602	: Pg=50.32, Qg=-16.8 -> Pg=36.7, Qg=3.8
% INFO    : Gen at bus 66602	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66602	: Pg=20.13, Qg=-20.2 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 66602	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66602	: Pg=16.36, Qg=-12.6 -> Pg=19.85, Qg=5.4
% INFO    : Gen at bus 66602	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66604	: Pg=60.41, Qg=37.5 -> Pg=40.75, Qg=37.5
% INFO    : Gen at bus 66604	: Vg=1.0124 -> Vg=1.0
% INFO    : Gen at bus 66605	: Pg=60.41, Qg=0.0 -> Pg=40.75, Qg=0.0
% INFO    : Gen at bus 66605	: Vg=1.0339 -> Vg=1.0
% INFO    : Gen at bus 66606	: Pg=52.73, Qg=-1.89 -> Pg=40.75, Qg=8.65
% INFO    : Gen at bus 66606	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66607	: Pg=55.73, Qg=-20.2 -> Pg=48.25, Qg=8.65
% INFO    : Gen at bus 66607	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66609	: Pg=57.73, Qg=37.5 -> Pg=53.25, Qg=37.5
% INFO    : Gen at bus 66609	: Vg=1.002 -> Vg=1.0
% INFO    : Gen at bus 66609	: Pg=57.73, Qg=37.5 -> Pg=53.25, Qg=37.5
% INFO    : Gen at bus 66609	: Vg=1.002 -> Vg=1.0
% INFO    : Gen at bus 66613	: Pg=15.13, Qg=19.7 -> Pg=37.4, Qg=19.7
% INFO    : Gen at bus 66613	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 66613	: Pg=15.13, Qg=19.7 -> Pg=37.4, Qg=19.7
% INFO    : Gen at bus 66613	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 66613	: Pg=40.49, Qg=25.7 -> Pg=46.65, Qg=25.7
% INFO    : Gen at bus 66613	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 66613	: Pg=40.49, Qg=25.7 -> Pg=46.65, Qg=25.7
% INFO    : Gen at bus 66613	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 66615	: Pg=11.93, Qg=-2.97 -> Pg=29.5, Qg=4.45
% INFO    : Gen at bus 66615	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66616	: Pg=58.91, Qg=-16.84 -> Pg=29.5, Qg=8.45
% INFO    : Gen at bus 66616	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66616	: Pg=58.91, Qg=-16.84 -> Pg=29.5, Qg=8.45
% INFO    : Gen at bus 66616	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66618	: Pg=35.13, Qg=43.9 -> Pg=46.75, Qg=43.9
% INFO    : Gen at bus 66618	: Vg=1.0003 -> Vg=1.0
% INFO    : Gen at bus 66620	: Pg=57.33, Qg=28.1 -> Pg=56.0, Qg=28.1
% INFO    : Gen at bus 66620	: Vg=1.0085 -> Vg=1.0
% INFO    : Gen at bus 66621	: Pg=11.65, Qg=3.1 -> Pg=28.8, Qg=4.35
% INFO    : Gen at bus 66621	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66621	: Pg=12.19, Qg=3.1 -> Pg=30.15, Qg=4.55
% INFO    : Gen at bus 66621	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66622	: Pg=57.31, Qg=-19.1 -> Pg=33.7, Qg=8.25
% INFO    : Gen at bus 66622	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66623	: Pg=12.92, Qg=15.33 -> Pg=29.0, Qg=11.65
% INFO    : Gen at bus 66623	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66623	: Pg=62.8, Qg=15.33 -> Pg=140.5, Qg=0.0
% INFO    : Gen at bus 66623	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66623	: Pg=62.8, Qg=15.33 -> Pg=140.5, Qg=0.0
% INFO    : Gen at bus 66623	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66623	: Pg=62.8, Qg=15.33 -> Pg=140.5, Qg=0.0
% INFO    : Gen at bus 66623	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66623	: Pg=62.8, Qg=15.33 -> Pg=140.5, Qg=0.0
% INFO    : Gen at bus 66623	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66623	: Pg=62.8, Qg=15.33 -> Pg=140.5, Qg=0.0
% INFO    : Gen at bus 66623	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66623	: Pg=62.8, Qg=15.33 -> Pg=140.5, Qg=0.0
% INFO    : Gen at bus 66623	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66624	: Pg=13.12, Qg=0.0 -> Pg=34.4, Qg=0.0
% INFO    : Gen at bus 66624	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66624	: Pg=17.16, Qg=0.0 -> Pg=27.65, Qg=0.0
% INFO    : Gen at bus 66624	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66626	: Pg=1.12, Qg=-18.4 -> Pg=28.15, Qg=4.2
% INFO    : Gen at bus 66626	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=54.92, Qg=0.0 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=117.82, Qg=0.0 -> Pg=70.0, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=117.82, Qg=0.0 -> Pg=70.0, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=137.79, Qg=0.0 -> Pg=80.0, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=54.92, Qg=0.0 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=54.92, Qg=0.0 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=54.92, Qg=0.0 -> Pg=37.5, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=109.84, Qg=0.0 -> Pg=66.0, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=109.84, Qg=0.0 -> Pg=66.0, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=112.83, Qg=0.0 -> Pg=67.5, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=117.82, Qg=0.0 -> Pg=70.0, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66628	: Pg=117.82, Qg=0.0 -> Pg=70.0, Qg=0.0
% INFO    : Gen at bus 66628	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66629	: Pg=15.52, Qg=0.0 -> Pg=30.25, Qg=0.0
% INFO    : Gen at bus 66629	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66629	: Pg=15.52, Qg=0.0 -> Pg=30.25, Qg=0.0
% INFO    : Gen at bus 66629	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66630	: Pg=54.92, Qg=-18.3 -> Pg=28.4, Qg=4.15
% INFO    : Gen at bus 66630	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66631	: Pg=54.92, Qg=9.16 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 66631	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66631	: Pg=54.92, Qg=9.16 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 66631	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66632	: Pg=54.92, Qg=3.17 -> Pg=32.5, Qg=4.15
% INFO    : Gen at bus 66632	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66632	: Pg=54.92, Qg=3.17 -> Pg=32.5, Qg=4.15
% INFO    : Gen at bus 66632	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66633	: Pg=15.12, Qg=7.22 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 66633	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66633	: Pg=15.12, Qg=7.22 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 66633	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66633	: Pg=15.12, Qg=7.22 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 66633	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66634	: Pg=12.04, Qg=11.33 -> Pg=15.15, Qg=11.33
% INFO    : Gen at bus 66634	: Vg=1.0082 -> Vg=1.0
% INFO    : Gen at bus 66634	: Pg=12.04, Qg=11.33 -> Pg=15.15, Qg=11.33
% INFO    : Gen at bus 66634	: Vg=1.0082 -> Vg=1.0
% INFO    : Gen at bus 66634	: Pg=12.04, Qg=11.33 -> Pg=15.15, Qg=11.33
% INFO    : Gen at bus 66634	: Vg=1.0082 -> Vg=1.0
% INFO    : Gen at bus 66635	: Pg=2.04, Qg=-0.58 -> Pg=10.15, Qg=0.0
% INFO    : Gen at bus 66635	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66635	: Pg=2.04, Qg=-0.58 -> Pg=10.15, Qg=0.0
% INFO    : Gen at bus 66635	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66635	: Pg=2.04, Qg=-0.58 -> Pg=10.15, Qg=0.0
% INFO    : Gen at bus 66635	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66636	: Pg=11.1, Qg=0.83 -> Pg=27.45, Qg=4.15
% INFO    : Gen at bus 66636	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66636	: Pg=12.38, Qg=0.83 -> Pg=30.6, Qg=4.6
% INFO    : Gen at bus 66636	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66638	: Pg=53.82, Qg=-9.91 -> Pg=27.95, Qg=4.05
% INFO    : Gen at bus 66638	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66639	: Pg=10.74, Qg=-17.7 -> Pg=26.55, Qg=4.0
% INFO    : Gen at bus 66639	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66640	: Pg=10.72, Qg=5.4 -> Pg=26.5, Qg=0.0
% INFO    : Gen at bus 66640	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66642	: Pg=32.09, Qg=0.0 -> Pg=37.05, Qg=0.0
% INFO    : Gen at bus 66642	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66642	: Pg=33.12, Qg=0.0 -> Pg=42.9, Qg=0.0
% INFO    : Gen at bus 66642	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66643	: Pg=10.56, Qg=5.52 -> Pg=26.1, Qg=3.95
% INFO    : Gen at bus 66643	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66643	: Pg=11.65, Qg=5.52 -> Pg=28.8, Qg=4.35
% INFO    : Gen at bus 66643	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66644	: Pg=10.45, Qg=7.98 -> Pg=25.85, Qg=3.9
% INFO    : Gen at bus 66644	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66644	: Pg=10.45, Qg=7.98 -> Pg=25.85, Qg=3.9
% INFO    : Gen at bus 66644	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66645	: Pg=35.09, Qg=-13.7 -> Pg=38.1, Qg=3.15
% INFO    : Gen at bus 66645	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66645	: Pg=41.11, Qg=-17.1 -> Pg=46.2, Qg=4.6
% INFO    : Gen at bus 66645	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66646	: Pg=14.11, Qg=0.0 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 66646	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66646	: Pg=14.11, Qg=0.0 -> Pg=27.5, Qg=0.0
% INFO    : Gen at bus 66646	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66647	: Pg=10.11, Qg=0.88 -> Pg=25.0, Qg=3.75
% INFO    : Gen at bus 66647	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66647	: Pg=10.11, Qg=0.88 -> Pg=25.0, Qg=3.75
% INFO    : Gen at bus 66647	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66649	: Pg=49.93, Qg=16.4 -> Pg=45.0, Qg=16.4
% INFO    : Gen at bus 66649	: Vg=1.0033 -> Vg=1.0
% INFO    : Gen at bus 66650	: Pg=13.11, Qg=24.2 -> Pg=31.5, Qg=24.2
% INFO    : Gen at bus 66650	: Vg=1.0019 -> Vg=1.0
% INFO    : Gen at bus 66651	: Pg=50.0, Qg=24.2 -> Pg=50.0, Qg=24.2
% INFO    : Gen at bus 66651	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 66651	: Pg=50.0, Qg=24.2 -> Pg=50.0, Qg=24.2
% INFO    : Gen at bus 66651	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 66651	: Pg=53.12, Qg=26.2 -> Pg=53.5, Qg=26.2
% INFO    : Gen at bus 66651	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 66652	: Pg=49.93, Qg=31.0 -> Pg=35.0, Qg=31.0
% INFO    : Gen at bus 66652	: Vg=0.9989 -> Vg=1.0
% INFO    : Gen at bus 66652	: Pg=49.93, Qg=31.0 -> Pg=35.0, Qg=31.0
% INFO    : Gen at bus 66652	: Vg=0.9989 -> Vg=1.0
% INFO    : Gen at bus 66653	: Pg=40.0, Qg=19.8 -> Pg=40.0, Qg=19.8
% INFO    : Gen at bus 66653	: Vg=1.0127 -> Vg=1.0
% INFO    : Gen at bus 66654	: Pg=49.83, Qg=16.4 -> Pg=44.25, Qg=16.4
% INFO    : Gen at bus 66654	: Vg=1.0351 -> Vg=1.0
% INFO    : Gen at bus 66654	: Pg=49.83, Qg=16.4 -> Pg=44.0, Qg=16.4
% INFO    : Gen at bus 66654	: Vg=1.0351 -> Vg=1.0
% INFO    : Gen at bus 66654	: Pg=49.83, Qg=16.4 -> Pg=43.65, Qg=16.4
% INFO    : Gen at bus 66654	: Vg=1.0351 -> Vg=1.0
% INFO    : Gen at bus 66656	: Pg=49.83, Qg=-16.6 -> Pg=42.45, Qg=3.8
% INFO    : Gen at bus 66656	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66657	: Pg=49.83, Qg=37.4 -> Pg=40.95, Qg=37.4
% INFO    : Gen at bus 66657	: Vg=1.0088 -> Vg=1.0
% INFO    : Gen at bus 66658	: Pg=43.93, Qg=-3.76 -> Pg=32.0, Qg=3.3
% INFO    : Gen at bus 66658	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66658	: Pg=35.11, Qg=-3.76 -> Pg=42.4, Qg=3.75
% INFO    : Gen at bus 66658	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66658	: Pg=35.11, Qg=-3.76 -> Pg=42.4, Qg=3.75
% INFO    : Gen at bus 66658	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66658	: Pg=13.67, Qg=-3.76 -> Pg=27.15, Qg=3.75
% INFO    : Gen at bus 66658	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66660	: Pg=49.73, Qg=0.0 -> Pg=47.85, Qg=0.0
% INFO    : Gen at bus 66660	: Vg=0.9932 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66663	: Pg=2.11, Qg=2.33 -> Pg=2.6, Qg=2.33
% INFO    : Gen at bus 66663	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 66665	: Pg=49.43, Qg=-16.5 -> Pg=45.75, Qg=4.45
% INFO    : Gen at bus 66665	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66666	: Pg=49.43, Qg=10.75 -> Pg=39.75, Qg=7.1
% INFO    : Gen at bus 66666	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66667	: Pg=49.43, Qg=-16.5 -> Pg=39.75, Qg=7.1
% INFO    : Gen at bus 66667	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66668	: Pg=21.09, Qg=2.43 -> Pg=30.25, Qg=5.65
% INFO    : Gen at bus 66668	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66668	: Pg=26.11, Qg=2.43 -> Pg=37.65, Qg=7.1
% INFO    : Gen at bus 66668	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66669	: Pg=12.28, Qg=5.95 -> Pg=6.15, Qg=5.95
% INFO    : Gen at bus 66669	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 66669	: Pg=12.28, Qg=5.95 -> Pg=6.15, Qg=5.95
% INFO    : Gen at bus 66669	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 66669	: Pg=12.28, Qg=5.95 -> Pg=6.15, Qg=5.95
% INFO    : Gen at bus 66669	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 66669	: Pg=12.28, Qg=5.95 -> Pg=6.15, Qg=5.95
% INFO    : Gen at bus 66669	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 66670	: Pg=15.09, Qg=25.4 -> Pg=28.0, Qg=25.4
% INFO    : Gen at bus 66670	: Vg=0.993 -> Vg=1.0
% INFO    : Gen at bus 66670	: Pg=20.11, Qg=31.4 -> Pg=34.5, Qg=31.4
% INFO    : Gen at bus 66670	: Vg=0.993 -> Vg=1.0
% INFO    : Gen at bus 66672	: Pg=48.93, Qg=-16.3 -> Pg=45.5, Qg=3.7
% INFO    : Gen at bus 66672	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66673	: Pg=48.93, Qg=3.4 -> Pg=35.5, Qg=7.05
% INFO    : Gen at bus 66673	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66673	: Pg=48.93, Qg=3.4 -> Pg=35.5, Qg=7.05
% INFO    : Gen at bus 66673	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66674	: Pg=48.63, Qg=30.2 -> Pg=32.35, Qg=30.2
% INFO    : Gen at bus 66674	: Vg=1.0088 -> Vg=1.0
% INFO    : Gen at bus 66675	: Pg=9.83, Qg=9.51 -> Pg=24.3, Qg=3.65
% INFO    : Gen at bus 66675	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66675	: Pg=9.83, Qg=9.51 -> Pg=24.3, Qg=3.65
% INFO    : Gen at bus 66675	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66678	: Pg=48.13, Qg=29.9 -> Pg=43.6, Qg=29.9
% INFO    : Gen at bus 66678	: Vg=1.0015 -> Vg=1.0
% INFO    : Gen at bus 66679	: Pg=47.43, Qg=-15.8 -> Pg=24.75, Qg=6.8
% INFO    : Gen at bus 66679	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66682	: Pg=46.93, Qg=29.1 -> Pg=29.5, Qg=29.1
% INFO    : Gen at bus 66682	: Vg=0.9877 -> Vg=1.0
% INFO    : Gen at bus 66683	: Pg=46.93, Qg=-9.31 -> Pg=33.5, Qg=6.7
% INFO    : Gen at bus 66683	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66684	: Pg=46.93, Qg=0.0 -> Pg=33.5, Qg=0.0
% INFO    : Gen at bus 66684	: Vg=1.0185 -> Vg=1.0
% INFO    : Gen at bus 66685	: Pg=46.93, Qg=-15.7 -> Pg=33.5, Qg=6.7
% INFO    : Gen at bus 66685	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66686	: Pg=46.93, Qg=-5.12 -> Pg=33.5, Qg=3.55
% INFO    : Gen at bus 66686	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66687	: Pg=46.93, Qg=29.1 -> Pg=33.5, Qg=29.1
% INFO    : Gen at bus 66687	: Vg=1.0076 -> Vg=1.0
% INFO    : Gen at bus 66688	: Pg=46.93, Qg=-15.7 -> Pg=33.5, Qg=6.7
% INFO    : Gen at bus 66688	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66689	: Pg=13.44, Qg=-15.6 -> Pg=25.85, Qg=3.5
% INFO    : Gen at bus 66689	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66691	: Pg=1.21, Qg=2.17 -> Pg=2.05, Qg=2.17
% INFO    : Gen at bus 66691	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 66692	: Pg=46.03, Qg=28.6 -> Pg=34.05, Qg=28.6
% INFO    : Gen at bus 66692	: Vg=1.0061 -> Vg=1.0
% INFO    : Gen at bus 66692	: Pg=46.03, Qg=28.6 -> Pg=34.05, Qg=28.6
% INFO    : Gen at bus 66692	: Vg=1.0061 -> Vg=1.0
% INFO    : Gen at bus 66693	: Pg=45.93, Qg=-12.03 -> Pg=39.0, Qg=6.6
% INFO    : Gen at bus 66693	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66694	: Pg=45.93, Qg=5.59 -> Pg=39.0, Qg=6.6
% INFO    : Gen at bus 66694	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66695	: Pg=45.93, Qg=-15.3 -> Pg=39.0, Qg=6.6
% INFO    : Gen at bus 66695	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66696	: Pg=45.93, Qg=28.5 -> Pg=43.0, Qg=28.5
% INFO    : Gen at bus 66696	: Vg=0.9983 -> Vg=1.0
% INFO    : Gen at bus 66697	: Pg=45.93, Qg=-15.3 -> Pg=33.5, Qg=6.6
% INFO    : Gen at bus 66697	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66699	: Pg=44.93, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66699	: Pg=44.93, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66699	: Pg=44.93, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66699	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66700	: Pg=36.0, Qg=-17.8 -> Pg=36.0, Qg=0.0
% INFO    : Gen at bus 66700	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66701	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 66701	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66701	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 66701	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66701	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 66701	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66701	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 66701	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66703	: Pg=12.9, Qg=6.3 -> Pg=24.5, Qg=6.3
% INFO    : Gen at bus 66703	: Vg=1.0078 -> Vg=1.0
% INFO    : Gen at bus 66704	: Pg=43.93, Qg=24.6 -> Pg=31.46, Qg=24.6
% INFO    : Gen at bus 66704	: Vg=1.014 -> Vg=1.0
% INFO    : Gen at bus 66705	: Pg=43.93, Qg=21.3 -> Pg=38.5, Qg=21.3
% INFO    : Gen at bus 66705	: Vg=0.9922 -> Vg=1.0
% INFO    : Gen at bus 66706	: Pg=34.72, Qg=-17.2 -> Pg=34.72, Qg=0.0
% INFO    : Gen at bus 66706	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66707	: Pg=17.5, Qg=-14.3 -> Pg=27.0, Qg=9.0
% INFO    : Gen at bus 66707	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66708	: Pg=42.14, Qg=-0.18 -> Pg=39.1, Qg=8.8
% INFO    : Gen at bus 66708	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66709	: Pg=11.25, Qg=-4.67 -> Pg=7.05, Qg=2.315
% INFO    : Gen at bus 66709	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66709	: Pg=11.25, Qg=-4.67 -> Pg=7.05, Qg=2.315
% INFO    : Gen at bus 66709	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66709	: Pg=11.25, Qg=-4.67 -> Pg=7.05, Qg=2.315
% INFO    : Gen at bus 66709	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66710	: Pg=23.09, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66710	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66710	: Pg=23.09, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66710	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66710	: Pg=23.18, Qg=0.0 -> Pg=51.5, Qg=0.0
% INFO    : Gen at bus 66710	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66711	: Pg=16.85, Qg=-11.99 -> Pg=20.95, Qg=3.15
% INFO    : Gen at bus 66711	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66712	: Pg=32.8, Qg=16.2 -> Pg=32.8, Qg=16.2
% INFO    : Gen at bus 66712	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 66713	: Pg=27.19, Qg=14.6 -> Pg=33.7, Qg=14.6
% INFO    : Gen at bus 66713	: Vg=0.9874 -> Vg=1.0
% INFO    : Gen at bus 66714	: Pg=9.99, Qg=-3.33 -> Pg=9.0, Qg=2.085
% INFO    : Gen at bus 66714	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66714	: Pg=9.99, Qg=-3.33 -> Pg=9.0, Qg=2.085
% INFO    : Gen at bus 66714	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66714	: Pg=9.99, Qg=-3.33 -> Pg=9.0, Qg=2.085
% INFO    : Gen at bus 66714	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66714	: Pg=9.99, Qg=-3.33 -> Pg=9.0, Qg=2.085
% INFO    : Gen at bus 66714	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66715	: Pg=16.09, Qg=-0.1 -> Pg=20.0, Qg=3.05
% INFO    : Gen at bus 66715	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66717	: Pg=29.09, Qg=24.8 -> Pg=34.5, Qg=24.8
% INFO    : Gen at bus 66717	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 66717	: Pg=29.09, Qg=24.8 -> Pg=34.5, Qg=24.8
% INFO    : Gen at bus 66717	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 66717	: Pg=16.47, Qg=25.1 -> Pg=19.25, Qg=25.1
% INFO    : Gen at bus 66717	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 66718	: Pg=16.84, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 66718	: Vg=1.0053 -> Vg=1.0
% INFO    : Gen at bus 66718	: Pg=18.49, Qg=0.0 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 66718	: Vg=1.0053 -> Vg=1.0
% INFO    : Gen at bus 66718	: Pg=18.49, Qg=0.0 -> Pg=22.0, Qg=0.0
% INFO    : Gen at bus 66718	: Vg=1.0053 -> Vg=1.0
% INFO    : Gen at bus 66719	: Pg=31.76, Qg=15.7 -> Pg=31.76, Qg=15.7
% INFO    : Gen at bus 66719	: Vg=1.0199 -> Vg=1.0
% INFO    : Gen at bus 66720	: Pg=15.93, Qg=-12.58 -> Pg=19.8, Qg=3.0
% INFO    : Gen at bus 66720	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66720	: Pg=15.93, Qg=-12.58 -> Pg=19.8, Qg=3.0
% INFO    : Gen at bus 66720	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66721	: Pg=39.04, Qg=0.0 -> Pg=37.55, Qg=0.0
% INFO    : Gen at bus 66721	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66722	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66722	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66722	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66723	: Pg=38.84, Qg=0.0 -> Pg=34.45, Qg=0.0
% INFO    : Gen at bus 66723	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66724	: Pg=38.74, Qg=-12.9 -> Pg=27.74, Qg=4.4
% INFO    : Gen at bus 66724	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66726	: Pg=16.13, Qg=-6.64 -> Pg=19.8, Qg=0.0
% INFO    : Gen at bus 66726	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66727	: Pg=17.09, Qg=-12.8 -> Pg=27.7, Qg=2.9
% INFO    : Gen at bus 66727	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66728	: Pg=38.34, Qg=0.0 -> Pg=37.2, Qg=0.0
% INFO    : Gen at bus 66728	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66729	: Pg=18.08, Qg=23.7 -> Pg=28.1, Qg=23.7
% INFO    : Gen at bus 66729	: Vg=0.9851 -> Vg=1.0
% INFO    : Gen at bus 66730	: Pg=38.14, Qg=0.0 -> Pg=34.1, Qg=0.0
% INFO    : Gen at bus 66730	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 66731	: Pg=18.97, Qg=0.0 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 66731	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66731	: Pg=18.97, Qg=0.0 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 66731	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66732	: Pg=30.4, Qg=-13.58 -> Pg=30.4, Qg=0.0
% INFO    : Gen at bus 66732	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66733	: Pg=15.38, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 66733	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66734	: Pg=15.38, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 66734	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66735	: Pg=15.38, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 66735	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66736	: Pg=11.5, Qg=-12.2 -> Pg=21.05, Qg=0.0
% INFO    : Gen at bus 66736	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66736	: Pg=11.5, Qg=-12.2 -> Pg=21.05, Qg=0.0
% INFO    : Gen at bus 66736	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66737	: Pg=14.84, Qg=17.9 -> Pg=18.45, Qg=17.9
% INFO    : Gen at bus 66737	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 66737	: Pg=14.84, Qg=17.9 -> Pg=18.45, Qg=17.9
% INFO    : Gen at bus 66737	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 66738	: Pg=29.44, Qg=-4.99 -> Pg=29.44, Qg=0.0
% INFO    : Gen at bus 66738	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66739	: Pg=15.89, Qg=3.66 -> Pg=19.75, Qg=0.0
% INFO    : Gen at bus 66739	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66739	: Pg=15.89, Qg=3.66 -> Pg=19.75, Qg=0.0
% INFO    : Gen at bus 66739	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66739	: Pg=14.68, Qg=3.66 -> Pg=18.25, Qg=2.75
% INFO    : Gen at bus 66739	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66740	: Pg=18.05, Qg=0.0 -> Pg=20.55, Qg=0.0
% INFO    : Gen at bus 66740	: Vg=0.9857 -> Vg=1.0
% INFO    : Gen at bus 66740	: Pg=22.08, Qg=0.0 -> Pg=29.1, Qg=0.0
% INFO    : Gen at bus 66740	: Vg=0.9857 -> Vg=1.0
% INFO    : Gen at bus 66741	: Pg=16.08, Qg=-7.1 -> Pg=26.1, Qg=2.7
% INFO    : Gen at bus 66741	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66742	: Pg=35.75, Qg=22.2 -> Pg=18.9, Qg=5.15
% INFO    : Gen at bus 66742	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66743	: Pg=35.75, Qg=-11.9 -> Pg=18.9, Qg=5.15
% INFO    : Gen at bus 66743	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66745	: Pg=35.0, Qg=17.0 -> Pg=18.83, Qg=17.0
% INFO    : Gen at bus 66745	: Vg=1.0066 -> Vg=1.0
% INFO    : Gen at bus 66746	: Pg=34.95, Qg=-0.88 -> Pg=18.83, Qg=2.65
% INFO    : Gen at bus 66746	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66747	: Pg=13.92, Qg=-0.9 -> Pg=17.3, Qg=2.65
% INFO    : Gen at bus 66747	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66747	: Pg=13.92, Qg=-0.9 -> Pg=17.3, Qg=2.65
% INFO    : Gen at bus 66747	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66748	: Pg=16.05, Qg=-9.4 -> Pg=19.05, Qg=0.0
% INFO    : Gen at bus 66748	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66748	: Pg=16.58, Qg=-14.7 -> Pg=25.5, Qg=0.0
% INFO    : Gen at bus 66748	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66749	: Pg=27.6, Qg=-13.6 -> Pg=27.6, Qg=0.0
% INFO    : Gen at bus 66749	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66750	: Pg=17.2, Qg=2.59 -> Pg=27.75, Qg=0.0
% INFO    : Gen at bus 66750	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66750	: Pg=17.2, Qg=2.59 -> Pg=27.75, Qg=0.0
% INFO    : Gen at bus 66750	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66750	: Pg=17.2, Qg=2.59 -> Pg=27.75, Qg=0.0
% INFO    : Gen at bus 66750	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66750	: Pg=13.34, Qg=2.59 -> Pg=21.15, Qg=2.6
% INFO    : Gen at bus 66750	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66751	: Pg=34.15, Qg=-11.4 -> Pg=18.4, Qg=2.6
% INFO    : Gen at bus 66751	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66752	: Pg=34.15, Qg=-0.63 -> Pg=18.4, Qg=2.6
% INFO    : Gen at bus 66752	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66753	: Pg=34.15, Qg=-11.4 -> Pg=18.4, Qg=2.6
% INFO    : Gen at bus 66753	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66754	: Pg=15.72, Qg=0.0 -> Pg=18.7, Qg=0.0
% INFO    : Gen at bus 66754	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66754	: Pg=15.72, Qg=0.0 -> Pg=18.7, Qg=0.0
% INFO    : Gen at bus 66754	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66754	: Pg=15.72, Qg=0.0 -> Pg=18.7, Qg=0.0
% INFO    : Gen at bus 66754	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66754	: Pg=16.64, Qg=-4.35 -> Pg=19.8, Qg=2.7
% INFO    : Gen at bus 66754	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66754	: Pg=16.84, Qg=-4.35 -> Pg=20.05, Qg=2.75
% INFO    : Gen at bus 66754	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66755	: Pg=33.95, Qg=21.1 -> Pg=17.5, Qg=21.1
% INFO    : Gen at bus 66755	: Vg=0.9991 -> Vg=1.0
% INFO    : Gen at bus 66756	: Pg=11.28, Qg=0.0 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 66756	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66756	: Pg=11.28, Qg=0.0 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 66756	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66756	: Pg=11.28, Qg=0.0 -> Pg=5.9, Qg=0.0
% INFO    : Gen at bus 66756	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66759	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66759	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66760	: Pg=10.88, Qg=3.57 -> Pg=6.45, Qg=3.57
% INFO    : Gen at bus 66760	: Vg=1.0097 -> Vg=1.0
% INFO    : Gen at bus 66760	: Pg=10.88, Qg=3.57 -> Pg=6.45, Qg=3.57
% INFO    : Gen at bus 66760	: Vg=1.0097 -> Vg=1.0
% INFO    : Gen at bus 66760	: Pg=10.88, Qg=3.57 -> Pg=6.45, Qg=3.57
% INFO    : Gen at bus 66760	: Vg=1.0097 -> Vg=1.0
% INFO    : Gen at bus 66761	: Pg=30.07, Qg=-10.7 -> Pg=31.3, Qg=0.0
% INFO    : Gen at bus 66761	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66761	: Pg=27.06, Qg=-9.2 -> Pg=27.25, Qg=2.05
% INFO    : Gen at bus 66761	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66761	: Pg=27.06, Qg=-9.2 -> Pg=27.25, Qg=2.05
% INFO    : Gen at bus 66761	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66761	: Pg=27.06, Qg=-9.2 -> Pg=27.25, Qg=2.05
% INFO    : Gen at bus 66761	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66762	: Pg=1.02, Qg=-0.76 -> Pg=5.915, Qg=0.0
% INFO    : Gen at bus 66762	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66762	: Pg=1.02, Qg=-0.76 -> Pg=5.915, Qg=0.0
% INFO    : Gen at bus 66762	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66762	: Pg=1.02, Qg=-0.76 -> Pg=5.915, Qg=0.0
% INFO    : Gen at bus 66762	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66763	: Pg=12.99, Qg=15.6 -> Pg=16.15, Qg=15.6
% INFO    : Gen at bus 66763	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 66763	: Pg=14.12, Qg=17.0 -> Pg=17.55, Qg=17.0
% INFO    : Gen at bus 66763	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 66763	: Pg=14.12, Qg=17.0 -> Pg=17.55, Qg=17.0
% INFO    : Gen at bus 66763	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 66764	: Pg=32.25, Qg=24.2 -> Pg=31.15, Qg=24.2
% INFO    : Gen at bus 66764	: Vg=1.0018 -> Vg=1.0
% INFO    : Gen at bus 66764	: Pg=32.25, Qg=24.2 -> Pg=31.15, Qg=24.2
% INFO    : Gen at bus 66764	: Vg=1.0018 -> Vg=1.0
% INFO    : Gen at bus 66765	: Pg=24.4, Qg=11.8 -> Pg=24.4, Qg=11.8
% INFO    : Gen at bus 66765	: Vg=1.0018 -> Vg=1.0
% INFO    : Gen at bus 66765	: Pg=31.77, Qg=17.6 -> Pg=31.85, Qg=17.6
% INFO    : Gen at bus 66765	: Vg=1.0018 -> Vg=1.0
% INFO    : Gen at bus 66766	: Pg=15.36, Qg=9.07 -> Pg=19.1, Qg=4.45
% INFO    : Gen at bus 66766	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66766	: Pg=15.36, Qg=9.07 -> Pg=19.1, Qg=4.45
% INFO    : Gen at bus 66766	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66766	: Pg=12.87, Qg=9.07 -> Pg=16.0, Qg=6.65
% INFO    : Gen at bus 66766	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66766	: Pg=13.35, Qg=9.07 -> Pg=16.6, Qg=6.9
% INFO    : Gen at bus 66766	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 66767	: Pg=6.45, Qg=-10.6 -> Pg=15.95, Qg=6.65
% INFO    : Gen at bus 66767	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66768	: Pg=31.35, Qg=-10.5 -> Pg=20.7, Qg=2.35
% INFO    : Gen at bus 66768	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66768	: Pg=31.35, Qg=-10.5 -> Pg=20.7, Qg=2.35
% INFO    : Gen at bus 66768	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66768	: Pg=31.35, Qg=-10.5 -> Pg=20.7, Qg=2.35
% INFO    : Gen at bus 66768	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66770	: Pg=18.06, Qg=12.1 -> Pg=21.5, Qg=12.1
% INFO    : Gen at bus 66770	: Vg=1.0004 -> Vg=1.0
% INFO    : Gen at bus 66770	: Pg=22.07, Qg=15.0 -> Pg=26.5, Qg=15.0
% INFO    : Gen at bus 66770	: Vg=1.0004 -> Vg=1.0
% INFO    : Gen at bus 66771	: Pg=12.47, Qg=-11.3 -> Pg=15.5, Qg=0.0
% INFO    : Gen at bus 66771	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66772	: Pg=1.07, Qg=-10.3 -> Pg=16.0, Qg=2.35
% INFO    : Gen at bus 66772	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66773	: Pg=24.8, Qg=-12.3 -> Pg=24.8, Qg=0.0
% INFO    : Gen at bus 66773	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66774	: Pg=15.05, Qg=17.6 -> Pg=19.25, Qg=17.6
% INFO    : Gen at bus 66774	: Vg=1.0006 -> Vg=1.0
% INFO    : Gen at bus 66774	: Pg=17.07, Qg=23.1 -> Pg=23.9, Qg=23.1
% INFO    : Gen at bus 66774	: Vg=1.0006 -> Vg=1.0
% INFO    : Gen at bus 66776	: Pg=10.18, Qg=0.12 -> Pg=5.515, Qg=0.835
% INFO    : Gen at bus 66776	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66776	: Pg=10.18, Qg=0.12 -> Pg=5.515, Qg=0.835
% INFO    : Gen at bus 66776	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66776	: Pg=10.18, Qg=0.12 -> Pg=5.515, Qg=0.835
% INFO    : Gen at bus 66776	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=3.61, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=3.61, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=3.61, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=3.61, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=3.61, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=15.11, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=25.09, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66778	: Pg=25.09, Qg=0.0 -> Pg=32.5, Qg=0.0
% INFO    : Gen at bus 66778	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 66780	: Pg=3.13, Qg=-5.0 -> Pg=9.05, Qg=3.125
% INFO    : Gen at bus 66780	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66780	: Pg=3.13, Qg=-5.0 -> Pg=9.05, Qg=3.125
% INFO    : Gen at bus 66780	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66781	: Pg=13.63, Qg=0.0 -> Pg=16.3, Qg=0.0
% INFO    : Gen at bus 66781	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 66781	: Pg=12.7, Qg=21.8 -> Pg=24.75, Qg=21.8
% INFO    : Gen at bus 66781	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 66782	: Pg=12.07, Qg=7.0 -> Pg=15.0, Qg=2.5
% INFO    : Gen at bus 66782	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66782	: Pg=12.07, Qg=7.0 -> Pg=15.0, Qg=2.5
% INFO    : Gen at bus 66782	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66782	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66782	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66784	: Pg=29.96, Qg=14.5 -> Pg=16.5, Qg=14.5
% INFO    : Gen at bus 66784	: Vg=0.9988 -> Vg=1.0
% INFO    : Gen at bus 66784	: Pg=29.96, Qg=14.5 -> Pg=16.5, Qg=14.5
% INFO    : Gen at bus 66784	: Vg=0.9988 -> Vg=1.0
% INFO    : Gen at bus 66784	: Pg=32.15, Qg=15.6 -> Pg=17.6, Qg=15.6
% INFO    : Gen at bus 66784	: Vg=0.9988 -> Vg=1.0
% INFO    : Gen at bus 66785	: Pg=29.96, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 66785	: Vg=0.9948 -> Vg=1.0
% INFO    : Gen at bus 66785	: Pg=29.96, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 66785	: Vg=0.9948 -> Vg=1.0
% INFO    : Gen at bus 66785	: Pg=29.96, Qg=0.0 -> Pg=16.5, Qg=0.0
% INFO    : Gen at bus 66785	: Vg=0.9948 -> Vg=1.0
% INFO    : Gen at bus 66786	: Pg=20.07, Qg=-2.54 -> Pg=25.0, Qg=4.3
% INFO    : Gen at bus 66786	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66786	: Pg=20.07, Qg=-2.54 -> Pg=25.0, Qg=4.3
% INFO    : Gen at bus 66786	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66786	: Pg=6.05, Qg=-2.54 -> Pg=14.5, Qg=4.8
% INFO    : Gen at bus 66786	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66787	: Pg=24.0, Qg=-11.9 -> Pg=24.0, Qg=0.0
% INFO    : Gen at bus 66787	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66788	: Pg=18.41, Qg=10.0 -> Pg=15.45, Qg=10.0
% INFO    : Gen at bus 66788	: Vg=1.0052 -> Vg=1.0
% INFO    : Gen at bus 66789	: Pg=23.92, Qg=-11.8 -> Pg=23.92, Qg=0.0
% INFO    : Gen at bus 66789	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66790	: Pg=3.3, Qg=-1.1 -> Pg=2.65, Qg=0.25
% INFO    : Gen at bus 66790	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66791	: Pg=11.95, Qg=5.0 -> Pg=14.85, Qg=2.25
% INFO    : Gen at bus 66791	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66792	: Pg=18.56, Qg=-7.12 -> Pg=18.56, Qg=0.0
% INFO    : Gen at bus 66792	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66792	: Pg=31.13, Qg=-7.12 -> Pg=31.13, Qg=0.0
% INFO    : Gen at bus 66792	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66793	: Pg=28.96, Qg=-9.7 -> Pg=20.5, Qg=6.05
% INFO    : Gen at bus 66793	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66794	: Pg=28.76, Qg=17.8 -> Pg=22.4, Qg=17.8
% INFO    : Gen at bus 66794	: Vg=1.0124 -> Vg=1.0
% INFO    : Gen at bus 66794	: Pg=28.76, Qg=17.8 -> Pg=22.4, Qg=17.8
% INFO    : Gen at bus 66794	: Vg=1.0124 -> Vg=1.0
% INFO    : Gen at bus 66794	: Pg=51.61, Qg=37.5 -> Pg=37.95, Qg=37.5
% INFO    : Gen at bus 66794	: Vg=1.0124 -> Vg=1.0
% INFO    : Gen at bus 66794	: Pg=51.61, Qg=37.5 -> Pg=37.95, Qg=37.5
% INFO    : Gen at bus 66794	: Vg=1.0124 -> Vg=1.0
% INFO    : Gen at bus 66795	: Pg=15.06, Qg=-5.02 -> Pg=21.8, Qg=2.2
% INFO    : Gen at bus 66795	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66796	: Pg=19.06, Qg=-9.5 -> Pg=23.75, Qg=4.1
% INFO    : Gen at bus 66796	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66796	: Pg=18.05, Qg=-7.7 -> Pg=20.5, Qg=3.3
% INFO    : Gen at bus 66796	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66797	: Pg=21.06, Qg=-12.1 -> Pg=24.65, Qg=0.0
% INFO    : Gen at bus 66797	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66799	: Pg=12.26, Qg=17.4 -> Pg=20.1, Qg=17.4
% INFO    : Gen at bus 66799	: Vg=0.9982 -> Vg=1.0
% INFO    : Gen at bus 66800	: Pg=4.06, Qg=-9.3 -> Pg=16.0, Qg=4.05
% INFO    : Gen at bus 66800	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66801	: Pg=12.06, Qg=-9.3 -> Pg=20.0, Qg=4.05
% INFO    : Gen at bus 66801	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66802	: Pg=12.26, Qg=-9.3 -> Pg=20.05, Qg=4.0
% INFO    : Gen at bus 66802	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66803	: Pg=27.66, Qg=-7.49 -> Pg=19.85, Qg=2.1
% INFO    : Gen at bus 66803	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66804	: Pg=5.51, Qg=-1.84 -> Pg=4.715, Qg=1.15
% INFO    : Gen at bus 66804	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66804	: Pg=5.51, Qg=-1.84 -> Pg=4.715, Qg=1.15
% INFO    : Gen at bus 66804	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66804	: Pg=5.51, Qg=-1.84 -> Pg=4.715, Qg=1.15
% INFO    : Gen at bus 66804	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66804	: Pg=5.51, Qg=-1.84 -> Pg=4.715, Qg=1.15
% INFO    : Gen at bus 66804	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66804	: Pg=5.51, Qg=-1.84 -> Pg=4.715, Qg=1.15
% INFO    : Gen at bus 66804	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66805	: Pg=27.36, Qg=-9.0 -> Pg=24.6, Qg=0.0
% INFO    : Gen at bus 66805	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66805	: Pg=27.36, Qg=-9.0 -> Pg=24.6, Qg=0.0
% INFO    : Gen at bus 66805	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66806	: Pg=27.36, Qg=9.0 -> Pg=25.35, Qg=9.0
% INFO    : Gen at bus 66806	: Vg=1.0016 -> Vg=1.0
% INFO    : Gen at bus 66807	: Pg=27.36, Qg=-9.1 -> Pg=21.2, Qg=2.1
% INFO    : Gen at bus 66807	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66807	: Pg=27.36, Qg=-9.1 -> Pg=21.2, Qg=2.1
% INFO    : Gen at bus 66807	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66808	: Pg=13.98, Qg=-3.9 -> Pg=16.15, Qg=0.0
% INFO    : Gen at bus 66808	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66809	: Pg=2.06, Qg=-9.1 -> Pg=14.65, Qg=3.9
% INFO    : Gen at bus 66809	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66810	: Pg=21.68, Qg=10.7 -> Pg=21.68, Qg=10.7
% INFO    : Gen at bus 66810	: Vg=1.0086 -> Vg=1.0
% INFO    : Gen at bus 66811	: Pg=13.48, Qg=0.29 -> Pg=6.75, Qg=1.025
% INFO    : Gen at bus 66811	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66811	: Pg=13.48, Qg=0.29 -> Pg=6.75, Qg=1.025
% INFO    : Gen at bus 66811	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66814	: Pg=16.08, Qg=-7.14 -> Pg=13.35, Qg=2.0
% INFO    : Gen at bus 66814	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66814	: Pg=16.08, Qg=-7.14 -> Pg=13.35, Qg=2.0
% INFO    : Gen at bus 66814	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66814	: Pg=16.08, Qg=-7.14 -> Pg=13.35, Qg=2.0
% INFO    : Gen at bus 66814	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66815	: Pg=5.88, Qg=8.05 -> Pg=9.575, Qg=8.05
% INFO    : Gen at bus 66815	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66815	: Pg=5.88, Qg=8.05 -> Pg=9.575, Qg=8.05
% INFO    : Gen at bus 66815	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66816	: Pg=6.59, Qg=3.2 -> Pg=3.3, Qg=3.2
% INFO    : Gen at bus 66816	: Vg=1.0074 -> Vg=1.0
% INFO    : Gen at bus 66816	: Pg=6.59, Qg=3.2 -> Pg=3.3, Qg=3.2
% INFO    : Gen at bus 66816	: Vg=1.0074 -> Vg=1.0
% INFO    : Gen at bus 66816	: Pg=6.59, Qg=3.2 -> Pg=3.3, Qg=3.2
% INFO    : Gen at bus 66816	: Vg=1.0074 -> Vg=1.0
% INFO    : Gen at bus 66816	: Pg=6.59, Qg=3.2 -> Pg=3.3, Qg=3.2
% INFO    : Gen at bus 66816	: Vg=1.0074 -> Vg=1.0
% INFO    : Gen at bus 66817	: Pg=15.05, Qg=14.3 -> Pg=19.0, Qg=14.3
% INFO    : Gen at bus 66817	: Vg=0.998 -> Vg=1.0
% INFO    : Gen at bus 66817	: Pg=15.56, Qg=15.9 -> Pg=20.55, Qg=15.9
% INFO    : Gen at bus 66817	: Vg=0.998 -> Vg=1.0
% INFO    : Gen at bus 66818	: Pg=15.36, Qg=3.09 -> Pg=12.75, Qg=3.65
% INFO    : Gen at bus 66818	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66818	: Pg=16.08, Qg=3.09 -> Pg=13.35, Qg=3.8
% INFO    : Gen at bus 66818	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66819	: Pg=15.76, Qg=-0.09 -> Pg=13.25, Qg=0.0
% INFO    : Gen at bus 66819	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66820	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66820	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66820	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66820	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66820	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66820	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66822	: Pg=12.48, Qg=0.0 -> Pg=10.25, Qg=0.0
% INFO    : Gen at bus 66822	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66822	: Pg=12.48, Qg=0.0 -> Pg=10.25, Qg=0.0
% INFO    : Gen at bus 66822	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66823	: Pg=10.12, Qg=0.0 -> Pg=12.55, Qg=0.0
% INFO    : Gen at bus 66823	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66823	: Pg=10.12, Qg=0.0 -> Pg=12.55, Qg=0.0
% INFO    : Gen at bus 66823	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66824	: Pg=15.06, Qg=15.5 -> Pg=20.0, Qg=15.5
% INFO    : Gen at bus 66824	: Vg=1.0033 -> Vg=1.0
% INFO    : Gen at bus 66825	: Pg=13.7, Qg=8.9 -> Pg=13.7, Qg=8.9
% INFO    : Gen at bus 66825	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 66825	: Pg=12.94, Qg=9.3 -> Pg=12.94, Qg=9.3
% INFO    : Gen at bus 66825	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 66825	: Pg=20.0, Qg=9.9 -> Pg=20.0, Qg=9.9
% INFO    : Gen at bus 66825	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 66825	: Pg=22.96, Qg=11.3 -> Pg=22.96, Qg=11.3
% INFO    : Gen at bus 66825	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 66826	: Pg=24.86, Qg=-8.3 -> Pg=17.95, Qg=1.9
% INFO    : Gen at bus 66826	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66826	: Pg=24.86, Qg=-8.3 -> Pg=17.95, Qg=1.9
% INFO    : Gen at bus 66826	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66828	: Pg=24.86, Qg=-2.84 -> Pg=22.95, Qg=3.55
% INFO    : Gen at bus 66828	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66828	: Pg=24.86, Qg=-2.84 -> Pg=22.95, Qg=3.55
% INFO    : Gen at bus 66828	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66829	: Pg=24.86, Qg=-2.14 -> Pg=22.95, Qg=3.55
% INFO    : Gen at bus 66829	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66829	: Pg=24.86, Qg=-2.14 -> Pg=22.95, Qg=3.55
% INFO    : Gen at bus 66829	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66830	: Pg=24.86, Qg=-1.63 -> Pg=22.95, Qg=3.55
% INFO    : Gen at bus 66830	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66830	: Pg=24.86, Qg=-1.63 -> Pg=22.95, Qg=3.55
% INFO    : Gen at bus 66830	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66831	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66831	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66832	: Pg=24.36, Qg=0.52 -> Pg=18.2, Qg=1.85
% INFO    : Gen at bus 66832	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66832	: Pg=24.36, Qg=0.52 -> Pg=18.2, Qg=1.85
% INFO    : Gen at bus 66832	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66833	: Pg=11.98, Qg=9.0 -> Pg=11.0, Qg=9.0
% INFO    : Gen at bus 66833	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 66833	: Pg=11.98, Qg=9.0 -> Pg=11.0, Qg=9.0
% INFO    : Gen at bus 66833	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 66834	: Pg=19.2, Qg=-6.77 -> Pg=19.2, Qg=0.0
% INFO    : Gen at bus 66834	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66834	: Pg=50.4, Qg=-6.77 -> Pg=50.4, Qg=0.0
% INFO    : Gen at bus 66834	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66835	: Pg=19.2, Qg=-8.01 -> Pg=19.2, Qg=0.0
% INFO    : Gen at bus 66835	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66836	: Pg=23.96, Qg=-8.0 -> Pg=13.5, Qg=3.45
% INFO    : Gen at bus 66836	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66837	: Pg=23.96, Qg=-4.8 -> Pg=18.0, Qg=1.8
% INFO    : Gen at bus 66837	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66838	: Pg=11.11, Qg=7.9 -> Pg=13.2, Qg=7.9
% INFO    : Gen at bus 66838	: Vg=1.0054 -> Vg=1.0
% INFO    : Gen at bus 66839	: Pg=14.33, Qg=4.04 -> Pg=11.9, Qg=1.8
% INFO    : Gen at bus 66839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66839	: Pg=15.06, Qg=4.04 -> Pg=12.5, Qg=1.9
% INFO    : Gen at bus 66839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66839	: Pg=15.06, Qg=4.04 -> Pg=12.5, Qg=1.9
% INFO    : Gen at bus 66839	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66840	: Pg=7.85, Qg=4.77 -> Pg=6.435, Qg=4.77
% INFO    : Gen at bus 66840	: Vg=0.9977 -> Vg=1.0
% INFO    : Gen at bus 66840	: Pg=7.85, Qg=4.77 -> Pg=6.435, Qg=4.77
% INFO    : Gen at bus 66840	: Vg=0.9977 -> Vg=1.0
% INFO    : Gen at bus 66840	: Pg=7.85, Qg=4.77 -> Pg=6.435, Qg=4.77
% INFO    : Gen at bus 66840	: Vg=0.9977 -> Vg=1.0
% INFO    : Gen at bus 66841	: Pg=23.27, Qg=14.4 -> Pg=18.65, Qg=14.4
% INFO    : Gen at bus 66841	: Vg=1.0119 -> Vg=1.0
% INFO    : Gen at bus 66841	: Pg=23.27, Qg=14.4 -> Pg=18.65, Qg=14.4
% INFO    : Gen at bus 66841	: Vg=1.0119 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=57.31, Qg=4.35 -> Pg=41.2, Qg=8.25
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=7.05, Qg=4.35 -> Pg=15.0, Qg=3.3
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=15.11, Qg=4.35 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=15.11, Qg=4.35 -> Pg=32.5, Qg=7.15
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=16.06, Qg=4.35 -> Pg=20.7, Qg=1.9
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=34.12, Qg=4.35 -> Pg=44.55, Qg=4.15
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=16.24, Qg=4.35 -> Pg=10.5, Qg=2.85
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66844	: Pg=16.24, Qg=4.35 -> Pg=10.5, Qg=2.85
% INFO    : Gen at bus 66844	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 66845	: Pg=5.05, Qg=-7.7 -> Pg=14.0, Qg=3.3
% INFO    : Gen at bus 66845	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66846	: Pg=17.92, Qg=-8.9 -> Pg=17.92, Qg=0.0
% INFO    : Gen at bus 66846	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66847	: Pg=17.76, Qg=8.8 -> Pg=17.76, Qg=8.8
% INFO    : Gen at bus 66847	: Vg=1.0341 -> Vg=1.0
% INFO    : Gen at bus 66847	: Pg=35.52, Qg=17.5 -> Pg=35.52, Qg=17.5
% INFO    : Gen at bus 66847	: Vg=1.0341 -> Vg=1.0
% INFO    : Gen at bus 66848	: Pg=13.25, Qg=-7.3 -> Pg=11.0, Qg=4.6
% INFO    : Gen at bus 66848	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66849	: Pg=14.05, Qg=-7.3 -> Pg=12.0, Qg=1.7
% INFO    : Gen at bus 66849	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66850	: Pg=10.88, Qg=-2.0 -> Pg=10.88, Qg=0.0
% INFO    : Gen at bus 66850	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66851	: Pg=4.62, Qg=-3.56 -> Pg=4.62, Qg=0.0
% INFO    : Gen at bus 66851	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66851	: Pg=7.01, Qg=-3.56 -> Pg=7.01, Qg=0.0
% INFO    : Gen at bus 66851	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66852	: Pg=8.76, Qg=4.35 -> Pg=8.76, Qg=4.35
% INFO    : Gen at bus 66852	: Vg=1.0106 -> Vg=1.0
% INFO    : Gen at bus 66852	: Pg=8.76, Qg=4.35 -> Pg=8.76, Qg=4.35
% INFO    : Gen at bus 66852	: Vg=1.0106 -> Vg=1.0
% INFO    : Gen at bus 66853	: Pg=17.36, Qg=-8.6 -> Pg=17.36, Qg=0.0
% INFO    : Gen at bus 66853	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66854	: Pg=21.57, Qg=-7.2 -> Pg=17.55, Qg=1.65
% INFO    : Gen at bus 66854	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66855	: Pg=9.28, Qg=-2.12 -> Pg=9.28, Qg=0.0
% INFO    : Gen at bus 66855	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66856	: Pg=4.22, Qg=-1.26 -> Pg=4.22, Qg=0.0
% INFO    : Gen at bus 66856	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66856	: Pg=4.22, Qg=-1.26 -> Pg=4.22, Qg=0.0
% INFO    : Gen at bus 66856	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66858	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66860	: Pg=8.73, Qg=9.9 -> Pg=10.65, Qg=9.9
% INFO    : Gen at bus 66860	: Vg=1.0059 -> Vg=1.0
% INFO    : Gen at bus 66861	: Pg=14.5, Qg=0.0 -> Pg=13.05, Qg=0.0
% INFO    : Gen at bus 66861	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66862	: Pg=9.99, Qg=-0.64 -> Pg=6.5, Qg=2.075
% INFO    : Gen at bus 66862	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66862	: Pg=9.99, Qg=-0.64 -> Pg=6.5, Qg=2.075
% INFO    : Gen at bus 66862	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66863	: Pg=9.99, Qg=-0.72 -> Pg=5.0, Qg=2.075
% INFO    : Gen at bus 66863	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66863	: Pg=9.99, Qg=-0.72 -> Pg=5.0, Qg=2.075
% INFO    : Gen at bus 66863	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66864	: Pg=6.66, Qg=1.27 -> Pg=4.17, Qg=0.0
% INFO    : Gen at bus 66864	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66864	: Pg=6.66, Qg=1.27 -> Pg=4.17, Qg=0.0
% INFO    : Gen at bus 66864	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66864	: Pg=6.66, Qg=1.27 -> Pg=4.17, Qg=0.0
% INFO    : Gen at bus 66864	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66865	: Pg=15.04, Qg=-6.7 -> Pg=17.5, Qg=1.5
% INFO    : Gen at bus 66865	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66866	: Pg=19.97, Qg=15.0 -> Pg=10.5, Qg=15.0
% INFO    : Gen at bus 66866	: Vg=0.9837 -> Vg=1.0
% INFO    : Gen at bus 66867	: Pg=1.04, Qg=-6.7 -> Pg=10.5, Qg=2.85
% INFO    : Gen at bus 66867	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 66868	: Pg=16.0, Qg=7.9 -> Pg=16.0, Qg=7.9
% INFO    : Gen at bus 66868	: Vg=1.0288 -> Vg=1.0
% INFO    : Gen at bus 75434	: Pg=132.06, Qg=-35.13 -> Pg=121.4, Qg=24.75
% INFO    : Gen at bus 75434	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75440	: Pg=85.2, Qg=-47.0 -> Pg=85.2, Qg=0.0
% INFO    : Gen at bus 75440	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75452	: Pg=8.39, Qg=-2.8 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 75452	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75452	: Pg=8.39, Qg=-2.8 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 75452	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75452	: Pg=8.39, Qg=-2.8 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 75452	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75452	: Pg=8.39, Qg=-2.8 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 75452	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75452	: Pg=8.39, Qg=-2.8 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 75452	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75452	: Pg=8.39, Qg=-2.8 -> Pg=4.7, Qg=1.75
% INFO    : Gen at bus 75452	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75455	: Pg=7.93, Qg=0.0 -> Pg=8.3, Qg=0.0
% INFO    : Gen at bus 75455	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75455	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75455	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75461	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75461	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75461	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75461	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75461	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75462	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75462	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75462	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75462	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75462	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75462	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75462	: Pg=5.02, Qg=-2.5 -> Pg=6.25, Qg=1.56
% INFO    : Gen at bus 75462	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75464	: Pg=23.27, Qg=-7.8 -> Pg=15.15, Qg=1.75
% INFO    : Gen at bus 75464	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75482	: Pg=69.92, Qg=-7.5 -> Pg=69.92, Qg=13.2
% INFO    : Gen at bus 75482	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75482	: Pg=50.16, Qg=-7.5 -> Pg=50.16, Qg=0.0
% INFO    : Gen at bus 75482	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75482	: Pg=59.8, Qg=-7.5 -> Pg=59.8, Qg=0.0
% INFO    : Gen at bus 75482	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75483	: Pg=55.12, Qg=54.1 -> Pg=55.12, Qg=54.1
% INFO    : Gen at bus 75483	: Vg=1.0195 -> Vg=1.0
% INFO    : Gen at bus 75490	: Pg=30.6, Qg=9.3 -> Pg=30.6, Qg=0.0
% INFO    : Gen at bus 75490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75490	: Pg=88.4, Qg=9.3 -> Pg=88.4, Qg=16.65
% INFO    : Gen at bus 75490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75498	: Pg=1.52, Qg=-1.77 -> Pg=5.04, Qg=1.405
% INFO    : Gen at bus 75498	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75498	: Pg=1.52, Qg=-1.77 -> Pg=5.04, Qg=1.405
% INFO    : Gen at bus 75498	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75498	: Pg=1.52, Qg=-1.77 -> Pg=5.04, Qg=1.405
% INFO    : Gen at bus 75498	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75498	: Pg=1.52, Qg=-1.77 -> Pg=5.04, Qg=1.405
% INFO    : Gen at bus 75498	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75498	: Pg=1.52, Qg=-1.77 -> Pg=5.04, Qg=1.405
% INFO    : Gen at bus 75498	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75498	: Pg=1.52, Qg=-1.77 -> Pg=5.04, Qg=1.405
% INFO    : Gen at bus 75498	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75500	: Pg=9.61, Qg=-15.8 -> Pg=23.75, Qg=3.6
% INFO    : Gen at bus 75500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75500	: Pg=9.61, Qg=-15.8 -> Pg=23.75, Qg=3.6
% INFO    : Gen at bus 75500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75500	: Pg=9.61, Qg=-15.8 -> Pg=23.75, Qg=3.6
% INFO    : Gen at bus 75500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75500	: Pg=9.61, Qg=-15.8 -> Pg=23.75, Qg=3.6
% INFO    : Gen at bus 75500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75516	: Pg=209.76, Qg=-87.4 -> Pg=209.76, Qg=19.8
% INFO    : Gen at bus 75516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75518	: Pg=205.55, Qg=-2.07 -> Pg=226.5, Qg=35.5
% INFO    : Gen at bus 75518	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75525	: Pg=76.76, Qg=-59.0 -> Pg=76.76, Qg=13.35
% INFO    : Gen at bus 75525	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75529	: Pg=90.38, Qg=-39.31 -> Pg=120.0, Qg=24.35
% INFO    : Gen at bus 75529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75529	: Pg=55.25, Qg=-38.1 -> Pg=84.65, Qg=16.35
% INFO    : Gen at bus 75529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75534	: Pg=59.76, Qg=29.58 -> Pg=59.76, Qg=0.0
% INFO    : Gen at bus 75534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75545	: Pg=38.36, Qg=-42.3 -> Pg=38.36, Qg=0.0
% INFO    : Gen at bus 75545	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75552	: Pg=36.2, Qg=-32.7 -> Pg=45.0, Qg=0.0
% INFO    : Gen at bus 75552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75552	: Pg=36.2, Qg=-32.7 -> Pg=45.0, Qg=0.0
% INFO    : Gen at bus 75552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75559	: Pg=28.08, Qg=21.65 -> Pg=28.08, Qg=0.0
% INFO    : Gen at bus 75559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75559	: Pg=56.16, Qg=21.65 -> Pg=56.16, Qg=0.0
% INFO    : Gen at bus 75559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75561	: Pg=17.47, Qg=-5.82 -> Pg=10.25, Qg=1.325
% INFO    : Gen at bus 75561	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75561	: Pg=17.47, Qg=-5.82 -> Pg=10.25, Qg=1.325
% INFO    : Gen at bus 75561	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75561	: Pg=17.47, Qg=-5.82 -> Pg=10.25, Qg=1.325
% INFO    : Gen at bus 75561	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75561	: Pg=17.47, Qg=-5.82 -> Pg=10.25, Qg=1.325
% INFO    : Gen at bus 75561	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75566	: Pg=5.11, Qg=23.0 -> Pg=26.25, Qg=23.0
% INFO    : Gen at bus 75566	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 75566	: Pg=5.11, Qg=23.0 -> Pg=26.25, Qg=23.0
% INFO    : Gen at bus 75566	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 75572	: Pg=7.44, Qg=4.81 -> Pg=18.4, Qg=0.0
% INFO    : Gen at bus 75572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75572	: Pg=7.44, Qg=4.81 -> Pg=18.4, Qg=0.0
% INFO    : Gen at bus 75572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75572	: Pg=7.44, Qg=4.81 -> Pg=18.4, Qg=0.0
% INFO    : Gen at bus 75572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75572	: Pg=19.6, Qg=4.81 -> Pg=48.45, Qg=0.0
% INFO    : Gen at bus 75572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75577	: Pg=7.99, Qg=-2.68 -> Pg=5.0, Qg=0.6
% INFO    : Gen at bus 75577	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75577	: Pg=7.99, Qg=-2.68 -> Pg=5.0, Qg=0.6
% INFO    : Gen at bus 75577	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75577	: Pg=7.99, Qg=-2.68 -> Pg=5.0, Qg=0.6
% INFO    : Gen at bus 75577	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75577	: Pg=7.99, Qg=-2.68 -> Pg=5.0, Qg=0.6
% INFO    : Gen at bus 75577	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75580	: Pg=9.11, Qg=-4.95 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 75580	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75580	: Pg=9.11, Qg=-4.95 -> Pg=7.6, Qg=0.0
% INFO    : Gen at bus 75580	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75583	: Pg=6.59, Qg=2.45 -> Pg=4.3, Qg=2.45
% INFO    : Gen at bus 75583	: Vg=1.012 -> Vg=1.0
% INFO    : Gen at bus 75583	: Pg=6.59, Qg=2.45 -> Pg=4.3, Qg=2.45
% INFO    : Gen at bus 75583	: Vg=1.012 -> Vg=1.0
% INFO    : Gen at bus 75583	: Pg=6.59, Qg=2.45 -> Pg=4.3, Qg=2.45
% INFO    : Gen at bus 75583	: Vg=1.012 -> Vg=1.0
% INFO    : Gen at bus 75583	: Pg=6.59, Qg=2.45 -> Pg=4.3, Qg=2.45
% INFO    : Gen at bus 75583	: Vg=1.012 -> Vg=1.0
% INFO    : Gen at bus 75585	: Pg=8.91, Qg=-8.1 -> Pg=14.65, Qg=1.85
% INFO    : Gen at bus 75585	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75588	: Pg=4.04, Qg=12.4 -> Pg=12.0, Qg=12.4
% INFO    : Gen at bus 75588	: Vg=1.0111 -> Vg=1.0
% INFO    : Gen at bus 75588	: Pg=4.06, Qg=15.5 -> Pg=14.5, Qg=15.5
% INFO    : Gen at bus 75588	: Vg=1.0111 -> Vg=1.0
% INFO    : Gen at bus 75593	: Pg=401.7, Qg=-24.05 -> Pg=218.65, Qg=30.35
% INFO    : Gen at bus 75593	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75595	: Pg=115.2, Qg=-63.5 -> Pg=115.2, Qg=0.0
% INFO    : Gen at bus 75595	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75600	: Pg=39.94, Qg=-13.3 -> Pg=32.35, Qg=3.05
% INFO    : Gen at bus 75600	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75600	: Pg=52.2, Qg=-30.0 -> Pg=71.0, Qg=6.8
% INFO    : Gen at bus 75600	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75604	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75604	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75606	: Pg=4.03, Qg=-3.83 -> Pg=7.75, Qg=1.65
% INFO    : Gen at bus 75606	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75606	: Pg=4.03, Qg=-3.83 -> Pg=7.75, Qg=1.65
% INFO    : Gen at bus 75606	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75606	: Pg=4.03, Qg=-3.83 -> Pg=7.75, Qg=1.65
% INFO    : Gen at bus 75606	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75608	: Pg=2.03, Qg=-5.0 -> Pg=8.5, Qg=2.15
% INFO    : Gen at bus 75608	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75608	: Pg=2.03, Qg=-5.0 -> Pg=8.5, Qg=2.15
% INFO    : Gen at bus 75608	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 75610	: Pg=120.38, Qg=-57.6 -> Pg=146.4, Qg=13.05
% INFO    : Gen at bus 75610	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75619	: Pg=50.18, Qg=-1.33 -> Pg=66.6, Qg=17.35
% INFO    : Gen at bus 75619	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75619	: Pg=50.18, Qg=-1.33 -> Pg=66.6, Qg=17.35
% INFO    : Gen at bus 75619	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75623	: Pg=45.83, Qg=-15.3 -> Pg=42.95, Qg=3.45
% INFO    : Gen at bus 75623	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75623	: Pg=45.83, Qg=-15.3 -> Pg=42.95, Qg=3.45
% INFO    : Gen at bus 75623	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75623	: Pg=120.4, Qg=-59.7 -> Pg=149.55, Qg=13.5
% INFO    : Gen at bus 75623	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75624	: Pg=8.92, Qg=-14.5 -> Pg=22.05, Qg=0.0
% INFO    : Gen at bus 75624	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75624	: Pg=8.92, Qg=-14.5 -> Pg=22.05, Qg=0.0
% INFO    : Gen at bus 75624	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75624	: Pg=8.92, Qg=-14.5 -> Pg=22.05, Qg=0.0
% INFO    : Gen at bus 75624	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75624	: Pg=8.92, Qg=-14.5 -> Pg=22.05, Qg=0.0
% INFO    : Gen at bus 75624	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75625	: Pg=8.82, Qg=-3.67 -> Pg=5.5, Qg=0.83
% INFO    : Gen at bus 75625	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75625	: Pg=8.82, Qg=-3.67 -> Pg=5.5, Qg=0.83
% INFO    : Gen at bus 75625	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75625	: Pg=8.82, Qg=-3.67 -> Pg=5.5, Qg=0.83
% INFO    : Gen at bus 75625	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75626	: Pg=6.23, Qg=-10.3 -> Pg=15.4, Qg=2.3
% INFO    : Gen at bus 75626	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75626	: Pg=6.23, Qg=-10.3 -> Pg=15.4, Qg=2.3
% INFO    : Gen at bus 75626	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75626	: Pg=6.23, Qg=-10.3 -> Pg=15.4, Qg=2.3
% INFO    : Gen at bus 75626	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 75632	: Pg=4.14, Qg=0.24 -> Pg=34.5, Qg=0.0
% INFO    : Gen at bus 75632	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75632	: Pg=4.06, Qg=0.24 -> Pg=16.4, Qg=4.1
% INFO    : Gen at bus 75632	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75632	: Pg=2.02, Qg=0.24 -> Pg=6.0, Qg=2.075
% INFO    : Gen at bus 75632	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 75632	: Pg=2.02, Qg=0.24 -> Pg=6.0, Qg=2.075
% INFO    : Gen at bus 75632	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76719	: Pg=53.92, Qg=-2.58 -> Pg=29.5, Qg=11.25
% INFO    : Gen at bus 76719	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76719	: Pg=7.31, Qg=-2.58 -> Pg=17.125, Qg=4.75
% INFO    : Gen at bus 76719	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76719	: Pg=7.31, Qg=-2.58 -> Pg=17.125, Qg=4.75
% INFO    : Gen at bus 76719	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76719	: Pg=7.31, Qg=-2.58 -> Pg=17.125, Qg=4.75
% INFO    : Gen at bus 76719	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76719	: Pg=7.31, Qg=-2.58 -> Pg=17.125, Qg=4.75
% INFO    : Gen at bus 76719	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76725	: Pg=32.1, Qg=-10.25 -> Pg=38.05, Qg=3.35
% INFO    : Gen at bus 76725	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76725	: Pg=37.14, Qg=-10.25 -> Pg=49.8, Qg=4.7
% INFO    : Gen at bus 76725	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76728	: Pg=50.53, Qg=-20.2 -> Pg=35.25, Qg=8.65
% INFO    : Gen at bus 76728	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76728	: Pg=50.53, Qg=-20.2 -> Pg=35.25, Qg=8.65
% INFO    : Gen at bus 76728	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76733	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76738	: Pg=3.06, Qg=-4.59 -> Pg=15.1, Qg=3.9
% INFO    : Gen at bus 76738	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76739	: Pg=26.96, Qg=6.1 -> Pg=16.0, Qg=3.85
% INFO    : Gen at bus 76739	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76739	: Pg=26.96, Qg=6.1 -> Pg=16.0, Qg=3.85
% INFO    : Gen at bus 76739	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76739	: Pg=26.96, Qg=6.1 -> Pg=16.0, Qg=3.85
% INFO    : Gen at bus 76739	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76739	: Pg=26.76, Qg=6.1 -> Pg=18.4, Qg=5.6
% INFO    : Gen at bus 76739	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76761	: Pg=97.94, Qg=-17.05 -> Pg=107.0, Qg=22.05
% INFO    : Gen at bus 76761	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76761	: Pg=97.94, Qg=-17.05 -> Pg=107.0, Qg=22.05
% INFO    : Gen at bus 76761	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76761	: Pg=45.52, Qg=-17.05 -> Pg=139.0, Qg=33.35
% INFO    : Gen at bus 76761	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76763	: Pg=75.33, Qg=-50.0 -> Pg=112.5, Qg=11.3
% INFO    : Gen at bus 76763	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76763	: Pg=75.33, Qg=-50.0 -> Pg=112.5, Qg=11.3
% INFO    : Gen at bus 76763	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76781	: Pg=11.4, Qg=-9.1 -> Pg=14.05, Qg=0.0
% INFO    : Gen at bus 76781	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76783	: Pg=8.81, Qg=15.2 -> Pg=16.875, Qg=15.2
% INFO    : Gen at bus 76783	: Vg=1.0064 -> Vg=1.0
% INFO    : Gen at bus 76783	: Pg=17.61, Qg=30.3 -> Pg=33.75, Qg=30.3
% INFO    : Gen at bus 76783	: Vg=1.0064 -> Vg=1.0
% INFO    : Gen at bus 76804	: Pg=80.0, Qg=-29.62 -> Pg=80.0, Qg=0.0
% INFO    : Gen at bus 76804	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76827	: Pg=63.85, Qg=-38.0 -> Pg=72.0, Qg=16.35
% INFO    : Gen at bus 76827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76827	: Pg=63.85, Qg=-38.0 -> Pg=72.0, Qg=16.35
% INFO    : Gen at bus 76827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76827	: Pg=63.85, Qg=-38.0 -> Pg=72.0, Qg=16.35
% INFO    : Gen at bus 76827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76827	: Pg=294.36, Qg=-98.3 -> Pg=172.4, Qg=22.25
% INFO    : Gen at bus 76827	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76833	: Pg=61.91, Qg=-20.7 -> Pg=56.0, Qg=4.65
% INFO    : Gen at bus 76833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76833	: Pg=61.91, Qg=-20.7 -> Pg=56.0, Qg=4.65
% INFO    : Gen at bus 76833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76833	: Pg=61.34, Qg=-21.3 -> Pg=57.0, Qg=4.85
% INFO    : Gen at bus 76833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76833	: Pg=61.34, Qg=-21.3 -> Pg=57.0, Qg=4.85
% INFO    : Gen at bus 76833	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76837	: Pg=11.78, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 76837	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76837	: Pg=11.78, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 76837	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76837	: Pg=11.78, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 76837	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76837	: Pg=11.78, Qg=0.0 -> Pg=5.95, Qg=0.0
% INFO    : Gen at bus 76837	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76839	: Pg=2.61, Qg=0.19 -> Pg=1.485, Qg=0.475
% INFO    : Gen at bus 76839	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76841	: Pg=19.05, Qg=-6.4 -> Pg=20.6, Qg=1.7
% INFO    : Gen at bus 76841	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76841	: Pg=19.05, Qg=-6.4 -> Pg=20.6, Qg=1.7
% INFO    : Gen at bus 76841	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76841	: Pg=19.05, Qg=-6.4 -> Pg=20.6, Qg=1.7
% INFO    : Gen at bus 76841	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76841	: Pg=14.95, Qg=-6.4 -> Pg=17.35, Qg=2.25
% INFO    : Gen at bus 76841	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 76850	: Pg=94.78, Qg=-57.3 -> Pg=123.5, Qg=24.65
% INFO    : Gen at bus 76850	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76850	: Pg=94.78, Qg=-57.3 -> Pg=123.5, Qg=24.65
% INFO    : Gen at bus 76850	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76850	: Pg=130.68, Qg=-101.7 -> Pg=217.5, Qg=23.0
% INFO    : Gen at bus 76850	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 76856	: Pg=43.34, Qg=3.72 -> Pg=31.7, Qg=3.25
% INFO    : Gen at bus 76856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76856	: Pg=43.34, Qg=3.72 -> Pg=31.7, Qg=3.25
% INFO    : Gen at bus 76856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76856	: Pg=43.34, Qg=3.72 -> Pg=31.7, Qg=3.25
% INFO    : Gen at bus 76856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76856	: Pg=43.34, Qg=3.72 -> Pg=31.7, Qg=3.25
% INFO    : Gen at bus 76856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76856	: Pg=43.34, Qg=3.72 -> Pg=31.7, Qg=3.25
% INFO    : Gen at bus 76856	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 76859	: Pg=39.94, Qg=19.4 -> Pg=36.0, Qg=19.4
% INFO    : Gen at bus 76859	: Vg=0.9848 -> Vg=1.0
% INFO    : Gen at bus 76859	: Pg=39.94, Qg=24.8 -> Pg=36.0, Qg=24.8
% INFO    : Gen at bus 76859	: Vg=0.9848 -> Vg=1.0
% INFO    : Gen at bus 76861	: Pg=30.65, Qg=-10.2 -> Pg=17.35, Qg=4.4
% INFO    : Gen at bus 76861	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78242	: Pg=28.09, Qg=-14.1 -> Pg=35.2, Qg=6.1
% INFO    : Gen at bus 78242	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78242	: Pg=62.2, Qg=-30.3 -> Pg=76.4, Qg=13.0
% INFO    : Gen at bus 78242	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78258	: Pg=55.17, Qg=-25.7 -> Pg=66.0, Qg=11.0
% INFO    : Gen at bus 78258	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78260	: Pg=18.17, Qg=-25.0 -> Pg=46.5, Qg=10.75
% INFO    : Gen at bus 78260	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78268	: Pg=24.06, Qg=-23.3 -> Pg=46.9, Qg=10.0
% INFO    : Gen at bus 78268	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78268	: Pg=24.06, Qg=-23.3 -> Pg=46.9, Qg=10.0
% INFO    : Gen at bus 78268	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78273	: Pg=60.41, Qg=-20.2 -> Pg=37.75, Qg=8.65
% INFO    : Gen at bus 78273	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78274	: Pg=60.41, Qg=-20.2 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 78274	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78274	: Pg=60.41, Qg=-20.2 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 78274	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78277	: Pg=51.53, Qg=37.5 -> Pg=37.75, Qg=8.65
% INFO    : Gen at bus 78277	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78277	: Pg=51.53, Qg=37.5 -> Pg=37.75, Qg=8.65
% INFO    : Gen at bus 78277	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78278	: Pg=22.27, Qg=-0.67 -> Pg=18.15, Qg=1.7
% INFO    : Gen at bus 78278	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78278	: Pg=14.59, Qg=-0.67 -> Pg=31.65, Qg=7.9
% INFO    : Gen at bus 78278	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78278	: Pg=11.37, Qg=-0.67 -> Pg=25.9, Qg=7.1
% INFO    : Gen at bus 78278	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78279	: Pg=23.13, Qg=-20.0 -> Pg=41.5, Qg=8.6
% INFO    : Gen at bus 78279	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78279	: Pg=15.07, Qg=-10.0 -> Pg=17.5, Qg=4.3
% INFO    : Gen at bus 78279	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78281	: Pg=47.68, Qg=-20.15 -> Pg=47.68, Qg=0.0
% INFO    : Gen at bus 78281	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78282	: Pg=58.81, Qg=-19.6 -> Pg=39.95, Qg=8.45
% INFO    : Gen at bus 78282	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78283	: Pg=58.21, Qg=-7.24 -> Pg=30.15, Qg=4.4
% INFO    : Gen at bus 78283	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78287	: Pg=30.12, Qg=26.9 -> Pg=42.75, Qg=26.9
% INFO    : Gen at bus 78287	: Vg=1.0159 -> Vg=1.0
% INFO    : Gen at bus 78289	: Pg=25.09, Qg=18.6 -> Pg=31.7, Qg=18.6
% INFO    : Gen at bus 78289	: Vg=1.0074 -> Vg=1.0
% INFO    : Gen at bus 78289	: Pg=13.56, Qg=14.2 -> Pg=20.55, Qg=14.2
% INFO    : Gen at bus 78289	: Vg=1.0074 -> Vg=1.0
% INFO    : Gen at bus 78289	: Pg=13.56, Qg=14.2 -> Pg=20.55, Qg=14.2
% INFO    : Gen at bus 78289	: Vg=1.0074 -> Vg=1.0
% INFO    : Gen at bus 78300	: Pg=22.12, Qg=33.5 -> Pg=38.0, Qg=33.5
% INFO    : Gen at bus 78300	: Vg=1.0002 -> Vg=1.0
% INFO    : Gen at bus 78303	: Pg=52.92, Qg=-3.86 -> Pg=49.0, Qg=7.55
% INFO    : Gen at bus 78303	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78303	: Pg=52.92, Qg=-3.86 -> Pg=49.0, Qg=7.55
% INFO    : Gen at bus 78303	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78305	: Pg=6.13, Qg=-19.9 -> Pg=32.85, Qg=8.55
% INFO    : Gen at bus 78305	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78305	: Pg=5.11, Qg=-16.7 -> Pg=27.5, Qg=10.4
% INFO    : Gen at bus 78305	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78307	: Pg=49.83, Qg=-8.08 -> Pg=43.35, Qg=0.0
% INFO    : Gen at bus 78307	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78307	: Pg=49.83, Qg=-8.08 -> Pg=43.2, Qg=0.0
% INFO    : Gen at bus 78307	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78309	: Pg=49.73, Qg=-4.79 -> Pg=47.85, Qg=7.15
% INFO    : Gen at bus 78309	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78310	: Pg=49.73, Qg=30.9 -> Pg=48.35, Qg=30.9
% INFO    : Gen at bus 78310	: Vg=0.9935 -> Vg=1.0
% INFO    : Gen at bus 78311	: Pg=49.73, Qg=-5.33 -> Pg=48.35, Qg=7.15
% INFO    : Gen at bus 78311	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78313	: Pg=49.43, Qg=-16.5 -> Pg=32.75, Qg=3.75
% INFO    : Gen at bus 78313	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78316	: Pg=48.93, Qg=-16.3 -> Pg=33.5, Qg=7.05
% INFO    : Gen at bus 78316	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78318	: Pg=9.83, Qg=-16.2 -> Pg=24.3, Qg=3.65
% INFO    : Gen at bus 78318	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78320	: Pg=48.43, Qg=-16.2 -> Pg=41.25, Qg=6.95
% INFO    : Gen at bus 78320	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78322	: Pg=47.23, Qg=-10.44 -> Pg=33.65, Qg=6.75
% INFO    : Gen at bus 78322	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78323	: Pg=47.23, Qg=-15.8 -> Pg=33.65, Qg=3.55
% INFO    : Gen at bus 78323	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78328	: Pg=46.43, Qg=5.11 -> Pg=35.75, Qg=3.5
% INFO    : Gen at bus 78328	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78333	: Pg=44.93, Qg=27.9 -> Pg=34.0, Qg=27.9
% INFO    : Gen at bus 78333	: Vg=1.0068 -> Vg=1.0
% INFO    : Gen at bus 78333	: Pg=44.93, Qg=27.9 -> Pg=34.0, Qg=27.9
% INFO    : Gen at bus 78333	: Vg=1.0068 -> Vg=1.0
% INFO    : Gen at bus 78333	: Pg=44.93, Qg=27.9 -> Pg=34.0, Qg=27.9
% INFO    : Gen at bus 78333	: Vg=1.0068 -> Vg=1.0
% INFO    : Gen at bus 78333	: Pg=44.93, Qg=27.9 -> Pg=34.0, Qg=27.9
% INFO    : Gen at bus 78333	: Vg=1.0068 -> Vg=1.0
% INFO    : Gen at bus 78335	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 78335	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78335	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 78335	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78335	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 78335	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78335	: Pg=11.18, Qg=0.0 -> Pg=8.6, Qg=0.0
% INFO    : Gen at bus 78335	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78341	: Pg=27.86, Qg=13.5 -> Pg=21.95, Qg=13.5
% INFO    : Gen at bus 78341	: Vg=1.0145 -> Vg=1.0
% INFO    : Gen at bus 78341	: Pg=27.86, Qg=13.5 -> Pg=21.95, Qg=13.5
% INFO    : Gen at bus 78341	: Vg=1.0145 -> Vg=1.0
% INFO    : Gen at bus 78341	: Pg=18.14, Qg=16.6 -> Pg=15.9, Qg=16.6
% INFO    : Gen at bus 78341	: Vg=1.0145 -> Vg=1.0
% INFO    : Gen at bus 78341	: Pg=19.09, Qg=30.0 -> Pg=22.5, Qg=30.0
% INFO    : Gen at bus 78341	: Vg=1.0145 -> Vg=1.0
% INFO    : Gen at bus 78347	: Pg=38.64, Qg=-12.9 -> Pg=31.85, Qg=5.55
% INFO    : Gen at bus 78347	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78354	: Pg=35.75, Qg=-8.7 -> Pg=18.9, Qg=5.15
% INFO    : Gen at bus 78354	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78359	: Pg=10.22, Qg=-1.11 -> Pg=8.6, Qg=3.45
% INFO    : Gen at bus 78359	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78359	: Pg=10.22, Qg=-1.11 -> Pg=8.6, Qg=3.45
% INFO    : Gen at bus 78359	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78360	: Pg=16.57, Qg=15.0 -> Pg=24.75, Qg=15.0
% INFO    : Gen at bus 78360	: Vg=1.0047 -> Vg=1.0
% INFO    : Gen at bus 78367	: Pg=21.55, Qg=3.28 -> Pg=22.5, Qg=1.8
% INFO    : Gen at bus 78367	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78367	: Pg=28.07, Qg=3.28 -> Pg=29.55, Qg=3.4
% INFO    : Gen at bus 78367	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78368	: Pg=14.25, Qg=14.3 -> Pg=17.5, Qg=14.3
% INFO    : Gen at bus 78368	: Vg=0.9993 -> Vg=1.0
% INFO    : Gen at bus 78368	: Pg=15.77, Qg=19.0 -> Pg=23.2, Qg=19.0
% INFO    : Gen at bus 78368	: Vg=0.9993 -> Vg=1.0
% INFO    : Gen at bus 78369	: Pg=30.06, Qg=18.7 -> Pg=16.05, Qg=18.7
% INFO    : Gen at bus 78369	: Vg=1.0007 -> Vg=1.0
% INFO    : Gen at bus 78371	: Pg=4.99, Qg=-1.67 -> Pg=4.3, Qg=1.04
% INFO    : Gen at bus 78371	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78371	: Pg=4.99, Qg=-1.67 -> Pg=4.3, Qg=1.04
% INFO    : Gen at bus 78371	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78371	: Pg=4.99, Qg=-1.67 -> Pg=4.3, Qg=1.04
% INFO    : Gen at bus 78371	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78371	: Pg=4.99, Qg=-1.67 -> Pg=4.3, Qg=1.04
% INFO    : Gen at bus 78371	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78371	: Pg=4.99, Qg=-1.67 -> Pg=4.3, Qg=1.04
% INFO    : Gen at bus 78371	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78371	: Pg=4.99, Qg=-1.67 -> Pg=4.3, Qg=1.04
% INFO    : Gen at bus 78371	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78373	: Pg=30.0, Qg=14.5 -> Pg=16.14, Qg=2.25
% INFO    : Gen at bus 78373	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 78376	: Pg=9.32, Qg=7.0 -> Pg=8.165, Qg=7.0
% INFO    : Gen at bus 78376	: Vg=0.9989 -> Vg=1.0
% INFO    : Gen at bus 78376	: Pg=9.32, Qg=7.0 -> Pg=8.165, Qg=7.0
% INFO    : Gen at bus 78376	: Vg=0.9989 -> Vg=1.0
% INFO    : Gen at bus 78376	: Pg=9.32, Qg=7.0 -> Pg=8.165, Qg=7.0
% INFO    : Gen at bus 78376	: Vg=0.9989 -> Vg=1.0
% INFO    : Gen at bus 78377	: Pg=19.55, Qg=0.0 -> Pg=21.75, Qg=0.0
% INFO    : Gen at bus 78377	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78377	: Pg=21.56, Qg=0.0 -> Pg=24.25, Qg=0.0
% INFO    : Gen at bus 78377	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78378	: Pg=22.47, Qg=16.9 -> Pg=16.5, Qg=16.9
% INFO    : Gen at bus 78378	: Vg=1.0012 -> Vg=1.0
% INFO    : Gen at bus 78378	: Pg=5.84, Qg=10.05 -> Pg=7.075, Qg=10.05
% INFO    : Gen at bus 78378	: Vg=1.0012 -> Vg=1.0
% INFO    : Gen at bus 78378	: Pg=5.84, Qg=10.05 -> Pg=7.075, Qg=10.05
% INFO    : Gen at bus 78378	: Vg=1.0012 -> Vg=1.0
% INFO    : Gen at bus 78381	: Pg=18.06, Qg=15.6 -> Pg=21.6, Qg=15.6
% INFO    : Gen at bus 78381	: Vg=1.0064 -> Vg=1.0
% INFO    : Gen at bus 78381	: Pg=22.07, Qg=19.7 -> Pg=26.9, Qg=19.7
% INFO    : Gen at bus 78381	: Vg=1.0064 -> Vg=1.0
% INFO    : Gen at bus 78384	: Pg=24.86, Qg=15.4 -> Pg=13.2, Qg=15.4
% INFO    : Gen at bus 78384	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 78384	: Pg=24.86, Qg=15.4 -> Pg=13.2, Qg=15.4
% INFO    : Gen at bus 78384	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 78388	: Pg=23.07, Qg=-7.7 -> Pg=13.05, Qg=1.75
% INFO    : Gen at bus 78388	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78388	: Pg=23.07, Qg=-7.7 -> Pg=13.05, Qg=1.75
% INFO    : Gen at bus 78388	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78388	: Pg=23.07, Qg=-7.7 -> Pg=13.05, Qg=1.75
% INFO    : Gen at bus 78388	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78388	: Pg=23.07, Qg=-7.7 -> Pg=13.05, Qg=1.75
% INFO    : Gen at bus 78388	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78389	: Pg=18.48, Qg=-9.1 -> Pg=18.48, Qg=0.0
% INFO    : Gen at bus 78389	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 78391	: Pg=15.09, Qg=15.8 -> Pg=13.55, Qg=15.8
% INFO    : Gen at bus 78391	: Vg=0.9898 -> Vg=1.0
% INFO    : Gen at bus 78392	: Pg=20.97, Qg=10.2 -> Pg=10.5, Qg=1.6
% INFO    : Gen at bus 78392	: Vg=1.0 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
