%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE2868RTE
%   AC Power flow data for French system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of French
%   very high voltage transmission network.
%   Part of this data was sampled in the offline platform of iTesla.
%   These data can be used to validate mathematical methods and tools.
%   These data should NOT be used for operation
%   nor planning of the French or European grids.
%
%   When publishing results using this data, please cite:
%     C. Josz, S. Fliscounakis, J. Maeght, and P. Panciatici,
%     "AC Power Flow Data in MATPOWER and QCQP Format: iTesla, RTE Snapshots, and PEGASE"
%     http://arxiv.org/abs/1603.01533
%
%   Contacts (primary contact for this file : Jean Maeght):
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 4th, 2016
%
%   Copyright (c) 2016 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case2868_rte
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 -18.5	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2	 1	 11.8	 0.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	3	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	4	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	5	 1	 0.2	 -0.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	6	 1	 5.6	 -19.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	7	 1	 223.6	 7.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	8	 1	 68.6	 7.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	10	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	11	 1	 49.1	 0.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2571	 1	 34.0	 14.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	12	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	13	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04534	    0.00000	 225.0	 1	    1.09067	    1.00000;
	14	 1	 0.2	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	15	 1	 10.3	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	16	 1	 189.8	 54.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	17	 1	 54.5	 13.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	18	 1	 67.6	 23.2	 0.0	 0.0	 1	    1.04481	    0.00000	 225.0	 1	    1.08962	    1.00000;
	19	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00362	    0.00000	 63.0	 1	    1.08661	    0.92063;
	20	 1	 150.5	 40.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	21	 1	 78.1	 6.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	22	 1	 15.0	 -9.4	 0.0	 0.0	 1	    1.00450	    0.00000	 63.0	 1	    1.07249	    0.93651;
	23	 1	 50.9	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	24	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	25	 1	 65.1	 1.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	26	 1	 1.6	 -4.2	 0.0	 0.0	 1	    1.04158	    0.00000	 225.0	 1	    1.09649	    0.98667;
	27	 1	 42.8	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	28	 1	 39.4	 15.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2574	 1	 42.2	 12.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	29	 1	 11.4	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	30	 1	 72.7	 36.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	31	 1	 2.7	 -1.4	 0.0	 0.0	 1	    1.00431	    0.00000	 63.0	 1	    1.07211	    0.93651;
	32	 1	 13.8	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	33	 1	 2.0	 -0.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	34	 1	 0.4	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	35	 1	 30.4	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	36	 1	 1.9	 -3.1	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	37	 1	 18.9	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	38	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	39	 1	 99.3	 18.8	 0.0	 0.0	 1	    1.03800	    0.00000	 225.0	 1	    1.08934	    0.98667;
	40	 1	 38.7	 0.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	41	 1	 89.8	 13.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	42	 1	 63.9	 9.7	 0.0	 0.0	 1	    1.00010	    0.00000	 63.0	 1	    1.06370	    0.93651;
	43	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	44	 1	 33.1	 -6.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	45	 1	 168.4	 34.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	46	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	47	 1	 29.5	 4.5	 0.0	 0.0	 1	    1.00128	    0.00000	 63.0	 1	    1.06606	    0.93651;
	48	 1	 1.6	 0.0	 0.0	 0.0	 1	    1.00193	    0.00000	 63.0	 1	    1.06735	    0.93651;
	49	 1	 14.9	 10.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2576	 1	 9.9	 7.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	50	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	51	 1	 114.9	 20.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	52	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2942	 1	 106.0	 29.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	53	 2	 5.7	 -6.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	54	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	55	 1	 65.6	 18.0	 0.0	 80.0	 1	    1.04730	    0.00000	 225.0	 1	    1.09459	    1.00000;
	56	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	57	 1	 146.4	 39.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	59	 1	 78.7	 21.1	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	60	 1	 125.2	 37.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	61	 1	 6.0	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	63	 1	 36.1	 4.7	 0.0	 7.7	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	64	 1	 53.3	 13.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	65	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	66	 1	 43.4	 -0.7	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2578	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	67	 1	 41.3	 12.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2579	 1	 38.5	 8.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	68	 1	 19.6	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	69	 1	 320.7	 74.9	 0.0	 0.0	 1	    1.04343	    0.00000	 225.0	 1	    1.08685	    1.00000;
	70	 1	 140.9	 -22.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	71	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00442	    0.00000	 150.0	 1	    1.10885	    0.90000;
	72	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	74	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	75	 1	 15.6	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	76	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	77	 1	 6.4	 0.3	 0.0	 0.0	 1	    1.00272	    0.00000	 63.0	 1	    1.08481	    0.92063;
	78	 1	 4.8	 2.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	79	 1	 17.4	 1.7	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	80	 1	 10.0	 -0.6	 0.0	 0.0	 1	    1.00404	    0.00000	 63.0	 1	    1.08744	    0.92063;
	81	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	82	 1	 63.1	 25.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	83	 1	 44.1	 1.9	 0.0	 0.0	 1	    1.01544	    0.00000	 63.0	 1	    1.06349	    0.96740;
	84	 1	 162.3	 51.1	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	85	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	86	 1	 58.3	 14.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	87	 1	 32.5	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	88	 1	 1.5	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	89	 1	 55.7	 8.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2581	 1	 30.1	 12.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	90	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	91	 1	 190.1	 8.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	92	 1	 36.8	 -8.5	 0.0	 0.0	 1	    1.01187	    0.00000	 225.0	 1	    1.09041	    0.93333;
	93	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00453	    0.00000	 150.0	 1	    1.10907	    0.90000;
	94	 1	 35.7	 55.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2583	 1	 34.0	 3.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	95	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	96	 1	 15.9	 4.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	97	 1	 40.4	 6.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	98	 1	 -3.5	 -1.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	99	 1	 18.2	 5.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2584	 1	 33.2	 14.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	100	 1	 -17.2	 -4.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	101	 1	 24.4	 1.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	102	 1	 0.0	 0.0	 0.0	 80.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2585	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	104	 1	 74.9	 14.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2586	 1	 29.0	 6.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	105	 1	 11.4	 9.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	107	 1	 5.7	 10.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	108	 1	 54.1	 1.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	111	 1	 103.3	 18.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	112	 1	 -1.5	 2.2	 0.0	 0.0	 1	    1.04517	    0.00000	 225.0	 1	    1.09035	    1.00000;
	2588	 1	 16.5	 -0.1	 0.0	 0.0	 1	    1.04517	    0.00000	 225.0	 1	    1.09035	    1.00000;
	113	 1	 47.0	 9.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	114	 1	 43.8	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	115	 1	 16.4	 1.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	116	 1	 56.9	 18.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	117	 1	 3.2	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	118	 1	 44.0	 10.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	119	 1	 28.5	 -5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	120	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00257	    0.00000	 63.0	 1	    1.06863	    0.93651;
	121	 1	 8.5	 3.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2589	 1	 15.0	 6.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	122	 1	 142.7	 -26.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	123	 1	 32.4	 7.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	124	 2	 4.7	 -2.0	 0.0	 0.0	 1	    1.00133	    0.00000	 63.0	 1	    1.08203	    0.92063;
	125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	128	 1	 26.4	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	129	 2	 16.3	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	130	 1	 10.9	 16.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	132	 1	 139.1	 40.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	133	 2	 9.2	 3.6	 0.0	 0.0	 1	    1.01682	    0.00000	 63.0	 1	    1.06538	    0.96825;
	134	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	135	 2	 -14.9	 -4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	136	 1	 31.7	 10.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	137	 1	 9.7	 -2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	138	 1	 12.8	 5.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	141	 1	 20.8	 1.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	142	 1	 10.3	 9.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	143	 1	 28.7	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	144	 1	 82.9	 11.1	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	145	 1	 72.9	 0.2	 0.0	 0.0	 1	    1.04462	    0.00000	 225.0	 1	    1.08925	    1.00000;
	146	 2	 -3.7	 -0.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2592	 1	 66.1	 19.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	151	 1	 24.0	 9.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	153	 1	 137.1	 23.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	155	 1	 55.3	 18.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	156	 1	 30.9	 4.2	 0.0	 0.0	 1	    1.00077	    0.00000	 63.0	 1	    1.06503	    0.93651;
	157	 1	 2.4	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	158	 1	 27.5	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	159	 1	 24.3	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	160	 1	 5.6	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	161	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	162	 1	 0.5	 -40.5	 0.0	 0.0	 1	    1.04527	    0.00000	 225.0	 1	    1.09053	    1.00000;
	163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	164	 1	 109.3	 -1.7	 0.0	 0.0	 1	    1.04895	    0.00000	 225.0	 1	    1.09791	    1.00000;
	165	 1	 187.3	 17.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	166	 1	 51.6	 6.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	167	 1	 119.3	 36.7	 0.0	 0.0	 1	    1.04534	    0.00000	 225.0	 1	    1.09067	    1.00000;
	168	 1	 14.1	 -5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	169	 1	 24.1	 -4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	170	 1	 1.8	 0.3	 0.0	 0.0	 1	    1.00236	    0.00000	 63.0	 1	    1.06822	    0.93651;
	171	 1	 181.5	 51.4	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	172	 2	 -0.0	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	173	 1	 82.5	 15.9	 0.0	 0.0	 1	    1.04141	    0.00000	 225.0	 1	    1.09616	    0.98667;
	174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	175	 1	 120.7	 -49.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	177	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01217	    0.00000	 63.0	 1	    1.06349	    0.96086;
	178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	180	 1	 5.0	 0.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	181	 1	 -3.0	 -14.3	 0.0	 0.0	 1	    0.95270	    0.00000	 45.0	 1	    1.01652	    0.88889;
	182	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	184	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	185	 1	 22.3	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	186	 1	 -2.4	 -2.2	 0.0	 0.0	 1	    1.04931	    0.00000	 225.0	 1	    1.09862	    1.00000;
	187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2594	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04175	    0.00000	 225.0	 1	    1.09683	    0.98667;
	2596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04175	    0.00000	 225.0	 1	    1.09683	    0.98667;
	189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	190	 1	 39.7	 -5.2	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	191	 1	 36.6	 -1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	192	 1	 38.7	 6.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	193	 1	 51.7	 10.5	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	197	 1	 6.2	 17.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	198	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	199	 1	 250.8	 25.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	200	 1	 47.3	 6.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2598	 1	 44.8	 9.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	201	 1	 51.0	 0.4	 0.0	 0.0	 1	    1.04514	    0.00000	 225.0	 1	    1.09027	    1.00000;
	202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04765	    0.00000	 225.0	 1	    1.09529	    1.00000;
	2599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04765	    0.00000	 225.0	 1	    1.09529	    1.00000;
	203	 1	 76.8	 4.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	204	 1	 31.4	 -2.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	207	 1	 13.9	 5.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	208	 1	 6.3	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	209	 1	 44.8	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	211	 1	 33.9	 5.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	215	 1	 -3.6	 -5.3	 0.0	 0.0	 1	    1.00034	    0.00000	 63.0	 1	    1.06418	    0.93651;
	216	 1	 186.0	 34.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04930	    0.00000	 225.0	 1	    1.09861	    1.00000;
	218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	219	 1	 37.1	 2.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	220	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	221	 1	 22.8	 6.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	223	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	224	 1	 70.6	 -9.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	225	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	227	 1	 15.7	 -0.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	229	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04520	    0.00000	 225.0	 1	    1.09040	    1.00000;
	230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	231	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	232	 1	 13.4	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2603	 1	 8.9	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	234	 1	 3.8	 0.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2604	 1	 53.2	 27.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	235	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	236	 2	 26.8	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	237	 1	 15.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	238	 1	 48.1	 15.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	239	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04595	    0.00000	 225.0	 1	    1.09190	    1.00000;
	2605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04595	    0.00000	 225.0	 1	    1.09190	    1.00000;
	2606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04595	    0.00000	 225.0	 1	    1.09190	    1.00000;
	2607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04595	    0.00000	 225.0	 1	    1.09190	    1.00000;
	2608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04595	    0.00000	 225.0	 1	    1.09190	    1.00000;
	240	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.05347	    0.00000	 380.0	 1	    1.10694	    1.00000;
	241	 1	 13.8	 6.5	 0.0	 0.0	 1	    1.00186	    0.00000	 63.0	 1	    1.06721	    0.93651;
	242	 1	 43.7	 6.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	243	 1	 165.4	 29.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	244	 1	 39.8	 7.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	245	 1	 36.4	 15.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	247	 1	 42.1	 16.7	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	248	 1	 24.3	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	249	 1	 13.6	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	250	 1	 -2.7	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	251	 1	 87.5	 47.6	 0.0	 0.0	 1	    1.04342	    0.00000	 225.0	 1	    1.08684	    1.00000;
	252	 2	 -0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	253	 1	 -0.9	 0.5	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	254	 1	 -0.4	 0.5	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	255	 1	 5.8	 -0.5	 0.0	 0.0	 1	    1.00202	    0.00000	 63.0	 1	    1.06754	    0.93651;
	256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	258	 1	 65.9	 4.3	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	259	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2613	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2614	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	261	 1	 92.8	 34.4	 0.0	 0.0	 1	    1.04244	    0.00000	 225.0	 1	    1.08489	    1.00000;
	262	 2	 9.8	 1.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	263	 1	 30.9	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2616	 1	 23.9	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2617	 1	 23.0	 0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	264	 1	 195.0	 -58.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	265	 1	 14.6	 -4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	266	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	268	 1	 21.6	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	269	 1	 34.5	 5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	270	 1	 155.6	 18.6	 0.0	 0.0	 1	    1.02000	    0.00000	 225.0	 1	    1.08889	    0.95111;
	271	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	272	 1	 76.6	 12.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	273	 1	 89.1	 13.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	274	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	275	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	276	 1	 21.1	 -6.0	 0.0	 0.0	 1	    1.00601	    0.00000	 63.0	 1	    1.09138	    0.92063;
	277	 1	 20.3	 2.7	 0.0	 0.0	 1	    1.00188	    0.00000	 63.0	 1	    1.06725	    0.93651;
	279	 1	 29.3	 1.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	281	 1	 41.0	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	282	 1	 108.4	 30.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	283	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	284	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	285	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2618	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	286	 1	 274.1	 47.6	 0.0	 80.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	288	 1	 112.4	 25.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	289	 1	 70.1	 19.9	 0.0	 0.0	 1	    1.04087	    0.00000	 225.0	 1	    1.09508	    0.98667;
	290	 1	 86.7	 14.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2621	 1	 26.5	 2.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	291	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2622	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	295	 1	 61.5	 7.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	296	 1	 13.2	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	297	 1	 81.6	 9.8	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	298	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2624	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2625	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	300	 1	 9.7	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	301	 1	 44.1	 19.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2627	 1	 -0.2	 -0.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	302	 1	 -0.7	 -3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	303	 1	 10.2	 0.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	304	 1	 14.3	 -2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	305	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01639	    0.00000	 63.0	 1	    1.06453	    0.96825;
	2628	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01639	    0.00000	 63.0	 1	    1.06453	    0.96825;
	306	 1	 79.9	 15.4	 0.0	 0.0	 1	    1.04553	    0.00000	 225.0	 1	    1.09106	    1.00000;
	307	 1	 19.9	 2.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2629	 1	 33.7	 -2.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	308	 1	 1.0	 0.3	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	309	 1	 -0.0	 -7.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	310	 2	 0.1	 -0.8	 0.0	 0.0	 1	    1.00477	    0.00000	 63.0	 1	    1.08891	    0.92063;
	311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	313	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	314	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94488	    0.00000	 45.0	 1	    1.00087	    0.88889;
	315	 1	 0.2	 -1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	316	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97670	    0.00000	 63.0	 1	    1.37727	    0.57614;
	317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	318	 1	 0.1	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	319	 1	 15.2	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2630	 1	 26.1	 -0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2631	 1	 16.6	 3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	320	 1	 152.8	 2.6	 0.0	 0.0	 1	    1.04967	    0.00000	 225.0	 1	    1.09934	    1.00000;
	321	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	322	 1	 102.3	 16.7	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	324	 1	 44.1	 13.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2632	 1	 35.0	 8.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	325	 1	 4.7	 1.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2633	 1	 -0.0	 1.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	326	 2	 7.1	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2634	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	327	 1	 1.9	 -1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	328	 1	 34.5	 2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	329	 1	 22.2	 10.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2635	 1	 16.2	 10.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	330	 1	 41.5	 -0.3	 0.0	 0.0	 1	    1.01615	    0.00000	 63.0	 1	    1.06405	    0.96825;
	331	 1	 20.0	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2636	 1	 22.7	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	332	 1	 3.5	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2637	 1	 18.9	 12.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2638	 1	 197.7	 48.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	334	 1	 64.2	 16.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2639	 1	 56.3	 15.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	335	 2	 -26.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	337	 1	 42.8	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	338	 1	 -8.9	 -19.9	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.11579	    1.00000;
	339	 1	 51.1	 21.8	 0.0	 0.0	 1	    1.05837	    0.00000	 380.0	 1	    1.11674	    1.00000;
	340	 1	 -16.7	 -26.0	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.11579	    1.00000;
	341	 1	 -35.3	 -10.2	 0.0	 0.0	 1	    1.05794	    0.00000	 380.0	 1	    1.11587	    1.00000;
	342	 1	 93.3	 25.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	344	 1	 28.5	 -2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	345	 1	 15.7	 -2.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	346	 1	 5.7	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	348	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2641	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	350	 1	 18.6	 -1.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	351	 1	 -1.5	 -1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	352	 1	 160.1	 26.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	353	 1	 14.1	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	354	 1	 28.2	 -4.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	356	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2642	 1	 2.5	 9.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2643	 1	 4.4	 0.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	358	 1	 165.9	 70.6	 0.0	 0.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	359	 1	 90.1	 -2.3	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	360	 1	 25.8	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	361	 1	 172.0	 23.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	362	 1	 29.7	 10.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	365	 1	 308.6	 79.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	367	 2	 43.4	 33.1	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	369	 1	 242.8	 92.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	370	 1	 1.9	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	371	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	372	 1	 306.7	 50.2	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	373	 1	 69.1	 41.5	 0.0	 0.0	 1	    1.04140	    0.00000	 225.0	 1	    1.09613	    0.98667;
	374	 1	 1.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	375	 1	 10.5	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	376	 1	 20.6	 0.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	377	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2647	 1	 44.0	 11.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	378	 1	 16.4	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00314	    0.00000	 63.0	 1	    1.06977	    0.93651;
	381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	383	 1	 2.5	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04522	    0.00000	 225.0	 1	    1.09043	    1.00000;
	2648	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04522	    0.00000	 225.0	 1	    1.09043	    1.00000;
	385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	386	 1	 43.1	 1.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2649	 1	 107.7	 16.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	387	 1	 77.8	 14.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	388	 1	 32.2	 5.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2650	 1	 22.3	 3.5	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	389	 1	 72.3	 11.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	391	 1	 182.8	 65.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2652	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	393	 1	 14.7	 1.1	 0.0	 0.0	 1	    1.00203	    0.00000	 63.0	 1	    1.06755	    0.93651;
	394	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	395	 1	 260.2	 52.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	396	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	397	 1	 59.5	 13.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	399	 1	 9.1	 -3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	402	 1	 273.1	 28.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	403	 1	 2.2	 -1.7	 0.0	 0.0	 1	    1.05823	    0.00000	 380.0	 1	    1.11646	    1.00000;
	404	 1	 -21.8	 6.7	 0.0	 0.0	 1	    1.05890	    0.00000	 380.0	 1	    1.11779	    1.00000;
	405	 1	 79.6	 21.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	409	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	410	 1	 121.1	 -28.4	 0.0	 0.0	 1	    1.04853	    0.00000	 225.0	 1	    1.09705	    1.00000;
	411	 1	 -12.6	 -2.4	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2655	 1	 -5.8	 -2.3	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	412	 1	 34.7	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	413	 1	 2.5	 -5.4	 0.0	 0.0	 1	    1.01182	    0.00000	 225.0	 1	    1.09031	    0.93333;
	414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	415	 1	 149.5	 16.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	416	 1	 57.0	 16.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2657	 1	 43.7	 8.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	417	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	418	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2658	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	420	 1	 3.7	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	421	 1	 200.9	 65.2	 0.0	 80.0	 1	    1.04498	    0.00000	 225.0	 1	    1.08996	    1.00000;
	422	 1	 16.8	 4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	423	 1	 76.2	 12.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	424	 1	 7.9	 -8.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	425	 1	 0.5	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	426	 2	 -4.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	427	 1	 0.0	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	428	 1	 135.6	 -20.4	 0.0	 0.0	 1	    1.04317	    0.00000	 225.0	 1	    1.08635	    1.00000;
	429	 1	 -5.3	 -12.9	 0.0	 0.0	 1	    1.03809	    0.00000	 225.0	 1	    1.08951	    0.98667;
	430	 1	 126.9	 17.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	431	 1	 25.6	 18.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	432	 1	 13.6	 7.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	433	 1	 132.9	 -6.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	434	 1	 48.0	 -1.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	435	 1	 31.1	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	436	 1	 35.6	 6.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	437	 1	 102.9	 23.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	438	 1	 25.2	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	439	 1	 86.3	 27.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	440	 1	 35.6	 15.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2660	 1	 35.5	 20.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	441	 1	 257.8	 47.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	442	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	443	 1	 -3.4	 7.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	444	 1	 388.0	 84.2	 0.0	 80.0	 1	    1.04310	    0.00000	 225.0	 1	    1.08619	    1.00000;
	445	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2661	 1	 -2.0	 0.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2662	 1	 -0.4	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	446	 1	 -5.5	 3.4	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	447	 1	 6.9	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	449	 1	 53.5	 12.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2663	 1	 67.4	 21.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	450	 1	 149.6	 32.1	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	451	 1	 59.1	 -2.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2664	 1	 124.6	 11.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2946	 1	 -4.9	 0.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	455	 1	 169.1	 39.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	456	 1	 11.6	 8.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	457	 1	 138.4	 26.6	 0.0	 0.0	 1	    1.03897	    0.00000	 225.0	 1	    1.09127	    0.98667;
	458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	460	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04643	    0.00000	 225.0	 1	    1.09286	    1.00000;
	461	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	462	 1	 18.3	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	463	 1	 -1.1	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	465	 1	 13.5	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	466	 1	 25.3	 12.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	467	 1	 81.9	 -16.5	 0.0	 0.0	 1	    1.04387	    0.00000	 225.0	 1	    1.08774	    1.00000;
	468	 1	 -0.5	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	469	 1	 25.3	 -3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	472	 1	 53.3	 -8.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	473	 1	 5.8	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	474	 1	 145.3	 36.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	475	 1	 15.9	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	476	 1	 17.6	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2668	 1	 49.0	 9.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	477	 1	 97.4	 7.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	478	 1	 -0.9	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	480	 1	 152.3	 34.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	482	 1	 30.2	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	483	 1	 93.4	 19.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2669	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2670	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	485	 1	 43.1	 8.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2671	 1	 64.4	 18.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	486	 1	 28.9	 -7.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	487	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	488	 1	 48.1	 19.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	489	 2	 -2.4	 0.0	 0.0	 0.0	 1	    1.00336	    0.00000	 63.0	 1	    1.08609	    0.92063;
	490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00782	    0.00000	 63.0	 1	    1.09501	    0.92063;
	491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	492	 1	 0.1	 -0.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2672	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	495	 1	 12.5	 1.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	496	 1	 31.4	 -0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	497	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	499	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02872	    0.00000	 63.0	 1	    1.13680	    0.92063;
	500	 1	 0.4	 1.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2675	 1	 3.1	 -0.1	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	501	 1	 1.7	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	502	 1	 19.1	 -4.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	503	 1	 23.3	 -0.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	504	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94451	    0.00000	 45.0	 1	    1.00014	    0.88889;
	505	 1	 116.9	 20.9	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	507	 1	 -2.3	 -3.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	509	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	510	 1	 11.9	 -3.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	511	 1	 94.4	 30.1	 0.0	 0.0	 1	    1.04101	    0.00000	 225.0	 1	    1.09536	    0.98667;
	512	 1	 107.9	 10.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	513	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	515	 1	 14.9	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	516	 1	 244.7	 12.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	517	 1	 67.4	 17.4	 0.0	 0.0	 1	    0.99919	    0.00000	 225.0	 1	    1.09172	    0.90667;
	518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	519	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02201	    0.00000	 63.0	 1	    1.07577	    0.96825;
	520	 1	 71.0	 15.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	521	 1	 48.6	 9.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	522	 1	 137.8	 34.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	523	 1	 9.4	 -0.1	 0.0	 0.0	 1	    1.00350	    0.00000	 63.0	 1	    1.07050	    0.93651;
	524	 1	 64.2	 -0.1	 0.0	 0.0	 1	    1.00445	    0.00000	 225.0	 1	    1.08889	    0.92000;
	526	 1	 32.5	 3.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	527	 1	 237.3	 53.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	528	 1	 6.4	 0.3	 0.0	 0.0	 1	    1.00045	    0.00000	 63.0	 1	    1.06440	    0.93651;
	529	 1	 31.1	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	530	 1	 -0.3	 0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	531	 1	 10.1	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	532	 1	 54.6	 8.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	533	 1	 -0.8	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	534	 1	 17.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	535	 1	 0.1	 0.4	 0.0	 0.0	 1	    1.00076	    0.00000	 63.0	 1	    1.06502	    0.93651;
	2678	 1	 -0.3	 0.5	 0.0	 0.0	 1	    1.00076	    0.00000	 63.0	 1	    1.06502	    0.93651;
	536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	538	 1	 47.5	 6.3	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	539	 1	 129.5	 40.1	 0.0	 0.0	 1	    1.04338	    0.00000	 225.0	 1	    1.08675	    1.00000;
	540	 1	 4.7	 -3.2	 0.0	 0.0	 1	    1.02127	    0.00000	 63.0	 1	    1.07428	    0.96825;
	541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	542	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	543	 1	 31.7	 5.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	544	 1	 51.3	 14.4	 0.0	 0.0	 1	    1.04538	    0.00000	 225.0	 1	    1.09076	    1.00000;
	545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04323	    0.00000	 225.0	 1	    1.09980	    0.98667;
	546	 1	 66.1	 11.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	547	 1	 67.0	 6.0	 0.0	 0.0	 1	    1.04319	    0.00000	 225.0	 1	    1.09971	    0.98667;
	548	 1	 49.4	 4.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	549	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	550	 1	 5.6	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	551	 1	 219.6	 28.2	 0.0	 0.0	 1	    1.03859	    0.00000	 225.0	 1	    1.09052	    0.98667;
	552	 1	 28.2	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2679	 1	 16.1	 3.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	554	 1	 -0.2	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	555	 1	 63.1	 18.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	556	 1	 31.2	 -3.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	557	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	558	 1	 76.4	 -55.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	560	 1	 73.0	 38.0	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	561	 1	 83.9	 23.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	562	 1	 12.2	 0.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	563	 1	 48.2	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	564	 1	 -1.5	 7.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00248	    0.00000	 45.0	 1	    1.07162	    0.93333;
	567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	568	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	569	 1	 46.7	 3.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	570	 1	 9.5	 0.2	 0.0	 0.0	 1	    0.98949	    0.00000	 225.0	 1	    1.09009	    0.88889;
	571	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	573	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	574	 1	 89.2	 22.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	575	 1	 40.8	 32.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	576	 1	 15.6	 -6.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	577	 1	 10.4	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	578	 1	 27.0	 -9.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	580	 1	 129.1	 56.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	582	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 17.0	 1	    1.20000	    0.80000;
	2680	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 17.0	 1	    1.20000	    0.80000;
	2977	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 17.0	 1	    1.20000	    0.80000;
	2978	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 17.0	 1	    1.20000	    0.80000;
	583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	2681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	584	 1	 93.2	 -11.7	 0.0	 0.0	 1	    1.04262	    0.00000	 225.0	 1	    1.08524	    1.00000;
	586	 1	 166.0	 38.4	 0.0	 0.0	 1	    1.04251	    0.00000	 225.0	 1	    1.08502	    1.00000;
	587	 1	 144.5	 38.2	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	590	 1	 154.6	 65.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	591	 1	 13.7	 -2.2	 0.0	 0.0	 1	    1.00673	    0.00000	 63.0	 1	    1.07696	    0.93651;
	592	 1	 35.5	 3.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	593	 1	 24.4	 6.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	594	 1	 22.9	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	595	 1	 5.3	 7.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	596	 1	 242.8	 23.2	 0.0	 0.0	 1	    1.04598	    0.00000	 225.0	 1	    1.09196	    1.00000;
	597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2682	 1	 25.9	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	598	 1	 31.7	 11.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	599	 1	 17.8	 2.6	 0.0	 0.0	 1	    1.00279	    0.00000	 63.0	 1	    1.06907	    0.93651;
	600	 1	 51.7	 7.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	603	 1	 76.3	 11.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	604	 2	 39.1	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	607	 1	 25.9	 7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	608	 1	 144.0	 42.4	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	609	 1	 25.0	 21.4	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	610	 1	 34.5	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	612	 1	 106.8	 -54.3	 0.0	 0.0	 1	    1.04277	    0.00000	 225.0	 1	    1.08554	    1.00000;
	613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	614	 1	 250.7	 18.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2685	 1	 51.9	 22.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	615	 1	 3.7	 7.9	 0.0	 0.0	 1	    1.04568	    0.00000	 225.0	 1	    1.09137	    1.00000;
	616	 1	 20.2	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	618	 1	 51.3	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	619	 1	 41.8	 -1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	620	 1	 6.1	 -4.8	 0.0	 0.0	 1	    1.01549	    0.00000	 63.0	 1	    1.06349	    0.96749;
	621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	622	 1	 10.4	 1.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2686	 1	 3.9	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	624	 1	 -0.6	 -0.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	625	 1	 34.3	 6.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2687	 1	 51.8	 13.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	626	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	627	 1	 72.5	 17.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	628	 1	 34.3	 -3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	629	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	630	 1	 18.9	 -2.4	 0.0	 0.0	 1	    1.01353	    0.00000	 63.0	 1	    1.06349	    0.96357;
	631	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	632	 1	 5.3	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	633	 1	 -0.1	 -0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	634	 1	 19.6	 2.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	635	 1	 -2.7	 0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	636	 1	 14.6	 -4.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	637	 1	 99.8	 15.3	 0.0	 0.0	 1	    1.03860	    0.00000	 225.0	 1	    1.09054	    0.98667;
	638	 1	 150.8	 28.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	639	 1	 71.8	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	641	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02121	    0.00000	 63.0	 1	    1.07417	    0.96825;
	643	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	644	 1	 65.7	 3.5	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05540	    0.00000	 380.0	 1	    1.11080	    1.00000;
	2688	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05540	    0.00000	 380.0	 1	    1.11080	    1.00000;
	646	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04258	    0.00000	 225.0	 1	    1.09849	    0.98667;
	2689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04258	    0.00000	 225.0	 1	    1.09849	    0.98667;
	647	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	648	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	649	 1	 77.3	 28.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	650	 1	 53.6	 12.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2690	 1	 48.5	 15.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2691	 1	 62.1	 -7.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2692	 1	 60.1	 -0.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	652	 1	 136.1	 39.7	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	653	 1	 63.8	 15.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2693	 1	 56.5	 11.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	654	 1	 106.8	 -16.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	655	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	656	 1	 15.6	 1.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	657	 1	 136.2	 13.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	658	 1	 11.9	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	659	 1	 0.3	 2.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2694	 1	 0.3	 2.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	660	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2695	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	662	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2696	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2697	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2699	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2700	 1	 18.4	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	665	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	666	 1	 22.1	 19.8	 0.0	 15.4	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	667	 1	 31.0	 8.6	 0.0	 0.0	 1	    1.00405	    0.00000	 63.0	 1	    1.08746	    0.92063;
	668	 1	 1.9	 1.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	669	 1	 4.6	 -0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	670	 1	 16.1	 7.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2701	 1	 16.5	 0.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2702	 1	 0.2	 -4.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2703	 1	 0.2	 -2.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	671	 1	 16.5	 13.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	672	 1	 -2.4	 2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	674	 1	 313.1	 32.8	 0.0	 0.0	 1	    1.04400	    0.00000	 225.0	 1	    1.08801	    1.00000;
	675	 1	 209.1	 31.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	676	 1	 118.1	 35.5	 0.0	 0.0	 1	    1.01148	    0.00000	 225.0	 1	    1.08963	    0.93333;
	677	 1	 248.2	 52.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	678	 1	 77.6	 15.9	 0.0	 10.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	681	 1	 40.6	 5.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2704	 1	 45.1	 9.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	682	 1	 40.3	 13.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	683	 1	 68.7	 13.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	684	 1	 135.2	 -0.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	685	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	687	 1	 44.6	 18.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	688	 1	 36.7	 -1.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	690	 1	 48.5	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	691	 1	 70.1	 5.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	692	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	693	 1	 39.1	 21.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	694	 1	 50.5	 27.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2705	 1	 -9.7	 -5.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	695	 1	 84.7	 37.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	696	 1	 -1.1	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	697	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01712	    0.00000	 63.0	 1	    1.06599	    0.96825;
	698	 1	 19.7	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2706	 1	 27.7	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	699	 1	 45.3	 8.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	700	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	702	 1	 7.2	 0.5	 0.0	 0.0	 1	    1.01089	    0.00000	 63.0	 1	    1.06349	    0.95830;
	703	 1	 41.8	 5.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	704	 1	 37.8	 3.8	 0.0	 0.0	 1	    1.00023	    0.00000	 63.0	 1	    1.06395	    0.93651;
	705	 1	 48.1	 -50.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	706	 1	 -0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	707	 1	 29.7	 16.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2707	 1	 20.3	 3.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	708	 1	 105.6	 26.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	709	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2708	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2709	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2710	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	714	 1	 11.1	 -4.1	 0.0	 0.0	 1	    1.00162	    0.00000	 63.0	 1	    1.08260	    0.92063;
	715	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	716	 1	 31.9	 7.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	717	 1	 87.4	 18.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	2714	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	719	 1	 -1.7	 -12.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	720	 1	 67.0	 4.1	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	721	 1	 56.3	 7.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	722	 1	 34.4	 7.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	724	 1	 54.9	 16.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	725	 1	 4.2	 10.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	726	 1	 56.7	 -6.5	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	728	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	730	 1	 120.8	 -13.6	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	731	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2715	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2716	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	732	 1	 22.9	 1.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	733	 1	 62.8	 57.7	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	734	 1	 293.7	 64.1	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	735	 1	 42.3	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	736	 1	 32.0	 -4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	738	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	741	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2718	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2719	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2720	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2721	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2724	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2725	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2726	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	745	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2727	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	747	 1	 151.9	 29.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	748	 1	 281.2	 54.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	749	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	751	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	752	 1	 22.4	 7.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2728	 1	 45.7	 10.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	753	 1	 33.8	 6.1	 0.0	 0.0	 1	    1.00782	    0.00000	 63.0	 1	    1.09501	    0.92063;
	754	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	755	 1	 20.0	 25.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	756	 1	 9.2	 35.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2729	 1	 -9.7	 -36.1	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	757	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04614	    0.00000	 225.0	 1	    1.09227	    1.00000;
	758	 1	 12.1	 -13.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	759	 1	 31.5	 5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	760	 1	 39.9	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	762	 1	 37.2	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04478	    0.00000	 225.0	 1	    1.08955	    1.00000;
	764	 1	 0.1	 2.0	 0.0	 0.0	 1	    1.00667	    0.00000	 63.0	 1	    1.09271	    0.92063;
	765	 1	 36.1	 3.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01646	    0.00000	 150.0	 1	    1.13291	    0.90000;
	767	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	768	 1	 187.7	 37.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	771	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	772	 1	 15.0	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2730	 1	 14.1	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2731	 1	 15.0	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	773	 1	 16.6	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2734	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	775	 1	 -22.1	 -19.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	776	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00313	    0.00000	 63.0	 1	    1.06976	    0.93651;
	777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	778	 1	 90.0	 8.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	779	 1	 83.3	 -6.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2738	 1	 65.4	 -0.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	782	 1	 17.6	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	785	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	787	 1	 42.0	 8.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	788	 1	 79.0	 22.2	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	2739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	789	 1	 111.3	 14.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	790	 1	 174.1	 35.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	791	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	792	 1	 146.8	 0.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	793	 1	 2.1	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	795	 1	 1.7	 -1.0	 0.0	 0.0	 1	    1.01493	    0.00000	 63.0	 1	    1.06349	    0.96637;
	796	 1	 153.5	 0.9	 0.0	 0.0	 1	    1.04573	    0.00000	 225.0	 1	    1.09146	    1.00000;
	797	 1	 51.3	 5.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2740	 1	 50.6	 3.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2741	 1	 53.2	 5.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	799	 1	 107.8	 29.2	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	800	 1	 25.3	 10.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	801	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	802	 1	 404.6	 121.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2742	 1	 22.8	 9.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	803	 1	 47.8	 -44.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	804	 1	 -2.4	 3.5	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2743	 1	 12.9	 9.1	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	805	 1	 47.1	 5.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	806	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	808	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	809	 1	 11.2	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	810	 1	 77.2	 11.8	 0.0	 0.0	 1	    1.04496	    0.00000	 225.0	 1	    1.08992	    1.00000;
	811	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	812	 1	 160.9	 15.7	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	813	 1	 7.7	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2744	 1	 8.6	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2745	 1	 10.2	 -0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	814	 1	 63.0	 35.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2746	 1	 62.2	 54.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	815	 1	 90.6	 24.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	816	 1	 31.2	 7.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2747	 1	 57.9	 12.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	818	 1	 51.4	 0.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	819	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	820	 1	 15.7	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	821	 1	 3.4	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2964	 1	 10.4	 1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	824	 1	 22.5	 -2.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2748	 1	 -2.7	 2.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	825	 1	 9.0	 4.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	826	 1	 2.9	 2.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	827	 1	 120.4	 11.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	828	 1	 72.0	 11.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2749	 1	 87.3	 33.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	830	 1	 81.6	 13.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	831	 1	 32.6	 19.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	832	 1	 48.9	 16.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	833	 1	 107.3	 12.9	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	834	 1	 -1.2	 5.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	835	 1	 0.0	 -0.7	 0.0	 0.0	 1	    0.90000	    0.00000	 150.0	 1	    1.00000	    0.80000;
	836	 1	 49.4	 -15.0	 0.0	 0.0	 1	    1.04678	    0.00000	 225.0	 1	    1.09355	    1.00000;
	837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	838	 2	 -1.6	 -9.2	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04817	    0.00000	 225.0	 1	    1.09634	    1.00000;
	840	 1	 33.8	 14.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	842	 1	 97.5	 10.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	843	 1	 67.1	 11.0	 0.0	 0.0	 1	    1.04510	    0.00000	 225.0	 1	    1.09020	    1.00000;
	2750	 1	 59.8	 14.9	 0.0	 0.0	 1	    1.04510	    0.00000	 225.0	 1	    1.09020	    1.00000;
	844	 1	 10.0	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	845	 1	 150.0	 13.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	846	 1	 -0.0	 -0.0	 0.0	 0.0	 1	    1.04016	    0.00000	 225.0	 1	    1.09366	    0.98667;
	847	 1	 55.3	 9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	848	 1	 198.7	 34.7	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2751	 1	 -30.2	 -13.4	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	851	 1	 40.1	 15.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	852	 1	 6.6	 3.5	 0.0	 0.0	 1	    1.01163	    0.00000	 63.0	 1	    1.06349	    0.95976;
	853	 1	 0.0	 0.0	 0.0	 15.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	855	 1	 44.2	 12.9	 0.0	 0.0	 1	    1.00276	    0.00000	 63.0	 1	    1.06902	    0.93651;
	856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	857	 1	 85.0	 20.0	 0.0	 0.0	 1	    1.01162	    0.00000	 225.0	 1	    1.08990	    0.93333;
	858	 1	 15.9	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	859	 1	 79.8	 17.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01409	    0.00000	 63.0	 1	    1.06349	    0.96470;
	861	 1	 21.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	862	 1	 23.5	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	863	 1	 60.5	 5.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	864	 1	 186.8	 -8.7	 0.0	 0.0	 1	    1.04458	    0.00000	 225.0	 1	    1.08916	    1.00000;
	865	 1	 64.2	 18.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	866	 1	 27.7	 -0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	867	 1	 8.5	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	868	 1	 51.8	 8.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	869	 1	 46.4	 13.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2752	 1	 39.7	 12.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	870	 1	 62.9	 12.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	872	 1	 6.6	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2753	 1	 6.7	 -4.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	873	 1	 15.8	 5.0	 0.0	 0.0	 1	    1.01948	    0.00000	 63.0	 1	    1.07070	    0.96825;
	2754	 1	 22.5	 7.8	 0.0	 0.0	 1	    1.01948	    0.00000	 63.0	 1	    1.07070	    0.96825;
	874	 1	 -1.7	 3.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	876	 2	 5.8	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	877	 2	 2.5	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	878	 1	 12.0	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2755	 1	 14.0	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	879	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	881	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2756	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	882	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00344	    0.00000	 150.0	 1	    1.10687	    0.90000;
	883	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2757	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2758	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2759	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2760	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2761	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	884	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	885	 1	 80.8	 12.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	886	 1	 4.7	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	887	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	888	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	889	 1	 8.5	 5.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2767	 1	 10.4	 5.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	890	 1	 16.3	 3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	891	 1	 26.2	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	892	 1	 -0.8	 -3.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2768	 1	 3.3	 2.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	894	 1	 82.5	 6.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2769	 1	 90.7	 19.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	895	 1	 42.9	 7.4	 0.0	 0.0	 1	    1.03958	    0.00000	 225.0	 1	    1.09250	    0.98667;
	896	 1	 302.7	 77.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	897	 1	 107.9	 24.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2770	 1	 44.1	 11.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	898	 1	 10.2	 -4.1	 0.0	 0.0	 1	    1.00132	    0.00000	 63.0	 1	    1.06614	    0.93651;
	899	 1	 4.1	 -8.5	 0.0	 0.0	 1	    1.00071	    0.00000	 63.0	 1	    1.06491	    0.93651;
	900	 1	 -1.9	 -33.6	 0.0	 0.0	 1	    1.00601	    0.00000	 150.0	 1	    1.11202	    0.90000;
	901	 1	 -25.2	 40.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	902	 1	 60.2	 13.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	904	 1	 316.7	 63.2	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	905	 1	 0.0	 -0.1	 0.0	 0.0	 1	    0.97515	    0.00000	 63.0	 1	    1.38737	    0.56294;
	906	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04623	    0.00000	 225.0	 1	    1.09246	    1.00000;
	909	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2771	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	910	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	911	 1	 36.0	 30.1	 0.0	 0.0	 1	    1.04515	    0.00000	 225.0	 1	    1.09030	    1.00000;
	912	 1	 246.3	 -25.3	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	913	 1	 26.7	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	914	 1	 45.8	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	915	 1	 10.5	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2772	 1	 9.3	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	916	 1	 -5.3	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	918	 1	 22.1	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	919	 1	 247.9	 -15.6	 0.0	 80.0	 1	    1.04556	    0.00000	 225.0	 1	    1.09111	    1.00000;
	920	 1	 25.1	 -4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	921	 1	 15.4	 -3.7	 0.0	 60.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	923	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	924	 1	 -3.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	925	 1	 0.2	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	926	 1	 149.6	 -4.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	927	 1	 89.2	 55.1	 0.0	 0.0	 1	    1.04731	    0.00000	 225.0	 1	    1.09463	    1.00000;
	928	 1	 148.8	 28.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	930	 1	 18.7	 10.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2773	 1	 17.0	 6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	931	 1	 -0.0	 -0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	932	 1	 60.6	 2.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2774	 1	 0.2	 1.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2775	 1	 17.7	 5.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00672	    0.00000	 63.0	 1	    1.09281	    0.92063;
	934	 1	 40.6	 2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	935	 1	 76.0	 12.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	936	 1	 20.5	 11.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	937	 1	 45.2	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00622	    0.00000	 63.0	 1	    1.07594	    0.93651;
	939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	940	 1	 11.7	 -3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	941	 1	 -0.2	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	942	 1	 20.7	 3.1	 0.0	 0.0	 1	    1.01609	    0.00000	 63.0	 1	    1.06392	    0.96825;
	943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	944	 1	 29.5	 1.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	945	 1	 3.3	 0.0	 0.0	 0.0	 1	    1.00160	    0.00000	 63.0	 1	    1.06670	    0.93651;
	946	 2	 4.2	 8.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	947	 1	 155.3	 15.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	948	 1	 15.8	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	949	 1	 216.8	 57.0	 0.0	 0.0	 1	    1.03829	    0.00000	 225.0	 1	    1.08992	    0.98667;
	950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	951	 1	 184.1	 7.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	952	 1	 65.8	 16.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	953	 1	 -1.5	 -9.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	954	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	955	 1	 26.3	 18.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	956	 1	 157.6	 28.6	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	958	 1	 34.8	 3.5	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	959	 1	 208.3	 -43.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	960	 1	 8.6	 1.7	 0.0	 0.0	 1	    1.00140	    0.00000	 63.0	 1	    1.06629	    0.93651;
	961	 1	 133.8	 23.4	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2776	 1	 133.3	 17.7	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	962	 1	 21.1	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	963	 2	 15.7	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	964	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	965	 1	 64.8	 11.6	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	966	 1	 151.1	 48.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	967	 1	 -9.4	 -15.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	968	 2	 -5.1	 -3.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	969	 1	 -1.2	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00421	    0.00000	 150.0	 1	    1.10841	    0.90000;
	971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	972	 1	 51.3	 5.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	973	 1	 11.0	 -0.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	974	 1	 23.7	 6.0	 0.0	 0.0	 1	    1.01474	    0.00000	 63.0	 1	    1.06349	    0.96600;
	975	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	976	 2	 -0.8	 9.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	978	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2777	 2	 2.8	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	979	 1	 -1.7	 -0.6	 0.0	 0.0	 1	    1.02100	    0.00000	 150.0	 1	    1.14200	    0.90000;
	980	 1	 41.5	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	981	 1	 159.2	 40.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	982	 1	 15.0	 6.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	984	 1	 0.2	 1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	985	 1	 99.8	 30.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	986	 1	 75.5	 -3.4	 0.0	 0.0	 1	    1.03824	    0.00000	 225.0	 1	    1.08981	    0.98667;
	987	 1	 114.7	 28.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	988	 1	 5.5	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2778	 1	 5.7	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	989	 1	 0.2	 -0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	990	 1	 38.2	 -4.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	991	 1	 88.0	 50.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	992	 1	 19.8	 1.8	 0.0	 0.0	 1	    1.00449	    0.00000	 63.0	 1	    1.07247	    0.93651;
	2779	 1	 93.2	 25.0	 0.0	 0.0	 1	    1.00449	    0.00000	 63.0	 1	    1.07247	    0.93651;
	993	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	994	 1	 7.2	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	995	 1	 27.3	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03592	    0.00000	 225.0	 1	    1.09407	    0.97778;
	998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03838	    0.00000	 225.0	 1	    1.09009	    0.98667;
	999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1000	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1002	 1	 140.3	 -0.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1004	 1	 -0.3	 3.8	 0.0	 0.0	 1	    1.00063	    0.00000	 63.0	 1	    1.06475	    0.93651;
	1005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1006	 1	 16.8	 4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04605	    0.00000	 225.0	 1	    1.09211	    1.00000;
	1008	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00264	    0.00000	 63.0	 1	    1.06877	    0.93651;
	1009	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01270	    0.00000	 225.0	 1	    1.09206	    0.93333;
	1010	 1	 44.0	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1013	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1014	 1	 69.3	 0.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1015	 1	 290.7	 36.4	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1016	 1	 36.9	 4.2	 0.0	 0.0	 1	    1.00018	    0.00000	 63.0	 1	    1.06386	    0.93651;
	1017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1018	 1	 33.4	 -3.2	 0.0	 0.0	 1	    1.03856	    0.00000	 225.0	 1	    1.09046	    0.98667;
	1019	 1	 161.5	 8.8	 0.0	 0.0	 1	    1.04829	    0.00000	 225.0	 1	    1.09659	    1.00000;
	1020	 1	 162.0	 51.1	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1023	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1024	 1	 158.8	 -26.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1025	 1	 2.8	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1026	 1	 102.1	 11.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2781	 1	 115.4	 16.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1027	 1	 0.7	 0.8	 0.0	 80.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	1028	 1	 128.8	 27.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1029	 1	 15.8	 8.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1030	 1	 3.9	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	2782	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 45.0	 1	    1.06667	    0.93333;
	1031	 1	 82.2	 23.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1032	 1	 122.3	 -23.5	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1033	 1	 24.5	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1034	 1	 152.5	 78.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1035	 1	 8.3	 -0.5	 0.0	 0.0	 1	    1.00655	    0.00000	 63.0	 1	    1.09247	    0.92063;
	1036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03963	    0.00000	 225.0	 1	    1.09260	    0.98667;
	2783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03963	    0.00000	 225.0	 1	    1.09260	    0.98667;
	1037	 1	 30.9	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1038	 1	 85.9	 15.5	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00276	    0.00000	 63.0	 1	    1.06902	    0.93651;
	1040	 1	 21.3	 4.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1041	 1	 5.3	 -2.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1043	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99058	    0.00000	 225.0	 1	    1.09227	    0.88889;
	1044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1045	 1	 24.2	 6.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1046	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1047	 1	 19.4	 -1.8	 0.0	 0.0	 1	    1.00054	    0.00000	 63.0	 1	    1.06457	    0.93651;
	1048	 1	 48.0	 5.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1051	 1	 44.1	 8.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2784	 1	 42.8	 16.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1052	 1	 -15.5	 -11.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04585	    0.00000	 225.0	 1	    1.09171	    1.00000;
	1054	 1	 0.8	 0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2949	 1	 1.2	 0.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1055	 1	 118.3	 63.2	 0.0	 80.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1056	 1	 22.1	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1057	 1	 3.1	 2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1058	 1	 12.8	 10.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1059	 1	 23.2	 -3.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1060	 1	 39.0	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1061	 1	 23.5	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1062	 1	 0.1	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1063	 1	 18.1	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1064	 1	 62.7	 9.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1068	 1	 42.7	 15.4	 0.0	 0.0	 1	    1.00186	    0.00000	 63.0	 1	    1.06721	    0.93651;
	1069	 2	 1.0	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00468	    0.00000	 150.0	 1	    1.10936	    0.90000;
	1071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04802	    0.00000	 225.0	 1	    1.09604	    1.00000;
	1072	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00445	    0.00000	 150.0	 1	    1.10890	    0.90000;
	1073	 1	 38.1	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1075	 1	 57.1	 11.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2785	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1078	 1	 1.0	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1079	 1	 35.9	 -0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1081	 1	 36.8	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1082	 1	 43.6	 -10.9	 0.0	 0.0	 1	    1.02994	    0.00000	 63.0	 1	    1.13924	    0.92063;
	1083	 1	 68.1	 11.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2787	 1	 67.8	 5.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1084	 1	 61.9	 14.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1085	 1	 10.1	 4.5	 0.0	 0.0	 1	    1.00236	    0.00000	 63.0	 1	    1.06822	    0.93651;
	2788	 1	 20.8	 -2.3	 0.0	 0.0	 1	    1.00236	    0.00000	 63.0	 1	    1.06822	    0.93651;
	1086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1087	 1	 9.0	 2.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1088	 1	 12.5	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2789	 1	 13.0	 5.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1089	 1	 8.3	 11.6	 0.0	 0.0	 1	    1.04602	    0.00000	 225.0	 1	    1.09203	    1.00000;
	1090	 1	 116.8	 9.8	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1091	 1	 85.5	 28.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2790	 1	 85.1	 35.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1092	 1	 16.2	 -5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1093	 1	 0.9	 -0.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1094	 1	 7.3	 2.0	 0.0	 0.0	 1	    1.00482	    0.00000	 150.0	 1	    1.10964	    0.90000;
	1095	 1	 24.0	 6.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2791	 1	 11.1	 -2.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2792	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1099	 1	 142.4	 8.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1100	 1	 29.5	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1101	 1	 123.9	 32.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1102	 1	 -2.4	 8.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2795	 1	 7.9	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2796	 1	 62.3	 21.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1107	 1	 47.7	 27.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1108	 1	 37.6	 -6.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1109	 1	 394.0	 28.2	 0.0	 0.0	 1	    1.04827	    0.00000	 225.0	 1	    1.09655	    1.00000;
	1110	 1	 43.3	 1.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1111	 1	 140.6	 16.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1112	 1	 101.4	 16.9	 0.0	 0.0	 1	    1.03861	    0.00000	 225.0	 1	    1.09056	    0.98667;
	1113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1114	 1	 55.2	 6.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1115	 1	 127.2	 25.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1116	 1	 20.6	 4.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1119	 1	 46.4	 8.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2797	 1	 45.0	 8.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1121	 1	 23.0	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1122	 1	 23.2	 -3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1123	 1	 5.6	 8.8	 0.0	 0.0	 1	    1.04769	    0.00000	 225.0	 1	    1.09538	    1.00000;
	1124	 1	 17.8	 -11.7	 0.0	 0.0	 1	    1.00039	    0.00000	 63.0	 1	    1.06428	    0.93651;
	1125	 1	 46.6	 1.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1126	 1	 10.0	 4.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1127	 1	 62.9	 9.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2798	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05415	    0.00000	 380.0	 1	    1.10830	    1.00000;
	1130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05420	    0.00000	 380.0	 1	    1.10840	    1.00000;
	2799	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05420	    0.00000	 380.0	 1	    1.10840	    1.00000;
	1131	 1	 152.8	 -7.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1132	 1	 43.7	 2.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2800	 1	 54.1	 1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1133	 1	 9.0	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1134	 1	 81.6	 14.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1135	 1	 0.4	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1137	 1	 1.7	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1138	 1	 98.0	 22.4	 0.0	 0.0	 1	    1.04089	    0.00000	 225.0	 1	    1.09512	    0.98667;
	1139	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1140	 1	 80.5	 14.5	 0.0	 30.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1142	 1	 3.3	 5.0	 0.0	 0.0	 1	    1.00102	    0.00000	 63.0	 1	    1.06554	    0.93651;
	1143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1144	 1	 0.7	 -1.4	 0.0	 0.0	 1	    0.94550	    0.00000	 45.0	 1	    1.00212	    0.88889;
	1145	 1	 64.5	 4.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1146	 1	 75.6	 21.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1148	 2	 4.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2801	 1	 8.3	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1149	 1	 69.5	 4.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1150	 1	 -0.7	 -0.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1151	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2802	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2803	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1153	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00165	    0.00000	 63.0	 1	    1.06680	    0.93651;
	1154	 1	 1.9	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1155	 1	 80.3	 17.7	 0.0	 19.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1157	 1	 20.0	 -0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1158	 1	 150.5	 19.3	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1159	 1	 41.0	 -3.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2806	 1	 61.9	 13.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1160	 1	 25.8	 11.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02129	    0.00000	 63.0	 1	    1.07432	    0.96825;
	1162	 1	 4.8	 0.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1163	 1	 145.6	 54.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2982	 1	 22.1	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1165	 1	 0.6	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04412	    0.00000	 380.0	 1	    1.10263	    0.98561;
	1168	 1	 -2.2	 -33.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2807	 1	 1.7	 1.5	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1169	 1	 32.5	 3.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1170	 1	 31.1	 3.6	 0.0	 0.0	 1	    1.00308	    0.00000	 63.0	 1	    1.06965	    0.93651;
	1171	 1	 134.0	 30.5	 0.0	 -80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1172	 1	 133.1	 -24.3	 0.0	 0.0	 1	    1.05204	    0.00000	 225.0	 1	    1.10407	    1.00000;
	1173	 1	 41.5	 6.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2808	 1	 49.1	 13.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1174	 1	 0.8	 -1.7	 0.0	 0.0	 1	    1.00086	    0.00000	 63.0	 1	    1.06522	    0.93651;
	1175	 1	 147.4	 36.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1176	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1178	 1	 0.0	 0.0	 0.0	 78.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1180	 1	 9.7	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1181	 1	 8.7	 0.7	 0.0	 0.0	 1	    1.00270	    0.00000	 63.0	 1	    1.06889	    0.93651;
	1182	 1	 4.4	 3.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2809	 1	 4.1	 2.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1183	 1	 34.4	 34.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1184	 1	 37.1	 3.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1185	 1	 108.7	 19.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1186	 1	 97.2	 28.7	 0.0	 0.0	 1	    0.99556	    0.00000	 225.0	 1	    1.08889	    0.90222;
	1187	 1	 27.3	 16.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2811	 1	 -0.3	 7.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1188	 2	 12.3	 0.0	 0.0	 0.0	 1	    1.00463	    0.00000	 150.0	 1	    1.10927	    0.90000;
	1189	 1	 109.1	 29.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1190	 1	 160.3	 53.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1191	 1	 16.6	 3.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1192	 1	 3.2	 -0.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1193	 1	 -67.4	 -40.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1194	 1	 38.1	 7.0	 0.0	 0.0	 1	    1.04512	    0.00000	 225.0	 1	    1.09024	    1.00000;
	2812	 1	 47.8	 10.8	 0.0	 0.0	 1	    1.04512	    0.00000	 225.0	 1	    1.09024	    1.00000;
	2813	 1	 40.7	 7.6	 0.0	 0.0	 1	    1.04512	    0.00000	 225.0	 1	    1.09024	    1.00000;
	1195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1196	 1	 -11.0	 14.1	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1197	 1	 28.8	 41.3	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1198	 1	 26.1	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1199	 1	 8.3	 -3.7	 0.0	 0.0	 1	    1.00361	    0.00000	 63.0	 1	    1.07072	    0.93651;
	1200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1202	 1	 199.2	 12.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1204	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00031	    0.00000	 150.0	 1	    1.10062	    0.90000;
	1205	 1	 15.4	 4.6	 0.0	 0.0	 1	    1.04510	    0.00000	 225.0	 1	    1.09020	    1.00000;
	1206	 1	 139.3	 24.5	 0.0	 0.0	 1	    1.00222	    0.00000	 225.0	 1	    1.08889	    0.91556;
	1207	 1	 62.8	 11.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1208	 1	 124.7	 17.6	 0.0	 0.0	 1	    1.04582	    0.00000	 225.0	 1	    1.09164	    1.00000;
	1209	 1	 18.2	 13.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1210	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1211	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1212	 1	 3.0	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1213	 1	 49.8	 10.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04159	    0.00000	 225.0	 1	    1.09652	    0.98667;
	1215	 1	 0.2	 1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1216	 1	 94.5	 24.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1217	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02261	    0.00000	 63.0	 1	    1.07697	    0.96825;
	1218	 1	 14.7	 3.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1219	 1	 267.4	 72.3	 0.0	 0.0	 1	    1.03864	    0.00000	 225.0	 1	    1.09062	    0.98667;
	1220	 1	 2.3	 -2.8	 0.0	 0.0	 1	    1.00221	    0.00000	 63.0	 1	    1.06792	    0.93651;
	1221	 1	 -0.7	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1222	 1	 28.0	 13.9	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.11579	    1.00000;
	2815	 1	 0.4	 111.8	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.11579	    1.00000;
	2816	 1	 0.0	 2.6	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.11579	    1.00000;
	2817	 1	 28.4	 35.2	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.11579	    1.00000;
	1223	 1	 -0.5	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2818	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1225	 1	 0.3	 -1.0	 0.0	 0.0	 1	    1.04406	    0.00000	 225.0	 1	    1.08812	    1.00000;
	2819	 1	 5.4	 -1.4	 0.0	 0.0	 1	    1.04406	    0.00000	 225.0	 1	    1.08812	    1.00000;
	1226	 1	 20.8	 4.8	 0.0	 0.0	 1	    1.00233	    0.00000	 63.0	 1	    1.06816	    0.93651;
	2820	 1	 55.3	 0.5	 0.0	 0.0	 1	    1.00233	    0.00000	 63.0	 1	    1.06816	    0.93651;
	1227	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1228	 1	 83.2	 27.2	 0.0	 0.0	 1	    1.04403	    0.00000	 225.0	 1	    1.08889	    0.99918;
	1229	 1	 3.5	 2.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1230	 1	 110.8	 26.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1231	 1	 8.6	 3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1232	 1	 112.3	 16.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1233	 1	 67.4	 0.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1234	 1	 31.5	 7.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1235	 1	 8.5	 2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1236	 1	 45.2	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1238	 1	 0.0	 -4.4	 0.0	 0.0	 1	    1.03951	    0.00000	 225.0	 1	    1.09236	    0.98667;
	1239	 1	 27.3	 0.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1240	 1	 167.5	 11.4	 0.0	 0.0	 1	    1.05307	    0.00000	 380.0	 1	    1.10614	    1.00000;
	1241	 1	 -14.2	 10.0	 0.0	 0.0	 1	    1.05351	    0.00000	 380.0	 1	    1.10702	    1.00000;
	2821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05351	    0.00000	 380.0	 1	    1.10702	    1.00000;
	1242	 1	 -1.6	 -1.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1243	 1	 2.3	 1.1	 0.0	 0.0	 1	    1.00112	    0.00000	 63.0	 1	    1.06574	    0.93651;
	1244	 1	 122.5	 25.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1245	 1	 0.0	 -0.9	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1246	 1	 42.2	 2.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1248	 1	 37.2	 7.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1249	 1	 71.1	 23.3	 0.0	 0.0	 1	    1.02445	    0.00000	 225.0	 1	    1.08889	    0.96000;
	1250	 1	 37.4	 3.7	 0.0	 0.0	 1	    1.01543	    0.00000	 63.0	 1	    1.06349	    0.96736;
	1251	 1	 300.1	 92.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1252	 1	 17.7	 -0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1253	 1	 96.3	 13.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1254	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00129	    0.00000	 63.0	 1	    1.06607	    0.93651;
	1255	 1	 33.0	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1256	 1	 1.7	 3.5	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1257	 1	 3.5	 0.6	 0.0	 0.0	 1	    1.00244	    0.00000	 63.0	 1	    1.06837	    0.93651;
	1258	 1	 14.4	 1.9	 0.0	 0.0	 1	    1.01947	    0.00000	 63.0	 1	    1.07068	    0.96825;
	1259	 1	 1.8	 10.5	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1260	 1	 0.6	 -1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1261	 2	 -6.2	 -1.0	 0.0	 0.0	 1	    1.00044	    0.00000	 63.0	 1	    1.08024	    0.92063;
	1262	 1	 24.5	 4.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1263	 2	 42.7	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04518	    0.00000	 225.0	 1	    1.09036	    1.00000;
	1265	 1	 -2.8	 -7.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1266	 1	 51.3	 5.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1267	 1	 141.2	 18.2	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1268	 1	 70.7	 9.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1269	 1	 45.7	 -8.3	 0.0	 0.0	 1	    0.95000	    0.00000	 150.0	 1	    1.10000	    0.80000;
	1270	 1	 52.8	 10.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04412	    0.00000	 380.0	 1	    1.10263	    0.98560;
	1273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2824	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1274	 1	 321.5	 49.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1275	 1	 -0.4	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1276	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02107	    0.00000	 150.0	 1	    1.14214	    0.90000;
	1277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1278	 1	 -0.3	 -0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1279	 2	 -15.7	 -3.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1280	 1	 6.2	 -0.8	 0.0	 0.0	 1	    1.00169	    0.00000	 63.0	 1	    1.06688	    0.93651;
	1281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1282	 1	 43.7	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1283	 1	 219.4	 32.1	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2826	 1	 214.5	 37.7	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1284	 1	 123.5	 19.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1285	 1	 154.6	 46.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1286	 1	 105.0	 20.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1288	 1	 37.5	 4.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2827	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1290	 1	 4.9	 2.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1291	 1	 89.5	 36.5	 0.0	 80.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	1292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1293	 1	 39.3	 21.5	 0.0	 0.0	 1	    1.03791	    0.00000	 225.0	 1	    1.08915	    0.98667;
	1294	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1295	 1	 210.0	 64.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1296	 1	 -0.3	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1297	 1	 25.4	 4.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1298	 1	 242.0	 23.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1299	 1	 105.7	 17.0	 0.0	 0.0	 1	    1.04041	    0.00000	 225.0	 1	    1.09415	    0.98667;
	1300	 1	 75.3	 11.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2828	 1	 74.4	 26.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1301	 1	 178.6	 76.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1302	 1	 24.9	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1303	 1	 75.2	 12.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1304	 1	 84.0	 30.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1305	 1	 9.2	 9.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2829	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1307	 1	 45.0	 8.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1308	 1	 3.4	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1309	 1	 1.0	 1.7	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	1310	 1	 -0.7	 14.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1312	 1	 24.4	 4.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03899	    0.00000	 225.0	 1	    1.08444	    0.99353;
	1314	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00570	    0.00000	 150.0	 1	    1.11139	    0.90000;
	1315	 1	 28.3	 -1.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1316	 1	 80.0	 3.5	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1317	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00057	    0.00000	 63.0	 1	    1.06463	    0.93651;
	1318	 1	 -4.9	 -1.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1320	 1	 65.2	 12.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1321	 1	 15.1	 2.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1323	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2831	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2832	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1325	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1326	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1327	 1	 26.0	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1331	 1	 16.8	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2833	 1	 17.8	 3.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1332	 1	 186.2	 43.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1334	 1	 60.9	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1335	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00381	    0.00000	 63.0	 1	    1.07111	    0.93651;
	1336	 1	 57.8	 2.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1337	 1	 8.6	 3.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1338	 1	 39.5	 11.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1339	 1	 -2.7	 -29.1	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1340	 1	 142.3	 119.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1341	 1	 10.4	 -1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1342	 1	 10.3	 -9.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1343	 1	 16.1	 22.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1344	 1	 48.0	 12.1	 0.0	 0.0	 1	    1.03975	    0.00000	 225.0	 1	    1.09283	    0.98667;
	1345	 1	 158.6	 44.1	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2960	 1	 174.0	 50.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1346	 2	 0.0	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1347	 1	 14.8	 2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1348	 1	 110.5	 5.3	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	1349	 1	 29.2	 9.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1350	 1	 201.3	 45.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1351	 1	 376.5	 51.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1352	 1	 19.1	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1353	 1	 29.3	 -2.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1354	 2	 13.4	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1355	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1356	 1	 13.4	 3.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1357	 1	 0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1358	 1	 79.3	 38.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1359	 1	 -2.7	 -2.1	 0.0	 0.0	 1	    1.03874	    0.00000	 225.0	 1	    1.09081	    0.98667;
	1360	 1	 12.2	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04359	    0.00000	 225.0	 1	    1.08718	    1.00000;
	1363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1364	 1	 99.1	 17.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1365	 1	 29.9	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1366	 1	 77.1	 0.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03507	    0.00000	 63.0	 1	    1.10699	    0.96315;
	1368	 1	 99.4	 17.5	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2834	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1370	 1	 3.1	 9.5	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01814	    0.00000	 150.0	 1	    1.13628	    0.90000;
	1372	 1	 -4.1	 -10.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1373	 1	 165.3	 -5.9	 0.0	 0.0	 1	    1.04561	    0.00000	 225.0	 1	    1.09121	    1.00000;
	1374	 1	 262.7	 3.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2836	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1375	 1	 52.4	 7.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1377	 1	 76.6	 18.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1378	 1	 13.6	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1382	 1	 33.2	 2.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1383	 1	 44.0	 16.7	 0.0	 0.0	 1	    0.98979	    0.00000	 225.0	 1	    1.09069	    0.88889;
	1384	 1	 230.8	 102.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1385	 1	 31.9	 -0.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1386	 1	 2.4	 3.3	 0.0	 0.0	 1	    1.04107	    0.00000	 225.0	 1	    1.09547	    0.98667;
	1387	 1	 249.0	 64.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1388	 1	 29.9	 -10.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2837	 1	 26.6	 9.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2838	 1	 59.4	 31.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1389	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1390	 1	 6.7	 3.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1391	 1	 -3.1	 9.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1393	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2843	 1	 24.7	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1394	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1395	 1	 25.8	 4.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1396	 1	 10.7	 -3.3	 0.0	 0.0	 1	    1.00305	    0.00000	 63.0	 1	    1.08546	    0.92063;
	1397	 1	 -1.9	 -3.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1398	 1	 41.3	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1399	 1	 -1.0	 5.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2845	 1	 41.6	 10.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2846	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2847	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1401	 1	 120.4	 -5.3	 0.0	 0.0	 1	    1.04100	    0.00000	 225.0	 1	    1.09534	    0.98667;
	1402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1403	 1	 43.9	 12.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1404	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1405	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2849	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2850	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1406	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2852	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1407	 1	 44.9	 5.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1408	 1	 47.9	 13.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2853	 1	 30.1	 5.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1409	 1	 46.0	 5.2	 0.0	 0.0	 1	    1.04174	    0.00000	 225.0	 1	    1.09682	    0.98667;
	1410	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1411	 1	 35.2	 -7.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1412	 1	 45.0	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1413	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1414	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1415	 1	 113.7	 13.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1416	 1	 23.4	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1417	 1	 81.9	 8.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1418	 1	 39.5	 8.4	 0.0	 0.0	 1	    1.00512	    0.00000	 63.0	 1	    1.07374	    0.93651;
	2854	 1	 16.3	 7.4	 0.0	 0.0	 1	    1.00512	    0.00000	 63.0	 1	    1.07374	    0.93651;
	1419	 1	 49.4	 4.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1420	 1	 46.5	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1421	 1	 42.7	 3.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2855	 1	 53.9	 8.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1422	 1	 35.6	 14.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1423	 1	 34.0	 -7.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1424	 1	 11.4	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1425	 1	 27.1	 0.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1426	 1	 3.5	 4.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1429	 1	 54.6	 0.2	 0.0	 0.0	 1	    1.03821	    0.00000	 225.0	 1	    1.08975	    0.98667;
	1431	 1	 49.4	 10.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2856	 1	 122.7	 15.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1432	 1	 -0.5	 1.3	 0.0	 0.0	 1	    1.01652	    0.00000	 63.0	 1	    1.06478	    0.96825;
	1433	 1	 50.8	 4.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1434	 1	 165.0	 -7.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1435	 1	 3.0	 -0.6	 0.0	 0.0	 1	    1.00078	    0.00000	 63.0	 1	    1.06505	    0.93651;
	1436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1438	 1	 6.8	 10.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1439	 1	 -1.3	 10.1	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1440	 1	 -5.8	 -1.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1441	 1	 4.6	 -4.1	 0.0	 0.0	 1	    1.02046	    0.00000	 63.0	 1	    1.07266	    0.96825;
	1442	 1	 49.2	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1443	 1	 217.0	 45.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1444	 1	 32.9	 9.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2858	 1	 50.3	 9.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1445	 1	 101.7	 3.4	 0.0	 0.0	 1	    1.02667	    0.00000	 225.0	 1	    1.08889	    0.96444;
	1446	 1	 39.6	 -11.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1447	 2	 -2.8	 -2.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1451	 1	 61.2	 7.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2859	 1	 67.2	 1.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1453	 1	 13.6	 1.8	 0.0	 0.0	 1	    1.00649	    0.00000	 63.0	 1	    1.09235	    0.92063;
	1454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04590	    0.00000	 225.0	 1	    1.09179	    1.00000;
	1455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05323	    0.00000	 380.0	 1	    1.10646	    1.00000;
	1456	 1	 6.4	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1457	 1	 0.0	 0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1460	 1	 4.8	 2.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1461	 1	 37.2	 9.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2860	 1	 106.1	 42.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1462	 1	 15.9	 0.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1463	 1	 14.5	 2.1	 0.0	 0.0	 1	    1.04542	    0.00000	 225.0	 1	    1.09084	    1.00000;
	2861	 1	 23.0	 6.5	 0.0	 0.0	 1	    1.04542	    0.00000	 225.0	 1	    1.09084	    1.00000;
	1464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1465	 1	 93.3	 27.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1466	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2863	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1469	 1	 16.5	 1.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1470	 1	 -28.8	 -32.6	 0.0	 0.0	 1	    1.03985	    0.00000	 225.0	 1	    1.09304	    0.98667;
	1471	 1	 131.2	 20.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1472	 1	 60.1	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1473	 1	 20.0	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1474	 2	 14.3	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1475	 1	 21.1	 -0.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1476	 1	 6.3	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1478	 1	 -0.9	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2864	 1	 -3.1	 0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1480	 1	 9.4	 -0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1481	 1	 84.5	 10.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1482	 1	 14.0	 2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1483	 1	 220.5	 56.4	 0.0	 80.0	 1	    1.04345	    0.00000	 225.0	 1	    1.08889	    0.99802;
	1484	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00238	    0.00000	 63.0	 1	    1.06826	    0.93651;
	1485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1486	 1	 60.1	 10.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1487	 1	 81.6	 32.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04623	    0.00000	 225.0	 1	    1.09246	    1.00000;
	1489	 1	 15.6	 -13.2	 0.0	 0.0	 1	    1.03826	    0.00000	 225.0	 1	    1.08986	    0.98667;
	1490	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1491	 1	 113.2	 -13.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1492	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1493	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1494	 1	 19.5	 7.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1495	 1	 1.6	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1496	 1	 128.7	 48.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1497	 1	 47.9	 2.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1498	 1	 91.8	 17.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1499	 1	 9.8	 -0.1	 0.0	 0.0	 1	    0.94449	    0.00000	 45.0	 1	    1.00009	    0.88889;
	1500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1502	 1	 18.9	 3.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2865	 1	 47.6	 12.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1504	 1	 9.7	 -1.2	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	1505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1506	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01641	    0.00000	 63.0	 1	    1.06457	    0.96825;
	1507	 1	 9.8	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1508	 1	 6.8	 -0.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00386	    0.00000	 63.0	 1	    1.07121	    0.93651;
	1510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01313	    0.00000	 225.0	 1	    1.09292	    0.93333;
	1511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1514	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1517	 1	 0.0	 -0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1518	 1	 40.2	 14.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1519	 1	 79.0	 27.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1520	 1	 33.6	 -2.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1521	 1	 15.2	 9.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1523	 1	 32.5	 0.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2866	 1	 89.7	 24.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1527	 1	 2.4	 16.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1528	 1	 -0.5	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1529	 1	 -0.3	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1530	 1	 40.8	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1531	 1	 97.6	 13.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1532	 1	 55.7	 14.7	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1533	 1	 12.2	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1534	 1	 116.7	 34.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1535	 1	 32.6	 4.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1536	 2	 16.1	 -3.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2867	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1540	 1	 10.0	 -1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1541	 1	 5.3	 7.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1542	 1	 216.0	 36.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1543	 1	 14.2	 11.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1545	 1	 213.4	 37.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1546	 1	 0.6	 -1.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2868	 1	 -2.5	 -1.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1547	 1	 27.7	 12.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1548	 1	 25.4	 1.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1549	 1	 97.2	 12.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1550	 1	 39.3	 1.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1551	 1	 112.7	 -0.1	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	1552	 1	 5.8	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1553	 1	 85.3	 -18.7	 0.0	 0.0	 1	    1.04329	    0.00000	 225.0	 1	    1.08657	    1.00000;
	1554	 1	 1.6	 11.5	 0.0	 0.0	 1	    1.00348	    0.00000	 150.0	 1	    1.10695	    0.90000;
	1555	 1	 17.0	 -1.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1556	 1	 211.4	 14.4	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1557	 1	 16.9	 -0.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1558	 1	 -1.9	 -1.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2869	 1	 -1.9	 -1.5	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1559	 1	 65.8	 -1.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2870	 1	 88.9	 20.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00250	    0.00000	 63.0	 1	    1.06849	    0.93651;
	1561	 1	 8.3	 -1.3	 0.0	 0.0	 1	    1.00255	    0.00000	 63.0	 1	    1.06860	    0.93651;
	2871	 1	 10.2	 -1.3	 0.0	 0.0	 1	    1.00255	    0.00000	 63.0	 1	    1.06860	    0.93651;
	1562	 1	 38.4	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1563	 1	 149.1	 6.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2872	 1	 17.4	 4.0	 0.0	 80.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1564	 1	 -14.8	 10.8	 0.0	 0.0	 1	    1.01668	    0.00000	 63.0	 1	    1.06511	    0.96825;
	1565	 1	 10.9	 2.7	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1566	 1	 0.1	 -0.4	 0.0	 0.0	 1	    1.00021	    0.00000	 63.0	 1	    1.06391	    0.93651;
	1567	 1	 189.6	 14.6	 0.0	 0.0	 1	    1.04249	    0.00000	 225.0	 1	    1.09831	    0.98667;
	1568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05529	    0.00000	 380.0	 1	    1.11057	    1.00000;
	1569	 1	 11.3	 3.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1570	 1	 40.5	 12.9	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1571	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04307	    0.00000	 225.0	 1	    1.08614	    1.00000;
	1572	 1	 116.5	 26.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1573	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1574	 1	 41.6	 6.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2873	 1	 30.2	 7.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1575	 1	 75.3	 -29.0	 0.0	 0.0	 1	    1.04541	    0.00000	 225.0	 1	    1.09083	    1.00000;
	1576	 2	 15.9	 1.7	 0.0	 0.0	 1	    1.01216	    0.00000	 63.0	 1	    1.06349	    0.96084;
	1577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2874	 1	 20.2	 3.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1578	 1	 24.8	 3.0	 0.0	 40.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1579	 1	 45.9	 15.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01652	    0.00000	 63.0	 1	    1.06479	    0.96825;
	1581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1582	 1	 0.0	 0.0	 0.0	 20.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1584	 1	 34.1	 5.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1585	 1	 0.2	 0.4	 0.0	 0.0	 1	    1.01722	    0.00000	 63.0	 1	    1.06618	    0.96825;
	1586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00107	    0.00000	 63.0	 1	    1.06564	    0.93651;
	2875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00107	    0.00000	 63.0	 1	    1.06564	    0.93651;
	1588	 1	 15.7	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1589	 1	 -0.4	 0.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1592	 1	 16.4	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1593	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1594	 2	 6.0	 -2.4	 0.0	 0.0	 1	    1.02196	    0.00000	 63.0	 1	    1.07567	    0.96825;
	1595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1596	 1	 45.6	 5.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1597	 1	 14.7	 3.5	 0.0	 0.0	 1	    1.00018	    0.00000	 63.0	 1	    1.06385	    0.93651;
	1598	 1	 2.7	 -1.1	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1600	 1	 43.4	 7.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1602	 1	 102.2	 11.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1604	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04359	    0.00000	 225.0	 1	    1.08718	    1.00000;
	1606	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1607	 1	 5.2	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1608	 1	 49.8	 -1.3	 0.0	 0.0	 1	    1.04527	    0.00000	 225.0	 1	    1.09054	    1.00000;
	1609	 1	 -0.1	 -0.2	 0.0	 0.0	 1	    1.00121	    0.00000	 63.0	 1	    1.06591	    0.93651;
	1610	 1	 13.7	 -0.5	 0.0	 0.0	 1	    1.00084	    0.00000	 63.0	 1	    1.06517	    0.93651;
	1611	 1	 88.6	 7.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2878	 1	 114.2	 10.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1612	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1613	 1	 7.8	 -2.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1614	 2	 8.5	 -0.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1615	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1616	 1	 93.6	 26.0	 0.0	 0.0	 1	    1.04099	    0.00000	 225.0	 1	    1.09531	    0.98667;
	2952	 1	 127.5	 37.3	 0.0	 0.0	 1	    1.04099	    0.00000	 225.0	 1	    1.09531	    0.98667;
	1617	 1	 5.8	 1.3	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1618	 1	 20.1	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2879	 1	 31.9	 1.9	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2880	 1	 20.4	 3.7	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1619	 1	 158.4	 23.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1620	 1	 233.7	 90.4	 0.0	 0.0	 1	    1.03963	    0.00000	 225.0	 1	    1.09260	    0.98667;
	1621	 1	 20.4	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2881	 1	 21.5	 1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1622	 1	 59.9	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1624	 1	 9.5	 -5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1625	 1	 27.5	 -4.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1626	 1	 39.9	 2.6	 0.0	 0.0	 1	    1.01170	    0.00000	 63.0	 1	    1.06349	    0.95990;
	1627	 1	 30.9	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1628	 1	 1.4	 0.2	 0.0	 0.0	 1	    0.94449	    0.00000	 45.0	 1	    1.00009	    0.88889;
	1629	 1	 15.9	 7.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1630	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1631	 1	 104.9	 16.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2882	 1	 40.5	 4.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1632	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1633	 1	 110.3	 15.7	 0.0	 0.0	 1	    1.03956	    0.00000	 225.0	 1	    1.09245	    0.98667;
	1634	 1	 67.0	 13.2	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1636	 1	 127.5	 6.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1637	 1	 148.7	 25.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1638	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04602	    0.00000	 225.0	 1	    1.09205	    1.00000;
	1639	 1	 20.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1640	 1	 45.5	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1641	 1	 41.6	 2.1	 0.0	 0.0	 1	    1.01540	    0.00000	 63.0	 1	    1.06349	    0.96732;
	1643	 1	 -2.7	 -2.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1644	 1	 33.4	 10.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2883	 1	 26.7	 -2.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1645	 1	 136.5	 28.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1646	 1	 7.8	 -1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1647	 1	 10.8	 7.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1648	 1	 0.7	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1649	 1	 24.6	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1650	 1	 35.4	 5.7	 0.0	 0.0	 1	    1.00231	    0.00000	 63.0	 1	    1.06811	    0.93651;
	1651	 1	 60.2	 2.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1652	 1	 22.5	 11.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1653	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03000	    0.00000	 150.0	 1	    1.09333	    0.96667;
	1654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1655	 1	 31.5	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1656	 1	 37.2	 7.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1657	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1658	 1	 4.2	 -2.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2884	 1	 8.4	 -0.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1659	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1660	 1	 36.8	 5.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1661	 1	 201.8	 37.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1662	 1	 4.8	 2.7	 0.0	 0.0	 1	    1.00122	    0.00000	 63.0	 1	    1.06593	    0.93651;
	2885	 1	 -0.5	 -3.3	 0.0	 0.0	 1	    1.00122	    0.00000	 63.0	 1	    1.06593	    0.93651;
	1663	 1	 0.4	 -0.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1665	 1	 73.1	 -0.9	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	1666	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2887	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2888	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1667	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2890	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2891	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2892	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1668	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1669	 1	 1.7	 -6.4	 0.0	 0.0	 1	    1.03933	    0.00000	 225.0	 1	    1.09200	    0.98667;
	1670	 1	 4.3	 1.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1671	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01588	    0.00000	 63.0	 1	    1.07937	    0.95238;
	1672	 1	 33.6	 3.7	 0.0	 0.0	 1	    1.03456	    0.00000	 63.0	 1	    1.10709	    0.96203;
	2893	 1	 43.1	 7.1	 0.0	 0.0	 1	    1.03456	    0.00000	 63.0	 1	    1.10709	    0.96203;
	1673	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03678	    0.00000	 63.0	 1	    1.10530	    0.96825;
	2894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03678	    0.00000	 63.0	 1	    1.10530	    0.96825;
	1674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1678	 2	 61.8	 8.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1679	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00151	    0.00000	 63.0	 1	    1.06651	    0.93651;
	1681	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1682	 1	 94.2	 5.7	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.08889	    0.93778;
	1683	 1	 48.4	 9.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1684	 1	 5.7	 -8.1	 0.0	 0.0	 1	    1.02107	    0.00000	 63.0	 1	    1.07389	    0.96825;
	1685	 1	 8.7	 13.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1687	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1688	 1	 5.1	 -2.8	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1689	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1691	 1	 31.5	 2.3	 0.0	 0.0	 1	    1.00126	    0.00000	 63.0	 1	    1.06602	    0.93651;
	1692	 1	 38.7	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1693	 1	 25.6	 5.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1694	 1	 0.1	 1.5	 0.0	 0.0	 1	    1.00382	    0.00000	 63.0	 1	    1.07114	    0.93651;
	1695	 1	 -0.4	 1.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1699	 1	 29.1	 -6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1700	 1	 2.8	 -8.8	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1701	 1	 18.8	 11.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1702	 1	 -116.1	 -15.6	 0.0	 0.0	 1	    1.04848	    0.00000	 225.0	 1	    1.09695	    1.00000;
	1703	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00075	    0.00000	 63.0	 1	    1.06499	    0.93651;
	1704	 1	 32.4	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1705	 1	 21.0	 -1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1706	 1	 9.0	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1707	 1	 110.0	 11.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1708	 2	 128.9	 63.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1710	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1711	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1712	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1713	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1714	 1	 36.7	 7.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1715	 1	 187.1	 71.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1716	 1	 3.1	 1.2	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1717	 1	 9.0	 -0.7	 0.0	 0.0	 1	    1.00134	    0.00000	 63.0	 1	    1.06618	    0.93651;
	1718	 1	 99.3	 27.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1719	 1	 162.7	 12.5	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2896	 1	 160.1	 40.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1720	 1	 29.3	 7.4	 0.0	 0.0	 1	    1.01792	    0.00000	 63.0	 1	    1.06758	    0.96825;
	2994	 1	 12.6	 -1.9	 0.0	 0.0	 1	    1.01792	    0.00000	 63.0	 1	    1.06758	    0.96825;
	1721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1722	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1723	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2897	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1724	 1	 309.3	 -49.9	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1725	 1	 29.1	 7.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1726	 1	 21.8	 1.3	 0.0	 0.0	 1	    1.00223	    0.00000	 63.0	 1	    1.06796	    0.93651;
	1727	 1	 125.0	 30.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1728	 1	 24.2	 1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1729	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1730	 1	 23.7	 5.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1731	 1	 49.8	 8.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1732	 1	 137.1	 26.3	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2898	 1	 137.1	 27.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1733	 1	 90.0	 30.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1734	 1	 92.4	 24.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1735	 1	 335.2	 28.3	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1736	 1	 38.2	 3.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2899	 1	 34.1	 9.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1737	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04573	    0.00000	 225.0	 1	    1.09146	    1.00000;
	1740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1741	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1742	 1	 2.1	 -1.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1743	 1	 81.6	 -2.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1744	 1	 71.5	 22.6	 0.0	 61.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1745	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1746	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1748	 1	 249.0	 0.2	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1749	 1	 10.7	 -0.5	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1750	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00385	    0.00000	 63.0	 1	    1.07119	    0.93651;
	1751	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1752	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2900	 1	 0.0	 0.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1753	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2902	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1754	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1755	 1	 13.2	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1756	 1	 101.2	 4.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1757	 1	 0.1	 2.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1758	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2908	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2909	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2910	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2911	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1759	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1760	 2	 -5.9	 0.3	 0.0	 0.0	 1	    1.00138	    0.00000	 63.0	 1	    1.08212	    0.92063;
	1761	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00445	    0.00000	 150.0	 1	    1.10890	    0.90000;
	1762	 1	 133.7	 49.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1763	 1	 5.7	 0.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2912	 1	 57.2	 15.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2913	 1	 -1.3	 0.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1764	 1	 61.3	 14.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1765	 1	 3.1	 -3.5	 0.0	 0.0	 1	    1.04120	    0.00000	 225.0	 1	    1.09573	    0.98667;
	1766	 1	 46.5	 6.7	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1767	 1	 58.8	 18.1	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1768	 1	 0.0	 -3.3	 0.0	 0.0	 1	    1.04258	    0.00000	 225.0	 1	    1.08517	    1.00000;
	1769	 1	 -0.3	 -1.5	 0.0	 0.0	 1	    1.00254	    0.00000	 45.0	 1	    1.07175	    0.93333;
	1770	 1	 44.3	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1771	 1	 34.7	 -6.7	 0.0	 50.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1773	 1	 62.5	 31.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1775	 1	 18.0	 21.4	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1776	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2914	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1777	 1	 39.8	 6.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1778	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1779	 1	 119.5	 22.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1780	 1	 25.2	 -5.4	 0.0	 0.0	 1	    1.01469	    0.00000	 63.0	 1	    1.06349	    0.96589;
	1781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1782	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1784	 1	 44.5	 3.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1786	 1	 51.6	 -7.1	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1787	 1	 -0.7	 -4.8	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1788	 1	 41.1	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1789	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1790	 1	 67.3	 10.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1791	 1	 37.5	 -4.6	 0.0	 0.0	 1	    1.04602	    0.00000	 225.0	 1	    1.09203	    1.00000;
	1792	 1	 27.1	 3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1793	 1	 4.3	 2.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1794	 1	 19.0	 1.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2916	 1	 10.9	 -0.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1795	 1	 23.0	 1.3	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1796	 1	 42.7	 -3.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1797	 1	 69.7	 7.4	 0.0	 0.0	 1	    1.04105	    0.00000	 225.0	 1	    1.09544	    0.98667;
	1798	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1799	 1	 103.2	 -12.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1800	 1	 6.7	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1801	 1	 -18.2	 -3.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1802	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2917	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2918	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2919	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2920	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2921	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1803	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1804	 1	 177.1	 29.5	 0.0	 0.0	 1	    1.04521	    0.00000	 225.0	 1	    1.09042	    1.00000;
	2981	 1	 63.2	 0.2	 0.0	 0.0	 1	    1.04521	    0.00000	 225.0	 1	    1.09042	    1.00000;
	1805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1806	 1	 30.8	 6.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1807	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1808	 1	 16.9	 2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1809	 1	 26.2	 5.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1810	 1	 21.9	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2922	 1	 25.5	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1811	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00381	    0.00000	 63.0	 1	    1.07111	    0.93651;
	1812	 1	 82.4	 9.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1813	 1	 169.8	 49.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1814	 1	 6.3	 -3.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1815	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1816	 1	 -0.4	 4.6	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1817	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1818	 1	 4.3	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1820	 1	 76.5	 7.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1822	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1823	 1	 55.4	 2.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1824	 1	 234.7	 19.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1825	 1	 20.6	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1826	 1	 46.3	 6.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1827	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1828	 1	 128.8	 31.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1829	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1830	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1831	 1	 122.0	 -0.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1832	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1833	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03947	    0.00000	 380.0	 1	    1.10526	    0.97368;
	1834	 1	 46.8	 8.4	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1835	 1	 9.8	 -2.6	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1836	 1	 1.5	 -3.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1837	 1	 0.0	 0.1	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1838	 1	 49.2	 4.0	 0.0	 0.0	 1	    1.03942	    0.00000	 225.0	 1	    1.09218	    0.98667;
	2923	 1	 73.1	 -0.6	 0.0	 0.0	 1	    1.03942	    0.00000	 225.0	 1	    1.09218	    0.98667;
	1839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03987	    0.00000	 225.0	 1	    1.09307	    0.98667;
	1841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1842	 1	 12.3	 4.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1843	 1	 82.6	 25.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2925	 1	 38.3	 3.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1845	 1	 120.6	 19.0	 0.0	 0.0	 1	    1.03879	    0.00000	 225.0	 1	    1.09092	    0.98667;
	1846	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1847	 2	 20.6	 1.8	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1848	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1849	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1850	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1852	 1	 41.6	 6.2	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1853	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2926	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1854	 1	 72.3	 12.7	 0.0	 0.0	 1	    1.03857	    0.00000	 225.0	 1	    1.09047	    0.98667;
	1855	 1	 144.5	 45.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1857	 1	 26.8	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1858	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1859	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1860	 1	 -5.0	 -5.2	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1862	 1	 112.8	 50.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1864	 1	 30.1	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1865	 1	 103.4	 11.3	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1866	 1	 2.3	 -6.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1867	 1	 150.1	 19.3	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2928	 1	 129.2	 20.4	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	1868	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1870	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2929	 1	 116.3	 17.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1872	 1	 51.8	 0.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1873	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2931	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	2932	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.20000	    0.80000;
	1874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2934	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1875	 1	 74.0	 10.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1876	 1	 67.9	 17.4	 0.0	 0.0	 1	    1.04401	    0.00000	 225.0	 1	    1.10136	    0.98667;
	1877	 1	 4.9	 -1.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1878	 1	 29.5	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1879	 1	 68.9	 9.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1880	 1	 91.9	 31.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1881	 1	 35.8	 6.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1882	 1	 62.4	 26.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1883	 1	 13.0	 -2.9	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1884	 1	 6.7	 6.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2936	 1	 16.0	 5.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1885	 1	 62.0	 10.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2937	 1	 95.6	 21.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1886	 1	 168.0	 39.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1887	 1	 18.5	 -3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1888	 1	 135.3	 33.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1889	 1	 25.7	 2.6	 0.0	 0.0	 1	    1.00564	    0.00000	 63.0	 1	    1.09065	    0.92063;
	1890	 1	 113.7	 -7.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1891	 1	 19.4	 -2.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2938	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1892	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1893	 1	 20.4	 9.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2940	 1	 31.0	 10.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1894	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1895	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1896	 1	 34.4	 10.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2941	 1	 12.8	 9.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1897	 1	 3.6	 0.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1898	 1	 84.1	 18.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1899	 1	 19.4	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1901	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1902	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00358	    0.00000	 63.0	 1	    1.08652	    0.92063;
	1904	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04354	    0.00000	 225.0	 1	    1.08709	    1.00000;
	1905	 1	 8.8	 -0.7	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00284	    0.00000	 63.0	 1	    1.06918	    0.93651;
	1907	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1908	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1909	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	1910	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1911	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03787	    0.00000	 150.0	 1	    1.10907	    0.96667;
	1912	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04516	    0.00000	 225.0	 1	    1.09032	    1.00000;
	1913	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04521	    0.00000	 225.0	 1	    1.09041	    1.00000;
	1914	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1916	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1919	 1	 21.3	 -4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1920	 1	 -19.1	 3.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1921	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00240	    0.00000	 63.0	 1	    1.06830	    0.93651;
	1922	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1923	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1925	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1926	 1	 8.6	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1931	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04343	    0.00000	 225.0	 1	    1.08685	    1.00000;
	1932	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1933	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1934	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99227	    0.00000	 225.0	 1	    1.09566	    0.88889;
	1935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1938	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1939	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1940	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1941	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97661	    0.00000	 63.0	 1	    1.37722	    0.57601;
	1942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1944	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1945	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1946	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1947	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1948	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1949	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00105	    0.00000	 63.0	 1	    1.06560	    0.93651;
	1950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	1953	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1954	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1956	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04291	    0.00000	 225.0	 1	    1.08582	    1.00000;
	1957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1959	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00229	    0.00000	 63.0	 1	    1.06807	    0.93651;
	1963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1964	 1	 -41.4	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1965	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1966	 1	 20.5	 -1.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1967	 1	 -0.3	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1968	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1969	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1972	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01688	    0.00000	 63.0	 1	    1.06551	    0.96825;
	1973	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1977	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1978	 1	 -5.3	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1981	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1982	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04568	    0.00000	 225.0	 1	    1.09137	    1.00000;
	1984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1985	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1986	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	1987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	1989	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1990	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1991	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1993	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1994	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04532	    0.00000	 225.0	 1	    1.09064	    1.00000;
	1995	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1996	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99135	    0.00000	 225.0	 1	    1.09381	    0.88889;
	1997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1998	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	1999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2000	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2001	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2002	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2006	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2008	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2009	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	2010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2011	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2013	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2014	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99128	    0.00000	 225.0	 1	    1.09367	    0.88889;
	2015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2020	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2021	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	2023	 1	 1.7	 0.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2024	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	2025	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2026	 1	 11.6	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2031	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00140	    0.00000	 63.0	 1	    1.06630	    0.93651;
	2032	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2033	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2034	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98933	    0.00000	 225.0	 1	    1.08977	    0.88889;
	2035	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2037	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98927	    0.00000	 225.0	 1	    1.08965	    0.88889;
	2038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2042	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2043	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	2044	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2046	 1	 7.6	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03817	    0.00000	 150.0	 1	    1.10968	    0.96667;
	2048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2050	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2052	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2053	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2054	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02129	    0.00000	 63.0	 1	    1.07432	    0.96825;
	2057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00085	    0.00000	 63.0	 1	    1.06520	    0.93651;
	2058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03797	    0.00000	 150.0	 1	    1.10927	    0.96667;
	2060	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04539	    0.00000	 225.0	 1	    1.09077	    1.00000;
	2062	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2064	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99162	    0.00000	 225.0	 1	    1.09435	    0.88889;
	2065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2067	 1	 43.7	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00111	    0.00000	 63.0	 1	    1.06572	    0.93651;
	2069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00055	    0.00000	 63.0	 1	    1.06460	    0.93651;
	2070	 1	 48.1	 9.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00127	    0.00000	 63.0	 1	    1.06604	    0.93651;
	2072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2073	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00145	    0.00000	 63.0	 1	    1.06639	    0.93651;
	2076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2078	 1	 -21.2	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2079	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01996	    0.00000	 150.0	 1	    1.06754	    0.97237;
	2080	 1	 -38.8	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00061	    0.00000	 63.0	 1	    1.06472	    0.93651;
	2082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	2086	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2087	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2089	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	2090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04357	    0.00000	 225.0	 1	    1.08714	    1.00000;
	2091	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2092	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2093	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04483	    0.00000	 225.0	 1	    1.08966	    1.00000;
	2096	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2097	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2098	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2100	 1	 -5.7	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	2103	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	2104	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	2105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2107	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2110	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98926	    0.00000	 225.0	 1	    1.08964	    0.88889;
	2111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04605	    0.00000	 225.0	 1	    1.09211	    1.00000;
	2112	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2115	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2118	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00255	    0.00000	 63.0	 1	    1.06860	    0.93651;
	2121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2122	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2124	 1	 29.2	 3.5	 0.0	 0.0	 1	    0.99701	    0.00000	 63.0	 1	    1.07937	    0.91464;
	2125	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2126	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2128	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99017	    0.00000	 225.0	 1	    1.09146	    0.88889;
	2129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01800	    0.00000	 63.0	 1	    1.06774	    0.96825;
	2131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	2134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	2135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00357	    0.00000	 63.0	 1	    1.07063	    0.93651;
	2136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2138	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2139	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94448	    0.00000	 45.0	 1	    1.00008	    0.88889;
	2140	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2142	 1	 -3.4	 2.5	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2143	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2145	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00386	    0.00000	 63.0	 1	    1.07121	    0.93651;
	2147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00329	    0.00000	 63.0	 1	    1.08594	    0.92063;
	2148	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2150	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	2151	 1	 27.9	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	2152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00135	    0.00000	 63.0	 1	    1.08206	    0.92063;
	2153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05131	    0.00000	 380.0	 1	    1.10263	    1.00000;
	2154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 63.0	 1	    1.06349	    0.96825;
	2156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04539	    0.00000	 225.0	 1	    1.09078	    1.00000;
	2157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.06349	    0.93651;
	2158	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.94444	    0.00000	 45.0	 1	    1.00000	    0.88889;
	2159	 1	 -19.7	 7.9	 0.0	 0.0	 1	    1.01964	    0.00000	 63.0	 1	    1.11864	    0.92063;
	2160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2161	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	2163	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2164	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2165	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2166	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2167	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2168	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2169	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2170	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2171	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2172	 1	 24.1	 1.9	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2173	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2174	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2175	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2176	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2177	 1	 0.0	 -0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2178	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2179	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2180	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2181	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2182	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2183	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2184	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2185	 1	 4.4	 -3.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2186	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2187	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	2188	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2189	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2190	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2191	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2192	 1	 63.1	 19.3	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2193	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2194	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2195	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2196	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2197	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2198	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2199	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2200	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2201	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2202	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2203	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2204	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2205	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2206	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2207	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2208	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2209	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2210	 1	 4.4	 -3.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2211	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2212	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2213	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2214	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2215	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2216	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2217	 1	 56.1	 0.4	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2218	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2219	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2220	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2221	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2222	 1	 49.1	 15.8	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2223	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2224	 1	 2.1	 -3.9	 0.0	 0.0	 1	    0.97500	    0.00000	 150.0	 1	    1.15000	    0.80000;
	2225	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2226	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2227	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2228	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2229	 1	 33.9	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2230	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2231	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2232	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2233	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2234	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2235	 1	 53.0	 -3.1	 0.0	 0.0	 1	    0.97500	    0.00000	 225.0	 1	    1.15000	    0.80000;
	2236	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2237	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2238	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2239	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2240	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2241	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2242	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2243	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2244	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2245	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2246	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2247	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2248	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 380.0	 1	    1.15000	    0.80000;
	2249	 1	 -0.0	 -0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 63.0	 1	    1.15000	    0.80000;
	2250	 2	 -0.0	 -0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2251	 2	 -0.0	 -0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2253	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2254	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2255	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2257	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	2258	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	2259	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2260	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2261	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2262	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2263	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2264	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2265	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2266	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2267	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2268	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2269	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2270	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2271	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2272	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2273	 2	 37.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2274	 2	 2.6	 1.8	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2275	 2	 14.0	 11.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2276	 2	 8.6	 6.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2277	 2	 10.1	 7.6	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	2278	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2279	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2280	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2281	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2282	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2283	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2284	 2	 13.0	 7.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2286	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2287	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	2289	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	2290	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 12.0	 1	    1.15000	    0.80000;
	2291	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2292	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2293	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2294	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2295	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2296	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2297	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2298	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2299	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2300	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2301	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2302	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2303	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2304	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 4.0	 1	    1.15000	    0.80000;
	2305	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2306	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2307	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2309	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2310	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2311	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2312	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2313	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2314	 2	 1.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2315	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2317	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2318	 2	 -2.1	 -5.9	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2319	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2320	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2321	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2322	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2323	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2324	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2325	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2326	 2	 3.5	 2.2	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2327	 2	 4.2	 2.3	 0.0	 0.0	 1	    0.97500	    0.00000	 14.0	 1	    1.15000	    0.80000;
	2328	 2	 10.4	 6.2	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2329	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2330	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2331	 2	 -0.8	 -0.5	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2332	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2336	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2337	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2338	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2339	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2340	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2341	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2342	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2343	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2344	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2345	 2	 40.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2346	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2348	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2349	 2	 2.6	 2.0	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	2350	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2351	 2	 8.8	 6.6	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	2352	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2353	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2354	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2355	 2	 40.0	 17.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2356	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	2357	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2358	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2359	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2360	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2361	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2362	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2363	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2364	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2365	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2367	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2368	 2	 7.3	 5.5	 0.0	 0.0	 1	    0.97500	    0.00000	 21.0	 1	    1.15000	    0.80000;
	2369	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2370	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2371	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2372	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2373	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2374	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2375	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2376	 2	 8.8	 2.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2377	 2	 5.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2378	 2	 4.0	 3.2	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	2379	 2	 18.8	 11.3	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2380	 2	 6.2	 3.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2381	 2	 8.6	 3.9	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2382	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2383	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2385	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2386	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2388	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2389	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2390	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2391	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2392	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2393	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2394	 2	 15.2	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2395	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2396	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2397	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2398	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2399	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2400	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2401	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2402	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2403	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2404	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2409	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2410	 2	 14.0	 8.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2411	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2412	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2413	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2414	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2415	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2416	 2	 6.0	 3.7	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2417	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2418	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2419	 2	 -5.7	 -3.6	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2420	 2	 -5.0	 -3.1	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2422	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	2423	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	2424	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 18.0	 1	    1.15000	    0.80000;
	2425	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2426	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2427	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2428	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2429	 2	 12.2	 3.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	2430	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2431	 2	 0.0	 -0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 17.0	 1	    1.15000	    0.80000;
	2432	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2434	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2435	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2436	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2437	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2438	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2439	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2440	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2441	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2442	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2443	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2444	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2445	 2	 -0.0	 -0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2446	 2	 -0.2	 -0.1	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2447	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2449	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2450	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2452	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2453	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2454	 2	 12.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2455	 2	 28.4	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2457	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2458	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 11.0	 1	    1.15000	    0.80000;
	2459	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2460	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2461	 2	 10.8	 8.6	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2462	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2463	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	2464	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	2465	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 3.0	 1	    1.15000	    0.80000;
	2466	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2467	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2468	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2469	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2470	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	2471	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	2473	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 13.0	 1	    1.15000	    0.80000;
	2474	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2475	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2477	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2478	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2481	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2482	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2483	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2484	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2485	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2486	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2487	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2489	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2490	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2491	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2493	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2494	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2496	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2497	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2498	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2499	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2500	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2501	 2	 15.8	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2502	 2	 2.1	 1.2	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	2503	 2	 7.0	 4.0	 0.0	 0.0	 1	    0.97500	    0.00000	 19.0	 1	    1.15000	    0.80000;
	2504	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2505	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2507	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2508	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2509	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2510	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2511	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2512	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2513	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2514	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2515	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2516	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2517	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 5.0	 1	    1.15000	    0.80000;
	2519	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2520	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2521	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2523	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2524	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2525	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2526	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2527	 2	 35.0	 18.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2528	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2529	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2530	 2	 35.0	 13.0	 0.0	 0.0	 1	    0.97500	    0.00000	 24.0	 1	    1.15000	    0.80000;
	2531	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2532	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2533	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2534	 1	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2535	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.97500	    0.00000	 20.0	 1	    1.15000	    0.80000;
	2536	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 15.0	 1	    1.15000	    0.80000;
	2537	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2538	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97500	    0.00000	 10.0	 1	    1.15000	    0.80000;
	2539	 1	 616.6	 388.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2540	 1	 496.0	 293.2	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2541	 1	 -95.5	 -17.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2542	 1	 63.8	 78.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2543	 1	 -209.1	 198.0	 0.0	 0.0	 1	    1.04730	    0.00000	 225.0	 1	    1.09459	    1.00000;
	2544	 1	 167.5	 -35.2	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2545	 1	 97.1	 69.4	 0.0	 0.0	 1	    1.03861	    0.00000	 225.0	 1	    1.09056	    0.98667;
	2546	 1	 84.3	 65.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2547	 1	 65.8	 61.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2548	 1	 -304.8	 127.1	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2549	 1	 -23.5	 -29.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2550	 1	 340.5	 -11.8	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2551	 1	 -275.2	 111.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	2552	 1	 21.3	 67.0	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.08444	    1.00000;
	2553	 1	 -528.7	 16.3	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2554	 1	 99.4	 61.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2555	 1	 402.5	 71.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2556	 1	 0.0	 -3.0	 0.0	 0.0	 1	    1.04249	    0.00000	 225.0	 1	    1.09831	    0.98667;
	2557	 1	 -133.4	 58.5	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2558	 1	 157.2	 73.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2559	 1	 158.9	 35.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2560	 1	 -499.1	 52.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2561	 1	 217.2	 -37.1	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2562	 1	 2.5	 -0.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2563	 1	 407.7	 21.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2564	 1	 932.7	 112.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2565	 1	 31.6	 2.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2566	 1	 685.2	 -73.8	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2567	 1	 145.3	 32.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2568	 1	 145.1	 32.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2569	 1	 466.2	 11.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	2570	 1	 -84.7	 56.3	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	1279	 0.0	 0.0	 15.0	 -15.0	 1.044445	 100.0	 0	 35.0	 7.0; % PEL
	1210	 21.66	 2.5	 20.0	 -15.0	 1.0	 100.0	 1	 36.1	 7.22; % PEL
	751	 27.6	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 9.2; % NG
	2777	 2.0	 0.0	 0.1	 -0.1	 1.0	 100.0	 1	 4.0	 0.0; % NG
	2777	 4.2	 0.95	 1.0	 0.9	 1.0	 100.0	 1	 7.0	 1.4; % NG
	978	 7.2	 -1.5	 4.0	 -7.0	 1.0	 100.0	 1	 12.0	 2.4; % NG
	158	 1.35	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 2.7	 0.0; % PEL
	1217	 7.8	 0.0	 5.0	 -5.0	 1.022612	 100.0	 1	 13.0	 2.6; % COW
	367	 30.0	 9.0	 27.0	 -9.0	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1127	 9.6	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 16.0	 3.2; % PEL
	460	 0.0	 0.0	 40.0	 -40.0	 1.04643	 100.0	 0	 62.0	 12.4; % NG
	968	 10.8	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 18.0	 3.6; % PEL
	1827	 13.2	 -2.5	 7.0	 -12.0	 1.033334	 100.0	 1	 22.0	 4.4; % NG
	1466	 20.5	 -5.0	 5.0	 -15.0	 1.0	 100.0	 1	 40.0	 1.0; % NG
	2863	 20.5	 0.0	 6.0	 -6.0	 1.0	 100.0	 1	 40.0	 1.0; % NG
	1466	 20.5	 -5.0	 5.0	 -15.0	 1.0	 100.0	 1	 40.0	 1.0; % NG
	2863	 20.5	 0.0	 6.0	 -6.0	 1.0	 100.0	 1	 40.0	 1.0; % COW
	1072	 0.0	 0.0	 1.0	 0.9	 1.00445	 100.0	 0	 12.0	 2.4; % NG
	1072	 0.0	 0.0	 1.0	 0.9	 1.00445	 100.0	 0	 14.0	 2.8; % NG
	1072	 0.0	 0.0	 1.0	 0.9	 1.00445	 100.0	 0	 12.0	 2.4; % NG
	642	 6.2	 0.0	 3.0	 -3.0	 1.021212	 100.0	 1	 10.33	 2.07; % NG
	642	 6.2	 0.0	 3.0	 -3.0	 1.021212	 100.0	 1	 10.33	 2.07; % NG
	542	 27.5	 6.0	 22.0	 -10.0	 1.015872	 100.0	 1	 50.0	 5.0; % NG
	773	 7.2	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 12.0	 2.4; % NG
	399	 8.28	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 13.8	 2.76; % NG
	399	 0.6	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 1.2	 0.0; % PEL
	21	 14.4	 0.0	 0.0	 0.0	 0.9888895	 100.0	 1	 24.0	 4.8; % NG
	21	 16.56	 0.0	 0.0	 0.0	 0.9888895	 100.0	 1	 27.6	 5.52; % PEL
	899	 10.8	 0.0	 0.0	 0.0	 1.000709	 100.0	 1	 18.0	 3.6; % PEL
	899	 12.6	 0.0	 0.0	 0.0	 1.000709	 100.0	 1	 21.0	 4.2; % PEL
	2618	 3.6	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 6.0	 1.2; % NG
	2618	 22.5	 2.0	 10.0	 -6.0	 0.999999	 100.0	 1	 37.5	 7.5; % PEL
	285	 3.6	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 6.0	 1.2; % PEL
	285	 22.5	 2.0	 10.0	 -6.0	 0.999999	 100.0	 1	 37.5	 7.5; % PEL
	135	 7.8	 -0.5	 5.0	 -6.0	 1.0000025	 100.0	 1	 13.0	 2.6; % NG
	53	 10.8	 0.0	 0.8	 -0.8	 1.015872	 100.0	 1	 18.0	 3.6; % NG
	53	 10.8	 0.0	 0.8	 -0.8	 1.015872	 100.0	 1	 18.0	 3.6; % NG
	596	 2.0	 0.0	 0.0	 0.0	 1.04598	 100.0	 1	 4.0	 0.0; % NG
	958	 2.3	 0.0	 0.0	 0.0	 0.975	 100.0	 1	 4.6	 0.0; % NG
	1679	 12.6	 1.0	 6.0	 -4.0	 1.0	 100.0	 1	 21.0	 4.2; % NG
	1679	 12.6	 1.1	 6.7	 -4.5	 1.0	 100.0	 1	 21.0	 4.2; % NG
	1157	 4.32	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 7.2	 1.44; % NG
	513	 0.0	 0.0	 5.0	 1.0	 1.0	 100.0	 0	 11.0	 2.2; % PEL
	513	 0.0	 0.0	 5.0	 1.0	 1.0	 100.0	 0	 11.0	 2.2; % NG
	371	 4.8	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 8.0	 1.6; % PEL
	371	 4.8	 0.0	 5.0	 -5.0	 0.999999	 100.0	 1	 8.0	 1.6; % NG
	976	 21.0	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 7.0; % NG
	976	 21.0	 -1.5	 12.0	 -15.0	 1.015872	 100.0	 1	 35.0	 7.0; % PEL
	2754	 6.9	 0.0	 0.0	 0.0	 1.019477	 100.0	 1	 11.5	 2.3; % NG
	749	 0.0	 0.0	 5.0	 -5.0	 0.9444445	 100.0	 0	 8.5	 1.7; % NG
	1188	 12.0	 1.95	 2.0	 1.9	 1.004635	 100.0	 1	 20.0	 4.0; % PEL
	1254	 14.4	 0.0	 7.0	 -7.0	 1.001289	 100.0	 1	 24.0	 4.8; % PEL
	252	 6.6	 1.5	 8.0	 -5.0	 0.9444445	 100.0	 1	 11.0	 2.2; % NG
	252	 5.4	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 1.8; % NG
	252	 6.6	 1.5	 8.0	 -5.0	 0.9444445	 100.0	 1	 11.0	 2.2; % NG
	252	 5.4	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 9.0	 1.8; % NG
	504	 7.44	 0.0	 6.5	 -6.5	 0.9445145	 100.0	 1	 12.4	 2.48; % NG
	115	 15.18	 0.0	 0.0	 0.0	 0.9888895	 100.0	 1	 25.3	 5.06; % NG
	967	 1.15	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 2.3	 0.0; % PEL
	1811	 5.4	 0.0	 5.5	 -5.5	 1.003809	 100.0	 1	 9.0	 1.8; % NG
	2634	 8.4	 0.0	 7.0	 -7.0	 1.0000025	 100.0	 1	 14.0	 2.8; % COW
	326	 8.4	 0.0	 7.0	 -7.0	 1.0000025	 100.0	 1	 14.0	 2.8; % PEL
	1829	 7.68	 0.0	 7.7	 -7.7	 0.999999	 100.0	 1	 12.8	 2.56; % PEL
	1314	 23.4	 0.0	 19.0	 -19.0	 1.005695	 100.0	 1	 39.0	 7.8; % NG
	71	 18.0	 3.0	 10.0	 -4.0	 1.004425	 100.0	 1	 30.0	 6.0; % PEL
	93	 0.0	 0.0	 2.0	 1.9	 1.004535	 100.0	 0	 6.0	 1.2; % NG
	129	 6.6	 0.0	 4.0	 -4.0	 0.999999	 100.0	 1	 11.0	 2.2; % COW
	1594	 7.2	 0.0	 5.0	 -5.0	 1.021962	 100.0	 1	 12.0	 2.4; % NG
	1594	 7.2	 0.0	 5.0	 -5.0	 1.021962	 100.0	 1	 12.0	 2.4; % NG
	1354	 2.5	 0.0	 2.0	 -2.0	 1.015872	 100.0	 1	 5.0	 0.0; % NG
	1133	 10.35	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 17.25	 3.45; % NG
	1405	 22.68	 2.0	 12.0	 -8.0	 1.0	 100.0	 1	 37.8	 7.56; % NG
	2850	 22.68	 2.0	 12.0	 -8.0	 1.0	 100.0	 1	 37.8	 7.56; % NG
	2849	 22.68	 2.0	 12.0	 -8.0	 1.0	 100.0	 1	 37.8	 7.56; % NG
	1122	 4.14	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 6.9	 1.38; % NG
	1708	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % NG
	1708	 44.5	 9.0	 27.0	 -9.0	 1.0377785	 100.0	 1	 45.0	 44.0; % NG
	1658	 17.94	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 29.9	 5.98; % NG
	2884	 8.22	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 13.7	 2.74; % NG
	1154	 12.48	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 20.8	 4.16; % NG
	231	 4.98	 0.0	 8.3	 -8.3	 1.0111115	 100.0	 1	 8.3	 1.66; % COW
	2887	 14.22	 2.0	 7.0	 -3.0	 1.0	 100.0	 1	 23.7	 4.74; % PEL
	2888	 14.22	 2.0	 7.0	 -3.0	 1.0	 100.0	 1	 23.7	 4.74; % NG
	1666	 14.22	 2.0	 7.0	 -3.0	 1.0	 100.0	 1	 23.7	 4.74; % PEL
	499	 10.2	 0.95	 1.0	 0.9	 1.0287175	 100.0	 1	 17.0	 3.4; % NG
	499	 4.2	 0.95	 1.0	 0.9	 1.0287175	 100.0	 1	 7.0	 1.4; % COW
	499	 10.2	 0.95	 1.0	 0.9	 1.0287175	 100.0	 1	 17.0	 3.4; % NG
	2709	 14.4	 0.0	 4.0	 -4.0	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	709	 14.4	 0.0	 4.0	 -4.0	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	2710	 14.4	 0.0	 4.0	 -4.0	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	2708	 14.4	 0.0	 4.0	 -4.0	 1.0	 100.0	 1	 24.0	 4.8; % NG
	1280	 10.8	 0.0	 0.0	 0.0	 1.001694	 100.0	 1	 18.0	 3.6; % PEL
	1493	 0.0	 0.0	 11.0	 -11.0	 0.9444445	 100.0	 0	 18.0	 3.6; % PEL
	745	 17.4	 -5.0	 8.0	 -18.0	 0.999999	 100.0	 1	 29.0	 5.8; % NG
	2727	 17.4	 -6.5	 5.0	 -18.0	 0.999999	 100.0	 1	 29.0	 5.8; % PEL
	1445	 33.0	 0.0	 0.0	 0.0	 1.026667	 100.0	 1	 55.0	 11.0; % NG
	316	 2.5	 0.95	 1.0	 0.9	 0.976703	 100.0	 1	 5.0	 0.0; % NG
	316	 5.88	 -0.145	 3.14	 -3.43	 0.976703	 100.0	 1	 9.8	 1.96; % NG
	564	 6.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 10.0	 2.0; % NG
	1047	 7.2	 0.0	 0.0	 0.0	 1.000539	 100.0	 1	 12.0	 2.4; % NG
	1047	 1.0	 0.0	 0.0	 0.0	 1.000539	 100.0	 1	 2.0	 0.0; % PEL
	1335	 1.0	 1.0	 3.0	 -1.0	 1.003809	 100.0	 1	 2.0	 0.0; % PEL
	2624	 18.6	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 31.0	 6.2; % NG
	298	 18.6	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 31.0	 6.2; % NG
	298	 18.6	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 31.0	 6.2; % PEL
	2625	 18.6	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 31.0	 6.2; % PEL
	2625	 18.6	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 31.0	 6.2; % PEL
	2624	 18.6	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 31.0	 6.2; % NG
	2721	 14.4	 -0.005	 0.0	 -0.01	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	2718	 14.4	 0.5	 8.0	 -7.0	 1.0	 100.0	 1	 24.0	 4.8; % COW
	741	 14.4	 0.5	 8.0	 -7.0	 1.0	 100.0	 1	 24.0	 4.8; % COW
	2719	 14.4	 0.5	 8.0	 -7.0	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	2720	 14.4	 0.5	 8.0	 -7.0	 1.0	 100.0	 1	 24.0	 4.8; % NG
	283	 14.1	 0.0	 8.0	 -8.0	 0.9888895	 100.0	 1	 23.5	 4.7; % COW
	1506	 16.2	 -2.5	 6.0	 -11.0	 1.016412	 100.0	 1	 27.0	 5.4; % NG
	1506	 16.2	 -2.5	 6.0	 -11.0	 1.016412	 100.0	 1	 27.0	 5.4; % NG
	1847	 19.2	 2.0	 12.0	 -8.0	 1.015872	 100.0	 1	 32.0	 6.4; % COW
	1398	 12.01	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.02	 4.0; % PEL
	1398	 12.21	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 20.35	 4.07; % PEL
	225	 27.0	 0.0	 45.0	 -45.0	 1.0	 100.0	 1	 45.0	 9.0; % NG
	225	 27.0	 0.0	 45.0	 -45.0	 1.0	 100.0	 1	 45.0	 9.0; % NG
	1607	 0.87	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 1.74	 0.0; % NG
	314	 12.0	 0.0	 10.0	 -10.0	 0.9448795	 100.0	 1	 20.0	 4.0; % PEL
	2680	 141.5	 20.0	 100.0	 -60.0	 1.0	 100.0	 1	 239.0	 44.0; % NG
	582	 125.5	 12.5	 70.0	 -45.0	 1.0	 100.0	 1	 169.0	 82.0; % COW
	2978	 125.5	 12.5	 70.0	 -45.0	 1.0	 100.0	 1	 169.0	 82.0; % COW
	2977	 141.5	 20.0	 100.0	 -60.0	 1.0	 100.0	 1	 239.0	 44.0; % NG
	240	 143.4	 2.5	 80.0	 -75.0	 1.05347	 100.0	 1	 239.0	 47.8; % NG
	1655	 7.2	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 12.0	 2.4; % NG
	1655	 2.0	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 4.0	 0.0; % PEL
	1150	 32.4	 0.0	 0.0	 0.0	 1.0377785	 100.0	 1	 54.0	 10.8; % PEL
	1447	 4.2	 -0.5	 2.0	 -3.0	 1.015872	 100.0	 1	 7.0	 1.4; % PEL
	906	 0.0	 0.0	 8.0	 -8.0	 1.04623	 100.0	 0	 21.0	 4.2; % PEL
	1474	 0.0	 -0.0	 1.0	 -1.0	 1.015872	 100.0	 0	 2.0	 0.0; % PEL
	1474	 4.8	 0.0	 3.0	 -3.0	 1.015872	 100.0	 1	 8.0	 1.6; % NG
	1474	 4.8	 0.0	 3.0	 -3.0	 1.015872	 100.0	 1	 8.0	 1.6; % COW
	963	 5.34	 -0.5	 1.0	 -2.0	 1.015872	 100.0	 1	 8.9	 1.78; % NG
	962	 13.2	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 22.0	 4.4; % PEL
	923	 7.2	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 12.0	 2.4; % COW
	1153	 9.6	 0.0	 17.3	 -17.3	 1.001654	 100.0	 1	 16.0	 3.2; % PEL
	1153	 10.08	 0.0	 10.0	 -10.0	 1.001654	 100.0	 1	 16.8	 3.36; % PEL
	274	 4.02	 0.0	 3.7	 -3.7	 0.999999	 100.0	 1	 6.7	 1.34; % NG
	274	 3.36	 0.0	 3.0	 -3.0	 0.999999	 100.0	 1	 5.6	 1.12; % PEL
	1776	 6.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 2.0; % NG
	1776	 6.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 2.0; % NG
	2914	 6.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 2.0; % NG
	2914	 6.0	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 10.0	 2.0; % NG
	184	 0.0	 0.0	 8.0	 -17.0	 1.033334	 100.0	 0	 23.4	 4.68; % PEL
	1657	 15.6	 -0.5	 16.0	 -17.0	 1.0233335	 100.0	 1	 26.0	 5.2; % NG
	1657	 15.6	 -0.5	 16.0	 -17.0	 1.0233335	 100.0	 1	 26.0	 5.2; % NG
	1761	 1.25	 0.0	 0.1	 -0.1	 1.00445	 100.0	 1	 2.5	 0.0; % PEL
	1761	 0.0	 0.0	 1.0	 0.9	 1.00445	 100.0	 0	 11.0	 2.2; % NG
	1868	 18.0	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 30.0	 6.0; % PEL
	1868	 18.0	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 30.0	 6.0; % PEL
	731	 0.0	 0.0	 26.0	 -26.0	 0.999999	 100.0	 0	 43.0	 8.6; % NG
	2715	 0.0	 0.0	 20.0	 -20.0	 0.999999	 100.0	 0	 38.0	 7.6; % COW
	1263	 13.86	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 4.62; % NG
	1263	 13.86	 0.0	 14.0	 -14.0	 0.999999	 100.0	 1	 23.1	 4.62; % NG
	161	 10.8	 0.0	 5.0	 -5.0	 0.975	 100.0	 1	 18.0	 3.6; % PEL
	604	 6.12	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 10.2	 2.04; % NG
	918	 15.6	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 26.0	 5.2; % PEL
	1760	 6.9	 0.0	 1.0	 -1.0	 1.0013775	 100.0	 1	 11.5	 2.3; % NG
	1760	 6.9	 0.0	 1.0	 -1.0	 1.0013775	 100.0	 1	 11.5	 2.3; % NG
	1414	 7.8	 0.0	 7.8	 -7.8	 0.999999	 100.0	 1	 13.0	 2.6; % NG
	1414	 7.2	 0.0	 7.2	 -7.2	 0.999999	 100.0	 1	 12.0	 2.4; % NG
	662	 24.0	 1.0	 20.0	 -18.0	 1.0	 100.0	 1	 40.0	 8.0; % NG
	2697	 24.0	 1.0	 20.0	 -18.0	 1.0	 100.0	 1	 40.0	 8.0; % COW
	2696	 24.0	 1.0	 20.0	 -18.0	 1.0	 100.0	 1	 40.0	 8.0; % NG
	1346	 7.2	 0.0	 7.0	 -7.0	 0.999999	 100.0	 1	 12.0	 2.4; % COW
	1346	 7.2	 0.0	 7.0	 -7.0	 0.999999	 100.0	 1	 12.0	 2.4; % PEL
	2622	 4.8	 0.0	 26.0	 -26.0	 1.0	 100.0	 1	 8.0	 1.6; % NG
	2622	 9.0	 0.0	 26.0	 -26.0	 1.0	 100.0	 1	 15.0	 3.0; % NG
	291	 11.4	 0.0	 26.0	 -26.0	 1.0	 100.0	 1	 19.0	 3.8; % NG
	1490	 6.36	 0.0	 6.5	 -6.5	 0.999999	 100.0	 1	 10.6	 2.12; % NG
	1671	 12.84	 0.0	 15.0	 -15.0	 1.0158755	 100.0	 1	 21.4	 4.28; % NG
	1615	 23.4	 0.0	 24.0	 -24.0	 0.999999	 100.0	 1	 39.0	 7.8; % COW
	1681	 52.2	 0.87	 26.1	 -24.36	 1.044445	 100.0	 1	 87.0	 17.4; % NG
	418	 45.0	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 75.0	 15.0; % PEL
	2658	 45.0	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 75.0	 15.0; % PEL
	418	 45.0	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 75.0	 15.0; % PEL
	2658	 45.0	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 75.0	 15.0; % NG
	461	 24.84	 0.415	 12.42	 -11.59	 1.044445	 100.0	 1	 41.4	 8.28; % NG
	31	 4.01	 0.0	 0.0	 0.0	 1.004309	 100.0	 1	 6.68	 1.34; % NG
	236	 9.0	 3.5	 7.0	 0.0	 1.015872	 100.0	 1	 15.0	 3.0; % NG
	236	 9.0	 3.5	 7.0	 0.0	 1.015872	 100.0	 1	 15.0	 3.0; % NG
	1754	 0.5	 0.0	 1.0	 -1.0	 1.015872	 100.0	 1	 1.0	 0.0; % PEL
	1754	 0.5	 0.0	 1.0	 -1.0	 1.015872	 100.0	 1	 1.0	 0.0; % PEL
	1754	 0.5	 0.0	 1.0	 -1.0	 1.015872	 100.0	 1	 1.0	 0.0; % PEL
	898	 0.85	 0.0	 0.0	 0.0	 1.001324	 100.0	 1	 1.7	 0.0; % PEL
	898	 13.56	 0.0	 0.0	 0.0	 1.001324	 100.0	 1	 22.6	 4.52; % NG
	120	 9.0	 0.0	 9.0	 -9.0	 1.002569	 100.0	 1	 15.0	 3.0; % NG
	549	 27.5	 6.0	 22.0	 -10.0	 1.015872	 100.0	 1	 50.0	 5.0; % NG
	77	 14.1	 0.0	 0.0	 0.0	 1.0027225	 100.0	 1	 23.5	 4.7; % PEL
	124	 -3.5	 0.0	 0.0	 0.0	 1.0013325	 100.0	 1	 0.0	 -7.0; % SYNC
	124	 -3.5	 0.0	 0.0	 0.0	 1.0013325	 100.0	 1	 0.0	 -7.0; % SYNC
	552	 12.6	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 21.0	 4.2; % COW
	1858	 5.76	 0.0	 6.0	 -6.0	 0.9444445	 100.0	 1	 9.6	 1.92; % NG
	134	 15.0	 2.0	 13.0	 -9.0	 1.0233335	 100.0	 1	 25.0	 5.0; % COW
	1204	 25.2	 2.5	 25.0	 -20.0	 1.00031	 100.0	 1	 42.0	 8.4; % NG
	1204	 25.2	 2.5	 25.0	 -20.0	 1.00031	 100.0	 1	 42.0	 8.4; % NG
	641	 6.6	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 11.0	 2.2; % NG
	641	 6.6	 0.0	 5.0	 -5.0	 1.015872	 100.0	 1	 11.0	 2.2; % NG
	916	 7.2	 0.0	 0.0	 0.0	 0.999999	 100.0	 1	 12.0	 2.4; % COW
	1317	 30.0	 0.0	 28.0	 -28.0	 1.000569	 100.0	 1	 50.0	 10.0; % NG
	1317	 24.0	 10.0	 30.0	 -10.0	 1.000569	 100.0	 1	 40.0	 8.0; % NG
	1610	 8.28	 0.0	 0.0	 0.0	 1.000839	 100.0	 1	 13.8	 2.76; % NG
	1610	 9.0	 0.0	 0.0	 0.0	 1.000839	 100.0	 1	 15.0	 3.0; % PEL
	271	 23.4	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 39.0	 7.8; % COW
	1123	 33.24	 0.0	 0.0	 0.0	 1.04769	 100.0	 1	 55.4	 11.08; % PEL
	300	 24.48	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 40.8	 8.16; % NG
	648	 17.34	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 28.9	 5.78; % PEL
	1630	 1.0	 0.0	 1.0	 -1.0	 1.015872	 100.0	 1	 2.0	 0.0; % PEL
	1630	 2.5	 0.0	 2.0	 -2.0	 1.015872	 100.0	 1	 5.0	 0.0; % NG
	1630	 1.0	 0.0	 1.0	 -1.0	 1.015872	 100.0	 1	 2.0	 0.0; % PEL
	1604	 2.5	 0.0	 2.0	 -2.0	 1.015872	 100.0	 1	 5.0	 0.0; % NG
	1802	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % NG
	2917	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % NG
	2921	 90.0	 0.0	 70.0	 -70.0	 1.0	 100.0	 1	 150.0	 30.0; % NG
	2918	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % COW
	2921	 90.0	 0.0	 70.0	 -70.0	 1.0	 100.0	 1	 150.0	 30.0; % NG
	2920	 0.0	 0.0	 70.0	 -70.0	 1.0	 100.0	 0	 150.0	 30.0; % NG
	2919	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % NG
	1802	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % NG
	2917	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % NG
	2919	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % NG
	2918	 102.0	 -5.0	 70.0	 -80.0	 1.0	 100.0	 1	 170.0	 34.0; % NG
	2920	 0.0	 0.0	 70.0	 -70.0	 1.0	 100.0	 0	 150.0	 30.0; % NG
	946	 9.6	 1.5	 12.0	 -9.0	 0.999999	 100.0	 1	 16.0	 3.2; % NG
	1576	 11.4	 0.0	 5.0	 -5.0	 1.012164	 100.0	 1	 19.0	 3.8; % NG
	335	 0.0	 0.0	 5.0	 -5.0	 1.0	 100.0	 0	 13.0	 2.6; % NG
	335	 0.0	 0.0	 5.0	 -5.0	 1.0	 100.0	 0	 13.0	 2.6; % NG
	335	 0.0	 0.0	 5.0	 -5.0	 1.0	 100.0	 0	 13.0	 2.6; % COW
	335	 0.0	 0.0	 5.0	 -5.0	 1.0	 100.0	 0	 13.0	 2.6; % NG
	2932	 21.06	 -4.5	 12.0	 -21.0	 1.0	 100.0	 1	 35.1	 7.02; % PEL
	1873	 21.06	 -4.5	 12.0	 -21.0	 1.0	 100.0	 1	 35.1	 7.02; % PEL
	2931	 21.06	 -4.5	 12.0	 -21.0	 1.0	 100.0	 1	 35.1	 7.02; % NG
	2761	 14.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 24.0	 4.8; % NG
	2759	 14.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	2760	 12.0	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 20.0	 4.0; % NG
	2758	 14.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	883	 14.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	2757	 14.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 24.0	 4.8; % NG
	631	 31.2	 -1.5	 10.0	 -13.0	 1.04222	 100.0	 1	 52.0	 10.4; % NG
	1355	 1.5	 0.0	 1.8	 -1.8	 0.999999	 100.0	 1	 3.0	 0.0; % NG
	1151	 22.8	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 38.0	 7.6; % NG
	2803	 22.8	 0.5	 20.0	 -19.0	 1.0	 100.0	 1	 38.0	 7.6; % NG
	2802	 22.8	 0.5	 20.0	 -19.0	 1.0	 100.0	 1	 38.0	 7.6; % PEL
	1593	 7.2	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 12.0	 2.4; % NG
	1593	 7.2	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 12.0	 2.4; % COW
	313	 16.2	 0.0	 10.0	 -10.0	 1.0000025	 100.0	 1	 27.0	 5.4; % NG
	1573	 7.8	 6.5	 13.0	 0.0	 0.999999	 100.0	 1	 13.0	 2.6; % NG
	1294	 7.68	 0.0	 7.6	 -7.6	 0.999999	 100.0	 1	 12.8	 2.56; % NG
	2578	 10.74	 -1.5	 10.0	 -13.0	 0.9444445	 100.0	 1	 17.9	 3.58; % PEL
	2578	 10.74	 -1.5	 10.0	 -13.0	 0.9444445	 100.0	 1	 17.9	 3.58; % NG
	1176	 16.2	 3.5	 10.0	 -3.0	 1.0	 100.0	 1	 27.0	 5.4; % PEL
	1176	 16.2	 3.5	 10.0	 -3.0	 1.0	 100.0	 1	 27.0	 5.4; % PEL
	1782	 18.0	 0.0	 10.0	 -10.0	 1.0233335	 100.0	 1	 30.0	 6.0; % PEL
	626	 46.8	 0.5	 1.0	 0.0	 1.0377785	 100.0	 1	 78.0	 15.6; % NG
	146	 78.0	 16.5	 59.0	 -26.0	 1.044445	 100.0	 1	 130.0	 26.0; % NG
	262	 2.0	 0.0	 2.5	 -2.5	 0.9444445	 100.0	 1	 4.0	 0.0; % NG
	262	 3.42	 0.0	 3.0	 -3.0	 0.9444445	 100.0	 1	 5.7	 1.14; % COW
	262	 5.1	 0.5	 6.0	 -5.0	 0.9444445	 100.0	 1	 8.5	 1.7; % NG
	262	 2.0	 0.0	 2.0	 -2.0	 0.9444445	 100.0	 1	 4.0	 0.0; % NG
	819	 0.0	 0.0	 9.0	 -9.0	 0.9444445	 100.0	 0	 15.0	 3.0; % NG
	1536	 2.5	 0.0	 2.0	 -2.0	 1.015872	 100.0	 1	 5.0	 0.0; % NG
	1536	 2.5	 0.0	 2.0	 -2.0	 1.015872	 100.0	 1	 5.0	 0.0; % NG
	19	 7.8	 0.95	 1.0	 0.9	 1.0036225	 100.0	 1	 13.0	 2.6; % NG
	838	 13.25	 0.0	 8.0	 -8.0	 1.0	 100.0	 1	 24.0	 2.5; % PEL
	838	 13.25	 0.0	 8.0	 -8.0	 1.0	 100.0	 1	 24.0	 2.5; % PEL
	519	 7.8	 1.0	 7.0	 -5.0	 1.022012	 100.0	 1	 13.0	 2.6; % PEL
	519	 7.8	 1.0	 7.0	 -5.0	 1.022012	 100.0	 1	 13.0	 2.6; % PEL
	275	 15.96	 0.0	 15.0	 -15.0	 0.999999	 100.0	 1	 26.6	 5.32; % PEL
	482	 2.3	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 4.6	 0.0; % NG
	876	 16.8	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 5.6; % NG
	876	 16.8	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 5.6; % NG
	876	 16.8	 1.5	 12.0	 -9.0	 1.015872	 100.0	 1	 28.0	 5.6; % NG
	305	 16.5	 -1.5	 6.0	 -9.0	 1.016392	 100.0	 1	 32.0	 1.0; % PEL
	305	 16.5	 -1.5	 6.0	 -9.0	 1.016392	 100.0	 1	 32.0	 1.0; % PEL
	2628	 16.5	 -1.5	 6.0	 -9.0	 1.016392	 100.0	 1	 32.0	 1.0; % PEL
	2628	 16.5	 -1.5	 6.0	 -9.0	 1.016392	 100.0	 1	 32.0	 1.0; % PEL
	2628	 16.5	 -1.5	 6.0	 -9.0	 1.016392	 100.0	 1	 32.0	 1.0; % NG
	2628	 16.5	 -1.5	 6.0	 -9.0	 1.016392	 100.0	 1	 32.0	 1.0; % PEL
	1456	 7.015	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 11.69	 2.34; % NG
	38	 27.6	 6.0	 21.0	 -9.0	 1.0158755	 100.0	 1	 46.0	 9.2; % NG
	1798	 16.2	 0.0	 18.0	 -18.0	 0.999999	 100.0	 1	 27.0	 5.4; % NG
	426	 4.2	 0.0	 0.1	 -0.1	 1.0000025	 100.0	 1	 7.0	 1.4; % PEL
	1714	 3.6	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 6.0	 1.2; % NG
	744	 17.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 29.0	 5.8; % PEL
	744	 17.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 29.0	 5.8; % PEL
	1261	 4.5	 0.0	 1.0	 -1.0	 1.0004375	 100.0	 1	 7.5	 1.5; % PEL
	1261	 4.5	 0.0	 1.0	 -1.0	 1.0004375	 100.0	 1	 7.5	 1.5; % NG
	1261	 4.5	 0.0	 1.0	 -1.0	 1.0004375	 100.0	 1	 7.5	 1.5; % COW
	1261	 4.5	 0.0	 1.0	 -1.0	 1.0004375	 100.0	 1	 7.5	 1.5; % COW
	1261	 4.5	 0.0	 1.0	 -1.0	 1.0004375	 100.0	 1	 7.5	 1.5; % PEL
	975	 1.3	 0.0	 1.7	 -1.7	 0.999999	 100.0	 1	 2.6	 0.0; % PEL
	975	 5.88	 0.0	 6.0	 -6.0	 0.999999	 100.0	 1	 9.8	 1.96; % PEL
	1706	 7.02	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 11.7	 2.34; % NG
	1160	 4.8	 0.0	 0.0	 0.0	 1.0377785	 100.0	 1	 8.0	 1.6; % PEL
	1160	 4.8	 0.0	 0.0	 0.0	 1.0377785	 100.0	 1	 8.0	 1.6; % NG
	235	 4.38	 0.0	 4.0	 -4.0	 0.999999	 100.0	 1	 7.3	 1.46; % NG
	2613	 22.2	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 37.0	 7.4; % PEL
	2613	 22.2	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 37.0	 7.4; % NG
	259	 22.2	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 37.0	 7.4; % PEL
	259	 22.2	 -1.0	 15.0	 -17.0	 1.0	 100.0	 1	 37.0	 7.4; % PEL
	2614	 22.2	 0.0	 15.0	 -15.0	 1.0	 100.0	 1	 37.0	 7.4; % COW
	2614	 22.2	 0.0	 15.0	 -15.0	 1.0	 100.0	 1	 37.0	 7.4; % NG
	1220	 6.12	 0.0	 0.0	 0.0	 1.002214	 100.0	 1	 10.2	 2.04; % NG
	1220	 10.8	 0.0	 0.0	 0.0	 1.002214	 100.0	 1	 18.0	 3.6; % PEL
	1148	 5.4	 6.0	 12.0	 0.0	 0.999999	 100.0	 1	 9.0	 1.8; % NG
	1069	 14.45	 0.0	 8.0	 -8.0	 1.0	 100.0	 1	 22.9	 6.0; % PEL
	1069	 16.25	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 26.5	 6.0; % NG
	1069	 16.25	 0.0	 9.0	 -9.0	 1.0	 100.0	 1	 26.5	 6.0; % PEL
	1815	 6.48	 0.0	 6.4	 -6.4	 0.9444445	 100.0	 1	 10.8	 2.16; % NG
	1815	 3.84	 0.0	 4.0	 -4.0	 0.9444445	 100.0	 1	 6.4	 1.28; % PEL
	1046	 8.28	 -0.465	 4.63	 -5.56	 1.033334	 100.0	 1	 13.8	 2.76; % NG
	1606	 27.6	 -7.0	 20.0	 -34.0	 0.999999	 100.0	 1	 46.0	 9.2; % NG
	76	 18.0	 0.0	 14.0	 -14.0	 0.9444445	 100.0	 1	 30.0	 6.0; % PEL
	1612	 26.4	 0.0	 25.0	 -25.0	 0.999999	 100.0	 1	 44.0	 8.8; % NG
	1276	 -4.0	 0.0	 0.0	 0.0	 1.02107	 100.0	 1	 0.0	 -8.0; % SYNC
	1276	 31.8	 3.5	 17.0	 -10.0	 1.02107	 100.0	 1	 53.0	 10.6; % NG
	1396	 6.0	 0.0	 0.0	 0.0	 1.0030475	 100.0	 1	 10.0	 2.0; % NG
	1396	 6.0	 0.0	 0.0	 0.0	 1.0030475	 100.0	 1	 10.0	 2.0; % NG
	1288	 6.0	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 10.0	 2.0; % NG
	489	 4.8	 -0.1	 2.6	 -2.8	 1.0033625	 100.0	 1	 8.0	 1.6; % COW
	489	 0.53	 0.0	 0.35	 -0.35	 1.0033625	 100.0	 1	 1.06	 0.0; % PEL
	489	 4.8	 -0.1	 2.6	 -2.8	 1.0033625	 100.0	 1	 8.0	 1.6; % PEL
	1678	 18.6	 1.0	 16.0	 -14.0	 1.015872	 100.0	 1	 31.0	 6.2; % PEL
	1614	 34.8	 0.0	 35.0	 -35.0	 1.0111115	 100.0	 1	 58.0	 11.6; % NG
	220	 3.66	 0.0	 1.0	 -1.0	 1.015872	 100.0	 1	 6.1	 1.22; % PEL
	133	 15.0	 2.0	 13.0	 -9.0	 1.016817	 100.0	 1	 25.0	 5.0; % NG
	172	 0.0	 0.0	 8.0	 -9.0	 1.015872	 100.0	 0	 25.0	 5.0; % NG
	1266	 1.5	 0.0	 0.0	 0.0	 1.015872	 100.0	 1	 3.0	 0.0; % NG
	877	 6.0	 0.0	 1.0	 -1.0	 1.0000025	 100.0	 1	 10.0	 2.0; % NG
	877	 4.2	 2.95	 3.0	 2.9	 1.0000025	 100.0	 1	 7.0	 1.4; % COW
	697	 2.5	 0.0	 2.0	 -2.0	 1.017122	 100.0	 1	 5.0	 0.0; % NG
	697	 2.0	 0.0	 1.0	 -1.0	 1.017122	 100.0	 1	 4.0	 0.0; % NG
	1181	 10.8	 0.0	 0.0	 0.0	 1.002699	 100.0	 1	 18.0	 3.6; % NG
	1181	 6.0	 0.0	 0.0	 0.0	 1.002699	 100.0	 1	 10.0	 2.0; % NG
	2982	 5.16	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 8.6	 1.72; % NG
	2982	 6.3	 0.0	 0.0	 0.0	 1.0000025	 100.0	 1	 10.5	 2.1; % NG
	310	 4.2	 0.0	 3.0	 -3.0	 1.0047725	 100.0	 1	 7.0	 1.4; % NG
	310	 7.8	 0.0	 3.0	 -3.0	 1.0047725	 100.0	 1	 13.0	 2.6; % PEL
	2250	 435.0	 43.915	 260.97	 -173.14	 0.975	 100.0	 1	 670.0	 200.0; % COW
	2251	 420.0	 79.12	 269.33	 -111.09	 0.975	 100.0	 1	 700.0	 140.0; % COW
	2253	 13.8	 2.565	 14.0	 -8.87	 0.975	 100.0	 1	 23.0	 4.6; % PEL
	2254	 13.8	 2.565	 14.0	 -8.87	 0.975	 100.0	 1	 23.0	 4.6; % NG
	2255	 16.2	 4.515	 22.36	 -13.33	 0.975	 100.0	 1	 27.0	 5.4; % PEL
	2257	 51.6	 16.295	 36.04	 -3.45	 0.975	 100.0	 1	 86.0	 17.2; % NG
	2258	 29.4	 9.48	 22.19	 -3.23	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2259	 74.4	 28.595	 79.63	 -22.44	 0.975	 100.0	 1	 124.0	 24.8; % NG
	2260	 19.2	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 6.4; % PEL
	2261	 19.2	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2262	 19.2	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2263	 19.2	 1.545	 9.89	 -6.8	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2264	 55.2	 14.82	 59.82	 -30.18	 0.975	 100.0	 1	 92.0	 18.4; % NG
	2265	 55.2	 14.82	 59.82	 -30.18	 0.975	 100.0	 1	 92.0	 18.4; % NG
	2266	 55.2	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 18.4; % NG
	2267	 55.2	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 18.4; % NG
	2268	 55.2	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 18.4; % NG
	2269	 55.2	 17.7	 62.7	 -27.3	 0.975	 100.0	 1	 92.0	 18.4; % NG
	2270	 590.5	 -41.595	 338.09	 -421.28	 0.975	 100.0	 1	 935.5	 245.5; % COW
	2271	 631.47	 -31.285	 348.02	 -410.59	 0.975	 100.0	 1	 976.47	 286.47; % COW
	2272	 612.51	 -36.095	 339.68	 -411.87	 0.975	 100.0	 1	 972.51	 252.51; % COW
	2273	 565.0	 -61.375	 315.49	 -438.24	 0.975	 100.0	 1	 910.0	 220.0; % COW
	2274	 204.0	 31.78	 164.82	 -101.26	 0.975	 100.0	 1	 252.0	 156.0; % NG
	2275	 188.0	 22.19	 153.82	 -109.44	 0.975	 100.0	 1	 236.0	 140.0; % NG
	2276	 202.0	 22.52	 101.23	 -56.19	 0.975	 100.0	 1	 250.0	 154.0; % NG
	2277	 203.5	 35.05	 237.67	 -167.57	 0.975	 100.0	 1	 295.0	 112.0; % NG
	2278	 122.0	 17.885	 102.26	 -66.49	 0.975	 100.0	 1	 155.0	 89.0; % NG
	2279	 34.8	 -0.45	 19.65	 -20.55	 0.975	 100.0	 1	 58.0	 11.6; % NG
	2280	 34.8	 -0.1	 12.29	 -12.49	 0.975	 100.0	 1	 58.0	 11.6; % PEL
	2281	 34.8	 -0.45	 19.65	 -20.55	 0.975	 100.0	 1	 58.0	 11.6; % NG
	2282	 34.8	 -0.1	 12.29	 -12.49	 0.975	 100.0	 1	 58.0	 11.6; % NG
	2283	 34.8	 -0.1	 12.29	 -12.49	 0.975	 100.0	 1	 58.0	 11.6; % NG
	2284	 185.0	 38.885	 166.05	 -88.28	 0.975	 100.0	 1	 250.0	 120.0; % COW
	2286	 83.4	 21.71	 99.9	 -56.48	 0.975	 100.0	 1	 139.0	 27.8; % NG
	2287	 29.4	 4.605	 31.97	 -22.76	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2289	 29.4	 4.57	 31.96	 -22.82	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2290	 29.4	 4.57	 31.96	 -22.82	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2291	 19.2	 2.37	 20.37	 -15.63	 0.975	 100.0	 1	 32.0	 6.4; % PEL
	2292	 19.2	 4.21	 22.21	 -13.79	 0.975	 100.0	 1	 32.0	 6.4; % PEL
	2293	 607.4	 158.255	 546.35	 -229.84	 0.975	 100.0	 1	 942.4	 272.4; % COW
	2294	 571.0	 148.685	 538.05	 -240.68	 0.975	 100.0	 1	 906.0	 236.0; % COW
	2295	 605.39	 144.91	 515.37	 -225.55	 0.975	 100.0	 1	 930.39	 280.39; % COW
	2296	 595.98	 148.13	 519.79	 -223.53	 0.975	 100.0	 1	 920.98	 270.98; % NG
	2297	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % NUC
	2298	 813.0	 218.085	 673.87	 -237.7	 0.975	 100.0	 1	 1308.0	 318.0; % COW
	2299	 21.0	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 7.0; % NG
	2300	 21.0	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 7.0; % PEL
	2301	 21.0	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 7.0; % NG
	2302	 21.0	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 7.0; % NG
	2303	 21.0	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 7.0; % PEL
	2304	 21.0	 1.8	 5.05	 -1.45	 0.975	 100.0	 1	 35.0	 7.0; % NG
	2305	 12.0	 1.615	 10.54	 -7.31	 0.975	 100.0	 1	 20.0	 4.0; % NG
	2306	 12.0	 1.615	 10.54	 -7.31	 0.975	 100.0	 1	 20.0	 4.0; % PEL
	2307	 833.5	 226.955	 703.47	 -249.56	 0.975	 100.0	 1	 1330.0	 337.0; % NUC
	2309	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % COW
	2310	 863.5	 235.535	 712.05	 -240.98	 0.975	 100.0	 1	 1360.0	 367.0; % NUC
	2311	 54.0	 10.005	 53.82	 -33.81	 0.975	 100.0	 1	 90.0	 18.0; % NG
	2312	 0.0	 0.0	 53.63	 -33.27	 0.975	 100.0	 0	 95.0	 19.0; % NG
	2313	 0.0	 0.0	 53.95	 -29.61	 0.975	 100.0	 0	 102.0	 20.4; % NG
	2314	 1.45	 91.015	 285.21	 -103.18	 0.975	 100.0	 1	 1.5	 1.4; % PEL
	2315	 144.0	 39.25	 109.25	 -30.75	 0.975	 100.0	 1	 240.0	 48.0; % NG
	2317	 587.09	 170.56	 500.9	 -159.78	 0.975	 100.0	 1	 942.09	 232.09; % COW
	2318	 549.0	 166.6	 495.92	 -162.72	 0.975	 100.0	 1	 904.0	 194.0; % COW
	2319	 594.12	 189.74	 532.88	 -153.4	 0.975	 100.0	 1	 949.12	 239.12; % COW
	2320	 588.12	 198.365	 551.77	 -155.04	 0.975	 100.0	 1	 943.12	 233.12; % PEL
	2321	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % COW
	2322	 953.0	 217.35	 657.68	 -222.98	 0.975	 100.0	 1	 1503.0	 403.0; % COW
	2323	 948.0	 -28.08	 390.29	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % NUC
	2324	 948.0	 -38.82	 368.81	 -446.45	 0.975	 100.0	 1	 1498.0	 398.0; % COW
	2325	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % NG
	2326	 66.75	 21.35	 93.6	 -50.9	 0.975	 100.0	 1	 125.0	 8.5; % NG
	2327	 76.2	 35.07	 72.7	 -2.56	 0.975	 100.0	 1	 148.2	 4.2; % COW
	2328	 432.5	 138.63	 328.92	 -51.66	 0.975	 100.0	 1	 685.0	 180.0; % NUC
	2329	 460.0	 94.405	 359.66	 -170.85	 0.975	 100.0	 1	 610.0	 310.0; % COW
	2330	 460.0	 55.15	 323.14	 -212.84	 0.975	 100.0	 1	 610.0	 310.0; % COW
	2331	 452.5	 82.085	 380.92	 -216.75	 0.975	 100.0	 1	 700.0	 205.0; % COW
	2332	 10.8	 1.86	 9.86	 -6.14	 0.975	 100.0	 1	 18.0	 3.6; % PEL
	2336	 30.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 10.0; % NG
	2337	 30.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 10.0; % PEL
	2338	 30.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 10.0; % NG
	2339	 30.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 10.0; % NG
	2340	 30.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 10.0; % COW
	2341	 30.0	 3.42	 17.81	 -10.97	 0.975	 100.0	 1	 50.0	 10.0; % NG
	2342	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	2343	 640.0	 196.325	 521.6	 -128.95	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	2344	 640.0	 218.295	 566.43	 -129.84	 0.975	 100.0	 1	 1000.0	 280.0; % COW
	2345	 605.0	 208.07	 565.46	 -149.32	 0.975	 100.0	 1	 930.0	 280.0; % COW
	2346	 34.2	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 11.4; % COW
	2348	 34.2	 4.565	 21.89	 -12.76	 0.975	 100.0	 1	 57.0	 11.4; % NG
	2349	 345.0	 112.365	 320.29	 -95.56	 0.975	 100.0	 1	 451.0	 239.0; % COW
	2350	 42.0	 27.63	 63.51	 -8.25	 0.975	 100.0	 1	 63.0	 21.0; % NG
	2351	 332.5	 48.26	 267.62	 -171.1	 0.975	 100.0	 1	 425.0	 240.0; % NG
	2352	 575.06	 190.56	 530.48	 -149.36	 0.975	 100.0	 1	 920.06	 230.06; % COW
	2353	 575.07	 190.625	 530.55	 -149.3	 0.975	 100.0	 1	 920.07	 230.07; % COW
	2354	 575.04	 190.245	 530.13	 -149.64	 0.975	 100.0	 1	 920.04	 230.04; % COW
	2355	 582.07	 191.95	 531.3	 -147.4	 0.975	 100.0	 1	 927.07	 237.07; % COW
	2356	 19.2	 2.31	 10.38	 -5.76	 0.975	 100.0	 1	 32.0	 6.4; % PEL
	2357	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	2358	 860.0	 -28.245	 407.48	 -463.97	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	2359	 39.0	 7.34	 37.34	 -22.66	 0.975	 100.0	 1	 65.0	 13.0; % PEL
	2360	 42.0	 0.32	 22.34	 -21.7	 0.975	 100.0	 1	 70.0	 14.0; % PEL
	2361	 39.0	 8.95	 53.95	 -36.05	 0.975	 100.0	 1	 65.0	 13.0; % PEL
	2362	 39.0	 10.38	 55.38	 -34.62	 0.975	 100.0	 1	 65.0	 13.0; % PEL
	2363	 42.0	 9.63	 39.63	 -20.37	 0.975	 100.0	 1	 70.0	 14.0; % NG
	2364	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % COW
	2365	 798.0	 36.21	 566.82	 -494.4	 0.975	 100.0	 1	 1308.0	 288.0; % COW
	2367	 0.0	 0.0	 10.52	 -6.96	 0.975	 100.0	 0	 22.0	 4.4; % PEL
	2368	 266.5	 79.385	 281.33	 -122.56	 0.975	 100.0	 1	 451.0	 82.0; % COW
	2369	 21.6	 -1.11	 10.34	 -12.56	 0.975	 100.0	 1	 36.0	 7.2; % COW
	2370	 21.6	 -1.11	 10.34	 -12.56	 0.975	 100.0	 1	 36.0	 7.2; % PEL
	2371	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % NUC
	2372	 607.0	 190.895	 527.89	 -146.1	 0.975	 100.0	 1	 947.0	 267.0; % COW
	2373	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	2374	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	2375	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % COW
	2376	 592.0	 189.94	 525.98	 -146.1	 0.975	 100.0	 1	 947.0	 237.0; % NG
	2377	 182.5	 60.46	 132.48	 -11.56	 0.975	 100.0	 1	 240.0	 125.0; % NG
	2378	 326.0	 63.21	 262.39	 -135.97	 0.975	 100.0	 1	 446.0	 206.0; % NG
	2379	 175.0	 25.245	 155.36	 -104.87	 0.975	 100.0	 1	 230.0	 120.0; % NG
	2380	 417.5	 77.205	 280.73	 -126.32	 0.975	 100.0	 1	 585.0	 250.0; % COW
	2381	 439.5	 94.165	 297.58	 -109.25	 0.975	 100.0	 1	 607.0	 272.0; % COW
	2382	 34.2	 12.66	 32.55	 -7.23	 0.975	 100.0	 1	 57.0	 11.4; % NG
	2383	 34.2	 12.66	 32.55	 -7.23	 0.975	 100.0	 1	 57.0	 11.4; % PEL
	2385	 18.6	 6.455	 20.13	 -7.22	 0.975	 100.0	 1	 31.0	 6.2; % NG
	2386	 18.6	 5.97	 33.89	 -21.95	 0.975	 100.0	 1	 31.0	 6.2; % NG
	2388	 11.7	 1.46	 7.83	 -4.91	 0.975	 100.0	 1	 19.5	 3.9; % NG
	2389	 0.0	 0.0	 8.32	 -5.51	 0.975	 100.0	 0	 21.0	 4.2; % COW
	2390	 21.0	 -0.555	 6.13	 -7.24	 0.975	 100.0	 1	 35.0	 7.0; % PEL
	2391	 21.0	 -0.555	 6.13	 -7.24	 0.975	 100.0	 1	 35.0	 7.0; % PEL
	2392	 21.0	 -0.15	 11.43	 -11.73	 0.975	 100.0	 1	 35.0	 7.0; % NG
	2393	 21.0	 -0.555	 6.13	 -7.24	 0.975	 100.0	 1	 35.0	 7.0; % COW
	2394	 177.5	 -0.51	 112.63	 -113.65	 0.975	 100.0	 1	 235.0	 120.0; % NG
	2395	 28.2	 3.06	 10.25	 -4.13	 0.975	 100.0	 1	 47.0	 9.4; % NG
	2396	 28.2	 3.06	 10.25	 -4.13	 0.975	 100.0	 1	 47.0	 9.4; % NG
	2397	 43.8	 10.17	 51.92	 -31.58	 0.975	 100.0	 1	 73.0	 14.6; % PEL
	2398	 41.4	 13.355	 55.2	 -28.49	 0.975	 100.0	 1	 69.0	 13.8; % NG
	2399	 45.6	 11.28	 51.28	 -28.72	 0.975	 100.0	 1	 76.0	 15.2; % PEL
	2400	 46.5	 10.505	 51.13	 -30.12	 0.975	 100.0	 1	 77.5	 15.5; % PEL
	2401	 18.6	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 6.2; % NG
	2402	 18.6	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 6.2; % NG
	2403	 18.6	 2.14	 14.95	 -10.67	 0.975	 100.0	 1	 31.0	 6.2; % PEL
	2404	 30.0	 8.08	 31.73	 -15.57	 0.975	 100.0	 1	 50.0	 10.0; % NG
	2409	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % NG
	2410	 193.5	 68.455	 170.47	 -33.56	 0.975	 100.0	 1	 250.0	 137.0; % COW
	2411	 11.4	 1.75	 10.62	 -7.12	 0.975	 100.0	 1	 19.0	 3.8; % PEL
	2412	 11.4	 1.75	 10.62	 -7.12	 0.975	 100.0	 1	 19.0	 3.8; % PEL
	2413	 69.0	 9.185	 75.67	 -57.3	 0.975	 100.0	 1	 115.0	 23.0; % NG
	2414	 69.0	 9.185	 75.67	 -57.3	 0.975	 100.0	 1	 115.0	 23.0; % NG
	2415	 73.2	 8.23	 25.64	 -9.18	 0.975	 100.0	 1	 122.0	 24.4; % NG
	2416	 305.0	 23.34	 211.59	 -164.91	 0.975	 100.0	 1	 414.0	 196.0; % NG
	2417	 31.2	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 10.4; % NG
	2418	 31.2	 10.215	 39.82	 -19.39	 0.975	 100.0	 1	 52.0	 10.4; % NG
	2419	 95.0	 40.425	 104.23	 -23.38	 0.975	 100.0	 1	 185.0	 5.0; % NG
	2420	 95.0	 40.425	 104.23	 -23.38	 0.975	 100.0	 1	 185.0	 5.0; % NG
	2422	 136.2	 69.86	 195.98	 -56.26	 0.975	 100.0	 1	 227.0	 45.4; % NG
	2423	 136.2	 69.86	 195.98	 -56.26	 0.975	 100.0	 1	 227.0	 45.4; % NG
	2424	 136.2	 69.955	 196.08	 -56.17	 0.975	 100.0	 1	 227.0	 45.4; % NG
	2425	 39.0	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 13.0; % NG
	2426	 39.0	 12.59	 79.87	 -54.69	 0.975	 100.0	 1	 65.0	 13.0; % PEL
	2427	 593.5	 165.99	 511.82	 -179.84	 0.975	 100.0	 1	 950.0	 237.0; % NG
	2428	 593.5	 193.685	 533.7	 -146.33	 0.975	 100.0	 1	 950.0	 237.0; % PEL
	2429	 230.0	 19.125	 191.0	 -152.75	 0.975	 100.0	 1	 304.0	 156.0; % NG
	2430	 149.0	 42.4	 179.42	 -94.62	 0.975	 100.0	 1	 191.0	 107.0; % COW
	2431	 242.0	 25.665	 197.29	 -145.96	 0.975	 100.0	 1	 316.0	 168.0; % NG
	2432	 824.5	 229.315	 671.92	 -213.29	 0.975	 100.0	 1	 1360.0	 289.0; % COW
	2434	 36.6	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 12.2; % NG
	2435	 36.6	 2.34	 28.9	 -24.22	 0.975	 100.0	 1	 61.0	 12.2; % NG
	2436	 21.0	 6.57	 23.24	 -10.1	 0.975	 100.0	 1	 35.0	 7.0; % NG
	2437	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % NUC
	2438	 865.0	 235.84	 706.84	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % NG
	2439	 865.0	 230.335	 695.83	 -235.16	 0.975	 100.0	 1	 1380.0	 350.0; % NG
	2440	 820.0	 210.31	 681.31	 -260.69	 0.975	 100.0	 1	 1290.0	 350.0; % COW
	2441	 25.9	 13.51	 37.51	 -10.49	 0.975	 100.0	 1	 51.0	 0.8; % NG
	2442	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	2443	 860.0	 234.135	 675.48	 -207.21	 0.975	 100.0	 1	 1380.0	 340.0; % COW
	2444	 380.0	 111.02	 322.12	 -100.08	 0.975	 100.0	 1	 585.0	 175.0; % NG
	2445	 380.0	 111.02	 322.12	 -100.08	 0.975	 100.0	 1	 585.0	 175.0; % NG
	2446	 380.0	 111.02	 322.12	 -100.08	 0.975	 100.0	 1	 585.0	 175.0; % COW
	2447	 380.0	 101.275	 311.95	 -109.4	 0.975	 100.0	 1	 585.0	 175.0; % COW
	2449	 25.8	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 8.6; % NG
	2450	 25.8	 6.31	 33.11	 -20.49	 0.975	 100.0	 1	 43.0	 8.6; % NG
	2452	 42.0	 27.06	 78.5	 -24.38	 0.975	 100.0	 1	 70.0	 14.0; % PEL
	2453	 0.0	 0.0	 42.66	 -21.78	 0.975	 100.0	 0	 80.0	 16.0; % NG
	2454	 150.0	 15.99	 107.83	 -75.85	 0.975	 100.0	 1	 230.0	 70.0; % NG
	2455	 450.0	 57.26	 230.47	 -115.95	 0.975	 100.0	 1	 605.0	 295.0; % COW
	2457	 33.6	 4.12	 24.74	 -16.5	 0.975	 100.0	 1	 56.0	 11.2; % PEL
	2458	 0.0	 0.0	 61.2	 -1.88	 0.975	 100.0	 0	 58.0	 11.6; % NG
	2459	 13.86	 3.15	 17.15	 -10.85	 0.975	 100.0	 1	 23.1	 4.62; % NG
	2460	 13.86	 3.14	 17.14	 -10.86	 0.975	 100.0	 1	 23.1	 4.62; % PEL
	2461	 324.5	 71.865	 159.05	 -15.32	 0.975	 100.0	 1	 429.0	 220.0; % COW
	2462	 24.6	 2.215	 21.74	 -17.31	 0.975	 100.0	 1	 41.0	 8.2; % NG
	2463	 48.0	 5.695	 18.02	 -6.63	 0.975	 100.0	 1	 80.0	 16.0; % COW
	2464	 48.0	 5.695	 18.02	 -6.63	 0.975	 100.0	 1	 80.0	 16.0; % NG
	2465	 48.0	 5.695	 18.02	 -6.63	 0.975	 100.0	 1	 80.0	 16.0; % NG
	2466	 19.2	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2467	 19.2	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2468	 19.2	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2469	 19.2	 4.57	 19.57	 -10.43	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2470	 108.0	 22.435	 124.73	 -79.86	 0.975	 100.0	 1	 180.0	 36.0; % NG
	2471	 108.0	 13.035	 116.01	 -89.94	 0.975	 100.0	 1	 180.0	 36.0; % NG
	2473	 108.0	 22.435	 124.73	 -79.86	 0.975	 100.0	 1	 180.0	 36.0; % COW
	2474	 19.2	 4.095	 27.25	 -19.06	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2475	 19.2	 4.095	 27.25	 -19.06	 0.975	 100.0	 1	 32.0	 6.4; % PEL
	2477	 19.2	 4.095	 27.25	 -19.06	 0.975	 100.0	 1	 32.0	 6.4; % PEL
	2478	 19.2	 4.095	 27.25	 -19.06	 0.975	 100.0	 1	 32.0	 6.4; % NG
	2481	 26.4	 4.315	 14.64	 -6.01	 0.975	 100.0	 1	 44.0	 8.8; % NG
	2482	 18.6	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 6.2; % PEL
	2483	 18.6	 2.94	 19.26	 -13.38	 0.975	 100.0	 1	 31.0	 6.2; % COW
	2484	 0.0	 0.0	 27.02	 -18.3	 0.975	 100.0	 0	 38.0	 7.6; % NG
	2485	 0.0	 0.0	 26.96	 -18.51	 0.975	 100.0	 0	 38.0	 7.6; % NG
	2486	 0.0	 0.0	 26.96	 -18.51	 0.975	 100.0	 0	 38.0	 7.6; % NG
	2487	 0.0	 0.0	 41.08	 -25.63	 0.975	 100.0	 0	 66.0	 13.2; % PEL
	2489	 50.4	 15.305	 54.62	 -24.01	 0.975	 100.0	 1	 84.0	 16.8; % COW
	2490	 0.0	 0.0	 26.24	 -3.76	 0.975	 100.0	 0	 33.0	 6.6; % NG
	2491	 0.0	 0.0	 26.24	 -3.76	 0.975	 100.0	 0	 33.0	 6.6; % NG
	2493	 48.6	 11.12	 51.12	 -28.88	 0.975	 100.0	 1	 81.0	 16.2; % NG
	2494	 48.6	 11.12	 51.12	 -28.88	 0.975	 100.0	 1	 81.0	 16.2; % NG
	2496	 78.0	 6.33	 30.84	 -18.18	 0.975	 100.0	 1	 130.0	 26.0; % COW
	2497	 78.0	 6.33	 30.84	 -18.18	 0.975	 100.0	 1	 130.0	 26.0; % NG
	2498	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % COW
	2499	 807.0	 215.91	 671.48	 -239.66	 0.975	 100.0	 1	 1332.0	 282.0; % COW
	2500	 217.5	 91.59	 168.9	 14.28	 0.975	 100.0	 1	 285.0	 150.0; % NG
	2501	 410.0	 53.715	 204.97	 -97.54	 0.975	 100.0	 1	 595.0	 225.0; % COW
	2502	 278.0	 128.115	 307.19	 -50.96	 0.975	 100.0	 1	 436.0	 120.0; % NG
	2503	 285.0	 131.285	 310.33	 -47.76	 0.975	 100.0	 1	 443.0	 127.0; % NG
	2504	 30.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 10.0; % NG
	2505	 30.0	 1.74	 27.73	 -24.25	 0.975	 100.0	 1	 50.0	 10.0; % NG
	2507	 29.4	 5.365	 32.52	 -21.79	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2508	 29.4	 5.365	 32.52	 -21.79	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2509	 0.0	 0.0	 21.62	 -13.24	 0.975	 100.0	 0	 30.0	 6.0; % NG
	2510	 0.0	 0.0	 21.62	 -13.24	 0.975	 100.0	 0	 30.0	 6.0; % PEL
	2511	 51.0	 19.785	 57.42	 -17.85	 0.975	 100.0	 1	 85.0	 17.0; % NG
	2512	 56.5	 17.585	 50.12	 -14.95	 0.975	 100.0	 1	 58.0	 55.0; % PEL
	2513	 590.09	 194.825	 541.66	 -152.01	 0.975	 100.0	 1	 950.09	 230.09; % COW
	2514	 593.09	 195.405	 541.94	 -151.13	 0.975	 100.0	 1	 953.09	 233.09; % COW
	2515	 29.4	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2516	 29.4	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2517	 29.4	 0.785	 21.77	 -20.2	 0.975	 100.0	 1	 49.0	 9.8; % NG
	2519	 96.6	 34.06	 114.06	 -45.94	 0.975	 100.0	 1	 161.0	 32.2; % COW
	2520	 96.6	 34.06	 114.06	 -45.94	 0.975	 100.0	 1	 161.0	 32.2; % NG
	2521	 96.6	 34.06	 114.06	 -45.94	 0.975	 100.0	 1	 161.0	 32.2; % PEL
	2523	 93.6	 32.39	 112.39	 -47.61	 0.975	 100.0	 1	 156.0	 31.2; % NG
	2524	 59.4	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 19.8; % NG
	2525	 59.4	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 19.8; % NG
	2526	 59.4	 -5.525	 22.91	 -33.96	 0.975	 100.0	 1	 99.0	 19.8; % NG
	2527	 630.0	 121.775	 405.58	 -162.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	2528	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	2529	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	2530	 630.0	 116.775	 400.58	 -167.03	 0.975	 100.0	 1	 985.0	 275.0; % COW
	2531	 128.5	 37.945	 102.61	 -26.72	 0.975	 100.0	 1	 185.0	 72.0; % NG
	2532	 128.5	 38.895	 102.61	 -24.82	 0.975	 100.0	 1	 185.0	 72.0; % NG
	2533	 128.5	 38.895	 102.61	 -24.82	 0.975	 100.0	 1	 185.0	 72.0; % NG
	2534	 185.0	 21.005	 138.09	 -96.08	 0.975	 100.0	 1	 250.0	 120.0; % NG
	2535	 203.0	 30.365	 148.09	 -87.36	 0.975	 100.0	 1	 268.0	 138.0; % NG
	2536	 108.0	 27.8	 97.8	 -42.2	 0.975	 100.0	 1	 180.0	 36.0; % NG
	2537	 81.6	 43.88	 133.88	 -46.12	 0.975	 100.0	 1	 136.0	 27.2; % COW
	2538	 76.8	 38.95	 123.95	 -46.05	 0.975	 100.0	 1	 128.0	 25.6; % COW
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	 100.986309	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.418079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.731394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.126035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.340287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.157194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.418605	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.635175	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.477929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.758944	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.818052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.333846	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.779420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.295674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.867529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.253779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.445017	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.926541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.340211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.973259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.940298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.906810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.093264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.543830	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.291874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.235693	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.167192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.772694	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.990006	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 102.341460	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.505422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.515642	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.166394	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.320443	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.243026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.237882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.171172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.516359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.060991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.340325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.769345	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.207211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.478299	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.644824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.143841	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.063488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.182536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.548887	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.399391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.433671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.380824	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.912049	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.061768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.311460	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.029694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.513096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.586535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.894607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 124.367340	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.320279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.140314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 123.799005	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.753605	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.961544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.879704	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.715142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.499876	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.650617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.596802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.909977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.435424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.250727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.966272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.089052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.705389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.847894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.254106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.851280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.104855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.440906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.870503	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  99.615888	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.192109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.748848	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.935647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.368275	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.812461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.571958	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 124.160569	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.716137	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.257074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.460880	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.089036	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.477694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.383190	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.821409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.695354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.888638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.684211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.839319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.083296	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 109.526673	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.835643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  63.494909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.994004	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.183185	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.344595	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.691496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.721503	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.788956	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.181650	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.443975	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.244939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.602296	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.589169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.113517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.089435	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  91.627137	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.180830	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.928989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.284540	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.075438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.387833	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.628779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.501955	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.562901	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.484077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.937162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.889690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  96.773902	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.201864	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 108.810518	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.646300	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.061063	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.152033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.556339	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.296792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.178986	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.131836	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 118.557785	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 142.759395	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.901832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.480176	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.619924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.844586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.816217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.602479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.533932	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.444523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.036512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.583074	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.383994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 126.780352	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.111267	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.883940	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.122404	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.746253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.735244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.971493	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.759241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.031202	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.530524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.562956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.663453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.598730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.774356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.799318	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.901715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.100556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  96.041267	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.274763	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  63.988407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.768817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.342247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.857844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.249181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.143849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.920347	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.840875	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.032186	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.187520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.584963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.901507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.975670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.195377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.180191	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.670246	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.018768	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.665173	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.104826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.544082	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.645314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 104.850363	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  25.705133	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.459884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.383320	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.400378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.728787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.664613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.272563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.428353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.832694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.947300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.855382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.116260	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.393596	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 130.711785	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.457778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.741987	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.223636	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.631639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.473348	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.089549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.094348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.996921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.983215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.449773	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.589481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.715154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.377622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.836583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.937031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.344084	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.762448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.161431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.891094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.981634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.764626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.874321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.563346	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.394093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  87.080070	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  87.695889	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.350130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.036990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.019537	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.882277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.329046	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.098854	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.931894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.587304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.669796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.253786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.099499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.296199	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  49.331497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.221724	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.073647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.652823	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.410029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.289699	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.883835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.203485	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.895089	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.843169	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.071138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.832238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.537064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.915580	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.784071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.421522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.796049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.756280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.002725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.599303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.071141	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.981604	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  93.317250	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.834977	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.900839	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.625531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.122433	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.762162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.176367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.223137	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 107.528266	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  96.850228	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 112.471150	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.846817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.028243	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.965389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.571794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.257918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.163822	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.098303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.289679	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.600588	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.624036	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.103686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.435900	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.192786	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.151308	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 118.727009	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 128.306953	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.425294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.728136	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.377733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.965398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  98.527676	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.310663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.895355	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 119.195197	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.796012	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.443637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.098722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.276695	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.268587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.807243	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  41.616122	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.047431	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.860837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.308800	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.355403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.788992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.802273	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.629472	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  38.296032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.759291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.711049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.309132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.785435	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 126.707953	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.057076	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 110.452270	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.681204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.944613	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.425371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.243670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.593906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.770428	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.742455	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.056277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.693826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.081294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.383553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.874806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.334756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.690820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.400831	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.367083	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.319166	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 119.989552	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.796031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.042034	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.804028	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.301525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.260473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.848152	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.151775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.733847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.929060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.266377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.908062	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.916402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.443712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.815382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.619617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.254187	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.307395	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.565229	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.678373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.985110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.686717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.418764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.949824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.153400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.018559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.841600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.090996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.450483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.511483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.034546	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.246371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.973064	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.701994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.430179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.395974	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  93.061261	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  13.050471	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.635102	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.299827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.900133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.945770	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  17.996361	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.839918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.038379	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.290240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.891710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.837330	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.046228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.916832	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.539396	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   6.559836	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  30.702513	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.938853	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.784523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.645954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.133366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.666506	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.880481	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.362294	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.736416	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.186928	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 101.153125	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.703137	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.990705	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.498585	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.886050	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.201361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.433357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.495197	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.725986	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.196845	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.618117	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.020252	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 122.229810	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.648898	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.709333	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.846287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.731056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.938890	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.785578	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.419784	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.423983	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.954435	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.196316	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.360659	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.064323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.843237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.421555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.100085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.365850	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.748567	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.268710	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.914006	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  97.912500	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.833146	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.473331	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 121.740063	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 113.420562	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.580220	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  94.217732	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.698246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.561679	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.158654	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 121.432439	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.492519	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.349755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 133.672098	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   6.943882	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.241013	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.083621	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.776675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.851556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.787881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.219617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.005053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.853599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.508535	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.403003	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.002772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.825418	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.283472	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.364211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.255971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.653192	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 123.099946	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 120.170840	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  35.610693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.795050	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.223878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.847488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.006494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.181684	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.327720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.099600	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 105.747874	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.918655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.321836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.604651	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.865173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.204386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.274765	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.316420	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.048379	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.399342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.703723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.439776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.969476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.497929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.257507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.042867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.278783	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.951022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.909886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.642360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.274624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.367023	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.603805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.196649	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.061903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.372860	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.021693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.655353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.169556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.873227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.608564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.228595	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.411159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.697422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.341771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.098347	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.329585	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.427629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.203369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.988465	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.288498	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.906166	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.076215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.164736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 132.084427	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.350651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.075035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.496496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.969765	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.794085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.310013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.270459	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.440712	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.077255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.408525	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.559950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.252935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.181068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.617784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.230990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.824550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.245695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.532251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.858624	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.974657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.066622	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.403891	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.477160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.418815	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  93.726480	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.050457	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.383322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.614579	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.939066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.589972	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.182405	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.111235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.948427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.679278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.771170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.375940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.655593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.636115	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.989790	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.836241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.386553	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.074593	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.887359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.616580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.567106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.467536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.972660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.066888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.409393	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  50.719393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.776329	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  28.863981	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.970154	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.538052	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.221956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  68.636420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.545785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.182829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.412377	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.137011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.328544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.588947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.183199	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.091830	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.333761	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.872749	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.929628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.669721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.166759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.607127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.206682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.937307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.707469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.060924	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.028374	   0.000000; % COW
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	639	 1	 0.005799	 0.010615	 0.0075	 2441	 2441	 2441	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 2	 0.002607	 0.017462	 0.0324	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 3	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	875	 3	 0.000145	 0.001877	 0.0635	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 3	 0.000319	 0.003234	 0.0838	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 3	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 4	 0.037541	 0.100529	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 4	 0.090199	 0.211388	 0.0023	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	1658	 4	 0.09801	 0.267574	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	1370	 5	 0.009383	 0.019753	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	1370	 6	 0.001975	 0.004444	 0.0	 5369	 5369	 5369	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 7	 0.006163	 0.041067	 0.0759	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 7	 0.000652	 0.004369	 0.0081	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 8	 0.067019	 0.137566	 0.0037	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 8	 0.032754	 0.088939	 0.0039	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 8	 0.030184	 0.080096	 0.0053	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	1371	 10	 0.009733	 0.034089	 0.0185	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	147	 11	 0.000277	 0.002015	 0.003	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	387	 2571	 0.00881	 0.033995	 0.0607	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	437	 2571	 0.004642	 0.019832	 0.0354	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 11	 0.008861	 0.03506	 0.0623	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 11	 0.006993	 0.032869	 0.0557	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1774	 2571	 0.002173	 0.008731	 0.0152	 3441	 3441	 3441	 0.0	 0.0	 1	 -30.0	 30.0;
	1817	 11	 0.00077	 0.003121	 0.0051	 9629	 9629	 9629	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 2571	 0.004109	 0.016138	 0.0284	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 12	 8.3e-05	 0.000907	 0.0202	 1034.0	 1034.0	 1034.0	 0.0	 0.0	 1	 -30.0	 30.0;
	419	 12	 0.000552	 0.006726	 0.0939	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 12	 0.000512	 0.008012	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 12	 0.001107	 0.00918	 0.1906	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 2572	 6.2e-05	 0.000741	 0.0173	 1095.0	 1095.0	 1095.0	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 12	 0.000512	 0.008019	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 2572	 0.001153	 0.013123	 0.1841	 1433.0	 1433.0	 1433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	167	 13	 0.000158	 0.000672	 0.0719	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 13	 4.5e-05	 8.9e-05	 0.002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 14	 0.033258	 0.090955	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	465	 15	 0.071303	 0.180902	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	878	 15	 0.071554	 0.18191	 0.0021	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 16	 0.00478	 0.028622	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	451	 16	 0.00478	 0.028583	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	151	 17	 0.000257	 0.000514	 0.0294	 53862	 53862	 53862	 0.0	 0.0	 1	 -30.0	 30.0;
	987	 18	 0.000257	 0.002153	 0.2147	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 18	 0.000277	 0.000869	 0.0931	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 19	 0.000756	 0.00252	 0.0	 11716	 11716	 11716	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 20	 0.000237	 0.00083	 0.1863	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 20	 0.000178	 0.000612	 0.1377	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 21	 0.002568	 0.011753	 0.0203	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1908	 21	 0.002568	 0.011615	 0.0228	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 22	 0.102293	 0.226757	 0.0025	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	855	 22	 0.177551	 0.405291	 0.0046	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 22	 0.088264	 0.161566	 0.0017	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 23	 0.043336	 0.11867	 0.001	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 23	 0.067775	 0.139834	 0.001	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	1691	 23	 0.047367	 0.16125	 0.0021	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 23	 0.004031	 0.016629	 0.001	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 24	 9.9e-05	 0.00077	 0.078	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 2573	 9.9e-05	 0.00077	 0.077	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1908	 25	 0.000514	 0.003437	 0.0061	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 25	 0.005476	 0.036879	 0.1255	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 25	 0.000514	 0.003457	 0.0061	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 26	 0.003477	 0.01118	 0.0187	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 26	 0.000612	 0.003121	 0.0152	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 27	 0.013857	 0.035525	 0.0004	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 28	 2.4e-05	 0.000144	 0.0213	 701.0	 701.0	 701.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 2574	 7.1e-05	 0.000162	 0.0162	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	249	 29	 0.068027	 0.173091	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 29	 0.027211	 0.068783	 0.001	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 29	 0.03099	 0.202822	 0.002	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 30	 0.000257	 0.001165	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1906	 31	 0.047317	 0.131595	 0.0015	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 32	 0.075838	 0.224742	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 32	 0.028471	 0.089695	 0.001	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 32	 0.080373	 0.255732	 0.003	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	2050	 32	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1907	 33	 0.000444	 0.001136	 0.0	 21404	 21404	 21404	 0.0	 0.0	 1	 -30.0	 30.0;
	1370	 34	 0.057284	 0.130864	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 35	 0.054749	 0.157445	 0.0027	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 35	 0.038549	 0.103049	 0.0012	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 35	 0.012598	 0.052406	 0.0006	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 36	 0.006914	 0.020741	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 37	 0.032124	 0.082892	 0.003	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 37	 0.025573	 0.09869	 0.0012	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 38	 0.001512	 0.005291	 0.0064	 5495	 5495	 5495	 0.0	 0.0	 1	 -30.0	 30.0;
	637	 39	 0.005709	 0.037926	 0.0688	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 39	 0.001758	 0.011654	 0.0208	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2585	 40	 0.001383	 0.009462	 0.0172	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	593	 40	 0.00156	 0.006933	 0.0121	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 40	 0.006376	 0.028733	 0.0506	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 40	 0.00158	 0.010627	 0.0192	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 41	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 41	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 42	 0.04059	 0.110708	 0.0013	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	248	 42	 0.073646	 0.225598	 0.0087	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 42	 0.02066	 0.088687	 0.0021	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 42	 0.019904	 0.08516	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	1935	 42	 0.014361	 0.068027	 0.0035	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	1770	 42	 0.059209	 0.150164	 0.0021	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 43	 0.004741	 0.020385	 0.0334	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 43	 0.009027	 0.048869	 0.084	 351.0	 351.0	 351.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 43	 0.003516	 0.016257	 0.0273	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 44	 0.059461	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 44	 0.146384	 0.373394	 0.0051	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 45	 0.000514	 0.003417	 0.0278	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 45	 0.001084	 0.007198	 0.0132	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1955	 45	 0.000523	 0.002436	 0.0167	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 45	 0.000514	 0.003457	 0.0203	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 45	 0.001086	 0.007249	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 45	 0.000553	 0.002469	 0.0157	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 45	 0.001086	 0.007269	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 47	 0.016125	 0.068279	 0.0081	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	1699	 47	 0.059209	 0.150416	 0.0021	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 47	 0.016125	 0.068279	 0.0081	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 48	 0.102293	 0.245906	 0.0027	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 48	 0.036533	 0.088435	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 49	 0.019148	 0.081381	 0.0012	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	1585	 49	 0.02318	 0.04258	 0.0006	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 49	 0.002268	 0.022424	 0.0002	 1314	 1314	 1314	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 2576	 0.012094	 0.030486	 0.0004	 901	 901	 901	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 2576	 0.03351	 0.088435	 0.001	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 2576	 0.00252	 0.02066	 0.0002	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 50	 0.001837	 0.011694	 0.0759	 467.0	 467.0	 467.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1256	 50	 0.001067	 0.007131	 0.0132	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 50	 0.001284	 0.008593	 0.0152	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 50	 0.001284	 0.008593	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2895	 50	 0.001284	 0.008533	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 51	 0.000494	 0.000928	 0.0699	 29203	 29203	 29203	 0.0	 0.0	 1	 -30.0	 30.0;
	434	 51	 0.000184	 0.00159	 0.1661	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 51	 0.000198	 0.001711	 0.1711	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 51	 0.000751	 0.003358	 0.1534	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	450	 52	 0.000178	 0.001047	 0.1499	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 2942	 0.000119	 0.000474	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 52	 0.000316	 0.002232	 0.2774	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2603	 53	 0.047115	 0.108088	 0.0031	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 53	 0.036281	 0.154195	 0.0037	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	1686	 54	 0.037227	 0.106836	 0.0328	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 54	 0.006089	 0.020756	 0.0067	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 55	 0.000729	 0.005118	 0.0933	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 55	 0.000755	 0.005235	 0.0909	 419.0	 419.0	 419.0	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 56	 0.001787	 0.01946	 0.4214	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 57	 0.001719	 0.00877	 0.0157	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 57	 0.009165	 0.04318	 0.077	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 59	 0.004879	 0.032454	 0.0602	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 59	 0.006341	 0.042746	 0.0785	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	284	 59	 0.006914	 0.031249	 0.0547	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	396	 60	 0.000582	 0.007652	 0.2643	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 60	 0.001648	 0.021634	 0.748	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 60	 0.000838	 0.014301	 0.5198	 2229	 2229	 2229	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 60	 0.001163	 0.015312	 0.5285	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	396	 60	 0.000575	 0.007576	 0.2614	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 60	 0.001646	 0.021633	 0.7479	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 60	 0.000838	 0.014287	 0.5198	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 60	 0.00117	 0.015339	 0.5285	 2074	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 60	 0.001821	 0.017874	 0.4318	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 61	 0.003023	 0.01159	 0.0002	 2466	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 63	 0.070043	 0.190728	 0.0021	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 2577	 0.110103	 0.294533	 0.004	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 63	 0.034014	 0.145629	 0.0018	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 2577	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 64	 0.000672	 0.003477	 0.0365	 254.0	 254.0	 254.0	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 66	 0.138123	 0.332	 0.001	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	1773	 2578	 0.000988	 0.003457	 0.0	 7261	 7261	 7261	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 66	 0.008395	 0.02321	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 67	 0.000632	 0.004188	 0.0081	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 2579	 0.000612	 0.004148	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 69	 0.000672	 0.004405	 0.0081	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 69	 0.000968	 0.004602	 0.0081	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 69	 0.000632	 0.004444	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 70	 0.001975	 0.013215	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 70	 0.001956	 0.013037	 0.0243	 2348	 2348	 2348	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 71	 0.002933	 0.010267	 0.0032	 3007	 3007	 3007	 0.0	 0.0	 1	 -30.0	 30.0;
	1911	 71	 0.0028	 0.007511	 0.0022	 4006	 4006	 4006	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 2580	 2e-05	 0.000198	 0.0121	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 72	 2e-05	 0.000198	 0.0142	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	377	 74	 0.000277	 0.000928	 0.2066	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 74	 0.002037	 0.010904	 0.0187	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 74	 0.000415	 0.002015	 0.1266	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 74	 0.000395	 0.00156	 0.1893	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 74	 4e-05	 0.000178	 0.0152	 169660	 169660	 169660	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 74	 0.001323	 0.012444	 0.0678	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1631	 74	 0.000454	 0.002133	 0.2511	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 74	 0.000119	 0.000691	 0.1002	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1886	 74	 0.00083	 0.005175	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	377	 74	 0.000277	 0.000928	 0.2086	 31961	 31961	 31961	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 74	 0.001314	 0.012115	 0.0673	 943.0	 943.0	 943.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 74	 5.9e-05	 0.000217	 0.0496	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1853	 74	 5.9e-05	 0.000217	 0.0466	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1640	 75	 0.000854	 0.001563	 0.0007	 16578	 16578	 16578	 0.0	 0.0	 1	 -30.0	 30.0;
	1909	 76	 0.000494	 0.000988	 0.0	 23633	 23633	 23633	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 77	 0.062232	 0.138574	 0.0015	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 77	 0.035525	 0.084782	 0.0009	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 78	 0.000158	 0.000948	 0.002	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 79	 0.035273	 0.218443	 0.0029	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	210	 79	 0.000252	 0.000504	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	354	 79	 0.034442	 0.11809	 0.0091	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 79	 0.034266	 0.221466	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 80	 0.0839	 0.229025	 0.0025	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	667	 80	 0.048627	 0.123205	 0.0014	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	903	 81	 0.001521	 0.007076	 0.0118	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 81	 0.002469	 0.011457	 0.0203	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	524	 82	 0.001442	 0.009699	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 82	 0.001422	 0.009541	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 83	 0.024691	 0.056941	 0.001	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 83	 0.0194	 0.038549	 0.0033	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 84	 0.004681	 0.028227	 0.0516	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 84	 0.001185	 0.008	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2103	 84	 0.005333	 0.02722	 0.0491	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 85	 0.000145	 0.001911	 0.0661	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 85	 0.000253	 0.003323	 0.1148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 86	 0.018645	 0.041068	 0.0005	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 86	 0.049131	 0.124465	 0.0014	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 86	 0.02192	 0.091207	 0.0011	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	205	 87	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	205	 87	 0.015117	 0.039808	 0.0005	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 88	 0.004787	 0.018141	 0.0002	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 2581	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	1807	 89	 0.007055	 0.020408	 0.0002	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 2581	 0.003779	 0.020912	 0.0028	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 2582	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 90	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 91	 0.004563	 0.030696	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 91	 0.009857	 0.04478	 0.077	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 91	 0.017106	 0.078321	 0.1387	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 91	 0.010272	 0.048691	 0.0866	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 92	 0.012978	 0.059338	 0.1002	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 92	 0.01197	 0.056632	 0.0942	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1911	 93	 0.000578	 0.001156	 0.0004	 24845	 24845	 24845	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 94	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 2583	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 95	 0.000277	 0.000573	 0.0334	 48541	 48541	 48541	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 96	 0.001055	 0.004836	 0.0081	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 97	 0.056437	 0.160242	 0.0019	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 97	 0.050894	 0.146384	 0.0017	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 98	 0.002114	 0.008553	 0.0152	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 99	 0.000158	 0.000652	 0.084	 46138	 46138	 46138	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 2584	 0.000198	 0.000731	 0.0942	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 100	 0.00324	 0.012616	 0.0225	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 101	 0.007522	 0.029736	 0.0496	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 101	 0.006809	 0.03043	 0.0521	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	524	 2585	 0.002153	 0.014736	 0.0273	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2687	 102	 0.000581	 0.003838	 0.0071	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 102	 0.001857	 0.020306	 0.0557	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 2585	 0.002331	 0.015526	 0.0278	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 102	 0.001345	 0.008968	 0.0162	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	625	 102	 0.000573	 0.003911	 0.0071	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 102	 0.001896	 0.012701	 0.0233	 501.0	 501.0	 501.0	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 103	 0.000602	 0.006717	 0.1357	 1725.0	 1725.0	 1725.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 103	 0.00063	 0.007098	 0.1588	 1916.0	 1916.0	 1916.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 103	 0.000367	 0.004631	 0.1126	 2275.0	 2275.0	 2275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 103	 0.000472	 0.006201	 0.2137	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 103	 0.001504	 0.019298	 0.4577	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 2586	 0.000158	 0.001106	 0.1357	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	485	 104	 0.000219	 0.00193	 0.1954	 407.0	 407.0	 407.0	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 104	 0.000158	 0.000909	 0.1316	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1286	 104	 0.000411	 0.00356	 0.3564	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 2586	 0.000158	 0.001264	 0.1286	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	714	 105	 0.045855	 0.121189	 0.0013	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	984	 105	 0.064248	 0.156211	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 106	 0.000198	 0.001383	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 2587	 0.000217	 0.001402	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	541	 107	 0.036029	 0.091711	 0.001	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 107	 0.018896	 0.047367	 0.0008	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 107	 0.003427	 0.009272	 0.0121	 2987	 2987	 2987	 0.0	 0.0	 1	 -30.0	 30.0;
	1808	 107	 0.006299	 0.018392	 0.0164	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 107	 0.017637	 0.044092	 0.0008	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	2140	 107	 0.046273	 0.084703	 0.0015	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 107	 0.00383	 0.008869	 0.0143	 3057	 3057	 3057	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 108	 0.001304	 0.008691	 0.0152	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 108	 0.000691	 0.004662	 0.0091	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 109	 9.9e-05	 0.000415	 0.0456	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2976	 110	 1e-06	 0.000104	 0.078	 1047.0	 1047.0	 1047.0	 0.0	 0.0	 1	 -30.0	 30.0;
	581	 110	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 110	 0.000699	 0.009179	 0.3177	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	400	 110	 1e-06	 0.000104	 0.0722	 1118.0	 1118.0	 1118.0	 0.0	 0.0	 1	 -30.0	 30.0;
	581	 110	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 110	 0.000734	 0.009245	 0.3148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 110	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 110	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 111	 0.002556	 0.017333	 0.0805	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 111	 0.008849	 0.062617	 0.1144	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 112	 2.2e-05	 9.9e-05	 0.001	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 2588	 2e-05	 9.9e-05	 0.0	 307279	 307279	 307279	 0.0	 0.0	 1	 -30.0	 30.0;
	965	 113	 0.000573	 0.002588	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 114	 0.039808	 0.117914	 0.0111	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	597	 114	 0.019854	 0.04772	 0.0085	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 115	 2e-05	 0.000198	 0.001	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 116	 0.000138	 0.00077	 0.001	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1915	 117	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 118	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	2124	 118	 0.046259	 0.156664	 0.0024	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 118	 0.036533	 0.120433	 0.0015	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 119	 0.039305	 0.163517	 0.0072	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 119	 0.04006	 0.090703	 0.0039	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	255	 120	 0.091993	 0.168392	 0.001	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 120	 0.059713	 0.134543	 0.001	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 2589	 0.001512	 0.010078	 0.014	 2898	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 121	 0.006551	 0.012094	 0.0046	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 122	 0.001171	 0.007842	 0.0166	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 122	 0.002212	 0.014979	 0.0388	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 123	 0.021416	 0.086672	 0.0011	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	1966	 123	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1967	 123	 0.00252	 0.006551	 0.0001	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 123	 0.021164	 0.08642	 0.0011	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	313	 125	 0.008679	 0.015886	 0.0142	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 125	 0.035878	 0.14646	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 125	 0.009675	 0.060166	 0.0022	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 125	 0.039053	 0.145377	 0.0054	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 125	 0.040312	 0.118166	 0.0049	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 125	 0.036054	 0.147241	 0.0074	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 125	 0.0097	 0.060393	 0.0027	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 125	 0.020408	 0.13026	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 125	 0.020106	 0.076216	 0.0011	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	1546	 126	 0.000691	 0.002588	 0.1691	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	2868	 126	 0.000691	 0.002588	 0.1509	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 127	 0.001627	 0.014855	 0.3899	 1717.0	 1717.0	 1717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 127	 0.001676	 0.013899	 0.4216	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	862	 128	 0.002771	 0.009574	 0.0091	 2963	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 128	 0.002771	 0.010834	 0.016	 2641	 2641	 2641	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 129	 0.027186	 0.073369	 0.0039	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 129	 0.027085	 0.073243	 0.0034	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	696	 2955	 0.023285	 0.042623	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 2955	 0.04258	 0.112371	 0.0012	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	1080	 2955	 0.062988	 0.133535	 0.0017	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 130	 0.006677	 0.035122	 0.0059	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 2955	 0.039053	 0.099017	 0.0011	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 130	 0.006551	 0.035021	 0.0059	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 131	 0.003081	 0.020286	 0.0365	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1141	 131	 0.00241	 0.01603	 0.0294	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1743	 132	 0.000176	 0.001385	 0.1521	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 132	 0.001817	 0.012642	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 132	 0.001865	 0.012502	 0.0229	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	519	 133	 0.039053	 0.099269	 0.0011	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 133	 0.074578	 0.195767	 0.0022	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	385	 134	 0.007422	 0.024489	 0.0081	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	621	 134	 0.028356	 0.083956	 0.0274	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 134	 0.016844	 0.058489	 0.0198	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	1782	 134	 0.009067	 0.028133	 0.0095	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 135	 0.028723	 0.075082	 0.0009	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 136	 0.000593	 0.00401	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 137	 0.055959	 0.123205	 0.0037	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	1685	 137	 0.130763	 0.331822	 0.0039	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 137	 0.116906	 0.21416	 0.0029	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 138	 0.010351	 0.032395	 0.0562	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	2020	 138	 0.009146	 0.025778	 0.041	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	2816	 2590	 0.000395	 0.006648	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 2590	 0.000492	 0.008345	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 140	 0.001198	 0.015699	 0.5401	 2026	 2026	 2026	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 140	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 2590	 0.001479	 0.019446	 0.6729	 1636	 1636	 1636	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 140	 0.000305	 0.003975	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 2590	 0.000395	 0.006641	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 140	 0.000492	 0.008338	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 2590	 0.001184	 0.015568	 0.5372	 2043	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 2590	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 140	 0.001482	 0.019467	 0.6729	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	1805	 2590	 0.000305	 0.003982	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2817	 140	 0.000388	 0.0066	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 140	 0.000388	 0.006593	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 141	 0.001817	 0.012049	 0.0233	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 142	 0.003496	 0.023269	 0.0425	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	643	 143	 0.028723	 0.06324	 0.0007	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 144	 0.030213	 0.105538	 0.0315	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 144	 0.019498	 0.06712	 0.0206	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	901	 145	 0.006262	 0.040849	 0.0749	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 146	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 147	 0.001936	 0.0128	 0.0182	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 149	 2e-05	 0.000198	 0.0081	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 149	 0.000296	 0.000988	 0.2207	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2632	 2592	 8.5e-05	 0.000198	 0.0192	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 150	 0.002487	 0.016492	 0.0304	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 150	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 150	 0.003563	 0.023682	 0.044	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 150	 0.002724	 0.018108	 0.0334	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 150	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 151	 0.000257	 0.000928	 0.1134	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 153	 0.002291	 0.009936	 0.0304	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 153	 0.004168	 0.028918	 0.0597	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 153	 0.002054	 0.024691	 0.1276	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 153	 0.004879	 0.032533	 0.0607	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 153	 0.005294	 0.036998	 0.0668	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 153	 0.001422	 0.009896	 0.0172	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 154	 0.002168	 0.029238	 0.9906	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	2737	 154	 0.001468	 0.01491	 0.3841	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 154	 0.002479	 0.028151	 0.6296	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 154	 0.00072	 0.00946	 0.3263	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	777	 154	 0.00142	 0.01617	 0.3636	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 154	 0.002486	 0.028165	 0.6296	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 154	 0.001184	 0.016073	 0.4869	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 155	 0.000521	 0.002315	 0.019	 13045	 13045	 13045	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 156	 0.002016	 0.004283	 0.0021	 6256	 6256	 6256	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 156	 0.008793	 0.026405	 0.0003	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 156	 0.013958	 0.087679	 0.0011	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 156	 0.075913	 0.210683	 0.0023	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 156	 0.002135	 0.003909	 0.0034	 6649	 6649	 6649	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 157	 0.053918	 0.138574	 0.0016	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 157	 0.014865	 0.038045	 0.0004	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 158	 0.031746	 0.072058	 0.0008	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	685	 158	 0.090703	 0.247669	 0.0028	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 158	 0.061225	 0.148652	 0.0016	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 158	 0.16513	 0.330511	 0.0096	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 158	 0.031998	 0.08642	 0.001	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 159	 0.018645	 0.077097	 0.001	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 160	 0.020242	 0.037052	 0.0011	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 161	 0.054926	 0.100781	 0.0011	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 162	 0.000178	 0.000909	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 163	 0.001512	 0.003023	 0.0013	 8736	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 164	 0.00241	 0.015694	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 164	 0.006874	 0.044761	 0.0835	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 165	 0.001521	 0.021728	 0.0871	 831.0	 831.0	 831.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2110	 165	 0.001304	 0.017205	 0.0729	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 166	 0.006047	 0.015873	 0.0002	 1739	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 166	 0.00252	 0.006299	 0.0004	 4352	 4352	 4352	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 166	 0.005795	 0.016125	 0.0002	 1724	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	635	 166	 0.021083	 0.038593	 0.0004	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 167	 0.000336	 0.001363	 0.1499	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 167	 0.000178	 0.001422	 0.1448	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	554	 168	 0.03351	 0.108214	 0.0013	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 168	 0.018392	 0.060217	 0.0008	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 169	 0.080121	 0.168304	 0.0018	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 169	 0.046863	 0.196019	 0.0024	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 170	 0.006047	 0.025951	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 171	 0.002252	 0.011951	 0.0218	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 171	 0.00079	 0.005333	 0.0101	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1310	 172	 0.008062	 0.020408	 0.0002	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	511	 173	 0.001501	 0.010015	 0.0182	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 173	 0.003103	 0.021146	 0.04	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 173	 0.00162	 0.010765	 0.0203	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 173	 0.001807	 0.017201	 0.0618	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	188	 173	 0.000217	 0.001442	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 173	 0.00162	 0.010726	 0.0203	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 173	 0.000119	 0.001086	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 174	 0.00072	 0.009453	 0.3263	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 174	 0.003206	 0.03536	 0.9025	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 174	 0.000616	 0.008054	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 2998	 0.000713	 0.009384	 0.3235	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 2998	 0.000616	 0.008061	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 174	 3.5e-05	 0.000374	 0.0087	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 175	 0.013393	 0.069551	 0.1261	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2960	 175	 0.013491	 0.070361	 0.1271	 412.0	 412.0	 412.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 177	 0.001764	 0.004535	 0.0048	 6068	 6068	 6068	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 178	 0.001956	 0.010469	 0.3286	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 178	 0.001402	 0.010173	 0.2673	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 179	 0.000648	 0.00657	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 179	 0.000651	 0.006572	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 181	 0.059259	 0.163457	 0.0	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 182	 0.000436	 0.000797	 0.0006	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 182	 0.012002	 0.02197	 0.0233	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 182	 0.074578	 0.197279	 0.003	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 182	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 182	 0.003527	 0.01285	 0.0015	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	597	 182	 0.015042	 0.040539	 0.0164	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	2745	 182	 0.005039	 0.01285	 0.0002	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 182	 0.003023	 0.013102	 0.0002	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 183	 0.00332	 0.015328	 0.0267	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 184	 2.4e-05	 9.7e-05	 0.001	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 185	 0.028496	 0.059461	 0.0006	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 185	 0.074074	 0.152683	 0.002	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 186	 9.9e-05	 0.000198	 0.0223	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 2595	 1.4e-05	 0.000145	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 187	 7e-06	 0.000159	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 2594	 1.4e-05	 0.000166	 0.0058	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 2593	 1.4e-05	 0.00018	 0.0058	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 191	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 191	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 192	 0.000251	 0.002177	 0.2187	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2794	 193	 0.001084	 0.014247	 0.491	 2232	 2232	 2232	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 193	 0.000492	 0.006489	 0.2224	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 193	 7e-06	 0.000152	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 193	 0.001112	 0.01462	 0.5054	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 193	 0.000492	 0.006489	 0.2238	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 193	 7e-06	 0.000104	 0.0029	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 194	 0.016377	 0.102041	 0.0017	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 194	 0.018392	 0.084908	 0.0021	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 2597	 0.011766	 0.048702	 0.0026	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 194	 0.005719	 0.022726	 0.0023	 1260	 1260	 1260	 0.0	 0.0	 1	 -30.0	 30.0;
	1411	 2597	 0.040816	 0.117914	 0.0061	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	1588	 194	 0.044596	 0.113631	 0.0037	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 2597	 0.004661	 0.018392	 0.0022	 1557	 1557	 1557	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 194	 0.013883	 0.056009	 0.0025	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 195	 0.001264	 0.00964	 0.0375	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	537	 195	 0.001264	 0.008415	 0.0152	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 195	 0.002627	 0.012188	 0.0218	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 195	 0.001063	 0.007064	 0.0132	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1663	 195	 0.002489	 0.016711	 0.0304	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 195	 0.0016	 0.014933	 0.0537	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 195	 0.001264	 0.009659	 0.0405	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	364	 196	 0.000501	 0.005472	 0.1155	 1429.0	 1429.0	 1429.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 196	 0.000429	 0.004737	 0.1011	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 197	 0.040564	 0.086924	 0.001	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 197	 0.04006	 0.107836	 0.0012	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	1093	 197	 0.035651	 0.095087	 0.0011	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	1122	 197	 0.011842	 0.031746	 0.0003	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 197	 0.015117	 0.032502	 0.0004	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	2874	 197	 0.07357	 0.192744	 0.0021	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 197	 0.013303	 0.035072	 0.0004	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 197	 0.058201	 0.147644	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 197	 0.012572	 0.033207	 0.0003	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 197	 0.065508	 0.233812	 0.0033	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	2900	 197	 0.010834	 0.035777	 0.0004	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 198	 0.000553	 0.003714	 0.0116	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 198	 0.003951	 0.020148	 0.0511	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 198	 0.007447	 0.034884	 0.0628	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 198	 0.000632	 0.004286	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 198	 0.000553	 0.003714	 0.0121	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1290	 198	 0.001106	 0.005353	 0.0091	 5617	 5617	 5617	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 198	 0.000672	 0.004543	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 199	 0.004188	 0.027872	 0.0516	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 199	 0.00322	 0.022183	 0.0395	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 199	 0.00322	 0.022183	 0.0395	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 200	 0.000217	 0.00081	 0.1013	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 2598	 0.000257	 0.000988	 0.1215	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 201	 0.003358	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 201	 0.003437	 0.022933	 0.0425	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 202	 0.002145	 0.009679	 0.017	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 2599	 0.002125	 0.009576	 0.0168	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 203	 0.000691	 0.001383	 0.2045	 20021	 20021	 20021	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 204	 0.001699	 0.011299	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 205	 0.04006	 0.109599	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 205	 0.035777	 0.09549	 0.0011	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 206	 0.0048	 0.022637	 0.0405	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 206	 0.003319	 0.015664	 0.0263	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1690	 207	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 208	 0.016881	 0.055682	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 209	 0.063668	 0.160393	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1825	 209	 0.020408	 0.052658	 0.001	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 211	 0.000514	 0.001541	 0.1144	 19054	 19054	 19054	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 213	 0.00324	 0.034272	 0.1336	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 2600	 0.005077	 0.023783	 0.0425	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 2600	 0.002368	 0.018825	 0.0511	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 2600	 0.003279	 0.043101	 0.1822	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 2600	 0.0014	 0.011018	 0.0192	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	213	 212	 4.8e-05	 8.8e-05	 0.004	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1287	 214	 0.000102	 0.001632	 0.0491	 2450.0	 2450.0	 2450.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 215	 0.005543	 0.014109	 0.0002	 1951	 1951	 1951	 0.0	 0.0	 1	 -30.0	 30.0;
	2681	 216	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 216	 0.000318	 0.002424	 0.0052	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 216	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 216	 0.000397	 0.002657	 0.0051	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 218	 0.000637	 0.008255	 0.2123	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 218	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 218	 0.000443	 0.006454	 0.1675	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 218	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 218	 0.000464	 0.006766	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 218	 0.000464	 0.006773	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1284	 219	 0.001025	 0.004614	 0.0081	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	697	 220	 0.045855	 0.116402	 0.0013	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 220	 0.019148	 0.053162	 0.0006	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	773	 221	 0.061275	 0.155707	 0.0047	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 222	 0.001934	 0.01293	 0.024	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 222	 0.004642	 0.03089	 0.0573	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	224	 223	 0.000968	 0.001975	 0.0081	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	224	 2601	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	224	 2602	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 224	 0.00348	 0.023956	 0.0456	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 224	 0.002449	 0.017106	 0.0304	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 224	 0.006001	 0.041452	 0.078	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 226	 4e-05	 0.000198	 0.0	 153231	 153231	 153231	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 227	 0.001205	 0.005511	 0.0091	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 229	 0.01438	 0.065067	 0.1154	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 229	 0.003538	 0.016484	 0.0273	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 229	 0.012634	 0.056573	 0.1008	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 229	 0.003516	 0.016158	 0.0273	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 229	 0.00316	 0.014914	 0.0253	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 229	 0.007704	 0.034647	 0.0607	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 229	 0.002489	 0.016257	 0.0294	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2648	 229	 0.003457	 0.015467	 0.0273	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 230	 0.006579	 0.049467	 1.0137	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 230	 0.001357	 0.014821	 0.3321	 1171.0	 1171.0	 1171.0	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 231	 0.00352	 0.014823	 0.0263	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 233	 0.001111	 0.003244	 0.0014	 8880	 8880	 8880	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 234	 2e-05	 0.000198	 0.0223	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 2604	 9.9e-05	 0.000296	 0.004	 99170	 99170	 99170	 0.0	 0.0	 1	 -30.0	 30.0;
	1573	 235	 0.024389	 0.066516	 0.0007	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	940	 236	 0.066264	 0.221718	 0.0027	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 236	 0.027211	 0.08642	 0.001	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 237	 0.084656	 0.214916	 0.003	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	1705	 237	 0.049131	 0.124465	 0.001	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 237	 0.066264	 0.147644	 0.002	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 238	 0.000936	 0.006236	 0.0146	 441.0	 441.0	 441.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 2607	 0.000217	 0.00079	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 2608	 0.000217	 0.00079	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 239	 0.000237	 0.000988	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 2605	 0.000257	 0.000988	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 2606	 0.000257	 0.000988	 0.0	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 240	 0.000111	 0.001026	 0.0884	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 241	 0.010859	 0.033384	 0.0319	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 242	 0.025951	 0.083648	 0.001	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	1660	 242	 0.007811	 0.023432	 0.0137	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 242	 0.019652	 0.082892	 0.001	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 242	 0.018443	 0.068178	 0.0152	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 242	 0.004283	 0.016881	 0.0005	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 243	 0.001636	 0.010939	 0.0216	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	458	 244	 0.004535	 0.026707	 0.0045	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 244	 0.008062	 0.015369	 0.0117	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	458	 244	 0.015747	 0.039909	 0.0005	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 245	 0.000257	 0.001758	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1404	 245	 0.00162	 0.011121	 0.0213	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 2611	 1.4e-05	 0.000173	 0.0982	 183736	 183736	 183736	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 2610	 1.4e-05	 0.000187	 0.0809	 170060	 170060	 170060	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 2609	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 246	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 247	 0.005215	 0.035002	 0.0638	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 248	 0.064349	 0.163291	 0.0018	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 248	 0.027916	 0.112976	 0.0013	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	1842	 248	 0.09229	 0.251852	 0.0033	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 249	 0.045603	 0.12522	 0.001	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 250	 0.001397	 0.009306	 0.0172	 340.0	 340.0	 340.0	 0.0	 0.0	 1	 -30.0	 30.0;
	998	 250	 0.003415	 0.021827	 0.04	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 251	 2e-05	 9.9e-05	 0.0	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	749	 252	 0.022222	 0.047407	 0.0002	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 252	 0.034568	 0.075062	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 253	 7e-06	 0.000132	 0.0058	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 254	 7e-06	 0.000104	 0.0029	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 255	 0.047871	 0.145377	 0.001	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 256	 0.000237	 0.000573	 0.078	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 257	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 2612	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 260	 0.002706	 0.0128	 0.0213	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 261	 0.00237	 0.015803	 0.0294	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1493	 262	 0.074074	 0.158025	 0.0012	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 262	 0.02321	 0.051852	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 262	 0.044444	 0.09679	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1816	 262	 0.108938	 0.258025	 0.001	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	654	 264	 0.003554	 0.024524	 0.0466	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	770	 264	 0.006493	 0.043265	 0.08	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 264	 0.007921	 0.053985	 0.1013	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 264	 0.004543	 0.030262	 0.0557	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1947	 265	 0.038095	 0.105115	 0.0012	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 266	 0.001126	 0.004978	 0.0091	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 267	 0.003536	 0.01683	 0.0284	 306.0	 306.0	 306.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1598	 267	 0.001541	 0.009936	 0.0258	 3054	 3054	 3054	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 267	 0.008375	 0.039704	 0.0658	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 268	 0.070799	 0.179894	 0.002	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 268	 0.06324	 0.181658	 0.002	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 268	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 269	 0.03225	 0.082389	 0.0046	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 269	 0.001008	 0.003779	 0.0035	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 269	 0.018392	 0.076846	 0.001	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	2876	 269	 0.001008	 0.003779	 0.0006	 7550	 7550	 7550	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 269	 0.0194	 0.079113	 0.001	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 270	 0.011378	 0.053886	 0.0957	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 270	 0.003457	 0.023724	 0.0445	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 270	 0.008415	 0.041422	 0.0739	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1531	 270	 0.003793	 0.017007	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 270	 0.004701	 0.026726	 0.0481	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 270	 0.001877	 0.018252	 0.0638	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 270	 0.001857	 0.017521	 0.0648	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1932	 271	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	595	 272	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 272	 0.000533	 0.004642	 0.4647	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 273	 0.002827	 0.011058	 0.0192	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	998	 273	 0.002258	 0.00946	 0.0172	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	275	 274	 0.024691	 0.062232	 0.001	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	1887	 274	 0.025951	 0.058453	 0.001	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	1346	 275	 0.03351	 0.068783	 0.001	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	753	 276	 0.051146	 0.129756	 0.001	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 276	 0.070547	 0.176871	 0.0165	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 276	 0.082389	 0.208869	 0.0024	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 277	 0.025951	 0.07231	 0.001	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 279	 0.001363	 0.009126	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 279	 0.0016	 0.010825	 0.0203	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 279	 0.001402	 0.009422	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 280	 0.001153	 0.010798	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 280	 0.00115	 0.010796	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 281	 0.03099	 0.078861	 0.0009	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	1093	 281	 0.02328	 0.065306	 0.0008	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	1632	 281	 0.009826	 0.018141	 0.0005	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 281	 0.040312	 0.100025	 0.0011	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	1333	 282	 0.000377	 0.00069	 0.0273	 39366	 39366	 39366	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 282	 0.000336	 0.001304	 0.2906	 22986	 22986	 22986	 0.0	 0.0	 1	 -30.0	 30.0;
	284	 283	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 284	 0.005472	 0.024889	 0.0445	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 2618	 0.000252	 0.000504	 0.001	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 286	 0.002015	 0.013551	 0.0764	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 286	 0.012484	 0.056454	 0.1002	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2844	 286	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 286	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 286	 0.001001	 0.006712	 0.0121	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 288	 0.001764	 0.01285	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	2080	 288	 0.001512	 0.010582	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	1934	 289	 0.000614	 0.004093	 0.0278	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 290	 0.000523	 0.002596	 0.2992	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 292	 0.021416	 0.058201	 0.001	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 2623	 0.048123	 0.15747	 0.002	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1270	 292	 0.03477	 0.097254	 0.002	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 2623	 0.066516	 0.17284	 0.0051	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	1692	 292	 0.024691	 0.062736	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 2623	 0.045603	 0.137566	 0.002	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 292	 0.026959	 0.085664	 0.001	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	2157	 292	 0.001008	 0.004031	 0.0	 7106	 7106	 7106	 0.0	 0.0	 1	 -30.0	 30.0;
	509	 292	 0.032363	 0.059241	 0.001	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	1692	 2623	 0.027715	 0.089443	 0.001	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 293	 0.00484	 0.021393	 0.0385	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 293	 0.001541	 0.007309	 0.0121	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	350	 293	 0.000672	 0.004602	 0.0152	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	746	 293	 0.00243	 0.011477	 0.0192	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 293	 0.002311	 0.011378	 0.0233	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 293	 0.000474	 0.002331	 0.0081	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 293	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	713	 293	 0.004286	 0.029037	 0.0527	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 293	 0.002074	 0.009758	 0.0162	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	364	 294	 0.001566	 0.015874	 0.4101	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	464	 294	 0.001309	 0.01286	 0.335	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 295	 0.012547	 0.053666	 0.0118	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	351	 295	 0.000504	 0.001764	 0.0021	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	465	 296	 0.026707	 0.067271	 0.001	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	359	 297	 7e-06	 0.000125	 0.0029	 552.0	 552.0	 552.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 297	 0.000693	 0.007687	 0.1704	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1936	 299	 0.000691	 0.003279	 0.0051	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2982	 300	 0.053666	 0.152431	 0.0002	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 2627	 0.000277	 0.001916	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	565	 301	 0.000277	 0.001936	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 302	 0.07609	 0.179642	 0.0017	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 302	 0.037289	 0.079113	 0.0009	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 303	 0.000217	 0.001205	 0.0086	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 304	 0.052658	 0.134467	 0.0039	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	1847	 304	 0.025598	 0.068405	 0.0012	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 2628	 0.000252	 0.001512	 0.0	 19327	 19327	 19327	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 305	 0.000171	 0.000313	 0.0	 82904	 82904	 82904	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 306	 0.00162	 0.007447	 0.0132	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 306	 0.000889	 0.005965	 0.0111	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 2629	 0.000533	 0.003536	 0.0061	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 307	 0.000178	 0.001185	 0.002	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	798	 308	 0.002889	 0.0064	 0.0022	 4554	 4554	 4554	 0.0	 0.0	 1	 -30.0	 30.0;
	2874	 309	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	753	 310	 0.13293	 0.358201	 0.0161	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 311	 0.000205	 0.002108	 0.2577	 546.0	 546.0	 546.0	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 312	 0.002899	 0.029385	 0.7595	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	1023	 312	 0.002045	 0.020735	 0.5343	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	1144	 314	 0.028148	 0.076543	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 314	 0.019753	 0.048889	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 315	 0.002922	 0.005348	 0.0048	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	1941	 316	 0.001906	 0.003489	 0.0	 12456	 12456	 12456	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 317	 0.081104	 0.188234	 0.0033	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 317	 0.050139	 0.113631	 0.0013	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 318	 0.000378	 0.001008	 0.0001	 27427	 27427	 27427	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 2631	 0.011298	 0.020682	 0.0088	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 319	 0.008062	 0.017133	 0.0156	 1560	 1560	 1560	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 2630	 0.007811	 0.016125	 0.0148	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 320	 0.00924	 0.060219	 0.1124	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 320	 0.009007	 0.066726	 0.1192	 468	 468	 468	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 320	 0.004543	 0.030479	 0.0547	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 320	 0.004326	 0.029037	 0.0527	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 321	 0.001357	 0.017597	 0.3494	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 321	 0.001343	 0.01741	 0.3437	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 322	 0.003615	 0.024178	 0.0445	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 323	 0.001136	 0.012154	 0.2657	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 323	 0.001309	 0.013996	 0.3061	 1917.0	 1917.0	 1917.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 2632	 0.000257	 0.001521	 0.162	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 2632	 0.000259	 0.000506	 0.042	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 325	 0.000928	 0.006202	 0.0111	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 2633	 0.000928	 0.006202	 0.0111	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 326	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 2634	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 327	 0.01033	 0.028219	 0.0013	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 328	 0.114135	 0.237087	 0.0026	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 328	 0.04258	 0.178634	 0.0021	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 328	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 329	 0.009245	 0.016923	 0.0002	 1532	 1532	 1532	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 2635	 0.006047	 0.011086	 0.0059	 2339	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	1720	 330	 0.031494	 0.085412	 0.001	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 330	 0.025951	 0.066516	 0.0007	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	2994	 330	 0.006803	 0.014361	 0.013	 1870	 1870	 1870	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 2636	 0.014613	 0.03099	 0.0281	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 331	 0.014613	 0.03099	 0.0283	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 332	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 2637	 2e-05	 0.000198	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	765	 2638	 0.001067	 0.00723	 0.0132	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 333	 0.003358	 0.022341	 0.0415	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 2638	 0.00318	 0.020938	 0.0395	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 2638	 0.000928	 0.008968	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2156	 333	 0.004899	 0.022815	 0.0405	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 333	 0.000889	 0.008415	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 2639	 0.000237	 0.001422	 0.1686	 21471	 21471	 21471	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 334	 0.000277	 0.001086	 0.1417	 27618	 27618	 27618	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 334	 0.000296	 0.000672	 0.0678	 42153	 42153	 42153	 0.0	 0.0	 1	 -30.0	 30.0;
	497	 336	 0.002267	 0.007156	 0.0022	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 337	 0.016377	 0.102041	 0.0013	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 337	 0.008062	 0.050139	 0.0006	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 338	 0.000286	 0.004868	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 339	 0.000287	 0.004892	 0.1776	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 340	 0.000283	 0.004814	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 341	 0.000285	 0.004843	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 342	 0.000514	 0.001383	 0.0952	 20979	 20979	 20979	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 342	 0.000247	 0.001084	 0.1478	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2140	 343	 0.013857	 0.025447	 0.0002	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 344	 0.015369	 0.040816	 0.0005	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 344	 0.041068	 0.104812	 0.0012	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 345	 0.058957	 0.16125	 0.0018	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 345	 0.024439	 0.102293	 0.0012	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	664	 346	 0.006047	 0.016629	 0.014	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	864	 2641	 0.013096	 0.066153	 0.12	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	901	 348	 0.002074	 0.009956	 0.0172	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	901	 348	 0.001533	 0.009225	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	901	 2641	 0.00156	 0.009343	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 349	 0.001452	 0.020223	 0.6741	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 349	 0.001672	 0.022177	 0.7607	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 349	 0.001447	 0.020166	 0.6721	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 349	 0.001669	 0.022168	 0.7624	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	2053	 351	 0.02066	 0.088183	 0.0051	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 352	 0.002874	 0.022174	 0.4476	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 352	 0.000139	 0.001115	 0.0231	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2151	 354	 0.042328	 0.160998	 0.0017	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 356	 0.00322	 0.021136	 0.0395	 460.0	 460.0	 460.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 356	 0.000553	 0.003694	 0.0071	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 2643	 0.000494	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 356	 0.000652	 0.004504	 0.0081	 437.0	 437.0	 437.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2028	 356	 0.000652	 0.004504	 0.0081	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 2643	 0.000514	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1992	 2642	 0.000869	 0.008435	 0.0339	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 2642	 0.000889	 0.008553	 0.039	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 2645	 0.000686	 0.007091	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 2645	 0.000609	 0.006378	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 357	 0.000686	 0.007119	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 357	 0.000609	 0.006406	 0.1487	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 358	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 358	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 360	 0.037793	 0.097002	 0.0011	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 360	 0.003023	 0.008314	 0.0001	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 361	 0.00083	 0.005649	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 361	 0.002193	 0.014894	 0.0284	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	977	 362	 0.002145	 0.011151	 0.0203	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1948	 362	 0.00638	 0.031486	 0.0537	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 363	 0.022096	 0.08841	 0.0011	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	865	 363	 0.025724	 0.105316	 0.0184	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 363	 0.029957	 0.121013	 0.0046	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	1640	 363	 0.009322	 0.028471	 0.0	 986	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 363	 0.046107	 0.130763	 0.001	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 363	 0.006047	 0.041068	 0.001	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	1640	 363	 0.004334	 0.026732	 0.001	 1091	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	464	 364	 0.002877	 0.028829	 0.7494	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	471	 364	 0.002188	 0.024233	 0.5227	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 364	 0.000997	 0.014175	 0.465	 2245	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 364	 0.000376	 0.002891	 0.0606	 1308.0	 1308.0	 1308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 364	 0.000976	 0.009886	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 364	 0.000389	 0.003951	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	471	 364	 0.001562	 0.01912	 0.4274	 1567.0	 1567.0	 1567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 364	 0.000998	 0.014177	 0.465	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 364	 0.000199	 0.002553	 0.0838	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 364	 0.000976	 0.009891	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 364	 0.000388	 0.003954	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 364	 0.000395	 0.004003	 0.104	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 364	 0.000395	 0.004003	 0.104	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 365	 0.003101	 0.020859	 0.0375	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 365	 0.004978	 0.022005	 0.0359	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 365	 0.003121	 0.0208	 0.0506	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 2646	 0.000499	 0.005048	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 366	 0.000499	 0.005042	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	661	 368	 0.002193	 0.010884	 0.0197	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 368	 0.004049	 0.018272	 0.0324	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 369	 0.011032	 0.050442	 0.0871	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 369	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 369	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 371	 0.018645	 0.047871	 0.0013	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	581	 372	 0.0016	 0.017334	 0.4043	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 372	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 372	 0.000824	 0.010499	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 372	 0.00133	 0.014252	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 372	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 372	 0.000824	 0.010505	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1401	 373	 0.001936	 0.012879	 0.0243	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 374	 0.060721	 0.170068	 0.002	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	1411	 375	 0.011842	 0.030486	 0.0003	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 376	 0.000164	 0.001106	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 2647	 0.000336	 0.000849	 0.1448	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2663	 377	 0.000178	 0.000691	 0.1002	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 2647	 0.000316	 0.001304	 0.1863	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 2647	 9.9e-05	 0.000612	 0.082	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	515	 378	 0.065256	 0.144369	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 378	 0.024943	 0.10456	 0.001	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	393	 380	 0.019652	 0.081885	 0.0052	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 380	 0.010078	 0.039305	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	2668	 380	 0.019652	 0.082389	 0.0081	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 380	 0.00252	 0.01033	 0.0	 2808	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	1779	 381	 0.001146	 0.007111	 0.2238	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2737	 382	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 382	 0.000547	 0.010021	 0.2801	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 382	 0.001184	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	606	 382	 0.000369	 0.006726	 0.1892	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	777	 382	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 382	 0.001177	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 383	 0.00861	 0.015761	 0.0002	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 384	 7.9e-05	 0.000316	 0.001	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1448	 385	 0.001956	 0.008844	 0.0027	 3362	 3362	 3362	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 385	 0.000133	 0.000311	 0.0	 90021	 90021	 90021	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 2649	 0.000198	 0.000672	 0.1509	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 386	 0.000198	 0.000691	 0.1529	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 387	 0.009264	 0.031822	 0.0567	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	516	 2650	 2e-05	 0.000198	 0.0051	 154266	 154266	 154266	 0.0	 0.0	 1	 -30.0	 30.0;
	516	 388	 4e-05	 0.000198	 0.0061	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 389	 0.00322	 0.021689	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 391	 0.003516	 0.016415	 0.0273	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 391	 0.004168	 0.028346	 0.0537	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 391	 0.001936	 0.00883	 0.0445	 3425	 3425	 3425	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 391	 0.008099	 0.036603	 0.0901	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2936	 391	 0.000948	 0.005886	 0.0289	 5192	 5192	 5192	 0.0	 0.0	 1	 -30.0	 30.0;
	1884	 391	 0.000948	 0.005748	 0.0304	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 391	 0.002311	 0.015763	 0.0435	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1390	 391	 0.000336	 0.002331	 0.004	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 391	 0.000211	 0.001199	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 391	 0.000209	 0.001189	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 392	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	409	 392	 0.00126	 0.014141	 0.2845	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 2652	 7.9e-05	 0.000859	 0.0173	 1204.0	 1204.0	 1204.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 2651	 0.001904	 0.021302	 0.4679	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 2652	 0.001517	 0.01687	 0.3494	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 2651	 2.1e-05	 0.000187	 0.0029	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 2651	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	409	 392	 0.00126	 0.01412	 0.2859	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2794	 2652	 0.000983	 0.010949	 0.2397	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 2652	 0.001711	 0.017348	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 2652	 0.001281	 0.018476	 0.491	 1720	 1720	 1720	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 2652	 0.001274	 0.018324	 0.4837	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 395	 0.002943	 0.02001	 0.0375	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 395	 0.005926	 0.04079	 0.077	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 395	 0.004571	 0.030552	 0.0557	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1831	 395	 0.002121	 0.009661	 0.0162	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 395	 0.002969	 0.013217	 0.0233	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 395	 0.005551	 0.025146	 0.0445	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 396	 0.000409	 0.005409	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 396	 0.001371	 0.013871	 0.361	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 396	 0.002154	 0.021884	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 396	 0.000416	 0.005443	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 396	 0.001364	 0.01383	 0.3596	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 396	 0.002154	 0.021877	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 397	 0.000968	 0.002943	 0.3453	 9991	 9991	 9991	 0.0	 0.0	 1	 -30.0	 30.0;
	2669	 397	 0.000217	 0.000849	 0.0931	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 397	 0.001205	 0.002746	 0.4668	 10322	 10322	 10322	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 397	 0.000454	 0.002331	 0.0516	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 397	 0.001284	 0.0096	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1886	 2653	 0.001225	 0.006104	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	483	 2653	 0.000257	 0.000849	 0.1893	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 2653	 0.000553	 0.002548	 0.0486	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 397	 0.001284	 0.00956	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 397	 0.000909	 0.00879	 0.039	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 397	 0.000533	 0.005096	 0.0248	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 398	 0.000277	 0.002618	 0.0693	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 399	 0.058453	 0.13026	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 399	 0.069035	 0.16906	 0.0026	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 402	 0.007802	 0.052444	 0.1018	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 402	 0.003101	 0.020563	 0.0385	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 402	 0.003761	 0.025235	 0.0456	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 402	 0.008889	 0.032197	 0.0537	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 402	 0.01442	 0.071763	 0.1291	 372.0	 372.0	 372.0	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 403	 0.000381	 0.007008	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 404	 0.000374	 0.006434	 0.2209	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 405	 0.001679	 0.017284	 0.0582	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 405	 0.001501	 0.018568	 0.0562	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 406	 0.058201	 0.120534	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 408	 0.00079	 0.005345	 0.0354	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 408	 0.00255	 0.017084	 0.0309	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 408	 0.000745	 0.005047	 0.0349	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 409	 0.000741	 0.009716	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 409	 0.000422	 0.004709	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 409	 0.000741	 0.009709	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 409	 0.000422	 0.004758	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 409	 0.000644	 0.005035	 0.1112	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 410	 0.004514	 0.029863	 0.1096	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 411	 1.4e-05	 0.000208	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 2655	 2.1e-05	 0.000242	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 2656	 0.035853	 0.12517	 0.0031	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 2656	 0.076594	 0.195011	 0.003	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	676	 413	 0.002402	 0.015149	 0.0582	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 413	 0.000889	 0.005333	 0.0101	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 414	 0.002268	 0.004787	 0.0	 5574	 5574	 5574	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 414	 0.002016	 0.004031	 0.0	 6551	 6551	 6551	 0.0	 0.0	 1	 -30.0	 30.0;
	2716	 414	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 415	 0.000751	 0.004978	 0.0091	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 415	 0.001738	 0.011694	 0.0213	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 415	 0.000652	 0.004346	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 416	 0.000593	 0.002667	 0.0051	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 2657	 0.000591	 0.00268	 0.0046	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1584	 417	 0.001764	 0.004787	 0.0001	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 419	 0.000972	 0.012113	 0.1636	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 420	 0.007811	 0.014361	 0.0107	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	588	 421	 0.003477	 0.023249	 0.0425	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	796	 421	 0.006341	 0.042232	 0.078	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 422	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 422	 0.001764	 0.010582	 0.0002	 2753	 2753	 2753	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 424	 4.5e-05	 8.9e-05	 0.0007	 320583	 320583	 320583	 0.0	 0.0	 1	 -30.0	 30.0;
	496	 425	 0.023683	 0.0645	 0.001	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 426	 0.014109	 0.060217	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 428	 0.002601	 0.017284	 0.0324	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 428	 0.008257	 0.036427	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 429	 0.001857	 0.014461	 0.0481	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 429	 0.003202	 0.030829	 0.1164	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 430	 0.006005	 0.02878	 0.0496	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 430	 0.003595	 0.0176	 0.0294	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 431	 0.002133	 0.014756	 0.0294	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 432	 0.016377	 0.044596	 0.0005	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 433	 0.00642	 0.043852	 0.083	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 433	 0.003002	 0.020227	 0.0385	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 434	 8.9e-05	 0.000751	 0.079	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2667	 436	 0.003477	 0.018074	 0.0304	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1086	 436	 0.003141	 0.015526	 0.0268	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 436	 0.000237	 0.001541	 0.0091	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 437	 0.001086	 0.00642	 0.0121	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 437	 0.004464	 0.021452	 0.0385	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1235	 438	 0.023683	 0.043588	 0.0004	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 438	 0.004283	 0.021164	 0.0156	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	2130	 438	 0.071554	 0.184177	 0.002	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	902	 439	 0.000158	 0.000474	 0.0506	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 439	 0.000198	 0.00077	 0.0972	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1955	 2660	 1.6e-05	 9.9e-05	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 440	 1.6e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 441	 0.004899	 0.033007	 0.0699	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 441	 0.005531	 0.037215	 0.0678	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1739	 441	 0.004365	 0.029491	 0.0537	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 441	 0.005452	 0.036365	 0.0668	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1909	 442	 0.04	 0.088889	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 443	 0.003002	 0.014163	 0.0253	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 443	 0.001778	 0.009837	 0.0248	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 444	 0.005491	 0.037076	 0.0658	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1571	 444	 0.000454	 0.0032	 0.0051	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 444	 0.00083	 0.005669	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 444	 0.005412	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 444	 0.005432	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 447	 0.109785	 0.20096	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 448	 0.00877	 0.026489	 0.0435	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	1505	 448	 0.000968	 0.003516	 0.0061	 8488	 8488	 8488	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 448	 0.008099	 0.028247	 0.0466	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	1292	 448	 0.001521	 0.00721	 0.0121	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	649	 2663	 0.000138	 0.000573	 0.0699	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 450	 0.000198	 0.000731	 0.647	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 450	 0.000652	 0.002351	 0.5123	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 450	 0.000593	 0.005649	 0.0223	 656.0	 656.0	 656.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 450	 0.000182	 0.000622	 0.5559	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 450	 0.000652	 0.00237	 0.5133	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 450	 0.000612	 0.005669	 0.0278	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 2990	 0.000237	 0.002114	 0.1954	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1992	 450	 0.000217	 0.002054	 0.0197	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 2990	 0.000217	 0.002035	 0.0147	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 451	 0.00287	 0.017709	 0.0334	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 2664	 0.002015	 0.012879	 0.0243	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 451	 0.00482	 0.03119	 0.0577	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 452	 0.000529	 0.008085	 0.2498	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 452	 0.001142	 0.014569	 0.3855	 1746.0	 1746.0	 1746.0	 0.0	 0.0	 1	 -30.0	 30.0;
	790	 453	 0.002884	 0.019358	 0.0714	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 453	 0.004978	 0.024514	 0.0435	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2960	 453	 0.015328	 0.102262	 0.1903	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1619	 453	 0.005531	 0.02797	 0.0567	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2076	 2946	 0.001067	 0.007289	 0.0486	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2661	 2946	 5.9e-05	 0.000889	 0.003	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 2946	 0.002805	 0.019002	 0.0365	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 453	 0.001027	 0.006775	 0.0121	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 2946	 7.9e-05	 0.00083	 0.002	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2662	 453	 5.9e-05	 0.000652	 0.001	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	581	 454	 0.003102	 0.031524	 0.8202	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 454	 0.001168	 0.011767	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	581	 454	 0.00313	 0.031724	 0.8202	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 454	 0.001163	 0.011728	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2780	 454	 0.004905	 0.049964	 1.301	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 454	 2.1e-05	 0.000249	 0.0058	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	456	 455	 0.001027	 0.004721	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 455	 0.001027	 0.004899	 0.0091	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 456	 0.002548	 0.012346	 0.0203	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 457	 0.004721	 0.031348	 0.0587	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 457	 0.003556	 0.023585	 0.0435	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 458	 0.03225	 0.148904	 0.0018	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 458	 0.008314	 0.034014	 0.0245	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 458	 0.084404	 0.252457	 0.0098	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 458	 0.032754	 0.15092	 0.0014	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 458	 0.014361	 0.038801	 0.0004	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 459	 0.00156	 0.01039	 0.0192	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 459	 0.001084	 0.005086	 0.0111	 361.0	 361.0	 361.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1178	 459	 0.002153	 0.012978	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 459	 0.0011	 0.004978	 0.0142	 353.0	 353.0	 353.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1178	 459	 0.002173	 0.013017	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 460	 0.000158	 0.000691	 0.001	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1123	 461	 0.002544	 0.02015	 0.0348	 561.0	 561.0	 561.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 461	 0.003727	 0.028836	 0.0527	 562.0	 562.0	 562.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 462	 0.012522	 0.044041	 0.0263	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 462	 0.044848	 0.110103	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 463	 0.032704	 0.079542	 0.0022	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 463	 0.011338	 0.026455	 0.0009	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	2674	 464	 3.5e-05	 0.000512	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 464	 0.001887	 0.019088	 0.4938	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 464	 0.001579	 0.01509	 0.4087	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 464	 0.000949	 0.009342	 0.2426	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 464	 3.5e-05	 0.000506	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 464	 0.001874	 0.018954	 0.491	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 464	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	493	 464	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 464	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2672	 464	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	515	 465	 0.081436	 0.149069	 0.001	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 465	 0.069287	 0.175611	 0.002	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 466	 0.000869	 0.006025	 0.0101	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	526	 468	 0.006047	 0.018896	 0.0067	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 2665	 0.001764	 0.012346	 0.0011	 2372	 2372	 2372	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 2665	 0.006803	 0.028975	 0.0	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 469	 0.000171	 0.000313	 0.0	 83031	 83031	 83031	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 469	 0.008314	 0.018141	 0.0	 1480	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 469	 0.004686	 0.019829	 0.0002	 1452	 1452	 1452	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 2665	 0.007307	 0.028975	 0.0018	 990	 990	 990	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 2667	 0.001027	 0.006677	 0.0121	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 470	 0.009521	 0.064237	 0.1215	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1086	 2667	 0.002133	 0.023348	 0.0648	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 2666	 0.002232	 0.007802	 0.0142	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 470	 0.000593	 0.002588	 0.0162	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 470	 2e-05	 0.015803	 0.0	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 2667	 0.001778	 0.016356	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1687	 2667	 0.011694	 0.078657	 0.1519	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 2667	 0.000237	 0.00156	 0.0142	 19617	 19617	 19617	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 470	 0.001027	 0.006657	 0.0121	 464.0	 464.0	 464.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1292	 470	 0.00476	 0.022499	 0.0375	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 2666	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1803	 471	 0.000462	 0.006438	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1803	 471	 0.000462	 0.006434	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	688	 472	 0.003234	 0.01923	 0.0365	 410.0	 410.0	 410.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2717	 472	 0.019951	 0.071546	 0.1144	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 472	 0.016	 0.053472	 0.0861	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	622	 473	 0.017637	 0.056185	 0.001	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	2706	 473	 0.002851	 0.005218	 0.0036	 4966	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	2686	 473	 0.018141	 0.057193	 0.001	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 473	 0.00126	 0.004535	 0.0046	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 474	 0.005472	 0.037728	 0.0709	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 474	 0.000968	 0.00638	 0.0111	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 474	 0.005669	 0.025639	 0.0456	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 475	 0.082196	 0.171444	 0.0486	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 476	 0.017133	 0.071806	 0.0071	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 477	 0.002825	 0.018765	 0.0349	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	931	 477	 0.000474	 0.003101	 0.0061	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 477	 0.00173	 0.01154	 0.0213	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 477	 0.001719	 0.011496	 0.0289	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 478	 0.000436	 0.000797	 0.0	 32501	 32501	 32501	 0.0	 0.0	 1	 -30.0	 30.0;
	695	 480	 0.013472	 0.067378	 0.1215	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1433	 480	 0.004563	 0.02448	 0.0425	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1916	 480	 0.010627	 0.045511	 0.0749	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 480	 0.009798	 0.045748	 0.0815	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 480	 0.011674	 0.053096	 0.0921	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 481	 0.000812	 0.006278	 0.1271	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 481	 0.001797	 0.019272	 0.4216	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 481	 0.003831	 0.029281	 0.592	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	577	 482	 0.145125	 0.32124	 0.0037	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 482	 0.07609	 0.189468	 0.0021	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 2669	 0.000198	 0.0016	 0.162	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2861	 2669	 0.000454	 0.001106	 0.1002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1734	 483	 0.000316	 0.000948	 0.1094	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 2670	 0.00077	 0.011178	 0.312	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 2670	 0.00088	 0.012722	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 2670	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 484	 0.000771	 0.011192	 0.291	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 484	 0.00088	 0.012715	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 484	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	673	 2671	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 485	 0.000178	 0.000632	 0.078	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 487	 0.00077	 0.005195	 0.0091	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 487	 0.000553	 0.003694	 0.0157	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 487	 0.000514	 0.001007	 0.1499	 27378	 27378	 27378	 0.0	 0.0	 1	 -30.0	 30.0;
	1830	 487	 0.001679	 0.008296	 0.0152	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 487	 0.002548	 0.016968	 0.0314	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 487	 0.000731	 0.004938	 0.0091	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 487	 0.000533	 0.003635	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2858	 487	 0.000494	 0.001007	 0.1488	 27596	 27596	 27596	 0.0	 0.0	 1	 -30.0	 30.0;
	693	 488	 0.000514	 0.001185	 0.0719	 23964	 23964	 23964	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 489	 0.006551	 0.016629	 0.0005	 1723	 1723	 1723	 0.0	 0.0	 1	 -30.0	 30.0;
	753	 490	 0.000756	 0.005795	 0.0001	 5357	 5357	 5357	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 491	 0.000138	 0.000573	 0.001	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	977	 492	 0.000632	 0.004168	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 494	 0.001244	 0.002276	 0.0	 11384	 11384	 11384	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 495	 2e-05	 0.000198	 0.003	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 496	 0.006299	 0.017133	 0.0	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	514	 497	 0.0004	 0.001244	 0.0004	 23302	 23302	 23302	 0.0	 0.0	 1	 -30.0	 30.0;
	621	 497	 0.019956	 0.0604	 0.0198	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 497	 0.017467	 0.063733	 0.0216	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	1231	 498	 0.005543	 0.015621	 0.0015	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 498	 0.016125	 0.0516	 0.0253	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	1810	 498	 0.028723	 0.062484	 0.0007	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 499	 0.019652	 0.082137	 0.001	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 499	 0.112875	 0.361048	 0.0037	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 500	 0.002519	 0.007753	 0.0	 3203	 3203	 3203	 0.0	 0.0	 1	 -30.0	 30.0;
	800	 2675	 0.001481	 0.004938	 0.0012	 5064	 5064	 5064	 0.0	 0.0	 1	 -30.0	 30.0;
	1266	 501	 0.066012	 0.167549	 0.0019	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	526	 502	 0.031494	 0.131015	 0.007	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 502	 0.01159	 0.04132	 0.0298	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 502	 0.028219	 0.117158	 0.0017	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 503	 0.001233	 0.008227	 0.0147	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 504	 0.002761	 0.005054	 0.0	 4535	 4535	 4535	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 505	 0.003911	 0.027062	 0.0486	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 505	 0.000711	 0.006894	 0.0223	 865.0	 865.0	 865.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1131	 505	 0.007012	 0.030617	 0.0511	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 505	 0.007639	 0.051542	 0.2291	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	589	 506	 0.002597	 0.034127	 1.1812	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 506	 0.002999	 0.033656	 0.6729	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 506	 0.001302	 0.013172	 0.3408	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	589	 506	 0.002597	 0.034127	 1.1783	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 506	 0.000256	 0.002701	 0.0693	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 506	 0.001309	 0.013255	 0.3437	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 507	 0.002765	 0.01843	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 508	 0.002114	 0.012662	 0.0233	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 508	 0.000595	 0.004024	 0.0081	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 510	 0.001264	 0.008415	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1559	 512	 0.000731	 0.001383	 0.1853	 19787	 19787	 19787	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 516	 0.005867	 0.03919	 0.083	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 516	 0.003812	 0.025482	 0.0466	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 517	 0.00316	 0.021017	 0.0375	 528.0	 528.0	 528.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1401	 517	 0.004612	 0.030706	 0.0547	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 518	 0.000138	 0.001363	 0.2025	 22551	 22551	 22551	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 2676	 0.000158	 0.001323	 0.1822	 23186	 23186	 23186	 0.0	 0.0	 1	 -30.0	 30.0;
	2130	 519	 0.034014	 0.086672	 0.001	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	681	 520	 0.000559	 0.001024	 0.0729	 26532	 26532	 26532	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 521	 0.001512	 0.003779	 0.0001	 7254	 7254	 7254	 0.0	 0.0	 1	 -30.0	 30.0;
	1970	 521	 0.001764	 0.006047	 0.0001	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	1972	 521	 0.031242	 0.127488	 0.0017	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 521	 0.031494	 0.127992	 0.0023	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 522	 0.000292	 0.002538	 0.2546	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 523	 0.069035	 0.233308	 0.0028	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 524	 0.000632	 0.004306	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1656	 526	 0.004787	 0.01285	 0.0232	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 526	 0.003275	 0.014361	 0.0069	 2005	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 2677	 0.001244	 0.008415	 0.0309	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 2677	 0.002114	 0.014242	 0.0486	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 528	 0.136558	 0.304107	 0.0033	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 530	 0.023935	 0.060469	 0.0007	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 530	 0.031494	 0.079869	 0.0009	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 531	 0.036281	 0.082389	 0.001	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	1424	 531	 0.015117	 0.036281	 0.0004	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 531	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 531	 0.028723	 0.090451	 0.001	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 532	 0.001719	 0.008	 0.0132	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 533	 0.000252	 0.001008	 0.0	 28417	 28417	 28417	 0.0	 0.0	 1	 -30.0	 30.0;
	2755	 534	 0.091459	 0.249685	 0.0028	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 536	 0.019929	 0.079592	 0.0093	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 536	 0.051071	 0.160116	 0.0096	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	1423	 536	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	1423	 536	 0.008566	 0.018896	 0.0213	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 539	 0.000608	 0.004067	 0.0071	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 539	 0.002054	 0.013689	 0.0253	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 540	 0.00126	 0.003779	 0.0001	 7564	 7564	 7564	 0.0	 0.0	 1	 -30.0	 30.0;
	2141	 541	 0.000504	 0.001008	 0.0	 26199	 26199	 26199	 0.0	 0.0	 1	 -30.0	 30.0;
	1975	 542	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	685	 543	 0.009826	 0.025951	 0.0003	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	685	 543	 0.014865	 0.039808	 0.0005	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 544	 0.000356	 0.000731	 0.0415	 38168	 38168	 38168	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 545	 2e-05	 9.8e-05	 0.0111	 315683	 315683	 315683	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 546	 0.000968	 0.005906	 0.0602	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 546	 0.001331	 0.009015	 0.0906	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	896	 547	 0.00561	 0.030894	 0.0567	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1876	 547	 0.003812	 0.025383	 0.0471	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	353	 548	 0.010582	 0.046359	 0.001	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 548	 0.014109	 0.044596	 0.001	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	622	 548	 0.035273	 0.099521	 0.001	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 548	 0.001915	 0.011817	 0.0209	 2467	 2467	 2467	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 548	 0.005795	 0.023432	 0.004	 1224	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 549	 0.000504	 0.001764	 0.0018	 16094	 16094	 16094	 0.0	 0.0	 1	 -30.0	 30.0;
	641	 550	 0.081381	 0.179894	 0.0021	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 551	 0.005233	 0.024413	 0.0435	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 551	 0.002252	 0.01037	 0.0182	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 551	 0.00397	 0.02639	 0.0537	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	482	 552	 0.141597	 0.439657	 0.0056	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 552	 0.005291	 0.013605	 0.0002	 2023	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 2679	 0.048123	 0.121945	 0.0013	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 552	 0.062484	 0.139834	 0.0016	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 552	 0.028219	 0.071554	 0.0014	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 2679	 0.055682	 0.139078	 0.0016	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 552	 0.018392	 0.040312	 0.0005	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 2679	 0.012346	 0.037541	 0.0004	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	977	 553	 0.005314	 0.024119	 0.0425	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 553	 0.003398	 0.017541	 0.0314	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	977	 553	 0.005412	 0.024571	 0.0461	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 554	 0.00126	 0.003275	 0.0	 8415	 8415	 8415	 0.0	 0.0	 1	 -30.0	 30.0;
	381	 555	 0.001256	 0.008251	 0.2389	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1779	 555	 0.000158	 0.000652	 0.0729	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 556	 0.001047	 0.006973	 0.0132	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 558	 0.005393	 0.029649	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2743	 558	 0.005393	 0.02963	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 558	 0.001877	 0.012543	 0.0344	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 559	 0.000589	 0.007708	 0.2628	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 559	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1901	 559	 0.00241	 0.024446	 0.6325	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 559	 0.000589	 0.007708	 0.2628	 2389.0	 2389.0	 2389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 559	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 559	 0.00153	 0.015526	 0.4014	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1186	 560	 0.004464	 0.029669	 0.0547	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 560	 0.005156	 0.034489	 0.0638	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 561	 0.008122	 0.036857	 0.0655	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 561	 0.011081	 0.049936	 0.0891	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 562	 0.000336	 0.002173	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1962	 563	 0.02066	 0.055682	 0.001	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	706	 564	 0.000974	 0.001783	 0.0008	 14533	 14533	 14533	 0.0	 0.0	 1	 -30.0	 30.0;
	751	 564	 0.000403	 0.001386	 0.0001	 20949	 20949	 20949	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 564	 0.027967	 0.082137	 0.002	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	1088	 564	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	2789	 564	 0.000504	 0.00126	 0.0	 21757	 21757	 21757	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 564	 0.011338	 0.044848	 0.0014	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 565	 0.00156	 0.01041	 0.0192	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 565	 0.000178	 0.001659	 0.0061	 818.0	 818.0	 818.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1376	 565	 0.002035	 0.012563	 0.1094	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 565	 0.000257	 0.001659	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 565	 0.001432	 0.009557	 0.0223	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 565	 0.000158	 0.001067	 0.0046	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1769	 566	 0.003457	 0.008395	 0.0	 3303	 3303	 3303	 0.0	 0.0	 1	 -30.0	 30.0;
	1769	 566	 0.000494	 0.008395	 0.0	 3566	 3566	 3566	 0.0	 0.0	 1	 -30.0	 30.0;
	798	 567	 0.008542	 0.029422	 0.0095	 1044	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 568	 0.003368	 0.036373	 0.0273	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 569	 0.000375	 0.001383	 0.1711	 313.0	 313.0	 313.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 570	 0.000903	 0.006023	 0.0111	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 574	 0.002359	 0.016431	 0.0203	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 575	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 575	 5.9e-05	 0.001185	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 575	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1136	 576	 0.059965	 0.163265	 0.0018	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 578	 0.110545	 0.202352	 0.0021	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 578	 0.08642	 0.191232	 0.0021	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 579	 0.000968	 0.00644	 0.0121	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 580	 0.011773	 0.053926	 0.0962	 427.0	 427.0	 427.0	 0.0	 0.0	 1	 -30.0	 30.0;
	881	 581	 0.000966	 0.009803	 0.2526	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1259	 581	 0.002015	 0.020838	 0.5401	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 581	 0.000963	 0.009792	 0.2541	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 584	 0.004207	 0.029077	 0.0547	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1748	 584	 0.002805	 0.019378	 0.0365	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 586	 0.010311	 0.068543	 0.1276	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 586	 0.001017	 0.006912	 0.0633	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 587	 0.000976	 0.013206	 0.4448	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 587	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 587	 0.001369	 0.017997	 0.6209	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 587	 0.002352	 0.025391	 0.5704	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 587	 0.002021	 0.026575	 0.9197	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	912	 587	 0.000976	 0.013213	 0.4448	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 587	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 588	 0.005223	 0.034671	 0.076	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2729	 589	 2.1e-05	 0.000301	 0.0116	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 589	 0.000697	 0.009107	 0.3114	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	756	 589	 1.9e-05	 0.00028	 0.0108	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 589	 0.001244	 0.016445	 0.5652	 1934	 1934	 1934	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 590	 0.005096	 0.033837	 0.0628	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 590	 0.005057	 0.030084	 0.0567	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 592	 2e-06	 0.000198	 0.0066	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 593	 0.000336	 0.001481	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 593	 0.000652	 0.004346	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	930	 593	 0.000336	 0.001501	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 594	 0.009776	 0.020635	 0.0187	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 596	 0.006202	 0.041343	 0.0759	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1739	 596	 0.001205	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1739	 596	 0.001225	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1981	 598	 0.000988	 0.005709	 0.0101	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1650	 599	 0.056552	 0.103518	 0.001	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 599	 0.059965	 0.149156	 0.0041	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 600	 0.001877	 0.012504	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 600	 0.001462	 0.009758	 0.0182	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 2683	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 601	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 2684	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 602	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 603	 0.000672	 0.003891	 0.08	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	944	 603	 0.000632	 0.003812	 0.0911	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1226	 604	 0.015873	 0.042328	 0.001	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 604	 0.003023	 0.006047	 0.0001	 4368	 4368	 4368	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 605	 0.00083	 0.005709	 0.0182	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1419	 605	 0.001709	 0.016636	 0.0577	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 605	 0.001758	 0.017442	 0.0547	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 605	 0.00083	 0.005709	 0.0223	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1318	 606	 0.000186	 0.003394	 0.0953	 2250.0	 2250.0	 2250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1573	 607	 0.026833	 0.059889	 0.0007	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 607	 0.073797	 0.187075	 0.0021	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 608	 0.003773	 0.025264	 0.0466	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 608	 0.005195	 0.023585	 0.0415	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2841	 609	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 609	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2901	 609	 7.9e-05	 0.001284	 0.002	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	618	 610	 0.022676	 0.073318	 0.0008	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 610	 0.081885	 0.259259	 0.0043	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	1014	 612	 0.028721	 0.081007	 0.1357	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	1034	 612	 0.012247	 0.062222	 0.1073	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 612	 0.009067	 0.042884	 0.0861	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1134	 612	 0.020602	 0.068109	 0.1083	 258.0	 258.0	 258.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 612	 0.016691	 0.075299	 0.1336	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1608	 612	 0.008158	 0.03516	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 612	 0.016612	 0.078676	 0.1316	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 612	 0.023407	 0.110815	 0.1853	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 613	 0.001898	 0.021337	 0.4245	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 613	 0.001828	 0.020533	 0.4101	 1546	 1546	 1546	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 613	 0.004633	 0.051018	 1.1581	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 613	 0.001053	 0.013843	 0.4765	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 613	 0.002888	 0.031752	 0.7595	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 613	 0.001053	 0.01383	 0.4765	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 614	 0.003319	 0.021472	 0.0405	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 614	 0.001205	 0.007684	 0.0142	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 2685	 0.002212	 0.014558	 0.0299	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1823	 2685	 0.000435	 0.002923	 0.0091	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 614	 0.000593	 0.00397	 0.4759	 530.0	 530.0	 530.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 614	 0.001146	 0.007664	 0.0142	 493.0	 493.0	 493.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 615	 0.000178	 0.001185	 0.002	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 616	 0.070799	 0.154951	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	1685	 616	 0.042832	 0.241371	 0.0048	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 617	 9.9e-05	 0.000454	 0.001	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 618	 0.031242	 0.101537	 0.0012	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 618	 0.025195	 0.077097	 0.0015	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 619	 0.015193	 0.061854	 0.0031	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	795	 620	 0.06324	 0.155077	 0.0017	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 2686	 0.028521	 0.087402	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	1486	 622	 0.041824	 0.153691	 0.002	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 622	 0.084404	 0.230537	 0.002	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 622	 0.073621	 0.187352	 0.0023	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 623	 0.005669	 0.026094	 0.0476	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1879	 623	 0.001719	 0.01199	 0.0213	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1907	 624	 0.018272	 0.041481	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	2122	 624	 0.075062	 0.195556	 0.0012	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 626	 1.3e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	752	 627	 0.000138	 0.000336	 0.0314	 85214	 85214	 85214	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 628	 0.007559	 0.015621	 0.0217	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 628	 0.006218	 0.011382	 0.0057	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 628	 0.01285	 0.048879	 0.0683	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 628	 0.017637	 0.039808	 0.0067	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 628	 0.014109	 0.036281	 0.0102	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 628	 0.007055	 0.016881	 0.0194	 1614	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 628	 0.016125	 0.04258	 0.0079	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 628	 0.013605	 0.033762	 0.0102	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	1178	 629	 0.001888	 0.013914	 0.403	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 630	 0.08642	 0.260015	 0.0073	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 630	 0.048375	 0.132275	 0.0015	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1986	 631	 2e-05	 9.9e-05	 0.0	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 632	 0.063089	 0.153162	 0.0021	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 632	 0.058957	 0.141849	 0.0014	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1987	 633	 0.027211	 0.049887	 0.0005	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	652	 634	 0.002481	 0.012134	 0.0218	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 634	 0.003398	 0.021373	 0.04	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 634	 0.00081	 0.005551	 0.0101	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 635	 0.000756	 0.002268	 0.0	 12351	 12351	 12351	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 636	 0.000336	 0.000672	 0.0469	 41198	 41198	 41198	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 637	 0.005294	 0.036464	 0.0618	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 638	 0.006558	 0.029807	 0.0516	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 639	 0.002696	 0.007155	 0.0081	 3862	 3862	 3862	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 639	 0.009574	 0.038297	 0.0152	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 639	 0.029378	 0.111287	 0.0018	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2023	 640	 0.001975	 0.013412	 0.0233	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 641	 0.018645	 0.041572	 0.0005	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 642	 0.022928	 0.058453	 0.0006	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 642	 0.01348	 0.034467	 0.0004	 814	 814	 814	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 643	 0.012144	 0.049332	 0.0012	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 643	 0.012094	 0.049206	 0.0009	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	629	 644	 0.005017	 0.033403	 0.0618	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	656	 644	 0.003595	 0.019635	 0.0354	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1038	 644	 0.001422	 0.008217	 0.1007	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 644	 0.002212	 0.014044	 0.0253	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 644	 0.001408	 0.008494	 0.2344	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 644	 0.002647	 0.01762	 0.0324	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 644	 0.002212	 0.013985	 0.0263	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 644	 0.000336	 0.002232	 0.004	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 645	 4.8e-05	 8.8e-05	 0.1993	 321303	 321303	 321303	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 2688	 4.8e-05	 8.8e-05	 0.1993	 321303	 321303	 321303	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 646	 4.8e-05	 8.8e-05	 0.001	 314228	 314228	 314228	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 2689	 4.8e-05	 8.8e-05	 0.001	 314228	 314228	 314228	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 2692	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 650	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 2690	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 2691	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 651	 0.000316	 0.001067	 0.2359	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1733	 651	 0.000395	 0.002706	 0.0253	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 651	 0.000217	 0.001817	 0.1812	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 651	 0.002193	 0.014736	 0.0461	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 651	 0.001225	 0.007822	 0.0324	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 651	 0.001225	 0.007822	 0.0324	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 652	 0.002779	 0.013788	 0.0243	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 653	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 2693	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	770	 654	 0.005057	 0.033561	 0.0607	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1693	 657	 0.004913	 0.032622	 0.0608	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	661	 659	 0.00033	 0.001503	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	661	 2694	 0.000296	 0.001349	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 2695	 7e-06	 0.000132	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 660	 7e-06	 0.000125	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 661	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 661	 0.00322	 0.014835	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 661	 0.00083	 0.00796	 0.0334	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2698	 661	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 661	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	872	 2700	 0.004283	 0.014109	 0.0033	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 2700	 0.002922	 0.005348	 0.0033	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	2154	 664	 0.005291	 0.009826	 0.0044	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 664	 0.006218	 0.011382	 0.0068	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 664	 0.001764	 0.003527	 0.0025	 7488	 7488	 7488	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 2700	 0.023683	 0.083396	 0.001	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 665	 0.002015	 0.013551	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 665	 0.001094	 0.011536	 0.036	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 665	 2e-05	 9.9e-05	 0.0405	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 665	 0.001205	 0.008	 0.0152	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 665	 0.00403	 0.027496	 0.0516	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 665	 0.001096	 0.011575	 0.0359	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 665	 2e-05	 0.000119	 0.0506	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 666	 0.078105	 0.22449	 0.002	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	753	 667	 0.081129	 0.180902	 0.0021	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 668	 0.001383	 0.007881	 0.0142	 3869	 3869	 3869	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 669	 0.037037	 0.09675	 0.0019	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 669	 0.022172	 0.056437	 0.0006	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 2701	 0.000256	 0.004377	 0.156	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 670	 0.000263	 0.004377	 0.1574	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 2703	 0.000263	 0.004384	 0.1588	 997.0	 997.0	 997.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 2702	 0.000263	 0.004391	 0.1588	 1592.0	 1592.0	 1592.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 671	 0.000134	 0.000245	 0.001	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 672	 0.007861	 0.049509	 0.0006	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 673	 0.000178	 0.000711	 0.079	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 673	 0.000316	 0.001264	 0.1417	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 674	 0.010943	 0.072652	 0.1347	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	1131	 674	 0.014775	 0.052267	 0.083	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 674	 0.020543	 0.073482	 0.1174	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 674	 0.015921	 0.072375	 0.1281	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 674	 0.008435	 0.056138	 0.1043	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 675	 0.009912	 0.044701	 0.1817	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 675	 0.007605	 0.036603	 0.0658	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 675	 0.005114	 0.03518	 0.0668	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 676	 0.00557	 0.03362	 0.0628	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 677	 0.002975	 0.019475	 0.0504	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 677	 0.002627	 0.017975	 0.0324	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 677	 0.002993	 0.019532	 0.0472	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 678	 0.049131	 0.139078	 0.0016	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	1661	 679	 0.002923	 0.020543	 0.0365	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 2704	 0.000142	 0.000822	 0.1073	 37106	 37106	 37106	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 681	 0.000217	 0.000849	 0.1104	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	682	 1764	 0.000138	 0.000296	 0.0223	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 683	 0.005965	 0.039901	 0.0739	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1924	 683	 0.000889	 0.006104	 0.0111	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1208	 684	 0.004681	 0.021847	 0.1382	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 685	 0.032452	 0.110179	 0.0013	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	948	 685	 0.071303	 0.193752	 0.0022	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 685	 0.017259	 0.056941	 0.002	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 686	 0.002953	 0.019787	 0.0363	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 686	 0.002963	 0.019733	 0.0365	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 687	 0.000494	 0.002212	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 687	 0.000474	 0.002193	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 689	 0.002086	 0.025528	 0.4534	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 689	 0.001432	 0.015665	 0.3754	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 690	 0.020408	 0.085412	 0.0014	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 691	 0.010582	 0.022928	 0.0231	 1170	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	1641	 691	 0.04132	 0.114135	 0.0022	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 691	 0.015117	 0.04006	 0.0005	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 691	 0.011086	 0.02318	 0.0211	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 692	 0.002726	 0.018212	 0.0481	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 692	 0.002765	 0.018212	 0.0486	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2023	 693	 0.000375	 0.002548	 0.0061	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 693	 0.001969	 0.011678	 0.0223	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1992	 2705	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1993	 694	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 695	 0.003832	 0.019733	 0.0359	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 697	 0.022172	 0.056437	 0.0006	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 699	 0.019904	 0.085412	 0.0039	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 700	 0.026959	 0.061225	 0.0007	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	1136	 700	 0.038801	 0.081885	 0.0009	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	1226	 701	 0.010834	 0.052658	 0.001	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	1490	 701	 0.010293	 0.018841	 0.0002	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 701	 0.007055	 0.026707	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	1961	 703	 0.002771	 0.011338	 0.0002	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 703	 0.007307	 0.031242	 0.0059	 921	 921	 921	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 704	 0.023432	 0.074074	 0.001	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 704	 0.04384	 0.109851	 0.001	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 705	 5.9e-05	 0.000138	 0.0081	 206236	 206236	 206236	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 707	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1995	 2707	 2e-05	 0.000198	 0.001	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	987	 708	 0.000217	 0.00081	 0.1002	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 2713	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 710	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 2711	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 2712	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 711	 0.00381	 0.02541	 0.0471	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 712	 0.007559	 0.050643	 0.001	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 712	 0.054422	 0.150214	 0.0844	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1584	 712	 0.031746	 0.136054	 0.0016	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	1825	 712	 0.023432	 0.126228	 0.002	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 712	 0.036281	 0.153943	 0.002	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 712	 0.021164	 0.071907	 0.0012	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 712	 0.008314	 0.035525	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 712	 0.035273	 0.089947	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 712	 0.008314	 0.035525	 0.001	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	2785	 713	 0.00476	 0.032099	 0.0567	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 713	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1468	 713	 0.000593	 0.00403	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 713	 0.0016	 0.010884	 0.0192	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 715	 0.018712	 0.063684	 0.1073	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 715	 0.01297	 0.04896	 0.079	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	782	 716	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 716	 0.075334	 0.13807	 0.0024	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	782	 716	 0.010078	 0.018645	 0.0236	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 717	 0.001363	 0.009106	 0.0304	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 717	 0.011437	 0.078084	 0.1377	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1975	 2714	 0.002016	 0.007055	 0.0065	 4122	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 718	 0.000171	 0.000313	 0.0	 84779	 84779	 84779	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 719	 0.007307	 0.019904	 0.0002	 1393	 1393	 1393	 0.0	 0.0	 1	 -30.0	 30.0;
	841	 720	 0.000869	 0.004407	 0.4212	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 721	 0.003527	 0.015117	 0.0002	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	1975	 721	 0.001764	 0.006047	 0.006	 4688	 4688	 4688	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 721	 0.003779	 0.015117	 0.0011	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 722	 0.003527	 0.009322	 0.0106	 3052	 3052	 3052	 0.0	 0.0	 1	 -30.0	 30.0;
	1915	 723	 0.000756	 0.002016	 0.0	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 724	 0.000217	 0.000474	 0.0445	 59375	 59375	 59375	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 725	 0.002765	 0.012998	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 726	 0.001205	 0.015845	 0.5487	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 726	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 726	 0.001205	 0.015852	 0.5487	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 726	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	947	 728	 0.001622	 0.010949	 0.0816	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1099	 728	 0.004361	 0.019407	 0.0346	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1661	 728	 0.00644	 0.043615	 0.081	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1099	 728	 0.002884	 0.019127	 0.0357	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 729	 0.003553	 0.040406	 0.8776	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 729	 0.001413	 0.020512	 0.5314	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 729	 0.002029	 0.020568	 0.5372	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 729	 0.001233	 0.012465	 0.3235	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 729	 0.00141	 0.019927	 0.5463	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 730	 0.000983	 0.012909	 0.4476	 2461	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 731	 0.028647	 0.075032	 0.0049	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 732	 0.001058	 0.006576	 0.0116	 4433	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 733	 0.011299	 0.051259	 0.0881	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 733	 0.002232	 0.012286	 0.0218	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 733	 0.003714	 0.017975	 0.0405	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 735	 0.017385	 0.074326	 0.0091	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 735	 0.013857	 0.056185	 0.0108	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 738	 0.003812	 0.018568	 0.0557	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 2717	 0.003911	 0.01679	 0.0284	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 738	 0.005057	 0.031131	 0.0587	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 2717	 0.002785	 0.018153	 0.0334	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 739	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 739	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 739	 0.005422	 0.039197	 0.841	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 740	 0.000171	 0.000313	 0.0	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 742	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 2723	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 2724	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 2725	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 2726	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 2722	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1404	 743	 0.00164	 0.011299	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 743	 0.002647	 0.018035	 0.0334	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1215	 2727	 0.045855	 0.140338	 0.002	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 745	 0.031494	 0.076846	 0.001	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 747	 2e-05	 0.000138	 0.001	 509.0	 509.0	 509.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2000	 747	 0.000395	 0.002647	 0.0051	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 748	 0.003259	 0.021669	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 748	 0.00324	 0.021768	 0.0395	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	982	 750	 0.002351	 0.011022	 0.0182	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	1213	 750	 0.002252	 0.015842	 0.079	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 750	 0.00132	 0.013076	 0.0385	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 750	 0.005531	 0.027042	 0.0628	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1734	 752	 0.000138	 0.000316	 0.0314	 89765	 89765	 89765	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 753	 0.076594	 0.194507	 0.0022	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	1889	 753	 0.120106	 0.327186	 0.0042	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	1941	 753	 0.180957	 0.33124	 0.0039	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 754	 0.009264	 0.038696	 0.0638	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 754	 0.022084	 0.061906	 0.1013	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 754	 0.017185	 0.07921	 0.1336	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 755	 0.000296	 0.001936	 0.0137	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 757	 0.00237	 0.005748	 0.0111	 5017	 5017	 5017	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 758	 0.000336	 0.002252	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 759	 0.068531	 0.186697	 0.0021	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 759	 0.016881	 0.045855	 0.0006	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 760	 0.022676	 0.070295	 0.0065	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 760	 0.035021	 0.081129	 0.0025	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 761	 0.001008	 0.00252	 0.001	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	773	 762	 0.117914	 0.298816	 0.0034	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 762	 0.059234	 0.162761	 0.0018	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 762	 0.071429	 0.181532	 0.0021	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 762	 0.03225	 0.081885	 0.0009	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	1946	 762	 0.008566	 0.053666	 0.0007	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 762	 0.03225	 0.081129	 0.001	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 763	 0.011556	 0.052998	 0.0942	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 763	 0.011299	 0.057086	 0.1013	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 765	 0.002173	 0.014519	 0.0273	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 766	 0.026449	 0.06568	 0.0207	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 766	 0.012133	 0.030178	 0.0095	 1044	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	830	 768	 0.000942	 0.004946	 0.0182	 6148	 6148	 6148	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 768	 0.008533	 0.038716	 0.0678	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 768	 0.002977	 0.014748	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 768	 0.002483	 0.016496	 0.0304	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 768	 0.004188	 0.019082	 0.0334	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1555	 768	 0.001742	 0.01171	 0.038	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 768	 0.001414	 0.009527	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 769	 0.008672	 0.04002	 0.084	 256.0	 256.0	 256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 769	 0.001237	 0.005636	 0.0256	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2810	 770	 0.003062	 0.020365	 0.0385	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 770	 0.000786	 0.00524	 0.0273	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2005	 770	 0.003615	 0.024336	 0.0445	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2878	 770	 0.001274	 0.008486	 0.0152	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	881	 771	 0.001634	 0.016835	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 771	 0.000935	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 771	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	2756	 771	 0.001634	 0.016842	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 771	 0.000934	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 771	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 772	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 2730	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 2731	 0.001512	 0.006803	 0.0001	 4237	 4237	 4237	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 2733	 0.000111	 0.001604	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 774	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 2732	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 2736	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 2735	 0.000111	 0.001606	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 2734	 0.000111	 0.001616	 0.0419	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 775	 0.000988	 0.006953	 0.0273	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 776	 0.013102	 0.089947	 0.002	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 776	 0.016881	 0.071806	 0.001	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 776	 0.066012	 0.21542	 0.002	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	796	 778	 0.005195	 0.034528	 0.0648	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1955	 779	 0.0013	 0.005888	 0.0101	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1954	 2738	 0.001306	 0.005912	 0.0101	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 782	 0.184933	 0.456034	 0.0052	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 782	 0.031494	 0.11615	 0.0014	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 782	 0.111363	 0.3419	 0.0039	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	1685	 782	 0.039305	 0.161502	 0.002	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	1687	 783	 0.002094	 0.013294	 0.0243	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 785	 0.006499	 0.043259	 0.08	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	981	 785	 0.003737	 0.037823	 0.1088	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1969	 785	 0.001254	 0.008365	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 786	 0.00247	 0.027208	 0.5747	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 786	 0.001766	 0.019792	 0.3957	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 787	 0.008062	 0.019904	 0.0187	 1375	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 787	 0.007811	 0.019652	 0.0187	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 788	 0.000401	 0.001817	 0.003	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 2739	 0.0032	 0.014637	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 571	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	949	 789	 0.003401	 0.022763	 0.0415	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 789	 0.004122	 0.027542	 0.0501	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1635	 790	 0.001817	 0.008198	 0.0142	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2076	 790	 0.001857	 0.012504	 0.0233	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 792	 0.002844	 0.018884	 0.0354	 402.0	 402.0	 402.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 793	 0.023683	 0.052406	 0.001	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 794	 0.00025	 0.0025	 0.0	 14962	 14962	 14962	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 797	 4e-05	 0.000375	 0.0	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 2740	 5.9e-05	 0.000395	 0.0	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 2741	 5.9e-05	 0.000454	 0.001	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 799	 0.000494	 0.003319	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 799	 0.00318	 0.016237	 0.0289	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 799	 0.003565	 0.013003	 0.0218	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 799	 0.001363	 0.006104	 0.0111	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 799	 0.000514	 0.003496	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 799	 0.000988	 0.004879	 0.0091	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	924	 800	 0.006914	 0.021235	 0.0013	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 800	 0.008395	 0.019753	 0.0047	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 802	 0.000356	 0.003319	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2742	 0.00036	 0.003356	 0.0167	 853.0	 853.0	 853.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 803	 0.001086	 0.007289	 0.0132	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 803	 0.00308	 0.020628	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1645	 803	 0.001067	 0.007289	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 803	 0.003022	 0.020109	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2981	 803	 0.003022	 0.020168	 0.0435	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 805	 0.019904	 0.051902	 0.0106	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 806	 0.025156	 0.046047	 0.0021	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	2881	 806	 0.003779	 0.009826	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 806	 0.0194	 0.103553	 0.001	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	2053	 806	 0.008062	 0.034266	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	1621	 806	 0.003023	 0.009826	 0.0	 2872	 2872	 2872	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 807	 0.001705	 0.010438	 0.0304	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 809	 0.005896	 0.030713	 0.0396	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 810	 0.001106	 0.007546	 0.0354	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	790	 811	 0.000158	 0.001343	 0.5594	 654.0	 654.0	 654.0	 0.0	 0.0	 1	 -30.0	 30.0;
	833	 812	 0.002264	 0.015056	 0.0273	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 812	 0.002173	 0.014617	 0.0263	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1446	 812	 0.000375	 0.002509	 0.004	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 812	 0.001746	 0.011648	 0.0216	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1896	 812	 0.000909	 0.00478	 0.0086	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1981	 812	 0.001936	 0.011239	 0.0203	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 812	 0.001738	 0.011635	 0.0213	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 812	 0.000751	 0.004148	 0.0101	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 812	 0.001679	 0.01122	 0.0203	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 815	 0.000381	 0.000697	 0.0486	 38967	 38967	 38967	 0.0	 0.0	 1	 -30.0	 30.0;
	2752	 818	 0.000158	 0.000593	 0.0688	 50437	 50437	 50437	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 818	 0.000336	 0.001304	 0.162	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 818	 4e-05	 0.000237	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 818	 0.000296	 0.002667	 0.1863	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 818	 0.000362	 0.000664	 0.0466	 40928	 40928	 40928	 0.0	 0.0	 1	 -30.0	 30.0;
	2862	 818	 0.000435	 0.001659	 0.3351	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 819	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 821	 0.001975	 0.004938	 0.0	 5585	 5585	 5585	 0.0	 0.0	 1	 -30.0	 30.0;
	824	 822	 2e-05	 0.000198	 0.0233	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 2964	 0.000237	 0.002272	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 2964	 0.000257	 0.002449	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2748	 2964	 2e-05	 0.000198	 0.0132	 870.0	 870.0	 870.0	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 823	 1e-05	 0.0001	 0.0462	 895.0	 895.0	 895.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 823	 0.001143	 0.011399	 0.2946	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 823	 0.001087	 0.012375	 0.2513	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1102	 826	 0.010582	 0.026455	 0.0003	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	1159	 827	 0.000879	 0.0037	 0.085	 8140	 8140	 8140	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 827	 0.000533	 0.003556	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 827	 0.000869	 0.003437	 0.0851	 8731	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 2749	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2011	 828	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 829	 4e-05	 0.000237	 0.0	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 831	 0.000852	 0.008636	 0.2224	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 831	 0.001288	 0.013033	 0.335	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 832	 2e-05	 0.000198	 0.001	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	956	 833	 0.001541	 0.010291	 0.0238	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 833	 0.000178	 0.001225	 0.002	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 833	 0.002489	 0.016612	 0.0304	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 833	 0.002805	 0.01282	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	956	 833	 0.001541	 0.010252	 0.0192	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2103	 833	 0.000158	 0.001106	 0.002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 834	 0.00243	 0.01357	 0.0248	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 836	 0.001402	 0.005452	 0.0101	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 837	 0.00214	 0.024723	 0.5545	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 837	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 837	 0.000229	 0.002465	 0.0549	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 837	 0.000561	 0.006198	 0.1473	 1731.0	 1731.0	 1731.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 837	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 839	 0.008535	 0.038929	 0.0678	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 839	 0.001106	 0.005136	 0.0081	 5972	 5972	 5972	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 840	 0.042832	 0.179894	 0.0022	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 842	 0.003081	 0.020109	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2028	 842	 0.000533	 0.003536	 0.0061	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2981	 2750	 0.001067	 0.004192	 0.0876	 7175	 7175	 7175	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 843	 0.001067	 0.004306	 0.08	 6997	 6997	 6997	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 844	 0.006444	 0.012667	 0.0036	 2204	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 845	 0.001936	 0.01284	 0.0243	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1969	 845	 0.001363	 0.015427	 0.0445	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 846	 0.000233	 0.00156	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 847	 0.017989	 0.07546	 0.0069	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	816	 848	 0.000691	 0.003852	 0.0071	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 848	 0.000454	 0.003121	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 848	 0.001896	 0.011022	 0.0284	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 848	 0.000514	 0.002331	 0.0116	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 848	 0.000474	 0.003101	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1893	 848	 0.002272	 0.011062	 0.0263	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 849	 0.000171	 0.000313	 0.0001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 850	 5.9e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 850	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2904	 2751	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 853	 0.068783	 0.23356	 0.0027	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	1398	 853	 0.032754	 0.111363	 0.0013	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 854	 0.00081	 0.008193	 0.2108	 1694.0	 1694.0	 1694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1039	 855	 0.000756	 0.002016	 0.0	 13856	 13856	 13856	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 855	 0.02287	 0.041864	 0.0004	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	1705	 855	 0.089947	 0.230537	 0.003	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 855	 0.194331	 0.531091	 0.006	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 856	 0.002528	 0.016731	 0.0304	 469.0	 469.0	 469.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 856	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 856	 0.008988	 0.060563	 0.1043	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1935	 858	 0.065256	 0.259259	 0.0031	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 859	 0.002193	 0.014716	 0.0263	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 859	 0.001323	 0.00883	 0.0162	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	852	 860	 0.039557	 0.087679	 0.001	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	1781	 860	 0.04258	 0.09423	 0.001	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 862	 0.013102	 0.035525	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	1419	 863	 0.001481	 0.007072	 0.0121	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 863	 0.001956	 0.013136	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 864	 0.011	 0.056595	 0.1027	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 865	 0.038574	 0.10199	 0.0201	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 866	 0.005795	 0.014361	 0.0135	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 866	 0.006551	 0.016125	 0.0152	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 867	 0.02066	 0.052154	 0.0006	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 868	 0.026984	 0.068808	 0.0022	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 868	 0.068783	 0.174099	 0.0063	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 870	 0.000691	 0.004563	 0.0081	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1139	 871	 0.084656	 0.181406	 0.002	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 873	 0.07609	 0.171076	 0.0187	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 873	 0.036533	 0.093726	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 2754	 0.069035	 0.175359	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 2754	 0.019501	 0.079516	 0.0085	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 2754	 0.095742	 0.282691	 0.0062	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 2754	 0.013605	 0.037541	 0.0019	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 2754	 0.066264	 0.168304	 0.0019	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 873	 0.019652	 0.080625	 0.0102	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 874	 0.002449	 0.016336	 0.0354	 479.0	 479.0	 479.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 874	 0.006461	 0.021728	 0.0385	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 874	 0.002568	 0.017146	 0.0405	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 875	 0.000457	 0.005035	 0.1458	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 876	 0.029479	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 876	 0.076594	 0.160242	 0.0019	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	1061	 876	 0.02973	 0.124717	 0.0016	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 877	 0.04258	 0.079617	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 2755	 0.015243	 0.050617	 0.0006	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	1562	 2755	 0.055984	 0.153691	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 878	 0.017561	 0.045906	 0.0035	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 878	 0.011842	 0.029982	 0.0	 916	 916	 916	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 879	 0.003	 0.013517	 0.0243	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 879	 0.003812	 0.013017	 0.0213	 2283	 2283	 2283	 0.0	 0.0	 1	 -30.0	 30.0;
	1070	 882	 0.0252	 0.085911	 0.0252	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 2764	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 884	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 2762	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 2763	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 2766	 2e-06	 0.001244	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 2765	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 885	 0.002449	 0.011141	 0.0203	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 885	 0.000672	 0.003141	 0.0051	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 886	 0.057697	 0.12522	 0.0002	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 887	 0.000756	 0.002016	 0.0001	 13714	 13714	 13714	 0.0	 0.0	 1	 -30.0	 30.0;
	2020	 888	 0.000296	 0.000751	 0.001	 38032	 38032	 38032	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 889	 5.9e-05	 0.000198	 0.0091	 148594	 148594	 148594	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 2767	 4e-05	 0.000198	 0.0051	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 890	 0.113379	 0.252457	 0.003	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 891	 0.044848	 0.131519	 0.0015	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 2768	 8e-05	 0.000147	 0.0091	 184947	 184947	 184947	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 892	 8.7e-05	 0.00016	 0.0091	 169954	 169954	 169954	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 893	 0.00019	 0.00062	 0.001	 48031	 48031	 48031	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 894	 0.003062	 0.020365	 0.0375	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 894	 0.000435	 0.002607	 0.0051	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 2769	 0.000494	 0.002923	 0.0051	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 895	 0.00239	 0.015842	 0.0284	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 895	 0.002765	 0.018548	 0.0344	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 895	 0.005539	 0.038098	 0.0719	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 895	 0.005116	 0.034252	 0.0628	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 895	 0.004306	 0.019919	 0.0354	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 896	 0.007802	 0.036069	 0.0633	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2033	 896	 0.000257	 0.00164	 0.003	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 896	 0.005077	 0.023921	 0.0425	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 897	 0.000514	 0.0048	 0.0172	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2021	 2770	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 898	 0.097279	 0.215092	 0.0025	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 898	 0.01326	 0.024272	 0.0	 1073	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 899	 0.103301	 0.230033	 0.003	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 899	 0.040816	 0.090955	 0.001	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 900	 0.010533	 0.0368	 0.0121	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 901	 0.011206	 0.050285	 0.0899	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1941	 905	 0.006047	 0.011842	 0.0001	 3767	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 906	 2e-05	 0.000198	 0.001	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 2771	 0.001975	 0.013235	 0.0309	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1445	 2771	 0.001284	 0.00879	 0.0162	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 910	 0.002119	 0.02151	 0.5545	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	2836	 911	 0.011536	 0.054933	 0.0931	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 912	 0.001136	 0.014935	 0.5198	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 912	 0.001136	 0.014935	 0.517	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	1073	 913	 0.078105	 0.191232	 0.0021	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	2884	 913	 0.046988	 0.086012	 0.0032	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	1737	 913	 0.030234	 0.073822	 0.0009	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 914	 0.027211	 0.070547	 0.0008	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 914	 0.028723	 0.073066	 0.0046	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 915	 0.002771	 0.007811	 0.0001	 3563	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 2772	 0.003527	 0.010078	 0.0001	 2766	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 916	 0.049131	 0.140338	 0.0017	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 917	 0.009322	 0.017133	 0.0012	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	1931	 919	 0.003996	 0.027473	 0.0516	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1956	 919	 0.007111	 0.048909	 0.0921	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 921	 0.014361	 0.088939	 0.0012	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 921	 0.02066	 0.076594	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 921	 0.014361	 0.090955	 0.0012	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 922	 0.000124	 0.001383	 0.0051	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1313	 922	 0.001047	 0.006953	 0.0132	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 922	 9.9e-05	 0.000277	 0.0284	 104366	 104366	 104366	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 922	 0.003417	 0.022696	 0.0425	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2840	 922	 9.9e-05	 0.000336	 0.0263	 87644	 87644	 87644	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 922	 4e-05	 9.9e-05	 0.0	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1749	 923	 0.042076	 0.100529	 0.0012	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 925	 0.012812	 0.023452	 0.0002	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 926	 0.004484	 0.021195	 0.0365	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 926	 0.00324	 0.014894	 0.0243	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 927	 0.002143	 0.014358	 0.0264	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 928	 0.00403	 0.018054	 0.0349	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 928	 0.004484	 0.021156	 0.0365	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1821	 929	 0.000557	 0.007335	 0.2533	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 2774	 0.000158	 0.000289	 0.0273	 93975	 93975	 93975	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 932	 0.000116	 0.000212	 0.0142	 128083	 128083	 128083	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 2775	 0.000123	 0.000226	 0.0152	 120296	 120296	 120296	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 933	 0.072058	 0.233812	 0.0036	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 935	 0.001327	 0.008873	 0.0466	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 935	 0.002291	 0.01521	 0.0284	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 936	 0.000179	 0.000327	 0.0233	 83031	 83031	 83031	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 937	 0.012094	 0.058957	 0.0172	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 938	 0.004359	 0.018544	 0.0008	 1581	 1581	 1581	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 938	 0.030234	 0.08642	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 938	 0.030234	 0.08642	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 939	 0.001244	 0.008296	 0.0142	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 940	 0.087679	 0.284455	 0.0034	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 941	 0.005845	 0.012925	 0.0001	 2082	 2082	 2082	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 942	 0.042328	 0.173595	 0.001	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 942	 0.008062	 0.047619	 0.0006	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	1809	 942	 0.025447	 0.070295	 0.0008	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 942	 0.017637	 0.056437	 0.0019	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 943	 0.010667	 0.034444	 0.0112	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	1440	 944	 0.009857	 0.066884	 0.1266	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 944	 0.000632	 0.003931	 0.0243	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 944	 0.002153	 0.009758	 0.0172	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 945	 0.097758	 0.247518	 0.0089	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 946	 0.019174	 0.04447	 0.0006	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	1661	 947	 0.003279	 0.022637	 0.0415	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 948	 0.055933	 0.146888	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 948	 0.031545	 0.104006	 0.0043	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 949	 0.001932	 0.012802	 0.0233	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 950	 0.00063	 0.006413	 0.1632	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 951	 0.000593	 0.003951	 0.0339	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 952	 0.000198	 0.001699	 0.1731	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 953	 0.02088	 0.03822	 0.0012	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	2001	 953	 0.024296	 0.118963	 0.0004	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 953	 0.002963	 0.009877	 0.0012	 2532	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 954	 0.010444	 0.032756	 0.0103	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 955	 0.000296	 0.001758	 0.003	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 955	 0.000356	 0.002054	 0.004	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 955	 0.006696	 0.029985	 0.0527	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 957	 0.000222	 0.002327	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 957	 0.001565	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	2115	 957	 0.000914	 0.009875	 0.2238	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 957	 0.001641	 0.021544	 0.7451	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 957	 0.000229	 0.002313	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 957	 0.001558	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 957	 0.001634	 0.021503	 0.7451	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 958	 0.060972	 0.168808	 0.0019	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 958	 0.000252	 0.001008	 0.0	 33358	 33358	 33358	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 959	 0.003378	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 960	 0.000171	 0.000313	 0.0	 83220	 83220	 83220	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 962	 0.071504	 0.176997	 0.0018	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 963	 0.039305	 0.102293	 0.0012	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 965	 0.003826	 0.018665	 0.0334	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2787	 965	 0.00077	 0.003536	 0.0066	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 965	 0.005037	 0.034785	 0.0653	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 965	 0.003615	 0.01762	 0.0314	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 965	 0.000711	 0.004583	 0.0081	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 966	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 966	 0.002596	 0.01165	 0.0203	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 967	 0.000504	 0.00252	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 967	 0.029226	 0.080625	 0.001	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	1942	 968	 0.031746	 0.080121	 0.0009	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 970	 0.004507	 0.013102	 0.0043	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 970	 0.012933	 0.044356	 0.0144	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 970	 0.002711	 0.008889	 0.0032	 3456	 3456	 3456	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 971	 0.000198	 0.000909	 0.002	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 972	 0.002252	 0.010509	 0.0187	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1836	 972	 0.008	 0.03998	 0.0709	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 973	 0.000109	 0.000494	 0.001	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 974	 0.06576	 0.17939	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 975	 0.007811	 0.027211	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 976	 0.022928	 0.094734	 0.0012	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	1288	 976	 0.039053	 0.144117	 0.0086	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 976	 0.014865	 0.033006	 0.0004	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 976	 0.012094	 0.033006	 0.0004	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 976	 0.02318	 0.093978	 0.0013	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 977	 0.005827	 0.02703	 0.0476	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1276	 979	 0.006409	 0.016431	 0.005	 1931	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 980	 0.013102	 0.03477	 0.0004	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 980	 0.074326	 0.157218	 0.0017	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 980	 0.017889	 0.045855	 0.0006	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 981	 0.001956	 0.020958	 0.0871	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 984	 0.057823	 0.168178	 0.0102	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 986	 5.9e-05	 0.000435	 0.0025	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2808	 987	 0.000336	 0.001225	 0.1529	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 987	 0.000138	 0.00079	 0.1063	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 987	 0.000138	 0.000889	 0.1215	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 2778	 0.001764	 0.004787	 0.0042	 5788	 5788	 5788	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 988	 0.001008	 0.003023	 0.003	 9266	 9266	 9266	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 989	 0.011086	 0.028471	 0.0003	 967	 967	 967	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 990	 0.001041	 0.006967	 0.0152	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 991	 0.009067	 0.029116	 0.0486	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 992	 0.024439	 0.101789	 0.001	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	1726	 992	 0.087931	 0.279667	 0.0033	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 993	 0.000701	 0.004599	 0.0082	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 993	 0.000705	 0.00463	 0.0083	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 994	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 995	 0.026959	 0.112875	 0.0023	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 996	 0.001956	 0.008691	 0.0248	 3495	 3495	 3495	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 998	 0.012496	 0.043621	 0.0734	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1293	 998	 0.018805	 0.069215	 0.1235	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 998	 0.012306	 0.062598	 0.1109	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 998	 0.00717	 0.042726	 0.0749	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 999	 0.001627	 0.017031	 0.3812	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2912	 1000	 0.000257	 0.000612	 0.0547	 46632	 46632	 46632	 0.0	 0.0	 1	 -30.0	 30.0;
	2913	 1000	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	1763	 1000	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 1001	 0.000395	 0.005229	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1572	 1002	 0.005017	 0.033521	 0.0607	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 1003	 0.001679	 0.007526	 0.0132	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 1004	 0.000579	 0.001587	 0.0	 17519	 17519	 17519	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 1005	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 1005	 0.004326	 0.019694	 0.0344	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 1005	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 1005	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 1005	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 1005	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 1006	 0.025951	 0.072814	 0.0085	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 1007	 0.000138	 0.000593	 0.0	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 1008	 0.15873	 0.35349	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	1561	 1008	 0.000756	 0.005291	 0.0001	 5579	 5579	 5579	 0.0	 0.0	 1	 -30.0	 30.0;
	1648	 1008	 0.068531	 0.165961	 0.0018	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	1906	 1008	 0.096246	 0.238851	 0.0027	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 1008	 0.005039	 0.012598	 0.0002	 2198	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	2871	 1008	 0.002771	 0.006047	 0.0001	 4483	 4483	 4483	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 1009	 0.007723	 0.032119	 0.0527	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 1009	 0.009541	 0.039585	 0.0648	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 1010	 0.03094	 0.093298	 0.0011	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 1010	 0.015621	 0.04132	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	2790	 1011	 0.001519	 0.010582	 0.0162	 510.0	 510.0	 510.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 1011	 0.002216	 0.014805	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1091	 1011	 0.001529	 0.010637	 0.0162	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 1011	 0.002206	 0.014728	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 1012	 0.000457	 0.006025	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 1012	 0.001856	 0.025166	 0.8563	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 1014	 0.014914	 0.055309	 0.0896	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	1799	 1014	 0.009383	 0.042607	 0.0759	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 1015	 0.002597	 0.020332	 0.4202	 1408.0	 1408.0	 1408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1689	 1015	 0.001932	 0.021399	 0.4448	 1391.0	 1391.0	 1391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1435	 1016	 0.068783	 0.155959	 0.0021	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 1017	 0.000198	 0.000909	 0.001	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 1018	 0.001106	 0.007328	 0.0132	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 1019	 0.015488	 0.067417	 0.1205	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 1022	 0.005985	 0.041383	 0.0739	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 1022	 0.000243	 0.001614	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 1024	 0.003737	 0.024798	 0.0456	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 1024	 0.000869	 0.005886	 0.0415	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1509	 1025	 0.119224	 0.218238	 0.002	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	1862	 1026	 0.000514	 0.004247	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 2781	 5.9e-05	 0.000474	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1244	 1027	 0.004286	 0.020405	 0.0344	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 1027	 0.007625	 0.035378	 0.0668	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 1029	 0.008818	 0.024943	 0.0	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 1031	 0.001146	 0.005551	 0.0101	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1831	 1032	 0.008296	 0.038795	 0.0648	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 1033	 0.024969	 0.106223	 0.0026	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 1034	 0.00528	 0.029102	 0.0496	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1620	 1036	 9.9e-05	 0.001007	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1620	 2783	 0.000119	 0.001067	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 1037	 0.052154	 0.104308	 0.0011	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 1038	 0.000395	 0.001126	 0.1043	 25728	 25728	 25728	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 1041	 0.000849	 0.003812	 0.0071	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2846	 1044	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2848	 1044	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1400	 1044	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2847	 1044	 7.6e-05	 0.000568	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 1046	 1.5e-05	 9.9e-05	 0.001	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 1047	 0.125894	 0.230447	 0.0021	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	1703	 1047	 0.109599	 0.26455	 0.003	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 1048	 0.04006	 0.101033	 0.0068	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 1049	 0.000277	 0.001244	 0.0886	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1050	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1735	 1050	 0.000298	 0.003019	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1050	 0.000505	 0.006637	 0.231	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1735	 1050	 0.000298	 0.003012	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1050	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1050	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 2784	 0.000158	 0.001284	 0.1185	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 2784	 0.000178	 0.001521	 0.1397	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 1052	 1.5e-05	 9.9e-05	 0.0	 309124	 309124	 309124	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 1053	 0.000158	 0.000652	 0.001	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1055	 0.002983	 0.020385	 0.0375	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1553	 1055	 0.005136	 0.034548	 0.0628	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 1056	 0.003049	 0.012824	 0.0194	 2240	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 1057	 0.003779	 0.014865	 0.0018	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 1059	 0.069035	 0.148652	 0.0021	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1978	 1060	 0.005795	 0.022424	 0.0002	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 1060	 0.000504	 0.002268	 0.0	 12709	 12709	 12709	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 1061	 0.02973	 0.124969	 0.0027	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1062	 0.055682	 0.13933	 0.0016	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 1064	 0.001323	 0.008824	 0.0339	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 1066	 0.000731	 0.00484	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1823	 1066	 0.002884	 0.018686	 0.0375	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 1066	 0.001817	 0.012168	 0.0223	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 1066	 0.002785	 0.018884	 0.0334	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 1066	 0.00077	 0.005136	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 1066	 0.003121	 0.020859	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 1066	 0.000731	 0.00482	 0.0091	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 1067	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 1067	 0.001468	 0.014903	 0.3841	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	1901	 1067	 0.00036	 0.003636	 0.0953	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 1067	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 1067	 0.001461	 0.014785	 0.3812	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 1067	 0.001247	 0.012673	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2823	 1067	 9.7e-05	 0.000983	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2824	 1067	 9.7e-05	 0.001025	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1486	 1068	 0.024439	 0.096498	 0.0194	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 1070	 0.006889	 0.018756	 0.0	 1613	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 1072	 0.001644	 0.005778	 0.0018	 5344	 5344	 5344	 0.0	 0.0	 1	 -30.0	 30.0;
	1818	 1075	 0.028471	 0.113883	 0.0032	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	1086	 2786	 0.011753	 0.05438	 0.0931	 294.0	 294.0	 294.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2796	 2786	 0.00083	 0.008375	 0.0263	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 2786	 0.00241	 0.016435	 0.0273	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1663	 2785	 0.007585	 0.028128	 0.0456	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 1076	 0.000652	 0.005946	 0.0172	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2006	 2785	 0.000632	 0.004346	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 2785	 0.000869	 0.008514	 0.0273	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 2785	 0.000632	 0.00559	 0.0476	 494.0	 494.0	 494.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 1078	 0.000252	 0.000504	 0.0003	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 1079	 0.057949	 0.137062	 0.0015	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1580	 1079	 0.011665	 0.066465	 0.0027	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 1079	 0.006475	 0.017259	 0.001	 1602	 1602	 1602	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 1080	 0.046359	 0.100781	 0.0011	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	1629	 1081	 0.001981	 0.003626	 0.0025	 7146	 7146	 7146	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 1084	 0.007862	 0.038716	 0.0658	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2831	 1084	 0.001719	 0.00881	 0.0203	 358.0	 358.0	 358.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 2788	 0.022676	 0.06576	 0.001	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	1878	 1085	 0.024188	 0.061728	 0.001	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 2788	 0.003779	 0.024943	 0.0	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 1085	 0.016377	 0.066264	 0.001	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 1085	 0.003779	 0.024439	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 1089	 0.014262	 0.067397	 0.1124	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1608	 1089	 0.021077	 0.088869	 0.1468	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1638	 1089	 0.00016	 0.000755	 0.0013	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 1089	 0.013452	 0.063625	 0.1063	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 1090	 0.00065	 0.008537	 0.2946	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1648	 1092	 0.081129	 0.199043	 0.002	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 1094	 0.000347	 0.000813	 0.0018	 36366	 36366	 36366	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 2791	 4e-05	 0.000198	 0.0223	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 1095	 2e-05	 0.000198	 0.0152	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 2792	 0.000138	 0.019753	 0.001	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 2792	 0.000494	 0.003002	 0.242	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1886	 2793	 0.002726	 0.013728	 0.084	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 1097	 0.000356	 0.003358	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 2793	 9.9e-05	 0.000198	 0.0091	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 2792	 0.000514	 0.003101	 0.2521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2021	 2792	 0.000909	 0.006005	 0.0142	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 2794	 0.000166	 0.002749	 0.1069	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 1098	 0.001004	 0.010997	 0.2339	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 1098	 0.000159	 0.002701	 0.0982	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 1100	 0.081633	 0.15999	 0.0021	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	1933	 1100	 0.040564	 0.110859	 0.001	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 1102	 0.004283	 0.026959	 0.0003	 1084	 1084	 1084	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 1102	 0.042076	 0.093222	 0.001	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 1102	 0.003275	 0.02066	 0.0002	 1412	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 1102	 0.044848	 0.114135	 0.0013	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 1103	 0.000395	 0.002686	 0.0051	 490.0	 490.0	 490.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 1105	 0.005291	 0.028219	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 2795	 0.01914	 0.035035	 0.0329	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	1612	 2795	 0.001512	 0.005543	 0.0055	 5139	 5139	 5139	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 2795	 0.007055	 0.029479	 0.001	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 2795	 0.003023	 0.021164	 0.001	 1382	 1382	 1382	 0.0	 0.0	 1	 -30.0	 30.0;
	2080	 1105	 0.003275	 0.022676	 0.001	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	1213	 2796	 0.000316	 0.002351	 0.0061	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 2796	 0.000512	 0.001327	 0.159	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 1107	 0.029479	 0.062988	 0.0015	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 1107	 0.026329	 0.069866	 0.0021	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 1107	 0.029479	 0.062988	 0.0007	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 1108	 0.001146	 0.008296	 0.0663	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1702	 1109	 0.000711	 0.00324	 0.2916	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1110	 0.001857	 0.008435	 0.0152	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 1110	 0.002647	 0.013254	 0.0243	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 1111	 0.001146	 0.010923	 0.1706	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 1111	 0.001185	 0.010844	 0.1671	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 1113	 0.000852	 0.011233	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 1113	 0.000852	 0.011226	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 1114	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 1114	 0.011338	 0.048627	 0.001	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1116	 0.047115	 0.196523	 0.0068	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 1120	 0.001101	 0.012181	 0.2599	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 1121	 0.013303	 0.036306	 0.0053	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	1661	 1123	 0.003356	 0.026424	 0.0458	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1662	 1124	 0.035273	 0.150164	 0.0021	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	1680	 1124	 0.015873	 0.066012	 0.001	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 1124	 0.075586	 0.202822	 0.0021	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	1812	 1125	 0.000573	 0.003832	 0.0071	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 1125	 0.003615	 0.025225	 0.0486	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1800	 1126	 0.026707	 0.112371	 0.0013	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	1714	 1127	 0.017637	 0.044848	 0.0086	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 1129	 2.1e-05	 0.000127	 0.1141	 1092.0	 1092.0	 1092.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 1129	 0.000111	 0.001932	 0.0289	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 1129	 2.1e-05	 0.000127	 0.1155	 1053.0	 1053.0	 1053.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2051	 2800	 2e-05	 0.000198	 0.0172	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 1132	 2e-05	 0.000198	 0.0142	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 1134	 0.003461	 0.013896	 0.0243	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2084	 1135	 0.013605	 0.033258	 0.003	 822	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 1136	 0.069035	 0.150416	 0.0016	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 1136	 0.001512	 0.004031	 0.0001	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 1136	 0.004283	 0.011842	 0.0002	 2345	 2345	 2345	 0.0	 0.0	 1	 -30.0	 30.0;
	2053	 1137	 0.009826	 0.026455	 0.0003	 1047	 1047	 1047	 0.0	 0.0	 1	 -30.0	 30.0;
	1737	 1139	 0.064752	 0.145629	 0.0016	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 1140	 0.048879	 0.16125	 0.0018	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	1991	 1140	 0.023683	 0.060217	 0.0006	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	1997	 1140	 0.04006	 0.101789	 0.0011	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 1141	 0.001462	 0.006677	 0.1488	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 1141	 0.001231	 0.008198	 0.0587	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 1141	 0.000865	 0.005772	 0.0101	 436.0	 436.0	 436.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 1141	 0.002588	 0.015862	 0.0304	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 1142	 0.063316	 0.146813	 0.0025	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1142	 0.017385	 0.037541	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 1143	 0.011804	 0.05293	 0.0942	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 1147	 0.001101	 0.012445	 0.3105	 1488.0	 1488.0	 1488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 1147	 0.0009	 0.007479	 0.0982	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1846	 1147	 0.002209	 0.024924	 0.5733	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 1147	 0.0009	 0.00741	 0.13	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 1148	 0.07609	 0.180146	 0.003	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 2801	 0.082892	 0.184933	 0.002	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 1149	 0.000395	 0.002607	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1845	 1150	 0.01022	 0.054673	 0.0997	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1985	 1150	 0.003488	 0.015777	 0.0284	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 1153	 0.003275	 0.007307	 0.0	 3711	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 1154	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	2070	 1155	 0.024969	 0.073268	 0.0013	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	2151	 1155	 0.025951	 0.090955	 0.001	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 1155	 0.024969	 0.083094	 0.001	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 1156	 0.029978	 0.100778	 0.0366	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 1157	 0.002016	 0.005291	 0.0001	 5215	 5215	 5215	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 1157	 0.092467	 0.244898	 0.0028	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 1160	 0.001025	 0.008148	 0.0142	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 1161	 0.001512	 0.003779	 0.0001	 7403	 7403	 7403	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 1162	 4.3e-05	 9e-05	 0.004	 310318	 310318	 310318	 0.0	 0.0	 1	 -30.0	 30.0;
	2865	 1163	 0.00079	 0.003931	 0.0071	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 1163	 0.001442	 0.006696	 0.0121	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1473	 2982	 0.013983	 0.047468	 0.0025	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 2982	 0.087075	 0.287932	 0.0029	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 1165	 0.04006	 0.07735	 0.0008	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 1166	 3.6e-05	 9.3e-05	 0.0121	 655.0	 655.0	 655.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 1167	 2.8e-05	 0.000277	 0.0058	 2187.0	 2187.0	 2187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 1168	 0.001734	 0.018573	 0.4072	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 1168	 0.002181	 0.031662	 0.8231	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 2807	 0.001711	 0.017313	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 2807	 0.002181	 0.031648	 0.8202	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 1171	 0.000198	 0.000652	 0.5832	 511.0	 511.0	 511.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 1171	 0.000316	 0.001442	 0.1326	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 1171	 0.000237	 0.001422	 0.1873	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 1171	 0.000257	 0.001007	 0.1215	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 1174	 0.000773	 0.001416	 0.0006	 18362	 18362	 18362	 0.0	 0.0	 1	 -30.0	 30.0;
	1865	 1175	 0.003319	 0.022716	 0.0415	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	1204	 1176	 0.024307	 0.078747	 0.0251	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	1827	 1178	 3.4e-05	 9.4e-05	 0.002	 286.0	 286.0	 286.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 1178	 0.003297	 0.021902	 0.0466	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 1179	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 1179	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 1179	 0.000942	 0.009536	 0.2455	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 1180	 0.012346	 0.033258	 0.0004	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 1181	 0.042051	 0.106601	 0.0012	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 1181	 0.015369	 0.04258	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 2809	 0.000277	 0.000632	 0.0607	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 1182	 0.000395	 0.000731	 0.0628	 37253	 37253	 37253	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 1183	 0.000178	 0.000928	 0.3564	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1578	 1184	 0.021416	 0.07735	 0.0093	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 1185	 0.012247	 0.044385	 0.0739	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 2810	 9.9e-05	 0.000988	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 1186	 0.006918	 0.046044	 0.0851	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2856	 1187	 0.000158	 0.000289	 0.0203	 93975	 93975	 93975	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 2811	 0.000145	 0.000265	 0.0182	 102466	 102466	 102466	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 1188	 0.000222	 0.000711	 0.0004	 43126	 43126	 43126	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 1189	 0.000968	 0.00644	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 1191	 0.073318	 0.197531	 0.0035	 141	 141	 141	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 1191	 0.052406	 0.141345	 0.0028	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 1194	 0.000229	 0.000419	 0.0527	 64995	 64995	 64995	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 2813	 0.000229	 0.000419	 0.0527	 64995	 64995	 64995	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 2812	 0.000284	 0.00052	 0.0461	 52379	 52379	 52379	 0.0	 0.0	 1	 -30.0	 30.0;
	2903	 1197	 4e-05	 0.001086	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2908	 1197	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 1198	 0.050894	 0.128748	 0.0014	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	1726	 1199	 0.124501	 0.227898	 0.0024	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 1200	 0.009007	 0.043872	 0.0749	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 1200	 0.002738	 0.018562	 0.04	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 1200	 0.002078	 0.008442	 0.0152	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 1203	 2.8e-05	 0.000172	 0.0243	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 1204	 0.020569	 0.065387	 0.0217	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 1205	 0.000126	 0.000261	 0.0152	 106993	 106993	 106993	 0.0	 0.0	 1	 -30.0	 30.0;
	1574	 1206	 0.00083	 0.003931	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 1206	 0.002825	 0.018943	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1836	 1206	 0.003338	 0.019161	 0.0349	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 1206	 0.00083	 0.003832	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 1206	 0.002588	 0.017264	 0.0314	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 1207	 0.000356	 0.000988	 0.1094	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 1208	 0.002568	 0.011358	 0.1539	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 1208	 0.000454	 0.00399	 0.3675	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 1208	 0.000909	 0.007901	 0.4445	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 1209	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 1209	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 1214	 0.000425	 0.001934	 0.003	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1825	 1215	 0.045603	 0.140338	 0.002	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 1216	 0.005798	 0.039696	 0.0724	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 1216	 0.004938	 0.033165	 0.0607	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 1217	 0.015569	 0.028499	 0.0003	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 1219	 0.001058	 0.001937	 0.161	 14073	 14073	 14073	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 1223	 0.004031	 0.013102	 0.0121	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 1223	 0.015621	 0.039808	 0.0017	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 2818	 0.011842	 0.041824	 0.0472	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1224	 0.001027	 0.012543	 0.0243	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 1224	 0.006935	 0.036516	 0.0663	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1224	 0.001798	 0.012089	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2827	 1224	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	1289	 1224	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 1225	 0.005906	 0.026627	 0.0456	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 2819	 0.005906	 0.026627	 0.0445	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 1226	 0.017385	 0.047367	 0.0102	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	1887	 1226	 0.07483	 0.18972	 0.0071	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	1982	 1226	 0.008617	 0.035097	 0.0015	 823	 823	 823	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 1229	 0.068783	 0.125976	 0.0013	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 1230	 0.004573	 0.020316	 0.0405	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 1232	 0.002825	 0.019239	 0.0476	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 1237	 0.007723	 0.044444	 0.082	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1620	 1238	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1620	 1238	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 1240	 2.1e-05	 0.000339	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 1240	 2.1e-05	 0.000325	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2066	 1242	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 1243	 0.006299	 0.018392	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	1531	 1244	 0.004741	 0.022124	 0.038	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1245	 0.14768	 0.270326	 0.001	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 1247	 0.000198	 0.000751	 0.0921	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1445	 1249	 0.002133	 0.009659	 0.0162	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 1250	 0.044848	 0.142857	 0.0017	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 1251	 0.002438	 0.016458	 0.0314	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 1251	 0.00243	 0.016454	 0.0319	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 1252	 0.057445	 0.119678	 0.0019	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	1498	 1253	 0.000356	 0.001422	 0.0	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 1254	 0.000227	 0.000605	 0.0	 45914	 45914	 45914	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 1258	 0.077324	 0.210154	 0.0033	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 1259	 0.000616	 0.006627	 0.1531	 1754.0	 1754.0	 1754.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 1260	 0.004975	 0.009106	 0.0065	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	2884	 1261	 0.009574	 0.026707	 0.0	 1074	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	1963	 1262	 0.036489	 0.066792	 0.0007	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 1262	 0.049887	 0.126732	 0.0014	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 1263	 0.043084	 0.144873	 0.002	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 1264	 0.000776	 0.004612	 0.1736	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 1264	 0.000119	 0.000691	 0.0076	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 1264	 0.000119	 0.000711	 0.0071	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 1264	 0.001126	 0.005965	 0.0162	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1915	 1266	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 1269	 0.032364	 0.095227	 0.0297	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 1270	 0.017637	 0.075334	 0.002	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 1271	 0.001993	 0.020458	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 1271	 0.001993	 0.020472	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 1274	 0.002686	 0.018173	 0.0324	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1572	 1274	 0.005748	 0.03836	 0.0688	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 1275	 0.005562	 0.010181	 0.0001	 2546	 2546	 2546	 0.0	 0.0	 1	 -30.0	 30.0;
	1659	 1277	 0.000277	 0.002588	 0.0051	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 1278	 0.027211	 0.062988	 0.0007	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 573	 2e-05	 0.000198	 0.0	 359.0	 359.0	 359.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 1280	 0.067422	 0.186621	 0.0021	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 1280	 0.06198	 0.216931	 0.002	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	1906	 1280	 0.059965	 0.147896	 0.0017	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 1280	 0.003527	 0.007811	 0.0	 3467	 3467	 3467	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 1281	 0.002647	 0.011911	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1486	 1282	 0.014059	 0.045578	 0.0006	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 1284	 0.001659	 0.011081	 0.0203	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 1284	 0.002509	 0.011319	 0.0203	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 1286	 0.000928	 0.006183	 0.0111	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 1286	 0.000217	 0.001481	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 1287	 7e-06	 0.00013	 0.0029	 2694.0	 2694.0	 2694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 1288	 0.04258	 0.102797	 0.0067	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 1291	 0.000111	 0.000741	 0.0014	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1830	 1291	 0.001857	 0.008375	 0.0142	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 1291	 9.9e-05	 0.000711	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1586	 1292	 0.000198	 0.000909	 0.001	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 1297	 0.076846	 0.15999	 0.009	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	1429	 1299	 0.013274	 0.060326	 0.1043	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 2828	 2e-05	 0.000198	 0.0091	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 1300	 2e-05	 0.000198	 0.0051	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 1302	 0.053918	 0.133787	 0.002	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 1302	 0.023683	 0.056941	 0.001	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 1302	 0.053666	 0.133787	 0.001	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	1882	 1303	 0.004701	 0.030064	 0.0547	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 1305	 0.001343	 0.007862	 0.0142	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 2829	 2.8e-05	 0.000145	 0.0606	 855.0	 855.0	 855.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 1306	 5e-06	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1306	 572	 1e-05	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 1307	 0.026455	 0.072562	 0.0008	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 1307	 0.032552	 0.067674	 0.0007	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 1308	 9.9e-05	 0.000182	 0.0004	 151180	 151180	 151180	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 1309	 0.00073	 0.001335	 0.1104	 22557	 22557	 22557	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 1310	 0.002016	 0.005543	 0.0001	 5006	 5006	 5006	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 1310	 0.028975	 0.121945	 0.0015	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 1311	 0.018038	 0.057792	 0.0916	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	2020	 1311	 0.001798	 0.004543	 0.0081	 6284	 6284	 6284	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 1312	 0.015873	 0.106828	 0.0018	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	1558	 1318	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2869	 1318	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1614	 1319	 0.000909	 0.003299	 0.0051	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2082	 1321	 0.049635	 0.125976	 0.0014	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 1323	 0.002627	 0.017284	 0.0435	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 1323	 0.002272	 0.011239	 0.0203	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1323	 0.002574	 0.013541	 0.0349	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1733	 2831	 0.001817	 0.012207	 0.0223	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 2831	 0.000375	 0.002509	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 1323	 0.000356	 0.002311	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 2830	 0.003081	 0.020089	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 2830	 0.000375	 0.002528	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 1323	 0.001798	 0.010133	 0.0182	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1323	 0.00097	 0.009481	 0.037	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1990	 2831	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1323	 0.000751	 0.007423	 0.0248	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1989	 2831	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 1324	 0.00099	 0.007576	 0.156	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 2832	 0.000298	 0.003262	 0.0693	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 2832	 0.000561	 0.006288	 0.1574	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 2832	 0.000554	 0.006163	 0.1588	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 1324	 0.000382	 0.005002	 0.1718	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 1324	 0.000381	 0.005	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 1324	 0.000547	 0.006046	 0.1242	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 1325	 0.026455	 0.054674	 0.002	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 1325	 0.010859	 0.026153	 0.0501	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 1327	 0.048324	 0.129478	 0.0026	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 1327	 0.078045	 0.142861	 0.0014	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 1327	 0.048803	 0.125926	 0.0021	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 1328	 0.006262	 0.043595	 0.078	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1748	 1328	 0.001659	 0.011022	 0.0203	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 1328	 0.002744	 0.018746	 0.0349	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1748	 1328	 0.001659	 0.011042	 0.0203	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 1330	 0.001764	 0.004283	 0.0001	 6375	 6375	 6375	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 2833	 0.022424	 0.054926	 0.0064	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 1331	 0.02318	 0.056437	 0.0066	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 1332	 0.003694	 0.02481	 0.0456	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 1332	 0.002963	 0.019793	 0.0694	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 1332	 0.002647	 0.017659	 0.0324	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1804	 1332	 0.00719	 0.033264	 0.0618	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1987	 1334	 0.014361	 0.048375	 0.0006	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 1334	 0.030234	 0.092719	 0.0025	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 1335	 0.006803	 0.015621	 0.0002	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	1937	 1338	 0.002771	 0.011842	 0.0177	 2428	 2428	 2428	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 1339	 0.003457	 0.015704	 0.0284	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1339	 0.00164	 0.021709	 0.0911	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1555	 1340	 2e-05	 9.9e-05	 0.0121	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 1340	 0.000435	 0.002878	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 1342	 0.00252	 0.005039	 0.0	 5241	 5241	 5241	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 1342	 0.006922	 0.012671	 0.004	 2045	 2045	 2045	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 1343	 0.001512	 0.003527	 0.0	 7695	 7695	 7695	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 1344	 0.003931	 0.020365	 0.037	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 1344	 0.002805	 0.012484	 0.0319	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1556	 1345	 0.007309	 0.049876	 0.0881	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1724	 2960	 0.006044	 0.042114	 0.0729	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 1346	 0.009826	 0.020912	 0.0009	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	1932	 1346	 0.030234	 0.082389	 0.001	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1347	 0.043084	 0.135047	 0.002	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 1350	 0.000612	 0.004128	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1471	 1350	 0.001225	 0.006854	 0.1397	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 1350	 0.001738	 0.011615	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 1351	 0.001059	 0.003597	 0.0458	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1417	 1351	 0.009699	 0.044839	 0.0749	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1636	 1351	 0.001426	 0.009276	 0.0292	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 1351	 0.014143	 0.064395	 0.1134	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 1351	 0.003502	 0.02318	 0.0547	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 1351	 0.004543	 0.024889	 0.0435	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 1353	 2e-05	 9.8e-05	 0.0	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1355	 0.003275	 0.00907	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 1356	 2e-05	 0.000198	 0.001	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 1357	 0.014361	 0.036029	 0.001	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	2088	 1357	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 1357	 0.022172	 0.046107	 0.001	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	1857	 1357	 0.014555	 0.026643	 0.0004	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 1358	 5.9e-05	 0.000356	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2091	 1361	 0.001126	 0.005037	 0.0091	 5986	 5986	 5986	 0.0	 0.0	 1	 -30.0	 30.0;
	1575	 1362	 0.004642	 0.030854	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 1362	 0.001578	 0.010526	 0.0192	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 1362	 0.000119	 0.000889	 0.002	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 1366	 0.001351	 0.008986	 0.0303	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 1367	 0.001512	 0.005039	 0.0123	 6082	 6082	 6082	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 1367	 0.003779	 0.014865	 0.0185	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 1368	 0.001027	 0.006123	 0.2162	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1370	 0.005926	 0.013827	 0.0	 1736	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	1907	 1370	 0.059259	 0.141284	 0.0005	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 1372	 0.000194	 0.000624	 0.0009	 47367	 47367	 47367	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 1373	 0.001146	 0.007625	 0.0142	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 1374	 9.9e-05	 0.000198	 0.0142	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	1369	 1374	 9.9e-05	 0.000198	 0.0182	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	1712	 2836	 9.9e-05	 0.000988	 0.004	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 1374	 0.000111	 0.000223	 0.0213	 123245	 123245	 123245	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 1376	 0.003477	 0.023822	 0.0456	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1426	 1377	 0.000324	 0.000992	 0.0729	 29661	 29661	 29661	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1379	 0.00081	 0.005472	 0.0101	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1379	 0.000751	 0.005057	 0.0127	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1380	 0.001884	 0.019197	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1380	 0.001891	 0.019134	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 1381	 0.029226	 0.076846	 0.0009	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 1383	 0.001462	 0.009817	 0.0177	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 1386	 0.000237	 0.001501	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 1387	 0.000402	 0.005242	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1723	 1387	 0.000402	 0.005242	 0.1819	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 1392	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 2841	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 1392	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1652	 1395	 0.009826	 0.032754	 0.0037	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 1395	 0.004031	 0.013605	 0.0002	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	1658	 1396	 0.111867	 0.241875	 0.0026	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	2147	 1396	 0.02318	 0.062988	 0.0007	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 1397	 0.038801	 0.073066	 0.0008	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 2845	 0.000366	 0.000669	 0.0476	 40590	 40590	 40590	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1399	 0.000352	 0.000645	 0.0466	 42124	 42124	 42124	 0.0	 0.0	 1	 -30.0	 30.0;
	1765	 1401	 0.003121	 0.020997	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 1401	 0.004602	 0.0208	 0.0365	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 1402	 0.002694	 0.028476	 0.6599	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 1403	 0.000751	 0.003417	 0.0061	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2852	 1404	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1406	 1404	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2851	 1404	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 1407	 0.00083	 0.005491	 0.0101	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 1408	 0.000567	 0.001298	 0.1843	 263.0	 263.0	 263.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 2853	 0.000395	 0.001422	 0.1903	 20973	 20973	 20973	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 1409	 0.000494	 0.002963	 0.0051	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 1411	 0.004006	 0.010129	 0.0054	 2711	 2711	 2711	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 1412	 0.02968	 0.124313	 0.0015	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 1412	 0.021164	 0.079365	 0.001	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 1414	 0.029554	 0.078534	 0.0013	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	2097	 1414	 0.005291	 0.011842	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 1415	 0.000435	 0.0016	 0.1974	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1772	 1415	 0.000435	 0.00162	 0.2005	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1701	 1417	 0.006499	 0.029472	 0.0506	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 1419	 0.004879	 0.022479	 0.0375	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1868	 1420	 0.017511	 0.074351	 0.0009	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 1420	 0.008541	 0.023154	 0.0007	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 2855	 9.9e-05	 0.000573	 0.0511	 53230	 53230	 53230	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 1421	 0.000138	 0.000435	 0.0445	 67824	 67824	 67824	 0.0	 0.0	 1	 -30.0	 30.0;
	2100	 1423	 0.001864	 0.007508	 0.0001	 3817	 3817	 3817	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 1427	 0.080877	 0.204334	 0.0043	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 1427	 0.038297	 0.131771	 0.0319	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	1988	 1427	 0.014613	 0.037289	 0.0025	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 1428	 0.002943	 0.019773	 0.0354	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 1428	 0.001679	 0.011101	 0.0203	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 1429	 0.006301	 0.028622	 0.0496	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 2856	 0.002746	 0.014183	 0.1868	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 1431	 0.002469	 0.013827	 0.1757	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1995	 2856	 0.002094	 0.010607	 0.1822	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1580	 1432	 0.000436	 0.000797	 0.001	 32580	 32580	 32580	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 1433	 0.009323	 0.046598	 0.08	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1957	 1434	 0.004425	 0.029349	 0.0547	 578.0	 578.0	 578.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1717	 1435	 0.079365	 0.163517	 0.0021	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 2857	 0.0032	 0.021472	 0.0385	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1732	 1437	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 1437	 0.001211	 0.017571	 0.4563	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 1437	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 1437	 0.001205	 0.017438	 0.4534	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	1653	 1439	 0.021244	 0.060489	 0.0193	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	2123	 1440	 0.000553	 0.003793	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 1443	 0.007546	 0.034173	 0.0607	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 1448	 0.009156	 0.040044	 0.0135	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 1449	 0.017133	 0.043336	 0.0005	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 1449	 0.005039	 0.014109	 0.0002	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 1450	 0.000928	 0.004148	 0.0071	 7269	 7269	 7269	 0.0	 0.0	 1	 -30.0	 30.0;
	1605	 1450	 0.002844	 0.018627	 0.0334	 468.0	 468.0	 468.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 1450	 0.00257	 0.017083	 0.0314	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 1454	 0.009936	 0.040059	 0.0658	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 1454	 0.001679	 0.011062	 0.0203	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 1454	 0.004958	 0.022716	 0.0395	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 1454	 0.000178	 0.00077	 0.0035	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 1462	 0.000237	 0.001541	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 1464	 0.000948	 0.009185	 0.0324	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 2862	 0.000889	 0.008652	 0.0304	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 1469	 0.001008	 0.00252	 0.0	 10879	 10879	 10879	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1470	 0.001738	 0.011595	 0.0213	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 1471	 0.008652	 0.039447	 0.0724	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 1475	 0.073822	 0.198539	 0.0119	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 1476	 0.107178	 0.196187	 0.0016	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 1477	 0.001067	 0.004346	 0.0182	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1478	 0.023735	 0.043446	 0.0005	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 2864	 0.017385	 0.031998	 0.0003	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 1480	 0.005543	 0.012094	 0.0002	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 1483	 0.008332	 0.037879	 0.0663	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 1484	 0.033006	 0.072814	 0.001	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	1751	 1485	 0.008774	 0.031285	 0.0491	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2110	 1487	 0.002311	 0.015467	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 1488	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 1488	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 1489	 0.005886	 0.031546	 0.0567	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 1489	 0.011239	 0.050647	 0.0901	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 1491	 0.001817	 0.012089	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 1494	 5.9e-05	 0.000403	 0.001	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 1496	 0.000316	 0.001936	 0.2551	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1497	 0.000221	 0.001357	 0.1974	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 1498	 0.003818	 0.024421	 0.1136	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1628	 1499	 0.003457	 0.007901	 0.0	 3028	 3028	 3028	 0.0	 0.0	 1	 -30.0	 30.0;
	2138	 1499	 0.008889	 0.019259	 0.0	 1231	 1231	 1231	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 1499	 0.000335	 0.000613	 0.0	 37377	 37377	 37377	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 1500	 0.00162	 0.009284	 0.0162	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 2865	 0.001956	 0.009146	 0.0152	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 1502	 0.001837	 0.008988	 0.0203	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 1502	 0.000672	 0.004543	 0.0167	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 1503	 0.000242	 0.002735	 0.0549	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 1508	 0.000237	 0.000494	 0.0294	 56492	 56492	 56492	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 1509	 0.041068	 0.098765	 0.001	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 1509	 0.004535	 0.010078	 0.0	 2711	 2711	 2711	 0.0	 0.0	 1	 -30.0	 30.0;
	2135	 1509	 0.003779	 0.010582	 0.0	 2666	 2666	 2666	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 1514	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1637	 1514	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1928	 1514	 0.000563	 0.003372	 0.0116	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 1514	 0.000211	 0.002058	 0.0111	 789.0	 789.0	 789.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 1521	 0.026707	 0.095994	 0.0264	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1987	 1521	 0.012346	 0.041572	 0.0005	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 1521	 0.016377	 0.042076	 0.0005	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 1525	 0.002746	 0.018746	 0.0329	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1525	 0.003002	 0.015052	 0.0268	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 1526	 0.002043	 0.022929	 0.4592	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 1526	 0.000776	 0.008497	 0.1805	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1655	 1528	 0.037541	 0.092467	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 1529	 0.000512	 0.000938	 0.0	 28461	 28461	 28461	 0.0	 0.0	 1	 -30.0	 30.0;
	2115	 1532	 1e-05	 0.0001	 0.0029	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 1536	 0.046863	 0.11867	 0.0013	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2013	 1538	 0.003121	 0.014183	 0.0243	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1564	 1543	 0.059461	 0.146384	 0.0028	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 1543	 0.0451	 0.153187	 0.0017	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 1544	 0.003099	 0.020113	 0.0385	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 1544	 0.002528	 0.016672	 0.0304	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1880	 1545	 0.001679	 0.011397	 0.0223	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 1547	 0.013152	 0.03487	 0.0021	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	1582	 1548	 0.036029	 0.092467	 0.001	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 1548	 0.124717	 0.316201	 0.0036	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	2882	 1549	 0.00077	 0.001659	 0.2106	 16924	 16924	 16924	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 1550	 0.01159	 0.031494	 0.0003	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	2119	 1552	 0.001764	 0.005039	 0.0001	 5531	 5531	 5531	 0.0	 0.0	 1	 -30.0	 30.0;
	2148	 1556	 0.005628	 0.038669	 0.0729	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 1557	 0.020156	 0.087176	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	1779	 2870	 0.000652	 0.001244	 0.1833	 22038	 22038	 22038	 0.0	 0.0	 1	 -30.0	 30.0;
	1560	 2871	 0.003731	 0.006829	 0.0	 3831	 3831	 3831	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 1563	 0.00083	 0.002588	 0.32	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1866	 2872	 0.000395	 0.002291	 0.0182	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 2872	 0.001659	 0.011062	 0.0203	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 1565	 0.009956	 0.035773	 0.0572	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 1565	 0.002102	 0.008286	 0.0142	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 1565	 0.001185	 0.008	 0.0152	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 1567	 0.00371	 0.01789	 0.0359	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1567	 0.001428	 0.019629	 0.0754	 638.0	 638.0	 638.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2110	 1567	 0.001244	 0.016316	 0.0699	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 1567	 0.006728	 0.030596	 0.0587	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 1568	 0.000471	 0.006184	 0.2368	 954.0	 954.0	 954.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2001	 1569	 0.021926	 0.055062	 0.0002	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	2122	 1569	 0.019753	 0.05037	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 2874	 0.036029	 0.093222	 0.0011	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1940	 1577	 0.008566	 0.023432	 0.0002	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	1577	 1591	 0.008062	 0.022172	 0.0002	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 1578	 0.05417	 0.137314	 0.0019	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 1578	 0.03351	 0.113631	 0.0013	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	1583	 1579	 0.006084	 0.023072	 0.24	 282.0	 282.0	 282.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 1582	 0.051524	 0.124313	 0.003	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 1582	 0.046863	 0.109851	 0.0012	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	2085	 1583	 0.004454	 0.01571	 0.0253	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1801	 1584	 0.032754	 0.083396	 0.001	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 1587	 0.021668	 0.066516	 0.0013	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 2875	 0.020912	 0.063996	 0.0013	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	2123	 1590	 0.000375	 0.001679	 0.003	 17958	 17958	 17958	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 1592	 0.001512	 0.004787	 0.0045	 5882	 5882	 5882	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 1595	 0.019867	 0.059067	 0.0189	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 1599	 2.8e-05	 0.000409	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1822	 2877	 2.8e-05	 0.000422	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1881	 1600	 0.029982	 0.075838	 0.0	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 1602	 0.010667	 0.052109	 0.0901	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1654	 1605	 0.003931	 0.026686	 0.0506	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 1606	 0.002268	 0.006803	 0.0005	 4118	 4118	 4118	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 1607	 0.049887	 0.166767	 0.0019	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 1609	 0.017385	 0.039053	 0.004	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 1615	 0.022172	 0.057697	 0.001	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	1934	 1616	 0.000415	 0.002785	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 2952	 0.001225	 0.005981	 0.0111	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 2952	 0.000474	 0.003149	 0.0061	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 1619	 0.000644	 0.002929	 0.0051	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1620	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1620	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 1620	 0.000435	 0.002963	 0.0208	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 1623	 5.9e-05	 0.000336	 0.001	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 1625	 0.057697	 0.120685	 0.0013	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	1796	 1626	 0.042328	 0.167297	 0.0021	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	1842	 1627	 0.046863	 0.158982	 0.002	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	1932	 1627	 0.012094	 0.033006	 0.0	 840	 840	 840	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 1630	 0.03477	 0.064752	 0.0006	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 1633	 0.003927	 0.026153	 0.0486	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 1636	 0.002035	 0.014025	 0.0263	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1764	 1637	 0.000237	 0.00083	 0.1843	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1826	 1640	 0.002394	 0.014865	 0.0002	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 1643	 0.000151	 0.000428	 0.0	 65055	 65055	 65055	 0.0	 0.0	 1	 -30.0	 30.0;
	1830	 2883	 0.000454	 0.002114	 0.0061	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1830	 1644	 0.000454	 0.002114	 0.004	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 1647	 0.069791	 0.171328	 0.0023	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	1877	 1649	 0.103301	 0.241371	 0.003	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 1649	 0.068178	 0.17357	 0.0021	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1650	 0.014613	 0.049383	 0.001	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 1650	 0.041572	 0.101789	 0.002	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	1750	 1650	 0.015873	 0.050643	 0.001	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 1651	 0.053666	 0.303603	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 1651	 0.053918	 0.303855	 0.0034	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	1776	 1652	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	1847	 1652	 0.03933	 0.101789	 0.0025	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	2914	 1652	 0.000252	 0.00252	 0.0001	 11659	 11659	 11659	 0.0	 0.0	 1	 -30.0	 30.0;
	2091	 1654	 0.002627	 0.017778	 0.0334	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1960	 1655	 0.006047	 0.025195	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	1903	 1658	 0.063265	 0.13613	 0.0015	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 1658	 0.011842	 0.033006	 0.0	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 1659	 0.001462	 0.010114	 0.0182	 442.0	 442.0	 442.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1660	 0.01033	 0.037541	 0.0005	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	1691	 1662	 0.006173	 0.025145	 0.0018	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	1731	 2885	 0.022676	 0.095994	 0.001	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 1662	 0.044344	 0.189216	 0.0021	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 2885	 0.048123	 0.206349	 0.003	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 1664	 0.002749	 0.039259	 1.1855	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 2892	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 2891	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 2890	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 1667	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 1671	 0.000454	 0.001209	 0.0013	 23415	 23415	 23415	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 1674	 0.006533	 0.022267	 0.0072	 1313	 1313	 1313	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 1674	 0.017067	 0.058356	 0.0193	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 1676	 0.100277	 0.301839	 0.004	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 1681	 1.4e-05	 9.9e-05	 0.0002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 1682	 0.002807	 0.014445	 0.0259	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1685	 0.054674	 0.120937	 0.0013	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 1685	 0.114059	 0.346964	 0.004	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 1687	 0.006933	 0.033403	 0.0607	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1999	 1688	 0.001383	 0.009343	 0.0172	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2000	 1688	 0.001027	 0.006815	 0.0121	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 1690	 0.014361	 0.039053	 0.0005	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 1690	 0.012346	 0.03351	 0.0004	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 1693	 5.9e-05	 0.000296	 0.0	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 1695	 0.006047	 0.024691	 0.0003	 1162	 1162	 1162	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1698	 0.00141	 0.020003	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 1698	 0.00141	 0.02	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 1701	 0.006696	 0.028583	 0.0496	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2896	 1707	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1719	 1707	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 2895	 0.005709	 0.036049	 0.0881	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 2895	 0.005748	 0.036247	 0.0997	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 1710	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2153	 1710	 0.001707	 0.022772	 0.7812	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 1710	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 1710	 0.00117	 0.010658	 0.2946	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 1710	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 1710	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1713	 1714	 0.009574	 0.025195	 0.0003	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 1714	 0.159234	 0.297304	 0.0033	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	2137	 1714	 0.00907	 0.024691	 0.0002	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	2139	 1716	 0.016769	 0.030696	 0.0	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 1717	 0.064248	 0.133283	 0.001	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 2896	 0.001015	 0.014744	 0.3841	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 1719	 0.001018	 0.014778	 0.3841	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	2076	 1724	 0.008119	 0.054084	 0.1002	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 1725	 0.024188	 0.060972	 0.0008	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 1727	 0.001067	 0.004899	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 1727	 0.000119	 0.00077	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2140	 1729	 0.019652	 0.040816	 0.0005	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	2143	 1736	 0.001244	 0.006301	 0.0111	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 1739	 0.000612	 0.004069	 0.0071	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1773	 1741	 0.004938	 0.013333	 0.0	 1837	 1837	 1837	 0.0	 0.0	 1	 -30.0	 30.0;
	2144	 1742	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 1744	 0.053666	 0.098262	 0.001	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 1745	 0.004464	 0.030933	 0.0547	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1953	 1747	 0.05543	 0.140842	 0.0016	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 1749	 0.061728	 0.148652	 0.0017	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 1750	 0.000252	 0.000504	 0.001	 53161	 53161	 53161	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 2902	 4e-05	 0.000968	 0.003	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 1754	 0.009826	 0.025447	 0.0002	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 1756	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 1757	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 2906	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2152	 1760	 0.001008	 0.00252	 0.0	 11263	 11263	 11263	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 1765	 0.010815	 0.050299	 0.0876	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 1772	 0.002509	 0.015921	 0.0294	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 1777	 0.169312	 0.378181	 0.0044	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 1777	 0.070295	 0.177879	 0.002	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 1778	 0.000316	 0.001971	 0.0273	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2929	 2915	 0.000245	 0.00302	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1940	 1780	 0.078609	 0.2129	 0.0024	 131	 131	 131	 0.0	 0.0	 1	 -30.0	 30.0;
	2048	 1788	 0.009574	 0.024943	 0.001	 1106	 1106	 1106	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 1790	 0.000356	 0.00241	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2156	 1791	 0.000375	 0.004741	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1926	 1792	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 1792	 0.000252	 0.00252	 0.0	 12010	 12010	 12010	 0.0	 0.0	 1	 -30.0	 30.0;
	2154	 1793	 0.000171	 0.000313	 0.0001	 82782	 82782	 82782	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 1794	 0.004787	 0.010078	 0.0001	 2647	 2647	 2647	 0.0	 0.0	 1	 -30.0	 30.0;
	2087	 1795	 0.042479	 0.09035	 0.001	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 1796	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 1796	 0.008818	 0.035777	 0.0005	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	2157	 1798	 0.014361	 0.048879	 0.001	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 1800	 0.070547	 0.17284	 0.002	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 2981	 0.002825	 0.012998	 0.0299	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 1808	 0.029982	 0.076594	 0.0009	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	2146	 1811	 0.011086	 0.024943	 0.0003	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 1812	 0.001481	 0.006696	 0.0111	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1835	 1814	 0.120937	 0.267322	 0.003	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	1815	 1816	 0.001184	 0.002167	 0.0003	 10572	 10572	 10572	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 1816	 0.036049	 0.098272	 0.0012	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 1816	 0.064198	 0.139753	 0.0012	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 1822	 0.000561	 0.005658	 0.1444	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 1822	 0.000561	 0.005665	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 1829	 0.034014	 0.072814	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	1894	 1830	 0.001501	 0.010023	 0.0182	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 1832	 0.002029	 0.013533	 0.025	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2115	 1833	 0.000693	 0.007389	 0.1617	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1977	 2923	 0.010864	 0.050469	 0.0845	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1934	 1840	 0.001719	 0.011457	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 1840	 0.00079	 0.00798	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 1840	 0.001434	 0.009559	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1854	 1845	 0.004186	 0.02786	 0.0516	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 1845	 0.002173	 0.014242	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2033	 1845	 0.004109	 0.027417	 0.0486	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 1845	 0.001106	 0.007407	 0.0132	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 1850	 0.010582	 0.04384	 0.0006	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 1850	 0.047871	 0.201058	 0.0068	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	2136	 1850	 0.026455	 0.109095	 0.0013	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 1856	 0.000252	 0.000504	 0.0	 52398	 52398	 52398	 0.0	 0.0	 1	 -30.0	 30.0;
	2158	 1858	 0.000988	 0.002469	 0.0	 9817	 9817	 9817	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 1859	 0.000247	 0.003489	 0.0462	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1866	 1862	 0.00083	 0.007052	 0.0724	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 2927	 0.000731	 0.003121	 0.0051	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 1862	 0.001025	 0.006888	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2051	 1862	 0.000553	 0.003595	 0.0071	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 1862	 0.000533	 0.003575	 0.0061	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2099	 1862	 0.000849	 0.00796	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 2927	 0.000731	 0.003121	 0.0051	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 2927	 0.000849	 0.008237	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 2927	 0.000375	 0.003733	 0.0121	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2000	 1865	 0.004109	 0.027911	 0.0516	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 1868	 0.017561	 0.072436	 0.0009	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	1913	 1870	 0.001916	 0.009323	 0.0223	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 1870	 0.000514	 0.004859	 0.0182	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 1870	 0.002212	 0.010114	 0.0233	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 1870	 0.000948	 0.004602	 0.0081	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1995	 2929	 0.000909	 0.004385	 0.0081	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 1874	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 2933	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 2934	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 1881	 0.006551	 0.043084	 0.001	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 1881	 0.006803	 0.017637	 0.0	 1562	 1562	 1562	 0.0	 0.0	 1	 -30.0	 30.0;
	2004	 1881	 0.003023	 0.020156	 0.0	 1449	 1449	 1449	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 1883	 0.015621	 0.066767	 0.0008	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 1892	 0.001127	 0.014433	 0.3408	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 1897	 0.000217	 0.000988	 0.002	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 1909	 0.025185	 0.08	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 1911	 0.002756	 0.007867	 0.0022	 3854	 3854	 3854	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 1918	 0.00126	 0.004787	 0.0001	 5965	 5965	 5965	 0.0	 0.0	 1	 -30.0	 30.0;
	1967	 1927	 0.083144	 0.200756	 0.0019	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	1947	 1937	 0.021416	 0.048879	 0.0006	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 1946	 0.031746	 0.083648	 0.001	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	2024	 1958	 0.000356	 0.00241	 0.004	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1970	 1963	 0.000252	 0.000756	 0.0	 37051	 37051	 37051	 0.0	 0.0	 1	 -30.0	 30.0;
	2063	 1991	 0.015369	 0.039808	 0.0005	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 2004	 0.003527	 0.022928	 0.0	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 2010	 0.000756	 0.001764	 0.0	 15385	 15385	 15385	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 2075	 0.163559	 0.299393	 0.003	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 2073	 0.102041	 0.22323	 0.0025	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	2149	 2082	 0.046107	 0.116906	 0.0013	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2123	 2091	 0.000691	 0.004681	 0.0091	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1594	 2249	 0.090451	 0.269841	 0.0026	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 2571	 0.003556	 0.120296	 0.0	 265	 265	 265	 0.985222	 0.0	 1	 -30.0	 30.0;
	2571	 2191	 0.00018	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	11	 2215	 0.00018	 -0.006163	 0.0	 1188.0	 1188.0	 1188.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	12	 2191	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 2215	 0.000291	 0.030817	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 43	 0.003556	 0.119309	 0.0	 258	 258	 258	 1.001002	 0.0	 1	 -30.0	 30.0;
	42	 43	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	2576	 50	 0.003338	 0.116543	 0.0	 262	 262	 262	 0.975606	 0.0	 1	 -30.0	 30.0;
	49	 50	 0.003595	 0.128593	 0.0	 237	 237	 237	 0.975606	 0.0	 1	 -30.0	 30.0;
	53	 54	 0.002178	 0.149156	 0.0	 203	 203	 203	 0.974664	 0.0	 1	 -30.0	 30.0;
	55	 56	 0.000332	 0.025	 0.0	 1187.0	 1187.0	 1187.0	 1.001	 0.0	 1	 -30.0	 30.0;
	59	 2163	 0.000145	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	59	 2216	 0.000125	 -0.006787	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60	 2163	 0.000194	 0.031302	 0.0	 1094	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 2216	 0.000215	 0.031995	 0.0	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 63	 0.000252	 0.00252	 0.0003	 11659	 11659	 11659	 1.0	 -1.3	 1	 -30.0	 30.0;
	68	 69	 7.9e-05	 0.000836	 0.0	 45569	 45569	 45569	 1.0	 0.0	 1	 -30.0	 30.0;
	74	 2192	 0.002252	 0.11358	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 2217	 0.002449	 0.127407	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 85	 0.000665	 0.048338	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	84	 85	 0.000783	 0.039612	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	89	 2582	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	2581	 90	 0.000277	 0.009481	 0.001	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	2581	 90	 0.000277	 0.009481	 0.0	 446.0	 446.0	 446.0	 0.957854	 0.0	 1	 -30.0	 30.0;
	102	 103	 0.000346	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	102	 103	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2585	 103	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	107	 108	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.987165	 0.0	 1	 -30.0	 30.0;
	107	 108	 0.003733	 0.122667	 0.0	 249	 249	 249	 0.978477	 0.0	 1	 -30.0	 30.0;
	109	 110	 0.000803	 0.042452	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	125	 127	 0.002916	 0.161475	 0.0	 196	 196	 196	 1.033058	 0.0	 1	 -30.0	 30.0;
	125	 127	 0.001801	 0.100416	 0.0	 316	 316	 316	 0.994033	 0.0	 1	 -30.0	 30.0;
	125	 127	 0.002825	 0.153927	 0.0	 206	 206	 206	 1.023541	 0.0	 1	 -30.0	 30.0;
	126	 127	 0.000734	 0.045014	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	126	 127	 0.000727	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	130	 131	 0.003931	 0.12484	 0.0	 247	 247	 247	 1.02459	 0.0	 1	 -30.0	 30.0;
	130	 131	 0.004662	 0.160988	 0.0	 192	 192	 192	 0.98912	 0.0	 1	 -30.0	 30.0;
	153	 154	 0.000803	 0.03892	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	153	 154	 0.000845	 0.03982	 0.0	 598.0	 598.0	 598.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	153	 2218	 0.000374	 -0.009003	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	154	 2218	 0.000471	 0.048892	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 2998	 0.000893	 0.043767	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	173	 174	 0.000693	 0.048615	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	177	 178	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.900901	 0.0	 1	 -30.0	 30.0;
	178	 2164	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	178	 2193	 0.000152	 -0.00644	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	179	 2164	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 2193	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 183	 0.003951	 0.124444	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	182	 183	 0.003753	 0.124642	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	182	 183	 0.002568	 0.164346	 0.0	 187	 187	 187	 0.980394	 0.0	 1	 -30.0	 30.0;
	194	 195	 0.003951	 0.118519	 0.0	 260	 260	 260	 0.989123	 0.0	 1	 -30.0	 30.0;
	2597	 195	 0.003358	 0.118519	 0.0	 260	 260	 260	 0.976559	 0.0	 1	 -30.0	 30.0;
	195	 196	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	195	 196	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	197	 198	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.964324	 0.0	 1	 -30.0	 30.0;
	197	 198	 0.00316	 0.117333	 0.0	 260	 260	 260	 0.975606	 0.0	 1	 -30.0	 30.0;
	197	 198	 0.001679	 0.122272	 0.0	 250	 250	 250	 0.975606	 0.0	 1	 -30.0	 30.0;
	205	 206	 0.004899	 0.162173	 0.0	 188	 188	 188	 0.956938	 0.0	 1	 -30.0	 30.0;
	2600	 212	 2e-05	 0.004741	 0.004	 935.0	 935.0	 935.0	 1.0	 4.66	 1	 -30.0	 30.0;
	2600	 214	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2600	 214	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	217	 218	 0.000886	 0.043837	 0.0	 632.0	 632.0	 632.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	221	 222	 0.003081	 0.125432	 0.0	 246	 246	 246	 0.963394	 0.0	 1	 -30.0	 30.0;
	221	 222	 0.003121	 0.125037	 0.0	 247	 247	 247	 0.963394	 0.0	 1	 -30.0	 30.0;
	225	 226	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	229	 2194	 0.000519	 -0.007825	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	230	 2194	 0.000277	 0.047507	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 233	 0.003733	 0.175822	 0.0	 173	 173	 173	 0.952385	 0.0	 1	 -30.0	 30.0;
	2613	 2615	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	2614	 2615	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	259	 260	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	263	 264	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	2616	 264	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	2617	 264	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	279	 2165	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	279	 2195	 0.000152	 -0.00644	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	280	 2165	 6.9e-05	 0.029294	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 2195	 0.00018	 0.03151	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 288	 0.012346	 0.453263	 0.0	 87	 87	 87	 1.001	 0.0	 1	 -30.0	 30.0;
	287	 288	 0.012346	 0.456286	 0.0	 86	 86	 86	 1.001	 0.0	 1	 -30.0	 30.0;
	2619	 288	 0.012598	 0.456034	 0.0	 86	 86	 86	 1.001	 0.0	 1	 -30.0	 30.0;
	291	 2623	 0.03225	 0.602419	 0.0	 65	 65	 65	 1.001	 0.0	 1	 -30.0	 30.0;
	2622	 292	 0.03225	 0.602419	 0.0	 65	 65	 65	 1.001	 0.0	 1	 -30.0	 30.0;
	2623	 293	 0.001975	 0.124444	 0.0	 247	 247	 247	 0.989123	 0.0	 1	 -30.0	 30.0;
	292	 293	 0.00316	 0.125037	 0.001	 246	 246	 246	 0.976559	 0.0	 1	 -30.0	 30.0;
	298	 2626	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	2625	 2626	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	2624	 299	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	311	 312	 0.000312	 0.024979	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	320	 321	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	320	 321	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	322	 323	 6.9e-05	 0.056094	 0.0	 566	 566	 566	 1.0	 0.0	 1	 -30.0	 30.0;
	335	 336	 0.006133	 0.237422	 0.0	 162	 162	 162	 0.938967	 0.0	 1	 -30.0	 30.0;
	2641	 2166	 0.000499	 -0.008379	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	348	 2196	 0.000325	 -0.008726	 0.0	 557.0	 557.0	 557.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	349	 2166	 0.000298	 0.048407	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	349	 2196	 0.000381	 0.047715	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 2167	 0.000166	 -0.005062	 0.0	 1168.0	 1168.0	 1168.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2642	 2219	 0.000166	 -0.010873	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2642	 2233	 0.000152	 -0.007756	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2643	 2243	 0.000118	 -0.007618	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2645	 2167	 0.000201	 0.026437	 0.0	 1168.0	 1168.0	 1168.0	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 2219	 0.000166	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	2645	 2233	 0.000187	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 2243	 0.00018	 0.034695	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 364	 0.001801	 0.09903	 0.0	 320	 320	 320	 0.971818	 0.0	 1	 -30.0	 30.0;
	363	 364	 0.001801	 0.099723	 0.0	 318	 318	 318	 0.991081	 0.0	 1	 -30.0	 30.0;
	365	 2646	 0.000325	 0.026801	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	365	 366	 0.000319	 0.026593	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	367	 368	 0.007664	 0.250785	 0.0	 153	 153	 153	 1.0	 0.0	 1	 -30.0	 30.0;
	367	 368	 0.007664	 0.250785	 0.0	 153	 153	 153	 1.0	 0.0	 1	 -30.0	 30.0;
	367	 368	 0.007664	 0.250785	 0.0	 153	 153	 153	 1.0	 0.0	 1	 -30.0	 30.0;
	380	 381	 0.001778	 0.119309	 0.0	 258	 258	 258	 0.95329	 0.0	 1	 -30.0	 30.0;
	379	 2168	 0.004224	 0.148199	 0.0	 252	 252	 252	 1.0	 0.0	 1	 -30.0	 30.0;
	380	 382	 0.001801	 0.101108	 0.0	 313	 313	 313	 0.971818	 0.0	 1	 -30.0	 30.0;
	380	 382	 0.001399	 0.101177	 0.0	 313	 313	 313	 0.971818	 0.0	 1	 -30.0	 30.0;
	381	 2168	 0.000388	 -0.009003	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	381	 2197	 0.00063	 -0.005194	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	382	 2168	 0.000395	 0.049169	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	382	 2197	 3.5e-05	 0.048476	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 392	 0.000325	 0.027147	 0.0	 1168	 1168	 1168	 0.999001	 0.0	 1	 -30.0	 30.0;
	391	 392	 0.000319	 0.027216	 0.0	 1165	 1165	 1165	 0.999001	 0.0	 1	 -30.0	 30.0;
	391	 2220	 0.000229	 -0.008102	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2651	 2220	 8.3e-05	 0.035734	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 409	 0.000339	 0.027285	 0.0	 1162	 1162	 1162	 1.0	 0.0	 1	 -30.0	 30.0;
	408	 409	 0.000339	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	408	 2221	 0.000132	 -0.007479	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	409	 2221	 0.000173	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 419	 3.5e-05	 0.07581	 0.0	 499	 499	 499	 1.0	 0.0	 1	 -30.0	 30.0;
	418	 419	 3.5e-05	 0.07581	 0.0	 499	 499	 499	 1.0	 0.0	 1	 -30.0	 30.0;
	435	 436	 0.002469	 0.533333	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	2664	 452	 0.000325	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	451	 452	 0.000325	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2946	 454	 0.000332	 0.027078	 0.0	 1165	 1165	 1165	 1.0	 0.0	 1	 -30.0	 30.0;
	453	 454	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	453	 454	 0.000817	 0.042313	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2946	 454	 0.000686	 0.043075	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	458	 459	 0.003417	 0.126222	 0.0	 242	 242	 242	 0.96432	 0.0	 1	 -30.0	 30.0;
	458	 459	 0.003812	 0.111605	 0.0	 274	 274	 274	 0.96432	 0.0	 1	 -30.0	 30.0;
	458	 459	 0.002035	 0.111605	 0.0	 274	 274	 274	 0.96432	 0.0	 1	 -30.0	 30.0;
	2665	 470	 0.003753	 0.122864	 0.0	 250	 250	 250	 0.976559	 0.0	 1	 -30.0	 30.0;
	469	 470	 0.003556	 0.127802	 0.0	 241	 241	 241	 0.965249	 0.0	 1	 -30.0	 30.0;
	2665	 2667	 0.003951	 0.125235	 0.0	 246	 246	 246	 0.976559	 0.0	 1	 -30.0	 30.0;
	2667	 471	 0.000319	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	470	 471	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2244	 480	 0.000402	 -0.007341	 0.0	 581.0	 581.0	 581.0	 1.049318	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.000263	 0.025277	 0.0	 585.0	 585.0	 585.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	480	 481	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	481	 2244	 0.000242	 0.03144	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	502	 503	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.987165	 0.0	 1	 -30.0	 30.0;
	502	 503	 0.004286	 0.162765	 0.0	 188	 188	 188	 0.98912	 0.0	 1	 -30.0	 30.0;
	505	 506	 0.000332	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	505	 506	 0.000312	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	513	 514	 0.006133	 0.237422	 0.0	 162	 162	 162	 0.938967	 0.0	 1	 -30.0	 30.0;
	536	 537	 0.003062	 0.125432	 0.0	 245	 245	 245	 0.967121	 0.0	 1	 -30.0	 30.0;
	538	 539	 7.9e-05	 0.000836	 0.0	 45573	 45573	 45573	 1.0	 0.0	 1	 -30.0	 30.0;
	552	 553	 0.003852	 0.12642	 0.0	 242	 242	 242	 1.02459	 0.0	 1	 -30.0	 30.0;
	2679	 553	 0.003812	 0.12484	 0.0	 245	 245	 245	 1.011122	 0.0	 1	 -30.0	 30.0;
	557	 2169	 0.00347	 0.094737	 0.0	 394	 394	 394	 1.0	 0.0	 1	 -30.0	 30.0;
	558	 2169	 0.000263	 -0.005471	 0.0	 1184.0	 1184.0	 1184.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	559	 2169	 6.2e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 565	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	564	 565	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	566	 568	 0.003081	 0.117728	 0.0	 262	 262	 262	 0.972767	 0.0	 1	 -30.0	 30.0;
	580	 581	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	580	 581	 0.000796	 0.041551	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	580	 581	 0.000727	 0.048753	 0.0	 607.0	 607.0	 607.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	580	 581	 0.000325	 0.027562	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	2978	 2681	 0.003714	 0.086361	 0.001	 432	 432	 432	 0.883392	 0.0	 1	 -30.0	 30.0;
	2680	 2681	 0.00156	 0.048494	 0.001	 769	 769	 769	 1.0101	 0.0	 1	 -30.0	 30.0;
	582	 583	 0.003714	 0.086361	 0.001	 432	 432	 432	 0.883392	 0.0	 1	 -30.0	 30.0;
	2977	 583	 0.00156	 0.048494	 0.001	 769	 769	 769	 1.0101	 0.0	 1	 -30.0	 30.0;
	586	 2234	 0.000159	 -0.007133	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	586	 2245	 0.000277	 -0.005609	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	587	 2234	 0.000173	 0.033726	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	587	 2245	 6.2e-05	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	588	 589	 0.000325	 0.024792	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	605	 606	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	605	 606	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	612	 2170	 0.000145	 -0.007548	 0.0	 1187.0	 1187.0	 1187.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	612	 2198	 0.000533	 -0.004848	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	613	 2170	 0.000187	 0.03428	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	613	 2198	 0.000173	 0.053186	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	620	 621	 0.005378	 0.132356	 0.0	 229	 229	 229	 0.946073	 0.0	 1	 -30.0	 30.0;
	620	 621	 0.004356	 0.137467	 0.0	 221	 221	 221	 0.946073	 0.0	 1	 -30.0	 30.0;
	2686	 623	 0.00316	 0.125037	 0.0	 246	 246	 246	 1.001002	 0.0	 1	 -30.0	 30.0;
	622	 623	 0.003951	 0.12563	 0.0	 245	 245	 245	 1.0142	 0.0	 1	 -30.0	 30.0;
	622	 623	 0.001778	 0.111012	 0.0	 277	 277	 277	 1.001002	 0.0	 1	 -30.0	 30.0;
	628	 629	 0.001778	 0.121481	 0.0	 251	 251	 251	 0.97561	 0.0	 1	 -30.0	 30.0;
	628	 629	 0.001778	 0.121481	 0.0	 251	 251	 251	 0.97561	 0.0	 1	 -30.0	 30.0;
	628	 629	 0.001778	 0.121481	 0.0	 251	 251	 251	 0.987167	 0.0	 1	 -30.0	 30.0;
	639	 640	 0.00316	 0.125827	 0.0	 245	 245	 245	 1.001002	 0.0	 1	 -30.0	 30.0;
	639	 640	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	643	 644	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.967121	 0.0	 1	 -30.0	 30.0;
	643	 644	 0.003931	 0.111605	 0.0	 273	 273	 273	 0.967121	 0.0	 1	 -30.0	 30.0;
	2697	 2699	 0.007901	 0.341728	 0.0	 112	 112	 112	 1.0	 0.0	 1	 -30.0	 30.0;
	2696	 2698	 0.007901	 0.341728	 0.0	 112	 112	 112	 1.0	 0.0	 1	 -30.0	 30.0;
	662	 663	 0.007901	 0.341728	 0.0	 112	 112	 112	 1.0	 0.0	 1	 -30.0	 30.0;
	2700	 665	 0.003635	 0.123654	 0.0	 247	 247	 247	 0.952382	 0.0	 1	 -30.0	 30.0;
	664	 665	 0.004484	 0.118716	 0.0	 257	 257	 257	 0.96432	 0.0	 1	 -30.0	 30.0;
	678	 679	 0.003635	 0.118519	 0.0	 261	 261	 261	 1.011122	 0.0	 1	 -30.0	 30.0;
	678	 679	 0.003279	 0.125235	 0.0	 247	 247	 247	 0.98619	 0.0	 1	 -30.0	 30.0;
	685	 686	 0.003081	 0.125037	 0.0	 247	 247	 247	 0.999001	 0.0	 1	 -30.0	 30.0;
	685	 686	 0.001956	 0.126025	 0.0	 245	 245	 245	 0.952382	 0.0	 1	 -30.0	 30.0;
	688	 689	 0.000735	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	691	 692	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.987167	 0.0	 1	 -30.0	 30.0;
	691	 692	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.987167	 0.0	 1	 -30.0	 30.0;
	2710	 2713	 0.000395	 0.238025	 0.0	 161	 161	 161	 1.0	 0.0	 1	 -30.0	 30.0;
	2708	 710	 0.000395	 0.238025	 0.0	 161	 161	 161	 1.0	 0.0	 1	 -30.0	 30.0;
	2709	 2711	 0.000395	 0.238025	 0.0	 161	 161	 161	 1.0	 0.0	 1	 -30.0	 30.0;
	709	 2712	 0.000395	 0.238025	 0.0	 161	 161	 161	 1.0	 0.0	 1	 -30.0	 30.0;
	712	 713	 0.001778	 0.122864	 0.0	 250	 250	 250	 0.998004	 0.0	 1	 -30.0	 30.0;
	712	 713	 0.00158	 0.122272	 0.0	 252	 252	 252	 0.998004	 0.0	 1	 -30.0	 30.0;
	714	 715	 0.004543	 0.163556	 0.0	 189	 189	 189	 0.95511	 0.0	 1	 -30.0	 30.0;
	728	 729	 0.000803	 0.034418	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	728	 2199	 0.000277	 -0.004709	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	729	 2199	 4.8e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 734	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	738	 739	 0.000332	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	738	 739	 0.000305	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2720	 742	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	2719	 2724	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	2718	 2725	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	2721	 2726	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	741	 2722	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	744	 746	 0.001975	 0.157432	 0.0	 243	 243	 243	 1.0	 0.0	 1	 -30.0	 30.0;
	753	 754	 0.003595	 0.119506	 0.0	 262	 262	 262	 0.974664	 0.0	 1	 -30.0	 30.0;
	753	 754	 0.004642	 0.160988	 0.0	 194	 194	 194	 0.956938	 0.0	 1	 -30.0	 30.0;
	762	 763	 0.003891	 0.124444	 0.0	 248	 248	 248	 0.956938	 0.0	 1	 -30.0	 30.0;
	762	 763	 0.003911	 0.11279	 0.0	 274	 274	 274	 0.956938	 0.0	 1	 -30.0	 30.0;
	770	 771	 0.000319	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	770	 771	 0.000339	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	770	 771	 0.00036	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	776	 2737	 0.002909	 0.158587	 0.0	 200	 200	 200	 0.971818	 0.0	 1	 -30.0	 30.0;
	776	 777	 0.002832	 0.157202	 0.0	 202	 202	 202	 0.962465	 0.0	 1	 -30.0	 30.0;
	782	 783	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.990104	 0.0	 1	 -30.0	 30.0;
	782	 783	 0.003437	 0.128395	 0.0	 238	 238	 238	 0.990104	 0.0	 1	 -30.0	 30.0;
	2171	 785	 0.000152	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	785	 786	 0.000312	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	786	 2171	 0.000159	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	571	 788	 0.000119	 0.00796	 0.0	 418.0	 418.0	 418.0	 1.0	 -1.94	 1	 -30.0	 30.0;
	798	 799	 0.005096	 0.143921	 0.0	 221	 221	 221	 1.0	 0.0	 1	 -30.0	 30.0;
	798	 799	 0.005531	 0.188247	 0.0	 169	 169	 169	 1.002007	 0.0	 1	 -30.0	 30.0;
	800	 801	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.939847	 0.0	 1	 -30.0	 30.0;
	800	 801	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.939847	 0.0	 1	 -30.0	 30.0;
	806	 807	 0.004741	 0.164148	 0.0	 188	 188	 188	 0.978477	 0.0	 1	 -30.0	 30.0;
	806	 807	 0.003358	 0.106667	 0.0	 288	 288	 288	 0.990101	 0.0	 1	 -30.0	 30.0;
	807	 808	 0.000713	 0.043283	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	807	 808	 0.000769	 0.043837	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	818	 2222	 0.001817	 0.123654	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 2235	 0.001877	 0.098765	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	2964	 823	 0.000319	 0.027424	 0.0	 1157	 1157	 1157	 1.0	 0.0	 1	 -30.0	 30.0;
	822	 823	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	835	 836	 0.002074	 0.161778	 0.0	 196	 196	 196	 0.875657	 0.0	 1	 -30.0	 30.0;
	835	 836	 0.002074	 0.161778	 0.0	 196	 196	 196	 0.875657	 0.0	 1	 -30.0	 30.0;
	838	 2172	 0.002864	 0.068543	 0.0	 544	 544	 544	 1.0	 0.0	 1	 -30.0	 30.0;
	839	 2172	 0.006499	 0.143802	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 841	 0.001896	 0.119704	 0.0	 255	 255	 255	 0.97561	 0.0	 1	 -30.0	 30.0;
	840	 841	 0.001896	 0.119704	 0.0	 255	 255	 255	 0.97561	 0.0	 1	 -30.0	 30.0;
	844	 845	 0.005472	 0.190025	 0.0	 166	 166	 166	 1.0	 0.0	 1	 -30.0	 30.0;
	853	 854	 0.00295	 0.163504	 0.0	 194	 194	 194	 0.984249	 0.0	 1	 -30.0	 30.0;
	855	 856	 0.003951	 0.112988	 0.0	 272	 272	 272	 1.001002	 0.0	 1	 -30.0	 30.0;
	855	 856	 0.003951	 0.124247	 0.0	 248	 248	 248	 0.989123	 0.0	 1	 -30.0	 30.0;
	873	 874	 0.00397	 0.124049	 0.0	 247	 247	 247	 0.990101	 0.0	 1	 -30.0	 30.0;
	2754	 874	 0.003062	 0.117728	 0.0	 260	 260	 260	 0.987165	 0.0	 1	 -30.0	 30.0;
	2754	 874	 0.003101	 0.125432	 0.0	 244	 244	 244	 0.987165	 0.0	 1	 -30.0	 30.0;
	874	 875	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2755	 879	 0.004543	 0.120691	 0.0	 255	 255	 255	 0.989123	 0.0	 1	 -30.0	 30.0;
	2755	 879	 0.004346	 0.120691	 0.0	 255	 255	 255	 0.989123	 0.0	 1	 -30.0	 30.0;
	878	 879	 0.004741	 0.157432	 0.0	 196	 196	 196	 0.978477	 0.0	 1	 -30.0	 30.0;
	880	 881	 0.000693	 0.048753	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	880	 2756	 0.000796	 0.042452	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	2760	 2764	 0.003951	 0.185679	 0.0	 206	 206	 206	 1.0	 0.0	 1	 -30.0	 30.0;
	2757	 884	 0.003951	 0.185679	 0.0	 206	 206	 206	 1.0	 0.0	 1	 -30.0	 30.0;
	883	 2762	 0.003951	 0.185679	 0.0	 206	 206	 206	 1.0	 0.0	 1	 -30.0	 30.0;
	2758	 2763	 0.003951	 0.185679	 0.0	 206	 206	 206	 1.0	 0.0	 1	 -30.0	 30.0;
	2759	 2766	 0.003951	 0.185679	 0.0	 206	 206	 206	 1.0	 0.0	 1	 -30.0	 30.0;
	2761	 2765	 0.003951	 0.185679	 0.0	 206	 206	 206	 1.0	 0.0	 1	 -30.0	 30.0;
	900	 901	 0.0032	 0.124444	 0.0	 258	 258	 258	 1.0	 0.0	 1	 -30.0	 30.0;
	2771	 910	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2771	 2200	 0.000145	 -0.006371	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	909	 2223	 0.000132	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	910	 2200	 0.000187	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 2223	 0.000187	 0.03144	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 912	 0.000845	 0.042729	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	921	 922	 0.003951	 0.124247	 0.0	 246	 246	 246	 0.974664	 0.0	 1	 -30.0	 30.0;
	921	 922	 0.003062	 0.124444	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	928	 929	 0.000332	 0.024238	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	928	 929	 0.000332	 0.024238	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	938	 939	 0.001975	 0.117531	 0.0	 263	 263	 263	 1.0142	 0.0	 1	 -30.0	 30.0;
	942	 943	 0.003867	 0.109333	 0.0	 277	 277	 277	 1.028807	 0.0	 1	 -30.0	 30.0;
	942	 944	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.963394	 0.0	 1	 -30.0	 30.0;
	942	 944	 0.003852	 0.112	 0.0	 273	 273	 273	 0.96432	 0.0	 1	 -30.0	 30.0;
	943	 944	 0.004543	 0.137284	 0.0	 224	 224	 224	 0.952381	 0.0	 1	 -30.0	 30.0;
	949	 950	 0.00081	 0.039266	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	949	 950	 0.00081	 0.039612	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	953	 955	 0.00322	 0.165926	 0.0	 189	 189	 189	 0.892063	 0.0	 1	 -30.0	 30.0;
	954	 955	 0.003338	 0.158025	 0.0	 202	 202	 202	 1.0	 0.0	 1	 -30.0	 30.0;
	969	 970	 0.001956	 0.003956	 0.0	 974.0	 974.0	 974.0	 1.0	 0.0	 1	 -30.0	 30.0;
	976	 977	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.98912	 0.0	 1	 -30.0	 30.0;
	976	 977	 0.003852	 0.12642	 0.0	 242	 242	 242	 0.978474	 0.0	 1	 -30.0	 30.0;
	978	 2224	 0.012444	 0.152889	 0.0	 244	 244	 244	 1.0	 0.0	 1	 -30.0	 30.0;
	2777	 979	 0.003956	 0.039511	 0.0	 941	 941	 941	 1.0	 0.0	 1	 -30.0	 30.0;
	979	 2224	 0.005333	 0.308444	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 993	 0.00158	 0.117531	 0.0	 262	 262	 262	 0.978477	 0.0	 1	 -30.0	 30.0;
	2779	 993	 0.001975	 0.11358	 0.0	 271	 271	 271	 0.989123	 0.0	 1	 -30.0	 30.0;
	992	 993	 0.001778	 0.118716	 0.0	 260	 260	 260	 1.001002	 0.0	 1	 -30.0	 30.0;
	998	 999	 0.000665	 0.043075	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	998	 999	 0.000672	 0.04356	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2225	 998	 0.000554	 -0.004224	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	999	 2225	 0.000118	 0.047576	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 1001	 0.000679	 0.04536	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1000	 1001	 0.000686	 0.045083	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1008	 1009	 0.00316	 0.162963	 0.0	 190	 190	 190	 0.975614	 0.0	 1	 -30.0	 30.0;
	1008	 1009	 0.002765	 0.170864	 0.0	 181	 181	 181	 0.967124	 0.0	 1	 -30.0	 30.0;
	1011	 1012	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1011	 1012	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1011	 1012	 0.000319	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1013	 2173	 0.004993	 0.223892	 0.0	 167	 167	 167	 1.0	 0.0	 1	 -30.0	 30.0;
	1014	 2173	 0.000651	 -0.005055	 0.0	 547.0	 547.0	 547.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1015	 2173	 4.2e-05	 0.05374	 0.0	 547.0	 547.0	 547.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 1017	 0.004938	 0.163556	 0.0	 188	 188	 188	 1.024591	 0.0	 1	 -30.0	 30.0;
	1019	 1020	 0.000759	 0.035838	 0.0	 887	 887	 887	 1.001	 0.0	 1	 -30.0	 30.0;
	1022	 2174	 0.000145	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1022	 2201	 0.000139	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2780	 2174	 0.000194	 0.038781	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	1023	 2201	 0.000187	 0.034903	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 1028	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1027	 1028	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2782	 1031	 0.003081	 0.117728	 0.0	 261	 261	 261	 0.93985	 0.0	 1	 -30.0	 30.0;
	1030	 1031	 0.004504	 0.162568	 0.0	 189	 189	 189	 0.950569	 0.0	 1	 -30.0	 30.0;
	1043	 2175	 0.000443	 -0.004848	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1043	 2202	 0.000305	 -0.007133	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1043	 1044	 0.000734	 0.024654	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1044	 2175	 0.000249	 0.047992	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 2202	 0.000506	 0.046814	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 1049	 0.003081	 0.12563	 0.0	 243	 243	 243	 0.964324	 0.0	 1	 -30.0	 30.0;
	1066	 2176	 0.000152	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1066	 2203	 0.000443	 -0.011011	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1066	 2226	 0.000215	 -0.005194	 0.0	 1186.0	 1186.0	 1186.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1066	 2236	 0.000145	 -0.011496	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1067	 2176	 0.000187	 0.038296	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 2203	 0.000374	 0.053463	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 2226	 9.7e-05	 0.032064	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 2236	 0.000194	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 2177	 0.002568	 0.070124	 0.0	 532	 532	 532	 1.0	 0.0	 1	 -30.0	 30.0;
	1071	 2177	 0.002765	 0.132148	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 2785	 0.003556	 0.118321	 0.0	 260	 260	 260	 0.989123	 0.0	 1	 -30.0	 30.0;
	2785	 2178	 0.000229	 -0.004571	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2786	 2204	 0.000215	 -0.004432	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1076	 1077	 0.000312	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	1077	 2178	 9.7e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 2204	 9.7e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	2788	 1086	 0.00316	 0.12484	 0.0	 247	 247	 247	 1.001002	 0.0	 1	 -30.0	 30.0;
	1085	 1086	 0.003753	 0.128	 0.0	 241	 241	 241	 0.989123	 0.0	 1	 -30.0	 30.0;
	1085	 1086	 0.003556	 0.121877	 0.0	 253	 253	 253	 1.001002	 0.0	 1	 -30.0	 30.0;
	2792	 2794	 0.000325	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1097	 2205	 0.000152	 -0.011357	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2792	 2227	 0.000145	 -0.00741	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2792	 2237	 0.000125	 -0.007756	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2794	 2205	 0.000187	 0.038435	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 2227	 0.000194	 0.034626	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 2237	 0.000215	 0.034903	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 2795	 0.03225	 0.602419	 0.0	 65	 65	 65	 1.001	 0.0	 1	 -30.0	 30.0;
	2795	 2796	 0.00316	 0.125037	 0.0	 246	 246	 246	 0.978477	 0.0	 1	 -30.0	 30.0;
	1105	 2796	 0.001679	 0.121679	 0.0	 253	 253	 253	 0.97466	 0.0	 1	 -30.0	 30.0;
	1107	 1108	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.953289	 0.0	 1	 -30.0	 30.0;
	1107	 1108	 0.003398	 0.118716	 0.0	 257	 257	 257	 0.952382	 0.0	 1	 -30.0	 30.0;
	1107	 1108	 0.003852	 0.11121	 0.0	 274	 274	 274	 0.96432	 0.0	 1	 -30.0	 30.0;
	1112	 1113	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1112	 1113	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1119	 2179	 0.00045	 -0.014404	 0.0	 567.0	 567.0	 567.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2797	 2206	 0.000471	 -0.013712	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1119	 1120	 0.000803	 0.034903	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2797	 1120	 0.000269	 0.027168	 0.0	 1167	 1167	 1167	 1.001	 0.0	 1	 -30.0	 30.0;
	1120	 2179	 0.000381	 0.050623	 0.0	 567.0	 567.0	 567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 2206	 0.000367	 0.050554	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 1141	 0.003279	 0.113383	 0.0	 272	 272	 272	 0.98912	 0.0	 1	 -30.0	 30.0;
	1140	 1141	 0.003931	 0.12484	 0.0	 247	 247	 247	 0.978474	 0.0	 1	 -30.0	 30.0;
	1140	 1141	 0.003891	 0.11279	 0.0	 274	 274	 274	 0.978474	 0.0	 1	 -30.0	 30.0;
	1142	 1143	 0.00316	 0.118519	 0.0	 260	 260	 260	 0.95329	 0.0	 1	 -30.0	 30.0;
	1151	 1152	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	2803	 2804	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	2802	 2805	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	1155	 1156	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.094092	 0.0	 1	 -30.0	 30.0;
	1155	 1156	 0.003067	 0.132444	 0.0	 237	 237	 237	 1.094091	 0.0	 1	 -30.0	 30.0;
	1178	 2180	 0.000235	 -0.004294	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1178	 2207	 0.000145	 -0.006233	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1179	 2180	 9e-05	 0.029086	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 2207	 0.000194	 0.031233	 0.0	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 1185	 0.000119	 0.009086	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1210	 1211	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	1223	 1224	 0.004049	 0.124049	 0.0	 246	 246	 246	 0.964324	 0.0	 1	 -30.0	 30.0;
	1223	 1224	 0.003358	 0.124247	 0.0	 246	 246	 246	 0.978473	 0.0	 1	 -30.0	 30.0;
	2818	 1224	 0.001956	 0.124642	 0.0	 245	 245	 245	 0.955109	 0.0	 1	 -30.0	 30.0;
	1226	 1227	 0.00397	 0.113383	 0.0	 271	 271	 271	 0.976559	 0.0	 1	 -30.0	 30.0;
	1226	 1227	 0.003951	 0.119111	 0.0	 258	 258	 258	 0.974657	 0.0	 1	 -30.0	 30.0;
	2820	 1227	 0.001975	 0.116938	 0.0	 263	 263	 263	 0.976559	 0.0	 1	 -30.0	 30.0;
	1236	 1237	 0.001798	 0.118716	 0.0	 260	 260	 260	 0.978474	 0.0	 1	 -30.0	 30.0;
	1236	 1237	 0.001719	 0.122272	 0.0	 253	 253	 253	 0.974664	 0.0	 1	 -30.0	 30.0;
	1271	 1272	 0.000284	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.046025	 0.0	 1	 -30.0	 30.0;
	573	 1279	 0.003951	 0.029126	 0.0162	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 1281	 0.004148	 0.165531	 0.0	 186	 186	 186	 0.978477	 0.0	 1	 -30.0	 30.0;
	572	 2829	 4.2e-05	 0.000339	 0.0061	 1184.0	 1184.0	 1184.0	 1.0	 1.87	 1	 -30.0	 30.0;
	1305	 2829	 0.000679	 0.042867	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1310	 1311	 0.004622	 0.227951	 0.0	 134	 134	 134	 0.937207	 0.0	 1	 -30.0	 30.0;
	1312	 1313	 0.00484	 0.165926	 0.0	 184	 184	 184	 0.968054	 0.0	 1	 -30.0	 30.0;
	2831	 2181	 0.000111	 -0.007895	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1323	 2208	 0.00027	 -0.005402	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2831	 2228	 0.000152	 -0.007964	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2830	 2238	 0.000152	 -0.007271	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1323	 1324	 0.000325	 0.027078	 0.0	 1171	 1171	 1171	 1.0	 0.0	 1	 -30.0	 30.0;
	2832	 2181	 0.000222	 0.03518	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 2208	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 2228	 0.000201	 0.034764	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 2238	 0.000194	 0.034141	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 1326	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.952382	 0.0	 1	 -30.0	 30.0;
	1325	 1326	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.963394	 0.0	 1	 -30.0	 30.0;
	1325	 1326	 0.003654	 0.114568	 0.0	 266	 266	 266	 0.941619	 0.0	 1	 -30.0	 30.0;
	1328	 1329	 0.000339	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	1338	 1339	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.987165	 0.0	 1	 -30.0	 30.0;
	1338	 1339	 0.003437	 0.122469	 0.0	 249	 249	 249	 0.987165	 0.0	 1	 -30.0	 30.0;
	1362	 2182	 0.000215	 -0.00554	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1362	 1363	 0.000325	 0.027355	 0.0	 1154	 1154	 1154	 1.0	 0.0	 1	 -30.0	 30.0;
	1363	 2182	 0.000125	 0.033241	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 1366	 0.003121	 0.125432	 0.0	 246	 246	 246	 0.978474	 0.0	 1	 -30.0	 30.0;
	1367	 1368	 0.00397	 0.124049	 0.0	 256	 256	 256	 0.931096	 0.0	 1	 -30.0	 30.0;
	1367	 1368	 0.003121	 0.125827	 0.0	 253	 253	 253	 0.931096	 0.0	 1	 -30.0	 30.0;
	1370	 1371	 0.004489	 0.280756	 0.0	 126	 126	 126	 0.860587	 0.0	 1	 -30.0	 30.0;
	1712	 1374	 0.000119	 0.009086	 0.0	 473.0	 473.0	 473.0	 1.0	 -6.32	 1	 -30.0	 30.0;
	1375	 1376	 0.00484	 0.162568	 0.0	 188	 188	 188	 0.937207	 0.0	 1	 -30.0	 30.0;
	1379	 1380	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1379	 1380	 0.000339	 0.025	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1379	 1380	 0.000325	 0.024584	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2838	 1389	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	1388	 2840	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	2838	 1389	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	2837	 2839	 0.00158	 0.124049	 0.0	 246	 246	 246	 0.957854	 0.0	 1	 -30.0	 30.0;
	2842	 2844	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	1393	 2844	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	2843	 1394	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	1401	 1402	 0.000817	 0.04349	 0.0	 608.0	 608.0	 608.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1401	 1402	 0.000319	 0.027978	 0.0	 1136	 1136	 1136	 1.005027	 0.0	 1	 -30.0	 30.0;
	1405	 2852	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	2850	 1406	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	2849	 2851	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	1412	 1413	 0.003951	 0.124247	 0.0	 248	 248	 248	 1.0142	 0.0	 1	 -30.0	 30.0;
	2854	 1419	 0.00316	 0.126025	 0.0	 245	 245	 245	 1.026695	 0.0	 1	 -30.0	 30.0;
	1418	 1419	 0.00316	 0.124049	 0.0	 249	 249	 249	 1.053742	 0.0	 1	 -30.0	 30.0;
	1427	 1428	 0.003358	 0.124049	 0.0	 246	 246	 246	 0.98619	 0.0	 1	 -30.0	 30.0;
	1427	 1428	 0.003911	 0.111407	 0.0	 274	 274	 274	 0.963394	 0.0	 1	 -30.0	 30.0;
	2856	 2229	 0.001956	 0.108444	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 1437	 0.000713	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1436	 1437	 0.000332	 0.026939	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	1436	 1437	 0.000319	 0.026385	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1447	 1448	 0.005911	 0.119689	 0.0	 253	 253	 253	 0.976562	 0.0	 1	 -30.0	 30.0;
	1449	 1450	 0.00164	 0.116938	 0.0	 261	 261	 261	 0.968054	 0.0	 1	 -30.0	 30.0;
	1449	 1450	 0.001699	 0.122212	 0.0	 250	 250	 250	 0.96432	 0.0	 1	 -30.0	 30.0;
	1453	 1454	 0.004286	 0.165333	 0.0	 189	 189	 189	 0.98912	 0.0	 1	 -30.0	 30.0;
	1454	 2183	 0.000519	 -0.00831	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1454	 2209	 0.000471	 -0.008033	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1455	 2183	 0.000277	 0.047922	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 2209	 0.00036	 0.049584	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 1459	 0.000796	 0.041413	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1458	 1459	 0.000831	 0.039681	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2863	 1467	 0.002016	 0.079113	 0.0	 493	 493	 493	 1.0	 0.0	 1	 -30.0	 30.0;
	1466	 1468	 0.001975	 0.079012	 0.0	 484	 484	 484	 1.0	 0.0	 1	 -30.0	 30.0;
	1484	 1485	 0.004346	 0.164543	 0.0	 187	 187	 187	 1.001002	 0.0	 1	 -30.0	 30.0;
	1491	 1492	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1491	 1492	 0.000332	 0.024792	 0.0	 1182.0	 1182.0	 1182.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1499	 1500	 0.004938	 0.159012	 0.0	 197	 197	 197	 0.872599	 0.0	 1	 -30.0	 30.0;
	1502	 2184	 0.000118	 -0.005956	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2865	 1503	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1503	 2184	 0.000187	 0.032964	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	1509	 1510	 0.004346	 0.158025	 0.0	 196	 196	 196	 1.013172	 0.0	 1	 -30.0	 30.0;
	1511	 1512	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1514	 2185	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 2210	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 1522	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.975606	 0.0	 1	 -30.0	 30.0;
	1521	 1522	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.975606	 0.0	 1	 -30.0	 30.0;
	2186	 1525	 0.000277	 -0.00464	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1525	 1526	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1526	 2186	 6.2e-05	 0.029571	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 2867	 0.001177	 0.042382	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2230	 1538	 0.000499	 -0.006925	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2239	 1538	 0.000353	 -0.010873	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2867	 2230	 0.000201	 0.055402	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 2239	 0.000429	 0.05374	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 1544	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.968054	 0.0	 1	 -30.0	 30.0;
	1543	 1544	 0.004484	 0.168494	 0.0	 181	 181	 181	 0.978474	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.003358	 0.11121	 0.0	 275	 275	 275	 1.011122	 0.0	 1	 -30.0	 30.0;
	1564	 1565	 0.003812	 0.130963	 0.0	 233	 233	 233	 1.012146	 0.0	 1	 -30.0	 30.0;
	1567	 1568	 0.000291	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1571	 1570	 7.9e-05	 0.000836	 0.0	 45593	 45593	 45593	 1.0	 0.0	 1	 -30.0	 30.0;
	2874	 1591	 0.000171	 0.000313	 0.0003	 82782	 82782	 82782	 1.0	 4.32	 1	 -30.0	 30.0;
	1578	 1579	 0.003891	 0.112198	 0.0	 272	 272	 272	 0.987165	 0.0	 1	 -30.0	 30.0;
	1578	 1579	 0.003556	 0.124642	 0.0	 245	 245	 245	 0.987165	 0.0	 1	 -30.0	 30.0;
	1580	 1581	 0.003931	 0.125373	 0.0	 244	 244	 244	 0.97561	 0.0	 1	 -30.0	 30.0;
	1582	 1583	 0.001699	 0.122469	 0.0	 252	 252	 252	 0.98912	 0.0	 1	 -30.0	 30.0;
	1582	 1583	 0.001679	 0.122469	 0.0	 252	 252	 252	 0.98912	 0.0	 1	 -30.0	 30.0;
	1593	 2187	 0.013911	 0.133333	 0.0	 279	 279	 279	 1.0	 0.0	 1	 -30.0	 30.0;
	1594	 2187	 0.008933	 0.147111	 0.0	 234	 234	 234	 1.0	 0.0	 1	 -30.0	 30.0;
	1595	 2187	 0.0036	 0.008933	 0.0	 3573	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	2246	 1602	 0.000457	 -0.005194	 0.0	 557.0	 557.0	 557.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1602	 1603	 0.000796	 0.048199	 0.0	 557.0	 557.0	 557.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1603	 2246	 0.000242	 0.047438	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 1605	 0.003911	 0.111407	 0.0	 275	 275	 275	 0.971818	 0.0	 1	 -30.0	 30.0;
	2879	 1619	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	2880	 1619	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	1618	 1619	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	1623	 1622	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	1634	 1635	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	1652	 1654	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.96432	 0.0	 1	 -30.0	 30.0;
	1652	 1654	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.957851	 0.0	 1	 -30.0	 30.0;
	1653	 1654	 0.003556	 0.127407	 0.0	 244	 244	 244	 1.012146	 0.0	 1	 -30.0	 30.0;
	1658	 1659	 0.003141	 0.117136	 0.0	 264	 264	 264	 0.974664	 0.0	 1	 -30.0	 30.0;
	2885	 1663	 0.004938	 0.161383	 0.0	 191	 191	 191	 0.967124	 0.0	 1	 -30.0	 30.0;
	2885	 1663	 0.004938	 0.163951	 0.0	 188	 188	 188	 0.956935	 0.0	 1	 -30.0	 30.0;
	1662	 1663	 0.004346	 0.118914	 0.0	 259	 259	 259	 0.976559	 0.0	 1	 -30.0	 30.0;
	2888	 2892	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	1666	 2890	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	2887	 1667	 0.001857	 0.114963	 0.0	 333	 333	 333	 1.0	 0.0	 1	 -30.0	 30.0;
	2894	 1674	 0.004356	 0.137467	 0.0	 231	 231	 231	 1.036269	 0.0	 1	 -30.0	 30.0;
	1673	 1674	 0.008711	 0.1592	 0.0	 199	 199	 199	 1.036269	 0.0	 1	 -30.0	 30.0;
	1675	 1676	 0.019652	 0.553288	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	1679	 1680	 0.002016	 0.079113	 0.0	 492	 492	 492	 1.0	 0.0	 1	 -30.0	 30.0;
	1685	 1687	 0.003951	 0.12484	 0.0	 245	 245	 245	 0.978474	 0.0	 1	 -30.0	 30.0;
	1686	 1687	 0.00164	 0.118519	 0.0	 259	 259	 259	 1.007049	 0.0	 1	 -30.0	 30.0;
	1688	 1689	 0.000783	 0.042936	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1688	 1689	 0.000776	 0.043075	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1697	 2188	 0.000159	 -0.006025	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1697	 2211	 0.000229	 -0.004571	 0.0	 1174.0	 1174.0	 1174.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1697	 1698	 0.000332	 0.025623	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1698	 2188	 0.000173	 0.031163	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	1698	 2211	 9e-05	 0.029363	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 1701	 0.003186	 0.137758	 0.0	 229	 229	 229	 0.987167	 0.0	 1	 -30.0	 30.0;
	1709	 1710	 0.000686	 0.047922	 0.0	 606.0	 606.0	 606.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2895	 1710	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	2895	 1710	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	1720	 1721	 0.00397	 0.125235	 0.0	 244	 244	 244	 0.999001	 0.0	 1	 -30.0	 30.0;
	2994	 1721	 0.00397	 0.125235	 0.0	 244	 244	 244	 1.011122	 0.0	 1	 -30.0	 30.0;
	1722	 2897	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1722	 1723	 0.000339	 0.029778	 0.0	 1065	 1065	 1065	 1.0	 0.0	 1	 -30.0	 30.0;
	1739	 2231	 0.00018	 -0.007687	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1739	 2240	 0.000125	 -0.007618	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1740	 2231	 0.000166	 0.035111	 0.0	 976	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	1740	 2240	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 1745	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.96432	 0.0	 1	 -30.0	 30.0;
	1744	 1745	 0.003773	 0.122667	 0.0	 249	 249	 249	 0.974664	 0.0	 1	 -30.0	 30.0;
	1744	 1745	 0.001857	 0.121086	 0.0	 252	 252	 252	 0.97561	 0.0	 1	 -30.0	 30.0;
	1745	 1746	 6.2e-05	 0.031787	 0.0	 993	 993	 993	 1.0	 0.0	 1	 -30.0	 30.0;
	1745	 1746	 6.2e-05	 0.031856	 0.0	 991	 991	 991	 1.0	 0.0	 1	 -30.0	 30.0;
	1750	 1751	 0.00316	 0.125432	 0.0	 246	 246	 246	 0.989123	 0.0	 1	 -30.0	 30.0;
	1750	 1751	 0.003951	 0.112988	 0.0	 273	 273	 273	 0.989123	 0.0	 1	 -30.0	 30.0;
	2911	 1759	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	2906	 1759	 0.000208	 0.014751	 0.0	 1746.0	 1746.0	 1746.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	2909	 1759	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	2910	 1759	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	2908	 1759	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	2907	 1759	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	2905	 1759	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	2904	 1759	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	1758	 1759	 0.000319	 0.024307	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1771	 1772	 0.001975	 0.126025	 0.0	 242	 242	 242	 0.963394	 0.0	 1	 -30.0	 30.0;
	1771	 1772	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	1771	 1772	 0.001956	 0.125037	 0.0	 244	 244	 244	 0.963394	 0.0	 1	 -30.0	 30.0;
	1773	 1774	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.933709	 0.0	 1	 -30.0	 30.0;
	1773	 1774	 0.005057	 0.160988	 0.0	 194	 194	 194	 0.933709	 0.0	 1	 -30.0	 30.0;
	1781	 1782	 0.017333	 0.441333	 0.0	 69	 69	 69	 0.971818	 0.0	 1	 -30.0	 30.0;
	1786	 2189	 0.000699	 -0.004709	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1786	 1787	 0.000686	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1787	 2189	 1.4e-05	 0.052839	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1788	 1789	 0.00316	 0.125235	 0.0	 246	 246	 246	 1.002005	 0.0	 1	 -30.0	 30.0;
	1788	 1789	 0.001675	 0.121284	 0.0	 254	 254	 254	 1.002005	 0.0	 1	 -30.0	 30.0;
	2917	 1803	 0.002431	 0.093213	 0.0	 406	 406	 406	 1.0	 0.0	 1	 -30.0	 30.0;
	1802	 1803	 0.002431	 0.092874	 0.0	 408	 408	 408	 1.0	 0.0	 1	 -30.0	 30.0;
	2919	 1803	 0.002431	 0.093428	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	2918	 1803	 0.002431	 0.09349	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	2921	 1803	 0.002431	 0.093428	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	2920	 1803	 0.008906	 0.093352	 0.0	 404	 404	 404	 1.0	 0.0	 1	 -30.0	 30.0;
	2981	 1805	 0.000339	 0.027008	 0.0	 1175	 1175	 1175	 1.0	 0.0	 1	 -30.0	 30.0;
	1804	 1805	 0.000395	 0.027216	 0.0	 1166	 1166	 1166	 1.0	 0.0	 1	 -30.0	 30.0;
	1804	 1805	 0.000325	 0.027632	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	1816	 1817	 0.005136	 0.160988	 0.0	 194	 194	 194	 0.863561	 0.0	 1	 -30.0	 30.0;
	1820	 1821	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1820	 2212	 0.000229	 -0.004363	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1821	 2212	 9.7e-05	 0.029155	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 1833	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1832	 1833	 0.000319	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2923	 1839	 0.000803	 0.039335	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1838	 1839	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2923	 1839	 0.000796	 0.039266	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1840	 2924	 0.000305	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1844	 1845	 0.002212	 0.125432	 0.0	 251	 251	 251	 0.928505	 0.0	 1	 -30.0	 30.0;
	1845	 1846	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1845	 1846	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1848	 1849	 0.003002	 0.118716	 0.0	 257	 257	 257	 0.94697	 0.0	 1	 -30.0	 30.0;
	1848	 1849	 0.003002	 0.118716	 0.0	 257	 257	 257	 0.968054	 0.0	 1	 -30.0	 30.0;
	1850	 1851	 0.003121	 0.12563	 0.0	 243	 243	 243	 0.987165	 0.0	 1	 -30.0	 30.0;
	1850	 1851	 0.003951	 0.125235	 0.0	 244	 244	 244	 0.987165	 0.0	 1	 -30.0	 30.0;
	1850	 1851	 0.003121	 0.12563	 0.0	 243	 243	 243	 0.987165	 0.0	 1	 -30.0	 30.0;
	2927	 2190	 0.00027	 -0.005332	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2927	 2213	 0.000249	 -0.005471	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1862	 2232	 0.000125	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2927	 2241	 0.000173	 -0.007895	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2927	 2247	 0.000132	 -0.010942	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1863	 2190	 5.5e-05	 0.032756	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 2213	 6.9e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 2232	 0.000201	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 2241	 0.000166	 0.034834	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 2247	 0.000208	 0.038643	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	1864	 1865	 7.9e-05	 0.000836	 0.0	 45649	 45649	 45649	 1.0	 0.0	 1	 -30.0	 30.0;
	1870	 2214	 0.000145	 -0.011288	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2929	 1871	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1870	 2242	 0.000291	 -0.00554	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2929	 1871	 0.000693	 0.048615	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2929	 2248	 0.000471	 -0.005263	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1871	 2214	 0.000187	 0.038712	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 2242	 2.8e-05	 0.032895	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 2248	 0.000235	 0.053324	 0.0	 605.0	 605.0	 605.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 1874	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	2931	 2933	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	1873	 2934	 0.011852	 0.355556	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	1891	 1892	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1891	 1892	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2938	 1892	 0.000339	 0.024446	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2938	 1892	 0.000332	 0.025069	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1894	 1895	 0.000346	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1894	 1895	 0.000332	 0.025208	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1900	 1901	 0.000325	 0.027701	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	2575	 2250	 0.0	 0.019737	 0.0	 254.0	 254.0	 254.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	46	 2251	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	81	 2253	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	81	 2254	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	81	 2255	 0.0	 0.54184	 0.0	 64	 64	 64	 1.044444	 0.0	 1	 -30.0	 30.0;
	95	 2257	 0.0	 0.142857	 0.0	 241	 241	 241	 1.111111	 0.0	 1	 -30.0	 30.0;
	95	 2258	 0.0	 0.219149	 0.0	 157	 157	 157	 1.111111	 0.0	 1	 -30.0	 30.0;
	98	 2259	 0.0	 0.090928	 0.0	 378	 378	 378	 1.066667	 0.0	 1	 -30.0	 30.0;
	106	 2260	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	106	 2261	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	2587	 2262	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	2587	 2263	 0.0	 0.366794	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	147	 2264	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	147	 2265	 0.0	 0.128409	 0.0	 268	 268	 268	 1.048889	 0.0	 1	 -30.0	 30.0;
	148	 2266	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	148	 2267	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	2591	 2268	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	2591	 2269	 0.0	 0.15	 0.0	 229	 229	 229	 1.060526	 0.0	 1	 -30.0	 30.0;
	2595	 2270	 0.0	 0.012611	 0.0	 1051.0	 1051.0	 1051.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	187	 2271	 0.0	 0.012611	 0.0	 1099.0	 1099.0	 1099.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	2594	 2272	 0.0	 0.012611	 0.0	 1094.0	 1094.0	 1094.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	2593	 2273	 0.0	 0.012611	 0.0	 1019.0	 1019.0	 1019.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	188	 2274	 0.0	 0.048207	 0.0	 711	 711	 711	 1.080978	 0.0	 1	 -30.0	 30.0;
	2596	 2275	 0.0	 0.048207	 0.0	 711	 711	 711	 1.080978	 0.0	 1	 -30.0	 30.0;
	189	 2276	 0.0	 0.043965	 0.0	 255.0	 255.0	 255.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	189	 2277	 0.0	 0.03442	 0.0	 995	 995	 995	 1.060526	 0.0	 1	 -30.0	 30.0;
	189	 2278	 0.0	 0.06506	 0.0	 527	 527	 527	 1.060526	 0.0	 1	 -30.0	 30.0;
	198	 2279	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	198	 2280	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	198	 2281	 0.0	 0.161429	 0.0	 213	 213	 213	 1.054667	 0.0	 1	 -30.0	 30.0;
	198	 2282	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	198	 2283	 0.0	 0.17931	 0.0	 192	 192	 192	 1.054667	 0.0	 1	 -30.0	 30.0;
	1027	 2284	 0.0	 0.044965	 0.0	 271.0	 271.0	 271.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	229	 2286	 0.0	 0.112429	 0.0	 306	 306	 306	 1.042667	 0.0	 1	 -30.0	 30.0;
	229	 2287	 0.0	 0.183397	 0.0	 188	 188	 188	 1.093334	 0.0	 1	 -30.0	 30.0;
	229	 2289	 0.0	 0.183397	 0.0	 188	 188	 188	 1.088889	 0.0	 1	 -30.0	 30.0;
	229	 2290	 0.0	 0.183397	 0.0	 188	 188	 188	 1.088889	 0.0	 1	 -30.0	 30.0;
	231	 2291	 0.0	 0.166743	 0.0	 206	 206	 206	 1.026879	 0.0	 1	 -30.0	 30.0;
	231	 2292	 0.0	 0.300114	 0.0	 115	 115	 115	 1.020096	 0.0	 1	 -30.0	 30.0;
	2611	 2293	 0.0	 0.012685	 0.0	 1080.0	 1080.0	 1080.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2610	 2294	 0.0	 0.012685	 0.0	 1036.0	 1036.0	 1036.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2609	 2295	 0.0	 0.012685	 0.0	 1053.0	 1053.0	 1053.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	246	 2296	 0.0	 0.012685	 0.0	 1042.0	 1042.0	 1042.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	253	 2297	 0.0	 0.009303	 0.0	 1533.0	 1533.0	 1533.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	254	 2298	 0.0	 0.009303	 0.0	 1533.0	 1533.0	 1533.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	257	 2299	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	257	 2300	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	257	 2301	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	2612	 2302	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	2612	 2303	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	2612	 2304	 0.0	 0.200062	 0.0	 172	 172	 172	 1.013333	 0.0	 1	 -30.0	 30.0;
	266	 2305	 0.0	 0.453182	 0.0	 76	 76	 76	 1.088889	 0.0	 1	 -30.0	 30.0;
	266	 2306	 0.0	 0.453182	 0.0	 76	 76	 76	 1.088889	 0.0	 1	 -30.0	 30.0;
	338	 2307	 0.0	 0.008909	 0.0	 1616.0	 1616.0	 1616.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	340	 2309	 0.0	 0.008909	 0.0	 1627.0	 1627.0	 1627.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	341	 2310	 0.0	 0.008909	 0.0	 1627.0	 1627.0	 1627.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	384	 2311	 0.0	 0.128889	 0.0	 267	 267	 267	 1.088445	 0.0	 1	 -30.0	 30.0;
	2648	 2312	 0.0	 0.133372	 0.0	 258	 258	 258	 1.043111	 0.0	 1	 -30.0	 30.0;
	2648	 2313	 0.0	 0.133372	 0.0	 258	 258	 258	 1.088445	 0.0	 1	 -30.0	 30.0;
	395	 2314	 0.0	 0.048207	 0.0	 713	 713	 713	 1.080978	 0.0	 1	 -30.0	 30.0;
	398	 2315	 0.0	 0.054074	 0.0	 634	 634	 634	 1.077631	 0.0	 1	 -30.0	 30.0;
	2976	 2317	 0.0	 0.012685	 0.0	 1056.0	 1056.0	 1056.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	400	 2318	 0.0	 0.012685	 0.0	 288.0	 288.0	 288.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2654	 2319	 0.0	 0.012611	 0.0	 1067.0	 1067.0	 1067.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	401	 2320	 0.0	 0.012611	 0.0	 1062.0	 1062.0	 1062.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	403	 2321	 0.0	 0.009257	 0.0	 1826.0	 1826.0	 1826.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	404	 2322	 0.0	 0.009257	 0.0	 1827.0	 1827.0	 1827.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	411	 2323	 0.0	 0.009257	 0.0	 1754.0	 1754.0	 1754.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2655	 2324	 0.0	 0.009257	 0.0	 1754.0	 1754.0	 1754.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2573	 2325	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	24	 2326	 0.0	 0.06579	 0.0	 522	 522	 522	 1.096667	 0.0	 1	 -30.0	 30.0;
	791	 2327	 0.0	 0.1	 0.0	 344	 344	 344	 1.057778	 0.0	 1	 -30.0	 30.0;
	2661	 2328	 0.0	 0.01954	 0.0	 725.0	 725.0	 725.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	445	 2329	 0.0	 0.020227	 0.0	 677.0	 677.0	 677.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	2662	 2330	 0.0	 0.01954	 0.0	 676.0	 676.0	 676.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	446	 2331	 0.0	 0.021576	 0.0	 666.0	 666.0	 666.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	448	 2332	 0.0	 0.411923	 0.0	 84	 84	 84	 1.08	 0.0	 1	 -30.0	 30.0;
	553	 2336	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	553	 2337	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	553	 2338	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	553	 2339	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	553	 2340	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	553	 2341	 0.0	 0.2424	 0.0	 142	 142	 142	 1.075778	 0.0	 1	 -30.0	 30.0;
	2674	 2342	 0.0	 0.012685	 0.0	 1136.0	 1136.0	 1136.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2673	 2343	 0.0	 0.012685	 0.0	 1136.0	 1136.0	 1136.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	493	 2344	 0.0	 0.012611	 0.0	 1144.0	 1144.0	 1144.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2672	 2345	 0.0	 0.012611	 0.0	 1064.0	 1064.0	 1064.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	508	 2346	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	508	 2348	 0.0	 0.181818	 0.0	 189	 189	 189	 1.044444	 0.0	 1	 -30.0	 30.0;
	518	 2349	 0.0	 0.041231	 0.0	 299.0	 299.0	 299.0	 1.0948	 0.0	 1	 -30.0	 30.0;
	2676	 2350	 0.0	 0.273494	 0.0	 126	 126	 126	 1.062667	 0.0	 1	 -30.0	 30.0;
	545	 2351	 0.0	 0.032831	 0.0	 286.0	 286.0	 286.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	2683	 2352	 0.0	 0.012685	 0.0	 1032.0	 1032.0	 1032.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	601	 2353	 0.0	 0.012685	 0.0	 1032.0	 1032.0	 1032.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2684	 2354	 0.0	 0.012685	 0.0	 1032.0	 1032.0	 1032.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	602	 2355	 0.0	 0.012685	 0.0	 1040.0	 1040.0	 1040.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	617	 2356	 0.0	 0.345838	 0.0	 100	 100	 100	 1.044444	 0.0	 1	 -30.0	 30.0;
	2701	 2357	 0.0	 0.009303	 0.0	 1617.0	 1617.0	 1617.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	670	 2358	 0.0	 0.009303	 0.0	 1617.0	 1617.0	 1617.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	2717	 2359	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	738	 2360	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	738	 2361	 0.0	 0.128214	 0.0	 268	 268	 268	 1.056743	 0.0	 1	 -30.0	 30.0;
	738	 2362	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	2717	 2363	 0.0	 0.148375	 0.0	 232	 232	 232	 1.057778	 0.0	 1	 -30.0	 30.0;
	2729	 2364	 0.0	 0.008909	 0.0	 1540.0	 1540.0	 1540.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	756	 2365	 0.0	 0.008909	 0.0	 1540.0	 1540.0	 1540.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	757	 2367	 0.0	 0.457282	 0.0	 75	 75	 75	 1.066667	 0.0	 1	 -30.0	 30.0;
	767	 2368	 0.0	 0.042476	 0.0	 809	 809	 809	 1.062222	 0.0	 1	 -30.0	 30.0;
	769	 2369	 0.0	 0.302795	 0.0	 114	 114	 114	 1.053333	 0.0	 1	 -30.0	 30.0;
	769	 2370	 0.0	 0.302795	 0.0	 114	 114	 114	 1.053333	 0.0	 1	 -30.0	 30.0;
	2733	 2371	 0.0	 0.012685	 0.0	 1122.0	 1122.0	 1122.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	774	 2372	 0.0	 0.012685	 0.0	 1123.0	 1123.0	 1123.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2732	 2373	 0.0	 0.012685	 0.0	 1122.0	 1122.0	 1122.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2736	 2374	 0.0	 0.012685	 0.0	 1122.0	 1122.0	 1122.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2735	 2375	 0.0	 0.012685	 0.0	 1122.0	 1122.0	 1122.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2734	 2376	 0.0	 0.012685	 0.0	 996.0	 996.0	 996.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	799	 2377	 0.0	 0.041112	 0.0	 835	 835	 835	 1.081067	 0.0	 1	 -30.0	 30.0;
	811	 2378	 0.0	 0.029081	 0.0	 516.0	 516.0	 516.0	 1.080888	 0.0	 1	 -30.0	 30.0;
	824	 2379	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	2748	 2380	 0.0	 0.020227	 0.0	 678.0	 678.0	 678.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	825	 2381	 0.0	 0.021197	 0.0	 702.0	 702.0	 702.0	 1.103079	 0.0	 1	 -30.0	 30.0;
	829	 2382	 0.0	 0.203226	 0.0	 169	 169	 169	 1.048889	 0.0	 1	 -30.0	 30.0;
	829	 2383	 0.0	 0.203226	 0.0	 169	 169	 169	 1.048889	 0.0	 1	 -30.0	 30.0;
	836	 2385	 0.0	 0.372846	 0.0	 92	 92	 92	 1.076889	 0.0	 1	 -30.0	 30.0;
	836	 2386	 0.0	 0.372846	 0.0	 92	 92	 92	 1.076889	 0.0	 1	 -30.0	 30.0;
	888	 2388	 0.0	 0.525174	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	906	 2389	 0.0	 0.460144	 0.0	 75	 75	 75	 1.035556	 0.0	 1	 -30.0	 30.0;
	977	 2390	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	977	 2391	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	977	 2392	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	977	 2393	 0.0	 0.312857	 0.0	 110	 110	 110	 1.054667	 0.0	 1	 -30.0	 30.0;
	964	 2394	 0.0	 0.048207	 0.0	 712	 712	 712	 1.080978	 0.0	 1	 -30.0	 30.0;
	971	 2395	 0.0	 0.220078	 0.0	 156	 156	 156	 1.07511	 0.0	 1	 -30.0	 30.0;
	971	 2396	 0.0	 0.220078	 0.0	 156	 156	 156	 1.07511	 0.0	 1	 -30.0	 30.0;
	991	 2397	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	991	 2398	 0.0	 0.17125	 0.0	 201	 201	 201	 1.053333	 0.0	 1	 -30.0	 30.0;
	991	 2399	 0.0	 0.13875	 0.0	 248	 248	 248	 1.049777	 0.0	 1	 -30.0	 30.0;
	991	 2400	 0.0	 0.120375	 0.0	 286	 286	 286	 1.053333	 0.0	 1	 -30.0	 30.0;
	996	 2401	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	996	 2402	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	996	 2403	 0.0	 0.329412	 0.0	 105	 105	 105	 1.053333	 0.0	 1	 -30.0	 30.0;
	1003	 2404	 0.0	 0.181636	 0.0	 189	 189	 189	 1.088889	 0.0	 1	 -30.0	 30.0;
	1036	 2409	 0.0	 0.044965	 0.0	 763	 763	 763	 1.080978	 0.0	 1	 -30.0	 30.0;
	2783	 2410	 0.0	 0.044965	 0.0	 763	 763	 763	 1.080978	 0.0	 1	 -30.0	 30.0;
	1053	 2411	 0.0	 0.482751	 0.0	 72	 72	 72	 1.137778	 0.0	 1	 -30.0	 30.0;
	1053	 2412	 0.0	 0.482751	 0.0	 72	 72	 72	 1.137778	 0.0	 1	 -30.0	 30.0;
	202	 2413	 0.0	 0.10632	 0.0	 323	 323	 323	 1.043111	 0.0	 1	 -30.0	 30.0;
	2599	 2414	 0.0	 0.10632	 0.0	 323	 323	 323	 1.043111	 0.0	 1	 -30.0	 30.0;
	1638	 2415	 0.0	 0.084636	 0.0	 406	 406	 406	 1.097778	 0.0	 1	 -30.0	 30.0;
	153	 2416	 0.0	 0.031723	 0.0	 340.0	 340.0	 340.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1123	 2417	 0.0	 0.25608	 0.0	 134	 134	 134	 1.072445	 0.0	 1	 -30.0	 30.0;
	1123	 2418	 0.0	 0.25608	 0.0	 134	 134	 134	 1.072445	 0.0	 1	 -30.0	 30.0;
	1128	 2419	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	2798	 2420	 0.0	 0.0516	 0.0	 666	 666	 666	 1.07511	 0.0	 1	 -30.0	 30.0;
	1130	 2422	 0.0	 0.0596	 0.0	 575	 575	 575	 1.092105	 0.0	 1	 -30.0	 30.0;
	2799	 2423	 0.0	 0.0596	 0.0	 575	 575	 575	 1.092105	 0.0	 1	 -30.0	 30.0;
	2799	 2424	 0.0	 0.05972	 0.0	 574	 574	 574	 1.092105	 0.0	 1	 -30.0	 30.0;
	1143	 2425	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	1143	 2426	 0.0	 0.15879	 0.0	 217	 217	 217	 1.052889	 0.0	 1	 -30.0	 30.0;
	2695	 2427	 0.0	 0.012685	 0.0	 1117.0	 1117.0	 1117.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	660	 2428	 0.0	 0.012685	 0.0	 1125.0	 1125.0	 1125.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1166	 2429	 0.0	 0.03299	 0.0	 1041	 1041	 1041	 1.04	 0.0	 1	 -30.0	 30.0;
	1166	 2430	 0.0	 0.04269	 0.0	 804	 804	 804	 1.081	 0.0	 1	 -30.0	 30.0;
	1167	 2431	 0.0	 0.034269	 0.0	 1000	 1000	 1000	 1.060526	 0.0	 1	 -30.0	 30.0;
	1195	 2432	 0.0	 0.009303	 0.0	 1665.0	 1665.0	 1665.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1200	 2434	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	1200	 2435	 0.0	 0.144154	 0.0	 239	 239	 239	 1.066667	 0.0	 1	 -30.0	 30.0;
	1203	 2436	 0.0	 0.297059	 0.0	 116	 116	 116	 1.066667	 0.0	 1	 -30.0	 30.0;
	2816	 2437	 0.0	 0.008909	 0.0	 1670.0	 1670.0	 1670.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1222	 2438	 0.0	 0.008909	 0.0	 1674.0	 1674.0	 1674.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2817	 2439	 0.0	 0.008909	 0.0	 1684.0	 1684.0	 1684.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2815	 2440	 0.0	 0.008909	 0.0	 1578.0	 1578.0	 1578.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1230	 2441	 0.0	 0.389792	 0.0	 89	 89	 89	 1.044444	 0.0	 1	 -30.0	 30.0;
	2821	 2442	 0.0	 0.009303	 0.0	 1662.0	 1662.0	 1662.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1241	 2443	 0.0	 0.009303	 0.0	 1662.0	 1662.0	 1662.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2822	 2444	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	1273	 2445	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	2823	 2446	 0.0	 0.021485	 0.0	 1594	 1594	 1594	 1.103079	 0.0	 1	 -30.0	 30.0;
	2824	 2447	 0.0	 0.019737	 0.0	 1735	 1735	 1735	 1.092105	 0.0	 1	 -30.0	 30.0;
	1277	 2449	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	1277	 2450	 0.0	 0.314388	 0.0	 110	 110	 110	 1.048889	 0.0	 1	 -30.0	 30.0;
	1279	 2452	 0.0	 0.156299	 0.0	 220	 220	 220	 1.053333	 0.0	 1	 -30.0	 30.0;
	1279	 2453	 0.0	 0.156299	 0.0	 220	 220	 220	 1.053333	 0.0	 1	 -30.0	 30.0;
	2827	 2454	 0.0	 0.044965	 0.0	 764	 764	 764	 1.080978	 0.0	 1	 -30.0	 30.0;
	1289	 2455	 0.0	 0.020227	 0.0	 573.0	 573.0	 573.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1311	 2457	 0.0	 0.214367	 0.0	 161	 161	 161	 1.026667	 0.0	 1	 -30.0	 30.0;
	1319	 2458	 0.0	 0.733548	 0.0	 47	 47	 47	 1.044444	 0.0	 1	 -30.0	 30.0;
	1357	 2459	 0.0	 0.431133	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	1357	 2460	 0.0	 0.431017	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	1348	 2461	 0.0	 0.046748	 0.0	 252.0	 252.0	 252.0	 1.066667	 0.0	 1	 -30.0	 30.0;
	1361	 2462	 0.0	 0.283636	 0.0	 122	 122	 122	 1.022222	 0.0	 1	 -30.0	 30.0;
	2835	 2463	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	1369	 2464	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	2834	 2465	 0.0	 0.155048	 0.0	 222	 222	 222	 1.0	 0.0	 1	 -30.0	 30.0;
	1371	 2466	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	1371	 2467	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	1371	 2468	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	1371	 2469	 0.0	 0.327904	 0.0	 105	 105	 105	 1.05641	 0.0	 1	 -30.0	 30.0;
	2846	 2470	 0.0	 0.0774	 0.0	 443	 443	 443	 1.052632	 0.0	 1	 -30.0	 30.0;
	2848	 2471	 0.0	 0.06037	 0.0	 568	 568	 568	 1.031422	 0.0	 1	 -30.0	 30.0;
	2847	 2473	 0.0	 0.0774	 0.0	 443	 443	 443	 1.052632	 0.0	 1	 -30.0	 30.0;
	2607	 2474	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	2608	 2475	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	239	 2477	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	2605	 2478	 0.0	 0.330403	 0.0	 104	 104	 104	 1.044444	 0.0	 1	 -30.0	 30.0;
	1477	 2481	 0.0	 0.317591	 0.0	 109	 109	 109	 1.022222	 0.0	 1	 -30.0	 30.0;
	1479	 2482	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	1479	 2483	 0.0	 0.329412	 0.0	 105	 105	 105	 1.044444	 0.0	 1	 -30.0	 30.0;
	1488	 2484	 0.0	 0.302312	 0.0	 114	 114	 114	 1.034667	 0.0	 1	 -30.0	 30.0;
	1488	 2485	 0.0	 0.290091	 0.0	 119	 119	 119	 1.04	 0.0	 1	 -30.0	 30.0;
	1488	 2486	 0.0	 0.290101	 0.0	 119	 119	 119	 1.04	 0.0	 1	 -30.0	 30.0;
	1488	 2487	 0.0	 0.175059	 0.0	 196	 196	 196	 1.103555	 0.0	 1	 -30.0	 30.0;
	1500	 2489	 0.0	 0.167949	 0.0	 205	 205	 205	 1.048889	 0.0	 1	 -30.0	 30.0;
	1505	 2490	 0.0	 0.733625	 0.0	 47	 47	 47	 1.08	 0.0	 1	 -30.0	 30.0;
	1505	 2491	 0.0	 0.733625	 0.0	 47	 47	 47	 1.08	 0.0	 1	 -30.0	 30.0;
	1541	 2493	 0.0	 0.124444	 0.0	 276	 276	 276	 1.046222	 0.0	 1	 -30.0	 30.0;
	1541	 2494	 0.0	 0.124444	 0.0	 276	 276	 276	 1.046222	 0.0	 1	 -30.0	 30.0;
	1544	 2496	 0.0	 0.088828	 0.0	 387	 387	 387	 1.022222	 0.0	 1	 -30.0	 30.0;
	1544	 2497	 0.0	 0.088828	 0.0	 387	 387	 387	 1.022222	 0.0	 1	 -30.0	 30.0;
	1558	 2498	 0.0	 0.009303	 0.0	 1578.0	 1578.0	 1578.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2869	 2499	 0.0	 0.009303	 0.0	 1578.0	 1578.0	 1578.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	646	 2500	 0.0	 0.035942	 0.0	 954	 954	 954	 1.081023	 0.0	 1	 -30.0	 30.0;
	2689	 2501	 0.0	 0.019697	 0.0	 254.0	 254.0	 254.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	645	 2502	 0.0	 0.037419	 0.0	 915	 915	 915	 1.11579	 0.0	 1	 -30.0	 30.0;
	2688	 2503	 0.0	 0.037117	 0.0	 923	 923	 923	 1.11579	 0.0	 1	 -30.0	 30.0;
	1581	 2504	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	1581	 2505	 0.0	 0.244364	 0.0	 141	 141	 141	 1.044444	 0.0	 1	 -30.0	 30.0;
	1586	 2507	 0.0	 0.226	 0.0	 152	 152	 152	 1.048889	 0.0	 1	 -30.0	 30.0;
	1586	 2508	 0.0	 0.226	 0.0	 152	 152	 152	 1.048889	 0.0	 1	 -30.0	 30.0;
	1587	 2509	 0.0	 0.3396	 0.0	 102	 102	 102	 1.069841	 0.0	 1	 -30.0	 30.0;
	2875	 2510	 0.0	 0.3396	 0.0	 102	 102	 102	 1.069841	 0.0	 1	 -30.0	 30.0;
	1590	 2511	 0.0	 0.148936	 0.0	 231	 231	 231	 1.073333	 0.0	 1	 -30.0	 30.0;
	1590	 2512	 0.0	 0.21875	 0.0	 157	 157	 157	 1.073333	 0.0	 1	 -30.0	 30.0;
	1599	 2513	 0.0	 0.012611	 0.0	 1068.0	 1068.0	 1068.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	2877	 2514	 0.0	 0.012611	 0.0	 1072.0	 1072.0	 1072.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1605	 2515	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	1605	 2516	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	1605	 2517	 0.0	 0.1992	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	1677	 2519	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	1677	 2520	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	1677	 2521	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	1677	 2523	 0.0	 0.092765	 0.0	 370	 370	 370	 1.065789	 0.0	 1	 -30.0	 30.0;
	1687	 2524	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	1687	 2525	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	1687	 2526	 0.0	 0.1195	 0.0	 288	 288	 288	 1.044444	 0.0	 1	 -30.0	 30.0;
	1753	 2527	 0.0	 0.012769	 0.0	 793.0	 793.0	 793.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	2903	 2528	 0.0	 0.012769	 0.0	 803.0	 803.0	 803.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	2902	 2529	 0.0	 0.012769	 0.0	 801.0	 801.0	 801.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	2901	 2530	 0.0	 0.012769	 0.0	 682.0	 682.0	 682.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1778	 2531	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	1778	 2532	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	2915	 2533	 0.0	 0.050588	 0.0	 679	 679	 679	 1.048889	 0.0	 1	 -30.0	 30.0;
	2926	 2534	 0.0	 0.044965	 0.0	 270.0	 270.0	 270.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	1853	 2535	 0.0	 0.044965	 0.0	 291.0	 291.0	 291.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	1859	 2536	 0.0	 0.070769	 0.0	 484	 484	 484	 1.026316	 0.0	 1	 -30.0	 30.0;
	1882	 2537	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
	1882	 2538	 0.0	 0.15125	 0.0	 227	 227	 227	 1.044444	 0.0	 1	 -30.0	 30.0;
	1001	 2539	 5e-06	 5e-05	 0.0014	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 2540	 5e-06	 5e-05	 0.0014	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 2541	 0.002262	 0.013491	 0.0253	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 2542	 0.000544	 0.006842	 0.1762	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 2543	 0.002222	 0.014124	 0.0294	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 2544	 0.000322	 0.003148	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 2545	 0.000781	 0.006247	 0.0106	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1160	 2546	 0.000232	 0.001856	 0.003	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 2547	 0.000661	 0.008092	 0.3004	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 2548	 0.00037	 0.004699	 0.1119	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 2549	 0.000544	 0.005689	 0.1249	 1253.0	 1253.0	 1253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 2550	 0.000457	 0.005163	 0.1148	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2825	 2551	 0.004375	 0.020138	 0.0327	 359.0	 359.0	 359.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2041	 2552	 0.00076	 0.004523	 0.0086	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 2553	 0.001086	 0.016543	 0.4202	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 2554	 0.00106	 0.005879	 0.0025	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 2555	 0.000264	 0.002841	 0.0505	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 2556	 0.00165	 0.007587	 0.0253	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 2557	 0.000256	 0.003556	 0.1292	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 2558	 0.000253	 0.003556	 0.1292	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	405	 2559	 0.003052	 0.022203	 0.0276	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 2560	 0.000544	 0.005865	 0.1274	 1624.0	 1624.0	 1624.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 2561	 0.000469	 0.005225	 0.1126	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	451	 2562	 0.005588	 0.034701	 0.0643	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2572	 2563	 0.000862	 0.019598	 0.2726	 1559.0	 1559.0	 1559.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 2564	 0.000862	 0.019598	 0.2726	 1559.0	 1559.0	 1559.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2664	 2565	 0.004375	 0.026805	 0.0486	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1859	 2566	 0.000332	 0.004013	 0.0628	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 2567	 0.001393	 0.009294	 0.0177	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 2568	 0.001393	 0.009304	 0.0177	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 2569	 6.2e-05	 0.000855	 0.0231	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 2570	 0.001043	 0.011382	 0.3054	 1624.0	 1624.0	 1624.0	 0.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    150 -     4.98
% INFO    : NUC    7   -    10.26
% INFO    : SYNC   3   -    -0.02
% INFO    : COW    105 -    63.46
% INFO    : NG     334 -    21.32
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 100.986309157 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.418079099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7313941152 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1260352036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.3402867081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1571943469 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.418604552 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.635174959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4779287376 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.7589440477 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 40.8180522803 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.333846013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7794198515 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.295674152 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.867529487 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2537791706 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4450171708 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 34.9265411736 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.3402113383 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.9732588307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9402975978 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9068101674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.093263741 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.5438300692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2918735807 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.23569344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1671920079 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.772694335 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.990005687 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.341459804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5054218849 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.515642262 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.166394354 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.320443081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2430255087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2378824762 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1711718971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5163592346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0609912888 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3403247193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7693453703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.2072109338 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 117.478299395 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.6448238252 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.143840825 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0634877635 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1825360778 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.54888676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3993909048 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.4336714925 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.38082434 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.912049223 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0617683845 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3114595174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0296943872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.5130957032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5865347158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.894606589 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.367340401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.3202789178 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.140314142 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.799004515 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.753605054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9615438524 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.879703758 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 37.7151416047 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.4998756022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6506166183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5968016055 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9099768092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.4354235378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2507271382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.966272144 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0890515752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7053886354 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.8478941361 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2541055776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8512797441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1048545351 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4409056595 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8705030764 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.6158882408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1921089449 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.748848052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.935646995 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.3682751779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8124608623 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.57195777 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.160569046 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.716136987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.257073925 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.460880236 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 103.089036449 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4776939333 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.383190062 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8214092572 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.6953538097 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8886376192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6842113343 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.839319189 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.083295563 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.526673159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.8356427798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 63.4949093784 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.994003822 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.183185099 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.344594732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6914962667 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.7215031265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7889561852 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1816497302 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.443974703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2449393983 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.602295693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5891686913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1135172809 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0894353397 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 91.6271369468 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.180830473 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.9289888099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2845404818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0754377545 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.387833068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6287790775 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5019549193 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.5629008474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4840770089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9371623892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8896897817 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.7739021504 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.201864264 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.810518004 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 120.646300042 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 125.061063183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1520332988 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.556338945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2967924119 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.178986301 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1318363514 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.557784859 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 142.759395214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9018324764 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.48017588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.6199243511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8445864505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8162168042 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6024787486 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 97.5339315423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.4445233163 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.036512442 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.583074274 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.3839939302 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.780351564 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.111266867 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 42.8839401714 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 30.1224035881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7462529379 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7352436832 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.97149317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7592405084 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.031202396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5305244472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.562956204 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6634525956 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.5987297223 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7743559851 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.799318096 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9017148325 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1005561141 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.0412671657 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2747631861 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 63.9884072624 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.76881668364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3422470894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8578438443 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2491806803 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1438487282 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 127.920346734 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.840874737 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.032186112 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1875200306 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5849627133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9015071717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9756702194 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1953774066 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.180190566 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.670246338 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.018767605 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.665173328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1048263879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5440817388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6453137407 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.85036264 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7051325364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.4598837715 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.3833203446 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4003778069 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.728786897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6646134627 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2725633817 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4283532166 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8326937562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9472995942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8553819193 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.116259666 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3935963337 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 130.711785246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4577775676 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.741986614 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.223636363 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.631638797 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.473347928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0895494659 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.0943476137 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.9969214328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.98321522 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4497729868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5894805439 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.7151542334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3776224407 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8365831801 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9370306483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3440838994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7624478436 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.1614306245 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8910940296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9816340028 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 33.7646259343 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 41.8743209636 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 34.5633456084 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.3940932257 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 87.0800695379 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 87.6958889825 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.3501297745 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0369900743 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.019537491 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.882277158 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.329046312 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.098854477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9318938459 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5873040988 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.669796311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2537855909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.0994992294 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.296199131 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3314969543 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2217240273 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0736470666 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6528231771 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.410029342 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.289699482 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8838350867 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.203485404 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.895088809 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.843168978 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0711379456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8322381082 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.5370642571 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9155795179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7840712827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4215223718 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 29.7960492585 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7562804338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0027247375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5993029878 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.0711406679 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.981604313 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 93.3172502301 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.834976902 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.900838887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6255314002 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1224329113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7621621268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1763670458 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.223136998 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.528265867 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 96.8502275958 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.471149797 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8468169074 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.02824255 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9653889638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5717944601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2579184064 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.163821791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.0983028643 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.289678768 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.600588474 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.62403569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1036857995 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4358999836 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.1927860273 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.151307849 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.727008835 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 128.306953315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4252944452 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.728135974 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3777326372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9653980285 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.5276760965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3106626776 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.895354864 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.195197424 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7960117114 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4436372225 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0987224823 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.276695468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2685873361 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.807243375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6161217349 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.047430514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8608369854 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.308800251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3554031123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7889918619 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.802273345 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6294722478 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2960323403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7592905265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.711048593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3091319844 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7854346312 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.707953218 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.05707624 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.45227023 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6812044813 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.944612598 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4253713433 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 36.2436703863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.593906037 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7704279479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7424546942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.0562774318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6938261991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0812944288 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3835531396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8748059418 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.3347562232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.6908202225 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.400830503 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.367082677 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3191657776 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.989552368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7960313199 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.042034253 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8040284058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3015251097 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2604728657 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.848151877 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1517754027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7338472619 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.9290596012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2663772318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9080618026 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9164016499 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4437120751 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.8153817638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6196170727 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2541867524 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3073945378 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5652294007 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6783726311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9851101496 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6867166829 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4187641406 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9498244232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.153399867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.0185586496 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.841599894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0909960778 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.4504828591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5114830099 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0345460753 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2463706221 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.973063818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.701993661 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4301786752 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.395974311 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 93.0612611967 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.0504705424 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.6351017457 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2998268879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9001334793 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.94577011218 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9963605029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8399184583 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.038378902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.2902402259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8917098959 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.83732958 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0462279689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9168315389 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.539395572 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.55983576365 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7025134564 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.93885327901 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7845231348 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 28.6459540732 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 25.1333663952 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.666506184 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8804810533 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3622943231 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7364161886 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.186928244 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.153124872 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7031365507 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9907054489 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.49858455454 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8860501515 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2013607526 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4333569449 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.4951965642 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.72598580484 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1968454442 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6181174271 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0202516468 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.229809991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6488975234 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.709333183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8462874467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7310564088 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.938890029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7855779794 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4197840916 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4239831918 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.954434841 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1963155472 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.3606592284 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0643232766 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8432371287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.4215554689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1000854935 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.3658497041 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.7485669165 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2687098379 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9140063081 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.9124997096 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8331457516 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.473331484 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.740063207 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.42056168 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.580219979 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 94.2177323371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6982463463 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5616788999 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1586536095 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 121.432438892 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4925185349 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3497547969 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 133.672097503 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.94388207476 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.2410128993 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0836206337 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7766751491 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.851555925 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7878814415 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2196167725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0050527256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.85359935 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.5085351699 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.4030029923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0027720926 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.825417623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2834716678 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3642113451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2559710184 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 24.6531916975 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.099946216 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.170840442 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6106925379 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7950504667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2238779336 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8474878592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.0064937197 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.181683558 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3277203816 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.099600411 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.747873645 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9186545946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.321836194 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.604651301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8651727942 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2043855948 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.274765147 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.316420035 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.048378935 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3993423038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7037225032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4397758983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9694762392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.4979292848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2575067463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0428674344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2787831809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9510222712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9098858307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6423602064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2746244849 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.367023249 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6038047887 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.196648901 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.0619034029 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3728601922 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0216929344 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6553531005 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1695555745 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8732273743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.60856397 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.22859520315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4111588329 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6974219368 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.3417712778 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0983470336 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.3295851895 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4276294347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2033688199 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.988464838 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.288498217 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9061657155 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0762152211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1647360251 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 132.084426708 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 39.3506510036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0750348407 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.4964957301 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.969764617 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 31.794084671 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3100130069 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.270458886 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4407122035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0772548114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4085251414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5599495114 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2529345715 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1810676017 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6177836168 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2309903402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8245496576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2456950799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5322509199 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.8586242936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9746568455 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.066622251 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.403891008 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.477159648 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4188154725 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 93.7264797248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0504565056 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 30.3833219414 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.6145785089 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 27.9390664045 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 114.589971616 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1824045531 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 45.1112349531 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 24.9484273101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.679278115 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.7711697995 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3759403623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6555926797 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6361150812 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.98979010097 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.836241094 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3865527095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0745928589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8873594983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.6165801679 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5671063503 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4675362518 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9726602259 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 38.0668881678 0
% INFO    : Updated Generator Cost: PEL - 0.0 2.0 0.0 -> 0 101.409393484 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7193934641 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.776328779 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8639813748 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9701544334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.538051663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.2219555028 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 68.6364201342 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5457845541 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1828285948 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.412377246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1370105413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3285435981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5889467043 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1831988788 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0918301391 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3337605492 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.87274859199 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.9296284781 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6697214088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1667594189 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6071271092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2066819121 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9373071906 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7074687121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.0609235588 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0283744831 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 639-1 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-2 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2575-3 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 875-3 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-3 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 46-3 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1073-4 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-4 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1658-4 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1370-5 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1370-6 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 199-7 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 880-7 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1061-8 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-8 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-8 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1371-10 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 147-11 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 387-2571 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 437-2571 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-11 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 991-11 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1774-2571 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1817-11 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2092-2571 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2591-12 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 419-12 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-12 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1158-12 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 148-2572 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-12 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-2572 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 167-13 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-13 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 820-14 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 465-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 878-15 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2664-16 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 451-16 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 151-17 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 987-18 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-18 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-19 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-20 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-20 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 59-21 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1908-21 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 591-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 855-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-22 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 820-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1059-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1691-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1922-23 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-24 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-2573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1908-25 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1914-25 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 59-25 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1138-26 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1409-26 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2755-27 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-2574 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 249-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 296-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 776-29 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1274-30 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1906-31 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-32 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 648-32 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-32 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2050-32 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1907-33 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1370-34 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 242-35 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1507-35 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2117-35 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 800-36 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 712-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1655-37 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 564-38 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 637-39 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2032-39 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2585-40 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 593-40 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 788-40 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1291-40 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 235-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 248-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 285-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1933-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1935-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1770-42 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 183-43 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2006-43 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2036-43 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 265-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-44 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 389-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 408-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1955-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 389-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 408-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1954-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 408-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 380-47 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1699-47 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 380-47 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1610-48 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2120-48 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1585-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1972-49 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2121-2576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-2576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1971-2576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-50 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1256-50 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-50 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2895-50 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2895-50 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2621-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 434-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1497-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 450-52 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-2942 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-52 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2603-53 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-53 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1686-54 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1929-54 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1109-55 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1109-55 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 321-56 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 638-57 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-57 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 190-59 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 258-59 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 284-59 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 396-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2897-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 396-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2897-60 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 182-61 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1589-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1684-2577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-63 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 65-2577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 738-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 252-66 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1773-2578 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2145-66 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1894-67 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1894-2579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-69 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2090-69 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-69 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2095-70 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2096-70 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1761-71 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1911-71 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 74-2580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 74-72 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 377-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2653-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 423-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 483-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 791-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2792-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1631-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1855-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1886-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 377-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2792-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2926-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1853-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1640-75 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1909-76 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 124-77 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-77 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-78 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 125-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 210-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 354-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 125-79 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 310-80 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 667-80 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 903-81 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1701-81 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 524-82 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 568-82 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 159-83 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 406-83 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-84 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1000-84 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2103-84 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-85 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-85 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 159-86 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 643-86 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1918-86 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 205-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 205-87 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-88 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 680-2581 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1807-89 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 680-2581 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1428-2582 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1428-90 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 142-91 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 428-91 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1066-91 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1728-91 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 612-92 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-92 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1911-93 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-94 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-2583 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 922-95 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-96 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 643-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2101-97 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1305-98 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 449-99 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2808-2584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1701-100 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1872-101 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-101 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 524-2585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2687-102 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1027-102 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-2585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2009-102 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 625-102 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-102 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 734-103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1895-103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-103 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 272-2586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 485-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 522-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1286-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-2586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 714-105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 984-105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-106 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-2587 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 541-107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 647-107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1656-107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1808-107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1951-107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2140-107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1656-107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 503-108 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-108 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 111-109 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2976-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 581-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 904-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 400-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 581-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 904-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2654-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 401-110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-111 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-111 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1913-112 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1912-2588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 965-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 182-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 597-114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1914-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 812-116 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1915-117 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 79-118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2124-118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 79-118 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1806-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-119 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 255-120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-120 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 628-2589 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 628-121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 243-122 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1119-122 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 853-123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1966-123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1967-123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 853-123 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 313-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 861-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1155-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1706-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 861-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1155-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1155-125 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1546-126 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2868-126 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 729-127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 729-127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 862-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 639-128 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2597-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 194-129 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 696-2955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 962-2955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1080-2955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1530-130 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1997-2955 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1530-130 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 679-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1141-131 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1743-132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 519-133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-133 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 385-134 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 621-134 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 943-134 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1782-134 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1037-135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1916-136 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 702-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1685-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1974-137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 486-138 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2020-138 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2816-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1437-140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2897-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1805-140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1222-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1437-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1805-2590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2817-140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2815-140 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1491-141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 204-142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 643-143 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 882-144 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 900-144 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 901-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 801-147 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 324-149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2632-2592 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 711-150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2746-150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 814-150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-151 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 180-153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1145-153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1879-153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1924-153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2737-154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1459-154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 777-154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1603-154 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-155 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2678-156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 704-156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2854-156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 535-156 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2118-157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 655-158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 685-158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 871-158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 913-158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1456-158 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2066-159 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2656-160 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-161 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 201-162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1297-163 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 320-164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1019-164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-165 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2110-165 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1427-166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1938-166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1427-166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 635-166 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 397-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2669-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 554-168 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2029-168 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1474-169 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2108-169 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1921-170 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1923-171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1310-172 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 511-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 547-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1797-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2064-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 188-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1797-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2596-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 837-174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1012-174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 837-2998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-2998 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 189-174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1295-175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2960-175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1576-177 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1326-178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1746-179 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1746-179 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-181 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 370-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2682-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 806-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 813-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1169-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 597-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2745-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2744-182 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 807-183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-184 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1899-185 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 217-186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 218-2595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 218-187 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 218-2594 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 218-2593 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2072-191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2073-191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2794-193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2807-193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1195-193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1098-193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1168-193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1196-193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 536-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1063-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1081-2597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1349-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1411-2597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1588-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2084-2597 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1081-194 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 512-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 537-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1058-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1064-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1663-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2017-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 512-195 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 364-196 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-196 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 427-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 723-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1093-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1122-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1221-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2874-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1752-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1783-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2049-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2106-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2900-197 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 486-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 553-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1721-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1758-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 486-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1290-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1758-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1202-199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1786-199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 512-200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 512-2598 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1066-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2095-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-2599 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 677-203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1436-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 974-205 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1795-205 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 553-206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1143-206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1690-207 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 861-208 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 712-209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1825-209 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 243-211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 656-2600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1200-2600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1339-2600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-2600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 213-212 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1287-214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1124-215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2681-216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 812-216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 583-216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 812-216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1120-218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2826-218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 506-218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1283-218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 506-218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 506-218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1284-219 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 697-220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2119-220 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 773-221 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1237-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 224-223 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 224-2601 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 224-2602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1022-224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1316-224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1957-224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2036-226 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 754-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1315-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1984-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2134-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2648-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-230 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-230 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 991-231 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1929-233 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1928-234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-2604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1573-235 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 940-236 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2062-236 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1025-237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1705-237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2109-237 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1891-238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-2607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-2608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-239 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-2605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-2606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-240 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 380-241 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 658-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1660-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 658-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-243 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 458-244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1425-244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 458-244 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1005-245 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1404-245 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-2611 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1664-2610 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-2609 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1664-246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 529-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1842-248 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 666-249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 638-250 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 998-250 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-251 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 749-252 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2008-252 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-253 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-254 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2031-255 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1715-256 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 874-257 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 874-2612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-260 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-261 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1493-262 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2008-262 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2158-262 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1816-262 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 654-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 770-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1947-265 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-266 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 365-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1598-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1768-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 529-268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 712-268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-268 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1048-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1596-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2876-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-269 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 322-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 909-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1531-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2771-270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1932-271 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 595-272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2865-272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 638-273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 998-273 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 275-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1887-274 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1346-275 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 753-276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 764-276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1889-276 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-277 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 944-279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1772-279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 944-279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 179-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 179-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1093-281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1632-281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2106-281 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1333-282 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-282 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 284-283 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1551-284 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1933-2618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 586-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1374-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2844-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1394-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2078-288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2080-288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1934-289 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 644-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 425-292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-2623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1270-292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1615-2623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1692-292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1788-2623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2144-292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2157-292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 509-292 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1692-2623 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2615-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2626-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 350-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 746-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1789-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1948-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1959-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 713-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-293 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 364-294 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 464-294 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 182-295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 351-295 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 465-296 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 359-297 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-297 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1936-299 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2982-300 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 565-2627 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 565-301 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 619-302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1848-302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-303 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1847-304 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1972-2628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1971-305 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 596-306 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1373-306 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 644-2629 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-307 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 798-308 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2874-309 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 753-310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-311 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 454-312 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1023-312 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1144-314 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-314 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1747-315 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1941-316 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1092-317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-317 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-318 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1107-2631 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1107-319 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1107-2630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1019-320 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1109-320 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1172-320 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1172-320 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1492-321 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1492-321 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-322 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 957-323 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-323 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1190-2632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1228-2632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-325 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-2633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-326 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1942-2634 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 438-327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 619-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 840-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1670-328 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-329 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-2635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1720-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1953-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2994-330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 840-2636 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 840-331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1945-332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-2637 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 765-2638 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1101-333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-2638 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1722-2638 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2156-333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1722-333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 818-2639 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1111-334 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1534-334 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 497-336 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 762-337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-337 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-338 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-339 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-340 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-341 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1304-342 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-342 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2140-343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1338-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2141-344 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 920-345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-345 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 664-346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 864-2641 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 901-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 901-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 901-2641 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1020-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1020-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-349 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2053-351 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1168-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-352 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2151-354 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1274-356 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1298-356 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-2643 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2027-356 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2028-356 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-2643 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1992-2642 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1993-2642 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-2645 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2897-2645 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1832-358 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1832-358 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2035-360 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 395-361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 977-362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1948-362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 858-363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 865-363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1075-363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1640-363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1731-363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1826-363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1640-363 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 464-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 471-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1664-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 471-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1664-364 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-2646 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-366 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 661-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 474-369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 785-369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 785-369 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1949-371 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 581-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 904-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2928-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 904-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1401-373 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1412-374 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1411-375 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1645-376 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 423-2647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2663-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2925-2647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1855-2647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 515-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 776-378 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 393-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 412-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2668-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-380 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1779-381 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2737-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1664-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 606-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 777-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1731-383 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-384 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1448-385 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1657-385 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2099-2649 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2098-386 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-387 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 516-2650 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 516-388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-389 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 527-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1175-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1233-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1443-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2936-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1884-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 527-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1390-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1128-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2798-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 394-392 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 409-392 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1391-2652 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-2651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1860-2652 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1950-2651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 394-2651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 409-392 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2794-2652 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1168-2652 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-2652 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-2652 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2946-395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1055-395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1382-395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1831-395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2018-395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 734-396 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-396 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-396 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 734-396 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-396 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-396 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 449-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2669-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1886-2653 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 483-2653 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2860-2653 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2038-397 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-398 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 890-399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1647-399 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-402 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-402 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1382-402 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1890-402 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-402 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 957-403 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 957-404 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1043-405 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1043-405 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2114-406 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 951-408 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 990-408 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 951-408 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 726-409 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-409 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 726-409 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-409 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-409 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-410 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-411 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-2655 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 736-2656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2755-2656 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 676-413 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-413 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2715-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2097-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2716-414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 803-415 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1002-415 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 803-415 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 568-416 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 568-2657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1584-417 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2829-419 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 588-421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 796-421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1296-422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1951-422 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1952-424 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 496-425 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 868-426 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 467-428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1904-428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 909-430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1101-430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1879-431 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1953-432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1556-433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-434 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2667-436 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1086-436 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1227-436 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 801-437 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 991-437 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1235-438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2130-438 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 902-439 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1111-439 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1955-2660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1954-440 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 596-441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1436-441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1739-441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1436-441 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1909-442 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 568-443 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 733-443 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1571-444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 580-444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1236-447 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1319-448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1505-448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1292-448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 649-2663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1171-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1171-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1171-2990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1992-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1993-2990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1285-451 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1965-2664 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-451 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-452 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1158-452 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 790-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1295-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2960-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1619-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2076-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2661-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1295-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2018-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 445-2946 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2662-453 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 581-454 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2776-454 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 581-454 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 961-454 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-454 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 446-454 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 456-455 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2792-455 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1087-456 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 474-457 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1838-457 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 840-458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1425-458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1540-458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 840-458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2116-458 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 629-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 720-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1178-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 720-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1178-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1958-460 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1123-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1659-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1624-462 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1062-463 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2674-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2673-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 493-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2672-464 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 515-465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-465 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1959-466 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 526-468 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1317-2665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1597-2665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1949-469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2125-469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2081-469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1317-2665 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 640-2667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 783-470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1086-2667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1227-2666 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1465-470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1541-2667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1687-2667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2105-2667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 640-470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1292-470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-2666 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1803-471 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1803-471 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 688-472 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2717-472 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1219-472 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 622-473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2706-473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2686-473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 698-473 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1303-474 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1708-474 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2034-474 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 844-475 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 788-477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 931-477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1894-477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1894-477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 695-480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1433-480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1916-480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2037-480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-480 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2807-481 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1402-481 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-481 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 577-482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-482 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2728-2669 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2861-2669 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1734-483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-2670 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-2670 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-2670 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-484 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 808-484 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1664-484 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 673-2671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1715-485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 848-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1336-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1830-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1894-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 848-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1336-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2858-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 693-488 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2147-489 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 753-490 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 754-491 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 977-492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 849-494 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1965-495 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 793-496 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 514-497 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 621-497 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1439-497 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1231-498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1810-498 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1082-499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1453-499 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 800-500 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 800-2675 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1266-501 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 526-502 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1639-502 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2060-502 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2016-503 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-504 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 778-505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1119-505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1131-505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1762-505 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 589-506 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-506 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1492-506 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 589-506 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1120-506 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1492-506 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1832-507 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 783-508 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-508 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 785-510 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1559-512 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-516 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1986-516 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1383-517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1401-517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-518 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-2676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2130-519 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 681-520 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1201-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1970-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1972-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1971-521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 938-523 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-524 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1656-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-526 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1268-2677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-2677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1008-528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1127-530 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 806-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1424-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1920-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-531 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2929-532 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1974-533 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2755-534 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 736-536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1360-536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1423-536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1423-536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1904-539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2090-539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2056-540 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2141-541 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1975-542 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 685-543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 685-543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2728-544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 547-545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 944-546 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-546 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 896-547 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1876-547 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 353-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 473-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 622-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 672-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 937-548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1976-549 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 641-550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1838-551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2034-551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2923-551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 482-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 501-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1127-2679 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1133-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1714-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1783-2679 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2093-552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-2679 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 977-553 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1758-553 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 977-553 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-554 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 381-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1779-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1977-556 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 804-558 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2743-558 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1986-558 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 726-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1901-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 726-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1186-560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1832-560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1762-561 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1824-561 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 803-562 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1962-563 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 706-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 751-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 989-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1088-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2789-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2044-564 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 665-565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 767-565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1376-565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 665-565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1769-566 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1769-566 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 798-567 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1027-568 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1813-569 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-574 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2751-575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1753-575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2907-575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1136-576 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2148-579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1202-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 881-581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1259-581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2756-581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1374-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1748-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2018-586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 912-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2776-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 912-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 961-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1824-588 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2729-589 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 929-589 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 756-589 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-589 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 657-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1979-590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-592 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2773-593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 930-593 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1744-594 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 675-596 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1739-596 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1739-596 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1981-598 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1650-599 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-599 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1428-600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-2683 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-2684 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-602 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 944-603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 944-603 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1226-604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1982-604 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1419-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1318-606 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1573-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1878-607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1000-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1551-608 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2841-609 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2911-609 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2901-609 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 618-610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-610 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1014-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1034-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1115-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1134-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1202-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1608-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1768-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-613 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-613 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-613 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-613 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-613 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-613 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1066-614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1496-614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1563-2685 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1823-2685 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1900-614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1496-614 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1983-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1685-616 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1984-617 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-618 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1744-619 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 795-620 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-2686 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1486-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2055-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2131-622 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 856-623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1879-623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1907-624 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2122-624 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1985-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 752-627 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 934-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1117-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1307-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 934-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-628 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1178-629 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1540-630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1626-630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1986-631 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 655-632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1255-632 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1987-633 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 652-634 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1031-634 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1790-634 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1988-635 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 733-636 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2128-637 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2013-638 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1457-639 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2045-639 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-639 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2023-640 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-641 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1684-642 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2066-643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2065-643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 629-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 656-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1038-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1568-645 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1568-2688 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-646 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-2689 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-2692 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-650 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-2690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-2691 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1190-651 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1733-651 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1190-651 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-651 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1990-651 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1989-651 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 799-652 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1990-653 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1989-2693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 770-654 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1693-657 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 661-659 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 661-2694 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1147-2695 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1147-660 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2699-661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1209-661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2935-661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2698-661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 663-661 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 872-2700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1054-2700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2154-664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2753-664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2949-664 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2044-2700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 922-665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1422-665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1581-665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-665 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2058-666 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 753-667 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 863-668 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2754-669 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-2701 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-670 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-2703 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-2702 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1894-671 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2779-672 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 985-673 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-673 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1131-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1185-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1483-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 911-675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1728-675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-675 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1882-676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2797-677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1119-677 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1255-678 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1661-679 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-2704 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-681 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 682-1764 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1413-683 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1924-683 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1208-684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 918-685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 948-685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1697-686 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1697-686 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 812-687 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 812-687 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-689 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 999-689 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1140-690 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1297-691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1641-691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2129-691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1297-691 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1745-692 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1745-692 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2023-693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2042-693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1992-2705 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1993-694 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1985-695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1594-697 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-699 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1133-700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1136-700 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1226-701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1490-701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1600-701 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1961-703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2060-703 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1347-704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1418-704 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-705 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1994-707 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1995-2707 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 987-708 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 711-2713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 711-710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 711-2711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 711-2712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-711 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1467-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1566-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1584-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1825-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1960-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2029-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-712 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2785-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1468-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1959-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1659-715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1851-715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 782-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2082-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 782-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1602-717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1999-717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1975-2714 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1976-718 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2116-719 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 841-720 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1975-721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-721 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1997-722 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1915-723 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-724 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1984-725 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-726 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-726 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-726 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-726 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 947-728 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1099-728 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1661-728 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1099-728 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-729 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1698-729 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-729 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-729 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1698-729 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1603-730 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 975-731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1521-732 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1249-733 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-733 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-733 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1063-735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1075-735 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1527-2717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1882-738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1965-2717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1114-740 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-742 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-2723 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-2724 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-2725 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-2726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-2722 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1404-743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-743 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1215-2727 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1528-745 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1999-747 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2000-747 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 928-748 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 928-748 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 982-750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1213-750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2786-750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1734-752 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1035-753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1889-753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1941-753 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1659-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1824-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2002-755 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2024-757 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1323-758 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1604-759 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 942-760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2083-761 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 773-762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1037-762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1378-762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1946-762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1942-762 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1659-763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-765 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 900-766 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 979-766 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 830-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1005-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1511-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1555-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2022-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2810-770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1611-770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2005-770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2878-770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 881-771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2826-771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2756-771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1283-771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-771 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-2730 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-2731 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-2733 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-774 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-2732 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-2736 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-2735 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-2734 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2786-775 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1412-776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2058-776 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 796-778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1955-779 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1954-2738 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1321-782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1504-782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1685-782 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1687-783 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 792-785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 981-785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1969-785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2886-786 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-786 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-787 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 851-788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2161-2739 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2739-571 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 949-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1875-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1635-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2076-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 964-792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1114-793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-794 connects the same voltage levels (20.0, 20.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-797 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-2740 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-2741 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1027-799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1790-799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 834-799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1027-799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1027-799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 924-800 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1192-800 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1891-802 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-2742 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1645-803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1804-803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1645-803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1804-803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2981-803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1184-805 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1294-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2881-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2053-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1621-806 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2042-807 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-809 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1804-810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 790-811 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 833-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1364-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1446-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1891-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1896-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1981-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2941-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2938-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 985-815 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2752-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1051-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1111-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1464-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 869-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2862-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2008-819 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2782-821 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 824-822 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-2964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-2964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2748-2964 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 825-823 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1437-823 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1437-823 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1102-826 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1159-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2009-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2806-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2012-2749 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2011-828 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-829 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-831 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-831 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2013-832 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 956-833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1460-833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1891-833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2161-833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 956-833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2103-833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1790-834 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2043-836 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 950-837 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2807-837 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1193-837 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1846-837 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1168-837 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1019-839 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1071-839 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 920-840 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2830-842 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2028-842 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2981-2750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1804-843 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2079-844 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 964-845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1969-845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2014-846 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-847 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 816-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2940-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2747-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1893-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2015-849 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1197-850 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2905-850 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2904-2751 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1792-853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1398-853 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-854 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1039-855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1257-855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1705-855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2071-855 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 939-856 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1040-856 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-856 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1935-858 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 966-859 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1209-859 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 852-860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1781-860 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2045-862 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1419-863 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-863 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 928-864 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1826-865 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-866 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1338-867 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1236-868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1378-868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2002-870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1139-871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1184-873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1198-873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1725-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1755-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2056-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-2754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1725-873 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1579-874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2016-874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1579-874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-875 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1061-876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1061-876 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2152-877 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1234-2755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1562-2755 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1613-878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1905-878 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1058-879 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2017-879 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1070-882 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-2764 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-884 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-2762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-2763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-2766 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-2765 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1209-885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1037-886 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2015-887 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2020-888 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1758-889 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1758-2767 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2144-890 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-891 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1171-2768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1171-892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2022-893 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 959-894 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1022-894 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1022-2769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1112-895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1138-895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1665-895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2014-895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1669-896 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2033-896 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-896 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1097-897 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2021-2770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1220-898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2057-898 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1280-899 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2109-899 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-900 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1279-901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1941-905 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2024-906 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1249-2771 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1445-2771 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-910 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2836-911 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-912 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-912 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1073-913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2884-913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1737-913 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1334-914 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-915 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-2772 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1704-916 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1375-917 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1931-919 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1956-919 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1121-921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-921 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1313-922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1389-922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2840-922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2839-922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1749-923 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2025-925 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 928-926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1019-927 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1824-928 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1824-928 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-929 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-2774 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-932 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1247-2775 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1453-933 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 951-935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1862-935 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2027-936 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 992-937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1068-938 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-938 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-938 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-939 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-940 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2029-941 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1766-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1809-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1766-942 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2102-943 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1440-944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1767-944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1772-944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1181-945 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1414-946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1661-947 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1456-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-948 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2032-949 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1147-950 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2030-951 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1051-952 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1617-953 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2001-953 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2126-953 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1952-954 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1888-955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2092-955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1113-957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2115-957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1113-957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-957 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1998-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2074-958 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1022-959 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2031-960 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1255-962 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-963 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1043-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2787-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1665-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1043-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1083-965 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1730-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 968-967 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1944-967 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1942-968 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1554-970 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-970 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2059-970 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2134-971 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1682-972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1836-972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1291-973 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1474-974 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-975 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 958-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1288-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1495-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2015-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 958-976 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1789-977 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1276-979 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1582-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1834-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1582-980 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2017-981 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1624-984 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2034-986 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2808-987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1431-987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1843-987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-2778 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-988 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-989 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1268-990 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1230-991 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1068-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1726-992 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-993 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-993 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2035-994 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-995 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-996 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1219-998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1293-998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1219-998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1539-999 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2912-1000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2913-1000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1763-1000 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1892-1001 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1572-1002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-1003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2081-1004 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1152-1005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1511-1005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1875-1005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2804-1005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1875-1005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2805-1005 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-1006 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-1007 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1047-1008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1561-1008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1648-1008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1906-1008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2120-1008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2871-1008 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-1009 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-1009 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-1010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1798-1010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2790-1011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-1011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1091-1011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-1011 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1512-1012 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-1012 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1115-1014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1799-1014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-1015 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1689-1015 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1435-1016 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2036-1017 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2037-1018 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1279-1019 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1556-1022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2148-1022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-1024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1917-1024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1509-1025 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1862-1026 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2038-2781 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1244-1027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-1027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-1029 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-1031 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1831-1032 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1582-1033 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1315-1034 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1620-1036 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1620-2783 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2019-1037 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1923-1041 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2846-1044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2848-1044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1400-1044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2847-1044 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2040-1046 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1092-1047 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1703-1047 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2119-1048 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-1049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1735-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1735-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1707-1050 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1146-2784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-2784 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2042-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2043-1053 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-1055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1553-1055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1105-1056 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2044-1057 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1135-1059 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1978-1060 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2045-1060 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1604-1061 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1714-1062 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-1064 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1274-1066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1823-1066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2054-1066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1189-1066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1274-1066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2096-1066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1274-1066 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2822-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1732-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1901-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1273-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2898-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2823-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2824-1067 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1486-1068 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1314-1070 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1761-1072 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1818-1075 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1086-2786 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2796-2786 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-2786 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1663-2785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1813-1076 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2006-2785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1106-2785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1813-2785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1079-1078 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-1079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1580-1079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2132-1079 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1140-1080 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1629-1081 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1101-1084 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2831-1084 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-2788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1878-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2068-2788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2069-1085 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-1089 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1608-1089 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1638-1089 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-1089 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-1090 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1648-1092 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2047-1094 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1097-2791 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2792-1095 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-2792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-2792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1886-2793 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2061-1097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-2793 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-2792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2021-2792 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-2794 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1950-1098 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-1098 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1124-1100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1933-1100 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1506-1102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1550-1102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1951-1102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2121-1102 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1438-1103 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1212-1105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-2795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1612-2795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2046-2795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2078-2795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2080-1105 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1213-2796 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-2796 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1784-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2072-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1784-1107 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1326-1108 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1702-1109 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1339-1110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1721-1110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-1111 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-1111 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-1113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-1113 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1788-1114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1788-1114 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-1116 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1492-1120 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1312-1121 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1661-1123 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1662-1124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1680-1124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1731-1124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1812-1125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1914-1125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1800-1126 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1714-1127 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1130-1129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-1129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2799-1129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2051-2800 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2052-1132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1145-1134 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2084-1135 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1783-1136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2155-1136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2916-1136 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2053-1137 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1737-1139 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1991-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1997-1140 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1253-1141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1697-1141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2085-1141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1697-1141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1220-1142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-1142 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-1143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1512-1147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2867-1147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1846-1147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1539-1147 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-1148 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-2801 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2054-1149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1845-1150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1985-1150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1280-1153 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2055-1154 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2070-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2151-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2067-1155 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1176-1156 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1589-1157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1910-1157 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1112-1160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2056-1161 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1163-1162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2865-1163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2929-1163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1473-2982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2159-2982 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2132-1165 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-1166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1272-1167 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1833-1168 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-1168 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1950-2807 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-2807 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-1171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1451-1171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-1171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2859-1171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2057-1174 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1865-1175 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1204-1176 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1827-1178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1849-1178 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1380-1179 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1380-1179 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1746-1179 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2058-1180 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2071-1181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2135-1181 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-2809 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-1182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1579-1183 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1578-1184 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1890-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1711-2810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-1186 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-1187 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1431-2811 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2059-1188 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2054-1189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1780-1191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2155-1191 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-1194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-2813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-2812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2903-1197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2908-1197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2060-1198 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1726-1199 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1544-1200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-1200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2040-1200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1305-1203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1700-1204 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-1205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1574-1206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1832-1206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1836-1206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2873-1206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1832-1206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-1207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1870-1208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2061-1208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1870-1208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1211-1209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2814-1209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1616-1214 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1825-1215 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-1216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2133-1216 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1594-1217 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-1219 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1976-1223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2101-1223 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1442-2818 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-1224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-1224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-1224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2827-1224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1289-1224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-1225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-2819 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1600-1226 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1887-1226 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1982-1226 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-1229 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1285-1230 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1722-1232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1659-1237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1620-1238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1620-1238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2821-1240 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1241-1240 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2066-1242 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2068-1243 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1531-1244 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1902-1245 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1718-1247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1445-1249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1604-1250 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1491-1251 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1491-1251 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-1252 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1498-1253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2071-1254 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1441-1258 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1867-1259 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2072-1260 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2884-1261 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1963-1262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2049-1262 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1615-1263 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1431-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1913-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1912-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1994-1264 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1915-1266 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1844-1269 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1788-1270 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-1271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-1271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1298-1274 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1572-1274 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2048-1275 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1659-1277 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2074-1278 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-573 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1484-1280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1704-1280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1906-1280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2075-1280 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-1281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1486-1282 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-1284 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-1284 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1502-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2113-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2153-1287 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1647-1288 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1523-1291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1830-1291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2866-1291 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1586-1292 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1625-1297 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1429-1299 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-2828 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-1300 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1484-1302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1704-1302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1484-1302 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1882-1303 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1500-1305 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1677-2829 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2077-1306 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1306-572 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1683-1307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2114-1307 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2079-1308 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2030-1309 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-1310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1474-1310 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-1311 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2020-1311 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1375-1312 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1558-1318 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2869-1318 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1614-1319 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2082-1321 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1248-1323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1502-1323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1733-2831 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1885-2831 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2003-1323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2027-2830 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2937-2830 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1928-1323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1990-2831 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-1323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1989-2831 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-1324 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1503-2832 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-2832 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2897-2832 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-1324 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2897-1324 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-1324 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-1325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-1325 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1236-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2142-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1236-1327 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1434-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1748-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1957-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1748-1328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2083-1330 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-2833 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1771-1331 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2857-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1481-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1804-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1987-1334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1521-1334 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2146-1335 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1937-1338 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-1339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1709-1339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1555-1340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-1340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1343-1342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-1342 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-1343 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1487-1344 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-1344 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1556-1345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1724-2960 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1646-1346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1932-1346 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-1347 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-1350 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1471-1350 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1481-1350 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1218-1351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1417-1351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1636-1351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1701-1351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-1351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-1351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2085-1353 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-1355 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-1356 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2010-1357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2088-1357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2097-1357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1857-1357 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2089-1358 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2091-1361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1575-1362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1904-1362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2090-1362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1697-1366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2893-1367 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1672-1367 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1939-1368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1902-1370 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1907-1370 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2092-1372 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1983-1373 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2835-1374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1369-1374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1712-2836 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2834-1374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-1376 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1426-1377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-1379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-1379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1380 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2093-1381 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1968-1383 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1797-1386 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2897-1387 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1723-1387 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1775-1392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2909-2841 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2910-1392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1652-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2062-1395 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1658-1396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2147-1396 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2094-1397 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-2845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1399 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1765-1401 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2037-1401 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-1402 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1875-1403 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2852-1404 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1406-1404 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2851-1404 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2096-1407 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-1408 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-2853 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1616-1409 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1964-1411 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2026-1412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2039-1412 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1919-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2097-1414 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1772-1415 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1772-1415 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1701-1417 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1751-1419 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1868-1420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2039-1420 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2099-2855 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2098-1421 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2100-1423 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1678-1427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1852-1427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1988-1427 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-1428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1581-1428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2086-1429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2929-2856 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1870-1431 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1995-2856 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1580-1432 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1977-1433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1957-1434 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1717-1435 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1898-2857 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1732-1437 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-1437 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2898-1437 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-1437 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1653-1439 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2123-1440 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-1443 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2102-1448 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1678-1449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1910-1449 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1479-1450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1605-1450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2016-1450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1510-1454 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1958-1454 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2022-1454 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-1454 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-1462 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-1464 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2927-2862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2106-1469 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-1470 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1898-1471 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1848-1475 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1899-1476 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2107-1477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-1478 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2108-2864 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2109-1480 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1762-1483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2031-1484 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1751-1485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2110-1487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-1488 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2111-1488 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-1489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1838-1489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1917-1491 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-1494 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1828-1496 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-1497 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1697-1498 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1628-1499 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2138-1499 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2139-1499 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2160-1500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2929-2865 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2003-1502 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2113-1502 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-1503 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2113-1508 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1609-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1694-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2135-1509 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-1514 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1637-1514 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1928-1514 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1930-1514 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1852-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1987-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2035-1521 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2899-1525 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1525 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-1526 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1860-1526 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1655-1528 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1530-1529 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2115-1532 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1576-1536 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2013-1538 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1564-1543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1814-1543 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1925-1544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2107-1544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1880-1545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2116-1547 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1582-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2117-1548 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2882-1549 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2118-1550 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2119-1552 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2148-1556 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1973-1557 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1779-2870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1560-2871 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1828-1563 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1866-2872 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2052-2872 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2040-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2107-1565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1669-1567 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-1567 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2110-1567 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2112-1567 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-1568 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2001-1569 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2122-1569 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1747-2874 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1940-1577 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1577-1591 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1806-1578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1834-1578 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1583-1579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2922-1582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2007-1582 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2085-1583 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1801-1584 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1949-1587 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1949-2875 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2123-1590 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2114-1592 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2102-1595 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-1599 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1822-2877 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1881-1600 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1872-1602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1654-1605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1600-1606 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1706-1607 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1610-1609 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1646-1615 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1934-1616 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2014-2952 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1996-2952 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1980-1619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-1620 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-1620 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-1620 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2127-1623 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1651-1625 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1796-1626 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1842-1627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1932-1627 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-1630 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2128-1633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1820-1636 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1764-1637 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1826-1640 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2131-1643 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1830-2883 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1830-1644 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1883-1647 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1877-1649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2131-1649 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-1650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1829-1650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1750-1650 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1744-1651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1744-1651 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1776-1652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1847-1652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2914-1652 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2091-1654 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1960-1655 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1903-1658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2152-1658 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2133-1659 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-1660 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1691-1662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1731-2885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1921-1662 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1922-2885 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-1664 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-2892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-2891 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-2890 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1668-1667 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2132-1671 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1929-1674 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1952-1674 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2055-1676 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2133-1681 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2104-1682 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-1685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1814-1685 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1544-1687 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1999-1688 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2000-1688 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1806-1690 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1834-1690 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2134-1693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-1695 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1698 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1710-1698 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2043-1701 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2896-1707 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1719-1707 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1851-2895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1851-2895 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-1710 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2153-1710 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-1710 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-1710 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-1710 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1759-1710 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1713-1714 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1795-1714 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2137-1714 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2139-1716 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1921-1717 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-2896 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-1719 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2076-1724 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2025-1725 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1790-1727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2089-1727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2140-1729 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2143-1736 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1983-1739 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1773-1741 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2144-1742 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1837-1744 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1849-1745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1953-1747 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1814-1749 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2146-1750 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1775-2902 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-1754 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-1756 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2150-1757 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1775-2906 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2152-1760 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1797-1765 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-1772 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1850-1777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2025-1777 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1870-1778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2929-2915 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1940-1780 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2048-1788 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2089-1790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2156-1791 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1926-1792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1927-1792 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2154-1793 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2155-1794 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2087-1795 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1848-1796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1848-1796 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2157-1798 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1974-1800 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1898-2981 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2118-1808 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2146-1811 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1923-1812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1835-1814 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1815-1816 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2145-1816 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2158-1816 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2928-1822 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1867-1822 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1899-1829 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1894-1830 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1968-1832 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2115-1833 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1977-2923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1934-1840 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2064-1840 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1996-1840 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1854-1845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2002-1845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2033-1845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2128-1845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2108-1850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2117-1850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2136-1850 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2093-1856 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2158-1858 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2077-1859 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1866-1862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1945-2927 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2030-1862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2051-1862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2052-1862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2099-1862 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1943-2927 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2098-2927 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2038-2927 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2000-1865 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2026-1868 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1913-1870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2061-1870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1912-1870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1994-1870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1995-2929 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2935-1874 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2935-2933 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1875-2934 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2068-1881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2083-1881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2004-1881 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2074-1883 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1895-1892 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2161-1897 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2126-1909 connects the same voltage levels (45.0, 45.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2059-1911 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2065-1918 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1967-1927 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1947-1937 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2019-1946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2024-1958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1970-1963 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2063-1991 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2069-2004 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2125-2010 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2057-2075 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2129-2073 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2149-2082 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2123-2091 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1594-2249 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 12-2191 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 12-2215 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 60-2163 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 60-2216 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 74-2192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 74-2217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 154-2218 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 179-2164 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 179-2193 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 230-2194 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 280-2165 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 280-2195 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 349-2166 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 349-2196 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2645-2167 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 357-2219 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2645-2233 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 357-2243 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 382-2168 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 382-2197 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2651-2220 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 409-2221 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 481-2244 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-2169 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 587-2234 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 587-2245 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 613-2170 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 613-2198 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 729-2199 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 786-2171 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 818-2222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 818-2235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 839-2172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-2200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-2223 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 979-2224 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 999-2225 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-2173 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2780-2174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1023-2201 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-2175 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-2202 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-2176 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-2203 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-2226 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-2236 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1071-2177 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-2178 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-2204 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2794-2205 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1098-2227 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1098-2237 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1120-2179 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1120-2206 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-2180 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-2207 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1711-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 573-1279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-2181 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2832-2208 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1324-2228 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1324-2238 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-2182 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2856-2229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-2183 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-2209 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1503-2184 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-2185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-2210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1526-2186 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2867-2230 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1539-2239 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1595-2187 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1603-2246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1698-2188 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1698-2211 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-2231 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1740-2240 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1787-2189 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1821-2212 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-2190 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-2213 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-2232 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-2241 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1863-2247 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-2214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-2242 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1871-2248 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-2539 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1001-2540 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1285-2541 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 957-2542 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 55-2543 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2867-2544 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1112-2545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1160-2546 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1028-2547 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 103-2548 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 999-2549 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2867-2550 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2825-2551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2041-2552 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 297-2553 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2935-2554 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1147-2555 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1567-2556 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1841-2557 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2924-2558 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 405-2559 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 56-2560 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1539-2561 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 451-2562 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2572-2563 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 12-2564 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2664-2565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1859-2566 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 738-2567 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 738-2568 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 297-2569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 127-2570 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 639-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2441
% INFO    : Updated Thermal Rating: on line 1073-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1533-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 1658-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 1370-5 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 1370-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5369
% INFO    : Updated Thermal Rating: on line 1061-8 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 1223-8 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 1223-8 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 1371-10 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 1774-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3441
% INFO    : Updated Thermal Rating: on line 1817-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9629
% INFO    : Updated Thermal Rating: on line 820-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 465-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 878-15 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 151-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53862
% INFO    : Updated Thermal Rating: on line 1903-19 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11716
% INFO    : Updated Thermal Rating: on line 591-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 855-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 1199-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 820-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 1059-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 1691-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 1922-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 2755-27 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 249-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 296-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 776-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 1906-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 2686-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 648-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 1337-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 2050-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1907-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21404
% INFO    : Updated Thermal Rating: on line 1370-34 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 242-35 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 1507-35 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 2117-35 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 800-36 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 712-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 1655-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 564-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5495
% INFO    : Updated Thermal Rating: on line 235-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 248-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 285-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 1933-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 1935-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 1770-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 183-43 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 265-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 1652-44 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 380-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 1699-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 380-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 1610-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 2120-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 1006-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 1585-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 1972-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on line 2121-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 901
% INFO    : Updated Thermal Rating: on line 1006-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 1971-2576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 2621-51 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29203
% INFO    : Updated Thermal Rating: on line 2603-53 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 1126-53 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 1686-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 1929-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 1001-60 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 1240-60 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2229
% INFO    : Updated Thermal Rating: on line 2897-60 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2077
% INFO    : Updated Thermal Rating: on line 1001-60 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 1240-60 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2231
% INFO    : Updated Thermal Rating: on line 1723-60 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2074
% INFO    : Updated Thermal Rating: on line 182-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 1589-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 1684-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 1755-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 65-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 252-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 1773-2578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7261
% INFO    : Updated Thermal Rating: on line 2145-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 2096-70 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2348
% INFO    : Updated Thermal Rating: on line 1761-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3007
% INFO    : Updated Thermal Rating: on line 1911-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4006
% INFO    : Updated Thermal Rating: on line 377-74 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 791-74 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169660
% INFO    : Updated Thermal Rating: on line 377-74 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31961
% INFO    : Updated Thermal Rating: on line 1640-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16578
% INFO    : Updated Thermal Rating: on line 1909-76 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23633
% INFO    : Updated Thermal Rating: on line 124-77 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 1903-77 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 125-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 210-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 354-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 125-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 310-80 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 667-80 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 159-83 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 406-83 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 159-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 643-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 1918-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 205-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 205-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 1449-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 680-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 1807-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 680-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 1911-93 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24845
% INFO    : Updated Thermal Rating: on line 1410-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 1410-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 922-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48541
% INFO    : Updated Thermal Rating: on line 643-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2101-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 449-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46138
% INFO    : Updated Thermal Rating: on line 1892-103 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 1648
% INFO    : Updated Thermal Rating: on line 714-105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 984-105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 541-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 647-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 1656-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2987
% INFO    : Updated Thermal Rating: on line 1808-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 1951-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 2140-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 1656-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3057
% INFO    : Updated Thermal Rating: on line 1912-2588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307279
% INFO    : Updated Thermal Rating: on line 182-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 597-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 1915-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 79-118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 2124-118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 79-118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 1806-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 2007-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 255-120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 1750-120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 628-2589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 628-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 853-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 1966-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1967-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 853-123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 313-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 861-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 1155-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 1164-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 1706-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 861-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 1155-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 2982-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 1155-125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 1546-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 2868-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 862-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 639-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2641
% INFO    : Updated Thermal Rating: on line 2597-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 194-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 696-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 962-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 1080-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 1530-130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 1997-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 1530-130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 519-133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 1354-133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 385-134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 621-134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 943-134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 1782-134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 1037-135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 702-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 1685-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 1974-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 486-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 2020-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 1387-140 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2026
% INFO    : Updated Thermal Rating: on line 2897-2590 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1636
% INFO    : Updated Thermal Rating: on line 1387-2590 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2043
% INFO    : Updated Thermal Rating: on line 1723-140 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1634
% INFO    : Updated Thermal Rating: on line 643-143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 882-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 900-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 1637-146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 324-149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 730-154 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1087
% INFO    : Updated Thermal Rating: on line 1015-154 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1128
% INFO    : Updated Thermal Rating: on line 1015-154 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1127
% INFO    : Updated Thermal Rating: on line 1603-154 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1979
% INFO    : Updated Thermal Rating: on line 2797-155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13045
% INFO    : Updated Thermal Rating: on line 2678-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6256
% INFO    : Updated Thermal Rating: on line 704-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 2854-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 1750-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 535-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6649
% INFO    : Updated Thermal Rating: on line 2994-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 2118-157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 655-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 685-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 871-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 913-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 1456-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 2066-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 2656-160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 1447-161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 1297-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 1427-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 1938-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4352
% INFO    : Updated Thermal Rating: on line 1427-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 635-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 554-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 2029-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 1474-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2108-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 1921-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 1310-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1012-174 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 899
% INFO    : Updated Thermal Rating: on line 1576-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6068
% INFO    : Updated Thermal Rating: on line 1499-181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 370-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 2682-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 806-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 813-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 1169-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 597-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 2745-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 2744-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 1302-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 1899-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 2072-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2073-191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2794-193 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 2232
% INFO    : Updated Thermal Rating: on line 1098-193 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2175
% INFO    : Updated Thermal Rating: on line 536-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 1063-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 1081-2597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 1349-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on line 1411-2597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 1588-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 2084-2597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1557
% INFO    : Updated Thermal Rating: on line 1081-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 427-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 723-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 1093-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 1122-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 1221-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 2874-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 1752-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 1783-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2049-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 2106-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 2900-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 1290-198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5617
% INFO    : Updated Thermal Rating: on line 677-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20021
% INFO    : Updated Thermal Rating: on line 974-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 1795-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 1690-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 861-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 712-209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1825-209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 243-211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19054
% INFO    : Updated Thermal Rating: on line 459-213 : Rate A, Rate B, Rate C , 935.0, 935.0, 935.0 -> 892
% INFO    : Updated Thermal Rating: on line 1124-215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1951
% INFO    : Updated Thermal Rating: on line 2681-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 583-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 697-220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 2119-220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 773-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 2036-226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153231
% INFO    : Updated Thermal Rating: on line 1015-230 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 639
% INFO    : Updated Thermal Rating: on line 991-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 1929-233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8880
% INFO    : Updated Thermal Rating: on line 1928-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1930-2604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99170
% INFO    : Updated Thermal Rating: on line 1573-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 940-236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 2062-236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 1025-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 1705-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2109-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 380-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 658-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 1660-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 658-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 1850-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2136-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 458-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 1425-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 458-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 2886-2611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183736
% INFO    : Updated Thermal Rating: on line 1664-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170060
% INFO    : Updated Thermal Rating: on line 2886-2609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 1664-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 529-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 1416-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 1842-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 666-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 749-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 2008-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 2031-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 1493-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 2008-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 2158-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1816-262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 1947-265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 1654-266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 1598-267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3054
% INFO    : Updated Thermal Rating: on line 529-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 712-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2094-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 1048-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 1596-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 1771-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 2876-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7550
% INFO    : Updated Thermal Rating: on line 1771-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 1932-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 595-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 275-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 1887-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 1346-275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 753-276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 764-276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 1889-276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 1750-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 1006-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 1093-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 1632-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 2106-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 1333-282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39366
% INFO    : Updated Thermal Rating: on line 2856-282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22986
% INFO    : Updated Thermal Rating: on line 1933-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 2078-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 2080-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 425-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 1263-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 1270-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 1615-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1692-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 1788-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 2144-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 2157-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7106
% INFO    : Updated Thermal Rating: on line 509-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 1692-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 182-295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 351-295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 465-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 2982-300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 619-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 1848-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 1652-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 1847-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 1972-2628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19327
% INFO    : Updated Thermal Rating: on line 1971-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82904
% INFO    : Updated Thermal Rating: on line 798-308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4554
% INFO    : Updated Thermal Rating: on line 2874-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 753-310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 454-312 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1075
% INFO    : Updated Thermal Rating: on line 1023-312 : Rate A, Rate B, Rate C , 1987.0, 1987.0, 1987.0 -> 1524
% INFO    : Updated Thermal Rating: on line 1144-314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 1499-314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 1747-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 1941-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12456
% INFO    : Updated Thermal Rating: on line 1092-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1533-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1937-318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27427
% INFO    : Updated Thermal Rating: on line 1107-2631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 1107-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1560
% INFO    : Updated Thermal Rating: on line 1107-2630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1648
% INFO    : Updated Thermal Rating: on line 1109-320 : Rate A, Rate B, Rate C , 736.0, 736.0, 736.0 -> 468
% INFO    : Updated Thermal Rating: on line 1492-321 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1807
% INFO    : Updated Thermal Rating: on line 1492-321 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1827
% INFO    : Updated Thermal Rating: on line 1944-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1942-2634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 438-327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 619-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 840-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1670-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 921-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1532
% INFO    : Updated Thermal Rating: on line 921-2635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 1720-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 1953-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 2994-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1870
% INFO    : Updated Thermal Rating: on line 840-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 840-331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 818-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21471
% INFO    : Updated Thermal Rating: on line 1111-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27618
% INFO    : Updated Thermal Rating: on line 1534-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42153
% INFO    : Updated Thermal Rating: on line 497-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 762-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1946-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 1304-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20979
% INFO    : Updated Thermal Rating: on line 2140-343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 1338-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 2141-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 920-345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1651-345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 664-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 1020-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1573
% INFO    : Updated Thermal Rating: on line 1821-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1434
% INFO    : Updated Thermal Rating: on line 1020-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1578
% INFO    : Updated Thermal Rating: on line 1821-349 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1435
% INFO    : Updated Thermal Rating: on line 2053-351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 2151-354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1223-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 2035-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 858-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 865-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 1075-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 1640-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 1731-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 1826-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 1640-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 464-364 : Rate A, Rate B, Rate C , 1611.0, 1611.0, 1611.0 -> 1100
% INFO    : Updated Thermal Rating: on line 471-364 : Rate A, Rate B, Rate C , 1567.0, 1567.0, 1567.0 -> 1311
% INFO    : Updated Thermal Rating: on line 808-364 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2245
% INFO    : Updated Thermal Rating: on line 808-364 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2244
% INFO    : Updated Thermal Rating: on line 1949-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 1412-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 1411-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 515-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 776-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 393-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 412-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 2668-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 1962-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 1731-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 1448-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3362
% INFO    : Updated Thermal Rating: on line 1657-385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90021
% INFO    : Updated Thermal Rating: on line 516-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154266
% INFO    : Updated Thermal Rating: on line 516-388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 1233-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3425
% INFO    : Updated Thermal Rating: on line 2936-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5192
% INFO    : Updated Thermal Rating: on line 1884-391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 1689-2651 : Rate A, Rate B, Rate C , 1566.0, 1566.0, 1566.0 -> 1490
% INFO    : Updated Thermal Rating: on line 1689-2652 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1720
% INFO    : Updated Thermal Rating: on line 1689-2652 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1735
% INFO    : Updated Thermal Rating: on line 1892-396 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 1892-396 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 449-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9991
% INFO    : Updated Thermal Rating: on line 1173-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10322
% INFO    : Updated Thermal Rating: on line 890-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 1647-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 2114-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 736-2656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2755-2656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2715-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5574
% INFO    : Updated Thermal Rating: on line 2097-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6551
% INFO    : Updated Thermal Rating: on line 2716-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 1584-417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 1006-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 1296-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1951-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2753
% INFO    : Updated Thermal Rating: on line 1952-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320583
% INFO    : Updated Thermal Rating: on line 496-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 868-426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 1879-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 1953-432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 1235-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 1771-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 2130-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 1909-442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 1236-447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 1319-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 1505-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8488
% INFO    : Updated Thermal Rating: on line 2105-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 2960-453 : Rate A, Rate B, Rate C , 558.0, 558.0, 558.0 -> 297
% INFO    : Updated Thermal Rating: on line 581-454 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1002
% INFO    : Updated Thermal Rating: on line 581-454 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 2780-454 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 633
% INFO    : Updated Thermal Rating: on line 840-458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 1425-458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 1540-458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 840-458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 2116-458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 1365-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 1624-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 976-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1062-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 515-465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 1420-465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 526-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 1317-2665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2372
% INFO    : Updated Thermal Rating: on line 1597-2665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 1949-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83031
% INFO    : Updated Thermal Rating: on line 2125-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 2081-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1452
% INFO    : Updated Thermal Rating: on line 1317-2665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 990
% INFO    : Updated Thermal Rating: on line 2105-2667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19617
% INFO    : Updated Thermal Rating: on line 1516-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 2717-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 1219-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 622-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 2706-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 2686-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 698-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 844-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 1962-476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 1963-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32501
% INFO    : Updated Thermal Rating: on line 1402-481 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 1648
% INFO    : Updated Thermal Rating: on line 1839-481 : Rate A, Rate B, Rate C , 1307.0, 1307.0, 1307.0 -> 1080
% INFO    : Updated Thermal Rating: on line 577-482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 976-482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 673-2671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1444-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27378
% INFO    : Updated Thermal Rating: on line 2858-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27596
% INFO    : Updated Thermal Rating: on line 693-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23964
% INFO    : Updated Thermal Rating: on line 2147-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1723
% INFO    : Updated Thermal Rating: on line 753-490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5357
% INFO    : Updated Thermal Rating: on line 849-494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11384
% INFO    : Updated Thermal Rating: on line 793-496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 514-497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23302
% INFO    : Updated Thermal Rating: on line 621-497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 1439-497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 1231-498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 1365-498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 1810-498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 1082-499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 1453-499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 800-500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3203
% INFO    : Updated Thermal Rating: on line 800-2675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5064
% INFO    : Updated Thermal Rating: on line 1266-501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 526-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 1639-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 2060-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1499-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4535
% INFO    : Updated Thermal Rating: on line 589-506 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 1267-506 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 944
% INFO    : Updated Thermal Rating: on line 589-506 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 1559-512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19787
% INFO    : Updated Thermal Rating: on line 1410-518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22551
% INFO    : Updated Thermal Rating: on line 1410-2676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23186
% INFO    : Updated Thermal Rating: on line 2130-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 681-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26532
% INFO    : Updated Thermal Rating: on line 1201-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7254
% INFO    : Updated Thermal Rating: on line 1970-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 1972-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 1971-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 938-523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 1656-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 1961-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 1008-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 976-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 1127-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 806-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 1424-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 1920-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 1973-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 1974-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28417
% INFO    : Updated Thermal Rating: on line 2755-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 736-536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 1360-536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 1423-536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 1423-536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 2056-540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7564
% INFO    : Updated Thermal Rating: on line 2141-541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26199
% INFO    : Updated Thermal Rating: on line 1975-542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 685-543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 685-543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 2728-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38168
% INFO    : Updated Thermal Rating: on line 547-545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315683
% INFO    : Updated Thermal Rating: on line 353-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 473-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 622-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 672-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2467
% INFO    : Updated Thermal Rating: on line 937-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 1976-549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16094
% INFO    : Updated Thermal Rating: on line 641-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 482-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 501-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 1127-2679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 1133-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 1714-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 1783-2679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 2093-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 2137-2679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 1472-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8415
% INFO    : Updated Thermal Rating: on line 1901-559 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 1297
% INFO    : Updated Thermal Rating: on line 1962-563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 706-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14533
% INFO    : Updated Thermal Rating: on line 751-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20949
% INFO    : Updated Thermal Rating: on line 989-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 1088-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 2789-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21757
% INFO    : Updated Thermal Rating: on line 2044-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 1769-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3303
% INFO    : Updated Thermal Rating: on line 1769-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3566
% INFO    : Updated Thermal Rating: on line 798-567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 1136-576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 1564-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 1564-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 1259-581 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1517
% INFO    : Updated Thermal Rating: on line 2018-586 : Rate A, Rate B, Rate C , 541.0, 541.0, 541.0 -> 444
% INFO    : Updated Thermal Rating: on line 912-587 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2406
% INFO    : Updated Thermal Rating: on line 1090-587 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1759
% INFO    : Updated Thermal Rating: on line 1329-587 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1245
% INFO    : Updated Thermal Rating: on line 1363-587 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1191
% INFO    : Updated Thermal Rating: on line 912-587 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1821-589 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1934
% INFO    : Updated Thermal Rating: on line 1744-594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 1650-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 1750-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 1226-604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 1982-604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4368
% INFO    : Updated Thermal Rating: on line 1573-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 1878-607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 618-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 1449-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 1014-612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 1089-612 : Rate A, Rate B, Rate C , 325.0, 325.0, 325.0 -> 275
% INFO    : Updated Thermal Rating: on line 1015-613 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1482
% INFO    : Updated Thermal Rating: on line 1267-613 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1546
% INFO    : Updated Thermal Rating: on line 1455-613 : Rate A, Rate B, Rate C , 1263.0, 1263.0, 1263.0 -> 623
% INFO    : Updated Thermal Rating: on line 1787-613 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2287
% INFO    : Updated Thermal Rating: on line 1822-613 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 1787-613 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2289
% INFO    : Updated Thermal Rating: on line 1126-616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 1685-616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 1223-618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 1223-618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 1744-619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 795-620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 1282-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 1486-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 2055-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 2131-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 1907-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 2122-624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 752-627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85214
% INFO    : Updated Thermal Rating: on line 934-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 1117-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 1307-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 1535-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 1683-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 934-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 1535-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 1683-628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 1540-630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 1626-630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 655-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 1255-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1987-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 1988-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12351
% INFO    : Updated Thermal Rating: on line 733-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41198
% INFO    : Updated Thermal Rating: on line 1457-639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3862
% INFO    : Updated Thermal Rating: on line 2045-639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 2088-639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 1126-641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 1341-642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 1684-642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 814
% INFO    : Updated Thermal Rating: on line 2066-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 2065-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 1568-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321303
% INFO    : Updated Thermal Rating: on line 1568-2688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321303
% INFO    : Updated Thermal Rating: on line 1567-646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314228
% INFO    : Updated Thermal Rating: on line 1567-2689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314228
% INFO    : Updated Thermal Rating: on line 651-2692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 651-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 651-2690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 651-2691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1990-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 1989-2693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 872-2700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 1054-2700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 2154-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 2753-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 2949-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7488
% INFO    : Updated Thermal Rating: on line 2044-2700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 2058-666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 753-667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 863-668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3869
% INFO    : Updated Thermal Rating: on line 805-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2754-669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 2779-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 2797-674 : Rate A, Rate B, Rate C , 509.0, 509.0, 509.0 -> 422
% INFO    : Updated Thermal Rating: on line 1131-674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 1255-678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 1301-2704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37106
% INFO    : Updated Thermal Rating: on line 918-685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 948-685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 1482-685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 739-689 : Rate A, Rate B, Rate C , 1253.0, 1253.0, 1253.0 -> 1246
% INFO    : Updated Thermal Rating: on line 1140-690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 1297-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 1641-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2129-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 1297-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 1594-697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 1771-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1133-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 1136-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 1226-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 1490-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 1600-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 1961-703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 2060-703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on line 1347-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 1418-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 1377-705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206236
% INFO    : Updated Thermal Rating: on line 1995-2707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1467-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 1566-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 1584-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 1825-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 1960-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2029-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 1472-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 2094-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 1472-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 1659-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 1851-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 782-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 2082-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 782-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 1975-2714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 1976-718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84779
% INFO    : Updated Thermal Rating: on line 2116-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1393
% INFO    : Updated Thermal Rating: on line 1223-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 1975-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4688
% INFO    : Updated Thermal Rating: on line 1223-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 1997-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3052
% INFO    : Updated Thermal Rating: on line 1915-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 2752-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59375
% INFO    : Updated Thermal Rating: on line 730-726 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1998
% INFO    : Updated Thermal Rating: on line 730-726 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1455-729 : Rate A, Rate B, Rate C , 1695.0, 1695.0, 1695.0 -> 788
% INFO    : Updated Thermal Rating: on line 1698-729 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1552
% INFO    : Updated Thermal Rating: on line 1821-729 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1543
% INFO    : Updated Thermal Rating: on line 1698-729 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1597
% INFO    : Updated Thermal Rating: on line 1603-730 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2461
% INFO    : Updated Thermal Rating: on line 975-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 1521-732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 1063-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1075-735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 1839-739 : Rate A, Rate B, Rate C , 1750.0, 1750.0, 1750.0 -> 873
% INFO    : Updated Thermal Rating: on line 1839-739 : Rate A, Rate B, Rate C , 2197.0, 2197.0, 2197.0 -> 873
% INFO    : Updated Thermal Rating: on line 1839-739 : Rate A, Rate B, Rate C , 1192.0, 1192.0, 1192.0 -> 806
% INFO    : Updated Thermal Rating: on line 1114-740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1215-2727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 1528-745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 982-750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 1734-752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89765
% INFO    : Updated Thermal Rating: on line 1035-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 1889-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 1941-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 1659-754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 2024-757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5017
% INFO    : Updated Thermal Rating: on line 995-759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 1604-759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 942-760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 1771-760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 2083-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 773-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 1037-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 1378-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 1944-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 1946-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 1942-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 900-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 979-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 830-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6148
% INFO    : Updated Thermal Rating: on line 2826-771 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 1787-771 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 1283-771 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 1787-771 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 1325-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 1325-2730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 1325-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4237
% INFO    : Updated Thermal Rating: on line 1412-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 1420-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 2058-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 1126-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 1321-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1504-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 1685-782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 2886-786 : Rate A, Rate B, Rate C , 1662.0, 1662.0, 1662.0 -> 1168
% INFO    : Updated Thermal Rating: on line 1839-786 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1605
% INFO    : Updated Thermal Rating: on line 1325-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 1325-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 2739-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1114-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 1104-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14962
% INFO    : Updated Thermal Rating: on line 924-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 1192-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 1184-805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 1294-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 2881-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 1973-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 2053-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 1621-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2872
% INFO    : Updated Thermal Rating: on line 2007-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 985-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38967
% INFO    : Updated Thermal Rating: on line 2752-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50437
% INFO    : Updated Thermal Rating: on line 869-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40928
% INFO    : Updated Thermal Rating: on line 2008-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 2782-821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5585
% INFO    : Updated Thermal Rating: on line 1102-826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 1159-827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8140
% INFO    : Updated Thermal Rating: on line 2806-827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 950-837 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1286
% INFO    : Updated Thermal Rating: on line 2807-837 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 1168-837 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 1071-839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5972
% INFO    : Updated Thermal Rating: on line 920-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 2981-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7175
% INFO    : Updated Thermal Rating: on line 1804-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6997
% INFO    : Updated Thermal Rating: on line 2079-844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 1164-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 2015-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 1792-853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 1398-853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 1039-855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13856
% INFO    : Updated Thermal Rating: on line 1257-855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 1705-855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 2071-855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 1040-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 1935-858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 852-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 1781-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 2045-862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 1826-865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 1535-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 1683-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 1338-867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 1236-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 1378-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 1139-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 1184-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1198-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1258-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 1725-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 1755-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 2056-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 1258-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 1725-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 1061-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 1652-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 1061-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2152-877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1234-2755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 1562-2755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1613-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 1905-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on line 2017-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2283
% INFO    : Updated Thermal Rating: on line 1070-882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 1037-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2015-887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13714
% INFO    : Updated Thermal Rating: on line 2020-888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38032
% INFO    : Updated Thermal Rating: on line 1758-889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148594
% INFO    : Updated Thermal Rating: on line 1758-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 2144-890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 1449-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 1171-2768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184947
% INFO    : Updated Thermal Rating: on line 1171-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169954
% INFO    : Updated Thermal Rating: on line 2022-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48031
% INFO    : Updated Thermal Rating: on line 1220-898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 2057-898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 1280-899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 2109-899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 2047-900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 1941-905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 1871-910 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1476
% INFO    : Updated Thermal Rating: on line 1707-912 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 1707-912 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 1073-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 2884-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 1737-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 1045-914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 1334-914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 921-915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 921-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 1704-916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1375-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 1045-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 1121-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 1045-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 1389-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104366
% INFO    : Updated Thermal Rating: on line 2840-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87644
% INFO    : Updated Thermal Rating: on line 1749-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2025-925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 1247-2774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93975
% INFO    : Updated Thermal Rating: on line 1247-932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128083
% INFO    : Updated Thermal Rating: on line 1247-2775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120296
% INFO    : Updated Thermal Rating: on line 1453-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 2027-936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83031
% INFO    : Updated Thermal Rating: on line 992-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 1068-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1581
% INFO    : Updated Thermal Rating: on line 1170-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 1170-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 1564-940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 2029-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2082
% INFO    : Updated Thermal Rating: on line 1354-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 1766-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 1809-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 1766-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 2102-943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 1440-944 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 455
% INFO    : Updated Thermal Rating: on line 1181-945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 1414-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 1456-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 1482-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 1617-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 2001-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 2126-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 1952-954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 1113-957 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 1028-957 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1476
% INFO    : Updated Thermal Rating: on line 1113-957 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 1028-957 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1479
% INFO    : Updated Thermal Rating: on line 1998-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 2074-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33358
% INFO    : Updated Thermal Rating: on line 2031-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83220
% INFO    : Updated Thermal Rating: on line 1255-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1325-963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 968-967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 1944-967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 1942-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 1554-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 2047-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 2059-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3456
% INFO    : Updated Thermal Rating: on line 1474-974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 1357-975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 958-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 1288-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1495-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 2015-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 958-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 1276-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 1582-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 1834-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 1582-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 1624-984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1045-2778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5788
% INFO    : Updated Thermal Rating: on line 1045-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9266
% INFO    : Updated Thermal Rating: on line 1341-989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 967
% INFO    : Updated Thermal Rating: on line 1068-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 1726-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 2035-994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1449-995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1450-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3495
% INFO    : Updated Thermal Rating: on line 1293-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 2912-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46632
% INFO    : Updated Thermal Rating: on line 2913-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 1763-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 2081-1004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17519
% INFO    : Updated Thermal Rating: on line 1262-1006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 1047-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 1561-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5579
% INFO    : Updated Thermal Rating: on line 1648-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 1906-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2120-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 2871-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4483
% INFO    : Updated Thermal Rating: on line 1281-1009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 1263-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 1798-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 1841-1012 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1264
% INFO    : Updated Thermal Rating: on line 1115-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 1435-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 1509-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 1420-1029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 1582-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2019-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 1368-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25728
% INFO    : Updated Thermal Rating: on line 1092-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 1703-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 2119-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 2042-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309124
% INFO    : Updated Thermal Rating: on line 1105-1056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 2044-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 1135-1059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1978-1060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 2045-1060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12709
% INFO    : Updated Thermal Rating: on line 1604-1061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 1714-1062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1732-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 2898-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 1486-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 1314-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 1761-1072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5344
% INFO    : Updated Thermal Rating: on line 1818-1075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 1663-2785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 1079-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1449-1079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1580-1079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 2132-1079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on line 1140-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 1629-1081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7146
% INFO    : Updated Thermal Rating: on line 1416-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 1878-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 2068-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 1416-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 2069-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 1648-1092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 2047-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36366
% INFO    : Updated Thermal Rating: on line 1124-1100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 1933-1100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 1506-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1084
% INFO    : Updated Thermal Rating: on line 1550-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 1951-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 2121-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 1212-1105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 1352-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 1612-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5139
% INFO    : Updated Thermal Rating: on line 2046-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2078-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on line 2080-1105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 1784-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 2072-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 1784-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 1788-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 1788-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 1850-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 1312-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 1662-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 1680-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 1731-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 1800-1126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 1714-1127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 2084-1135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 1783-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 2155-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 2916-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2345
% INFO    : Updated Thermal Rating: on line 2053-1137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1047
% INFO    : Updated Thermal Rating: on line 1737-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 1365-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 1991-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 1997-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 1220-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2087-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 1846-1147 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1275
% INFO    : Updated Thermal Rating: on line 1357-1148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 1357-2801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 1280-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 2055-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 2070-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 2151-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 2067-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 1176-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 1589-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5215
% INFO    : Updated Thermal Rating: on line 1910-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 2056-1161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7403
% INFO    : Updated Thermal Rating: on line 1163-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310318
% INFO    : Updated Thermal Rating: on line 1473-2982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 2159-2982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 2132-1165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 1839-1168 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1005
% INFO    : Updated Thermal Rating: on line 1839-2807 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1006
% INFO    : Updated Thermal Rating: on line 2057-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18362
% INFO    : Updated Thermal Rating: on line 1865-1175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1204-1176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 2058-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 2071-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 2135-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 1637-1182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37253
% INFO    : Updated Thermal Rating: on line 1578-1184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 2856-1187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93975
% INFO    : Updated Thermal Rating: on line 1431-2811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102466
% INFO    : Updated Thermal Rating: on line 2059-1188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43126
% INFO    : Updated Thermal Rating: on line 1780-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on line 2155-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 1264-1194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64995
% INFO    : Updated Thermal Rating: on line 1264-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64995
% INFO    : Updated Thermal Rating: on line 1264-2812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52379
% INFO    : Updated Thermal Rating: on line 2060-1198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 1726-1199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 1700-1204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 1461-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106993
% INFO    : Updated Thermal Rating: on line 1825-1215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 1594-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 1359-1219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14073
% INFO    : Updated Thermal Rating: on line 1976-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 2101-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 1442-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 2827-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 1289-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 1600-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 1887-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 1982-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on line 1652-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 2066-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 2068-1243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 1902-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 1604-1250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1536-1252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 2071-1254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45914
% INFO    : Updated Thermal Rating: on line 1441-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 2072-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 2884-1261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 1963-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 2049-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 1615-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 1915-1266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1844-1269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 1788-1270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 2048-1275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2546
% INFO    : Updated Thermal Rating: on line 2074-1278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 1484-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 1704-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 1906-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 2075-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3467
% INFO    : Updated Thermal Rating: on line 1486-1282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 1647-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 1625-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 1484-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 1704-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 1484-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 1683-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2114-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 2079-1308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151180
% INFO    : Updated Thermal Rating: on line 2030-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22557
% INFO    : Updated Thermal Rating: on line 1265-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5006
% INFO    : Updated Thermal Rating: on line 1474-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 1281-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 2020-1311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6284
% INFO    : Updated Thermal Rating: on line 1375-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 2082-1321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 1248-1323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 1252-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 1252-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 1236-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 2142-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 1236-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 2083-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6375
% INFO    : Updated Thermal Rating: on line 1771-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 1771-1331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 1987-1334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 1521-1334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 2146-1335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 1937-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2428
% INFO    : Updated Thermal Rating: on line 1343-1342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5241
% INFO    : Updated Thermal Rating: on line 1472-1342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2045
% INFO    : Updated Thermal Rating: on line 1472-1343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7695
% INFO    : Updated Thermal Rating: on line 1646-1346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 1932-1346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 1750-1347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 1701-1351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 2087-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 2010-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 2088-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 2097-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 1857-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 2091-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5986
% INFO    : Updated Thermal Rating: on line 2893-1367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6082
% INFO    : Updated Thermal Rating: on line 1672-1367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 1902-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 1907-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 2092-1372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47367
% INFO    : Updated Thermal Rating: on line 2835-1374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 1369-1374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 2834-1374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123245
% INFO    : Updated Thermal Rating: on line 1426-1377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29661
% INFO    : Updated Thermal Rating: on line 2093-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 1652-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 2062-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 1658-1396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 2147-1396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 2094-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 1514-2845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40590
% INFO    : Updated Thermal Rating: on line 1514-1399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42124
% INFO    : Updated Thermal Rating: on line 2924-1402 : Rate A, Rate B, Rate C , 1708.0, 1708.0, 1708.0 -> 1115
% INFO    : Updated Thermal Rating: on line 2852-1404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1406-1404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2851-1404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1549-2853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20973
% INFO    : Updated Thermal Rating: on line 1964-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2711
% INFO    : Updated Thermal Rating: on line 2026-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2039-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 1919-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 2097-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 1868-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2039-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 2099-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53230
% INFO    : Updated Thermal Rating: on line 2098-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67824
% INFO    : Updated Thermal Rating: on line 2100-1423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3817
% INFO    : Updated Thermal Rating: on line 1678-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 1852-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 1988-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 1580-1432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32580
% INFO    : Updated Thermal Rating: on line 1717-1435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 1740-1437 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1811
% INFO    : Updated Thermal Rating: on line 1740-1437 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1825
% INFO    : Updated Thermal Rating: on line 1653-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 2102-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 1678-1449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 1910-1449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 1479-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7269
% INFO    : Updated Thermal Rating: on line 2106-1469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10879
% INFO    : Updated Thermal Rating: on line 1848-1475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 1899-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 1850-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 2108-2864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 811
% INFO    : Updated Thermal Rating: on line 2109-1480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 2031-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 1628-1499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3028
% INFO    : Updated Thermal Rating: on line 2138-1499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on line 2139-1499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37377
% INFO    : Updated Thermal Rating: on line 2113-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56492
% INFO    : Updated Thermal Rating: on line 1609-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 1694-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2711
% INFO    : Updated Thermal Rating: on line 2135-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2666
% INFO    : Updated Thermal Rating: on line 1852-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1987-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 2035-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 1839-1526 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1386
% INFO    : Updated Thermal Rating: on line 1655-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1530-1529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28461
% INFO    : Updated Thermal Rating: on line 1576-1536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 1564-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 1814-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 2116-1547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 1582-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 2117-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 2882-1549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16924
% INFO    : Updated Thermal Rating: on line 2118-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 2119-1552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5531
% INFO    : Updated Thermal Rating: on line 1973-1557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 1779-2870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22038
% INFO    : Updated Thermal Rating: on line 1560-2871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3831
% INFO    : Updated Thermal Rating: on line 2001-1569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 2122-1569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 1747-2874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1940-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 1577-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 1806-1578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 1834-1578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 2922-1582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2007-1582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 1801-1584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 1949-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1949-2875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 2123-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17958
% INFO    : Updated Thermal Rating: on line 2114-1592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5882
% INFO    : Updated Thermal Rating: on line 2102-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 1881-1600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 1600-1606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4118
% INFO    : Updated Thermal Rating: on line 1706-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 1610-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 1646-1615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 1651-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 1796-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 1842-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 1932-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on line 2149-1630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 1826-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 2131-1643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65055
% INFO    : Updated Thermal Rating: on line 1883-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1877-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 2131-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 1750-1650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 1829-1650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 1750-1650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 1744-1651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 1744-1651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 1776-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 1847-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 2914-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on line 1960-1655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 1903-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 2152-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 1850-1660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 1691-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 1731-2885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 1921-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1922-2885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 1839-1664 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 811
% INFO    : Updated Thermal Rating: on line 2132-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23415
% INFO    : Updated Thermal Rating: on line 1929-1674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1313
% INFO    : Updated Thermal Rating: on line 1952-1674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 2055-1676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 1517-1685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 1814-1685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 1806-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 1834-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 2136-1695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1162
% INFO    : Updated Thermal Rating: on line 1710-1698 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 1710-1698 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 2153-1710 : Rate A, Rate B, Rate C , 2450.0, 2450.0, 2450.0 -> 1390
% INFO    : Updated Thermal Rating: on line 1713-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 1795-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 2137-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 2139-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 1921-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 1740-2896 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2158
% INFO    : Updated Thermal Rating: on line 1740-1719 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2153
% INFO    : Updated Thermal Rating: on line 2025-1725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 2140-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 1773-1741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on line 2144-1742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 1837-1744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 1953-1747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 1814-1749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 2146-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53161
% INFO    : Updated Thermal Rating: on line 2149-1754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 2152-1760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11263
% INFO    : Updated Thermal Rating: on line 1850-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 2025-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 1940-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on line 2048-1788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1106
% INFO    : Updated Thermal Rating: on line 1926-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 1927-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12010
% INFO    : Updated Thermal Rating: on line 2154-1793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on line 2155-1794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2647
% INFO    : Updated Thermal Rating: on line 2087-1795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1848-1796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 1848-1796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 2157-1798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 1974-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 2118-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 2146-1811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 1835-1814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 1815-1816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10572
% INFO    : Updated Thermal Rating: on line 2145-1816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 2158-1816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 1899-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 2108-1850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 2117-1850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 2136-1850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 2093-1856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52398
% INFO    : Updated Thermal Rating: on line 2158-1858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9817
% INFO    : Updated Thermal Rating: on line 2026-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 2935-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2935-2933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1875-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 2068-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 2083-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1562
% INFO    : Updated Thermal Rating: on line 2004-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1449
% INFO    : Updated Thermal Rating: on line 2074-1883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 1895-1892 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 2203
% INFO    : Updated Thermal Rating: on line 2126-1909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 2059-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3854
% INFO    : Updated Thermal Rating: on line 2065-1918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5965
% INFO    : Updated Thermal Rating: on line 1967-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 1947-1937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 2019-1946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 1970-1963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37051
% INFO    : Updated Thermal Rating: on line 2063-1991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 2069-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 2125-2010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15385
% INFO    : Updated Thermal Rating: on line 2057-2075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 2129-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 2149-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 1594-2249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 10-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 12-2191 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1111
% INFO    : Updated Thermal Rating: on line 12-2215 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 42-43 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 42-43 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2576-50 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 49-50 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 53-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 60-2163 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1094
% INFO    : Updated Thermal Rating: on line 60-2216 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1070
% INFO    : Updated Thermal Rating: on transformer 65-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11659
% INFO    : Updated Thermal Rating: on transformer 68-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45569
% INFO    : Updated Thermal Rating: on line 74-2192 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 303
% INFO    : Updated Thermal Rating: on line 74-2217 : Rate A, Rate B, Rate C , 444.0, 444.0, 444.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 107-108 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 107-108 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 125-127 : Rate A, Rate B, Rate C , 1020.0, 1020.0, 1020.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 125-127 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 125-127 : Rate A, Rate B, Rate C , 1016.0, 1016.0, 1016.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 130-131 : Rate A, Rate B, Rate C , 433.0, 433.0, 433.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 130-131 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 177-178 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on line 179-2164 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 179-2193 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 182-183 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 182-183 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 182-183 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 194-195 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2597-195 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 197-198 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 197-198 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 197-198 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 205-206 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 221-222 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 221-222 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 225-226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 232-233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 2613-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 2614-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 259-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 263-264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 2616-264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 2617-264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on line 280-2165 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1169
% INFO    : Updated Thermal Rating: on line 280-2195 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 2620-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on transformer 287-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 2619-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 291-2623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 2622-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 2623-293 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 292-293 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 298-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 2625-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 2624-299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 322-323 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 566
% INFO    : Updated Thermal Rating: on transformer 335-336 : Rate A, Rate B, Rate C , 2164.0, 2164.0, 2164.0 -> 162
% INFO    : Updated Thermal Rating: on line 357-2219 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 894
% INFO    : Updated Thermal Rating: on line 2645-2233 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 357-2243 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 987
% INFO    : Updated Thermal Rating: on transformer 363-364 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 320
% INFO    : Updated Thermal Rating: on transformer 363-364 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 318
% INFO    : Updated Thermal Rating: on transformer 365-2646 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 367-368 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 367-368 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 367-368 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 380-381 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 379-2168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 380-382 : Rate A, Rate B, Rate C , 1627.0, 1627.0, 1627.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 380-382 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 391-392 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1168
% INFO    : Updated Thermal Rating: on transformer 391-392 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1165
% INFO    : Updated Thermal Rating: on line 2651-2220 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 959
% INFO    : Updated Thermal Rating: on transformer 408-409 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1162
% INFO    : Updated Thermal Rating: on transformer 408-409 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1159
% INFO    : Updated Thermal Rating: on line 409-2221 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 985
% INFO    : Updated Thermal Rating: on transformer 2658-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on transformer 418-419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on transformer 435-436 : Rate A, Rate B, Rate C , 1038.0, 1038.0, 1038.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 2946-454 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 453-454 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 458-459 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 458-459 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 458-459 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 2665-470 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 469-470 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 2665-2667 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 502-503 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 502-503 : Rate A, Rate B, Rate C , 316.0, 316.0, 316.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 513-514 : Rate A, Rate B, Rate C , 2164.0, 2164.0, 2164.0 -> 162
% INFO    : Updated Thermal Rating: on transformer 536-537 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 538-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45573
% INFO    : Updated Thermal Rating: on transformer 552-553 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 2679-553 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 557-2169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 559-2169 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 564-565 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 564-565 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 566-568 : Rate A, Rate B, Rate C , 545.0, 545.0, 545.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 580-581 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 580-581 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 2978-2681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 2680-2681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on transformer 582-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 2977-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 587-2234 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1016
% INFO    : Updated Thermal Rating: on line 587-2245 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on line 613-2170 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 620-621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 620-621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 2686-623 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 622-623 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 622-623 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 628-629 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 628-629 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 628-629 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 639-640 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 639-640 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 643-644 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 643-644 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2697-2699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on transformer 2696-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on transformer 662-663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on transformer 2700-665 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 664-665 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 678-679 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 678-679 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 685-686 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 685-686 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 691-692 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 691-692 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 2710-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 2708-710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 2709-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 709-2712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 712-713 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 712-713 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 714-715 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 189
% INFO    : Updated Thermal Rating: on line 729-2199 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 2720-742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 2719-2724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 2718-2725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 2721-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 741-2722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 744-746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 753-754 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 753-754 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 762-763 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 762-763 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 770-771 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 770-771 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 770-771 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 776-2737 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 776-777 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 782-783 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on transformer 782-783 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 238
% INFO    : Updated Thermal Rating: on line 786-2171 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 798-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 798-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 800-801 : Rate A, Rate B, Rate C , 560.0, 560.0, 560.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 800-801 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 806-807 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 806-807 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 288
% INFO    : Updated Thermal Rating: on line 818-2222 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 278
% INFO    : Updated Thermal Rating: on line 818-2235 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 348
% INFO    : Updated Thermal Rating: on transformer 2964-823 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 822-823 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 835-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 835-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 838-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 839-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 840-841 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 840-841 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 844-845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 853-854 : Rate A, Rate B, Rate C , 1018.0, 1018.0, 1018.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 855-856 : Rate A, Rate B, Rate C , 428.0, 428.0, 428.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 855-856 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 873-874 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 2754-874 : Rate A, Rate B, Rate C , 447.0, 447.0, 447.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 2754-874 : Rate A, Rate B, Rate C , 438.0, 438.0, 438.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2755-879 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 2755-879 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 878-879 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 2760-2764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 2757-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 883-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 2758-2763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 2759-2766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 2761-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 900-901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 910-2200 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 910-2223 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1089
% INFO    : Updated Thermal Rating: on transformer 921-922 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 921-922 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 938-939 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 942-943 : Rate A, Rate B, Rate C , 278.0, 278.0, 278.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 942-944 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 942-944 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 943-944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on transformer 953-955 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 954-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 976-977 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 976-977 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 978-2224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2777-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 979-2224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on transformer 2779-993 : Rate A, Rate B, Rate C , 445.0, 445.0, 445.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 2779-993 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 992-993 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1008-1009 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 1008-1009 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 1013-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on transformer 1016-1017 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 1019-1020 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 887
% INFO    : Updated Thermal Rating: on line 2780-2174 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 883
% INFO    : Updated Thermal Rating: on line 1023-2201 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 982
% INFO    : Updated Thermal Rating: on transformer 2782-1031 : Rate A, Rate B, Rate C , 604.0, 604.0, 604.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1030-1031 : Rate A, Rate B, Rate C , 342.0, 342.0, 342.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1048-1049 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 243
% INFO    : Updated Thermal Rating: on line 1067-2176 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 894
% INFO    : Updated Thermal Rating: on line 1067-2226 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1068
% INFO    : Updated Thermal Rating: on line 1067-2236 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 891
% INFO    : Updated Thermal Rating: on transformer 1069-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 1071-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1075-2785 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 260
% INFO    : Updated Thermal Rating: on line 1077-2178 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1166
% INFO    : Updated Thermal Rating: on line 1077-2204 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 2788-1086 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1085-1086 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 1085-1086 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 2792-2794 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 2794-2205 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 891
% INFO    : Updated Thermal Rating: on line 1098-2227 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 989
% INFO    : Updated Thermal Rating: on line 1098-2237 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 981
% INFO    : Updated Thermal Rating: on transformer 1104-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 2795-2796 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1105-2796 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1107-1108 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 1107-1108 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1107-1108 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 2797-1120 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1167
% INFO    : Updated Thermal Rating: on transformer 1140-1141 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1140-1141 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 247
% INFO    : Updated Thermal Rating: on transformer 1140-1141 : Rate A, Rate B, Rate C , 432.0, 432.0, 432.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 1142-1143 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1151-1152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 2803-2804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 2802-2805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 1155-1156 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 1155-1156 : Rate A, Rate B, Rate C , 292.0, 292.0, 292.0 -> 237
% INFO    : Updated Thermal Rating: on line 1179-2180 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1178
% INFO    : Updated Thermal Rating: on line 1179-2207 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 1210-1211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 1223-1224 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1223-1224 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2818-1224 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1226-1227 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 1226-1227 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2820-1227 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 263
% INFO    : Updated Thermal Rating: on transformer 1236-1237 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 1236-1237 : Rate A, Rate B, Rate C , 723.0, 723.0, 723.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1280-1281 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 186
% INFO    : Updated Thermal Rating: on transformer 1310-1311 : Rate A, Rate B, Rate C , 313.0, 313.0, 313.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 1312-1313 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 1323-1324 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1171
% INFO    : Updated Thermal Rating: on line 2832-2181 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 974
% INFO    : Updated Thermal Rating: on line 2832-2208 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1046
% INFO    : Updated Thermal Rating: on line 1324-2228 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 985
% INFO    : Updated Thermal Rating: on line 1324-2238 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 1325-1326 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 1325-1326 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 1325-1326 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 266
% INFO    : Updated Thermal Rating: on transformer 1328-1329 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 1338-1339 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1338-1339 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1362-1363 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1154
% INFO    : Updated Thermal Rating: on line 1363-2182 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 1365-1366 : Rate A, Rate B, Rate C , 434.0, 434.0, 434.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1367-1368 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 1367-1368 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1370-1371 : Rate A, Rate B, Rate C , 290.0, 290.0, 290.0 -> 126
% INFO    : Updated Thermal Rating: on transformer 1375-1376 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 2838-1389 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1388-2840 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2838-1389 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2837-2839 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 2842-2844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 1393-2844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 2843-1394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 1401-1402 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1136
% INFO    : Updated Thermal Rating: on transformer 1405-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 2850-1406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 2849-2851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 1412-1413 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 2854-1419 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1418-1419 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1427-1428 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1427-1428 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 274
% INFO    : Updated Thermal Rating: on line 2856-2229 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 1436-1437 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 1447-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 1449-1450 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 261
% INFO    : Updated Thermal Rating: on transformer 1449-1450 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1453-1454 : Rate A, Rate B, Rate C , 311.0, 311.0, 311.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2863-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on transformer 1466-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 1484-1485 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1499-1500 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 197
% INFO    : Updated Thermal Rating: on line 1503-2184 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1039
% INFO    : Updated Thermal Rating: on transformer 1509-1510 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 1521-1522 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1521-1522 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on line 1526-2186 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1158
% INFO    : Updated Thermal Rating: on transformer 1543-1544 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 1543-1544 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 181
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 1564-1565 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 233
% INFO    : Updated Thermal Rating: on transformer 1571-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45593
% INFO    : Updated Thermal Rating: on transformer 2874-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82782
% INFO    : Updated Thermal Rating: on transformer 1578-1579 : Rate A, Rate B, Rate C , 436.0, 436.0, 436.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 1578-1579 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1580-1581 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1582-1583 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1582-1583 : Rate A, Rate B, Rate C , 726.0, 726.0, 726.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1593-2187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on transformer 1594-2187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 1595-2187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on transformer 1604-1605 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 2879-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 2880-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 1618-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 1623-1622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 1634-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 1652-1654 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1652-1654 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1653-1654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1658-1659 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 2885-1663 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 2885-1663 : Rate A, Rate B, Rate C , 312.0, 312.0, 312.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 1662-1663 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 2888-2892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 1666-2890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 2887-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 2894-1674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 1673-1674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on transformer 1675-1676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 1679-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on transformer 1685-1687 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 1686-1687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 1698-2188 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1099
% INFO    : Updated Thermal Rating: on line 1698-2211 : Rate A, Rate B, Rate C , 1174.0, 1174.0, 1174.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 1700-1701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 2895-1710 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 2895-1710 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 1720-1721 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 2994-1721 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1722-2897 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 1722-1723 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1065
% INFO    : Updated Thermal Rating: on line 1740-2231 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 976
% INFO    : Updated Thermal Rating: on line 1740-2240 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 983
% INFO    : Updated Thermal Rating: on transformer 1744-1745 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1744-1745 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 1744-1745 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 252
% INFO    : Updated Thermal Rating: on transformer 1745-1746 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 1745-1746 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 991
% INFO    : Updated Thermal Rating: on transformer 1750-1751 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1750-1751 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 273
% INFO    : Updated Thermal Rating: on transformer 2909-1759 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 2910-1759 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 2905-1759 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 2904-1759 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 1771-1772 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 1771-1772 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1771-1772 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1773-1774 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 1773-1774 : Rate A, Rate B, Rate C , 374.0, 374.0, 374.0 -> 194
% INFO    : Updated Thermal Rating: on transformer 1781-1782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 1788-1789 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 246
% INFO    : Updated Thermal Rating: on transformer 1788-1789 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 254
% INFO    : Updated Thermal Rating: on transformer 2917-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 1802-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on transformer 2919-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 2918-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 2921-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 2920-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on transformer 2981-1805 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 1804-1805 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 1804-1805 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 1816-1817 : Rate A, Rate B, Rate C , 453.0, 453.0, 453.0 -> 194
% INFO    : Updated Thermal Rating: on line 1821-2212 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 1844-1845 : Rate A, Rate B, Rate C , 358.0, 358.0, 358.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 1848-1849 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1848-1849 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 1850-1851 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 1850-1851 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 244
% INFO    : Updated Thermal Rating: on transformer 1850-1851 : Rate A, Rate B, Rate C , 435.0, 435.0, 435.0 -> 243
% INFO    : Updated Thermal Rating: on line 1863-2190 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1046
% INFO    : Updated Thermal Rating: on line 1863-2213 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1041
% INFO    : Updated Thermal Rating: on line 1863-2232 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 1863-2241 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 983
% INFO    : Updated Thermal Rating: on line 1863-2247 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 1864-1865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45649
% INFO    : Updated Thermal Rating: on transformer 2929-1871 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 1871-2214 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 885
% INFO    : Updated Thermal Rating: on line 1871-2242 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 2932-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 2931-2933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 1873-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 1900-1901 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 46-2251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 81-2253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 81-2254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 81-2255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 95-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 95-2258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on transformer 98-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on transformer 106-2260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 106-2261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 2587-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 2587-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 147-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 147-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 148-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 148-2267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 2591-2268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 2591-2269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 188-2274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 2596-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 189-2277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on transformer 189-2278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 198-2279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 198-2280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 198-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 198-2282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 198-2283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on transformer 229-2286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on transformer 229-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 229-2289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 229-2290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 231-2291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 231-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 257-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 257-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 257-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 2612-2302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 2612-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 2612-2304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 266-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 266-2306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 384-2311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 2648-2312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 2648-2313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on transformer 395-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on transformer 398-2315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on transformer 2573-2325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 24-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 791-2327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 448-2332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on transformer 553-2336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 553-2337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 553-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 553-2339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 553-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 553-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 508-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 508-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 2676-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on transformer 617-2356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 2717-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 738-2360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 738-2361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on transformer 738-2362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 2717-2363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 757-2367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 767-2368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 769-2369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 769-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 799-2377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 824-2379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 829-2382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 829-2383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 836-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 836-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 888-2388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 906-2389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 977-2390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 977-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 977-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 977-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 964-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on transformer 971-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 971-2396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 991-2397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 991-2398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on transformer 991-2399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on transformer 991-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on transformer 996-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 996-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 996-2403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 1003-2404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on transformer 1036-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 2783-2410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 1053-2411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 1053-2412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 202-2413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on transformer 2599-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on transformer 1638-2415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 1123-2417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 1123-2418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 1128-2419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 2798-2420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 1130-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on transformer 2799-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on transformer 2799-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 1143-2425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 1143-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 1166-2429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on transformer 1166-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 1167-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on transformer 1200-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 1200-2435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on transformer 1203-2436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 1230-2441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 2822-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 1273-2445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 2823-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on transformer 2824-2447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on transformer 1277-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 1277-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 1279-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 1279-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on transformer 2827-2454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 1311-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 1319-2458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 1357-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 1357-2460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 1361-2462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 2835-2463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 1369-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 2834-2465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 1371-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 1371-2467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 1371-2468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 1371-2469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 2846-2470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 2848-2471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on transformer 2847-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 2607-2474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 2608-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 239-2477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 2605-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 1477-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on transformer 1479-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 1479-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 1488-2484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 1488-2485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 1488-2486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 1488-2487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on transformer 1500-2489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 1505-2490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 1505-2491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 1541-2493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1541-2494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 1544-2496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 1544-2497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 646-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on transformer 645-2502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on transformer 2688-2503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on transformer 1581-2504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 1581-2505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 1586-2507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1586-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1587-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 2875-2510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 1590-2511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 1590-2512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on transformer 1605-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 1605-2516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 1605-2517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 1677-2519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 1677-2520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 1677-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 1677-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 1687-2524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 1687-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 1687-2526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 1778-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 1778-2532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 2915-2533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 1859-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on transformer 1882-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on transformer 1882-2538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.03957074, theta=-12.7856509 -> V=0.999999, theta=0.0
% INFO    : Bus 2	: V=1.06516669, theta=-13.3775389 -> V=0.9888895, theta=0.0
% INFO    : Bus 3	: V=1.08888546, theta=-4.51671702 -> V=1.051315, theta=0.0
% INFO    : Bus 4	: V=1.00600996, theta=-20.9505448 -> V=1.0000025, theta=0.0
% INFO    : Bus 5	: V=0.942209712, theta=-9.07367325 -> V=0.9444445, theta=0.0
% INFO    : Bus 6	: V=0.94296561, theta=-9.11016114 -> V=0.9444445, theta=0.0
% INFO    : Bus 7	: V=1.06730298, theta=-11.3034406 -> V=1.04222, theta=0.0
% INFO    : Bus 8	: V=1.00974411, theta=-19.5488389 -> V=1.015872, theta=0.0
% INFO    : Bus 10	: V=1.05674633, theta=-7.6859698 -> V=1.003335, theta=0.0
% INFO    : Bus 11	: V=1.04778703, theta=-10.4959639 -> V=1.0111115, theta=0.0
% INFO    : Bus 2571	: V=1.04686282, theta=-11.4360738 -> V=1.0111115, theta=0.0
% INFO    : Bus 12	: V=1.0570783, theta=-10.6257474 -> V=1.05263, theta=0.0
% INFO    : Bus 2572	: V=1.06291996, theta=-10.1490097 -> V=1.05263, theta=0.0
% INFO    : Bus 13	: V=1.06118059, theta=-20.8121594 -> V=1.045335, theta=0.0
% INFO    : Bus 14	: V=0.998402273, theta=-19.5349019 -> V=0.999999, theta=0.0
% INFO    : Bus 15	: V=1.00960184, theta=-16.8840236 -> V=0.999999, theta=0.0
% INFO    : Bus 16	: V=1.03332753, theta=-15.2015161 -> V=1.0111115, theta=0.0
% INFO    : Bus 17	: V=1.07437329, theta=-22.1328317 -> V=1.044445, theta=0.0
% INFO    : Bus 18	: V=1.06826934, theta=-19.369661 -> V=1.04481, theta=0.0
% INFO    : Bus 19	: V=1.04150565, theta=-15.107511 -> V=1.0036225, theta=0.0
% INFO    : Bus 20	: V=1.07414904, theta=-22.1336063 -> V=1.044445, theta=0.0
% INFO    : Bus 21	: V=1.07837745, theta=-10.4264501 -> V=0.9888895, theta=0.0
% INFO    : Bus 22	: V=0.990279412, theta=-25.014912 -> V=1.004499, theta=0.0
% INFO    : Bus 23	: V=1.00173474, theta=-18.3619703 -> V=0.999999, theta=0.0
% INFO    : Bus 24	: V=1.08736673, theta=-7.06750396 -> V=1.044445, theta=0.0
% INFO    : Bus 2573	: V=1.08736631, theta=-7.06750114 -> V=1.044445, theta=0.0
% INFO    : Bus 25	: V=1.07853363, theta=-10.4233912 -> V=0.9888895, theta=0.0
% INFO    : Bus 26	: V=1.07598744, theta=-4.14811723 -> V=1.0415785, theta=0.0
% INFO    : Bus 27	: V=1.01405223, theta=-18.4056103 -> V=0.999999, theta=0.0
% INFO    : Bus 28	: V=1.05113895, theta=-20.4941876 -> V=1.044445, theta=0.0
% INFO    : Bus 2574	: V=1.05112133, theta=-20.4945453 -> V=1.044445, theta=0.0
% INFO    : Bus 29	: V=1.00515521, theta=-16.7539769 -> V=0.999999, theta=0.0
% INFO    : Bus 30	: V=1.06337239, theta=-18.9692115 -> V=1.044445, theta=0.0
% INFO    : Bus 31	: V=1.04330906, theta=-14.6242825 -> V=1.004309, theta=0.0
% INFO    : Bus 32	: V=1.02946566, theta=-19.8883959 -> V=0.999999, theta=0.0
% INFO    : Bus 33	: V=0.937076005, theta=-9.75466137 -> V=0.9444445, theta=0.0
% INFO    : Bus 34	: V=0.94194428, theta=-9.10370635 -> V=0.9444445, theta=0.0
% INFO    : Bus 35	: V=1.02086428, theta=-18.2068976 -> V=1.015872, theta=0.0
% INFO    : Bus 36	: V=0.974471963, theta=-12.2688461 -> V=0.9444445, theta=0.0
% INFO    : Bus 37	: V=0.996883091, theta=-16.0858104 -> V=0.999999, theta=0.0
% INFO    : Bus 38	: V=1.036, theta=-12.7572317 -> V=1.0158755, theta=0.0
% INFO    : Bus 39	: V=1.04880949, theta=-12.8596939 -> V=1.0380035, theta=0.0
% INFO    : Bus 40	: V=1.06143677, theta=-12.0055618 -> V=0.9888895, theta=0.0
% INFO    : Bus 41	: V=1.05307427, theta=-28.0690398 -> V=1.04222, theta=0.0
% INFO    : Bus 42	: V=1.02349613, theta=-14.0643108 -> V=1.000104, theta=0.0
% INFO    : Bus 43	: V=1.04400425, theta=-11.7772435 -> V=1.0111115, theta=0.0
% INFO    : Bus 44	: V=1.02695311, theta=-18.1849839 -> V=1.015872, theta=0.0
% INFO    : Bus 45	: V=1.05508118, theta=-18.6863905 -> V=1.044445, theta=0.0
% INFO    : Bus 46	: V=1.08899996, theta=-4.50903487 -> V=1.05263, theta=0.0
% INFO    : Bus 2575	: V=1.08899763, theta=-4.5052882 -> V=1.05263, theta=0.0
% INFO    : Bus 47	: V=1.02924994, theta=-11.0032309 -> V=1.001284, theta=0.0
% INFO    : Bus 48	: V=1.0380023, theta=-15.0627934 -> V=1.001929, theta=0.0
% INFO    : Bus 49	: V=1.04449377, theta=-10.7690362 -> V=1.015872, theta=0.0
% INFO    : Bus 2576	: V=1.04213976, theta=-11.5674386 -> V=1.015872, theta=0.0
% INFO    : Bus 50	: V=1.07524181, theta=-8.92969468 -> V=1.04222, theta=0.0
% INFO    : Bus 51	: V=1.07080154, theta=-14.9322226 -> V=1.04222, theta=0.0
% INFO    : Bus 52	: V=1.07543395, theta=-21.9585367 -> V=1.044445, theta=0.0
% INFO    : Bus 2942	: V=1.03656994, theta=-20.8860482 -> V=1.044445, theta=0.0
% INFO    : Bus 53	: V=1.03967305, theta=-11.2114832 -> V=1.015872, theta=0.0
% INFO    : Bus 54	: V=1.06904972, theta=-11.0690101 -> V=1.0233335, theta=0.0
% INFO    : Bus 55	: V=1.02277092, theta=-7.31812106 -> V=1.047295, theta=0.0
% INFO    : Bus 56	: V=1.03724147, theta=-4.57515341 -> V=1.05263, theta=0.0
% INFO    : Bus 57	: V=1.02124002, theta=-17.7251591 -> V=1.0377785, theta=0.0
% INFO    : Bus 59	: V=1.07954393, theta=-10.2093798 -> V=1.0288895, theta=0.0
% INFO    : Bus 60	: V=1.08484514, theta=-8.00388709 -> V=1.05263, theta=0.0
% INFO    : Bus 61	: V=1.03128173, theta=-15.4711978 -> V=0.999999, theta=0.0
% INFO    : Bus 63	: V=1.00933558, theta=-20.0679804 -> V=1.015872, theta=0.0
% INFO    : Bus 2577	: V=1.00934424, theta=-21.3334173 -> V=1.015872, theta=0.0
% INFO    : Bus 64	: V=1.05276128, theta=-12.6446356 -> V=1.0111115, theta=0.0
% INFO    : Bus 65	: V=1.00931717, theta=-21.3374383 -> V=1.015872, theta=0.0
% INFO    : Bus 66	: V=0.92175763, theta=-13.4339467 -> V=0.9444445, theta=0.0
% INFO    : Bus 2578	: V=0.958, theta=-13.3407261 -> V=0.9444445, theta=0.0
% INFO    : Bus 67	: V=1.06670888, theta=-10.8411748 -> V=0.9888895, theta=0.0
% INFO    : Bus 2579	: V=1.06690256, theta=-10.835916 -> V=0.9888895, theta=0.0
% INFO    : Bus 68	: V=1.06949128, theta=-18.381187 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=1.06953469, theta=-18.3731259 -> V=1.043425, theta=0.0
% INFO    : Bus 70	: V=1.06893349, theta=-20.6667868 -> V=1.044445, theta=0.0
% INFO    : Bus 71	: V=1.091, theta=-12.4948451 -> V=1.004425, theta=0.0
% INFO    : Bus 72	: V=1.0487681, theta=-20.6337343 -> V=1.044445, theta=0.0
% INFO    : Bus 2580	: V=1.04876788, theta=-20.6337331 -> V=1.044445, theta=0.0
% INFO    : Bus 74	: V=1.04876663, theta=-20.6337262 -> V=1.044445, theta=0.0
% INFO    : Bus 75	: V=1.02954269, theta=-12.5232602 -> V=0.999999, theta=0.0
% INFO    : Bus 76	: V=0.936, theta=-9.18763306 -> V=0.9444445, theta=0.0
% INFO    : Bus 77	: V=1.03543542, theta=-16.1086493 -> V=1.0027225, theta=0.0
% INFO    : Bus 78	: V=1.05502862, theta=-19.2480453 -> V=1.044445, theta=0.0
% INFO    : Bus 79	: V=1.00754108, theta=-27.4814562 -> V=1.0000025, theta=0.0
% INFO    : Bus 80	: V=0.995772648, theta=-19.1831462 -> V=1.0040375, theta=0.0
% INFO    : Bus 81	: V=1.0440276, theta=-17.359702 -> V=1.044445, theta=0.0
% INFO    : Bus 82	: V=1.05795939, theta=-12.3730191 -> V=0.9888895, theta=0.0
% INFO    : Bus 83	: V=0.997900327, theta=-25.7645007 -> V=1.0154445, theta=0.0
% INFO    : Bus 84	: V=1.07048844, theta=-7.92331607 -> V=1.0288895, theta=0.0
% INFO    : Bus 85	: V=1.08605073, theta=-4.78732009 -> V=1.05263, theta=0.0
% INFO    : Bus 86	: V=1.00724259, theta=-23.3698198 -> V=1.015872, theta=0.0
% INFO    : Bus 87	: V=0.993796119, theta=-13.6335423 -> V=1.015872, theta=0.0
% INFO    : Bus 88	: V=1.02834157, theta=-16.4283637 -> V=1.015872, theta=0.0
% INFO    : Bus 89	: V=1.02175873, theta=-14.0720657 -> V=1.015872, theta=0.0
% INFO    : Bus 2581	: V=1.02212915, theta=-13.8487246 -> V=1.015872, theta=0.0
% INFO    : Bus 90	: V=1.06765662, theta=-13.7777708 -> V=1.04222, theta=0.0
% INFO    : Bus 2582	: V=1.06760338, theta=-13.807522 -> V=1.04222, theta=0.0
% INFO    : Bus 91	: V=1.0609556, theta=-20.2843633 -> V=1.044445, theta=0.0
% INFO    : Bus 92	: V=1.06964778, theta=-10.0034274 -> V=1.0118715, theta=0.0
% INFO    : Bus 93	: V=1.09047512, theta=-12.5519577 -> V=1.004535, theta=0.0
% INFO    : Bus 94	: V=1.07939534, theta=-12.9106011 -> V=1.04222, theta=0.0
% INFO    : Bus 2583	: V=1.08021703, theta=-12.9173291 -> V=1.04222, theta=0.0
% INFO    : Bus 95	: V=1.07839122, theta=-13.2249988 -> V=1.033334, theta=0.0
% INFO    : Bus 96	: V=1.0615075, theta=-11.1187178 -> V=0.9888895, theta=0.0
% INFO    : Bus 97	: V=1.00685807, theta=-21.6222117 -> V=1.015872, theta=0.0
% INFO    : Bus 98	: V=1.05224889, theta=-10.2497723 -> V=1.0111115, theta=0.0
% INFO    : Bus 99	: V=1.06121608, theta=-20.8488846 -> V=1.044445, theta=0.0
% INFO    : Bus 2584	: V=1.06715039, theta=-19.6241436 -> V=1.044445, theta=0.0
% INFO    : Bus 100	: V=1.04357054, theta=-17.5525378 -> V=1.044445, theta=0.0
% INFO    : Bus 101	: V=1.06339988, theta=-13.9006632 -> V=1.0377785, theta=0.0
% INFO    : Bus 102	: V=1.07290192, theta=-10.5578661 -> V=0.9888895, theta=0.0
% INFO    : Bus 2585	: V=1.06406579, theta=-11.4221677 -> V=0.9888895, theta=0.0
% INFO    : Bus 103	: V=1.07695363, theta=-7.11066132 -> V=1.05263, theta=0.0
% INFO    : Bus 104	: V=1.0501149, theta=-20.7221334 -> V=1.044445, theta=0.0
% INFO    : Bus 2586	: V=1.06454398, theta=-19.7362121 -> V=1.044445, theta=0.0
% INFO    : Bus 105	: V=1.00103775, theta=-16.9248584 -> V=1.0000025, theta=0.0
% INFO    : Bus 106	: V=1.06901319, theta=-10.0460515 -> V=1.033334, theta=0.0
% INFO    : Bus 2587	: V=1.06901999, theta=-10.0459566 -> V=1.033334, theta=0.0
% INFO    : Bus 107	: V=1.03757067, theta=-14.1962729 -> V=1.015872, theta=0.0
% INFO    : Bus 108	: V=1.06695524, theta=-10.7581791 -> V=1.04222, theta=0.0
% INFO    : Bus 109	: V=1.07658268, theta=-14.0193555 -> V=1.04222, theta=0.0
% INFO    : Bus 110	: V=1.09331748, theta=-8.28931693 -> V=1.051315, theta=0.0
% INFO    : Bus 111	: V=1.07626914, theta=-14.0756991 -> V=1.04222, theta=0.0
% INFO    : Bus 112	: V=1.06928796, theta=-19.2036147 -> V=1.045175, theta=0.0
% INFO    : Bus 2588	: V=1.06925164, theta=-19.2134954 -> V=1.045175, theta=0.0
% INFO    : Bus 113	: V=1.0819927, theta=-4.56327751 -> V=0.9888895, theta=0.0
% INFO    : Bus 114	: V=1.02384974, theta=-16.6455425 -> V=0.999999, theta=0.0
% INFO    : Bus 115	: V=1.0690746, theta=-11.5058425 -> V=0.9888895, theta=0.0
% INFO    : Bus 116	: V=1.07288681, theta=-6.70235687 -> V=0.9888895, theta=0.0
% INFO    : Bus 117	: V=1.01221849, theta=-13.8566616 -> V=1.015872, theta=0.0
% INFO    : Bus 118	: V=0.984057863, theta=-29.8904038 -> V=1.0000025, theta=0.0
% INFO    : Bus 119	: V=1.02675218, theta=-21.3609643 -> V=1.015872, theta=0.0
% INFO    : Bus 120	: V=1.049, theta=-15.058726 -> V=1.002569, theta=0.0
% INFO    : Bus 121	: V=1.02653722, theta=-25.5795491 -> V=1.015872, theta=0.0
% INFO    : Bus 2589	: V=1.02659968, theta=-25.6110124 -> V=1.015872, theta=0.0
% INFO    : Bus 122	: V=1.05285733, theta=-12.506156 -> V=1.044445, theta=0.0
% INFO    : Bus 123	: V=1.01316225, theta=-23.5029903 -> V=1.0000025, theta=0.0
% INFO    : Bus 124	: V=1.03095395, theta=-17.0573027 -> V=1.0013325, theta=0.0
% INFO    : Bus 125	: V=1.0336739, theta=-21.4763796 -> V=1.0000025, theta=0.0
% INFO    : Bus 126	: V=1.0233504, theta=-12.9463589 -> V=1.044445, theta=0.0
% INFO    : Bus 127	: V=1.061739, theta=-12.9611097 -> V=1.05263, theta=0.0
% INFO    : Bus 128	: V=1.03631833, theta=-13.1986143 -> V=0.999999, theta=0.0
% INFO    : Bus 129	: V=1.02632529, theta=-15.7888272 -> V=0.999999, theta=0.0
% INFO    : Bus 130	: V=1.04663197, theta=-17.5668721 -> V=1.0000025, theta=0.0
% INFO    : Bus 2955	: V=1.0227956, theta=-19.8618164 -> V=1.0000025, theta=0.0
% INFO    : Bus 131	: V=1.0527202, theta=-15.6919249 -> V=1.044445, theta=0.0
% INFO    : Bus 132	: V=1.04578364, theta=-17.0663527 -> V=1.044445, theta=0.0
% INFO    : Bus 133	: V=1.008, theta=-29.2069551 -> V=1.016817, theta=0.0
% INFO    : Bus 134	: V=1.00881558, theta=-21.5295796 -> V=1.0233335, theta=0.0
% INFO    : Bus 135	: V=1.02936073, theta=-19.2981863 -> V=1.0000025, theta=0.0
% INFO    : Bus 136	: V=1.04827941, theta=-12.3656357 -> V=1.0377785, theta=0.0
% INFO    : Bus 137	: V=1.0198151, theta=-13.6526439 -> V=1.015872, theta=0.0
% INFO    : Bus 138	: V=1.06116318, theta=-8.64980177 -> V=1.04222, theta=0.0
% INFO    : Bus 140	: V=1.09861059, theta=-3.91680983 -> V=1.05263, theta=0.0
% INFO    : Bus 2590	: V=1.09940833, theta=-3.83524305 -> V=1.05263, theta=0.0
% INFO    : Bus 141	: V=1.05545215, theta=-11.2719939 -> V=1.044445, theta=0.0
% INFO    : Bus 142	: V=1.06626653, theta=-16.3570817 -> V=1.044445, theta=0.0
% INFO    : Bus 143	: V=1.01995095, theta=-21.3560134 -> V=1.015872, theta=0.0
% INFO    : Bus 144	: V=1.075666, theta=-15.3110955 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=1.04693974, theta=-13.700896 -> V=1.044625, theta=0.0
% INFO    : Bus 146	: V=1.051, theta=-20.5356037 -> V=1.044445, theta=0.0
% INFO    : Bus 147	: V=1.04733528, theta=-10.4089217 -> V=1.0111115, theta=0.0
% INFO    : Bus 148	: V=1.06293868, theta=-10.0930426 -> V=1.05263, theta=0.0
% INFO    : Bus 2591	: V=1.05707552, theta=-10.5433047 -> V=1.05263, theta=0.0
% INFO    : Bus 149	: V=1.07473471, theta=-22.1074766 -> V=1.044445, theta=0.0
% INFO    : Bus 2592	: V=1.0347394, theta=-21.1306766 -> V=1.044445, theta=0.0
% INFO    : Bus 150	: V=1.02224417, theta=-11.0332254 -> V=1.0377785, theta=0.0
% INFO    : Bus 151	: V=1.07455824, theta=-22.1203835 -> V=1.044445, theta=0.0
% INFO    : Bus 153	: V=1.02980033, theta=-10.4231277 -> V=1.0111115, theta=0.0
% INFO    : Bus 154	: V=1.06626964, theta=-7.13788385 -> V=1.05263, theta=0.0
% INFO    : Bus 155	: V=1.05850973, theta=-10.6112512 -> V=1.044445, theta=0.0
% INFO    : Bus 156	: V=1.04464819, theta=-16.3219945 -> V=1.000769, theta=0.0
% INFO    : Bus 157	: V=1.03564222, theta=-14.6858502 -> V=1.015872, theta=0.0
% INFO    : Bus 158	: V=1.01640934, theta=-21.2022009 -> V=1.0000025, theta=0.0
% INFO    : Bus 159	: V=1.0065889, theta=-23.9976681 -> V=1.015872, theta=0.0
% INFO    : Bus 160	: V=1.01781991, theta=-17.888386 -> V=0.999999, theta=0.0
% INFO    : Bus 161	: V=0.997372449, theta=-21.1158526 -> V=0.975, theta=0.0
% INFO    : Bus 162	: V=1.0724193, theta=-19.7796414 -> V=1.045265, theta=0.0
% INFO    : Bus 163	: V=1.01942021, theta=-31.2100473 -> V=1.015872, theta=0.0
% INFO    : Bus 164	: V=1.0439638, theta=-11.5860344 -> V=1.048955, theta=0.0
% INFO    : Bus 165	: V=1.05303584, theta=-8.53297324 -> V=1.0377785, theta=0.0
% INFO    : Bus 166	: V=1.03235274, theta=-16.7482068 -> V=1.015872, theta=0.0
% INFO    : Bus 167	: V=1.06118842, theta=-20.807027 -> V=1.045335, theta=0.0
% INFO    : Bus 168	: V=1.0076754, theta=-16.301367 -> V=0.999999, theta=0.0
% INFO    : Bus 169	: V=1.0124195, theta=-16.0049382 -> V=1.015872, theta=0.0
% INFO    : Bus 170	: V=1.03162859, theta=-15.9797699 -> V=1.002364, theta=0.0
% INFO    : Bus 171	: V=1.05497058, theta=-12.8212795 -> V=1.006667, theta=0.0
% INFO    : Bus 172	: V=0.995015, theta=-12.2363058 -> V=1.015872, theta=0.0
% INFO    : Bus 173	: V=1.08898655, theta=-2.73327438 -> V=1.0414135, theta=0.0
% INFO    : Bus 174	: V=1.09568901, theta=-1.70247243 -> V=1.05263, theta=0.0
% INFO    : Bus 2998	: V=1.09658913, theta=-1.16129964 -> V=1.05263, theta=0.0
% INFO    : Bus 175	: V=1.0660945, theta=-23.1480029 -> V=1.04222, theta=0.0
% INFO    : Bus 177	: V=0.970410004, theta=-27.7752476 -> V=1.0121725, theta=0.0
% INFO    : Bus 178	: V=1.05671877, theta=-26.7198436 -> V=1.04222, theta=0.0
% INFO    : Bus 179	: V=1.052746, theta=-23.9394857 -> V=1.051315, theta=0.0
% INFO    : Bus 180	: V=1.0297866, theta=-10.4512216 -> V=1.0111115, theta=0.0
% INFO    : Bus 181	: V=0.979322683, theta=-9.47678764 -> V=0.9527045, theta=0.0
% INFO    : Bus 182	: V=1.03156899, theta=-15.4353561 -> V=0.999999, theta=0.0
% INFO    : Bus 183	: V=1.04537042, theta=-11.8208058 -> V=1.0111115, theta=0.0
% INFO    : Bus 184	: V=1.06817651, theta=-8.81250699 -> V=1.033334, theta=0.0
% INFO    : Bus 185	: V=1.02336812, theta=-17.9629197 -> V=0.999999, theta=0.0
% INFO    : Bus 186	: V=1.07442958, theta=-2.97708778 -> V=1.04931, theta=0.0
% INFO    : Bus 187	: V=1.07034557, theta=-2.95500976 -> V=1.05263, theta=0.0
% INFO    : Bus 2593	: V=1.07037922, theta=-2.95118917 -> V=1.05263, theta=0.0
% INFO    : Bus 2594	: V=1.07039187, theta=-2.95206658 -> V=1.05263, theta=0.0
% INFO    : Bus 2595	: V=1.0704066, theta=-2.96429662 -> V=1.05263, theta=0.0
% INFO    : Bus 188	: V=1.08944704, theta=-2.60427878 -> V=1.0417485, theta=0.0
% INFO    : Bus 2596	: V=1.08914177, theta=-2.62414739 -> V=1.0417485, theta=0.0
% INFO    : Bus 189	: V=1.09591932, theta=-1.6310889 -> V=1.05263, theta=0.0
% INFO    : Bus 190	: V=1.08029811, theta=-10.8632695 -> V=1.0288895, theta=0.0
% INFO    : Bus 191	: V=0.995118832, theta=-32.5658518 -> V=1.015872, theta=0.0
% INFO    : Bus 192	: V=1.05307326, theta=-28.0231606 -> V=1.04222, theta=0.0
% INFO    : Bus 193	: V=1.09016654, theta=-9.69846799 -> V=1.05263, theta=0.0
% INFO    : Bus 194	: V=1.02850746, theta=-15.8394437 -> V=0.999999, theta=0.0
% INFO    : Bus 2597	: V=1.02840305, theta=-15.4801169 -> V=0.999999, theta=0.0
% INFO    : Bus 195	: V=1.05985128, theta=-11.069304 -> V=1.0111115, theta=0.0
% INFO    : Bus 196	: V=1.07295788, theta=-6.42782881 -> V=1.05263, theta=0.0
% INFO    : Bus 197	: V=1.03044726, theta=-11.2048008 -> V=1.015872, theta=0.0
% INFO    : Bus 198	: V=1.06510936, theta=-7.30516403 -> V=1.04222, theta=0.0
% INFO    : Bus 199	: V=1.05980321, theta=-10.1162357 -> V=1.04222, theta=0.0
% INFO    : Bus 200	: V=1.05925231, theta=-11.7515465 -> V=1.0111115, theta=0.0
% INFO    : Bus 2598	: V=1.05922187, theta=-11.7543252 -> V=1.0111115, theta=0.0
% INFO    : Bus 201	: V=1.07207587, theta=-19.7758121 -> V=1.045135, theta=0.0
% INFO    : Bus 202	: V=1.06248786, theta=-8.82510115 -> V=1.047645, theta=0.0
% INFO    : Bus 2599	: V=1.06229395, theta=-8.9368443 -> V=1.047645, theta=0.0
% INFO    : Bus 203	: V=1.05028687, theta=-12.3262135 -> V=1.044445, theta=0.0
% INFO    : Bus 204	: V=1.07500568, theta=-13.3068191 -> V=1.044445, theta=0.0
% INFO    : Bus 205	: V=0.997198422, theta=-13.2794297 -> V=1.015872, theta=0.0
% INFO    : Bus 206	: V=1.05232106, theta=-9.01931724 -> V=1.04222, theta=0.0
% INFO    : Bus 207	: V=1.02358871, theta=-20.1544227 -> V=1.015872, theta=0.0
% INFO    : Bus 208	: V=1.02098324, theta=-22.6659143 -> V=1.0000025, theta=0.0
% INFO    : Bus 209	: V=0.992421152, theta=-17.4871505 -> V=0.999999, theta=0.0
% INFO    : Bus 210	: V=1.00754108, theta=-27.4814562 -> V=1.0000025, theta=0.0
% INFO    : Bus 211	: V=1.04861401, theta=-13.0257362 -> V=1.044445, theta=0.0
% INFO    : Bus 212	: V=1.07373759, theta=-16.7460124 -> V=1.04222, theta=0.0
% INFO    : Bus 213	: V=1.07364159, theta=-16.7549775 -> V=1.04222, theta=0.0
% INFO    : Bus 2600	: V=1.07397671, theta=-11.5979057 -> V=1.04222, theta=0.0
% INFO    : Bus 214	: V=1.07465635, theta=-9.21425352 -> V=1.051315, theta=0.0
% INFO    : Bus 215	: V=1.0388281, theta=-14.8193034 -> V=1.000344, theta=0.0
% INFO    : Bus 216	: V=1.07315993, theta=-6.43953699 -> V=0.9888895, theta=0.0
% INFO    : Bus 217	: V=1.07442094, theta=-2.97715229 -> V=1.049305, theta=0.0
% INFO    : Bus 218	: V=1.07029979, theta=-3.02756499 -> V=1.05263, theta=0.0
% INFO    : Bus 219	: V=1.06496714, theta=-15.2881817 -> V=1.0377785, theta=0.0
% INFO    : Bus 220	: V=0.996253007, theta=-28.4394501 -> V=1.015872, theta=0.0
% INFO    : Bus 221	: V=1.00192462, theta=-18.316836 -> V=1.0000025, theta=0.0
% INFO    : Bus 222	: V=1.04250102, theta=-17.0309642 -> V=1.044445, theta=0.0
% INFO    : Bus 223	: V=1.07479961, theta=-29.5169266 -> V=1.04222, theta=0.0
% INFO    : Bus 2601	: V=1.07479208, theta=-29.5167297 -> V=1.04222, theta=0.0
% INFO    : Bus 2602	: V=1.07479208, theta=-29.5167297 -> V=1.04222, theta=0.0
% INFO    : Bus 224	: V=1.07479102, theta=-29.516702 -> V=1.04222, theta=0.0
% INFO    : Bus 225	: V=1.046, theta=-9.82965848 -> V=1.0, theta=0.0
% INFO    : Bus 226	: V=1.04306698, theta=-11.7466699 -> V=1.0111115, theta=0.0
% INFO    : Bus 227	: V=1.05747308, theta=-14.9826078 -> V=1.0377785, theta=0.0
% INFO    : Bus 229	: V=1.05606007, theta=-9.37781221 -> V=1.0452, theta=0.0
% INFO    : Bus 230	: V=1.07526447, theta=-7.62852964 -> V=1.05263, theta=0.0
% INFO    : Bus 231	: V=1.03988197, theta=-9.75112301 -> V=1.0111115, theta=0.0
% INFO    : Bus 232	: V=1.01473966, theta=-12.4596836 -> V=1.015872, theta=0.0
% INFO    : Bus 2603	: V=1.03606897, theta=-11.7348658 -> V=1.015872, theta=0.0
% INFO    : Bus 233	: V=1.06782003, theta=-11.2749989 -> V=1.0233335, theta=0.0
% INFO    : Bus 234	: V=1.05213064, theta=-20.2424564 -> V=1.044445, theta=0.0
% INFO    : Bus 2604	: V=1.05137029, theta=-20.3185732 -> V=1.044445, theta=0.0
% INFO    : Bus 235	: V=1.022, theta=-14.0623899 -> V=0.999999, theta=0.0
% INFO    : Bus 236	: V=1.0305346, theta=-15.1516013 -> V=1.015872, theta=0.0
% INFO    : Bus 237	: V=1.01896284, theta=-18.5363978 -> V=0.999999, theta=0.0
% INFO    : Bus 238	: V=1.07329949, theta=-7.06866443 -> V=0.9888895, theta=0.0
% INFO    : Bus 239	: V=1.06541891, theta=-10.209633 -> V=1.04595, theta=0.0
% INFO    : Bus 2605	: V=1.06542687, theta=-10.20784 -> V=1.04595, theta=0.0
% INFO    : Bus 2606	: V=1.0654032, theta=-10.2177315 -> V=1.04595, theta=0.0
% INFO    : Bus 2607	: V=1.06542549, theta=-10.2087765 -> V=1.04595, theta=0.0
% INFO    : Bus 2608	: V=1.06541839, theta=-10.211206 -> V=1.04595, theta=0.0
% INFO    : Bus 240	: V=1.073, theta=-6.9951648 -> V=1.05347, theta=0.0
% INFO    : Bus 241	: V=1.03061761, theta=-10.1305569 -> V=1.001859, theta=0.0
% INFO    : Bus 242	: V=1.02972188, theta=-16.1934971 -> V=1.015872, theta=0.0
% INFO    : Bus 243	: V=1.04877458, theta=-12.9984157 -> V=1.044445, theta=0.0
% INFO    : Bus 244	: V=1.02309984, theta=-23.7865505 -> V=1.015872, theta=0.0
% INFO    : Bus 245	: V=1.03372553, theta=-10.8546675 -> V=1.0377785, theta=0.0
% INFO    : Bus 246	: V=1.08330278, theta=-4.59795122 -> V=1.05263, theta=0.0
% INFO    : Bus 2609	: V=1.08216675, theta=-4.65656581 -> V=1.05263, theta=0.0
% INFO    : Bus 2610	: V=1.08333167, theta=-4.60468491 -> V=1.05263, theta=0.0
% INFO    : Bus 2611	: V=1.0821875, theta=-4.66695353 -> V=1.05263, theta=0.0
% INFO    : Bus 247	: V=1.05530716, theta=-11.8000114 -> V=1.006667, theta=0.0
% INFO    : Bus 248	: V=1.01037357, theta=-15.6624609 -> V=0.999999, theta=0.0
% INFO    : Bus 249	: V=0.988372119, theta=-18.395922 -> V=0.999999, theta=0.0
% INFO    : Bus 250	: V=1.02879773, theta=-17.3967958 -> V=1.0377785, theta=0.0
% INFO    : Bus 251	: V=1.05105895, theta=-23.8594833 -> V=1.04342, theta=0.0
% INFO    : Bus 252	: V=0.952, theta=-10.693816 -> V=0.9444445, theta=0.0
% INFO    : Bus 253	: V=1.06739339, theta=-1.95901453 -> V=1.051315, theta=0.0
% INFO    : Bus 254	: V=1.06742899, theta=-1.97694925 -> V=1.051315, theta=0.0
% INFO    : Bus 255	: V=1.04108714, theta=-15.6924303 -> V=1.002024, theta=0.0
% INFO    : Bus 256	: V=1.04802943, theta=-21.0042406 -> V=1.044445, theta=0.0
% INFO    : Bus 257	: V=1.07341686, theta=-10.6545713 -> V=1.033334, theta=0.0
% INFO    : Bus 2612	: V=1.07341709, theta=-10.6544928 -> V=1.033334, theta=0.0
% INFO    : Bus 258	: V=1.07543535, theta=-11.6004712 -> V=1.0288895, theta=0.0
% INFO    : Bus 259	: V=1.052, theta=-6.18745299 -> V=1.0, theta=0.0
% INFO    : Bus 2613	: V=1.053, theta=-6.11709177 -> V=1.0, theta=0.0
% INFO    : Bus 2614	: V=1.053, theta=-5.9480219 -> V=1.0, theta=0.0
% INFO    : Bus 260	: V=1.0494647, theta=-8.03197906 -> V=1.0111115, theta=0.0
% INFO    : Bus 2615	: V=1.05054589, theta=-7.81397912 -> V=1.0111115, theta=0.0
% INFO    : Bus 261	: V=1.04930906, theta=-20.4617819 -> V=1.042445, theta=0.0
% INFO    : Bus 262	: V=0.951, theta=-10.8511045 -> V=0.9444445, theta=0.0
% INFO    : Bus 263	: V=1.05792948, theta=-17.2385687 -> V=1.0, theta=0.0
% INFO    : Bus 2616	: V=1.05792049, theta=-17.2355003 -> V=1.0, theta=0.0
% INFO    : Bus 2617	: V=1.0579425, theta=-17.2352241 -> V=1.0, theta=0.0
% INFO    : Bus 264	: V=1.05796364, theta=-17.2254014 -> V=1.04222, theta=0.0
% INFO    : Bus 265	: V=1.03462864, theta=-16.9763243 -> V=1.015872, theta=0.0
% INFO    : Bus 266	: V=1.06948702, theta=-12.0802636 -> V=1.033334, theta=0.0
% INFO    : Bus 267	: V=1.0719158, theta=-10.9568693 -> V=1.04222, theta=0.0
% INFO    : Bus 268	: V=1.00284192, theta=-16.8725531 -> V=0.999999, theta=0.0
% INFO    : Bus 269	: V=0.985967287, theta=-33.200291 -> V=1.015872, theta=0.0
% INFO    : Bus 270	: V=1.06080131, theta=-13.9558041 -> V=1.0200005, theta=0.0
% INFO    : Bus 271	: V=1.02, theta=-12.4697603 -> V=0.999999, theta=0.0
% INFO    : Bus 272	: V=1.06474395, theta=-19.6050343 -> V=1.044445, theta=0.0
% INFO    : Bus 273	: V=1.03000674, theta=-17.4714247 -> V=1.0377785, theta=0.0
% INFO    : Bus 274	: V=1.033, theta=-11.5888962 -> V=0.999999, theta=0.0
% INFO    : Bus 275	: V=1.034, theta=-11.2869092 -> V=0.999999, theta=0.0
% INFO    : Bus 276	: V=1.0034792, theta=-19.0238284 -> V=1.0060075, theta=0.0
% INFO    : Bus 277	: V=1.03341783, theta=-16.0513951 -> V=1.001879, theta=0.0
% INFO    : Bus 279	: V=1.0445784, theta=-27.1139 -> V=1.04222, theta=0.0
% INFO    : Bus 280	: V=1.04991004, theta=-24.8913451 -> V=1.051315, theta=0.0
% INFO    : Bus 281	: V=1.02129183, theta=-13.0931352 -> V=1.015872, theta=0.0
% INFO    : Bus 282	: V=1.06383788, theta=-19.9364848 -> V=1.044445, theta=0.0
% INFO    : Bus 283	: V=1.074, theta=-10.2904789 -> V=0.9888895, theta=0.0
% INFO    : Bus 284	: V=1.07399443, theta=-10.2920615 -> V=0.9888895, theta=0.0
% INFO    : Bus 285	: V=1.032, theta=-12.2945607 -> V=0.999999, theta=0.0
% INFO    : Bus 2618	: V=1.032, theta=-13.7187552 -> V=0.999999, theta=0.0
% INFO    : Bus 286	: V=1.0766022, theta=-20.189502 -> V=1.04222, theta=0.0
% INFO    : Bus 287	: V=0.994940234, theta=-13.0785206 -> V=1.0, theta=0.0
% INFO    : Bus 2619	: V=0.994940234, theta=-13.0785206 -> V=1.0, theta=0.0
% INFO    : Bus 2620	: V=0.994940234, theta=-13.0785206 -> V=1.0, theta=0.0
% INFO    : Bus 288	: V=0.993946287, theta=-13.0785206 -> V=0.999999, theta=0.0
% INFO    : Bus 289	: V=1.07636194, theta=-3.95089415 -> V=1.0408735, theta=0.0
% INFO    : Bus 290	: V=1.06932015, theta=-15.4248603 -> V=1.04222, theta=0.0
% INFO    : Bus 2621	: V=1.07069318, theta=-14.944909 -> V=1.04222, theta=0.0
% INFO    : Bus 291	: V=1.03, theta=-8.45573582 -> V=1.0, theta=0.0
% INFO    : Bus 2622	: V=1.024, theta=-9.18323012 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=1.01546532, theta=-12.9886237 -> V=0.999999, theta=0.0
% INFO    : Bus 2623	: V=1.02600154, theta=-11.8108308 -> V=0.999999, theta=0.0
% INFO    : Bus 293	: V=1.04563673, theta=-8.77324039 -> V=1.0111115, theta=0.0
% INFO    : Bus 294	: V=1.09412371, theta=-1.93438639 -> V=1.05263, theta=0.0
% INFO    : Bus 295	: V=1.02479642, theta=-16.183913 -> V=0.999999, theta=0.0
% INFO    : Bus 296	: V=1.00288813, theta=-16.9483063 -> V=0.999999, theta=0.0
% INFO    : Bus 297	: V=1.07077708, theta=-10.5267001 -> V=1.05263, theta=0.0
% INFO    : Bus 298	: V=1.05, theta=-6.49306994 -> V=1.0, theta=0.0
% INFO    : Bus 2624	: V=1.051, theta=-6.46094512 -> V=1.0, theta=0.0
% INFO    : Bus 2625	: V=1.05, theta=-6.49760008 -> V=1.0, theta=0.0
% INFO    : Bus 299	: V=1.04834051, theta=-8.25437473 -> V=1.0111115, theta=0.0
% INFO    : Bus 2626	: V=1.04727125, theta=-8.41885091 -> V=1.0111115, theta=0.0
% INFO    : Bus 300	: V=1.02577334, theta=-21.7820114 -> V=1.0000025, theta=0.0
% INFO    : Bus 301	: V=1.08004015, theta=-12.8562842 -> V=1.04222, theta=0.0
% INFO    : Bus 2627	: V=1.08052132, theta=-12.8169662 -> V=1.04222, theta=0.0
% INFO    : Bus 302	: V=1.01742053, theta=-27.1422273 -> V=1.015872, theta=0.0
% INFO    : Bus 303	: V=1.07256383, theta=-14.0508154 -> V=1.04222, theta=0.0
% INFO    : Bus 304	: V=1.0319334, theta=-14.069741 -> V=1.015872, theta=0.0
% INFO    : Bus 305	: V=1.0433618, theta=-11.5297241 -> V=1.016392, theta=0.0
% INFO    : Bus 2628	: V=1.04891341, theta=-10.4890756 -> V=1.016392, theta=0.0
% INFO    : Bus 306	: V=1.065705, theta=-15.4313629 -> V=1.04553, theta=0.0
% INFO    : Bus 307	: V=1.06984675, theta=-15.3350846 -> V=1.04222, theta=0.0
% INFO    : Bus 2629	: V=1.06962676, theta=-15.3720289 -> V=1.04222, theta=0.0
% INFO    : Bus 308	: V=1.0686738, theta=-10.6675649 -> V=1.0266685, theta=0.0
% INFO    : Bus 309	: V=1.01955429, theta=-15.1133941 -> V=1.015872, theta=0.0
% INFO    : Bus 310	: V=1.01944205, theta=-17.5265543 -> V=1.0047725, theta=0.0
% INFO    : Bus 311	: V=1.07539298, theta=-28.0246742 -> V=1.04222, theta=0.0
% INFO    : Bus 312	: V=1.0779951, theta=-23.6739127 -> V=1.051315, theta=0.0
% INFO    : Bus 313	: V=1.03749252, theta=-21.3056222 -> V=1.0000025, theta=0.0
% INFO    : Bus 314	: V=0.962, theta=-8.87042657 -> V=0.9448795, theta=0.0
% INFO    : Bus 315	: V=1.02499127, theta=-15.0839442 -> V=1.015872, theta=0.0
% INFO    : Bus 316	: V=1.04044066, theta=-16.0196539 -> V=0.976703, theta=0.0
% INFO    : Bus 317	: V=1.00378254, theta=-20.73961 -> V=1.0000025, theta=0.0
% INFO    : Bus 318	: V=1.04563506, theta=-14.5329591 -> V=1.015872, theta=0.0
% INFO    : Bus 319	: V=0.995061092, theta=-31.6204241 -> V=1.015872, theta=0.0
% INFO    : Bus 2630	: V=0.994147092, theta=-31.7111595 -> V=1.015872, theta=0.0
% INFO    : Bus 2631	: V=0.99337701, theta=-31.6377505 -> V=1.015872, theta=0.0
% INFO    : Bus 320	: V=1.04814933, theta=-10.4229182 -> V=1.04967, theta=0.0
% INFO    : Bus 321	: V=1.05175222, theta=-7.67253232 -> V=1.05263, theta=0.0
% INFO    : Bus 322	: V=1.06728829, theta=-10.757927 -> V=1.0000005, theta=0.0
% INFO    : Bus 323	: V=1.08587171, theta=-3.8869832 -> V=1.05263, theta=0.0
% INFO    : Bus 324	: V=1.07470194, theta=-22.1116759 -> V=1.044445, theta=0.0
% INFO    : Bus 2632	: V=1.03482905, theta=-21.1245137 -> V=1.044445, theta=0.0
% INFO    : Bus 325	: V=1.06790766, theta=-14.7734596 -> V=1.0377785, theta=0.0
% INFO    : Bus 2633	: V=1.06794854, theta=-14.7588162 -> V=1.0377785, theta=0.0
% INFO    : Bus 326	: V=1.03683656, theta=-18.5852417 -> V=1.0000025, theta=0.0
% INFO    : Bus 2634	: V=1.03869776, theta=-18.487083 -> V=1.0000025, theta=0.0
% INFO    : Bus 327	: V=0.997866468, theta=-32.3238568 -> V=1.015872, theta=0.0
% INFO    : Bus 328	: V=1.00731761, theta=-28.7572216 -> V=1.015872, theta=0.0
% INFO    : Bus 329	: V=1.04222449, theta=-18.0005769 -> V=1.015872, theta=0.0
% INFO    : Bus 2635	: V=1.04392845, theta=-17.917461 -> V=1.015872, theta=0.0
% INFO    : Bus 330	: V=1.04403982, theta=-14.5789922 -> V=1.016152, theta=0.0
% INFO    : Bus 331	: V=1.02087775, theta=-25.2199752 -> V=1.015872, theta=0.0
% INFO    : Bus 2636	: V=1.02060293, theta=-25.2690409 -> V=1.015872, theta=0.0
% INFO    : Bus 332	: V=1.06137441, theta=-20.10949 -> V=1.044445, theta=0.0
% INFO    : Bus 2637	: V=1.06087732, theta=-20.1307624 -> V=1.044445, theta=0.0
% INFO    : Bus 333	: V=1.05412038, theta=-17.1218381 -> V=1.044445, theta=0.0
% INFO    : Bus 2638	: V=1.04791546, theta=-18.3582594 -> V=1.044445, theta=0.0
% INFO    : Bus 334	: V=1.05707084, theta=-21.4936354 -> V=1.044445, theta=0.0
% INFO    : Bus 2639	: V=1.05779221, theta=-21.4390024 -> V=1.044445, theta=0.0
% INFO    : Bus 335	: V=0.978399804, theta=-13.6170675 -> V=1.0, theta=0.0
% INFO    : Bus 336	: V=1.04420119, theta=-16.8723491 -> V=1.0233335, theta=0.0
% INFO    : Bus 337	: V=1.00924401, theta=-20.3413497 -> V=1.0000025, theta=0.0
% INFO    : Bus 338	: V=1.11549309, theta=3.58461368 -> V=1.057895, theta=0.0
% INFO    : Bus 339	: V=1.10135316, theta=0.550558235 -> V=1.05837, theta=0.0
% INFO    : Bus 340	: V=1.11527199, theta=5.12722992 -> V=1.057895, theta=0.0
% INFO    : Bus 341	: V=1.11483423, theta=5.18977628 -> V=1.057935, theta=0.0
% INFO    : Bus 342	: V=1.05036883, theta=-20.5864559 -> V=1.044445, theta=0.0
% INFO    : Bus 343	: V=1.03770076, theta=-14.200197 -> V=1.015872, theta=0.0
% INFO    : Bus 344	: V=1.04191674, theta=-14.8495835 -> V=1.015872, theta=0.0
% INFO    : Bus 345	: V=1.00673911, theta=-32.423318 -> V=1.015872, theta=0.0
% INFO    : Bus 346	: V=1.04448239, theta=-13.9931666 -> V=1.015872, theta=0.0
% INFO    : Bus 348	: V=1.0520999, theta=-12.1534955 -> V=1.044445, theta=0.0
% INFO    : Bus 2641	: V=1.05304462, theta=-12.6347362 -> V=1.044445, theta=0.0
% INFO    : Bus 349	: V=1.06498802, theta=-12.1506664 -> V=1.05263, theta=0.0
% INFO    : Bus 350	: V=1.04563705, theta=-8.81905809 -> V=1.0111115, theta=0.0
% INFO    : Bus 351	: V=1.02496808, theta=-16.150986 -> V=0.999999, theta=0.0
% INFO    : Bus 352	: V=1.07232871, theta=-13.019409 -> V=1.05263, theta=0.0
% INFO    : Bus 353	: V=0.9753215, theta=-20.0705703 -> V=0.999999, theta=0.0
% INFO    : Bus 354	: V=1.00596549, theta=-27.9946693 -> V=1.0000025, theta=0.0
% INFO    : Bus 356	: V=1.0657983, theta=-19.4255969 -> V=1.044445, theta=0.0
% INFO    : Bus 2642	: V=1.07500433, theta=-19.7083604 -> V=1.044445, theta=0.0
% INFO    : Bus 2643	: V=1.07435482, theta=-19.601173 -> V=1.044445, theta=0.0
% INFO    : Bus 357	: V=1.07126884, theta=-14.2582492 -> V=1.05263, theta=0.0
% INFO    : Bus 2645	: V=1.0712469, theta=-14.2973692 -> V=1.05263, theta=0.0
% INFO    : Bus 358	: V=1.05026858, theta=-11.899369 -> V=1.0088895, theta=0.0
% INFO    : Bus 359	: V=1.07077406, theta=-10.5323368 -> V=1.05263, theta=0.0
% INFO    : Bus 360	: V=1.02091953, theta=-19.552378 -> V=1.015872, theta=0.0
% INFO    : Bus 361	: V=1.05951996, theta=-18.1566804 -> V=1.04222, theta=0.0
% INFO    : Bus 362	: V=1.04532846, theta=-8.58758847 -> V=1.0111115, theta=0.0
% INFO    : Bus 363	: V=1.03451573, theta=-11.8577976 -> V=0.999999, theta=0.0
% INFO    : Bus 364	: V=1.07972568, theta=-5.10032397 -> V=1.05263, theta=0.0
% INFO    : Bus 365	: V=1.0691399, theta=-11.0908002 -> V=1.04222, theta=0.0
% INFO    : Bus 366	: V=1.08077975, theta=-7.95583314 -> V=1.051315, theta=0.0
% INFO    : Bus 2646	: V=1.08080083, theta=-7.95265582 -> V=1.051315, theta=0.0
% INFO    : Bus 367	: V=0.995, theta=-14.6591414 -> V=1.0, theta=0.0
% INFO    : Bus 368	: V=1.02071727, theta=-14.920379 -> V=1.0377785, theta=0.0
% INFO    : Bus 369	: V=1.04830415, theta=-15.1615982 -> V=1.0377785, theta=0.0
% INFO    : Bus 370	: V=1.0315643, theta=-15.4362728 -> V=0.999999, theta=0.0
% INFO    : Bus 371	: V=1.04, theta=-10.5384016 -> V=0.999999, theta=0.0
% INFO    : Bus 372	: V=1.08615527, theta=-11.3637582 -> V=1.051315, theta=0.0
% INFO    : Bus 373	: V=1.06743192, theta=-9.276543 -> V=1.0413985, theta=0.0
% INFO    : Bus 374	: V=1.02696294, theta=-14.4052411 -> V=0.999999, theta=0.0
% INFO    : Bus 375	: V=1.02604902, theta=-15.9479226 -> V=0.999999, theta=0.0
% INFO    : Bus 376	: V=1.07196363, theta=-12.1816528 -> V=1.044445, theta=0.0
% INFO    : Bus 377	: V=1.0485378, theta=-20.6681083 -> V=1.044445, theta=0.0
% INFO    : Bus 2647	: V=1.04843411, theta=-20.7329651 -> V=1.044445, theta=0.0
% INFO    : Bus 378	: V=1.01778444, theta=-14.91924 -> V=0.999999, theta=0.0
% INFO    : Bus 379	: V=1.08566466, theta=-8.58749421 -> V=1.0, theta=0.0
% INFO    : Bus 380	: V=1.03363595, theta=-9.91083967 -> V=1.003139, theta=0.0
% INFO    : Bus 381	: V=1.07744467, theta=-7.89371394 -> V=1.0111115, theta=0.0
% INFO    : Bus 382	: V=1.08172399, theta=-4.76935454 -> V=1.05263, theta=0.0
% INFO    : Bus 383	: V=1.01653393, theta=-14.4392725 -> V=0.999999, theta=0.0
% INFO    : Bus 384	: V=1.04343971, theta=-10.1875761 -> V=1.045215, theta=0.0
% INFO    : Bus 2648	: V=1.05628308, theta=-9.38051645 -> V=1.045215, theta=0.0
% INFO    : Bus 385	: V=1.00221452, theta=-21.7526112 -> V=1.0233335, theta=0.0
% INFO    : Bus 386	: V=1.06214839, theta=-20.4868563 -> V=1.044445, theta=0.0
% INFO    : Bus 2649	: V=1.05686247, theta=-19.9843355 -> V=1.044445, theta=0.0
% INFO    : Bus 387	: V=1.04044283, theta=-13.1227504 -> V=1.0111115, theta=0.0
% INFO    : Bus 388	: V=1.05475479, theta=-14.5912784 -> V=1.04222, theta=0.0
% INFO    : Bus 2650	: V=1.05476679, theta=-14.5903462 -> V=1.04222, theta=0.0
% INFO    : Bus 389	: V=1.0548406, theta=-18.7861615 -> V=1.044445, theta=0.0
% INFO    : Bus 391	: V=1.0537741, theta=-15.5509536 -> V=1.044445, theta=0.0
% INFO    : Bus 392	: V=1.06601347, theta=-12.8724113 -> V=1.05263, theta=0.0
% INFO    : Bus 2651	: V=1.06659474, theta=-12.7630958 -> V=1.05263, theta=0.0
% INFO    : Bus 2652	: V=1.08083873, theta=-9.81996968 -> V=1.05263, theta=0.0
% INFO    : Bus 393	: V=1.03011217, theta=-10.5498654 -> V=1.002029, theta=0.0
% INFO    : Bus 394	: V=1.06630427, theta=-12.8177421 -> V=1.05263, theta=0.0
% INFO    : Bus 395	: V=1.05843088, theta=-18.7814896 -> V=1.04222, theta=0.0
% INFO    : Bus 396	: V=1.08221863, theta=-8.29175898 -> V=1.05263, theta=0.0
% INFO    : Bus 397	: V=1.06159607, theta=-20.730129 -> V=1.044445, theta=0.0
% INFO    : Bus 2653	: V=1.04678078, theta=-20.9011391 -> V=1.044445, theta=0.0
% INFO    : Bus 398	: V=1.06892035, theta=-8.37108059 -> V=1.05263, theta=0.0
% INFO    : Bus 399	: V=0.983991435, theta=-15.7312645 -> V=1.015872, theta=0.0
% INFO    : Bus 400	: V=1.09344699, theta=-8.27960691 -> V=1.051315, theta=0.0
% INFO    : Bus 2976	: V=1.09335058, theta=-8.24586204 -> V=1.051315, theta=0.0
% INFO    : Bus 401	: V=1.09342466, theta=-8.24598434 -> V=1.051315, theta=0.0
% INFO    : Bus 2654	: V=1.09340932, theta=-8.24562923 -> V=1.051315, theta=0.0
% INFO    : Bus 402	: V=1.05354695, theta=-19.5709483 -> V=1.04222, theta=0.0
% INFO    : Bus 403	: V=1.11549548, theta=4.25103974 -> V=1.05823, theta=0.0
% INFO    : Bus 404	: V=1.11429695, theta=3.93755914 -> V=1.058895, theta=0.0
% INFO    : Bus 405	: V=1.08342599, theta=-4.41240297 -> V=0.9888895, theta=0.0
% INFO    : Bus 406	: V=1.00020427, theta=-26.0229084 -> V=1.015872, theta=0.0
% INFO    : Bus 408	: V=1.05803764, theta=-18.0755835 -> V=1.044445, theta=0.0
% INFO    : Bus 409	: V=1.06283934, theta=-13.3730318 -> V=1.05263, theta=0.0
% INFO    : Bus 410	: V=1.06314247, theta=-12.4703796 -> V=1.048525, theta=0.0
% INFO    : Bus 411	: V=1.07108876, theta=-0.708482323 -> V=1.051315, theta=0.0
% INFO    : Bus 2655	: V=1.07111639, theta=-0.68380987 -> V=1.051315, theta=0.0
% INFO    : Bus 412	: V=1.03171862, theta=-10.6658371 -> V=0.999999, theta=0.0
% INFO    : Bus 2656	: V=1.02000601, theta=-17.8067519 -> V=0.999999, theta=0.0
% INFO    : Bus 413	: V=1.04106585, theta=-13.9190731 -> V=1.0118215, theta=0.0
% INFO    : Bus 414	: V=1.03607851, theta=-10.9708559 -> V=0.999999, theta=0.0
% INFO    : Bus 415	: V=1.07162914, theta=-12.440512 -> V=1.044445, theta=0.0
% INFO    : Bus 416	: V=1.05836924, theta=-12.2842821 -> V=0.9888895, theta=0.0
% INFO    : Bus 2657	: V=1.05864494, theta=-12.2688509 -> V=0.9888895, theta=0.0
% INFO    : Bus 417	: V=1.00228462, theta=-16.5034218 -> V=0.999999, theta=0.0
% INFO    : Bus 418	: V=1.061, theta=-9.8663421 -> V=1.0, theta=0.0
% INFO    : Bus 2658	: V=1.061, theta=-9.8663421 -> V=1.0, theta=0.0
% INFO    : Bus 419	: V=1.0598119, theta=-11.0252336 -> V=1.05263, theta=0.0
% INFO    : Bus 420	: V=1.03169191, theta=-12.2639508 -> V=1.015872, theta=0.0
% INFO    : Bus 421	: V=1.06015285, theta=-13.7608579 -> V=1.04498, theta=0.0
% INFO    : Bus 422	: V=1.03447186, theta=-13.8726653 -> V=1.015872, theta=0.0
% INFO    : Bus 423	: V=1.04846833, theta=-20.7273577 -> V=1.044445, theta=0.0
% INFO    : Bus 424	: V=1.06632955, theta=-11.4211403 -> V=1.003335, theta=0.0
% INFO    : Bus 425	: V=1.01273227, theta=-13.710328 -> V=0.999999, theta=0.0
% INFO    : Bus 426	: V=0.987478842, theta=-21.8808354 -> V=1.0000025, theta=0.0
% INFO    : Bus 427	: V=1.03032331, theta=-11.2015845 -> V=1.015872, theta=0.0
% INFO    : Bus 428	: V=1.06347168, theta=-21.9386957 -> V=1.043175, theta=0.0
% INFO    : Bus 429	: V=1.06310301, theta=-14.6428291 -> V=1.0380885, theta=0.0
% INFO    : Bus 430	: V=1.0475188, theta=-17.3348155 -> V=1.044445, theta=0.0
% INFO    : Bus 431	: V=1.00584162, theta=-14.5540224 -> V=1.0111115, theta=0.0
% INFO    : Bus 432	: V=1.02652521, theta=-15.252076 -> V=1.015872, theta=0.0
% INFO    : Bus 433	: V=1.07195956, theta=-30.7769433 -> V=1.04222, theta=0.0
% INFO    : Bus 434	: V=1.07039016, theta=-15.1885709 -> V=1.04222, theta=0.0
% INFO    : Bus 435	: V=1.04705179, theta=-18.569678 -> V=1.0, theta=0.0
% INFO    : Bus 436	: V=1.0571762, theta=-9.95106659 -> V=1.0111115, theta=0.0
% INFO    : Bus 437	: V=1.04169924, theta=-11.1052425 -> V=1.0111115, theta=0.0
% INFO    : Bus 438	: V=0.997733999, theta=-32.2860774 -> V=1.015872, theta=0.0
% INFO    : Bus 439	: V=1.05742867, theta=-21.4528823 -> V=1.044445, theta=0.0
% INFO    : Bus 440	: V=1.05423101, theta=-18.8129728 -> V=1.044445, theta=0.0
% INFO    : Bus 2660	: V=1.05418583, theta=-18.8339754 -> V=1.044445, theta=0.0
% INFO    : Bus 441	: V=1.06788586, theta=-14.3617516 -> V=1.044445, theta=0.0
% INFO    : Bus 442	: V=0.93595053, theta=-9.20031787 -> V=0.9444445, theta=0.0
% INFO    : Bus 443	: V=1.06084142, theta=-12.002971 -> V=0.9888895, theta=0.0
% INFO    : Bus 444	: V=1.05825944, theta=-18.9017103 -> V=1.043095, theta=0.0
% INFO    : Bus 445	: V=1.07074545, theta=-15.0217844 -> V=1.04222, theta=0.0
% INFO    : Bus 2661	: V=1.07059418, theta=-14.9863307 -> V=1.04222, theta=0.0
% INFO    : Bus 2662	: V=1.07243424, theta=-15.8190845 -> V=1.04222, theta=0.0
% INFO    : Bus 446	: V=1.08527906, theta=-15.1693596 -> V=1.051315, theta=0.0
% INFO    : Bus 447	: V=0.999110784, theta=-21.5780693 -> V=1.0000025, theta=0.0
% INFO    : Bus 448	: V=1.06533117, theta=-8.58121091 -> V=1.0111115, theta=0.0
% INFO    : Bus 449	: V=1.06124791, theta=-20.8429095 -> V=1.044445, theta=0.0
% INFO    : Bus 2663	: V=1.04804997, theta=-20.7168413 -> V=1.044445, theta=0.0
% INFO    : Bus 450	: V=1.07549803, theta=-21.8968246 -> V=1.044445, theta=0.0
% INFO    : Bus 2990	: V=1.07457618, theta=-21.6435102 -> V=1.044445, theta=0.0
% INFO    : Bus 451	: V=1.04346405, theta=-13.534546 -> V=1.0111115, theta=0.0
% INFO    : Bus 2664	: V=1.04604655, theta=-14.109847 -> V=1.0111115, theta=0.0
% INFO    : Bus 452	: V=1.0614094, theta=-11.4918919 -> V=1.05263, theta=0.0
% INFO    : Bus 453	: V=1.07226012, theta=-16.002415 -> V=1.04222, theta=0.0
% INFO    : Bus 2946	: V=1.07042036, theta=-15.2553787 -> V=1.04222, theta=0.0
% INFO    : Bus 454	: V=1.08517838, theta=-15.2368592 -> V=1.051315, theta=0.0
% INFO    : Bus 455	: V=1.05259835, theta=-19.4787356 -> V=1.044445, theta=0.0
% INFO    : Bus 456	: V=1.05200578, theta=-19.5244294 -> V=1.044445, theta=0.0
% INFO    : Bus 457	: V=1.04640922, theta=-16.9254976 -> V=1.0389685, theta=0.0
% INFO    : Bus 458	: V=1.02550703, theta=-23.4086243 -> V=1.015872, theta=0.0
% INFO    : Bus 459	: V=1.06558465, theta=-20.2942012 -> V=1.04222, theta=0.0
% INFO    : Bus 460	: V=1.06572482, theta=-10.2203584 -> V=1.04643, theta=0.0
% INFO    : Bus 461	: V=1.04779847, theta=-14.7975827 -> V=1.044445, theta=0.0
% INFO    : Bus 462	: V=1.01843788, theta=-19.1511438 -> V=1.0000025, theta=0.0
% INFO    : Bus 463	: V=1.00973573, theta=-12.3077031 -> V=1.015872, theta=0.0
% INFO    : Bus 464	: V=1.1031158, theta=0.601986418 -> V=1.051315, theta=0.0
% INFO    : Bus 465	: V=1.00661136, theta=-16.6886089 -> V=0.999999, theta=0.0
% INFO    : Bus 466	: V=1.04385006, theta=-9.51086993 -> V=1.0111115, theta=0.0
% INFO    : Bus 467	: V=1.06435884, theta=-22.6793902 -> V=1.04387, theta=0.0
% INFO    : Bus 468	: V=1.03508638, theta=-14.786676 -> V=1.015872, theta=0.0
% INFO    : Bus 469	: V=1.03591871, theta=-10.7418864 -> V=0.999999, theta=0.0
% INFO    : Bus 2665	: V=1.03573663, theta=-8.84335202 -> V=0.999999, theta=0.0
% INFO    : Bus 470	: V=1.06245142, theta=-9.00422558 -> V=1.0111115, theta=0.0
% INFO    : Bus 2666	: V=1.06010149, theta=-9.6727172 -> V=1.0111115, theta=0.0
% INFO    : Bus 2667	: V=1.06263043, theta=-8.89504528 -> V=1.0111115, theta=0.0
% INFO    : Bus 471	: V=1.07552353, theta=-5.79843097 -> V=1.05263, theta=0.0
% INFO    : Bus 472	: V=1.03115891, theta=-16.1472593 -> V=1.0377785, theta=0.0
% INFO    : Bus 473	: V=0.987959417, theta=-19.9728226 -> V=0.999999, theta=0.0
% INFO    : Bus 474	: V=1.0341662, theta=-17.0954053 -> V=1.0377785, theta=0.0
% INFO    : Bus 475	: V=1.00321071, theta=-19.0766267 -> V=1.0, theta=0.0
% INFO    : Bus 476	: V=1.02676906, theta=-10.9333586 -> V=0.999999, theta=0.0
% INFO    : Bus 2668	: V=1.0160154, theta=-12.0153885 -> V=0.999999, theta=0.0
% INFO    : Bus 477	: V=1.06496209, theta=-10.967558 -> V=1.0111115, theta=0.0
% INFO    : Bus 478	: V=1.02975513, theta=-12.5762433 -> V=1.015872, theta=0.0
% INFO    : Bus 480	: V=1.05444705, theta=-11.5842408 -> V=1.0377785, theta=0.0
% INFO    : Bus 481	: V=1.08730107, theta=-10.2051606 -> V=1.05263, theta=0.0
% INFO    : Bus 482	: V=0.993667141, theta=-15.3492338 -> V=1.015872, theta=0.0
% INFO    : Bus 483	: V=1.04695581, theta=-20.8853986 -> V=1.044445, theta=0.0
% INFO    : Bus 2669	: V=1.06135667, theta=-20.7920975 -> V=1.044445, theta=0.0
% INFO    : Bus 484	: V=1.07788376, theta=-6.66168739 -> V=1.05263, theta=0.0
% INFO    : Bus 2670	: V=1.0772848, theta=-6.69802841 -> V=1.05263, theta=0.0
% INFO    : Bus 485	: V=1.04867557, theta=-20.9474699 -> V=1.044445, theta=0.0
% INFO    : Bus 2671	: V=1.06289016, theta=-20.0279705 -> V=1.044445, theta=0.0
% INFO    : Bus 486	: V=1.06521962, theta=-7.40369903 -> V=1.04222, theta=0.0
% INFO    : Bus 487	: V=1.06393409, theta=-12.1845115 -> V=0.9888895, theta=0.0
% INFO    : Bus 488	: V=1.05388746, theta=-10.2830295 -> V=1.0111115, theta=0.0
% INFO    : Bus 489	: V=1.055, theta=-13.9849901 -> V=1.0033625, theta=0.0
% INFO    : Bus 490	: V=1.01484307, theta=-16.7488054 -> V=1.0078225, theta=0.0
% INFO    : Bus 491	: V=1.05461532, theta=-12.7098856 -> V=1.044445, theta=0.0
% INFO    : Bus 492	: V=1.04657503, theta=-8.36108008 -> V=1.04222, theta=0.0
% INFO    : Bus 493	: V=1.10386831, theta=0.840312967 -> V=1.05263, theta=0.0
% INFO    : Bus 2672	: V=1.10388443, theta=0.822687131 -> V=1.05263, theta=0.0
% INFO    : Bus 2673	: V=1.10368828, theta=0.822895425 -> V=1.05263, theta=0.0
% INFO    : Bus 2674	: V=1.10369136, theta=0.825526797 -> V=1.05263, theta=0.0
% INFO    : Bus 494	: V=1.00752855, theta=-11.7588324 -> V=1.015872, theta=0.0
% INFO    : Bus 495	: V=1.04491801, theta=-13.8850072 -> V=1.0111115, theta=0.0
% INFO    : Bus 496	: V=1.00962959, theta=-14.488609 -> V=0.999999, theta=0.0
% INFO    : Bus 497	: V=1.04379403, theta=-16.9727051 -> V=1.0233335, theta=0.0
% INFO    : Bus 498	: V=1.01459275, theta=-19.5412318 -> V=1.0000025, theta=0.0
% INFO    : Bus 499	: V=1.08488865, theta=-17.1380314 -> V=1.0287175, theta=0.0
% INFO    : Bus 500	: V=0.973841274, theta=-12.2321638 -> V=0.9444445, theta=0.0
% INFO    : Bus 2675	: V=0.973907958, theta=-12.2415034 -> V=0.9444445, theta=0.0
% INFO    : Bus 501	: V=1.0287478, theta=-13.2929308 -> V=1.015872, theta=0.0
% INFO    : Bus 502	: V=1.04865075, theta=-13.9384764 -> V=1.015872, theta=0.0
% INFO    : Bus 503	: V=1.06693402, theta=-11.3164153 -> V=1.04222, theta=0.0
% INFO    : Bus 504	: V=0.954337767, theta=-9.23086724 -> V=0.9445145, theta=0.0
% INFO    : Bus 505	: V=1.06336087, theta=-10.4434675 -> V=1.044445, theta=0.0
% INFO    : Bus 506	: V=1.06809179, theta=-5.1973179 -> V=1.05263, theta=0.0
% INFO    : Bus 507	: V=1.05739705, theta=-11.3282008 -> V=0.9888895, theta=0.0
% INFO    : Bus 508	: V=1.06772615, theta=-8.7403944 -> V=1.04222, theta=0.0
% INFO    : Bus 509	: V=1.01543706, theta=-12.9877525 -> V=0.999999, theta=0.0
% INFO    : Bus 510	: V=1.05728068, theta=-14.1057914 -> V=1.0377785, theta=0.0
% INFO    : Bus 511	: V=1.0849693, theta=-3.17061338 -> V=1.0410135, theta=0.0
% INFO    : Bus 512	: V=1.05935476, theta=-11.7320632 -> V=1.0111115, theta=0.0
% INFO    : Bus 513	: V=0.980088395, theta=-16.9727097 -> V=1.0, theta=0.0
% INFO    : Bus 514	: V=1.04379429, theta=-16.9727097 -> V=1.0233335, theta=0.0
% INFO    : Bus 515	: V=1.0084536, theta=-16.4236379 -> V=0.999999, theta=0.0
% INFO    : Bus 516	: V=1.05477706, theta=-14.5881054 -> V=1.04222, theta=0.0
% INFO    : Bus 517	: V=1.06064095, theta=-10.6785991 -> V=0.9991935, theta=0.0
% INFO    : Bus 518	: V=1.08147134, theta=-12.7360416 -> V=1.033334, theta=0.0
% INFO    : Bus 2676	: V=1.08052193, theta=-12.876817 -> V=1.033334, theta=0.0
% INFO    : Bus 519	: V=1.01, theta=-29.0081815 -> V=1.022012, theta=0.0
% INFO    : Bus 520	: V=1.07324331, theta=-22.2043747 -> V=1.044445, theta=0.0
% INFO    : Bus 521	: V=1.02999221, theta=-12.5796563 -> V=1.015872, theta=0.0
% INFO    : Bus 522	: V=1.0502138, theta=-20.708736 -> V=1.044445, theta=0.0
% INFO    : Bus 523	: V=0.992540082, theta=-20.7507066 -> V=1.003504, theta=0.0
% INFO    : Bus 524	: V=1.05982075, theta=-12.241702 -> V=1.004445, theta=0.0
% INFO    : Bus 526	: V=1.03511944, theta=-14.7928313 -> V=1.015872, theta=0.0
% INFO    : Bus 527	: V=1.04652195, theta=-16.5061186 -> V=1.044445, theta=0.0
% INFO    : Bus 2677	: V=1.05511839, theta=-19.2591779 -> V=1.044445, theta=0.0
% INFO    : Bus 528	: V=1.02578684, theta=-15.8080231 -> V=1.000454, theta=0.0
% INFO    : Bus 529	: V=0.991429006, theta=-17.6653064 -> V=0.999999, theta=0.0
% INFO    : Bus 530	: V=1.00732113, theta=-12.6372449 -> V=1.015872, theta=0.0
% INFO    : Bus 531	: V=1.02641871, theta=-14.1897576 -> V=0.999999, theta=0.0
% INFO    : Bus 532	: V=1.0650373, theta=-18.7637542 -> V=1.044445, theta=0.0
% INFO    : Bus 533	: V=1.02234182, theta=-13.1390331 -> V=1.015872, theta=0.0
% INFO    : Bus 534	: V=1.00405492, theta=-19.9468451 -> V=0.999999, theta=0.0
% INFO    : Bus 535	: V=1.04463812, theta=-16.3219593 -> V=1.000764, theta=0.0
% INFO    : Bus 2678	: V=1.04463817, theta=-16.3209119 -> V=1.000764, theta=0.0
% INFO    : Bus 536	: V=1.03090486, theta=-16.0568532 -> V=0.999999, theta=0.0
% INFO    : Bus 537	: V=1.05937524, theta=-11.3869566 -> V=1.0111115, theta=0.0
% INFO    : Bus 538	: V=1.06633992, theta=-19.1650094 -> V=1.0, theta=0.0
% INFO    : Bus 539	: V=1.06642457, theta=-19.1452525 -> V=1.043375, theta=0.0
% INFO    : Bus 540	: V=1.04833372, theta=-15.2582171 -> V=1.021267, theta=0.0
% INFO    : Bus 541	: V=1.03962757, theta=-14.5014837 -> V=1.015872, theta=0.0
% INFO    : Bus 542	: V=1.019, theta=-19.277379 -> V=1.015872, theta=0.0
% INFO    : Bus 543	: V=1.03964459, theta=-17.6391875 -> V=1.0000025, theta=0.0
% INFO    : Bus 544	: V=1.06075449, theta=-20.8868726 -> V=1.04538, theta=0.0
% INFO    : Bus 545	: V=1.0849642, theta=-3.90825798 -> V=1.0432335, theta=0.0
% INFO    : Bus 546	: V=1.04676372, theta=-27.7529591 -> V=1.04222, theta=0.0
% INFO    : Bus 547	: V=1.08488194, theta=-3.91885959 -> V=1.0431885, theta=0.0
% INFO    : Bus 548	: V=0.9848262, theta=-19.7864008 -> V=0.999999, theta=0.0
% INFO    : Bus 549	: V=1.02, theta=-19.0426362 -> V=1.015872, theta=0.0
% INFO    : Bus 550	: V=1.01866996, theta=-12.4633607 -> V=1.015872, theta=0.0
% INFO    : Bus 551	: V=1.05211981, theta=-16.5710677 -> V=1.0385935, theta=0.0
% INFO    : Bus 552	: V=1.03011387, theta=-13.2330543 -> V=1.015872, theta=0.0
% INFO    : Bus 2679	: V=1.02723162, theta=-12.7848488 -> V=1.015872, theta=0.0
% INFO    : Bus 553	: V=1.05399849, theta=-7.77779169 -> V=1.04222, theta=0.0
% INFO    : Bus 554	: V=1.00375652, theta=-16.1509047 -> V=0.999999, theta=0.0
% INFO    : Bus 555	: V=1.07575012, theta=-8.39451633 -> V=1.0111115, theta=0.0
% INFO    : Bus 556	: V=1.06364656, theta=-13.9199025 -> V=1.0377785, theta=0.0
% INFO    : Bus 557	: V=1.01273984, theta=-12.0992064 -> V=1.0, theta=0.0
% INFO    : Bus 558	: V=1.0659196, theta=-11.7373464 -> V=1.04222, theta=0.0
% INFO    : Bus 559	: V=1.07558247, theta=-9.27821291 -> V=1.051315, theta=0.0
% INFO    : Bus 560	: V=1.03906498, theta=-13.3643532 -> V=0.9977785, theta=0.0
% INFO    : Bus 561	: V=1.03027584, theta=-17.3228796 -> V=1.044445, theta=0.0
% INFO    : Bus 562	: V=1.07367887, theta=-11.9057141 -> V=1.044445, theta=0.0
% INFO    : Bus 563	: V=1.01839669, theta=-11.676899 -> V=0.999999, theta=0.0
% INFO    : Bus 564	: V=1.03490937, theta=-12.8731222 -> V=1.015872, theta=0.0
% INFO    : Bus 565	: V=1.08050529, theta=-12.8170353 -> V=1.04222, theta=0.0
% INFO    : Bus 566	: V=1.03187605, theta=-12.1957464 -> V=1.0024765, theta=0.0
% INFO    : Bus 567	: V=1.06886066, theta=-10.666932 -> V=1.0266685, theta=0.0
% INFO    : Bus 568	: V=1.0590905, theta=-12.2114008 -> V=0.9888895, theta=0.0
% INFO    : Bus 569	: V=1.05943723, theta=-10.1819491 -> V=1.0111115, theta=0.0
% INFO    : Bus 570	: V=1.08241786, theta=-5.64718497 -> V=0.9894895, theta=0.0
% INFO    : Bus 571	: V=1.05840806, theta=-11.7679342 -> V=0.9888895, theta=0.0
% INFO    : Bus 572	: V=1.06242333, theta=-10.3210872 -> V=1.05263, theta=0.0
% INFO    : Bus 573	: V=0.995993984, theta=-2.4707232 -> V=0.975, theta=0.0
% INFO    : Bus 574	: V=1.03480039, theta=-10.6416122 -> V=1.0377785, theta=0.0
% INFO    : Bus 575	: V=1.04155565, theta=1.00327955 -> V=1.013331, theta=0.0
% INFO    : Bus 576	: V=0.996585516, theta=-19.5273316 -> V=1.015872, theta=0.0
% INFO    : Bus 577	: V=0.975583234, theta=-17.2706825 -> V=1.015872, theta=0.0
% INFO    : Bus 578	: V=1.06418117, theta=-13.0181817 -> V=1.015872, theta=0.0
% INFO    : Bus 579	: V=1.07804062, theta=-29.0506455 -> V=1.04222, theta=0.0
% INFO    : Bus 580	: V=1.07256687, theta=-14.4544569 -> V=1.04222, theta=0.0
% INFO    : Bus 581	: V=1.08725879, theta=-9.90576698 -> V=1.051315, theta=0.0
% INFO    : Bus 582	: V=0.957, theta=-0.474938706 -> V=1.0, theta=0.0
% INFO    : Bus 2680	: V=1.094, theta=0.797597537 -> V=1.0, theta=0.0
% INFO    : Bus 2977	: V=1.094, theta=0.878489956 -> V=1.0, theta=0.0
% INFO    : Bus 2978	: V=0.957, theta=-0.496771195 -> V=1.0, theta=0.0
% INFO    : Bus 583	: V=1.07574057, theta=-3.94328593 -> V=1.0222245, theta=0.0
% INFO    : Bus 2681	: V=1.07576692, theta=-3.96509377 -> V=1.0222245, theta=0.0
% INFO    : Bus 584	: V=1.0656106, theta=-24.6435746 -> V=1.04262, theta=0.0
% INFO    : Bus 586	: V=1.07822795, theta=-18.9397903 -> V=1.04251, theta=0.0
% INFO    : Bus 587	: V=1.08365937, theta=-15.6078985 -> V=1.051315, theta=0.0
% INFO    : Bus 588	: V=1.06431318, theta=-10.7113968 -> V=1.044445, theta=0.0
% INFO    : Bus 589	: V=1.07289219, theta=-4.54321171 -> V=1.05263, theta=0.0
% INFO    : Bus 590	: V=1.0211185, theta=-12.7214036 -> V=1.044445, theta=0.0
% INFO    : Bus 591	: V=0.980767827, theta=-26.9879695 -> V=1.006734, theta=0.0
% INFO    : Bus 592	: V=1.0553448, theta=-19.0744838 -> V=1.04222, theta=0.0
% INFO    : Bus 593	: V=1.05943666, theta=-12.2511974 -> V=0.9888895, theta=0.0
% INFO    : Bus 594	: V=1.02651756, theta=-28.5004585 -> V=1.015872, theta=0.0
% INFO    : Bus 595	: V=1.06473585, theta=-19.6051023 -> V=1.044445, theta=0.0
% INFO    : Bus 596	: V=1.06664133, theta=-15.2470143 -> V=1.04598, theta=0.0
% INFO    : Bus 597	: V=1.02848656, theta=-15.9946291 -> V=0.999999, theta=0.0
% INFO    : Bus 2682	: V=1.02806837, theta=-15.7287152 -> V=0.999999, theta=0.0
% INFO    : Bus 598	: V=1.07073687, theta=-6.93608068 -> V=0.9888895, theta=0.0
% INFO    : Bus 599	: V=1.031406, theta=-16.2811769 -> V=1.002789, theta=0.0
% INFO    : Bus 600	: V=1.06935542, theta=-14.0172308 -> V=1.04222, theta=0.0
% INFO    : Bus 601	: V=1.08026084, theta=-5.61248011 -> V=1.051315, theta=0.0
% INFO    : Bus 2683	: V=1.08026084, theta=-5.61248011 -> V=1.051315, theta=0.0
% INFO    : Bus 602	: V=1.08025981, theta=-5.61113553 -> V=1.051315, theta=0.0
% INFO    : Bus 2684	: V=1.08026084, theta=-5.61248011 -> V=1.051315, theta=0.0
% INFO    : Bus 603	: V=1.04320377, theta=-27.4733234 -> V=1.04222, theta=0.0
% INFO    : Bus 604	: V=1.027, theta=-12.2555558 -> V=0.999999, theta=0.0
% INFO    : Bus 605	: V=1.05932557, theta=-8.8819525 -> V=1.0111115, theta=0.0
% INFO    : Bus 606	: V=1.08099848, theta=-3.70240633 -> V=1.05263, theta=0.0
% INFO    : Bus 607	: V=1.01079979, theta=-14.7782521 -> V=0.999999, theta=0.0
% INFO    : Bus 608	: V=1.06516157, theta=-9.42637328 -> V=1.0288895, theta=0.0
% INFO    : Bus 609	: V=1.04268514, theta=0.549853391 -> V=1.013331, theta=0.0
% INFO    : Bus 610	: V=1.00401627, theta=-20.5982798 -> V=1.015872, theta=0.0
% INFO    : Bus 612	: V=1.07115743, theta=-9.62212662 -> V=1.04277, theta=0.0
% INFO    : Bus 613	: V=1.07724619, theta=-4.82205804 -> V=1.051315, theta=0.0
% INFO    : Bus 614	: V=1.06181334, theta=-20.3658267 -> V=1.044445, theta=0.0
% INFO    : Bus 2685	: V=1.05802315, theta=-20.5971747 -> V=1.044445, theta=0.0
% INFO    : Bus 615	: V=1.06900326, theta=-14.600306 -> V=1.045685, theta=0.0
% INFO    : Bus 616	: V=1.01931115, theta=-12.8167128 -> V=1.015872, theta=0.0
% INFO    : Bus 617	: V=1.05544456, theta=-9.14858935 -> V=1.044445, theta=0.0
% INFO    : Bus 618	: V=1.0077235, theta=-20.4058779 -> V=1.015872, theta=0.0
% INFO    : Bus 619	: V=1.01843856, theta=-29.0398089 -> V=1.015872, theta=0.0
% INFO    : Bus 620	: V=0.978407791, theta=-19.3343175 -> V=1.015488, theta=0.0
% INFO    : Bus 621	: V=1.03049181, theta=-19.0436124 -> V=1.0233335, theta=0.0
% INFO    : Bus 622	: V=0.997996317, theta=-19.0032711 -> V=0.999999, theta=0.0
% INFO    : Bus 2686	: V=0.997913581, theta=-19.5399879 -> V=0.999999, theta=0.0
% INFO    : Bus 623	: V=1.00707525, theta=-15.0465679 -> V=1.0111115, theta=0.0
% INFO    : Bus 624	: V=0.935690914, theta=-9.89443679 -> V=0.9444445, theta=0.0
% INFO    : Bus 625	: V=1.07248854, theta=-10.6228672 -> V=0.9888895, theta=0.0
% INFO    : Bus 2687	: V=1.07215108, theta=-10.6531017 -> V=0.9888895, theta=0.0
% INFO    : Bus 626	: V=1.05285165, theta=-11.574996 -> V=1.0377785, theta=0.0
% INFO    : Bus 627	: V=1.04572149, theta=-20.9980602 -> V=1.044445, theta=0.0
% INFO    : Bus 628	: V=1.02741666, theta=-25.5338732 -> V=1.015872, theta=0.0
% INFO    : Bus 629	: V=1.06342595, theta=-20.0695115 -> V=1.04222, theta=0.0
% INFO    : Bus 630	: V=0.99131347, theta=-30.7707752 -> V=1.0135285, theta=0.0
% INFO    : Bus 631	: V=1.063, theta=-12.5736349 -> V=1.04222, theta=0.0
% INFO    : Bus 632	: V=1.01839987, theta=-21.836101 -> V=1.0000025, theta=0.0
% INFO    : Bus 633	: V=1.02396395, theta=-19.7170459 -> V=1.015872, theta=0.0
% INFO    : Bus 634	: V=1.0574942, theta=-11.6651647 -> V=0.9888895, theta=0.0
% INFO    : Bus 635	: V=1.0334747, theta=-16.6244279 -> V=1.015872, theta=0.0
% INFO    : Bus 636	: V=1.06234342, theta=-11.8849229 -> V=0.9888895, theta=0.0
% INFO    : Bus 637	: V=1.05235821, theta=-12.4669986 -> V=1.0386035, theta=0.0
% INFO    : Bus 638	: V=1.02487942, theta=-17.622826 -> V=1.0377785, theta=0.0
% INFO    : Bus 639	: V=1.03849906, theta=-12.8886245 -> V=0.999999, theta=0.0
% INFO    : Bus 640	: V=1.05995824, theta=-9.32463886 -> V=1.0111115, theta=0.0
% INFO    : Bus 641	: V=1.023, theta=-11.9045935 -> V=1.015872, theta=0.0
% INFO    : Bus 642	: V=1.02583432, theta=-17.0852697 -> V=1.021212, theta=0.0
% INFO    : Bus 643	: V=1.02957967, theta=-20.4011652 -> V=1.015872, theta=0.0
% INFO    : Bus 644	: V=1.06968788, theta=-15.3114891 -> V=1.04222, theta=0.0
% INFO    : Bus 645	: V=1.10602587, theta=1.57504353 -> V=1.0554, theta=0.0
% INFO    : Bus 2688	: V=1.10602496, theta=1.57518171 -> V=1.0554, theta=0.0
% INFO    : Bus 646	: V=1.08429945, theta=-3.61187443 -> V=1.0425785, theta=0.0
% INFO    : Bus 2689	: V=1.08433499, theta=-3.60960494 -> V=1.0425785, theta=0.0
% INFO    : Bus 647	: V=1.03754468, theta=-14.1957002 -> V=1.015872, theta=0.0
% INFO    : Bus 648	: V=1.051, theta=-18.9853903 -> V=0.999999, theta=0.0
% INFO    : Bus 649	: V=1.04781541, theta=-20.7382039 -> V=1.044445, theta=0.0
% INFO    : Bus 650	: V=1.03677728, theta=-20.8664363 -> V=1.044445, theta=0.0
% INFO    : Bus 2690	: V=1.03677235, theta=-20.865865 -> V=1.044445, theta=0.0
% INFO    : Bus 2691	: V=1.03681422, theta=-20.8675485 -> V=1.044445, theta=0.0
% INFO    : Bus 2692	: V=1.0367999, theta=-20.8672554 -> V=1.044445, theta=0.0
% INFO    : Bus 651	: V=1.03681018, theta=-20.8609055 -> V=1.044445, theta=0.0
% INFO    : Bus 652	: V=1.05794361, theta=-11.5979279 -> V=1.015556, theta=0.0
% INFO    : Bus 653	: V=1.04029602, theta=-20.2030764 -> V=1.044445, theta=0.0
% INFO    : Bus 2693	: V=1.0405663, theta=-20.1868429 -> V=1.044445, theta=0.0
% INFO    : Bus 654	: V=1.06073168, theta=-15.8233765 -> V=1.04222, theta=0.0
% INFO    : Bus 655	: V=1.01704969, theta=-21.4090407 -> V=1.0000025, theta=0.0
% INFO    : Bus 656	: V=1.07057938, theta=-13.7196124 -> V=1.04222, theta=0.0
% INFO    : Bus 657	: V=1.02544641, theta=-12.9265508 -> V=1.044445, theta=0.0
% INFO    : Bus 658	: V=1.02904516, theta=-16.4716019 -> V=1.015872, theta=0.0
% INFO    : Bus 659	: V=1.01697147, theta=-14.975308 -> V=1.0377785, theta=0.0
% INFO    : Bus 2694	: V=1.01697565, theta=-14.9753332 -> V=1.0377785, theta=0.0
% INFO    : Bus 660	: V=1.07471801, theta=-8.18889931 -> V=1.05263, theta=0.0
% INFO    : Bus 2695	: V=1.07470115, theta=-8.18571579 -> V=1.05263, theta=0.0
% INFO    : Bus 661	: V=1.01701229, theta=-14.9755512 -> V=1.0377785, theta=0.0
% INFO    : Bus 662	: V=1.018, theta=-9.95523801 -> V=1.0, theta=0.0
% INFO    : Bus 2696	: V=1.018, theta=-9.80685461 -> V=1.0, theta=0.0
% INFO    : Bus 2697	: V=1.018, theta=-9.80495209 -> V=1.0, theta=0.0
% INFO    : Bus 663	: V=1.01699629, theta=-14.9582284 -> V=1.0377785, theta=0.0
% INFO    : Bus 2698	: V=1.01699529, theta=-14.9577183 -> V=1.0377785, theta=0.0
% INFO    : Bus 2699	: V=1.01699528, theta=-14.9577118 -> V=1.0377785, theta=0.0
% INFO    : Bus 664	: V=1.04480265, theta=-13.943199 -> V=1.015872, theta=0.0
% INFO    : Bus 2700	: V=1.02767539, theta=-13.7347531 -> V=1.015872, theta=0.0
% INFO    : Bus 665	: V=1.08030661, theta=-12.8943609 -> V=1.04222, theta=0.0
% INFO    : Bus 666	: V=0.981739603, theta=-18.5754094 -> V=0.999999, theta=0.0
% INFO    : Bus 667	: V=0.986664142, theta=-19.3530873 -> V=1.0040475, theta=0.0
% INFO    : Bus 668	: V=1.04719395, theta=-11.2360604 -> V=1.0111115, theta=0.0
% INFO    : Bus 669	: V=1.04029837, theta=-16.3150348 -> V=1.015872, theta=0.0
% INFO    : Bus 670	: V=1.08673639, theta=-2.69548029 -> V=1.05263, theta=0.0
% INFO    : Bus 2701	: V=1.08687401, theta=-2.69744423 -> V=1.05263, theta=0.0
% INFO    : Bus 2702	: V=1.08622791, theta=-5.51765406 -> V=1.05263, theta=0.0
% INFO    : Bus 2703	: V=1.08614625, theta=-5.51739778 -> V=1.05263, theta=0.0
% INFO    : Bus 671	: V=1.06738712, theta=-10.7591781 -> V=0.9888895, theta=0.0
% INFO    : Bus 672	: V=0.985582003, theta=-19.3257135 -> V=0.999999, theta=0.0
% INFO    : Bus 673	: V=1.06293717, theta=-20.0216939 -> V=1.044445, theta=0.0
% INFO    : Bus 674	: V=1.04143264, theta=-17.3508862 -> V=1.044005, theta=0.0
% INFO    : Bus 675	: V=1.05335417, theta=-21.2090854 -> V=1.044445, theta=0.0
% INFO    : Bus 676	: V=1.03621758, theta=-14.2627487 -> V=1.0114815, theta=0.0
% INFO    : Bus 677	: V=1.05070604, theta=-12.2687067 -> V=1.044445, theta=0.0
% INFO    : Bus 678	: V=1.03609719, theta=-19.9247878 -> V=1.0000025, theta=0.0
% INFO    : Bus 679	: V=1.04731872, theta=-16.6323903 -> V=1.044445, theta=0.0
% INFO    : Bus 680	: V=1.02215908, theta=-13.8490277 -> V=1.015872, theta=0.0
% INFO    : Bus 681	: V=1.07371826, theta=-22.1712837 -> V=1.044445, theta=0.0
% INFO    : Bus 2704	: V=1.07390883, theta=-22.1430567 -> V=1.044445, theta=0.0
% INFO    : Bus 682	: V=1.05050445, theta=-20.5959364 -> V=1.044445, theta=0.0
% INFO    : Bus 683	: V=1.02556268, theta=-11.2909226 -> V=1.0111115, theta=0.0
% INFO    : Bus 684	: V=1.06910421, theta=-20.1348739 -> V=1.044445, theta=0.0
% INFO    : Bus 685	: V=1.04232786, theta=-17.3938852 -> V=1.0000025, theta=0.0
% INFO    : Bus 686	: V=1.06603943, theta=-13.9848924 -> V=1.044445, theta=0.0
% INFO    : Bus 687	: V=1.07281356, theta=-6.7041672 -> V=0.9888895, theta=0.0
% INFO    : Bus 688	: V=1.03015121, theta=-15.3379748 -> V=1.0377785, theta=0.0
% INFO    : Bus 689	: V=1.06666856, theta=-12.8310471 -> V=1.05263, theta=0.0
% INFO    : Bus 690	: V=1.02510556, theta=-20.4156486 -> V=1.0000025, theta=0.0
% INFO    : Bus 691	: V=1.02195501, theta=-30.9022877 -> V=1.015872, theta=0.0
% INFO    : Bus 692	: V=1.04829686, theta=-25.3322803 -> V=1.04222, theta=0.0
% INFO    : Bus 693	: V=1.05430101, theta=-10.2578538 -> V=1.0111115, theta=0.0
% INFO    : Bus 694	: V=1.07406255, theta=-21.3151994 -> V=1.044445, theta=0.0
% INFO    : Bus 2705	: V=1.07545788, theta=-21.4602905 -> V=1.044445, theta=0.0
% INFO    : Bus 695	: V=1.0465363, theta=-12.2045253 -> V=1.0377785, theta=0.0
% INFO    : Bus 696	: V=1.02267073, theta=-19.8246547 -> V=1.0000025, theta=0.0
% INFO    : Bus 697	: V=1.009, theta=-25.8891371 -> V=1.017122, theta=0.0
% INFO    : Bus 698	: V=0.987469994, theta=-20.0214617 -> V=0.999999, theta=0.0
% INFO    : Bus 2706	: V=0.986876782, theta=-20.0488402 -> V=0.999999, theta=0.0
% INFO    : Bus 699	: V=0.982940766, theta=-34.2736105 -> V=1.015872, theta=0.0
% INFO    : Bus 700	: V=1.00527367, theta=-16.4592304 -> V=1.015872, theta=0.0
% INFO    : Bus 701	: V=1.02925168, theta=-11.9975894 -> V=0.999999, theta=0.0
% INFO    : Bus 702	: V=1.01543611, theta=-14.1338805 -> V=1.0108935, theta=0.0
% INFO    : Bus 703	: V=1.0342571, theta=-15.2640975 -> V=1.015872, theta=0.0
% INFO    : Bus 704	: V=1.04443751, theta=-16.5223332 -> V=1.000229, theta=0.0
% INFO    : Bus 705	: V=1.08729312, theta=-7.1159807 -> V=1.044445, theta=0.0
% INFO    : Bus 706	: V=1.03490839, theta=-12.8730924 -> V=1.015872, theta=0.0
% INFO    : Bus 707	: V=1.0707187, theta=-18.8148768 -> V=1.044445, theta=0.0
% INFO    : Bus 2707	: V=1.06585154, theta=-18.9711791 -> V=1.044445, theta=0.0
% INFO    : Bus 708	: V=1.06724508, theta=-19.6041256 -> V=1.044445, theta=0.0
% INFO    : Bus 709	: V=1.021, theta=-9.10766444 -> V=1.0, theta=0.0
% INFO    : Bus 2708	: V=1.021, theta=-9.39570867 -> V=1.0, theta=0.0
% INFO    : Bus 2709	: V=1.021, theta=-9.31811166 -> V=1.0, theta=0.0
% INFO    : Bus 2710	: V=1.021, theta=-9.71922146 -> V=1.0, theta=0.0
% INFO    : Bus 710	: V=1.02101529, theta=-10.9461324 -> V=1.0377785, theta=0.0
% INFO    : Bus 2711	: V=1.0210151, theta=-10.9457482 -> V=1.0377785, theta=0.0
% INFO    : Bus 2712	: V=1.02101454, theta=-10.9447062 -> V=1.0377785, theta=0.0
% INFO    : Bus 2713	: V=1.02101598, theta=-10.9477346 -> V=1.0377785, theta=0.0
% INFO    : Bus 711	: V=1.02101662, theta=-10.95385 -> V=1.0377785, theta=0.0
% INFO    : Bus 712	: V=1.01000618, theta=-15.3025985 -> V=0.999999, theta=0.0
% INFO    : Bus 713	: V=1.04555783, theta=-9.6769138 -> V=1.0111115, theta=0.0
% INFO    : Bus 714	: V=1.0128183, theta=-15.5534257 -> V=1.0016175, theta=0.0
% INFO    : Bus 715	: V=1.05989827, theta=-12.8837109 -> V=1.044445, theta=0.0
% INFO    : Bus 716	: V=1.03917171, theta=-11.5084036 -> V=1.015872, theta=0.0
% INFO    : Bus 717	: V=1.06044733, theta=-9.84706222 -> V=1.0377785, theta=0.0
% INFO    : Bus 718	: V=1.01999778, theta=-19.0478542 -> V=1.0158755, theta=0.0
% INFO    : Bus 2714	: V=1.0189596, theta=-19.2819944 -> V=1.0158755, theta=0.0
% INFO    : Bus 719	: V=1.02445957, theta=-23.9969583 -> V=1.015872, theta=0.0
% INFO    : Bus 720	: V=1.06495623, theta=-20.5520218 -> V=1.04222, theta=0.0
% INFO    : Bus 721	: V=1.01865185, theta=-19.2950622 -> V=1.015872, theta=0.0
% INFO    : Bus 722	: V=1.01828444, theta=-20.0789314 -> V=1.0000025, theta=0.0
% INFO    : Bus 723	: V=1.0125677, theta=-13.804245 -> V=1.015872, theta=0.0
% INFO    : Bus 724	: V=1.05756898, theta=-21.4376161 -> V=1.044445, theta=0.0
% INFO    : Bus 725	: V=1.05418395, theta=-9.17099589 -> V=1.044445, theta=0.0
% INFO    : Bus 726	: V=1.07203808, theta=-8.200319 -> V=1.051315, theta=0.0
% INFO    : Bus 728	: V=1.06037959, theta=-14.9769941 -> V=1.044445, theta=0.0
% INFO    : Bus 729	: V=1.06815635, theta=-11.9740561 -> V=1.05263, theta=0.0
% INFO    : Bus 730	: V=1.06747936, theta=-2.04391726 -> V=1.051315, theta=0.0
% INFO    : Bus 731	: V=1.03719066, theta=-11.0123894 -> V=0.999999, theta=0.0
% INFO    : Bus 2715	: V=1.03607851, theta=-10.9708559 -> V=0.999999, theta=0.0
% INFO    : Bus 2716	: V=1.03607851, theta=-10.9708559 -> V=0.999999, theta=0.0
% INFO    : Bus 732	: V=1.02825838, theta=-19.018807 -> V=1.015872, theta=0.0
% INFO    : Bus 733	: V=1.06234503, theta=-11.8787399 -> V=1.015556, theta=0.0
% INFO    : Bus 734	: V=1.07783029, theta=-8.4860777 -> V=1.05263, theta=0.0
% INFO    : Bus 735	: V=1.02094586, theta=-15.9404721 -> V=0.999999, theta=0.0
% INFO    : Bus 736	: V=1.02490033, theta=-17.6142128 -> V=0.999999, theta=0.0
% INFO    : Bus 738	: V=1.05347862, theta=-12.5528441 -> V=1.0111115, theta=0.0
% INFO    : Bus 2717	: V=1.04335475, theta=-13.4424316 -> V=1.0111115, theta=0.0
% INFO    : Bus 739	: V=1.07268147, theta=-10.1029661 -> V=1.05263, theta=0.0
% INFO    : Bus 740	: V=1.01524812, theta=-14.048683 -> V=0.999999, theta=0.0
% INFO    : Bus 741	: V=1.03, theta=-9.58712403 -> V=1.0, theta=0.0
% INFO    : Bus 2718	: V=1.03, theta=-10.1770024 -> V=1.0, theta=0.0
% INFO    : Bus 2719	: V=1.03, theta=-9.67434911 -> V=1.0, theta=0.0
% INFO    : Bus 2720	: V=1.03, theta=-9.59151666 -> V=1.0, theta=0.0
% INFO    : Bus 2721	: V=1.02986925, theta=-9.58250002 -> V=1.0, theta=0.0
% INFO    : Bus 742	: V=1.02973644, theta=-10.4788976 -> V=1.0377785, theta=0.0
% INFO    : Bus 2722	: V=1.02973641, theta=-10.4788528 -> V=1.0377785, theta=0.0
% INFO    : Bus 2723	: V=1.02973739, theta=-10.4880454 -> V=1.0377785, theta=0.0
% INFO    : Bus 2724	: V=1.02973688, theta=-10.4797424 -> V=1.0377785, theta=0.0
% INFO    : Bus 2725	: V=1.02973909, theta=-10.4848699 -> V=1.0377785, theta=0.0
% INFO    : Bus 2726	: V=1.02973505, theta=-10.4788078 -> V=1.0377785, theta=0.0
% INFO    : Bus 743	: V=1.02973678, theta=-10.4880453 -> V=1.0377785, theta=0.0
% INFO    : Bus 744	: V=1.048, theta=-5.2402268 -> V=1.0, theta=0.0
% INFO    : Bus 745	: V=0.984, theta=-13.8161746 -> V=0.999999, theta=0.0
% INFO    : Bus 2727	: V=0.991, theta=-13.3089956 -> V=0.999999, theta=0.0
% INFO    : Bus 746	: V=1.04659322, theta=-8.53324383 -> V=1.0111115, theta=0.0
% INFO    : Bus 747	: V=1.05905743, theta=-10.7207163 -> V=1.04222, theta=0.0
% INFO    : Bus 748	: V=1.03787141, theta=-16.2509435 -> V=1.044445, theta=0.0
% INFO    : Bus 749	: V=0.952004513, theta=-10.6939433 -> V=0.9444445, theta=0.0
% INFO    : Bus 750	: V=1.05718655, theta=-9.35117589 -> V=1.0111115, theta=0.0
% INFO    : Bus 751	: V=1.035, theta=-12.8392052 -> V=1.0158755, theta=0.0
% INFO    : Bus 752	: V=1.04586854, theta=-20.9864541 -> V=1.044445, theta=0.0
% INFO    : Bus 2728	: V=1.06100985, theta=-20.8699685 -> V=1.044445, theta=0.0
% INFO    : Bus 753	: V=1.01484278, theta=-16.7488032 -> V=1.0078225, theta=0.0
% INFO    : Bus 754	: V=1.05461502, theta=-12.7098816 -> V=1.044445, theta=0.0
% INFO    : Bus 755	: V=1.0621124, theta=-9.9785569 -> V=1.0377785, theta=0.0
% INFO    : Bus 756	: V=1.07313499, theta=-4.36748305 -> V=1.05263, theta=0.0
% INFO    : Bus 2729	: V=1.07335611, theta=-4.35223377 -> V=1.05263, theta=0.0
% INFO    : Bus 757	: V=1.06579467, theta=-10.2213952 -> V=1.046135, theta=0.0
% INFO    : Bus 758	: V=1.05523195, theta=-19.4886128 -> V=1.044445, theta=0.0
% INFO    : Bus 759	: V=1.01961176, theta=-16.9200797 -> V=1.015872, theta=0.0
% INFO    : Bus 760	: V=0.996412504, theta=-31.5128739 -> V=1.015872, theta=0.0
% INFO    : Bus 761	: V=1.02872479, theta=-13.2573096 -> V=0.999999, theta=0.0
% INFO    : Bus 762	: V=1.01574369, theta=-19.1027887 -> V=1.0000025, theta=0.0
% INFO    : Bus 763	: V=1.05211079, theta=-16.6423656 -> V=1.044775, theta=0.0
% INFO    : Bus 764	: V=1.00133698, theta=-18.9867364 -> V=1.0066725, theta=0.0
% INFO    : Bus 765	: V=1.0465271, theta=-18.7622242 -> V=1.044445, theta=0.0
% INFO    : Bus 766	: V=1.09772795, theta=-13.059105 -> V=1.016455, theta=0.0
% INFO    : Bus 767	: V=1.08142768, theta=-12.7272033 -> V=1.033334, theta=0.0
% INFO    : Bus 768	: V=1.02763168, theta=-11.1025843 -> V=1.0377785, theta=0.0
% INFO    : Bus 769	: V=1.06190591, theta=-10.29797 -> V=1.044445, theta=0.0
% INFO    : Bus 770	: V=1.06531423, theta=-12.0389217 -> V=1.04222, theta=0.0
% INFO    : Bus 771	: V=1.07128517, theta=-6.77558807 -> V=1.051315, theta=0.0
% INFO    : Bus 772	: V=0.995021613, theta=-29.8631389 -> V=1.015872, theta=0.0
% INFO    : Bus 2730	: V=0.995035354, theta=-29.8595962 -> V=1.015872, theta=0.0
% INFO    : Bus 2731	: V=0.994953229, theta=-29.8622681 -> V=1.015872, theta=0.0
% INFO    : Bus 773	: V=0.997718541, theta=-19.8754786 -> V=1.0000025, theta=0.0
% INFO    : Bus 774	: V=1.10256952, theta=-2.42056942 -> V=1.05263, theta=0.0
% INFO    : Bus 2732	: V=1.10256952, theta=-2.42056942 -> V=1.05263, theta=0.0
% INFO    : Bus 2733	: V=1.10257715, theta=-2.41890428 -> V=1.05263, theta=0.0
% INFO    : Bus 2734	: V=1.10298038, theta=-2.50513833 -> V=1.05263, theta=0.0
% INFO    : Bus 2735	: V=1.10258048, theta=-2.41806969 -> V=1.05263, theta=0.0
% INFO    : Bus 2736	: V=1.10256952, theta=-2.42056942 -> V=1.05263, theta=0.0
% INFO    : Bus 775	: V=1.05978266, theta=-9.11298419 -> V=1.0111115, theta=0.0
% INFO    : Bus 776	: V=1.02706425, theta=-12.9469752 -> V=1.003134, theta=0.0
% INFO    : Bus 777	: V=1.0759987, theta=-6.12818567 -> V=1.05263, theta=0.0
% INFO    : Bus 2737	: V=1.07540751, theta=-6.15844272 -> V=1.05263, theta=0.0
% INFO    : Bus 778	: V=1.05665059, theta=-13.0880045 -> V=1.044445, theta=0.0
% INFO    : Bus 779	: V=1.05357768, theta=-19.0902143 -> V=1.044445, theta=0.0
% INFO    : Bus 2738	: V=1.05349857, theta=-19.0115236 -> V=1.044445, theta=0.0
% INFO    : Bus 782	: V=1.04152745, theta=-11.3721968 -> V=1.015872, theta=0.0
% INFO    : Bus 783	: V=1.06541459, theta=-9.01154717 -> V=1.04222, theta=0.0
% INFO    : Bus 785	: V=1.05710907, theta=-14.0518971 -> V=1.0377785, theta=0.0
% INFO    : Bus 786	: V=1.06950253, theta=-11.1005788 -> V=1.05263, theta=0.0
% INFO    : Bus 787	: V=0.993070904, theta=-30.0321147 -> V=1.015872, theta=0.0
% INFO    : Bus 788	: V=1.05975697, theta=-10.7290981 -> V=1.0000005, theta=0.0
% INFO    : Bus 2739	: V=1.05841348, theta=-11.7453208 -> V=1.0000005, theta=0.0
% INFO    : Bus 789	: V=1.04085792, theta=-12.4399179 -> V=1.0377785, theta=0.0
% INFO    : Bus 790	: V=1.07223696, theta=-15.2686122 -> V=1.04222, theta=0.0
% INFO    : Bus 791	: V=1.04879671, theta=-20.6204791 -> V=1.044445, theta=0.0
% INFO    : Bus 792	: V=1.05601535, theta=-15.2981392 -> V=1.0377785, theta=0.0
% INFO    : Bus 793	: V=1.0107634, theta=-14.3931706 -> V=0.999999, theta=0.0
% INFO    : Bus 794	: V=1.00186758, theta=-12.2602457 -> V=1.0, theta=0.0
% INFO    : Bus 795	: V=0.979016848, theta=-19.5329186 -> V=1.0149295, theta=0.0
% INFO    : Bus 796	: V=1.05495486, theta=-14.8983351 -> V=1.04573, theta=0.0
% INFO    : Bus 797	: V=1.05714939, theta=-9.36093577 -> V=1.0111115, theta=0.0
% INFO    : Bus 2740	: V=1.05714671, theta=-9.36132881 -> V=1.0111115, theta=0.0
% INFO    : Bus 2741	: V=1.0571356, theta=-9.36340883 -> V=1.0111115, theta=0.0
% INFO    : Bus 798	: V=1.06871128, theta=-10.664607 -> V=1.0266685, theta=0.0
% INFO    : Bus 799	: V=1.0670185, theta=-10.6220237 -> V=1.022223, theta=0.0
% INFO    : Bus 800	: V=0.973947156, theta=-12.2321164 -> V=0.9444445, theta=0.0
% INFO    : Bus 801	: V=1.04313422, theta=-10.9397152 -> V=1.0111115, theta=0.0
% INFO    : Bus 802	: V=1.06942608, theta=-7.57470863 -> V=0.9888895, theta=0.0
% INFO    : Bus 2742	: V=1.08212562, theta=-5.65489729 -> V=0.9888895, theta=0.0
% INFO    : Bus 803	: V=1.07373063, theta=-11.8926502 -> V=1.044445, theta=0.0
% INFO    : Bus 804	: V=1.06607571, theta=-11.7018094 -> V=1.04222, theta=0.0
% INFO    : Bus 2743	: V=1.06373108, theta=-11.9155311 -> V=1.04222, theta=0.0
% INFO    : Bus 805	: V=1.03039801, theta=-18.1370565 -> V=1.015872, theta=0.0
% INFO    : Bus 806	: V=1.03305529, theta=-13.9214553 -> V=0.999999, theta=0.0
% INFO    : Bus 807	: V=1.05407994, theta=-10.6720212 -> V=1.0111115, theta=0.0
% INFO    : Bus 808	: V=1.06853161, theta=-8.43261511 -> V=1.05263, theta=0.0
% INFO    : Bus 809	: V=1.03092748, theta=-20.7450414 -> V=1.0000025, theta=0.0
% INFO    : Bus 810	: V=1.07954974, theta=-9.93752254 -> V=1.04496, theta=0.0
% INFO    : Bus 811	: V=1.072974, theta=-14.9824272 -> V=1.04222, theta=0.0
% INFO    : Bus 812	: V=1.0730953, theta=-6.68184704 -> V=1.0288895, theta=0.0
% INFO    : Bus 813	: V=1.03124345, theta=-15.4897619 -> V=0.999999, theta=0.0
% INFO    : Bus 2744	: V=1.0313685, theta=-15.4967047 -> V=0.999999, theta=0.0
% INFO    : Bus 2745	: V=1.0311209, theta=-15.5070728 -> V=0.999999, theta=0.0
% INFO    : Bus 814	: V=1.02046774, theta=-11.1395446 -> V=1.0377785, theta=0.0
% INFO    : Bus 2746	: V=1.01982395, theta=-11.1291208 -> V=1.0377785, theta=0.0
% INFO    : Bus 815	: V=1.06184277, theta=-20.1141011 -> V=1.044445, theta=0.0
% INFO    : Bus 816	: V=1.06302281, theta=-12.3366841 -> V=0.9888895, theta=0.0
% INFO    : Bus 2747	: V=1.06292553, theta=-12.3433994 -> V=0.9888895, theta=0.0
% INFO    : Bus 818	: V=1.05799748, theta=-21.3987274 -> V=1.044445, theta=0.0
% INFO    : Bus 819	: V=0.95139977, theta=-10.7868323 -> V=0.9444445, theta=0.0
% INFO    : Bus 820	: V=0.997421545, theta=-19.5024331 -> V=0.999999, theta=0.0
% INFO    : Bus 821	: V=0.994248986, theta=-11.6039827 -> V=1.0000015, theta=0.0
% INFO    : Bus 822	: V=1.08847701, theta=-3.41682825 -> V=1.044445, theta=0.0
% INFO    : Bus 2964	: V=1.08685396, theta=-6.67669068 -> V=1.044445, theta=0.0
% INFO    : Bus 823	: V=1.09097458, theta=-5.81689826 -> V=1.05263, theta=0.0
% INFO    : Bus 824	: V=1.08849293, theta=-3.39933771 -> V=1.044445, theta=0.0
% INFO    : Bus 2748	: V=1.08695588, theta=-6.62247421 -> V=1.044445, theta=0.0
% INFO    : Bus 825	: V=1.0910257, theta=-5.78933859 -> V=1.05263, theta=0.0
% INFO    : Bus 826	: V=1.0338138, theta=-13.4687246 -> V=1.015872, theta=0.0
% INFO    : Bus 827	: V=1.06487221, theta=-12.0761653 -> V=0.9888895, theta=0.0
% INFO    : Bus 828	: V=1.07404896, theta=-20.9258583 -> V=1.044445, theta=0.0
% INFO    : Bus 2749	: V=1.07294013, theta=-20.9593356 -> V=1.044445, theta=0.0
% INFO    : Bus 829	: V=1.04610191, theta=-10.9882223 -> V=1.0111115, theta=0.0
% INFO    : Bus 830	: V=1.02627117, theta=-11.3154304 -> V=1.0377785, theta=0.0
% INFO    : Bus 831	: V=1.07086873, theta=-12.8219026 -> V=1.05263, theta=0.0
% INFO    : Bus 832	: V=1.02722544, theta=-16.049352 -> V=1.0377785, theta=0.0
% INFO    : Bus 833	: V=1.06696723, theta=-8.5701944 -> V=1.0288895, theta=0.0
% INFO    : Bus 834	: V=1.06354913, theta=-10.9507252 -> V=0.9888895, theta=0.0
% INFO    : Bus 835	: V=0.920669448, theta=-17.4601418 -> V=0.9, theta=0.0
% INFO    : Bus 836	: V=1.05086566, theta=-17.4597654 -> V=1.046775, theta=0.0
% INFO    : Bus 837	: V=1.09108534, theta=-4.73301997 -> V=1.05263, theta=0.0
% INFO    : Bus 838	: V=1.06, theta=-9.23073007 -> V=1.0, theta=0.0
% INFO    : Bus 839	: V=1.04250229, theta=-11.2303232 -> V=1.04817, theta=0.0
% INFO    : Bus 840	: V=1.02422032, theta=-24.8925564 -> V=1.015872, theta=0.0
% INFO    : Bus 841	: V=1.06372092, theta=-20.8450267 -> V=1.04222, theta=0.0
% INFO    : Bus 842	: V=1.06446094, theta=-19.3143116 -> V=1.044445, theta=0.0
% INFO    : Bus 843	: V=1.08011576, theta=-9.79526533 -> V=1.0451, theta=0.0
% INFO    : Bus 2750	: V=1.08101249, theta=-9.51865839 -> V=1.0451, theta=0.0
% INFO    : Bus 844	: V=1.02750134, theta=-17.856228 -> V=1.0, theta=0.0
% INFO    : Bus 845	: V=1.05757889, theta=-14.9374109 -> V=1.0377785, theta=0.0
% INFO    : Bus 846	: V=1.08016589, theta=-3.41856328 -> V=1.0401635, theta=0.0
% INFO    : Bus 847	: V=0.973690737, theta=-28.1470755 -> V=1.0000025, theta=0.0
% INFO    : Bus 848	: V=1.06347254, theta=-12.2781543 -> V=1.006667, theta=0.0
% INFO    : Bus 849	: V=1.00752855, theta=-11.7588324 -> V=1.015872, theta=0.0
% INFO    : Bus 850	: V=1.03980042, theta=0.828027299 -> V=1.013331, theta=0.0
% INFO    : Bus 2751	: V=1.04128474, theta=0.858831605 -> V=1.013331, theta=0.0
% INFO    : Bus 851	: V=1.05933859, theta=-10.7631056 -> V=0.9888895, theta=0.0
% INFO    : Bus 852	: V=0.955674837, theta=-23.4157135 -> V=1.011627, theta=0.0
% INFO    : Bus 853	: V=1.02335738, theta=-21.9852725 -> V=1.0000025, theta=0.0
% INFO    : Bus 854	: V=1.06451929, theta=-11.8259285 -> V=1.05263, theta=0.0
% INFO    : Bus 855	: V=1.01421687, theta=-16.8330333 -> V=1.002764, theta=0.0
% INFO    : Bus 856	: V=1.02053443, theta=-13.9997464 -> V=1.0111115, theta=0.0
% INFO    : Bus 857	: V=1.04235656, theta=-13.7880848 -> V=1.0116165, theta=0.0
% INFO    : Bus 858	: V=1.0306872, theta=-12.9386367 -> V=0.999999, theta=0.0
% INFO    : Bus 859	: V=1.01868506, theta=-15.9418896 -> V=1.0377785, theta=0.0
% INFO    : Bus 860	: V=0.961587014, theta=-23.1401095 -> V=1.014093, theta=0.0
% INFO    : Bus 861	: V=1.02475509, theta=-22.5200312 -> V=1.0000025, theta=0.0
% INFO    : Bus 862	: V=1.03516797, theta=-13.3409415 -> V=0.999999, theta=0.0
% INFO    : Bus 863	: V=1.04725829, theta=-11.2286141 -> V=1.0111115, theta=0.0
% INFO    : Bus 864	: V=1.04396522, theta=-16.7815794 -> V=1.04458, theta=0.0
% INFO    : Bus 865	: V=1.01303638, theta=-13.9975823 -> V=0.999999, theta=0.0
% INFO    : Bus 866	: V=1.02128867, theta=-26.2494376 -> V=1.015872, theta=0.0
% INFO    : Bus 867	: V=1.04257884, theta=-14.5430322 -> V=1.015872, theta=0.0
% INFO    : Bus 868	: V=0.98720102, theta=-22.078588 -> V=1.0000025, theta=0.0
% INFO    : Bus 869	: V=1.05777279, theta=-21.4125563 -> V=1.044445, theta=0.0
% INFO    : Bus 2752	: V=1.057744, theta=-21.4258337 -> V=1.044445, theta=0.0
% INFO    : Bus 870	: V=1.06167524, theta=-10.1040458 -> V=1.0377785, theta=0.0
% INFO    : Bus 871	: V=1.01520983, theta=-21.5682598 -> V=1.0000025, theta=0.0
% INFO    : Bus 872	: V=1.02686041, theta=-13.776182 -> V=1.015872, theta=0.0
% INFO    : Bus 2753	: V=1.04492318, theta=-13.9987907 -> V=1.015872, theta=0.0
% INFO    : Bus 873	: V=1.04523799, theta=-15.4890593 -> V=1.019477, theta=0.0
% INFO    : Bus 2754	: V=1.04769601, theta=-15.1311941 -> V=1.019477, theta=0.0
% INFO    : Bus 874	: V=1.07291416, theta=-10.8229133 -> V=1.04222, theta=0.0
% INFO    : Bus 875	: V=1.08668526, theta=-4.83327564 -> V=1.051315, theta=0.0
% INFO    : Bus 876	: V=1.04, theta=-13.6941321 -> V=1.015872, theta=0.0
% INFO    : Bus 877	: V=1.04498894, theta=-14.5932649 -> V=1.0000025, theta=0.0
% INFO    : Bus 878	: V=1.01928676, theta=-16.0181779 -> V=0.999999, theta=0.0
% INFO    : Bus 2755	: V=1.02080498, theta=-17.5814811 -> V=0.999999, theta=0.0
% INFO    : Bus 879	: V=1.0485013, theta=-12.8929582 -> V=1.0111115, theta=0.0
% INFO    : Bus 880	: V=1.06962969, theta=-10.9391494 -> V=1.04222, theta=0.0
% INFO    : Bus 881	: V=1.08185212, theta=-9.01464623 -> V=1.051315, theta=0.0
% INFO    : Bus 2756	: V=1.08169609, theta=-9.04685916 -> V=1.051315, theta=0.0
% INFO    : Bus 882	: V=1.08806156, theta=-13.9703024 -> V=1.003435, theta=0.0
% INFO    : Bus 883	: V=1.031, theta=-14.3023292 -> V=1.0, theta=0.0
% INFO    : Bus 2757	: V=1.031, theta=-13.4072679 -> V=1.0, theta=0.0
% INFO    : Bus 2758	: V=1.031, theta=-14.3457211 -> V=1.0, theta=0.0
% INFO    : Bus 2759	: V=1.031, theta=-14.0184457 -> V=1.0, theta=0.0
% INFO    : Bus 2760	: V=1.031, theta=-13.3981859 -> V=1.0, theta=0.0
% INFO    : Bus 2761	: V=1.031, theta=-13.8825478 -> V=1.0, theta=0.0
% INFO    : Bus 884	: V=1.02935167, theta=-15.0437867 -> V=1.0377785, theta=0.0
% INFO    : Bus 2762	: V=1.02935578, theta=-15.0494659 -> V=1.0377785, theta=0.0
% INFO    : Bus 2763	: V=1.02935594, theta=-15.0497413 -> V=1.0377785, theta=0.0
% INFO    : Bus 2764	: V=1.02935162, theta=-15.0437291 -> V=1.0377785, theta=0.0
% INFO    : Bus 2765	: V=1.02935405, theta=-15.046802 -> V=1.0377785, theta=0.0
% INFO    : Bus 2766	: V=1.02935499, theta=-15.0473385 -> V=1.0377785, theta=0.0
% INFO    : Bus 885	: V=1.02934754, theta=-15.0542505 -> V=1.0377785, theta=0.0
% INFO    : Bus 886	: V=1.01199229, theta=-20.4218858 -> V=1.0000025, theta=0.0
% INFO    : Bus 887	: V=1.00752863, theta=-11.7588341 -> V=1.015872, theta=0.0
% INFO    : Bus 888	: V=1.05882547, theta=-9.48224333 -> V=1.04222, theta=0.0
% INFO    : Bus 889	: V=1.06665387, theta=-6.95730984 -> V=1.04222, theta=0.0
% INFO    : Bus 2767	: V=1.06665314, theta=-6.95752742 -> V=1.04222, theta=0.0
% INFO    : Bus 890	: V=0.983021655, theta=-15.8116607 -> V=0.999999, theta=0.0
% INFO    : Bus 891	: V=1.01130366, theta=-18.2168584 -> V=1.015872, theta=0.0
% INFO    : Bus 892	: V=1.0748184, theta=-21.9882355 -> V=1.044445, theta=0.0
% INFO    : Bus 2768	: V=1.07480745, theta=-21.988312 -> V=1.044445, theta=0.0
% INFO    : Bus 893	: V=1.06276271, theta=-10.2839181 -> V=1.044445, theta=0.0
% INFO    : Bus 894	: V=1.07787625, theta=-29.2250799 -> V=1.04222, theta=0.0
% INFO    : Bus 2769	: V=1.0772328, theta=-29.1147925 -> V=1.04222, theta=0.0
% INFO    : Bus 895	: V=1.08064708, theta=-3.50894856 -> V=1.0395835, theta=0.0
% INFO    : Bus 896	: V=1.06581459, theta=-7.07332283 -> V=1.0377785, theta=0.0
% INFO    : Bus 897	: V=1.07114616, theta=-18.2171743 -> V=1.044445, theta=0.0
% INFO    : Bus 2770	: V=1.05563866, theta=-19.1601238 -> V=1.044445, theta=0.0
% INFO    : Bus 898	: V=1.03536659, theta=-13.8938636 -> V=1.001324, theta=0.0
% INFO    : Bus 899	: V=1.03477387, theta=-17.3956715 -> V=1.000709, theta=0.0
% INFO    : Bus 900	: V=1.08850643, theta=-13.5167833 -> V=1.00601, theta=0.0
% INFO    : Bus 901	: V=1.05016812, theta=-12.1361041 -> V=1.044445, theta=0.0
% INFO    : Bus 902	: V=1.05729263, theta=-21.4666741 -> V=1.044445, theta=0.0
% INFO    : Bus 903	: V=1.04407119, theta=-17.3602161 -> V=1.044445, theta=0.0
% INFO    : Bus 904	: V=1.08755402, theta=-10.6366404 -> V=1.051315, theta=0.0
% INFO    : Bus 905	: V=1.04019568, theta=-16.0277278 -> V=0.975153, theta=0.0
% INFO    : Bus 906	: V=1.06576078, theta=-10.2206421 -> V=1.04623, theta=0.0
% INFO    : Bus 909	: V=1.06373922, theta=-14.1825857 -> V=0.9888895, theta=0.0
% INFO    : Bus 2771	: V=1.06525435, theta=-13.2718626 -> V=0.9888895, theta=0.0
% INFO    : Bus 910	: V=1.07266219, theta=-11.6541911 -> V=1.05263, theta=0.0
% INFO    : Bus 911	: V=1.06518527, theta=-19.7745182 -> V=1.04515, theta=0.0
% INFO    : Bus 912	: V=1.08253253, theta=-12.7431793 -> V=1.05263, theta=0.0
% INFO    : Bus 913	: V=1.01036791, theta=-22.5375614 -> V=1.0000025, theta=0.0
% INFO    : Bus 914	: V=1.01933823, theta=-20.9870957 -> V=1.015872, theta=0.0
% INFO    : Bus 915	: V=1.04563091, theta=-17.8973958 -> V=1.015872, theta=0.0
% INFO    : Bus 2772	: V=1.0454198, theta=-17.9001763 -> V=1.015872, theta=0.0
% INFO    : Bus 916	: V=1.03073878, theta=-16.5076211 -> V=0.999999, theta=0.0
% INFO    : Bus 917	: V=1.01560913, theta=-17.0538511 -> V=1.015872, theta=0.0
% INFO    : Bus 918	: V=1.04333449, theta=-17.3925194 -> V=1.0000025, theta=0.0
% INFO    : Bus 919	: V=1.06444119, theta=-24.7529334 -> V=1.045555, theta=0.0
% INFO    : Bus 920	: V=1.01417132, theta=-30.0521148 -> V=1.015872, theta=0.0
% INFO    : Bus 921	: V=1.04591653, theta=-17.8545652 -> V=1.015872, theta=0.0
% INFO    : Bus 922	: V=1.07818791, theta=-13.2520996 -> V=1.04222, theta=0.0
% INFO    : Bus 923	: V=1.04, theta=-10.9833465 -> V=1.015872, theta=0.0
% INFO    : Bus 924	: V=0.974173305, theta=-12.1939038 -> V=0.9444445, theta=0.0
% INFO    : Bus 925	: V=1.02721406, theta=-16.9209389 -> V=1.015872, theta=0.0
% INFO    : Bus 926	: V=1.04087806, theta=-17.3143624 -> V=1.044445, theta=0.0
% INFO    : Bus 927	: V=1.02712624, theta=-12.9485992 -> V=1.047315, theta=0.0
% INFO    : Bus 928	: V=1.04787474, theta=-14.6846399 -> V=1.044445, theta=0.0
% INFO    : Bus 929	: V=1.05900555, theta=-9.81972191 -> V=1.05263, theta=0.0
% INFO    : Bus 930	: V=1.05923091, theta=-12.2637561 -> V=0.9888895, theta=0.0
% INFO    : Bus 2773	: V=1.05929, theta=-12.2629138 -> V=0.9888895, theta=0.0
% INFO    : Bus 931	: V=1.06497216, theta=-10.9676409 -> V=0.9888895, theta=0.0
% INFO    : Bus 932	: V=1.07478786, theta=-22.0921359 -> V=1.044445, theta=0.0
% INFO    : Bus 2774	: V=1.07485836, theta=-22.0859499 -> V=1.044445, theta=0.0
% INFO    : Bus 2775	: V=1.07482698, theta=-22.0875735 -> V=1.044445, theta=0.0
% INFO    : Bus 933	: V=1.06647253, theta=-12.9986754 -> V=1.0067225, theta=0.0
% INFO    : Bus 934	: V=1.02594235, theta=-25.7126138 -> V=1.015872, theta=0.0
% INFO    : Bus 935	: V=1.05686877, theta=-19.0807915 -> V=1.044445, theta=0.0
% INFO    : Bus 936	: V=1.06530134, theta=-19.2138474 -> V=1.044445, theta=0.0
% INFO    : Bus 937	: V=0.986311768, theta=-20.0034753 -> V=0.999999, theta=0.0
% INFO    : Bus 938	: V=0.998767008, theta=-19.4735496 -> V=1.006224, theta=0.0
% INFO    : Bus 939	: V=1.0222668, theta=-13.0394349 -> V=1.0111115, theta=0.0
% INFO    : Bus 940	: V=1.04685355, theta=-14.3366938 -> V=1.015872, theta=0.0
% INFO    : Bus 941	: V=1.00908571, theta=-15.8459636 -> V=0.999999, theta=0.0
% INFO    : Bus 942	: V=1.00337542, theta=-29.4388131 -> V=1.016087, theta=0.0
% INFO    : Bus 943	: V=0.991559719, theta=-24.1204527 -> V=1.0233335, theta=0.0
% INFO    : Bus 944	: V=1.0434779, theta=-27.3963164 -> V=1.04222, theta=0.0
% INFO    : Bus 945	: V=1.05463948, theta=-15.524125 -> V=1.001604, theta=0.0
% INFO    : Bus 946	: V=1.034, theta=-10.6681018 -> V=0.999999, theta=0.0
% INFO    : Bus 947	: V=1.0538828, theta=-16.05633 -> V=1.044445, theta=0.0
% INFO    : Bus 948	: V=1.02945883, theta=-19.1547782 -> V=1.0000025, theta=0.0
% INFO    : Bus 949	: V=1.05312148, theta=-11.8771594 -> V=1.0382935, theta=0.0
% INFO    : Bus 950	: V=1.07161248, theta=-8.3762069 -> V=1.05263, theta=0.0
% INFO    : Bus 951	: V=1.0575574, theta=-18.6186895 -> V=1.044445, theta=0.0
% INFO    : Bus 952	: V=1.05744734, theta=-21.5291753 -> V=1.044445, theta=0.0
% INFO    : Bus 953	: V=0.934775785, theta=-10.3105747 -> V=0.9444445, theta=0.0
% INFO    : Bus 954	: V=1.06326346, theta=-11.3037842 -> V=1.003335, theta=0.0
% INFO    : Bus 955	: V=1.04608618, theta=-10.9963493 -> V=1.0111115, theta=0.0
% INFO    : Bus 956	: V=1.06453855, theta=-8.96831852 -> V=1.0288895, theta=0.0
% INFO    : Bus 957	: V=1.09865045, theta=-0.489607127 -> V=1.05263, theta=0.0
% INFO    : Bus 958	: V=0.998824307, theta=-13.2833857 -> V=0.975, theta=0.0
% INFO    : Bus 959	: V=1.07949697, theta=-30.2454001 -> V=1.04222, theta=0.0
% INFO    : Bus 960	: V=1.03840365, theta=-15.7960769 -> V=1.001399, theta=0.0
% INFO    : Bus 961	: V=1.08417673, theta=-15.7947344 -> V=1.051315, theta=0.0
% INFO    : Bus 2776	: V=1.08446718, theta=-15.7956804 -> V=1.051315, theta=0.0
% INFO    : Bus 962	: V=1.02032093, theta=-20.685204 -> V=1.0000025, theta=0.0
% INFO    : Bus 963	: V=0.989463204, theta=-30.2013031 -> V=1.015872, theta=0.0
% INFO    : Bus 964	: V=1.0586802, theta=-14.4120811 -> V=1.0377785, theta=0.0
% INFO    : Bus 965	: V=1.0824694, theta=-4.50643704 -> V=1.0288895, theta=0.0
% INFO    : Bus 966	: V=1.0185815, theta=-16.2413386 -> V=1.0377785, theta=0.0
% INFO    : Bus 967	: V=1.05238424, theta=-18.2434069 -> V=1.0000025, theta=0.0
% INFO    : Bus 968	: V=1.05239893, theta=-18.2386745 -> V=1.0000025, theta=0.0
% INFO    : Bus 969	: V=1.0890945, theta=-12.7040297 -> V=1.0, theta=0.0
% INFO    : Bus 970	: V=1.08902573, theta=-12.7050946 -> V=1.004205, theta=0.0
% INFO    : Bus 971	: V=1.03924707, theta=-10.6897075 -> V=1.044445, theta=0.0
% INFO    : Bus 972	: V=1.0543133, theta=-14.804006 -> V=0.9888895, theta=0.0
% INFO    : Bus 973	: V=1.06249773, theta=-12.5311605 -> V=0.9888895, theta=0.0
% INFO    : Bus 974	: V=0.988671506, theta=-14.4891366 -> V=1.014744, theta=0.0
% INFO    : Bus 975	: V=1.037, theta=-11.0083673 -> V=0.999999, theta=0.0
% INFO    : Bus 976	: V=1.00751523, theta=-11.7585547 -> V=1.015872, theta=0.0
% INFO    : Bus 977	: V=1.04654204, theta=-8.36058314 -> V=1.04222, theta=0.0
% INFO    : Bus 978	: V=1.113, theta=-11.775721 -> V=1.0, theta=0.0
% INFO    : Bus 2777	: V=1.1018475, theta=-12.7460029 -> V=1.0, theta=0.0
% INFO    : Bus 979	: V=1.10148552, theta=-12.8407572 -> V=1.021, theta=0.0
% INFO    : Bus 980	: V=1.03736043, theta=-19.4154151 -> V=1.0000025, theta=0.0
% INFO    : Bus 981	: V=1.04850889, theta=-14.2047934 -> V=1.0377785, theta=0.0
% INFO    : Bus 982	: V=1.05625851, theta=-9.42914904 -> V=1.0111115, theta=0.0
% INFO    : Bus 984	: V=1.0067792, theta=-18.0161774 -> V=1.0000025, theta=0.0
% INFO    : Bus 985	: V=1.06231212, theta=-20.0862756 -> V=1.044445, theta=0.0
% INFO    : Bus 986	: V=1.04624981, theta=-17.0358148 -> V=1.0382385, theta=0.0
% INFO    : Bus 987	: V=1.06761939, theta=-19.5634043 -> V=1.044445, theta=0.0
% INFO    : Bus 988	: V=1.03265442, theta=-19.5717526 -> V=1.015872, theta=0.0
% INFO    : Bus 2778	: V=1.03256174, theta=-19.5763061 -> V=1.015872, theta=0.0
% INFO    : Bus 989	: V=1.02990361, theta=-15.0693974 -> V=1.015872, theta=0.0
% INFO    : Bus 990	: V=1.05573219, theta=-19.0188215 -> V=1.044445, theta=0.0
% INFO    : Bus 991	: V=1.03929709, theta=-10.1800829 -> V=1.0111115, theta=0.0
% INFO    : Bus 992	: V=0.998767462, theta=-19.0096057 -> V=1.004489, theta=0.0
% INFO    : Bus 2779	: V=0.989576899, theta=-17.4791666 -> V=1.004489, theta=0.0
% INFO    : Bus 993	: V=1.02489495, theta=-12.4605083 -> V=1.0111115, theta=0.0
% INFO    : Bus 994	: V=1.02203721, theta=-19.481485 -> V=1.015872, theta=0.0
% INFO    : Bus 995	: V=1.0191147, theta=-17.6574594 -> V=1.015872, theta=0.0
% INFO    : Bus 996	: V=1.06995936, theta=-11.8494319 -> V=1.035924, theta=0.0
% INFO    : Bus 998	: V=1.03738095, theta=-16.9017858 -> V=1.0383785, theta=0.0
% INFO    : Bus 999	: V=1.05581473, theta=-13.5938688 -> V=1.05263, theta=0.0
% INFO    : Bus 1000	: V=1.07148612, theta=-7.84430369 -> V=0.9888895, theta=0.0
% INFO    : Bus 1001	: V=1.08042291, theta=-5.51588405 -> V=1.05263, theta=0.0
% INFO    : Bus 1002	: V=1.06592657, theta=-14.3577297 -> V=1.044445, theta=0.0
% INFO    : Bus 1003	: V=1.06974844, theta=-11.9702254 -> V=1.033334, theta=0.0
% INFO    : Bus 1004	: V=1.03514982, theta=-10.7277905 -> V=1.000629, theta=0.0
% INFO    : Bus 1005	: V=1.03431069, theta=-10.8818143 -> V=1.0377785, theta=0.0
% INFO    : Bus 1006	: V=1.03201817, theta=-12.2367465 -> V=1.015872, theta=0.0
% INFO    : Bus 1007	: V=1.06211354, theta=-9.20089147 -> V=1.046055, theta=0.0
% INFO    : Bus 1008	: V=1.0348524, theta=-14.7667871 -> V=1.002639, theta=0.0
% INFO    : Bus 1009	: V=1.05728801, theta=-11.6050122 -> V=1.0126965, theta=0.0
% INFO    : Bus 1010	: V=1.00882856, theta=-13.666431 -> V=0.999999, theta=0.0
% INFO    : Bus 1011	: V=1.04029211, theta=-9.88814414 -> V=1.0377785, theta=0.0
% INFO    : Bus 1012	: V=1.05929801, theta=-6.9663855 -> V=1.05263, theta=0.0
% INFO    : Bus 1013	: V=0.929531144, theta=-11.2994497 -> V=1.0, theta=0.0
% INFO    : Bus 1014	: V=1.0556917, theta=-11.0594855 -> V=1.04222, theta=0.0
% INFO    : Bus 1015	: V=1.07809997, theta=-7.13442003 -> V=1.051315, theta=0.0
% INFO    : Bus 1016	: V=1.05267492, theta=-15.6513779 -> V=1.000184, theta=0.0
% INFO    : Bus 1017	: V=1.04287396, theta=-11.771779 -> V=1.0111115, theta=0.0
% INFO    : Bus 1018	: V=1.06769921, theta=-10.0907306 -> V=1.0385635, theta=0.0
% INFO    : Bus 1019	: V=1.03655709, theta=-12.321295 -> V=1.048295, theta=0.0
% INFO    : Bus 1020	: V=1.05949395, theta=-12.8318642 -> V=1.05263, theta=0.0
% INFO    : Bus 1022	: V=1.07816701, theta=-28.9886371 -> V=1.04222, theta=0.0
% INFO    : Bus 1023	: V=1.07820626, theta=-25.9881747 -> V=1.051315, theta=0.0
% INFO    : Bus 2780	: V=1.08096498, theta=-24.1369663 -> V=1.051315, theta=0.0
% INFO    : Bus 1024	: V=1.05347737, theta=-12.6222573 -> V=1.044445, theta=0.0
% INFO    : Bus 1025	: V=1.03317163, theta=-16.7439873 -> V=0.999999, theta=0.0
% INFO    : Bus 1026	: V=1.05761276, theta=-19.5087705 -> V=1.044445, theta=0.0
% INFO    : Bus 2781	: V=1.06080255, theta=-20.5206318 -> V=1.044445, theta=0.0
% INFO    : Bus 1027	: V=1.06948429, theta=-10.3222102 -> V=1.022223, theta=0.0
% INFO    : Bus 1028	: V=1.07938984, theta=-6.18656256 -> V=1.05263, theta=0.0
% INFO    : Bus 1029	: V=1.01888644, theta=-15.0035597 -> V=0.999999, theta=0.0
% INFO    : Bus 1030	: V=1.00771247, theta=-11.7174267 -> V=1.0000015, theta=0.0
% INFO    : Bus 2782	: V=0.994366202, theta=-11.5953974 -> V=1.0000015, theta=0.0
% INFO    : Bus 1031	: V=1.05922432, theta=-11.3923109 -> V=0.9888895, theta=0.0
% INFO    : Bus 1032	: V=1.05534274, theta=-20.4624824 -> V=1.04222, theta=0.0
% INFO    : Bus 1033	: V=1.0312084, theta=-20.2531119 -> V=1.0000025, theta=0.0
% INFO    : Bus 1034	: V=1.02880531, theta=-12.5053585 -> V=1.044445, theta=0.0
% INFO    : Bus 1035	: V=1.00959177, theta=-17.6778622 -> V=1.0065525, theta=0.0
% INFO    : Bus 1036	: V=1.0850764, theta=-2.38200628 -> V=1.0396335, theta=0.0
% INFO    : Bus 2783	: V=1.08513965, theta=-2.40578747 -> V=1.0396335, theta=0.0
% INFO    : Bus 1037	: V=1.01566331, theta=-20.1192145 -> V=1.0000025, theta=0.0
% INFO    : Bus 1038	: V=1.06976843, theta=-15.335224 -> V=1.04222, theta=0.0
% INFO    : Bus 1039	: V=1.01421687, theta=-16.8330333 -> V=1.002764, theta=0.0
% INFO    : Bus 1040	: V=1.02052102, theta=-14.0006736 -> V=1.0111115, theta=0.0
% INFO    : Bus 1041	: V=1.05699289, theta=-12.5994306 -> V=0.9888895, theta=0.0
% INFO    : Bus 1043	: V=1.0897083, theta=-3.39353608 -> V=0.9905795, theta=0.0
% INFO    : Bus 1044	: V=1.09773017, theta=-0.703254449 -> V=1.05263, theta=0.0
% INFO    : Bus 1045	: V=1.03279711, theta=-19.5644668 -> V=1.015872, theta=0.0
% INFO    : Bus 1046	: V=1.06998093, theta=-10.6814939 -> V=1.033334, theta=0.0
% INFO    : Bus 1047	: V=1.00937931, theta=-19.4850898 -> V=1.000539, theta=0.0
% INFO    : Bus 1048	: V=0.986227102, theta=-31.698863 -> V=1.015872, theta=0.0
% INFO    : Bus 1049	: V=1.02796779, theta=-28.7118454 -> V=1.04222, theta=0.0
% INFO    : Bus 1050	: V=1.0856516, theta=-5.51540415 -> V=1.05263, theta=0.0
% INFO    : Bus 1051	: V=1.05768389, theta=-21.4726175 -> V=1.044445, theta=0.0
% INFO    : Bus 2784	: V=1.07356448, theta=-22.2129228 -> V=1.044445, theta=0.0
% INFO    : Bus 1052	: V=1.05507929, theta=-10.43878 -> V=1.0111115, theta=0.0
% INFO    : Bus 1053	: V=1.0500389, theta=-17.4255784 -> V=1.045855, theta=0.0
% INFO    : Bus 1054	: V=1.0276461, theta=-13.7368749 -> V=1.015872, theta=0.0
% INFO    : Bus 2949	: V=1.04475999, theta=-13.9448061 -> V=1.015872, theta=0.0
% INFO    : Bus 1055	: V=1.04918801, theta=-23.2226223 -> V=1.04222, theta=0.0
% INFO    : Bus 1056	: V=1.00023359, theta=-12.7263145 -> V=0.999999, theta=0.0
% INFO    : Bus 1057	: V=1.03111676, theta=-13.2331135 -> V=1.015872, theta=0.0
% INFO    : Bus 1058	: V=1.05371988, theta=-11.9657764 -> V=1.0111115, theta=0.0
% INFO    : Bus 1059	: V=1.00667348, theta=-18.3118767 -> V=0.999999, theta=0.0
% INFO    : Bus 1060	: V=1.03432791, theta=-13.4873648 -> V=0.999999, theta=0.0
% INFO    : Bus 1061	: V=1.02983908, theta=-15.9738249 -> V=1.015872, theta=0.0
% INFO    : Bus 1062	: V=1.01044502, theta=-12.5107223 -> V=1.015872, theta=0.0
% INFO    : Bus 1063	: V=1.02376714, theta=-16.2978544 -> V=0.999999, theta=0.0
% INFO    : Bus 1064	: V=1.06035359, theta=-10.6184623 -> V=1.0111115, theta=0.0
% INFO    : Bus 1066	: V=1.06622367, theta=-18.5644589 -> V=1.044445, theta=0.0
% INFO    : Bus 1067	: V=1.07564788, theta=-13.8447975 -> V=1.05263, theta=0.0
% INFO    : Bus 1068	: V=0.99252545, theta=-20.0180513 -> V=1.001859, theta=0.0
% INFO    : Bus 1069	: V=1.035, theta=-6.45601058 -> V=1.0, theta=0.0
% INFO    : Bus 1070	: V=1.09610013, theta=-12.8601212 -> V=1.00468, theta=0.0
% INFO    : Bus 1071	: V=1.04264226, theta=-11.1098931 -> V=1.04802, theta=0.0
% INFO    : Bus 1072	: V=1.09106042, theta=-12.4905664 -> V=1.00445, theta=0.0
% INFO    : Bus 1073	: V=0.999872435, theta=-22.9711315 -> V=1.0000025, theta=0.0
% INFO    : Bus 1075	: V=1.02700977, theta=-14.3978434 -> V=0.999999, theta=0.0
% INFO    : Bus 1076	: V=1.06248269, theta=-9.77992675 -> V=1.0111115, theta=0.0
% INFO    : Bus 2785	: V=1.05967537, theta=-9.88667192 -> V=1.0111115, theta=0.0
% INFO    : Bus 2786	: V=1.05821713, theta=-9.18102357 -> V=1.0111115, theta=0.0
% INFO    : Bus 1077	: V=1.07535105, theta=-5.85640612 -> V=1.05263, theta=0.0
% INFO    : Bus 1078	: V=1.03479814, theta=-15.828102 -> V=1.015872, theta=0.0
% INFO    : Bus 1079	: V=1.03480634, theta=-15.827992 -> V=1.015872, theta=0.0
% INFO    : Bus 1080	: V=1.03150508, theta=-18.920619 -> V=1.0000025, theta=0.0
% INFO    : Bus 1081	: V=1.02423378, theta=-16.3822346 -> V=0.999999, theta=0.0
% INFO    : Bus 1082	: V=1.08472309, theta=-18.9867954 -> V=1.0299375, theta=0.0
% INFO    : Bus 1083	: V=1.08155931, theta=-4.65541043 -> V=0.9888895, theta=0.0
% INFO    : Bus 2787	: V=1.08182075, theta=-4.62184704 -> V=0.9888895, theta=0.0
% INFO    : Bus 1084	: V=1.04323679, theta=-19.3152639 -> V=1.044445, theta=0.0
% INFO    : Bus 1085	: V=1.03409754, theta=-12.8986438 -> V=1.002364, theta=0.0
% INFO    : Bus 2788	: V=1.03532288, theta=-13.1900314 -> V=1.002364, theta=0.0
% INFO    : Bus 1086	: V=1.05519131, theta=-10.0217365 -> V=1.0111115, theta=0.0
% INFO    : Bus 1087	: V=1.05157852, theta=-19.5796317 -> V=1.044445, theta=0.0
% INFO    : Bus 1088	: V=1.03477542, theta=-12.8799309 -> V=1.015872, theta=0.0
% INFO    : Bus 2789	: V=1.03477542, theta=-12.8803219 -> V=1.015872, theta=0.0
% INFO    : Bus 1089	: V=1.06211354, theta=-9.20089147 -> V=1.046015, theta=0.0
% INFO    : Bus 1090	: V=1.08547501, theta=-14.7615201 -> V=1.051315, theta=0.0
% INFO    : Bus 1091	: V=1.03619119, theta=-10.3493443 -> V=1.0377785, theta=0.0
% INFO    : Bus 2790	: V=1.03552362, theta=-10.3395395 -> V=1.0377785, theta=0.0
% INFO    : Bus 1092	: V=1.01104242, theta=-19.8219669 -> V=0.999999, theta=0.0
% INFO    : Bus 1093	: V=1.02476634, theta=-12.3430479 -> V=1.015872, theta=0.0
% INFO    : Bus 1094	: V=1.0882278, theta=-13.2218317 -> V=1.00482, theta=0.0
% INFO    : Bus 1095	: V=1.05664437, theta=-19.027104 -> V=1.044445, theta=0.0
% INFO    : Bus 2791	: V=1.0727482, theta=-17.9662164 -> V=1.044445, theta=0.0
% INFO    : Bus 1097	: V=1.07274591, theta=-17.9650527 -> V=1.044445, theta=0.0
% INFO    : Bus 2792	: V=1.05665987, theta=-19.0247255 -> V=1.044445, theta=0.0
% INFO    : Bus 2793	: V=1.05297124, theta=-20.1170281 -> V=1.044445, theta=0.0
% INFO    : Bus 1098	: V=1.06785646, theta=-14.1468059 -> V=1.05263, theta=0.0
% INFO    : Bus 2794	: V=1.07056176, theta=-13.614413 -> V=1.05263, theta=0.0
% INFO    : Bus 1099	: V=1.05744627, theta=-15.674562 -> V=1.044445, theta=0.0
% INFO    : Bus 1100	: V=1.02672197, theta=-15.2033337 -> V=0.999999, theta=0.0
% INFO    : Bus 1101	: V=1.04543234, theta=-18.1520742 -> V=1.044445, theta=0.0
% INFO    : Bus 1102	: V=1.03479757, theta=-13.4428465 -> V=1.015872, theta=0.0
% INFO    : Bus 1103	: V=1.06900653, theta=-10.0802117 -> V=1.04222, theta=0.0
% INFO    : Bus 1104	: V=1.00186758, theta=-12.2602457 -> V=1.0, theta=0.0
% INFO    : Bus 1105	: V=1.0011585, theta=-12.567524 -> V=0.999999, theta=0.0
% INFO    : Bus 2795	: V=1.00086671, theta=-12.2602457 -> V=0.999999, theta=0.0
% INFO    : Bus 1106	: V=1.05979853, theta=-9.88735163 -> V=1.0111115, theta=0.0
% INFO    : Bus 2796	: V=1.05329423, theta=-9.88295305 -> V=1.0111115, theta=0.0
% INFO    : Bus 1107	: V=0.995991267, theta=-31.4616088 -> V=1.015872, theta=0.0
% INFO    : Bus 1108	: V=1.0530557, theta=-27.9789405 -> V=1.04222, theta=0.0
% INFO    : Bus 1109	: V=1.02347067, theta=-7.82255786 -> V=1.048275, theta=0.0
% INFO    : Bus 1110	: V=1.06668724, theta=-11.0812309 -> V=1.04222, theta=0.0
% INFO    : Bus 1111	: V=1.05791629, theta=-21.3980677 -> V=1.044445, theta=0.0
% INFO    : Bus 1112	: V=1.08359702, theta=-2.56600399 -> V=1.0386135, theta=0.0
% INFO    : Bus 1113	: V=1.09868165, theta=0.00773034737 -> V=1.05263, theta=0.0
% INFO    : Bus 1114	: V=1.01524812, theta=-14.048683 -> V=0.999999, theta=0.0
% INFO    : Bus 1115	: V=1.05386704, theta=-11.7759177 -> V=1.04222, theta=0.0
% INFO    : Bus 1116	: V=1.02076834, theta=-16.9219663 -> V=1.015872, theta=0.0
% INFO    : Bus 1117	: V=1.02744998, theta=-25.5348886 -> V=1.015872, theta=0.0
% INFO    : Bus 1119	: V=1.06016331, theta=-10.4442028 -> V=1.044445, theta=0.0
% INFO    : Bus 2797	: V=1.05916165, theta=-10.5504422 -> V=1.044445, theta=0.0
% INFO    : Bus 1120	: V=1.06463754, theta=-5.95197069 -> V=1.05263, theta=0.0
% INFO    : Bus 1121	: V=1.03382442, theta=-17.7323459 -> V=1.015872, theta=0.0
% INFO    : Bus 1122	: V=1.02875877, theta=-11.63636 -> V=1.015872, theta=0.0
% INFO    : Bus 1123	: V=1.04721308, theta=-15.0813332 -> V=1.04769, theta=0.0
% INFO    : Bus 1124	: V=1.03791474, theta=-14.8306512 -> V=1.000394, theta=0.0
% INFO    : Bus 1125	: V=1.06077616, theta=-12.2584512 -> V=0.9888895, theta=0.0
% INFO    : Bus 1126	: V=1.02411555, theta=-12.1904782 -> V=1.015872, theta=0.0
% INFO    : Bus 1127	: V=1.00762015, theta=-13.816363 -> V=1.015872, theta=0.0
% INFO    : Bus 1128	: V=1.0539983, theta=-15.5347086 -> V=1.044445, theta=0.0
% INFO    : Bus 2798	: V=1.05396238, theta=-15.5462907 -> V=1.044445, theta=0.0
% INFO    : Bus 1129	: V=1.07143149, theta=-6.82840226 -> V=1.05415, theta=0.0
% INFO    : Bus 1130	: V=1.07141104, theta=-6.81862667 -> V=1.0542, theta=0.0
% INFO    : Bus 2799	: V=1.07137728, theta=-6.81854276 -> V=1.0542, theta=0.0
% INFO    : Bus 1131	: V=1.05036274, theta=-14.5176116 -> V=1.04222, theta=0.0
% INFO    : Bus 1132	: V=1.05960952, theta=-19.3851745 -> V=1.044445, theta=0.0
% INFO    : Bus 2800	: V=1.05827515, theta=-19.3948282 -> V=1.044445, theta=0.0
% INFO    : Bus 1133	: V=1.01223163, theta=-15.4528336 -> V=1.015872, theta=0.0
% INFO    : Bus 1134	: V=1.03590088, theta=-11.7764296 -> V=1.0111115, theta=0.0
% INFO    : Bus 1135	: V=1.02321937, theta=-16.199926 -> V=0.999999, theta=0.0
% INFO    : Bus 1136	: V=0.995614859, theta=-17.8281772 -> V=1.015872, theta=0.0
% INFO    : Bus 1137	: V=1.03044595, theta=-14.5897254 -> V=0.999999, theta=0.0
% INFO    : Bus 1138	: V=1.07533705, theta=-4.23441016 -> V=1.0408935, theta=0.0
% INFO    : Bus 1139	: V=1.01307127, theta=-22.0125371 -> V=1.0000025, theta=0.0
% INFO    : Bus 1140	: V=1.03796375, theta=-18.2166131 -> V=1.0000025, theta=0.0
% INFO    : Bus 1141	: V=1.06126542, theta=-14.5574402 -> V=1.044445, theta=0.0
% INFO    : Bus 1142	: V=1.01230787, theta=-11.4758542 -> V=1.001024, theta=0.0
% INFO    : Bus 1143	: V=1.05344896, theta=-9.47606125 -> V=1.0111115, theta=0.0
% INFO    : Bus 1144	: V=0.962907771, theta=-8.92794229 -> V=0.9455045, theta=0.0
% INFO    : Bus 1145	: V=1.03312808, theta=-11.6515776 -> V=1.0111115, theta=0.0
% INFO    : Bus 1146	: V=1.07327606, theta=-22.2600312 -> V=1.044445, theta=0.0
% INFO    : Bus 1147	: V=1.07444931, theta=-8.24365561 -> V=1.05263, theta=0.0
% INFO    : Bus 1148	: V=1.037, theta=-11.1337876 -> V=0.999999, theta=0.0
% INFO    : Bus 2801	: V=1.02895721, theta=-11.9693443 -> V=0.999999, theta=0.0
% INFO    : Bus 1149	: V=1.06227916, theta=-19.2686043 -> V=1.044445, theta=0.0
% INFO    : Bus 1150	: V=1.05743089, theta=-11.1021789 -> V=1.0377785, theta=0.0
% INFO    : Bus 1151	: V=1.036, theta=-6.58772263 -> V=1.0, theta=0.0
% INFO    : Bus 2802	: V=1.036, theta=-6.59727368 -> V=1.0, theta=0.0
% INFO    : Bus 2803	: V=1.036, theta=-6.58199197 -> V=1.0, theta=0.0
% INFO    : Bus 1152	: V=1.03429856, theta=-10.8675624 -> V=1.0377785, theta=0.0
% INFO    : Bus 2804	: V=1.03429852, theta=-10.8675434 -> V=1.0377785, theta=0.0
% INFO    : Bus 2805	: V=1.03429862, theta=-10.867594 -> V=1.0377785, theta=0.0
% INFO    : Bus 1153	: V=1.045, theta=-14.2316791 -> V=1.001654, theta=0.0
% INFO    : Bus 1154	: V=0.999225032, theta=-19.0154799 -> V=0.999999, theta=0.0
% INFO    : Bus 1155	: V=1.02161131, theta=-23.5260994 -> V=1.0000025, theta=0.0
% INFO    : Bus 1156	: V=0.937300414, theta=-21.6063995 -> V=1.0, theta=0.0
% INFO    : Bus 1157	: V=1.00813636, theta=-19.8102114 -> V=1.015872, theta=0.0
% INFO    : Bus 1158	: V=1.05839358, theta=-11.4020217 -> V=1.05263, theta=0.0
% INFO    : Bus 1159	: V=1.06480788, theta=-12.1563374 -> V=0.9888895, theta=0.0
% INFO    : Bus 2806	: V=1.06408775, theta=-12.1799709 -> V=0.9888895, theta=0.0
% INFO    : Bus 1160	: V=1.0767825, theta=-2.96958025 -> V=1.0377785, theta=0.0
% INFO    : Bus 1161	: V=1.04827488, theta=-15.2468554 -> V=1.021287, theta=0.0
% INFO    : Bus 1162	: V=1.06366681, theta=-18.9197893 -> V=1.044445, theta=0.0
% INFO    : Bus 1163	: V=1.06366932, theta=-18.9195852 -> V=1.044445, theta=0.0
% INFO    : Bus 1164	: V=0.992100833, theta=-25.7723977 -> V=1.0000025, theta=0.0
% INFO    : Bus 2982	: V=1.02006969, theta=-22.2960242 -> V=1.0000025, theta=0.0
% INFO    : Bus 1165	: V=1.03587264, theta=-15.6771513 -> V=1.015872, theta=0.0
% INFO    : Bus 1166	: V=1.07918298, theta=-13.0525951 -> V=1.033334, theta=0.0
% INFO    : Bus 1167	: V=1.03715334, theta=-10.8113272 -> V=1.044118, theta=0.0
% INFO    : Bus 1168	: V=1.08882462, theta=-9.5699844 -> V=1.05263, theta=0.0
% INFO    : Bus 2807	: V=1.08824835, theta=-10.0778593 -> V=1.05263, theta=0.0
% INFO    : Bus 1169	: V=1.03007182, theta=-15.6547994 -> V=0.999999, theta=0.0
% INFO    : Bus 1170	: V=0.99242045, theta=-20.2197701 -> V=1.003079, theta=0.0
% INFO    : Bus 1171	: V=1.07481206, theta=-21.9881339 -> V=1.044445, theta=0.0
% INFO    : Bus 1172	: V=1.04943877, theta=-11.4888078 -> V=1.052035, theta=0.0
% INFO    : Bus 1173	: V=1.06164947, theta=-20.8005022 -> V=1.044445, theta=0.0
% INFO    : Bus 2808	: V=1.06727185, theta=-19.6128048 -> V=1.044445, theta=0.0
% INFO    : Bus 1174	: V=1.03630492, theta=-13.9503476 -> V=1.000864, theta=0.0
% INFO    : Bus 1175	: V=1.04237846, theta=-15.8691893 -> V=1.044445, theta=0.0
% INFO    : Bus 1176	: V=0.956, theta=-18.8052404 -> V=1.0, theta=0.0
% INFO    : Bus 1178	: V=1.06711286, theta=-19.9235043 -> V=1.04222, theta=0.0
% INFO    : Bus 1179	: V=1.06099467, theta=-17.6466581 -> V=1.051315, theta=0.0
% INFO    : Bus 1180	: V=0.997630375, theta=-16.3962395 -> V=0.999999, theta=0.0
% INFO    : Bus 1181	: V=1.05656857, theta=-15.0792485 -> V=1.002699, theta=0.0
% INFO    : Bus 1182	: V=1.05092794, theta=-20.5504682 -> V=1.044445, theta=0.0
% INFO    : Bus 2809	: V=1.05093693, theta=-20.5502114 -> V=1.044445, theta=0.0
% INFO    : Bus 1183	: V=1.06835602, theta=-12.4971372 -> V=1.04222, theta=0.0
% INFO    : Bus 1184	: V=1.03690402, theta=-17.8582592 -> V=1.015872, theta=0.0
% INFO    : Bus 1185	: V=1.05496268, theta=-16.2250187 -> V=1.04222, theta=0.0
% INFO    : Bus 2810	: V=1.05571214, theta=-14.829782 -> V=1.04222, theta=0.0
% INFO    : Bus 1186	: V=1.03689943, theta=-14.0587621 -> V=0.995556, theta=0.0
% INFO    : Bus 1187	: V=1.06423445, theta=-19.8696012 -> V=1.044445, theta=0.0
% INFO    : Bus 2811	: V=1.06806116, theta=-19.4833843 -> V=1.044445, theta=0.0
% INFO    : Bus 1188	: V=1.0899564, theta=-12.6094496 -> V=1.004635, theta=0.0
% INFO    : Bus 1189	: V=1.06157408, theta=-19.277264 -> V=1.044445, theta=0.0
% INFO    : Bus 1190	: V=1.03588123, theta=-20.9801903 -> V=1.044445, theta=0.0
% INFO    : Bus 1191	: V=0.987302794, theta=-20.2187862 -> V=1.015872, theta=0.0
% INFO    : Bus 1192	: V=0.973756807, theta=-12.2724483 -> V=0.9444445, theta=0.0
% INFO    : Bus 1193	: V=1.09221141, theta=-4.65794932 -> V=1.05263, theta=0.0
% INFO    : Bus 1194	: V=1.0689525, theta=-19.2713811 -> V=1.04512, theta=0.0
% INFO    : Bus 2812	: V=1.06888302, theta=-19.2751353 -> V=1.04512, theta=0.0
% INFO    : Bus 2813	: V=1.06894458, theta=-19.2718585 -> V=1.04512, theta=0.0
% INFO    : Bus 1195	: V=1.09060911, theta=-9.60250172 -> V=1.05263, theta=0.0
% INFO    : Bus 1196	: V=1.09015396, theta=-9.69786946 -> V=1.05263, theta=0.0
% INFO    : Bus 1197	: V=1.04016919, theta=0.985383583 -> V=1.013331, theta=0.0
% INFO    : Bus 1198	: V=1.03656925, theta=-16.1011923 -> V=1.015872, theta=0.0
% INFO    : Bus 1199	: V=0.986093881, theta=-25.116639 -> V=1.003614, theta=0.0
% INFO    : Bus 1200	: V=1.07082067, theta=-10.8306242 -> V=1.04222, theta=0.0
% INFO    : Bus 1201	: V=1.02999241, theta=-12.5796607 -> V=1.015872, theta=0.0
% INFO    : Bus 1202	: V=1.0605306, theta=-12.6956283 -> V=1.04222, theta=0.0
% INFO    : Bus 1203	: V=1.05105504, theta=-10.503435 -> V=1.0111115, theta=0.0
% INFO    : Bus 1204	: V=0.964341777, theta=-17.1139271 -> V=1.00031, theta=0.0
% INFO    : Bus 1205	: V=1.06113242, theta=-20.7920822 -> V=1.0451, theta=0.0
% INFO    : Bus 1206	: V=1.04978825, theta=-12.8467314 -> V=1.002223, theta=0.0
% INFO    : Bus 1207	: V=1.05067831, theta=-20.579931 -> V=1.044445, theta=0.0
% INFO    : Bus 1208	: V=1.07363215, theta=-18.6402133 -> V=1.04582, theta=0.0
% INFO    : Bus 1209	: V=1.02112508, theta=-15.3852939 -> V=1.0377785, theta=0.0
% INFO    : Bus 1210	: V=1.023, theta=-10.5436374 -> V=1.0, theta=0.0
% INFO    : Bus 1211	: V=1.02111019, theta=-15.3692278 -> V=1.0377785, theta=0.0
% INFO    : Bus 2814	: V=1.02112508, theta=-15.3852939 -> V=1.0377785, theta=0.0
% INFO    : Bus 1212	: V=1.00091499, theta=-12.6150209 -> V=0.999999, theta=0.0
% INFO    : Bus 1213	: V=1.05354147, theta=-9.86570145 -> V=1.0111115, theta=0.0
% INFO    : Bus 1214	: V=1.07622019, theta=-4.02607375 -> V=1.0415935, theta=0.0
% INFO    : Bus 1215	: V=0.99219629, theta=-15.0733734 -> V=0.999999, theta=0.0
% INFO    : Bus 1216	: V=1.05025551, theta=-13.2152309 -> V=1.044445, theta=0.0
% INFO    : Bus 1217	: V=1.017, theta=-24.647911 -> V=1.022612, theta=0.0
% INFO    : Bus 1218	: V=1.04001232, theta=-18.0117931 -> V=1.044445, theta=0.0
% INFO    : Bus 1219	: V=1.01856261, theta=-18.8273312 -> V=1.0386435, theta=0.0
% INFO    : Bus 1220	: V=1.02516531, theta=-12.399591 -> V=1.002214, theta=0.0
% INFO    : Bus 1221	: V=1.03055662, theta=-11.1926987 -> V=1.015872, theta=0.0
% INFO    : Bus 1222	: V=1.11523806, theta=0.199677981 -> V=1.057895, theta=0.0
% INFO    : Bus 2815	: V=1.11055584, theta=-0.0665207316 -> V=1.057895, theta=0.0
% INFO    : Bus 2816	: V=1.11522251, theta=0.291261963 -> V=1.057895, theta=0.0
% INFO    : Bus 2817	: V=1.1147168, theta=0.0959700209 -> V=1.057895, theta=0.0
% INFO    : Bus 1223	: V=1.01987452, theta=-19.0852159 -> V=1.015872, theta=0.0
% INFO    : Bus 2818	: V=1.02351124, theta=-17.1229088 -> V=1.015872, theta=0.0
% INFO    : Bus 1224	: V=1.07134719, theta=-14.0414974 -> V=1.04222, theta=0.0
% INFO    : Bus 1225	: V=1.07244649, theta=-18.1114371 -> V=1.04406, theta=0.0
% INFO    : Bus 2819	: V=1.07224803, theta=-18.1801464 -> V=1.04406, theta=0.0
% INFO    : Bus 1226	: V=1.02926839, theta=-11.9190358 -> V=1.002334, theta=0.0
% INFO    : Bus 2820	: V=1.02915653, theta=-13.309334 -> V=1.002334, theta=0.0
% INFO    : Bus 1227	: V=1.05723291, theta=-9.9825275 -> V=1.0111115, theta=0.0
% INFO    : Bus 1228	: V=1.03449864, theta=-21.1435866 -> V=1.044033, theta=0.0
% INFO    : Bus 1229	: V=1.02856415, theta=-13.8838551 -> V=1.015872, theta=0.0
% INFO    : Bus 1230	: V=1.02912826, theta=-12.4421479 -> V=1.0111115, theta=0.0
% INFO    : Bus 1231	: V=1.01367138, theta=-19.607047 -> V=1.0000025, theta=0.0
% INFO    : Bus 1232	: V=1.05053768, theta=-17.6580204 -> V=1.044445, theta=0.0
% INFO    : Bus 1233	: V=1.05266727, theta=-15.8601211 -> V=1.044445, theta=0.0
% INFO    : Bus 1234	: V=1.01227176, theta=-18.4033014 -> V=0.999999, theta=0.0
% INFO    : Bus 1235	: V=0.994793717, theta=-32.4715138 -> V=1.015872, theta=0.0
% INFO    : Bus 1236	: V=1.00419456, theta=-20.7046692 -> V=1.0000025, theta=0.0
% INFO    : Bus 1237	: V=1.04046722, theta=-17.0512837 -> V=1.044445, theta=0.0
% INFO    : Bus 1238	: V=1.08518092, theta=-2.4839485 -> V=1.0395135, theta=0.0
% INFO    : Bus 1239	: V=1.07181263, theta=-13.106522 -> V=1.05263, theta=0.0
% INFO    : Bus 1240	: V=1.10577803, theta=-2.25995925 -> V=1.05307, theta=0.0
% INFO    : Bus 1241	: V=1.10655818, theta=-2.055496 -> V=1.05351, theta=0.0
% INFO    : Bus 2821	: V=1.10660701, theta=-2.04896897 -> V=1.05351, theta=0.0
% INFO    : Bus 1242	: V=1.02066774, theta=-21.7644756 -> V=1.015872, theta=0.0
% INFO    : Bus 1243	: V=1.03234583, theta=-13.2516589 -> V=1.001124, theta=0.0
% INFO    : Bus 1244	: V=1.05816066, theta=-12.6452204 -> V=0.9888895, theta=0.0
% INFO    : Bus 1245	: V=0.945033356, theta=-9.16345406 -> V=0.9444445, theta=0.0
% INFO    : Bus 1246	: V=1.05316349, theta=-9.91344217 -> V=1.0111115, theta=0.0
% INFO    : Bus 1247	: V=1.07485737, theta=-22.0858838 -> V=1.044445, theta=0.0
% INFO    : Bus 1248	: V=1.05321438, theta=-19.7970116 -> V=1.044445, theta=0.0
% INFO    : Bus 1249	: V=1.06253581, theta=-13.4546522 -> V=1.024445, theta=0.0
% INFO    : Bus 1250	: V=1.00419602, theta=-18.8745508 -> V=1.015425, theta=0.0
% INFO    : Bus 1251	: V=1.04842114, theta=-12.5694572 -> V=1.044445, theta=0.0
% INFO    : Bus 1252	: V=0.993107821, theta=-29.9235673 -> V=1.015872, theta=0.0
% INFO    : Bus 1253	: V=1.05991327, theta=-14.8143911 -> V=1.044445, theta=0.0
% INFO    : Bus 1254	: V=1.057, theta=-15.0577834 -> V=1.001289, theta=0.0
% INFO    : Bus 1255	: V=1.01676448, theta=-21.6768049 -> V=1.0000025, theta=0.0
% INFO    : Bus 1256	: V=1.07504337, theta=-8.93425585 -> V=1.033334, theta=0.0
% INFO    : Bus 1257	: V=1.01318655, theta=-16.9073421 -> V=1.002439, theta=0.0
% INFO    : Bus 1258	: V=1.04362135, theta=-16.0353267 -> V=1.019467, theta=0.0
% INFO    : Bus 1259	: V=1.08657928, theta=-8.59618892 -> V=1.051315, theta=0.0
% INFO    : Bus 1260	: V=0.995296338, theta=-32.5700026 -> V=1.015872, theta=0.0
% INFO    : Bus 1261	: V=1.027, theta=-21.2485728 -> V=1.0004375, theta=0.0
% INFO    : Bus 1262	: V=1.0270748, theta=-12.5485819 -> V=1.015872, theta=0.0
% INFO    : Bus 1263	: V=1.018, theta=-12.7186963 -> V=0.999999, theta=0.0
% INFO    : Bus 1264	: V=1.06904977, theta=-19.2638351 -> V=1.04518, theta=0.0
% INFO    : Bus 1265	: V=0.995739133, theta=-12.2417478 -> V=1.015872, theta=0.0
% INFO    : Bus 1266	: V=1.01215265, theta=-13.865206 -> V=1.015872, theta=0.0
% INFO    : Bus 1267	: V=1.07743243, theta=-5.88044651 -> V=1.05263, theta=0.0
% INFO    : Bus 1268	: V=1.05480221, theta=-19.2641956 -> V=1.044445, theta=0.0
% INFO    : Bus 1269	: V=0.993557807, theta=-15.0045975 -> V=0.95, theta=0.0
% INFO    : Bus 1270	: V=1.00770922, theta=-14.2801113 -> V=0.999999, theta=0.0
% INFO    : Bus 1271	: V=1.07905944, theta=-13.0632512 -> V=1.04222, theta=0.0
% INFO    : Bus 1272	: V=1.03704411, theta=-10.8357597 -> V=1.0441175, theta=0.0
% INFO    : Bus 1273	: V=1.07660612, theta=-13.7650816 -> V=1.05263, theta=0.0
% INFO    : Bus 2822	: V=1.07660612, theta=-13.7650816 -> V=1.05263, theta=0.0
% INFO    : Bus 2823	: V=1.07661655, theta=-13.7638572 -> V=1.05263, theta=0.0
% INFO    : Bus 2824	: V=1.07665269, theta=-13.7603297 -> V=1.05263, theta=0.0
% INFO    : Bus 1274	: V=1.06394698, theta=-18.9310552 -> V=1.044445, theta=0.0
% INFO    : Bus 1275	: V=1.021501, theta=-13.1537882 -> V=0.999999, theta=0.0
% INFO    : Bus 1276	: V=1.102, theta=-12.7907089 -> V=1.02107, theta=0.0
% INFO    : Bus 1277	: V=1.05022611, theta=-14.4757364 -> V=1.044445, theta=0.0
% INFO    : Bus 1278	: V=0.99886779, theta=-13.2859821 -> V=1.015872, theta=0.0
% INFO    : Bus 1279	: V=1.02560036, theta=-7.18633327 -> V=1.044445, theta=0.0
% INFO    : Bus 2825	: V=0.995796204, theta=-2.43823467 -> V=1.044445, theta=0.0
% INFO    : Bus 1280	: V=1.04355095, theta=-14.3388961 -> V=1.001694, theta=0.0
% INFO    : Bus 1281	: V=1.0515568, theta=-11.4517724 -> V=1.0111115, theta=0.0
% INFO    : Bus 1282	: V=0.977571832, theta=-21.638224 -> V=0.999999, theta=0.0
% INFO    : Bus 1283	: V=1.06942783, theta=-5.25075717 -> V=1.051315, theta=0.0
% INFO    : Bus 2826	: V=1.06914741, theta=-5.23568214 -> V=1.051315, theta=0.0
% INFO    : Bus 1284	: V=1.06540948, theta=-15.2027448 -> V=1.0377785, theta=0.0
% INFO    : Bus 1285	: V=1.03336042, theta=-13.3232838 -> V=1.0111115, theta=0.0
% INFO    : Bus 1286	: V=1.05201262, theta=-20.217775 -> V=1.044445, theta=0.0
% INFO    : Bus 1287	: V=1.07586163, theta=-8.89853394 -> V=1.051315, theta=0.0
% INFO    : Bus 1288	: V=0.986567359, theta=-14.5640535 -> V=1.015872, theta=0.0
% INFO    : Bus 1289	: V=1.07156407, theta=-14.0207648 -> V=1.033334, theta=0.0
% INFO    : Bus 2827	: V=1.07141707, theta=-14.0347383 -> V=1.033334, theta=0.0
% INFO    : Bus 1290	: V=1.06495369, theta=-7.31724903 -> V=1.04222, theta=0.0
% INFO    : Bus 1291	: V=1.06250782, theta=-12.5283884 -> V=1.0088895, theta=0.0
% INFO    : Bus 1292	: V=1.06515673, theta=-8.55119393 -> V=1.0111115, theta=0.0
% INFO    : Bus 1293	: V=1.01962054, theta=-18.2217498 -> V=1.0379085, theta=0.0
% INFO    : Bus 1294	: V=1.038, theta=-13.6881734 -> V=0.999999, theta=0.0
% INFO    : Bus 1295	: V=1.06193334, theta=-17.5206502 -> V=1.04222, theta=0.0
% INFO    : Bus 1296	: V=1.0344724, theta=-13.8726165 -> V=1.015872, theta=0.0
% INFO    : Bus 1297	: V=1.01941821, theta=-31.209991 -> V=1.015872, theta=0.0
% INFO    : Bus 1298	: V=1.06381755, theta=-19.7128611 -> V=1.044445, theta=0.0
% INFO    : Bus 1299	: V=1.02806908, theta=-18.5618927 -> V=1.0404085, theta=0.0
% INFO    : Bus 1300	: V=1.07395918, theta=-22.1321689 -> V=1.044445, theta=0.0
% INFO    : Bus 2828	: V=1.07393157, theta=-22.1319309 -> V=1.044445, theta=0.0
% INFO    : Bus 1301	: V=1.07399388, theta=-22.1248741 -> V=1.044445, theta=0.0
% INFO    : Bus 1302	: V=1.02838605, theta=-17.213131 -> V=0.999999, theta=0.0
% INFO    : Bus 1303	: V=1.03456981, theta=-15.4739447 -> V=1.0377785, theta=0.0
% INFO    : Bus 1304	: V=1.04962557, theta=-20.64011 -> V=1.044445, theta=0.0
% INFO    : Bus 1305	: V=1.05105016, theta=-10.5065052 -> V=1.0111115, theta=0.0
% INFO    : Bus 1306	: V=1.06241779, theta=-10.3473683 -> V=1.05263, theta=0.0
% INFO    : Bus 2829	: V=1.06248179, theta=-12.1018056 -> V=1.05263, theta=0.0
% INFO    : Bus 1307	: V=1.01654791, theta=-26.6031474 -> V=1.015872, theta=0.0
% INFO    : Bus 1308	: V=1.02691294, theta=-17.8693938 -> V=1.0, theta=0.0
% INFO    : Bus 1309	: V=1.05825515, theta=-18.8696293 -> V=0.975, theta=0.0
% INFO    : Bus 1310	: V=0.995259097, theta=-12.2418569 -> V=1.015872, theta=0.0
% INFO    : Bus 1311	: V=1.05810188, theta=-9.65185074 -> V=1.04222, theta=0.0
% INFO    : Bus 1312	: V=1.03139383, theta=-17.2016946 -> V=1.015872, theta=0.0
% INFO    : Bus 1313	: V=1.07727841, theta=-13.4062668 -> V=1.038985, theta=0.0
% INFO    : Bus 1314	: V=1.098, theta=-12.6165887 -> V=1.005695, theta=0.0
% INFO    : Bus 1315	: V=1.0379243, theta=-11.7264882 -> V=1.044445, theta=0.0
% INFO    : Bus 1316	: V=1.0726099, theta=-30.1947215 -> V=1.04222, theta=0.0
% INFO    : Bus 1317	: V=1.036, theta=-8.75995712 -> V=1.000569, theta=0.0
% INFO    : Bus 1318	: V=1.08865272, theta=-1.81169139 -> V=1.05263, theta=0.0
% INFO    : Bus 1319	: V=1.06600663, theta=-8.54727261 -> V=1.0111115, theta=0.0
% INFO    : Bus 1320	: V=1.05075149, theta=-9.70126487 -> V=1.0111115, theta=0.0
% INFO    : Bus 1321	: V=1.03336945, theta=-11.8491555 -> V=1.015872, theta=0.0
% INFO    : Bus 1323	: V=1.05497766, theta=-19.4722153 -> V=1.044445, theta=0.0
% INFO    : Bus 2830	: V=1.06567739, theta=-18.0562516 -> V=1.044445, theta=0.0
% INFO    : Bus 2831	: V=1.04470637, theta=-19.302438 -> V=1.044445, theta=0.0
% INFO    : Bus 1324	: V=1.06787327, theta=-13.5920374 -> V=1.05263, theta=0.0
% INFO    : Bus 2832	: V=1.06574714, theta=-13.9105777 -> V=1.05263, theta=0.0
% INFO    : Bus 1325	: V=0.995379612, theta=-29.8057637 -> V=1.015872, theta=0.0
% INFO    : Bus 1326	: V=1.0538104, theta=-27.6663354 -> V=1.04222, theta=0.0
% INFO    : Bus 1327	: V=0.995540311, theta=-21.4659315 -> V=1.0000025, theta=0.0
% INFO    : Bus 1328	: V=1.07091388, theta=-25.7124987 -> V=1.04222, theta=0.0
% INFO    : Bus 1329	: V=1.07356743, theta=-20.4558067 -> V=1.051315, theta=0.0
% INFO    : Bus 1330	: V=1.02872371, theta=-13.2572858 -> V=0.999999, theta=0.0
% INFO    : Bus 1331	: V=0.993685555, theta=-32.6080134 -> V=1.015872, theta=0.0
% INFO    : Bus 2833	: V=0.993631871, theta=-32.6264689 -> V=1.015872, theta=0.0
% INFO    : Bus 1332	: V=1.07998222, theta=-8.80449244 -> V=1.044445, theta=0.0
% INFO    : Bus 1333	: V=1.0638479, theta=-19.9367796 -> V=1.044445, theta=0.0
% INFO    : Bus 1334	: V=1.01874867, theta=-20.6397462 -> V=1.015872, theta=0.0
% INFO    : Bus 1335	: V=1.04099202, theta=-15.312488 -> V=1.003809, theta=0.0
% INFO    : Bus 1336	: V=1.06376433, theta=-12.2379477 -> V=0.9888895, theta=0.0
% INFO    : Bus 1337	: V=1.01301502, theta=-20.9313463 -> V=0.999999, theta=0.0
% INFO    : Bus 1338	: V=1.04610373, theta=-14.3499486 -> V=1.015872, theta=0.0
% INFO    : Bus 1339	: V=1.07071709, theta=-11.240438 -> V=1.04222, theta=0.0
% INFO    : Bus 1340	: V=1.02140594, theta=-11.2782971 -> V=1.0377785, theta=0.0
% INFO    : Bus 1341	: V=1.0278885, theta=-15.8397468 -> V=1.015872, theta=0.0
% INFO    : Bus 1342	: V=1.00328812, theta=-16.1983545 -> V=0.999999, theta=0.0
% INFO    : Bus 1343	: V=1.00290901, theta=-16.1748698 -> V=0.999999, theta=0.0
% INFO    : Bus 1344	: V=1.07625127, theta=-4.54667908 -> V=1.0397485, theta=0.0
% INFO    : Bus 1345	: V=1.07458069, theta=-28.3917214 -> V=1.04222, theta=0.0
% INFO    : Bus 2960	: V=1.04875304, theta=-24.1075046 -> V=1.04222, theta=0.0
% INFO    : Bus 1346	: V=1.028, theta=-11.7614577 -> V=0.999999, theta=0.0
% INFO    : Bus 1347	: V=1.0397515, theta=-16.4489338 -> V=0.999999, theta=0.0
% INFO    : Bus 1348	: V=1.06183175, theta=-11.0815853 -> V=1.006667, theta=0.0
% INFO    : Bus 1349	: V=1.02486959, theta=-16.1722379 -> V=0.999999, theta=0.0
% INFO    : Bus 1350	: V=1.08601954, theta=-7.03004192 -> V=1.044445, theta=0.0
% INFO    : Bus 1351	: V=1.04019405, theta=-17.9843064 -> V=1.044445, theta=0.0
% INFO    : Bus 1352	: V=0.998069199, theta=-12.6719332 -> V=0.999999, theta=0.0
% INFO    : Bus 1353	: V=1.06094778, theta=-14.5870016 -> V=1.044445, theta=0.0
% INFO    : Bus 1354	: V=1.00273886, theta=-29.856162 -> V=1.015872, theta=0.0
% INFO    : Bus 1355	: V=1.00947933, theta=-11.9792812 -> V=0.999999, theta=0.0
% INFO    : Bus 1356	: V=1.04195483, theta=-15.0765835 -> V=1.0377785, theta=0.0
% INFO    : Bus 1357	: V=1.03627625, theta=-11.1576299 -> V=0.999999, theta=0.0
% INFO    : Bus 1358	: V=1.05525367, theta=-11.8778608 -> V=0.9888895, theta=0.0
% INFO    : Bus 1359	: V=1.01878943, theta=-18.8305512 -> V=1.0387385, theta=0.0
% INFO    : Bus 1360	: V=1.0282417, theta=-17.1764751 -> V=0.999999, theta=0.0
% INFO    : Bus 1361	: V=1.06163305, theta=-14.1821205 -> V=1.033334, theta=0.0
% INFO    : Bus 1362	: V=1.07156369, theta=-18.0967882 -> V=1.04359, theta=0.0
% INFO    : Bus 1363	: V=1.08375526, theta=-13.8604308 -> V=1.051315, theta=0.0
% INFO    : Bus 1364	: V=1.06875627, theta=-7.38772846 -> V=0.9888895, theta=0.0
% INFO    : Bus 1365	: V=1.02287006, theta=-18.7259565 -> V=1.0000025, theta=0.0
% INFO    : Bus 1366	: V=1.06361362, theta=-14.106429 -> V=1.044445, theta=0.0
% INFO    : Bus 1367	: V=0.989908369, theta=-17.6996731 -> V=1.03507, theta=0.0
% INFO    : Bus 1368	: V=1.07012651, theta=-15.2910102 -> V=1.04222, theta=0.0
% INFO    : Bus 1369	: V=1.06304089, theta=-21.1610189 -> V=1.04222, theta=0.0
% INFO    : Bus 2834	: V=1.06304888, theta=-21.1600253 -> V=1.04222, theta=0.0
% INFO    : Bus 2835	: V=1.06304047, theta=-21.1610075 -> V=1.04222, theta=0.0
% INFO    : Bus 1370	: V=0.942187702, theta=-9.0699123 -> V=0.9444445, theta=0.0
% INFO    : Bus 1371	: V=1.06970635, theta=-6.7282328 -> V=1.01814, theta=0.0
% INFO    : Bus 1372	: V=1.04827199, theta=-11.2780913 -> V=1.0111115, theta=0.0
% INFO    : Bus 1373	: V=1.06660229, theta=-15.3455939 -> V=1.045605, theta=0.0
% INFO    : Bus 1374	: V=1.06297749, theta=-21.1689731 -> V=1.04222, theta=0.0
% INFO    : Bus 2836	: V=1.05911404, theta=-26.3339146 -> V=1.04222, theta=0.0
% INFO    : Bus 1375	: V=1.01559869, theta=-17.0535306 -> V=1.015872, theta=0.0
% INFO    : Bus 1376	: V=1.07696723, theta=-12.8247825 -> V=1.04222, theta=0.0
% INFO    : Bus 1377	: V=1.08725503, theta=-7.11131725 -> V=1.044445, theta=0.0
% INFO    : Bus 1378	: V=0.993058536, theta=-21.2311171 -> V=1.0000025, theta=0.0
% INFO    : Bus 1379	: V=1.07258678, theta=-14.0447162 -> V=1.04222, theta=0.0
% INFO    : Bus 1380	: V=1.06939943, theta=-12.6865115 -> V=1.051315, theta=0.0
% INFO    : Bus 1381	: V=1.03019726, theta=-13.2350198 -> V=1.015872, theta=0.0
% INFO    : Bus 1382	: V=1.05546937, theta=-19.4520684 -> V=1.04222, theta=0.0
% INFO    : Bus 1383	: V=1.05664331, theta=-11.2313282 -> V=0.9897895, theta=0.0
% INFO    : Bus 1384	: V=1.02812921, theta=-10.8930535 -> V=1.0377785, theta=0.0
% INFO    : Bus 1385	: V=1.08048264, theta=-12.8272516 -> V=1.04222, theta=0.0
% INFO    : Bus 1386	: V=1.08728574, theta=-3.33526345 -> V=1.0410685, theta=0.0
% INFO    : Bus 1387	: V=1.07743746, theta=-10.1554948 -> V=1.05263, theta=0.0
% INFO    : Bus 1388	: V=1.04370546, theta=-15.0751964 -> V=1.015872, theta=0.0
% INFO    : Bus 2837	: V=1.02089121, theta=-14.8908556 -> V=1.015872, theta=0.0
% INFO    : Bus 2838	: V=1.01403813, theta=-15.0961045 -> V=1.015872, theta=0.0
% INFO    : Bus 1389	: V=1.07805046, theta=-13.2586409 -> V=1.04222, theta=0.0
% INFO    : Bus 2839	: V=1.07816813, theta=-13.2531856 -> V=1.04222, theta=0.0
% INFO    : Bus 2840	: V=1.07819587, theta=-13.2576082 -> V=1.04222, theta=0.0
% INFO    : Bus 1390	: V=1.05367578, theta=-15.5584096 -> V=1.044445, theta=0.0
% INFO    : Bus 1391	: V=1.08077273, theta=-9.81833073 -> V=1.05263, theta=0.0
% INFO    : Bus 1392	: V=1.04105774, theta=0.723475585 -> V=1.04222, theta=0.0
% INFO    : Bus 2841	: V=1.04225052, theta=0.418212519 -> V=1.04222, theta=0.0
% INFO    : Bus 1393	: V=1.07661714, theta=-20.1896788 -> V=1.0, theta=0.0
% INFO    : Bus 2842	: V=1.07661714, theta=-20.1896788 -> V=1.0, theta=0.0
% INFO    : Bus 2843	: V=1.07616526, theta=-20.2451774 -> V=1.0, theta=0.0
% INFO    : Bus 1394	: V=1.07622458, theta=-20.2351694 -> V=1.04222, theta=0.0
% INFO    : Bus 2844	: V=1.07661714, theta=-20.1896788 -> V=1.04222, theta=0.0
% INFO    : Bus 1395	: V=1.03007991, theta=-14.4086292 -> V=1.015872, theta=0.0
% INFO    : Bus 1396	: V=1.05209676, theta=-14.4418047 -> V=1.0030475, theta=0.0
% INFO    : Bus 1397	: V=1.01095882, theta=-16.0555323 -> V=0.999999, theta=0.0
% INFO    : Bus 1398	: V=1.00725766, theta=-23.7392649 -> V=1.0000025, theta=0.0
% INFO    : Bus 1399	: V=1.05115174, theta=-20.4905189 -> V=1.044445, theta=0.0
% INFO    : Bus 2845	: V=1.05097129, theta=-20.5043255 -> V=1.044445, theta=0.0
% INFO    : Bus 1400	: V=1.0977337, theta=-0.703279705 -> V=1.05263, theta=0.0
% INFO    : Bus 2846	: V=1.09783827, theta=-0.694368103 -> V=1.05263, theta=0.0
% INFO    : Bus 2847	: V=1.09784036, theta=-0.694128407 -> V=1.05263, theta=0.0
% INFO    : Bus 2848	: V=1.0978335, theta=-0.694333888 -> V=1.05263, theta=0.0
% INFO    : Bus 1401	: V=1.07355227, theta=-8.87041212 -> V=1.0410035, theta=0.0
% INFO    : Bus 1402	: V=1.08317199, theta=-6.64524653 -> V=1.05263, theta=0.0
% INFO    : Bus 1403	: V=1.03248799, theta=-11.5977741 -> V=1.0377785, theta=0.0
% INFO    : Bus 1404	: V=1.03216541, theta=-10.4778474 -> V=1.0377785, theta=0.0
% INFO    : Bus 1405	: V=1.033, theta=-6.33926239 -> V=1.0, theta=0.0
% INFO    : Bus 2849	: V=1.033, theta=-6.36613565 -> V=1.0, theta=0.0
% INFO    : Bus 2850	: V=1.033, theta=-6.3200669 -> V=1.0, theta=0.0
% INFO    : Bus 1406	: V=1.03215135, theta=-10.4640626 -> V=1.0377785, theta=0.0
% INFO    : Bus 2851	: V=1.03215164, theta=-10.4642148 -> V=1.0377785, theta=0.0
% INFO    : Bus 2852	: V=1.03215147, theta=-10.464126 -> V=1.0377785, theta=0.0
% INFO    : Bus 1407	: V=1.06651706, theta=-20.1619658 -> V=1.044445, theta=0.0
% INFO    : Bus 1408	: V=1.05665459, theta=-19.2316855 -> V=1.044445, theta=0.0
% INFO    : Bus 2853	: V=1.05690987, theta=-19.223791 -> V=1.044445, theta=0.0
% INFO    : Bus 1409	: V=1.07594653, theta=-4.11947316 -> V=1.0417435, theta=0.0
% INFO    : Bus 1410	: V=1.08034895, theta=-12.8896247 -> V=1.04222, theta=0.0
% INFO    : Bus 1411	: V=1.0266674, theta=-15.7608323 -> V=0.999999, theta=0.0
% INFO    : Bus 1412	: V=1.02779747, theta=-14.2448253 -> V=0.999999, theta=0.0
% INFO    : Bus 1413	: V=1.02235617, theta=-11.9983716 -> V=1.0111115, theta=0.0
% INFO    : Bus 1414	: V=1.036, theta=-10.9234353 -> V=0.999999, theta=0.0
% INFO    : Bus 1415	: V=1.03878202, theta=-28.2566431 -> V=1.04222, theta=0.0
% INFO    : Bus 1416	: V=1.02597988, theta=-13.9272905 -> V=0.999999, theta=0.0
% INFO    : Bus 1417	: V=1.03800055, theta=-18.5547752 -> V=1.044445, theta=0.0
% INFO    : Bus 1418	: V=1.06955666, theta=-15.4389323 -> V=1.005124, theta=0.0
% INFO    : Bus 2854	: V=1.05463204, theta=-14.6954234 -> V=1.005124, theta=0.0
% INFO    : Bus 1419	: V=1.04802136, theta=-11.1599327 -> V=1.0111115, theta=0.0
% INFO    : Bus 1420	: V=1.02238842, theta=-14.8289916 -> V=0.999999, theta=0.0
% INFO    : Bus 1421	: V=1.06212174, theta=-20.4803628 -> V=1.044445, theta=0.0
% INFO    : Bus 2855	: V=1.05703692, theta=-19.9636138 -> V=1.044445, theta=0.0
% INFO    : Bus 1422	: V=1.07890399, theta=-13.0263567 -> V=1.04222, theta=0.0
% INFO    : Bus 1423	: V=1.03039098, theta=-16.2178716 -> V=0.999999, theta=0.0
% INFO    : Bus 1424	: V=1.02342461, theta=-14.3850163 -> V=0.999999, theta=0.0
% INFO    : Bus 1425	: V=1.02321462, theta=-23.8326716 -> V=1.015872, theta=0.0
% INFO    : Bus 1426	: V=1.08724286, theta=-7.11297006 -> V=1.044445, theta=0.0
% INFO    : Bus 1427	: V=1.03416013, theta=-16.5618771 -> V=1.015872, theta=0.0
% INFO    : Bus 1428	: V=1.06803475, theta=-13.7465186 -> V=1.04222, theta=0.0
% INFO    : Bus 1429	: V=1.03627922, theta=-16.7702523 -> V=1.0382085, theta=0.0
% INFO    : Bus 1431	: V=1.06807555, theta=-19.4838584 -> V=1.044445, theta=0.0
% INFO    : Bus 2856	: V=1.06431667, theta=-19.8668371 -> V=1.044445, theta=0.0
% INFO    : Bus 1432	: V=1.03952108, theta=-14.9233903 -> V=1.016517, theta=0.0
% INFO    : Bus 1433	: V=1.05643632, theta=-12.7735558 -> V=1.0377785, theta=0.0
% INFO    : Bus 1434	: V=1.06950976, theta=-28.1144698 -> V=1.04222, theta=0.0
% INFO    : Bus 1435	: V=1.04360573, theta=-16.1722398 -> V=1.000779, theta=0.0
% INFO    : Bus 1436	: V=1.0802443, theta=-11.6648175 -> V=1.044445, theta=0.0
% INFO    : Bus 2857	: V=1.0817399, theta=-8.7836711 -> V=1.044445, theta=0.0
% INFO    : Bus 1437	: V=1.0879983, theta=-7.79004147 -> V=1.05263, theta=0.0
% INFO    : Bus 1438	: V=1.06871978, theta=-10.0873098 -> V=1.04222, theta=0.0
% INFO    : Bus 1439	: V=1.05214941, theta=-15.6897064 -> V=1.0233335, theta=0.0
% INFO    : Bus 1440	: V=1.05763409, theta=-15.4907044 -> V=1.04222, theta=0.0
% INFO    : Bus 1441	: V=1.04873593, theta=-16.7147198 -> V=1.020457, theta=0.0
% INFO    : Bus 1442	: V=1.01793338, theta=-18.2601109 -> V=1.015872, theta=0.0
% INFO    : Bus 1443	: V=1.0461655, theta=-17.044012 -> V=1.0377785, theta=0.0
% INFO    : Bus 1444	: V=1.06376922, theta=-12.2011226 -> V=0.9888895, theta=0.0
% INFO    : Bus 2858	: V=1.06368635, theta=-12.2097852 -> V=0.9888895, theta=0.0
% INFO    : Bus 1445	: V=1.06332391, theta=-13.5475717 -> V=1.026667, theta=0.0
% INFO    : Bus 1446	: V=1.07323774, theta=-6.73352072 -> V=0.9888895, theta=0.0
% INFO    : Bus 1447	: V=0.990282663, theta=-21.1652639 -> V=1.015872, theta=0.0
% INFO    : Bus 1448	: V=1.00260423, theta=-21.9697022 -> V=1.0233335, theta=0.0
% INFO    : Bus 1449	: V=1.02853304, theta=-16.4154107 -> V=1.015872, theta=0.0
% INFO    : Bus 1450	: V=1.06916687, theta=-12.1965926 -> V=1.04222, theta=0.0
% INFO    : Bus 1451	: V=1.0746312, theta=-22.0319042 -> V=1.044445, theta=0.0
% INFO    : Bus 2859	: V=1.07469911, theta=-22.0223523 -> V=1.044445, theta=0.0
% INFO    : Bus 1453	: V=1.0660237, theta=-12.9912407 -> V=1.0064925, theta=0.0
% INFO    : Bus 1454	: V=1.0654032, theta=-10.2177315 -> V=1.045895, theta=0.0
% INFO    : Bus 1455	: V=1.07288037, theta=-7.11431651 -> V=1.05323, theta=0.0
% INFO    : Bus 1456	: V=1.01833376, theta=-20.5045629 -> V=1.0000025, theta=0.0
% INFO    : Bus 1457	: V=1.03846714, theta=-12.887961 -> V=0.999999, theta=0.0
% INFO    : Bus 1458	: V=1.02724863, theta=-12.1522624 -> V=1.0111115, theta=0.0
% INFO    : Bus 1459	: V=1.05493253, theta=-8.68252104 -> V=1.05263, theta=0.0
% INFO    : Bus 1460	: V=1.06692723, theta=-8.57290426 -> V=0.9888895, theta=0.0
% INFO    : Bus 1461	: V=1.06115992, theta=-20.790277 -> V=1.044445, theta=0.0
% INFO    : Bus 2860	: V=1.04524301, theta=-21.0311396 -> V=1.044445, theta=0.0
% INFO    : Bus 1462	: V=1.05639474, theta=-14.7781212 -> V=0.9888895, theta=0.0
% INFO    : Bus 1463	: V=1.06117278, theta=-20.8127705 -> V=1.04542, theta=0.0
% INFO    : Bus 2861	: V=1.06124931, theta=-20.8048392 -> V=1.04542, theta=0.0
% INFO    : Bus 1464	: V=1.05898497, theta=-21.108008 -> V=1.044445, theta=0.0
% INFO    : Bus 2862	: V=1.0592933, theta=-21.1933573 -> V=1.044445, theta=0.0
% INFO    : Bus 1465	: V=1.06127717, theta=-9.11887998 -> V=1.0111115, theta=0.0
% INFO    : Bus 1466	: V=1.05, theta=-6.38874841 -> V=1.0, theta=0.0
% INFO    : Bus 2863	: V=0.997063981, theta=-11.365979 -> V=1.0, theta=0.0
% INFO    : Bus 1467	: V=1.00639527, theta=-13.747543 -> V=0.999999, theta=0.0
% INFO    : Bus 1468	: V=1.04604767, theta=-9.51719567 -> V=1.0111115, theta=0.0
% INFO    : Bus 1469	: V=1.0198529, theta=-13.1684255 -> V=1.015872, theta=0.0
% INFO    : Bus 1470	: V=1.08968617, theta=-2.43896525 -> V=1.0398535, theta=0.0
% INFO    : Bus 1471	: V=1.08356671, theta=-7.7170404 -> V=1.044445, theta=0.0
% INFO    : Bus 1472	: V=1.00366897, theta=-16.1468148 -> V=0.999999, theta=0.0
% INFO    : Bus 1473	: V=1.01673123, theta=-22.8114533 -> V=1.0000025, theta=0.0
% INFO    : Bus 1474	: V=1.00141029, theta=-14.222438 -> V=1.015872, theta=0.0
% INFO    : Bus 1475	: V=1.00151857, theta=-28.6728012 -> V=1.015872, theta=0.0
% INFO    : Bus 1476	: V=1.01796358, theta=-18.6673153 -> V=0.999999, theta=0.0
% INFO    : Bus 1477	: V=1.06989105, theta=-9.94640498 -> V=1.033334, theta=0.0
% INFO    : Bus 1478	: V=1.03789575, theta=-14.792535 -> V=1.015872, theta=0.0
% INFO    : Bus 2864	: V=1.03395321, theta=-14.9197787 -> V=1.015872, theta=0.0
% INFO    : Bus 1479	: V=1.06932421, theta=-12.1359702 -> V=1.033334, theta=0.0
% INFO    : Bus 1480	: V=1.02635689, theta=-18.1876943 -> V=0.999999, theta=0.0
% INFO    : Bus 1481	: V=1.08222552, theta=-8.01748922 -> V=1.044445, theta=0.0
% INFO    : Bus 1482	: V=1.03527034, theta=-18.2719652 -> V=1.0000025, theta=0.0
% INFO    : Bus 1483	: V=1.030949, theta=-20.538931 -> V=1.0434545, theta=0.0
% INFO    : Bus 1484	: V=1.04079677, theta=-15.5356551 -> V=1.002384, theta=0.0
% INFO    : Bus 1485	: V=1.04945064, theta=-11.8356642 -> V=1.0111115, theta=0.0
% INFO    : Bus 1486	: V=0.97816643, theta=-21.6406446 -> V=0.999999, theta=0.0
% INFO    : Bus 1487	: V=1.0679101, theta=-5.6236572 -> V=1.0377785, theta=0.0
% INFO    : Bus 1488	: V=1.06544446, theta=-10.2182645 -> V=1.04623, theta=0.0
% INFO    : Bus 1489	: V=1.07048284, theta=-15.1084437 -> V=1.0382635, theta=0.0
% INFO    : Bus 1490	: V=1.03, theta=-11.888185 -> V=0.999999, theta=0.0
% INFO    : Bus 1491	: V=1.05579033, theta=-11.1429483 -> V=1.044445, theta=0.0
% INFO    : Bus 1492	: V=1.06060415, theta=-7.1121867 -> V=1.05263, theta=0.0
% INFO    : Bus 1493	: V=0.951090177, theta=-10.8536512 -> V=0.9444445, theta=0.0
% INFO    : Bus 1494	: V=1.07250854, theta=-5.67384518 -> V=1.0377785, theta=0.0
% INFO    : Bus 1495	: V=1.00725285, theta=-11.7877015 -> V=1.015872, theta=0.0
% INFO    : Bus 1496	: V=1.05884252, theta=-20.9826515 -> V=1.044445, theta=0.0
% INFO    : Bus 1497	: V=1.07127444, theta=-14.7323228 -> V=1.04222, theta=0.0
% INFO    : Bus 1498	: V=1.05998244, theta=-14.8001016 -> V=1.044445, theta=0.0
% INFO    : Bus 1499	: V=0.953646471, theta=-9.25775015 -> V=0.9444895, theta=0.0
% INFO    : Bus 1500	: V=1.05063369, theta=-10.5448076 -> V=1.0111115, theta=0.0
% INFO    : Bus 1502	: V=1.05436567, theta=-19.6141278 -> V=1.044445, theta=0.0
% INFO    : Bus 2865	: V=1.06515628, theta=-18.8595557 -> V=1.044445, theta=0.0
% INFO    : Bus 1503	: V=1.06503338, theta=-14.6756647 -> V=1.05263, theta=0.0
% INFO    : Bus 1504	: V=1.03520548, theta=-13.2182638 -> V=0.975, theta=0.0
% INFO    : Bus 1505	: V=1.0653426, theta=-8.58138008 -> V=1.0111115, theta=0.0
% INFO    : Bus 1506	: V=1.037, theta=-12.9554702 -> V=1.016412, theta=0.0
% INFO    : Bus 1507	: V=1.01767097, theta=-18.7758091 -> V=1.015872, theta=0.0
% INFO    : Bus 1508	: V=1.05261902, theta=-20.0755296 -> V=1.044445, theta=0.0
% INFO    : Bus 1509	: V=1.05858381, theta=-14.7331502 -> V=1.003859, theta=0.0
% INFO    : Bus 1510	: V=1.05885578, theta=-11.0967734 -> V=1.0131265, theta=0.0
% INFO    : Bus 1511	: V=1.04326871, theta=-10.1396176 -> V=1.0377785, theta=0.0
% INFO    : Bus 1512	: V=1.06096179, theta=-7.75613657 -> V=1.05263, theta=0.0
% INFO    : Bus 1514	: V=1.05116757, theta=-20.4914238 -> V=1.044445, theta=0.0
% INFO    : Bus 1515	: V=1.05310477, theta=-20.1070383 -> V=1.044445, theta=0.0
% INFO    : Bus 1516	: V=1.0601448, theta=-9.66457533 -> V=1.0111115, theta=0.0
% INFO    : Bus 1517	: V=1.03320456, theta=-11.1990201 -> V=1.015872, theta=0.0
% INFO    : Bus 1518	: V=1.01647321, theta=-11.4926165 -> V=1.0377785, theta=0.0
% INFO    : Bus 1519	: V=1.01804544, theta=-11.7637132 -> V=1.0111115, theta=0.0
% INFO    : Bus 1520	: V=1.05505637, theta=-19.2458892 -> V=1.044445, theta=0.0
% INFO    : Bus 1521	: V=1.02852617, theta=-18.9375025 -> V=1.015872, theta=0.0
% INFO    : Bus 1522	: V=1.07166577, theta=-14.5395281 -> V=1.04222, theta=0.0
% INFO    : Bus 1523	: V=1.0624723, theta=-12.5405989 -> V=0.9888895, theta=0.0
% INFO    : Bus 2866	: V=1.06225845, theta=-12.5595208 -> V=0.9888895, theta=0.0
% INFO    : Bus 1525	: V=1.06801051, theta=-14.7593136 -> V=1.0377785, theta=0.0
% INFO    : Bus 1526	: V=1.07649075, theta=-12.5838845 -> V=1.05263, theta=0.0
% INFO    : Bus 1527	: V=1.04088345, theta=-13.4332325 -> V=1.0111115, theta=0.0
% INFO    : Bus 1528	: V=0.985947602, theta=-14.8005268 -> V=0.999999, theta=0.0
% INFO    : Bus 1529	: V=1.04472634, theta=-17.9328306 -> V=1.0000025, theta=0.0
% INFO    : Bus 1530	: V=1.04471499, theta=-17.9326826 -> V=1.0000025, theta=0.0
% INFO    : Bus 1531	: V=1.05680204, theta=-13.8562389 -> V=1.0111115, theta=0.0
% INFO    : Bus 1532	: V=1.08268706, theta=-4.61377711 -> V=1.05263, theta=0.0
% INFO    : Bus 1533	: V=0.999160813, theta=-21.2934501 -> V=1.0000025, theta=0.0
% INFO    : Bus 1534	: V=1.05654769, theta=-21.5291877 -> V=1.044445, theta=0.0
% INFO    : Bus 1535	: V=1.02241141, theta=-26.0995905 -> V=1.015872, theta=0.0
% INFO    : Bus 1536	: V=0.983853202, theta=-29.3708216 -> V=1.015872, theta=0.0
% INFO    : Bus 1538	: V=1.03197522, theta=-14.9444051 -> V=1.0377785, theta=0.0
% INFO    : Bus 1539	: V=1.06453435, theta=-10.8831169 -> V=1.05263, theta=0.0
% INFO    : Bus 2867	: V=1.06110133, theta=-11.2950667 -> V=1.05263, theta=0.0
% INFO    : Bus 1540	: V=1.00480958, theta=-27.7486828 -> V=1.015872, theta=0.0
% INFO    : Bus 1541	: V=1.06243068, theta=-8.32297086 -> V=1.0111115, theta=0.0
% INFO    : Bus 1542	: V=1.04134937, theta=-23.2109919 -> V=1.04222, theta=0.0
% INFO    : Bus 1543	: V=1.04601661, theta=-10.5627487 -> V=1.015872, theta=0.0
% INFO    : Bus 1544	: V=1.06989124, theta=-9.16896361 -> V=1.04222, theta=0.0
% INFO    : Bus 1545	: V=1.04753119, theta=-10.9339898 -> V=1.0111115, theta=0.0
% INFO    : Bus 1546	: V=1.02360066, theta=-12.9510101 -> V=1.044445, theta=0.0
% INFO    : Bus 2868	: V=1.02361266, theta=-12.9464883 -> V=1.044445, theta=0.0
% INFO    : Bus 1547	: V=1.01401849, theta=-24.4093471 -> V=1.015872, theta=0.0
% INFO    : Bus 1548	: V=1.0305943, theta=-19.6163466 -> V=1.015872, theta=0.0
% INFO    : Bus 1549	: V=1.05695613, theta=-19.2008395 -> V=1.044445, theta=0.0
% INFO    : Bus 1550	: V=1.02901624, theta=-14.9094553 -> V=1.015872, theta=0.0
% INFO    : Bus 1551	: V=1.06710178, theta=-10.5413368 -> V=1.0288895, theta=0.0
% INFO    : Bus 1552	: V=0.991891703, theta=-29.6833213 -> V=1.015872, theta=0.0
% INFO    : Bus 1553	: V=1.05190241, theta=-24.8118608 -> V=1.043285, theta=0.0
% INFO    : Bus 1554	: V=1.08760467, theta=-12.6907173 -> V=1.003475, theta=0.0
% INFO    : Bus 1555	: V=1.02146061, theta=-11.2779171 -> V=1.0377785, theta=0.0
% INFO    : Bus 1556	: V=1.07238463, theta=-30.5197581 -> V=1.04222, theta=0.0
% INFO    : Bus 1557	: V=1.02490618, theta=-15.3289107 -> V=0.999999, theta=0.0
% INFO    : Bus 1558	: V=1.08881556, theta=-1.74933902 -> V=1.05263, theta=0.0
% INFO    : Bus 2869	: V=1.08881547, theta=-1.74933863 -> V=1.05263, theta=0.0
% INFO    : Bus 1559	: V=1.05906068, theta=-11.7831258 -> V=1.0111115, theta=0.0
% INFO    : Bus 2870	: V=1.07499456, theta=-8.4653684 -> V=1.0111115, theta=0.0
% INFO    : Bus 1560	: V=1.03465532, theta=-14.8017283 -> V=1.002499, theta=0.0
% INFO    : Bus 1561	: V=1.03485841, theta=-14.7908102 -> V=1.002554, theta=0.0
% INFO    : Bus 2871	: V=1.03465532, theta=-14.8017283 -> V=1.002554, theta=0.0
% INFO    : Bus 1562	: V=0.989405009, theta=-20.7655937 -> V=0.999999, theta=0.0
% INFO    : Bus 1563	: V=1.05783511, theta=-21.2558351 -> V=1.044445, theta=0.0
% INFO    : Bus 2872	: V=1.06353654, theta=-19.4150101 -> V=1.044445, theta=0.0
% INFO    : Bus 1564	: V=1.06833459, theta=-11.4479001 -> V=1.016682, theta=0.0
% INFO    : Bus 1565	: V=1.06922189, theta=-10.5936015 -> V=1.04222, theta=0.0
% INFO    : Bus 1566	: V=1.01698659, theta=-15.4556159 -> V=1.000209, theta=0.0
% INFO    : Bus 1567	: V=1.08422065, theta=-3.61795026 -> V=1.0424885, theta=0.0
% INFO    : Bus 1568	: V=1.10592334, theta=1.57163533 -> V=1.055285, theta=0.0
% INFO    : Bus 1569	: V=0.927097043, theta=-10.8289586 -> V=0.9444445, theta=0.0
% INFO    : Bus 1570	: V=1.05757062, theta=-18.9819376 -> V=1.0, theta=0.0
% INFO    : Bus 1571	: V=1.05770289, theta=-18.9651171 -> V=1.04307, theta=0.0
% INFO    : Bus 1572	: V=1.05785081, theta=-17.5232945 -> V=1.044445, theta=0.0
% INFO    : Bus 1573	: V=1.018, theta=-14.2356669 -> V=0.999999, theta=0.0
% INFO    : Bus 1574	: V=1.04922545, theta=-12.9291152 -> V=0.9888895, theta=0.0
% INFO    : Bus 2873	: V=1.0492746, theta=-12.903685 -> V=0.9888895, theta=0.0
% INFO    : Bus 1575	: V=1.0773045, theta=-19.3242582 -> V=1.045415, theta=0.0
% INFO    : Bus 1576	: V=0.9710112, theta=-27.8451073 -> V=1.012164, theta=0.0
% INFO    : Bus 1577	: V=1.01603761, theta=-19.5904107 -> V=1.015872, theta=0.0
% INFO    : Bus 2874	: V=1.01796468, theta=-15.0808581 -> V=1.015872, theta=0.0
% INFO    : Bus 1578	: V=1.05401924, theta=-16.9504148 -> V=1.015872, theta=0.0
% INFO    : Bus 1579	: V=1.06853551, theta=-12.4823711 -> V=1.04222, theta=0.0
% INFO    : Bus 1580	: V=1.03952853, theta=-14.9238897 -> V=1.016522, theta=0.0
% INFO    : Bus 1581	: V=1.07165307, theta=-13.3233413 -> V=1.04222, theta=0.0
% INFO    : Bus 1582	: V=1.0425288, theta=-18.9320342 -> V=1.0000025, theta=0.0
% INFO    : Bus 1583	: V=1.06046355, theta=-14.4128414 -> V=1.044445, theta=0.0
% INFO    : Bus 1584	: V=1.00228438, theta=-16.5034167 -> V=0.999999, theta=0.0
% INFO    : Bus 1585	: V=1.04429963, theta=-10.7690374 -> V=1.017217, theta=0.0
% INFO    : Bus 1586	: V=1.06522358, theta=-8.52886619 -> V=1.0111115, theta=0.0
% INFO    : Bus 1587	: V=1.03599566, theta=-10.7415259 -> V=1.001074, theta=0.0
% INFO    : Bus 2875	: V=1.03599397, theta=-10.7414977 -> V=1.001074, theta=0.0
% INFO    : Bus 1588	: V=1.02570888, theta=-16.9003323 -> V=0.999999, theta=0.0
% INFO    : Bus 1589	: V=1.00814489, theta=-19.8154184 -> V=1.015872, theta=0.0
% INFO    : Bus 1590	: V=1.0596187, theta=-14.7674165 -> V=1.033334, theta=0.0
% INFO    : Bus 1591	: V=1.01792885, theta=-19.4034069 -> V=1.015872, theta=0.0
% INFO    : Bus 1592	: V=1.0071852, theta=-26.8468465 -> V=1.015872, theta=0.0
% INFO    : Bus 1593	: V=1.012, theta=-22.4598228 -> V=1.0, theta=0.0
% INFO    : Bus 1594	: V=1.015, theta=-24.8325457 -> V=1.021962, theta=0.0
% INFO    : Bus 1595	: V=1.00527859, theta=-23.411173 -> V=1.0233335, theta=0.0
% INFO    : Bus 1596	: V=0.985291056, theta=-33.2986964 -> V=1.015872, theta=0.0
% INFO    : Bus 2876	: V=0.985968405, theta=-33.2003083 -> V=1.015872, theta=0.0
% INFO    : Bus 1597	: V=1.03378098, theta=-9.05853287 -> V=1.000179, theta=0.0
% INFO    : Bus 1598	: V=1.07211632, theta=-10.9722286 -> V=1.04222, theta=0.0
% INFO    : Bus 1599	: V=1.08426854, theta=-7.20339001 -> V=1.051315, theta=0.0
% INFO    : Bus 2877	: V=1.0842704, theta=-7.19717866 -> V=1.051315, theta=0.0
% INFO    : Bus 1600	: V=1.02886594, theta=-12.1872627 -> V=0.999999, theta=0.0
% INFO    : Bus 1602	: V=1.06258776, theta=-9.34872757 -> V=1.0377785, theta=0.0
% INFO    : Bus 1603	: V=1.06648816, theta=-5.53366374 -> V=1.05263, theta=0.0
% INFO    : Bus 1604	: V=1.02733699, theta=-15.996044 -> V=1.015872, theta=0.0
% INFO    : Bus 1605	: V=1.06787837, theta=-11.8859141 -> V=1.04359, theta=0.0
% INFO    : Bus 1606	: V=1.03, theta=-12.0285652 -> V=0.999999, theta=0.0
% INFO    : Bus 1607	: V=1.02542977, theta=-22.6859379 -> V=1.0000025, theta=0.0
% INFO    : Bus 1608	: V=1.06883541, theta=-10.1717983 -> V=1.04527, theta=0.0
% INFO    : Bus 1609	: V=1.05034963, theta=-15.326239 -> V=1.001209, theta=0.0
% INFO    : Bus 1610	: V=1.04678928, theta=-15.5591565 -> V=1.000839, theta=0.0
% INFO    : Bus 1611	: V=1.0643433, theta=-12.2710386 -> V=1.04222, theta=0.0
% INFO    : Bus 2878	: V=1.06315414, theta=-12.523093 -> V=1.04222, theta=0.0
% INFO    : Bus 1612	: V=1.001, theta=-12.1461162 -> V=0.999999, theta=0.0
% INFO    : Bus 1613	: V=1.01891794, theta=-16.2368529 -> V=0.999999, theta=0.0
% INFO    : Bus 1614	: V=1.066, theta=-8.54162653 -> V=1.0111115, theta=0.0
% INFO    : Bus 1615	: V=1.028, theta=-11.542311 -> V=0.999999, theta=0.0
% INFO    : Bus 1616	: V=1.07621706, theta=-4.02603722 -> V=1.0409885, theta=0.0
% INFO    : Bus 2952	: V=1.07984385, theta=-3.38968161 -> V=1.0409885, theta=0.0
% INFO    : Bus 1617	: V=0.932964211, theta=-10.4390942 -> V=0.9444445, theta=0.0
% INFO    : Bus 1618	: V=1.05490308, theta=-19.0908705 -> V=1.0, theta=0.0
% INFO    : Bus 2879	: V=1.05490056, theta=-19.095982 -> V=1.0, theta=0.0
% INFO    : Bus 2880	: V=1.05489493, theta=-19.090959 -> V=1.0, theta=0.0
% INFO    : Bus 1619	: V=1.05493954, theta=-19.0823289 -> V=1.04222, theta=0.0
% INFO    : Bus 1620	: V=1.08488911, theta=-2.48173964 -> V=1.0396335, theta=0.0
% INFO    : Bus 1621	: V=1.03209437, theta=-14.0229998 -> V=0.999999, theta=0.0
% INFO    : Bus 2881	: V=1.03214241, theta=-14.0323361 -> V=0.999999, theta=0.0
% INFO    : Bus 1622	: V=1.07677113, theta=-19.7071356 -> V=1.0, theta=0.0
% INFO    : Bus 1623	: V=1.07688117, theta=-19.6827237 -> V=1.04222, theta=0.0
% INFO    : Bus 1624	: V=1.01531521, theta=-19.1234058 -> V=1.0000025, theta=0.0
% INFO    : Bus 1625	: V=1.00661335, theta=-33.3634697 -> V=1.015872, theta=0.0
% INFO    : Bus 1626	: V=0.98973154, theta=-30.7957953 -> V=1.0116965, theta=0.0
% INFO    : Bus 1627	: V=1.01337039, theta=-13.3415152 -> V=0.999999, theta=0.0
% INFO    : Bus 1628	: V=0.95357914, theta=-9.26428382 -> V=0.9444895, theta=0.0
% INFO    : Bus 1629	: V=1.02366497, theta=-16.405763 -> V=0.999999, theta=0.0
% INFO    : Bus 1630	: V=1.02693958, theta=-10.6077202 -> V=1.015872, theta=0.0
% INFO    : Bus 1631	: V=1.04825717, theta=-20.7497218 -> V=1.044445, theta=0.0
% INFO    : Bus 2882	: V=1.05677635, theta=-19.2382118 -> V=1.044445, theta=0.0
% INFO    : Bus 1632	: V=1.02129646, theta=-13.0932759 -> V=1.015872, theta=0.0
% INFO    : Bus 1633	: V=1.05671398, theta=-11.6977662 -> V=1.0395585, theta=0.0
% INFO    : Bus 1634	: V=1.06998374, theta=-15.5591309 -> V=1.0, theta=0.0
% INFO    : Bus 1635	: V=1.07013647, theta=-15.531625 -> V=1.04222, theta=0.0
% INFO    : Bus 1636	: V=1.04242849, theta=-17.7047983 -> V=1.044445, theta=0.0
% INFO    : Bus 1637	: V=1.05094261, theta=-20.5487447 -> V=1.044445, theta=0.0
% INFO    : Bus 1638	: V=1.06215928, theta=-9.18448662 -> V=1.046025, theta=0.0
% INFO    : Bus 1639	: V=1.04701098, theta=-14.3790066 -> V=1.015872, theta=0.0
% INFO    : Bus 1640	: V=1.0297171, theta=-12.5114499 -> V=0.999999, theta=0.0
% INFO    : Bus 1641	: V=1.00146081, theta=-33.5152539 -> V=1.015403, theta=0.0
% INFO    : Bus 1643	: V=0.980823071, theta=-22.1282798 -> V=0.999999, theta=0.0
% INFO    : Bus 1644	: V=1.06399111, theta=-12.0060907 -> V=0.9888895, theta=0.0
% INFO    : Bus 2883	: V=1.06428637, theta=-12.0019989 -> V=0.9888895, theta=0.0
% INFO    : Bus 1645	: V=1.07199914, theta=-12.1703245 -> V=1.044445, theta=0.0
% INFO    : Bus 1646	: V=1.02780305, theta=-11.7735675 -> V=0.999999, theta=0.0
% INFO    : Bus 1647	: V=0.982885932, theta=-14.9982378 -> V=1.015872, theta=0.0
% INFO    : Bus 1648	: V=1.02258302, theta=-17.0694288 -> V=0.999999, theta=0.0
% INFO    : Bus 1649	: V=0.960526748, theta=-25.297421 -> V=0.999999, theta=0.0
% INFO    : Bus 1650	: V=1.03550152, theta=-16.0350025 -> V=1.002309, theta=0.0
% INFO    : Bus 1651	: V=1.0070846, theta=-32.9608563 -> V=1.015872, theta=0.0
% INFO    : Bus 1652	: V=1.03388583, theta=-13.7363947 -> V=1.015872, theta=0.0
% INFO    : Bus 1653	: V=1.0665048, theta=-14.6312256 -> V=1.0299985, theta=0.0
% INFO    : Bus 1654	: V=1.06930749, theta=-12.1548378 -> V=1.04222, theta=0.0
% INFO    : Bus 1655	: V=0.989411002, theta=-16.0235269 -> V=0.999999, theta=0.0
% INFO    : Bus 1656	: V=1.03623062, theta=-14.415139 -> V=1.015872, theta=0.0
% INFO    : Bus 1657	: V=1.00213278, theta=-21.7468522 -> V=1.0233335, theta=0.0
% INFO    : Bus 1658	: V=1.0360366, theta=-15.3147597 -> V=1.0000025, theta=0.0
% INFO    : Bus 2884	: V=1.02373608, theta=-21.610377 -> V=1.0000025, theta=0.0
% INFO    : Bus 1659	: V=1.05024783, theta=-14.5357161 -> V=1.044445, theta=0.0
% INFO    : Bus 1660	: V=1.03094197, theta=-15.9407395 -> V=1.015872, theta=0.0
% INFO    : Bus 1661	: V=1.04763958, theta=-16.5059582 -> V=1.044445, theta=0.0
% INFO    : Bus 1662	: V=1.02696927, theta=-15.2158523 -> V=1.001219, theta=0.0
% INFO    : Bus 2885	: V=1.01860557, theta=-13.541043 -> V=1.001219, theta=0.0
% INFO    : Bus 1663	: V=1.05705796, theta=-11.2791495 -> V=1.0111115, theta=0.0
% INFO    : Bus 1664	: V=1.08310462, theta=-4.68174106 -> V=1.05263, theta=0.0
% INFO    : Bus 2886	: V=1.08196888, theta=-4.74142289 -> V=1.05263, theta=0.0
% INFO    : Bus 1665	: V=1.08120017, theta=-4.69361945 -> V=1.0288895, theta=0.0
% INFO    : Bus 1666	: V=1.024, theta=-9.9503884 -> V=1.0, theta=0.0
% INFO    : Bus 2887	: V=1.024, theta=-9.95927649 -> V=1.0, theta=0.0
% INFO    : Bus 2888	: V=1.024, theta=-9.95102326 -> V=1.0, theta=0.0
% INFO    : Bus 1667	: V=1.02379185, theta=-11.0858231 -> V=1.0377785, theta=0.0
% INFO    : Bus 2890	: V=1.0237918, theta=-11.0857325 -> V=1.0377785, theta=0.0
% INFO    : Bus 2891	: V=1.02379477, theta=-11.0974342 -> V=1.0377785, theta=0.0
% INFO    : Bus 2892	: V=1.0237918, theta=-11.085739 -> V=1.0377785, theta=0.0
% INFO    : Bus 1668	: V=1.02379477, theta=-11.0974342 -> V=1.0377785, theta=0.0
% INFO    : Bus 1669	: V=1.07912586, theta=-4.77597255 -> V=1.0393335, theta=0.0
% INFO    : Bus 1670	: V=1.00724931, theta=-28.7620457 -> V=1.015872, theta=0.0
% INFO    : Bus 1671	: V=1.036, theta=-15.6340371 -> V=1.0158755, theta=0.0
% INFO    : Bus 1672	: V=0.988190387, theta=-17.986028 -> V=1.0345585, theta=0.0
% INFO    : Bus 2893	: V=0.98891604, theta=-17.8210352 -> V=1.0345585, theta=0.0
% INFO    : Bus 1673	: V=1.10648798, theta=-11.3034114 -> V=1.036777, theta=0.0
% INFO    : Bus 2894	: V=1.10648798, theta=-11.3034114 -> V=1.036777, theta=0.0
% INFO    : Bus 1674	: V=1.06776134, theta=-11.3034114 -> V=1.0233335, theta=0.0
% INFO    : Bus 1675	: V=0.999827905, theta=-19.0270688 -> V=1.0, theta=0.0
% INFO    : Bus 1676	: V=0.999827905, theta=-19.0270688 -> V=0.999999, theta=0.0
% INFO    : Bus 1677	: V=1.06254707, theta=-12.0819475 -> V=1.05263, theta=0.0
% INFO    : Bus 1678	: V=1.02424082, theta=-17.5785869 -> V=1.015872, theta=0.0
% INFO    : Bus 1679	: V=1.048, theta=-12.7942595 -> V=1.0, theta=0.0
% INFO    : Bus 1680	: V=1.04436977, theta=-13.91536 -> V=1.001509, theta=0.0
% INFO    : Bus 1681	: V=1.0487969, theta=-14.1715237 -> V=1.044445, theta=0.0
% INFO    : Bus 1682	: V=1.05389358, theta=-15.0815029 -> V=1.013334, theta=0.0
% INFO    : Bus 1683	: V=1.02143897, theta=-26.1642563 -> V=1.015872, theta=0.0
% INFO    : Bus 1684	: V=1.02556546, theta=-17.6749651 -> V=1.021072, theta=0.0
% INFO    : Bus 1685	: V=1.03312334, theta=-11.1969838 -> V=1.015872, theta=0.0
% INFO    : Bus 1686	: V=1.07573845, theta=-10.0116449 -> V=1.0233335, theta=0.0
% INFO    : Bus 1687	: V=1.06663289, theta=-8.82618435 -> V=1.04222, theta=0.0
% INFO    : Bus 1688	: V=1.0628725, theta=-9.97274217 -> V=1.04222, theta=0.0
% INFO    : Bus 1689	: V=1.07999126, theta=-5.77500746 -> V=1.051315, theta=0.0
% INFO    : Bus 1690	: V=1.02385365, theta=-20.1381381 -> V=1.015872, theta=0.0
% INFO    : Bus 1691	: V=1.02155701, theta=-16.0033548 -> V=1.001264, theta=0.0
% INFO    : Bus 1692	: V=1.01318819, theta=-13.2579309 -> V=0.999999, theta=0.0
% INFO    : Bus 1693	: V=1.03900141, theta=-10.748486 -> V=1.044445, theta=0.0
% INFO    : Bus 1694	: V=1.0584367, theta=-14.730187 -> V=1.003824, theta=0.0
% INFO    : Bus 1695	: V=1.03037965, theta=-15.9938705 -> V=1.015872, theta=0.0
% INFO    : Bus 1697	: V=1.06686503, theta=-13.441194 -> V=1.044445, theta=0.0
% INFO    : Bus 1698	: V=1.07286822, theta=-10.1400934 -> V=1.05263, theta=0.0
% INFO    : Bus 1699	: V=1.02032121, theta=-13.5895592 -> V=0.999999, theta=0.0
% INFO    : Bus 1700	: V=0.989587812, theta=-17.6708159 -> V=1.0, theta=0.0
% INFO    : Bus 1701	: V=1.04237032, theta=-17.6574042 -> V=1.044445, theta=0.0
% INFO    : Bus 1702	: V=1.0252473, theta=-7.62916586 -> V=1.048475, theta=0.0
% INFO    : Bus 1703	: V=1.00978, theta=-19.4945129 -> V=1.000749, theta=0.0
% INFO    : Bus 1704	: V=1.02661053, theta=-17.1541679 -> V=0.999999, theta=0.0
% INFO    : Bus 1705	: V=1.0118419, theta=-18.9152407 -> V=0.999999, theta=0.0
% INFO    : Bus 1706	: V=1.02662473, theta=-22.1731857 -> V=1.0000025, theta=0.0
% INFO    : Bus 1707	: V=1.0844421, theta=-7.36442203 -> V=1.05263, theta=0.0
% INFO    : Bus 1708	: V=1.03, theta=-17.200478 -> V=1.0377785, theta=0.0
% INFO    : Bus 1709	: V=1.07570573, theta=-9.00177203 -> V=1.04222, theta=0.0
% INFO    : Bus 2895	: V=1.07801513, theta=-8.31621809 -> V=1.04222, theta=0.0
% INFO    : Bus 1710	: V=1.08702084, theta=-4.48154115 -> V=1.051315, theta=0.0
% INFO    : Bus 1711	: V=1.05541484, theta=-14.9663446 -> V=1.04222, theta=0.0
% INFO    : Bus 1712	: V=1.05931139, theta=-26.4493026 -> V=1.04222, theta=0.0
% INFO    : Bus 1713	: V=1.01454511, theta=-13.5438069 -> V=1.015872, theta=0.0
% INFO    : Bus 1714	: V=1.01454127, theta=-13.5437246 -> V=1.015872, theta=0.0
% INFO    : Bus 1715	: V=1.04800601, theta=-21.003711 -> V=1.044445, theta=0.0
% INFO    : Bus 1716	: V=0.952695218, theta=-9.30601496 -> V=0.9444445, theta=0.0
% INFO    : Bus 1717	: V=1.03460826, theta=-16.4223049 -> V=1.001344, theta=0.0
% INFO    : Bus 1718	: V=1.07452055, theta=-22.1207198 -> V=1.044445, theta=0.0
% INFO    : Bus 1719	: V=1.08415585, theta=-7.81292286 -> V=1.05263, theta=0.0
% INFO    : Bus 2896	: V=1.08359892, theta=-7.80851537 -> V=1.05263, theta=0.0
% INFO    : Bus 1720	: V=1.04909884, theta=-13.6857483 -> V=1.017917, theta=0.0
% INFO    : Bus 2994	: V=1.04825856, theta=-14.3338355 -> V=1.017917, theta=0.0
% INFO    : Bus 1721	: V=1.06130092, theta=-10.5448552 -> V=1.04222, theta=0.0
% INFO    : Bus 1722	: V=1.0563643, theta=-16.5632978 -> V=1.044445, theta=0.0
% INFO    : Bus 1723	: V=1.07262119, theta=-12.0970712 -> V=1.05263, theta=0.0
% INFO    : Bus 2897	: V=1.07328778, theta=-11.8688136 -> V=1.05263, theta=0.0
% INFO    : Bus 1724	: V=1.05567368, theta=-24.3829215 -> V=1.04222, theta=0.0
% INFO    : Bus 1725	: V=1.0363175, theta=-16.3073813 -> V=1.015872, theta=0.0
% INFO    : Bus 1726	: V=0.981897806, theta=-23.8546498 -> V=1.002234, theta=0.0
% INFO    : Bus 1727	: V=1.05529887, theta=-11.8844186 -> V=0.9888895, theta=0.0
% INFO    : Bus 1728	: V=1.05696191, theta=-21.0858435 -> V=1.044445, theta=0.0
% INFO    : Bus 1729	: V=1.03770871, theta=-14.2003991 -> V=1.015872, theta=0.0
% INFO    : Bus 1730	: V=1.01750989, theta=-16.3881656 -> V=1.0377785, theta=0.0
% INFO    : Bus 1731	: V=1.01683716, theta=-14.4202456 -> V=0.999999, theta=0.0
% INFO    : Bus 1732	: V=1.08191786, theta=-10.3134376 -> V=1.05263, theta=0.0
% INFO    : Bus 2898	: V=1.08183741, theta=-10.3231888 -> V=1.05263, theta=0.0
% INFO    : Bus 1733	: V=1.03729782, theta=-20.6775703 -> V=1.044445, theta=0.0
% INFO    : Bus 1734	: V=1.04605533, theta=-20.9722196 -> V=1.044445, theta=0.0
% INFO    : Bus 1735	: V=1.08491566, theta=-5.75986841 -> V=1.05263, theta=0.0
% INFO    : Bus 1736	: V=1.06524252, theta=-14.7945166 -> V=1.0377785, theta=0.0
% INFO    : Bus 2899	: V=1.06586196, theta=-15.071202 -> V=1.0377785, theta=0.0
% INFO    : Bus 1737	: V=1.0112609, theta=-22.3626069 -> V=1.0000025, theta=0.0
% INFO    : Bus 1739	: V=1.07076877, theta=-14.1962874 -> V=1.04573, theta=0.0
% INFO    : Bus 1740	: V=1.08281289, theta=-9.23417377 -> V=1.05263, theta=0.0
% INFO    : Bus 1741	: V=0.95743483, theta=-13.3791283 -> V=0.9444445, theta=0.0
% INFO    : Bus 1742	: V=1.00880347, theta=-13.7965029 -> V=0.999999, theta=0.0
% INFO    : Bus 1743	: V=1.0457837, theta=-17.126521 -> V=1.044445, theta=0.0
% INFO    : Bus 1744	: V=1.0287117, theta=-28.2441451 -> V=1.015872, theta=0.0
% INFO    : Bus 1745	: V=1.05269071, theta=-24.5240704 -> V=1.04222, theta=0.0
% INFO    : Bus 1746	: V=1.05362924, theta=-22.6145693 -> V=1.051315, theta=0.0
% INFO    : Bus 1747	: V=1.0248899, theta=-15.0800904 -> V=1.015872, theta=0.0
% INFO    : Bus 1748	: V=1.06835425, theta=-26.0135129 -> V=1.04222, theta=0.0
% INFO    : Bus 1749	: V=1.03844055, theta=-11.6352355 -> V=1.015872, theta=0.0
% INFO    : Bus 1750	: V=1.04045551, theta=-15.3057733 -> V=1.003849, theta=0.0
% INFO    : Bus 1751	: V=1.04725637, theta=-12.1549443 -> V=1.0111115, theta=0.0
% INFO    : Bus 1752	: V=1.03045449, theta=-11.2049532 -> V=1.015872, theta=0.0
% INFO    : Bus 2900	: V=1.03024627, theta=-11.2014166 -> V=1.015872, theta=0.0
% INFO    : Bus 1753	: V=1.04288647, theta=1.40351183 -> V=1.033334, theta=0.0
% INFO    : Bus 2901	: V=1.0443038, theta=0.917780724 -> V=1.033334, theta=0.0
% INFO    : Bus 2902	: V=1.04256945, theta=1.21377915 -> V=1.033334, theta=0.0
% INFO    : Bus 2903	: V=1.04133763, theta=1.35868017 -> V=1.033334, theta=0.0
% INFO    : Bus 1754	: V=1.02733914, theta=-10.803788 -> V=1.015872, theta=0.0
% INFO    : Bus 1755	: V=1.01507461, theta=-19.0274209 -> V=1.015872, theta=0.0
% INFO    : Bus 1756	: V=1.06282699, theta=-11.287393 -> V=0.9888895, theta=0.0
% INFO    : Bus 1757	: V=1.06285143, theta=-11.2772692 -> V=0.9888895, theta=0.0
% INFO    : Bus 1758	: V=1.06666727, theta=-6.95660143 -> V=1.04222, theta=0.0
% INFO    : Bus 2904	: V=1.04080524, theta=0.689511616 -> V=1.04222, theta=0.0
% INFO    : Bus 2905	: V=1.03940896, theta=0.648485395 -> V=1.04222, theta=0.0
% INFO    : Bus 2906	: V=1.04096776, theta=0.694275954 -> V=1.04222, theta=0.0
% INFO    : Bus 2907	: V=1.04111598, theta=0.833724957 -> V=1.04222, theta=0.0
% INFO    : Bus 2908	: V=1.03975098, theta=0.807378386 -> V=1.04222, theta=0.0
% INFO    : Bus 2909	: V=1.0417245, theta=0.268309339 -> V=1.04222, theta=0.0
% INFO    : Bus 2910	: V=1.04058739, theta=0.551694342 -> V=1.04222, theta=0.0
% INFO    : Bus 2911	: V=1.04214247, theta=0.401298748 -> V=1.04222, theta=0.0
% INFO    : Bus 1759	: V=1.0939278, theta=-1.71624559 -> V=1.051315, theta=0.0
% INFO    : Bus 1760	: V=1.04040195, theta=-14.8540567 -> V=1.0013775, theta=0.0
% INFO    : Bus 1761	: V=1.09105475, theta=-12.4904817 -> V=1.00445, theta=0.0
% INFO    : Bus 1762	: V=1.03121937, theta=-17.5454754 -> V=1.044445, theta=0.0
% INFO    : Bus 1763	: V=1.07148666, theta=-7.84617804 -> V=0.9888895, theta=0.0
% INFO    : Bus 2912	: V=1.07127996, theta=-7.86022998 -> V=0.9888895, theta=0.0
% INFO    : Bus 2913	: V=1.07150111, theta=-7.84422255 -> V=0.9888895, theta=0.0
% INFO    : Bus 1764	: V=1.05059168, theta=-20.5906155 -> V=1.044445, theta=0.0
% INFO    : Bus 1765	: V=1.0765571, theta=-7.26814353 -> V=1.0411985, theta=0.0
% INFO    : Bus 1766	: V=0.998789469, theta=-30.1060548 -> V=1.015872, theta=0.0
% INFO    : Bus 1767	: V=1.04248656, theta=-27.5124754 -> V=1.04222, theta=0.0
% INFO    : Bus 1768	: V=1.07520547, theta=-10.5501681 -> V=1.042585, theta=0.0
% INFO    : Bus 1769	: V=1.03194165, theta=-12.1958226 -> V=1.0025415, theta=0.0
% INFO    : Bus 1770	: V=0.968545837, theta=-17.3325882 -> V=0.999999, theta=0.0
% INFO    : Bus 1771	: V=0.999615842, theta=-32.1075516 -> V=1.015872, theta=0.0
% INFO    : Bus 1772	: V=1.03896183, theta=-28.20718 -> V=1.04222, theta=0.0
% INFO    : Bus 1773	: V=0.95743483, theta=-13.3791283 -> V=0.9444445, theta=0.0
% INFO    : Bus 1774	: V=1.04408517, theta=-11.6023297 -> V=1.0111115, theta=0.0
% INFO    : Bus 1775	: V=1.04151064, theta=0.883013736 -> V=1.013331, theta=0.0
% INFO    : Bus 1776	: V=1.03417342, theta=-13.7134389 -> V=1.015872, theta=0.0
% INFO    : Bus 2914	: V=1.03417342, theta=-13.7134389 -> V=1.015872, theta=0.0
% INFO    : Bus 1777	: V=1.0018539, theta=-18.7502582 -> V=1.015872, theta=0.0
% INFO    : Bus 1778	: V=1.07401337, theta=-18.2629828 -> V=1.044445, theta=0.0
% INFO    : Bus 2915	: V=1.06699489, theta=-18.442241 -> V=1.044445, theta=0.0
% INFO    : Bus 1779	: V=1.0756477, theta=-8.41373883 -> V=1.0111115, theta=0.0
% INFO    : Bus 1780	: V=0.99603416, theta=-21.6189613 -> V=1.0146895, theta=0.0
% INFO    : Bus 1781	: V=0.96787965, theta=-22.8453703 -> V=1.015872, theta=0.0
% INFO    : Bus 1782	: V=1.01269305, theta=-21.2117363 -> V=1.0233335, theta=0.0
% INFO    : Bus 1783	: V=1.01836549, theta=-13.8456501 -> V=1.015872, theta=0.0
% INFO    : Bus 1784	: V=0.988338167, theta=-32.2525538 -> V=1.015872, theta=0.0
% INFO    : Bus 1786	: V=1.06432118, theta=-7.37088801 -> V=1.04222, theta=0.0
% INFO    : Bus 1787	: V=1.07114808, theta=-0.861924185 -> V=1.051315, theta=0.0
% INFO    : Bus 1788	: V=1.02142594, theta=-13.1611582 -> V=0.999999, theta=0.0
% INFO    : Bus 1789	: V=1.04121912, theta=-9.13350369 -> V=1.0111115, theta=0.0
% INFO    : Bus 1790	: V=1.05696526, theta=-11.7110025 -> V=0.9888895, theta=0.0
% INFO    : Bus 1791	: V=1.05420584, theta=-17.6762981 -> V=1.046015, theta=0.0
% INFO    : Bus 1792	: V=0.999955589, theta=-24.9276916 -> V=1.0000025, theta=0.0
% INFO    : Bus 1793	: V=1.04438776, theta=-13.9604792 -> V=1.015872, theta=0.0
% INFO    : Bus 1794	: V=0.993896264, theta=-18.0412313 -> V=1.015872, theta=0.0
% INFO    : Bus 2916	: V=0.995193664, theta=-17.903833 -> V=1.015872, theta=0.0
% INFO    : Bus 1795	: V=0.999965004, theta=-13.2402858 -> V=1.015872, theta=0.0
% INFO    : Bus 1796	: V=1.01115441, theta=-27.071441 -> V=1.015872, theta=0.0
% INFO    : Bus 1797	: V=1.08733408, theta=-3.33387626 -> V=1.0410535, theta=0.0
% INFO    : Bus 1798	: V=1.014, theta=-13.1231303 -> V=0.999999, theta=0.0
% INFO    : Bus 1799	: V=1.05228471, theta=-13.4078469 -> V=1.04222, theta=0.0
% INFO    : Bus 1800	: V=1.02271142, theta=-12.8078628 -> V=1.015872, theta=0.0
% INFO    : Bus 1801	: V=1.01109625, theta=-15.7128691 -> V=0.999999, theta=0.0
% INFO    : Bus 1802	: V=1.079, theta=-2.09198212 -> V=1.0, theta=0.0
% INFO    : Bus 2917	: V=1.079, theta=-2.08059856 -> V=1.0, theta=0.0
% INFO    : Bus 2918	: V=1.079, theta=-2.07129688 -> V=1.0, theta=0.0
% INFO    : Bus 2919	: V=1.079, theta=-2.07337885 -> V=1.0, theta=0.0
% INFO    : Bus 2920	: V=1.0765655, theta=-5.20508444 -> V=1.0, theta=0.0
% INFO    : Bus 2921	: V=1.077, theta=-0.496302117 -> V=1.0, theta=0.0
% INFO    : Bus 1803	: V=1.0765655, theta=-5.20508444 -> V=1.05263, theta=0.0
% INFO    : Bus 1804	: V=1.08103426, theta=-9.656803 -> V=1.04521, theta=0.0
% INFO    : Bus 2981	: V=1.08198433, theta=-9.40097235 -> V=1.04521, theta=0.0
% INFO    : Bus 1805	: V=1.09428459, theta=-4.87547193 -> V=1.05263, theta=0.0
% INFO    : Bus 1806	: V=1.02468275, theta=-20.1274227 -> V=1.015872, theta=0.0
% INFO    : Bus 1807	: V=1.02176082, theta=-14.0721061 -> V=1.015872, theta=0.0
% INFO    : Bus 1808	: V=1.03554818, theta=-14.4293765 -> V=1.015872, theta=0.0
% INFO    : Bus 1809	: V=0.993000973, theta=-30.4253676 -> V=1.015872, theta=0.0
% INFO    : Bus 1810	: V=1.00536257, theta=-20.2346271 -> V=1.0000025, theta=0.0
% INFO    : Bus 2922	: V=1.02329512, theta=-20.4979603 -> V=1.0000025, theta=0.0
% INFO    : Bus 1811	: V=1.04226223, theta=-15.2842449 -> V=1.003809, theta=0.0
% INFO    : Bus 1812	: V=1.05969349, theta=-12.2818491 -> V=0.9888895, theta=0.0
% INFO    : Bus 1813	: V=1.05952828, theta=-10.1478911 -> V=1.0111115, theta=0.0
% INFO    : Bus 1814	: V=1.04170809, theta=-11.732872 -> V=1.015872, theta=0.0
% INFO    : Bus 1815	: V=0.933220921, theta=-10.9145737 -> V=0.9444445, theta=0.0
% INFO    : Bus 1816	: V=0.932776157, theta=-10.9292799 -> V=0.9444445, theta=0.0
% INFO    : Bus 1817	: V=1.04838212, theta=-10.5116996 -> V=1.0111115, theta=0.0
% INFO    : Bus 1818	: V=1.02588114, theta=-14.6652076 -> V=0.999999, theta=0.0
% INFO    : Bus 1820	: V=1.04893997, theta=-16.3507535 -> V=1.044445, theta=0.0
% INFO    : Bus 1821	: V=1.06266312, theta=-11.2284037 -> V=1.05263, theta=0.0
% INFO    : Bus 1822	: V=1.08395739, theta=-7.37892947 -> V=1.051315, theta=0.0
% INFO    : Bus 1823	: V=1.05884065, theta=-20.3919733 -> V=1.044445, theta=0.0
% INFO    : Bus 1824	: V=1.04649308, theta=-14.889583 -> V=1.044445, theta=0.0
% INFO    : Bus 1825	: V=0.9958942, theta=-16.838246 -> V=0.999999, theta=0.0
% INFO    : Bus 1826	: V=1.0285096, theta=-12.7454595 -> V=0.999999, theta=0.0
% INFO    : Bus 1827	: V=1.06710908, theta=-19.9223077 -> V=1.033334, theta=0.0
% INFO    : Bus 1828	: V=1.05829819, theta=-21.1724277 -> V=1.044445, theta=0.0
% INFO    : Bus 1829	: V=1.033, theta=-16.9464338 -> V=0.999999, theta=0.0
% INFO    : Bus 1830	: V=1.06433991, theta=-11.9727499 -> V=0.9888895, theta=0.0
% INFO    : Bus 1831	: V=1.05607794, theta=-19.6041969 -> V=1.04222, theta=0.0
% INFO    : Bus 1832	: V=1.05642658, theta=-11.3425353 -> V=0.9888895, theta=0.0
% INFO    : Bus 1833	: V=1.074043, theta=-7.55842373 -> V=1.039472, theta=0.0
% INFO    : Bus 1834	: V=1.02651347, theta=-19.9280442 -> V=1.015872, theta=0.0
% INFO    : Bus 1835	: V=1.03700791, theta=-13.2996773 -> V=1.015872, theta=0.0
% INFO    : Bus 1836	: V=1.0524672, theta=-13.5012332 -> V=0.9888895, theta=0.0
% INFO    : Bus 1837	: V=1.02866671, theta=-28.2427767 -> V=1.015872, theta=0.0
% INFO    : Bus 1838	: V=1.06556641, theta=-15.16231 -> V=1.0394235, theta=0.0
% INFO    : Bus 2923	: V=1.06805309, theta=-14.0541876 -> V=1.0394235, theta=0.0
% INFO    : Bus 1839	: V=1.08369725, theta=-11.176324 -> V=1.05263, theta=0.0
% INFO    : Bus 1840	: V=1.08562634, theta=-2.57219438 -> V=1.0398685, theta=0.0
% INFO    : Bus 1841	: V=1.10197847, theta=0.667077152 -> V=1.05263, theta=0.0
% INFO    : Bus 2924	: V=1.10514686, theta=2.155145 -> V=1.05263, theta=0.0
% INFO    : Bus 1842	: V=1.00484053, theta=-14.8332203 -> V=0.999999, theta=0.0
% INFO    : Bus 1843	: V=1.06736181, theta=-19.5990711 -> V=1.044445, theta=0.0
% INFO    : Bus 2925	: V=1.04839988, theta=-20.7600755 -> V=1.044445, theta=0.0
% INFO    : Bus 1844	: V=1.00018801, theta=-12.3122395 -> V=1.0, theta=0.0
% INFO    : Bus 1845	: V=1.06888418, theta=-9.40377815 -> V=1.0387935, theta=0.0
% INFO    : Bus 1846	: V=1.08029317, theta=-6.52605483 -> V=1.05263, theta=0.0
% INFO    : Bus 1847	: V=1.033, theta=-13.6808831 -> V=1.015872, theta=0.0
% INFO    : Bus 1848	: V=1.01501249, theta=-26.2486652 -> V=1.015872, theta=0.0
% INFO    : Bus 1849	: V=1.0588133, theta=-22.6078559 -> V=1.04222, theta=0.0
% INFO    : Bus 1850	: V=1.03818117, theta=-14.8281317 -> V=1.015872, theta=0.0
% INFO    : Bus 1851	: V=1.06656067, theta=-10.7655581 -> V=1.04222, theta=0.0
% INFO    : Bus 1852	: V=1.02220315, theta=-19.1638661 -> V=1.015872, theta=0.0
% INFO    : Bus 1853	: V=1.04889097, theta=-20.6062009 -> V=1.044445, theta=0.0
% INFO    : Bus 2926	: V=1.04887776, theta=-20.6080676 -> V=1.044445, theta=0.0
% INFO    : Bus 1854	: V=1.06331355, theta=-10.398614 -> V=1.0385685, theta=0.0
% INFO    : Bus 1855	: V=1.0484019, theta=-20.7097961 -> V=1.044445, theta=0.0
% INFO    : Bus 1856	: V=1.03016163, theta=-13.2342662 -> V=1.015872, theta=0.0
% INFO    : Bus 1857	: V=1.03304801, theta=-11.5570968 -> V=0.999999, theta=0.0
% INFO    : Bus 1858	: V=0.949815772, theta=-10.6586937 -> V=0.9444445, theta=0.0
% INFO    : Bus 1859	: V=1.06279693, theta=-11.2875104 -> V=1.05263, theta=0.0
% INFO    : Bus 1860	: V=1.07959598, theta=-11.6508668 -> V=1.05263, theta=0.0
% INFO    : Bus 1862	: V=1.05853928, theta=-19.2896179 -> V=1.044445, theta=0.0
% INFO    : Bus 2927	: V=1.06138731, theta=-20.1034326 -> V=1.044445, theta=0.0
% INFO    : Bus 1863	: V=1.06151554, theta=-14.3903999 -> V=1.05263, theta=0.0
% INFO    : Bus 1864	: V=1.04494962, theta=-14.4322562 -> V=1.0, theta=0.0
% INFO    : Bus 1865	: V=1.04501081, theta=-14.419252 -> V=1.04222, theta=0.0
% INFO    : Bus 1866	: V=1.06250229, theta=-19.3850949 -> V=1.044445, theta=0.0
% INFO    : Bus 1867	: V=1.08460989, theta=-8.16399026 -> V=1.051315, theta=0.0
% INFO    : Bus 2928	: V=1.08374845, theta=-8.76982103 -> V=1.051315, theta=0.0
% INFO    : Bus 1868	: V=1.04, theta=-14.0355312 -> V=0.999999, theta=0.0
% INFO    : Bus 1870	: V=1.07315187, theta=-18.4040576 -> V=1.044445, theta=0.0
% INFO    : Bus 2929	: V=1.06653072, theta=-18.5504082 -> V=1.044445, theta=0.0
% INFO    : Bus 1871	: V=1.06774662, theta=-14.3713303 -> V=1.05263, theta=0.0
% INFO    : Bus 1872	: V=1.06234195, theta=-12.7508557 -> V=1.0377785, theta=0.0
% INFO    : Bus 1873	: V=1.034, theta=-7.47569388 -> V=1.0, theta=0.0
% INFO    : Bus 2931	: V=1.013, theta=-10.5953932 -> V=1.0, theta=0.0
% INFO    : Bus 2932	: V=1.013, theta=-10.5814082 -> V=1.0, theta=0.0
% INFO    : Bus 1874	: V=1.01161569, theta=-15.1688745 -> V=1.0377785, theta=0.0
% INFO    : Bus 2933	: V=1.01161578, theta=-15.1689207 -> V=1.0377785, theta=0.0
% INFO    : Bus 2934	: V=1.0331811, theta=-11.5084992 -> V=1.0377785, theta=0.0
% INFO    : Bus 1875	: V=1.03319459, theta=-11.5219148 -> V=1.0377785, theta=0.0
% INFO    : Bus 2935	: V=1.01163046, theta=-15.1841408 -> V=1.0377785, theta=0.0
% INFO    : Bus 1876	: V=1.07892421, theta=-4.73518413 -> V=1.0440135, theta=0.0
% INFO    : Bus 1877	: V=0.958264836, theta=-26.1132612 -> V=0.999999, theta=0.0
% INFO    : Bus 1878	: V=1.02228488, theta=-14.0902973 -> V=0.999999, theta=0.0
% INFO    : Bus 1879	: V=1.00893002, theta=-14.3615959 -> V=1.0111115, theta=0.0
% INFO    : Bus 1880	: V=1.0427082, theta=-11.4568227 -> V=1.0111115, theta=0.0
% INFO    : Bus 1881	: V=1.02870353, theta=-13.256852 -> V=0.999999, theta=0.0
% INFO    : Bus 1882	: V=1.04140307, theta=-12.9994864 -> V=1.0111115, theta=0.0
% INFO    : Bus 1883	: V=0.995009232, theta=-14.1650595 -> V=1.015872, theta=0.0
% INFO    : Bus 1884	: V=1.05344567, theta=-15.5684267 -> V=1.044445, theta=0.0
% INFO    : Bus 2936	: V=1.05339527, theta=-15.5975099 -> V=1.044445, theta=0.0
% INFO    : Bus 1885	: V=1.04424192, theta=-19.3821637 -> V=1.044445, theta=0.0
% INFO    : Bus 2937	: V=1.0648349, theta=-18.1742608 -> V=1.044445, theta=0.0
% INFO    : Bus 1886	: V=1.04731182, theta=-20.8443446 -> V=1.044445, theta=0.0
% INFO    : Bus 1887	: V=1.03017471, theta=-12.1503586 -> V=0.999999, theta=0.0
% INFO    : Bus 1888	: V=1.04513997, theta=-11.1158297 -> V=1.0111115, theta=0.0
% INFO    : Bus 1889	: V=0.991864098, theta=-19.9444908 -> V=1.0056425, theta=0.0
% INFO    : Bus 1890	: V=1.0504182, theta=-19.2990041 -> V=1.04222, theta=0.0
% INFO    : Bus 1891	: V=1.07459721, theta=-6.92665923 -> V=0.9888895, theta=0.0
% INFO    : Bus 2938	: V=1.08247219, theta=-5.61900617 -> V=0.9888895, theta=0.0
% INFO    : Bus 1892	: V=1.09865714, theta=-3.07762796 -> V=1.05263, theta=0.0
% INFO    : Bus 1893	: V=1.06224126, theta=-12.3838335 -> V=0.9888895, theta=0.0
% INFO    : Bus 2940	: V=1.0620431, theta=-12.4434079 -> V=0.9888895, theta=0.0
% INFO    : Bus 1894	: V=1.06743915, theta=-10.7580645 -> V=0.9888895, theta=0.0
% INFO    : Bus 1895	: V=1.07774165, theta=-7.10766223 -> V=1.05263, theta=0.0
% INFO    : Bus 1896	: V=1.07237457, theta=-6.75936963 -> V=0.9888895, theta=0.0
% INFO    : Bus 2941	: V=1.07265296, theta=-6.70486676 -> V=0.9888895, theta=0.0
% INFO    : Bus 1897	: V=1.06268426, theta=-10.0627012 -> V=0.9888895, theta=0.0
% INFO    : Bus 1898	: V=1.08050847, theta=-9.1906949 -> V=1.044445, theta=0.0
% INFO    : Bus 1899	: V=1.02316996, theta=-17.941224 -> V=0.999999, theta=0.0
% INFO    : Bus 1900	: V=1.06527634, theta=-19.556682 -> V=1.044445, theta=0.0
% INFO    : Bus 1901	: V=1.0738101, theta=-13.8938379 -> V=1.05263, theta=0.0
% INFO    : Bus 1902	: V=0.942332336, theta=-9.0736975 -> V=0.9444445, theta=0.0
% INFO    : Bus 1903	: V=1.04130644, theta=-15.1397233 -> V=1.0035775, theta=0.0
% INFO    : Bus 1904	: V=1.06780785, theta=-19.0802451 -> V=1.043545, theta=0.0
% INFO    : Bus 1905	: V=1.01846612, theta=-16.1683738 -> V=0.999999, theta=0.0
% INFO    : Bus 1906	: V=1.04163596, theta=-14.5574874 -> V=1.002844, theta=0.0
% INFO    : Bus 1907	: V=0.93707942, theta=-9.75303407 -> V=0.9444445, theta=0.0
% INFO    : Bus 1908	: V=1.07854042, theta=-10.4245463 -> V=0.9933315, theta=0.0
% INFO    : Bus 1909	: V=0.93595053, theta=-9.20031787 -> V=0.9444445, theta=0.0
% INFO    : Bus 1910	: V=1.027414, theta=-16.5971601 -> V=1.015872, theta=0.0
% INFO    : Bus 1911	: V=1.09047487, theta=-12.5519511 -> V=1.0378685, theta=0.0
% INFO    : Bus 1912	: V=1.06925464, theta=-19.2126758 -> V=1.04516, theta=0.0
% INFO    : Bus 1913	: V=1.06928964, theta=-19.2037127 -> V=1.045205, theta=0.0
% INFO    : Bus 1914	: V=1.0690765, theta=-11.5059681 -> V=0.9933315, theta=0.0
% INFO    : Bus 1915	: V=1.01224936, theta=-13.8536742 -> V=1.015872, theta=0.0
% INFO    : Bus 1916	: V=1.04883464, theta=-12.3024238 -> V=0.9888895, theta=0.0
% INFO    : Bus 1917	: V=1.05427464, theta=-12.1382814 -> V=1.046665, theta=0.0
% INFO    : Bus 1918	: V=1.02090211, theta=-21.4894596 -> V=1.015872, theta=0.0
% INFO    : Bus 1919	: V=1.03292974, theta=-11.8850867 -> V=0.999999, theta=0.0
% INFO    : Bus 1920	: V=1.02650432, theta=-14.1701202 -> V=0.999999, theta=0.0
% INFO    : Bus 1921	: V=1.03180966, theta=-15.9556028 -> V=1.002404, theta=0.0
% INFO    : Bus 1922	: V=1.00282877, theta=-17.9973955 -> V=0.999999, theta=0.0
% INFO    : Bus 1923	: V=1.05694905, theta=-12.5880255 -> V=0.9933315, theta=0.0
% INFO    : Bus 1924	: V=1.02721368, theta=-10.9595087 -> V=1.0111115, theta=0.0
% INFO    : Bus 1925	: V=1.06817646, theta=-8.8125063 -> V=1.04222, theta=0.0
% INFO    : Bus 1926	: V=0.999926331, theta=-24.9400669 -> V=1.0000025, theta=0.0
% INFO    : Bus 1927	: V=1.00001658, theta=-24.9098904 -> V=1.0000025, theta=0.0
% INFO    : Bus 1928	: V=1.05212942, theta=-20.2420562 -> V=1.044445, theta=0.0
% INFO    : Bus 1929	: V=1.06799603, theta=-11.2538195 -> V=1.0233335, theta=0.0
% INFO    : Bus 1930	: V=1.05149803, theta=-20.3118269 -> V=1.044445, theta=0.0
% INFO    : Bus 1931	: V=1.05112044, theta=-23.8554846 -> V=1.043425, theta=0.0
% INFO    : Bus 1932	: V=1.01992833, theta=-12.4826343 -> V=0.999999, theta=0.0
% INFO    : Bus 1933	: V=1.0318986, theta=-13.7269763 -> V=0.999999, theta=0.0
% INFO    : Bus 1934	: V=1.07746034, theta=-3.81469211 -> V=0.9922745, theta=0.0
% INFO    : Bus 1935	: V=1.02500197, theta=-13.8305198 -> V=0.999999, theta=0.0
% INFO    : Bus 1936	: V=1.04798982, theta=-8.32834576 -> V=1.0111115, theta=0.0
% INFO    : Bus 1937	: V=1.0456479, theta=-14.5331627 -> V=1.015872, theta=0.0
% INFO    : Bus 1938	: V=1.03235404, theta=-16.7482357 -> V=1.015872, theta=0.0
% INFO    : Bus 1939	: V=1.06990963, theta=-15.32352 -> V=1.04222, theta=0.0
% INFO    : Bus 1940	: V=1.0140386, theta=-19.7886316 -> V=1.015872, theta=0.0
% INFO    : Bus 1941	: V=1.04018368, theta=-16.0273903 -> V=0.9766145, theta=0.0
% INFO    : Bus 1942	: V=1.03850297, theta=-18.4999328 -> V=1.0000025, theta=0.0
% INFO    : Bus 1943	: V=1.06090392, theta=-20.1289831 -> V=1.044445, theta=0.0
% INFO    : Bus 1944	: V=1.03672892, theta=-18.5918235 -> V=1.0000025, theta=0.0
% INFO    : Bus 1945	: V=1.06137496, theta=-20.109137 -> V=1.044445, theta=0.0
% INFO    : Bus 1946	: V=1.01291189, theta=-19.7786434 -> V=1.0000025, theta=0.0
% INFO    : Bus 1947	: V=1.04128256, theta=-15.3082065 -> V=1.015872, theta=0.0
% INFO    : Bus 1948	: V=1.0456854, theta=-8.76122576 -> V=1.0111115, theta=0.0
% INFO    : Bus 1949	: V=1.03595087, theta=-10.7407189 -> V=1.001054, theta=0.0
% INFO    : Bus 1950	: V=1.06689041, theta=-12.757804 -> V=1.05263, theta=0.0
% INFO    : Bus 1951	: V=1.03517973, theta=-13.7831688 -> V=1.015872, theta=0.0
% INFO    : Bus 1952	: V=1.06632617, theta=-11.4206037 -> V=1.003335, theta=0.0
% INFO    : Bus 1953	: V=1.03212602, theta=-14.9938211 -> V=1.015872, theta=0.0
% INFO    : Bus 1954	: V=1.05425063, theta=-18.8112808 -> V=1.044445, theta=0.0
% INFO    : Bus 1955	: V=1.05421042, theta=-18.8323321 -> V=1.044445, theta=0.0
% INFO    : Bus 1956	: V=1.056425, theta=-19.7439218 -> V=1.04291, theta=0.0
% INFO    : Bus 1957	: V=1.07173207, theta=-27.2768392 -> V=1.04222, theta=0.0
% INFO    : Bus 1958	: V=1.06572446, theta=-10.2203539 -> V=1.046665, theta=0.0
% INFO    : Bus 1959	: V=1.04474553, theta=-9.4361949 -> V=1.0111115, theta=0.0
% INFO    : Bus 1960	: V=0.992328162, theta=-15.9211237 -> V=0.999999, theta=0.0
% INFO    : Bus 1961	: V=1.03468547, theta=-15.0561491 -> V=1.015872, theta=0.0
% INFO    : Bus 1962	: V=1.03119201, theta=-10.268239 -> V=1.002289, theta=0.0
% INFO    : Bus 1963	: V=1.0297521, theta=-12.5766545 -> V=1.015872, theta=0.0
% INFO    : Bus 1964	: V=1.0273241, theta=-15.5121082 -> V=0.999999, theta=0.0
% INFO    : Bus 1965	: V=1.04492293, theta=-13.8837225 -> V=1.0111115, theta=0.0
% INFO    : Bus 1966	: V=1.01309247, theta=-23.5321929 -> V=1.0000025, theta=0.0
% INFO    : Bus 1967	: V=1.0128246, theta=-23.5471992 -> V=1.0000025, theta=0.0
% INFO    : Bus 1968	: V=1.05668056, theta=-11.2791157 -> V=0.9933315, theta=0.0
% INFO    : Bus 1969	: V=1.05719083, theta=-14.3661864 -> V=0.9888895, theta=0.0
% INFO    : Bus 1970	: V=1.02977888, theta=-12.5770426 -> V=1.015872, theta=0.0
% INFO    : Bus 1971	: V=1.04329152, theta=-11.5320906 -> V=1.015872, theta=0.0
% INFO    : Bus 1972	: V=1.0484371, theta=-10.528747 -> V=1.016882, theta=0.0
% INFO    : Bus 1973	: V=1.02786185, theta=-14.5215412 -> V=0.999999, theta=0.0
% INFO    : Bus 1974	: V=1.02234083, theta=-13.139489 -> V=1.015872, theta=0.0
% INFO    : Bus 1975	: V=1.01893624, theta=-19.281619 -> V=1.015872, theta=0.0
% INFO    : Bus 1976	: V=1.01999778, theta=-19.0478542 -> V=1.015872, theta=0.0
% INFO    : Bus 1977	: V=1.06369698, theta=-13.8076352 -> V=0.9888895, theta=0.0
% INFO    : Bus 1978	: V=1.03445303, theta=-13.4212737 -> V=0.999999, theta=0.0
% INFO    : Bus 1979	: V=1.0434239, theta=-10.1970768 -> V=1.046665, theta=0.0
% INFO    : Bus 1980	: V=1.05535211, theta=-19.0708715 -> V=1.04222, theta=0.0
% INFO    : Bus 1981	: V=1.07159152, theta=-6.85090018 -> V=0.9933315, theta=0.0
% INFO    : Bus 1982	: V=1.02753274, theta=-12.2070121 -> V=0.999999, theta=0.0
% INFO    : Bus 1983	: V=1.06909572, theta=-14.5988027 -> V=1.045685, theta=0.0
% INFO    : Bus 1984	: V=1.05543053, theta=-9.15600629 -> V=1.046665, theta=0.0
% INFO    : Bus 1985	: V=1.05285022, theta=-11.5751701 -> V=0.9888895, theta=0.0
% INFO    : Bus 1986	: V=1.06299086, theta=-12.5747883 -> V=1.04222, theta=0.0
% INFO    : Bus 1987	: V=1.0239246, theta=-19.7193823 -> V=1.015872, theta=0.0
% INFO    : Bus 1988	: V=1.03351289, theta=-16.6208533 -> V=1.015872, theta=0.0
% INFO    : Bus 1989	: V=1.04089516, theta=-20.1545696 -> V=1.044445, theta=0.0
% INFO    : Bus 1990	: V=1.04070744, theta=-20.1677173 -> V=1.044445, theta=0.0
% INFO    : Bus 1991	: V=1.03801375, theta=-18.2176987 -> V=1.0000025, theta=0.0
% INFO    : Bus 1992	: V=1.07544565, theta=-21.4611859 -> V=1.044445, theta=0.0
% INFO    : Bus 1993	: V=1.07412273, theta=-21.3105071 -> V=1.044445, theta=0.0
% INFO    : Bus 1994	: V=1.07075503, theta=-18.8121043 -> V=1.04532, theta=0.0
% INFO    : Bus 1995	: V=1.06586231, theta=-18.9691897 -> V=1.044445, theta=0.0
% INFO    : Bus 1996	: V=1.08128751, theta=-3.18655324 -> V=0.9913495, theta=0.0
% INFO    : Bus 1997	: V=1.02013466, theta=-19.9159676 -> V=1.0000025, theta=0.0
% INFO    : Bus 1998	: V=0.99898451, theta=-13.286705 -> V=0.999999, theta=0.0
% INFO    : Bus 1999	: V=1.05912432, theta=-10.7083733 -> V=1.04222, theta=0.0
% INFO    : Bus 2000	: V=1.0590463, theta=-10.7577838 -> V=1.04222, theta=0.0
% INFO    : Bus 2001	: V=0.929939334, theta=-10.6773293 -> V=0.9444445, theta=0.0
% INFO    : Bus 2002	: V=1.06260979, theta=-9.96254067 -> V=0.9888895, theta=0.0
% INFO    : Bus 2003	: V=1.05489709, theta=-19.5014835 -> V=1.044445, theta=0.0
% INFO    : Bus 2004	: V=1.0303031, theta=-13.149319 -> V=0.999999, theta=0.0
% INFO    : Bus 2005	: V=1.05817042, theta=-14.9253034 -> V=1.04222, theta=0.0
% INFO    : Bus 2006	: V=1.05868632, theta=-10.0423025 -> V=1.0111115, theta=0.0
% INFO    : Bus 2007	: V=1.03195917, theta=-20.5638992 -> V=1.0000025, theta=0.0
% INFO    : Bus 2008	: V=0.95139977, theta=-10.7868323 -> V=0.9444445, theta=0.0
% INFO    : Bus 2009	: V=1.06710547, theta=-11.6430004 -> V=0.9933315, theta=0.0
% INFO    : Bus 2010	: V=1.0359643, theta=-10.8921815 -> V=0.999999, theta=0.0
% INFO    : Bus 2011	: V=1.07448361, theta=-20.8506331 -> V=1.044445, theta=0.0
% INFO    : Bus 2012	: V=1.07386412, theta=-20.8710813 -> V=1.044445, theta=0.0
% INFO    : Bus 2013	: V=1.02726666, theta=-16.0442735 -> V=0.9888895, theta=0.0
% INFO    : Bus 2014	: V=1.08016336, theta=-3.41854325 -> V=0.9912795, theta=0.0
% INFO    : Bus 2015	: V=1.00752853, theta=-11.7588319 -> V=1.015872, theta=0.0
% INFO    : Bus 2016	: V=1.068537, theta=-11.4438495 -> V=1.04222, theta=0.0
% INFO    : Bus 2017	: V=1.05304778, theta=-12.5895695 -> V=1.0111115, theta=0.0
% INFO    : Bus 2018	: V=1.07071937, theta=-16.7647763 -> V=1.04222, theta=0.0
% INFO    : Bus 2019	: V=1.01430072, theta=-19.9240188 -> V=1.0000025, theta=0.0
% INFO    : Bus 2020	: V=1.05881018, theta=-9.48555324 -> V=1.04222, theta=0.0
% INFO    : Bus 2021	: V=1.05566867, theta=-19.1557531 -> V=1.044445, theta=0.0
% INFO    : Bus 2022	: V=1.06276238, theta=-10.2839127 -> V=1.046665, theta=0.0
% INFO    : Bus 2023	: V=1.05519704, theta=-10.1102064 -> V=1.0111115, theta=0.0
% INFO    : Bus 2024	: V=1.06576067, theta=-10.2206415 -> V=1.046665, theta=0.0
% INFO    : Bus 2025	: V=1.02728226, theta=-16.9197101 -> V=1.015872, theta=0.0
% INFO    : Bus 2026	: V=1.03368708, theta=-14.3881805 -> V=0.999999, theta=0.0
% INFO    : Bus 2027	: V=1.06536795, theta=-19.2114101 -> V=1.044445, theta=0.0
% INFO    : Bus 2028	: V=1.0650609, theta=-19.363536 -> V=1.044445, theta=0.0
% INFO    : Bus 2029	: V=1.00899662, theta=-15.845428 -> V=0.999999, theta=0.0
% INFO    : Bus 2030	: V=1.05820551, theta=-18.8672723 -> V=1.044445, theta=0.0
% INFO    : Bus 2031	: V=1.03842294, theta=-15.794801 -> V=1.001404, theta=0.0
% INFO    : Bus 2032	: V=1.0509668, theta=-12.391644 -> V=0.9888895, theta=0.0
% INFO    : Bus 2033	: V=1.06596797, theta=-7.20570884 -> V=0.9888895, theta=0.0
% INFO    : Bus 2034	: V=1.04627773, theta=-17.0185155 -> V=0.9893295, theta=0.0
% INFO    : Bus 2035	: V=1.02204757, theta=-19.4792872 -> V=1.015872, theta=0.0
% INFO    : Bus 2036	: V=1.04304556, theta=-11.7514506 -> V=1.0111115, theta=0.0
% INFO    : Bus 2037	: V=1.06777648, theta=-9.96552793 -> V=0.9892695, theta=0.0
% INFO    : Bus 2038	: V=1.06094008, theta=-20.4932768 -> V=1.044445, theta=0.0
% INFO    : Bus 2039	: V=1.02381461, theta=-14.6989855 -> V=0.999999, theta=0.0
% INFO    : Bus 2040	: V=1.0699842, theta=-10.6821793 -> V=1.04222, theta=0.0
% INFO    : Bus 2041	: V=1.02808188, theta=-28.6823157 -> V=1.04222, theta=0.0
% INFO    : Bus 2042	: V=1.05506611, theta=-10.4394795 -> V=1.0111115, theta=0.0
% INFO    : Bus 2043	: V=1.0499898, theta=-17.4338613 -> V=1.046665, theta=0.0
% INFO    : Bus 2044	: V=1.03159147, theta=-13.2133893 -> V=1.015872, theta=0.0
% INFO    : Bus 2045	: V=1.03457756, theta=-13.4474876 -> V=0.999999, theta=0.0
% INFO    : Bus 2046	: V=0.999487578, theta=-12.3770496 -> V=0.999999, theta=0.0
% INFO    : Bus 2047	: V=1.08826522, theta=-13.2192782 -> V=1.0381735, theta=0.0
% INFO    : Bus 2048	: V=1.02147871, theta=-13.1560085 -> V=0.999999, theta=0.0
% INFO    : Bus 2049	: V=1.02977833, theta=-11.4828517 -> V=1.015872, theta=0.0
% INFO    : Bus 2050	: V=1.02946664, theta=-19.8884231 -> V=0.999999, theta=0.0
% INFO    : Bus 2051	: V=1.05828619, theta=-19.3893526 -> V=1.044445, theta=0.0
% INFO    : Bus 2052	: V=1.05962002, theta=-19.3807714 -> V=1.044445, theta=0.0
% INFO    : Bus 2053	: V=1.03060406, theta=-14.565377 -> V=0.999999, theta=0.0
% INFO    : Bus 2054	: V=1.06265212, theta=-19.1775648 -> V=1.044445, theta=0.0
% INFO    : Bus 2055	: V=0.999224351, theta=-19.015571 -> V=0.999999, theta=0.0
% INFO    : Bus 2056	: V=1.04827468, theta=-15.2468511 -> V=1.021287, theta=0.0
% INFO    : Bus 2057	: V=1.03628722, theta=-13.9490288 -> V=1.000854, theta=0.0
% INFO    : Bus 2058	: V=0.999428755, theta=-16.2234857 -> V=0.999999, theta=0.0
% INFO    : Bus 2059	: V=1.0899302, theta=-12.6115412 -> V=1.0379685, theta=0.0
% INFO    : Bus 2060	: V=1.03756779, theta=-15.1557366 -> V=1.015872, theta=0.0
% INFO    : Bus 2061	: V=1.07343583, theta=-18.3107789 -> V=1.045385, theta=0.0
% INFO    : Bus 2062	: V=1.03016518, theta=-14.5093377 -> V=1.015872, theta=0.0
% INFO    : Bus 2063	: V=1.03802408, theta=-18.2179189 -> V=1.0000025, theta=0.0
% INFO    : Bus 2064	: V=1.08696102, theta=-2.62451994 -> V=0.9916195, theta=0.0
% INFO    : Bus 2065	: V=1.02168743, theta=-21.3925368 -> V=1.015872, theta=0.0
% INFO    : Bus 2066	: V=1.02065639, theta=-21.7647112 -> V=1.015872, theta=0.0
% INFO    : Bus 2067	: V=1.00107179, theta=-25.407601 -> V=1.0000025, theta=0.0
% INFO    : Bus 2068	: V=1.03268219, theta=-13.2326482 -> V=1.001114, theta=0.0
% INFO    : Bus 2069	: V=1.03213634, theta=-13.0277159 -> V=1.000554, theta=0.0
% INFO    : Bus 2070	: V=1.00190785, theta=-25.3616884 -> V=1.0000025, theta=0.0
% INFO    : Bus 2071	: V=1.05695051, theta=-15.0598633 -> V=1.001274, theta=0.0
% INFO    : Bus 2072	: V=0.995141353, theta=-32.5610231 -> V=1.015872, theta=0.0
% INFO    : Bus 2073	: V=0.995154804, theta=-32.563914 -> V=1.015872, theta=0.0
% INFO    : Bus 2074	: V=0.99876406, theta=-13.2962889 -> V=1.015872, theta=0.0
% INFO    : Bus 2075	: V=1.04337199, theta=-14.3304543 -> V=1.001449, theta=0.0
% INFO    : Bus 2076	: V=1.06933908, theta=-15.9672535 -> V=1.04222, theta=0.0
% INFO    : Bus 2077	: V=1.06243663, theta=-10.3735336 -> V=1.05263, theta=0.0
% INFO    : Bus 2078	: V=0.996524147, theta=-12.6680625 -> V=0.999999, theta=0.0
% INFO    : Bus 2079	: V=1.02692185, theta=-17.8692286 -> V=1.0199565, theta=0.0
% INFO    : Bus 2080	: V=0.996262194, theta=-12.7503957 -> V=0.999999, theta=0.0
% INFO    : Bus 2081	: V=1.0352064, theta=-10.7292214 -> V=1.000614, theta=0.0
% INFO    : Bus 2082	: V=1.03324348, theta=-11.3700479 -> V=1.015872, theta=0.0
% INFO    : Bus 2083	: V=1.02872349, theta=-13.2572807 -> V=0.999999, theta=0.0
% INFO    : Bus 2084	: V=1.02703734, theta=-15.7372956 -> V=0.999999, theta=0.0
% INFO    : Bus 2085	: V=1.06095099, theta=-14.5855145 -> V=1.046665, theta=0.0
% INFO    : Bus 2086	: V=1.04196338, theta=-15.0752164 -> V=0.9888895, theta=0.0
% INFO    : Bus 2087	: V=1.00927543, theta=-11.9825969 -> V=0.999999, theta=0.0
% INFO    : Bus 2088	: V=1.03625402, theta=-11.1660133 -> V=0.999999, theta=0.0
% INFO    : Bus 2089	: V=1.05542773, theta=-11.8645045 -> V=0.9933315, theta=0.0
% INFO    : Bus 2090	: V=1.07104696, theta=-18.1937259 -> V=1.04357, theta=0.0
% INFO    : Bus 2091	: V=1.06145812, theta=-14.2365811 -> V=1.04222, theta=0.0
% INFO    : Bus 2092	: V=1.04820399, theta=-11.2783987 -> V=1.0111115, theta=0.0
% INFO    : Bus 2093	: V=1.03016163, theta=-13.2342662 -> V=1.015872, theta=0.0
% INFO    : Bus 2094	: V=1.00803185, theta=-16.067247 -> V=0.999999, theta=0.0
% INFO    : Bus 2095	: V=1.07035034, theta=-20.3428571 -> V=1.04483, theta=0.0
% INFO    : Bus 2096	: V=1.0671328, theta=-20.0399895 -> V=1.044445, theta=0.0
% INFO    : Bus 2097	: V=1.03607851, theta=-10.9708559 -> V=0.999999, theta=0.0
% INFO    : Bus 2098	: V=1.06218047, theta=-20.4709847 -> V=1.044445, theta=0.0
% INFO    : Bus 2099	: V=1.05711642, theta=-19.9480489 -> V=1.044445, theta=0.0
% INFO    : Bus 2100	: V=1.03034137, theta=-16.1926683 -> V=0.999999, theta=0.0
% INFO    : Bus 2101	: V=1.01664893, theta=-19.6241526 -> V=1.015872, theta=0.0
% INFO    : Bus 2102	: V=0.999501819, theta=-23.1899811 -> V=1.0233335, theta=0.0
% INFO    : Bus 2103	: V=1.06710666, theta=-8.54496766 -> V=0.9933315, theta=0.0
% INFO    : Bus 2104	: V=1.05643675, theta=-14.7655946 -> V=0.9933315, theta=0.0
% INFO    : Bus 2105	: V=1.06277795, theta=-8.87863692 -> V=1.0111115, theta=0.0
% INFO    : Bus 2106	: V=1.02004077, theta=-13.1460798 -> V=1.015872, theta=0.0
% INFO    : Bus 2107	: V=1.06964766, theta=-10.0299563 -> V=1.04222, theta=0.0
% INFO    : Bus 2108	: V=1.03358227, theta=-14.9774712 -> V=1.015872, theta=0.0
% INFO    : Bus 2109	: V=1.02679325, theta=-18.1240471 -> V=0.999999, theta=0.0
% INFO    : Bus 2110	: V=1.06838619, theta=-5.85467246 -> V=0.9892645, theta=0.0
% INFO    : Bus 2111	: V=1.06541956, theta=-10.217935 -> V=1.046055, theta=0.0
% INFO    : Bus 2112	: V=1.07254761, theta=-5.67015262 -> V=0.9888895, theta=0.0
% INFO    : Bus 2113	: V=1.05262247, theta=-20.0734826 -> V=1.044445, theta=0.0
% INFO    : Bus 2114	: V=1.00742561, theta=-26.802406 -> V=1.015872, theta=0.0
% INFO    : Bus 2115	: V=1.08270562, theta=-4.61112565 -> V=1.05263, theta=0.0
% INFO    : Bus 2116	: V=1.02186899, theta=-23.9646458 -> V=1.015872, theta=0.0
% INFO    : Bus 2117	: V=1.02555248, theta=-17.7337742 -> V=1.015872, theta=0.0
% INFO    : Bus 2118	: V=1.03263191, theta=-14.7371515 -> V=1.015872, theta=0.0
% INFO    : Bus 2119	: V=0.992025123, theta=-29.6669146 -> V=1.015872, theta=0.0
% INFO    : Bus 2120	: V=1.03525548, theta=-14.8035848 -> V=1.002554, theta=0.0
% INFO    : Bus 2121	: V=1.04050091, theta=-11.9611736 -> V=1.015872, theta=0.0
% INFO    : Bus 2122	: V=0.928881154, theta=-10.6368781 -> V=0.9444445, theta=0.0
% INFO    : Bus 2123	: V=1.05941743, theta=-14.8392276 -> V=1.04222, theta=0.0
% INFO    : Bus 2124	: V=0.963458954, theta=-32.5611682 -> V=0.9970065, theta=0.0
% INFO    : Bus 2125	: V=1.03595462, theta=-10.8790043 -> V=0.999999, theta=0.0
% INFO    : Bus 2126	: V=0.934868256, theta=-10.188899 -> V=0.9444445, theta=0.0
% INFO    : Bus 2127	: V=1.07694043, theta=-19.6730269 -> V=1.04222, theta=0.0
% INFO    : Bus 2128	: V=1.06436494, theta=-10.2540859 -> V=0.9901745, theta=0.0
% INFO    : Bus 2129	: V=1.01822739, theta=-31.1574414 -> V=1.015872, theta=0.0
% INFO    : Bus 2130	: V=1.00576078, theta=-30.0506574 -> V=1.017997, theta=0.0
% INFO    : Bus 2131	: V=0.980806696, theta=-22.1287163 -> V=0.999999, theta=0.0
% INFO    : Bus 2132	: V=1.03592342, theta=-15.6471754 -> V=1.015872, theta=0.0
% INFO    : Bus 2133	: V=1.04881845, theta=-14.172255 -> V=1.046665, theta=0.0
% INFO    : Bus 2134	: V=1.03916899, theta=-10.7252284 -> V=1.046665, theta=0.0
% INFO    : Bus 2135	: V=1.05818344, theta=-14.8019285 -> V=1.003569, theta=0.0
% INFO    : Bus 2136	: V=1.03068785, theta=-16.0037144 -> V=1.015872, theta=0.0
% INFO    : Bus 2137	: V=1.01970673, theta=-13.2441726 -> V=1.015872, theta=0.0
% INFO    : Bus 2138	: V=0.953646471, theta=-9.25775015 -> V=0.9444445, theta=0.0
% INFO    : Bus 2139	: V=0.953627836, theta=-9.25869411 -> V=0.9444845, theta=0.0
% INFO    : Bus 2140	: V=1.03769812, theta=-14.2001176 -> V=1.015872, theta=0.0
% INFO    : Bus 2141	: V=1.03964501, theta=-14.5050557 -> V=1.015872, theta=0.0
% INFO    : Bus 2142	: V=0.994693733, theta=-21.0751257 -> V=1.0000025, theta=0.0
% INFO    : Bus 2143	: V=1.0658489, theta=-14.6747277 -> V=0.9888895, theta=0.0
% INFO    : Bus 2144	: V=1.00880272, theta=-13.7957368 -> V=0.999999, theta=0.0
% INFO    : Bus 2145	: V=0.923704652, theta=-12.9512972 -> V=0.9444445, theta=0.0
% INFO    : Bus 2146	: V=1.0405082, theta=-15.3057022 -> V=1.003859, theta=0.0
% INFO    : Bus 2147	: V=1.05436073, theta=-14.0804122 -> V=1.0032875, theta=0.0
% INFO    : Bus 2148	: V=1.07799862, theta=-29.0503099 -> V=1.04222, theta=0.0
% INFO    : Bus 2149	: V=1.02795355, theta=-10.8379489 -> V=1.015872, theta=0.0
% INFO    : Bus 2150	: V=1.06285518, theta=-11.2772794 -> V=0.9933315, theta=0.0
% INFO    : Bus 2151	: V=1.00845254, theta=-26.0038215 -> V=1.0000025, theta=0.0
% INFO    : Bus 2152	: V=1.04018278, theta=-14.8776716 -> V=1.0013475, theta=0.0
% INFO    : Bus 2153	: V=1.07595129, theta=-8.87337354 -> V=1.051315, theta=0.0
% INFO    : Bus 2154	: V=1.04440138, theta=-13.9599693 -> V=1.015872, theta=0.0
% INFO    : Bus 2155	: V=0.995005229, theta=-17.9355481 -> V=1.015872, theta=0.0
% INFO    : Bus 2156	: V=1.0541035, theta=-17.5836112 -> V=1.04539, theta=0.0
% INFO    : Bus 2157	: V=1.01536335, theta=-12.9990089 -> V=0.999999, theta=0.0
% INFO    : Bus 2158	: V=0.949569945, theta=-10.6684795 -> V=0.9444445, theta=0.0
% INFO    : Bus 2159	: V=1.01304581, theta=-18.7745944 -> V=1.0196375, theta=0.0
% INFO    : Bus 2160	: V=1.04692142, theta=-10.9143976 -> V=1.0111115, theta=0.0
% INFO    : Bus 2161	: V=1.06269149, theta=-10.0608952 -> V=0.9933315, theta=0.0
% INFO    : Bus 2163	: V=1.0788472, theta=-10.7702266 -> V=0.975, theta=0.0
% INFO    : Bus 2164	: V=1.05833579, theta=-27.217813 -> V=0.975, theta=0.0
% INFO    : Bus 2165	: V=1.04428475, theta=-27.5221928 -> V=0.975, theta=0.0
% INFO    : Bus 2166	: V=1.04816065, theta=-12.7502648 -> V=0.975, theta=0.0
% INFO    : Bus 2167	: V=1.07494225, theta=-20.8466385 -> V=0.975, theta=0.0
% INFO    : Bus 2168	: V=1.08566466, theta=-8.58749421 -> V=0.975, theta=0.0
% INFO    : Bus 2169	: V=1.07414631, theta=-12.2191748 -> V=0.975, theta=0.0
% INFO    : Bus 2170	: V=1.06886567, theta=-10.9882203 -> V=0.975, theta=0.0
% INFO    : Bus 2171	: V=1.05499693, theta=-14.794265 -> V=0.975, theta=0.0
% INFO    : Bus 2172	: V=1.05289372, theta=-10.4450376 -> V=0.975, theta=0.0
% INFO    : Bus 2173	: V=1.06272863, theta=-11.4595921 -> V=0.975, theta=0.0
% INFO    : Bus 2174	: V=1.0801835, theta=-30.9617501 -> V=0.975, theta=0.0
% INFO    : Bus 2175	: V=1.08352016, theta=-3.70698838 -> V=0.975, theta=0.0
% INFO    : Bus 2176	: V=1.06541968, theta=-20.5396329 -> V=0.975, theta=0.0
% INFO    : Bus 2177	: V=1.03657314, theta=-8.07856966 -> V=0.975, theta=0.0
% INFO    : Bus 2178	: V=1.05950689, theta=-10.647173 -> V=0.975, theta=0.0
% INFO    : Bus 2179	: V=1.0619986, theta=-12.2327977 -> V=0.975, theta=0.0
% INFO    : Bus 2180	: V=1.06883604, theta=-20.310135 -> V=0.975, theta=0.0
% INFO    : Bus 2181	: V=1.04115162, theta=-20.9036133 -> V=0.975, theta=0.0
% INFO    : Bus 2182	: V=1.07065756, theta=-18.9581535 -> V=0.975, theta=0.0
% INFO    : Bus 2183	: V=1.0626651, theta=-10.8811437 -> V=0.975, theta=0.0
% INFO    : Bus 2184	: V=1.05370914, theta=-20.7157209 -> V=0.975, theta=0.0
% INFO    : Bus 2185	: V=1.05085148, theta=-20.4752143 -> V=0.975, theta=0.0
% INFO    : Bus 2186	: V=1.06716316, theta=-15.1728698 -> V=0.975, theta=0.0
% INFO    : Bus 2187	: V=1.00605137, theta=-23.4461118 -> V=0.975, theta=0.0
% INFO    : Bus 2188	: V=1.06522201, theta=-14.2399391 -> V=0.975, theta=0.0
% INFO    : Bus 2189	: V=1.07100532, theta=-8.00120834 -> V=0.975, theta=0.0
% INFO    : Bus 2190	: V=1.06133186, theta=-21.2098263 -> V=0.975, theta=0.0
% INFO    : Bus 2191	: V=1.04583377, theta=-11.6466157 -> V=0.975, theta=0.0
% INFO    : Bus 2192	: V=1.02365279, theta=-24.4382448 -> V=0.975, theta=0.0
% INFO    : Bus 2193	: V=1.05862083, theta=-27.4268238 -> V=0.975, theta=0.0
% INFO    : Bus 2194	: V=1.05043019, theta=-9.74958322 -> V=0.975, theta=0.0
% INFO    : Bus 2195	: V=1.04385035, theta=-27.6900906 -> V=0.975, theta=0.0
% INFO    : Bus 2196	: V=1.04664307, theta=-12.1643038 -> V=0.975, theta=0.0
% INFO    : Bus 2197	: V=1.08535253, theta=-8.26314557 -> V=0.975, theta=0.0
% INFO    : Bus 2198	: V=1.07680298, theta=-10.1009975 -> V=0.975, theta=0.0
% INFO    : Bus 2199	: V=1.05874162, theta=-15.5554628 -> V=0.975, theta=0.0
% INFO    : Bus 2200	: V=1.0637716, theta=-13.6942803 -> V=0.975, theta=0.0
% INFO    : Bus 2201	: V=1.07916985, theta=-29.834034 -> V=0.975, theta=0.0
% INFO    : Bus 2202	: V=1.08268208, theta=-3.89042104 -> V=0.975, theta=0.0
% INFO    : Bus 2203	: V=1.07170744, theta=-19.7916707 -> V=0.975, theta=0.0
% INFO    : Bus 2204	: V=1.0574594, theta=-9.79649405 -> V=0.975, theta=0.0
% INFO    : Bus 2205	: V=1.07637422, theta=-19.7748585 -> V=0.975, theta=0.0
% INFO    : Bus 2206	: V=1.06068883, theta=-12.2668271 -> V=0.975, theta=0.0
% INFO    : Bus 2207	: V=1.06928409, theta=-20.4829252 -> V=0.975, theta=0.0
% INFO    : Bus 2208	: V=1.05530238, theta=-20.5827547 -> V=0.975, theta=0.0
% INFO    : Bus 2209	: V=1.06266335, theta=-10.8288266 -> V=0.975, theta=0.0
% INFO    : Bus 2210	: V=1.05090347, theta=-20.474921 -> V=0.975, theta=0.0
% INFO    : Bus 2211	: V=1.06560343, theta=-14.056458 -> V=0.975, theta=0.0
% INFO    : Bus 2212	: V=1.04727163, theta=-17.2701391 -> V=0.975, theta=0.0
% INFO    : Bus 2213	: V=1.06127784, theta=-21.2389946 -> V=0.975, theta=0.0
% INFO    : Bus 2214	: V=1.07464658, theta=-20.0484474 -> V=0.975, theta=0.0
% INFO    : Bus 2215	: V=1.0467479, theta=-10.4686762 -> V=0.975, theta=0.0
% INFO    : Bus 2216	: V=1.078751, theta=-10.8081993 -> V=0.975, theta=0.0
% INFO    : Bus 2217	: V=1.0447305, theta=-24.3734931 -> V=0.975, theta=0.0
% INFO    : Bus 2218	: V=1.03050851, theta=-11.2113825 -> V=0.975, theta=0.0
% INFO    : Bus 2219	: V=1.07725751, theta=-21.8501118 -> V=0.975, theta=0.0
% INFO    : Bus 2220	: V=1.04837419, theta=-16.3905828 -> V=0.975, theta=0.0
% INFO    : Bus 2221	: V=1.05596403, theta=-19.3726463 -> V=0.975, theta=0.0
% INFO    : Bus 2222	: V=1.03668404, theta=-24.5569502 -> V=0.975, theta=0.0
% INFO    : Bus 2223	: V=1.06223079, theta=-14.8257848 -> V=0.975, theta=0.0
% INFO    : Bus 2224	: V=1.11231325, theta=-12.2292649 -> V=0.975, theta=0.0
% INFO    : Bus 2225	: V=1.0366486, theta=-17.2422917 -> V=0.975, theta=0.0
% INFO    : Bus 2226	: V=1.07123979, theta=-19.4797974 -> V=0.975, theta=0.0
% INFO    : Bus 2227	: V=1.05574761, theta=-20.3694848 -> V=0.975, theta=0.0
% INFO    : Bus 2228	: V=1.04090118, theta=-21.0494134 -> V=0.975, theta=0.0
% INFO    : Bus 2229	: V=1.05903074, theta=-21.7319274 -> V=0.975, theta=0.0
% INFO    : Bus 2230	: V=1.02900934, theta=-15.4995051 -> V=0.975, theta=0.0
% INFO    : Bus 2231	: V=1.06980102, theta=-15.6061577 -> V=0.975, theta=0.0
% INFO    : Bus 2232	: V=1.05983077, theta=-20.6766773 -> V=0.975, theta=0.0
% INFO    : Bus 2233	: V=1.07594738, theta=-21.2262428 -> V=0.975, theta=0.0
% INFO    : Bus 2234	: V=1.07798302, theta=-19.8391298 -> V=0.975, theta=0.0
% INFO    : Bus 2235	: V=1.05879131, theta=-24.0800408 -> V=0.975, theta=0.0
% INFO    : Bus 2236	: V=1.06538217, theta=-20.5987679 -> V=0.975, theta=0.0
% INFO    : Bus 2237	: V=1.0556297, theta=-20.4356969 -> V=0.975, theta=0.0
% INFO    : Bus 2238	: V=1.06695613, theta=-19.2631313 -> V=0.975, theta=0.0
% INFO    : Bus 2239	: V=1.02555641, theta=-16.0333324 -> V=0.975, theta=0.0
% INFO    : Bus 2240	: V=1.06960098, theta=-15.603689 -> V=0.975, theta=0.0
% INFO    : Bus 2241	: V=1.06166696, theta=-21.7725998 -> V=0.975, theta=0.0
% INFO    : Bus 2242	: V=1.07328133, theta=-19.211217 -> V=0.975, theta=0.0
% INFO    : Bus 2243	: V=1.07488614, theta=-21.0946649 -> V=0.975, theta=0.0
% INFO    : Bus 2244	: V=1.11396231, theta=-12.0197736 -> V=0.975, theta=0.0
% INFO    : Bus 2245	: V=1.07836587, theta=-19.6278577 -> V=0.975, theta=0.0
% INFO    : Bus 2246	: V=1.0633467, theta=-9.81909349 -> V=0.975, theta=0.0
% INFO    : Bus 2247	: V=1.06229067, theta=-22.3530603 -> V=0.975, theta=0.0
% INFO    : Bus 2248	: V=1.06526228, theta=-19.0083229 -> V=0.975, theta=0.0
% INFO    : Bus 2249	: V=1.01535617, theta=-24.8392852 -> V=0.975, theta=0.0
% INFO    : Bus 2250	: V=1.009, theta=-2.25679518 -> V=0.975, theta=0.0
% INFO    : Bus 2251	: V=1.011, theta=-2.93841323 -> V=0.975, theta=0.0
% INFO    : Bus 2253	: V=1.008, theta=-12.6402781 -> V=0.975, theta=0.0
% INFO    : Bus 2254	: V=1.009, theta=-13.7498393 -> V=0.975, theta=0.0
% INFO    : Bus 2255	: V=1.006, theta=-10.1536496 -> V=0.975, theta=0.0
% INFO    : Bus 2257	: V=0.965, theta=-5.95184067 -> V=0.975, theta=0.0
% INFO    : Bus 2258	: V=0.972, theta=-11.9205094 -> V=0.975, theta=0.0
% INFO    : Bus 2259	: V=0.986, theta=-7.32564522 -> V=0.975, theta=0.0
% INFO    : Bus 2260	: V=1.061, theta=-5.58909637 -> V=0.975, theta=0.0
% INFO    : Bus 2261	: V=1.061, theta=-5.53519799 -> V=0.975, theta=0.0
% INFO    : Bus 2262	: V=1.061, theta=-5.6057561 -> V=0.975, theta=0.0
% INFO    : Bus 2263	: V=1.061, theta=-5.62991545 -> V=0.975, theta=0.0
% INFO    : Bus 2264	: V=0.996, theta=-4.56191464 -> V=0.975, theta=0.0
% INFO    : Bus 2265	: V=0.995, theta=-4.35648143 -> V=0.975, theta=0.0
% INFO    : Bus 2266	: V=1.001, theta=-3.9572789 -> V=0.975, theta=0.0
% INFO    : Bus 2267	: V=1.0, theta=-3.50677495 -> V=0.975, theta=0.0
% INFO    : Bus 2268	: V=0.993, theta=-2.9861283 -> V=0.975, theta=0.0
% INFO    : Bus 2269	: V=0.992, theta=-2.78376571 -> V=0.975, theta=0.0
% INFO    : Bus 2270	: V=1.022, theta=3.10976677 -> V=0.975, theta=0.0
% INFO    : Bus 2271	: V=1.022, theta=3.39916647 -> V=0.975, theta=0.0
% INFO    : Bus 2272	: V=1.021, theta=3.38007281 -> V=0.975, theta=0.0
% INFO    : Bus 2273	: V=1.02, theta=2.95986544 -> V=0.975, theta=0.0
% INFO    : Bus 2274	: V=1.015, theta=2.43192201 -> V=0.975, theta=0.0
% INFO    : Bus 2275	: V=1.009, theta=3.01573592 -> V=0.975, theta=0.0
% INFO    : Bus 2276	: V=1.026, theta=3.43546991 -> V=0.975, theta=0.0
% INFO    : Bus 2277	: V=1.047, theta=0.226629291 -> V=0.975, theta=0.0
% INFO    : Bus 2278	: V=1.038, theta=1.46335942 -> V=0.975, theta=0.0
% INFO    : Bus 2279	: V=1.008, theta=-3.33420194 -> V=0.975, theta=0.0
% INFO    : Bus 2280	: V=1.008, theta=-3.00182302 -> V=0.975, theta=0.0
% INFO    : Bus 2281	: V=1.008, theta=-3.37245339 -> V=0.975, theta=0.0
% INFO    : Bus 2282	: V=1.008, theta=-3.00182302 -> V=0.975, theta=0.0
% INFO    : Bus 2283	: V=1.008, theta=-3.00182302 -> V=0.975, theta=0.0
% INFO    : Bus 2284	: V=0.998, theta=-4.46686991 -> V=0.975, theta=0.0
% INFO    : Bus 2286	: V=0.987, theta=-1.26051702 -> V=0.975, theta=0.0
% INFO    : Bus 2287	: V=0.962, theta=-6.54954516 -> V=0.975, theta=0.0
% INFO    : Bus 2289	: V=0.964, theta=-5.23370328 -> V=0.975, theta=0.0
% INFO    : Bus 2290	: V=0.966, theta=-7.75578167 -> V=0.975, theta=0.0
% INFO    : Bus 2291	: V=1.013, theta=-7.06422941 -> V=0.975, theta=0.0
% INFO    : Bus 2292	: V=1.019, theta=-6.0836585 -> V=0.975, theta=0.0
% INFO    : Bus 2293	: V=1.005, theta=1.80560983 -> V=0.975, theta=0.0
% INFO    : Bus 2294	: V=1.006, theta=1.59075879 -> V=0.975, theta=0.0
% INFO    : Bus 2295	: V=1.003, theta=1.68926569 -> V=0.975, theta=0.0
% INFO    : Bus 2296	: V=1.004, theta=1.66877903 -> V=0.975, theta=0.0
% INFO    : Bus 2297	: V=0.972, theta=5.19076316 -> V=0.975, theta=0.0
% INFO    : Bus 2298	: V=0.972, theta=5.17258876 -> V=0.975, theta=0.0
% INFO    : Bus 2299	: V=1.057, theta=-7.72125581 -> V=0.975, theta=0.0
% INFO    : Bus 2300	: V=1.057, theta=-7.72125581 -> V=0.975, theta=0.0
% INFO    : Bus 2301	: V=1.057, theta=-7.73253183 -> V=0.975, theta=0.0
% INFO    : Bus 2302	: V=1.057, theta=-7.72220311 -> V=0.975, theta=0.0
% INFO    : Bus 2303	: V=1.057, theta=-7.72220311 -> V=0.975, theta=0.0
% INFO    : Bus 2304	: V=1.057, theta=-7.72630349 -> V=0.975, theta=0.0
% INFO    : Bus 2305	: V=0.977, theta=-8.45195757 -> V=0.975, theta=0.0
% INFO    : Bus 2306	: V=0.977, theta=-7.77928528 -> V=0.975, theta=0.0
% INFO    : Bus 2307	: V=1.048, theta=9.75753631 -> V=0.975, theta=0.0
% INFO    : Bus 2309	: V=1.041, theta=11.4879805 -> V=0.975, theta=0.0
% INFO    : Bus 2310	: V=1.041, theta=11.5530348 -> V=0.975, theta=0.0
% INFO    : Bus 2311	: V=0.95, theta=-5.72324673 -> V=0.975, theta=0.0
% INFO    : Bus 2312	: V=1.01262768, theta=-9.38051645 -> V=0.975, theta=0.0
% INFO    : Bus 2313	: V=0.970451495, theta=-9.38051645 -> V=0.975, theta=0.0
% INFO    : Bus 2314	: V=1.002, theta=-18.7800819 -> V=0.975, theta=0.0
% INFO    : Bus 2315	: V=0.996, theta=-6.86562575 -> V=0.975, theta=0.0
% INFO    : Bus 2317	: V=1.01, theta=-1.96552157 -> V=0.975, theta=0.0
% INFO    : Bus 2318	: V=1.018, theta=-6.88113836 -> V=0.975, theta=0.0
% INFO    : Bus 2319	: V=1.012, theta=-1.96457768 -> V=0.975, theta=0.0
% INFO    : Bus 2320	: V=1.014, theta=-2.02041777 -> V=0.975, theta=0.0
% INFO    : Bus 2321	: V=1.051, theta=11.4886062 -> V=0.975, theta=0.0
% INFO    : Bus 2322	: V=1.05, theta=11.1898895 -> V=0.975, theta=0.0
% INFO    : Bus 2323	: V=1.002, theta=6.98348914 -> V=0.975, theta=0.0
% INFO    : Bus 2324	: V=1.001, theta=7.01569263 -> V=0.975, theta=0.0
% INFO    : Bus 2325	: V=0.992, theta=-2.55979362 -> V=0.975, theta=0.0
% INFO    : Bus 2326	: V=0.992, theta=-2.55979817 -> V=0.975, theta=0.0
% INFO    : Bus 2327	: V=0.987, theta=-12.4074346 -> V=0.975, theta=0.0
% INFO    : Bus 2328	: V=0.987, theta=-8.02266292 -> V=0.975, theta=0.0
% INFO    : Bus 2329	: V=0.988, theta=-8.30272037 -> V=0.975, theta=0.0
% INFO    : Bus 2330	: V=0.987, theta=-9.33289918 -> V=0.975, theta=0.0
% INFO    : Bus 2331	: V=1.001, theta=-8.29941311 -> V=0.975, theta=0.0
% INFO    : Bus 2332	: V=0.985, theta=-5.83043734 -> V=0.975, theta=0.0
% INFO    : Bus 2336	: V=0.979, theta=-2.84430497 -> V=0.975, theta=0.0
% INFO    : Bus 2337	: V=0.979, theta=-2.76727346 -> V=0.975, theta=0.0
% INFO    : Bus 2338	: V=0.979, theta=-2.70622318 -> V=0.975, theta=0.0
% INFO    : Bus 2339	: V=0.98, theta=-2.92629499 -> V=0.975, theta=0.0
% INFO    : Bus 2340	: V=0.98, theta=-3.06709332 -> V=0.975, theta=0.0
% INFO    : Bus 2341	: V=0.979, theta=-2.7905292 -> V=0.975, theta=0.0
% INFO    : Bus 2342	: V=1.025, theta=7.37896587 -> V=0.975, theta=0.0
% INFO    : Bus 2343	: V=1.025, theta=7.37635287 -> V=0.975, theta=0.0
% INFO    : Bus 2344	: V=1.029, theta=7.32887581 -> V=0.975, theta=0.0
% INFO    : Bus 2345	: V=1.029, theta=6.83593181 -> V=0.975, theta=0.0
% INFO    : Bus 2346	: V=1.02, theta=-5.69887523 -> V=0.975, theta=0.0
% INFO    : Bus 2348	: V=1.018, theta=-4.00022693 -> V=0.975, theta=0.0
% INFO    : Bus 2349	: V=1.015, theta=-7.15732717 -> V=0.975, theta=0.0
% INFO    : Bus 2350	: V=1.021, theta=-9.68879989 -> V=0.975, theta=0.0
% INFO    : Bus 2351	: V=1.055, theta=0.063288969 -> V=0.975, theta=0.0
% INFO    : Bus 2352	: V=0.997, theta=0.69402666 -> V=0.975, theta=0.0
% INFO    : Bus 2353	: V=0.997, theta=0.69402666 -> V=0.975, theta=0.0
% INFO    : Bus 2354	: V=0.997, theta=0.69402666 -> V=0.975, theta=0.0
% INFO    : Bus 2355	: V=0.997, theta=0.74728234 -> V=0.975, theta=0.0
% INFO    : Bus 2356	: V=1.004, theta=-3.08283785 -> V=0.975, theta=0.0
% INFO    : Bus 2357	: V=1.025, theta=4.15710746 -> V=0.975, theta=0.0
% INFO    : Bus 2358	: V=1.025, theta=4.15994363 -> V=0.975, theta=0.0
% INFO    : Bus 2359	: V=0.989, theta=-10.3700134 -> V=0.975, theta=0.0
% INFO    : Bus 2360	: V=0.995, theta=-8.71593538 -> V=0.975, theta=0.0
% INFO    : Bus 2361	: V=1.0, theta=-10.8260531 -> V=0.975, theta=0.0
% INFO    : Bus 2362	: V=0.998, theta=-8.56646769 -> V=0.975, theta=0.0
% INFO    : Bus 2363	: V=0.985, theta=-7.58810346 -> V=0.975, theta=0.0
% INFO    : Bus 2364	: V=1.017, theta=1.99511378 -> V=0.975, theta=0.0
% INFO    : Bus 2365	: V=1.017, theta=1.98117776 -> V=0.975, theta=0.0
% INFO    : Bus 2367	: V=0.999182192, theta=-10.2213952 -> V=0.975, theta=0.0
% INFO    : Bus 2368	: V=1.039, theta=-10.0675071 -> V=0.975, theta=0.0
% INFO    : Bus 2369	: V=1.003, theta=-5.72927656 -> V=0.975, theta=0.0
% INFO    : Bus 2370	: V=1.003, theta=-6.03902778 -> V=0.975, theta=0.0
% INFO    : Bus 2371	: V=1.042, theta=3.69312591 -> V=0.975, theta=0.0
% INFO    : Bus 2372	: V=1.042, theta=3.69150322 -> V=0.975, theta=0.0
% INFO    : Bus 2373	: V=1.042, theta=3.69150322 -> V=0.975, theta=0.0
% INFO    : Bus 2374	: V=1.042, theta=3.69150322 -> V=0.975, theta=0.0
% INFO    : Bus 2375	: V=1.042, theta=3.69394195 -> V=0.975, theta=0.0
% INFO    : Bus 2376	: V=1.045, theta=2.77844539 -> V=0.975, theta=0.0
% INFO    : Bus 2377	: V=0.996, theta=-7.76463813 -> V=0.975, theta=0.0
% INFO    : Bus 2378	: V=0.994, theta=-7.71871999 -> V=0.975, theta=0.0
% INFO    : Bus 2379	: V=1.005, theta=1.80632249 -> V=0.975, theta=0.0
% INFO    : Bus 2380	: V=1.005, theta=-0.118833516 -> V=0.975, theta=0.0
% INFO    : Bus 2381	: V=0.997, theta=1.39001936 -> V=0.975, theta=0.0
% INFO    : Bus 2382	: V=0.996, theta=-7.63853916 -> V=0.975, theta=0.0
% INFO    : Bus 2383	: V=0.995, theta=-6.72966894 -> V=0.975, theta=0.0
% INFO    : Bus 2385	: V=0.982, theta=-12.2830277 -> V=0.975, theta=0.0
% INFO    : Bus 2386	: V=0.984, theta=-12.6263321 -> V=0.975, theta=0.0
% INFO    : Bus 2388	: V=1.054, theta=-7.27076572 -> V=0.975, theta=0.0
% INFO    : Bus 2389	: V=1.02916769, theta=-10.2206421 -> V=0.975, theta=0.0
% INFO    : Bus 2390	: V=0.994, theta=-3.97100224 -> V=0.975, theta=0.0
% INFO    : Bus 2391	: V=0.994, theta=-3.96917953 -> V=0.975, theta=0.0
% INFO    : Bus 2392	: V=0.994, theta=-3.97829303 -> V=0.975, theta=0.0
% INFO    : Bus 2393	: V=0.994, theta=-3.99834233 -> V=0.975, theta=0.0
% INFO    : Bus 2394	: V=0.981, theta=-9.47877541 -> V=0.975, theta=0.0
% INFO    : Bus 2395	: V=0.961, theta=-4.69669451 -> V=0.975, theta=0.0
% INFO    : Bus 2396	: V=0.964, theta=-6.88311222 -> V=0.975, theta=0.0
% INFO    : Bus 2397	: V=0.987, theta=-5.31514675 -> V=0.975, theta=0.0
% INFO    : Bus 2398	: V=0.988, theta=-4.05684652 -> V=0.975, theta=0.0
% INFO    : Bus 2399	: V=0.99, theta=-5.11624539 -> V=0.975, theta=0.0
% INFO    : Bus 2400	: V=0.986, theta=-4.85538987 -> V=0.975, theta=0.0
% INFO    : Bus 2401	: V=1.011, theta=-7.9796608 -> V=0.975, theta=0.0
% INFO    : Bus 2402	: V=1.009, theta=-6.55498351 -> V=0.975, theta=0.0
% INFO    : Bus 2403	: V=1.009, theta=-6.63080345 -> V=0.975, theta=0.0
% INFO    : Bus 2404	: V=0.977, theta=-6.75861171 -> V=0.975, theta=0.0
% INFO    : Bus 2409	: V=1.008, theta=2.8071196 -> V=0.975, theta=0.0
% INFO    : Bus 2410	: V=1.01, theta=1.33928434 -> V=0.975, theta=0.0
% INFO    : Bus 2411	: V=0.931, theta=-14.1240693 -> V=0.975, theta=0.0
% INFO    : Bus 2412	: V=0.929, theta=-12.6939173 -> V=0.975, theta=0.0
% INFO    : Bus 2413	: V=1.008, theta=-4.44158532 -> V=0.975, theta=0.0
% INFO    : Bus 2414	: V=1.009, theta=-5.84075033 -> V=0.975, theta=0.0
% INFO    : Bus 2415	: V=0.966, theta=-6.99189258 -> V=0.975, theta=0.0
% INFO    : Bus 2416	: V=0.939, theta=-5.67185676 -> V=0.975, theta=0.0
% INFO    : Bus 2417	: V=0.971, theta=-8.29067279 -> V=0.975, theta=0.0
% INFO    : Bus 2418	: V=0.972, theta=-8.96509683 -> V=0.975, theta=0.0
% INFO    : Bus 2419	: V=0.987, theta=-14.6534963 -> V=0.975, theta=0.0
% INFO    : Bus 2420	: V=0.987, theta=-15.2340165 -> V=0.975, theta=0.0
% INFO    : Bus 2422	: V=0.956, theta=-1.44612516 -> V=0.975, theta=0.0
% INFO    : Bus 2423	: V=0.96, theta=-5.17214319 -> V=0.975, theta=0.0
% INFO    : Bus 2424	: V=0.958, theta=-3.22488483 -> V=0.975, theta=0.0
% INFO    : Bus 2425	: V=0.997, theta=-7.76570931 -> V=0.975, theta=0.0
% INFO    : Bus 2426	: V=0.996, theta=-6.61088681 -> V=0.975, theta=0.0
% INFO    : Bus 2427	: V=1.011, theta=-1.64789608 -> V=0.975, theta=0.0
% INFO    : Bus 2428	: V=1.014, theta=-1.67060901 -> V=0.975, theta=0.0
% INFO    : Bus 2429	: V=1.046, theta=-10.5475891 -> V=0.975, theta=0.0
% INFO    : Bus 2430	: V=1.009, theta=-10.4535073 -> V=0.975, theta=0.0
% INFO    : Bus 2431	: V=0.988, theta=-7.39537281 -> V=0.975, theta=0.0
% INFO    : Bus 2432	: V=1.03, theta=-2.73536919 -> V=0.975, theta=0.0
% INFO    : Bus 2434	: V=0.999, theta=-5.96576897 -> V=0.975, theta=0.0
% INFO    : Bus 2435	: V=0.999, theta=-6.0715577 -> V=0.975, theta=0.0
% INFO    : Bus 2436	: V=0.979, theta=-4.49361276 -> V=0.975, theta=0.0
% INFO    : Bus 2437	: V=1.047, theta=6.70696861 -> V=0.975, theta=0.0
% INFO    : Bus 2438	: V=1.048, theta=6.60914734 -> V=0.975, theta=0.0
% INFO    : Bus 2439	: V=1.05, theta=6.49618379 -> V=0.975, theta=0.0
% INFO    : Bus 2440	: V=1.046, theta=5.95762446 -> V=0.975, theta=0.0
% INFO    : Bus 2441	: V=0.981, theta=-2.83410404 -> V=0.975, theta=0.0
% INFO    : Bus 2442	: V=1.038, theta=4.76298442 -> V=0.975, theta=0.0
% INFO    : Bus 2443	: V=1.038, theta=4.75675943 -> V=0.975, theta=0.0
% INFO    : Bus 2444	: V=0.996, theta=-11.5484434 -> V=0.975, theta=0.0
% INFO    : Bus 2445	: V=0.996, theta=-11.5484434 -> V=0.975, theta=0.0
% INFO    : Bus 2446	: V=0.996, theta=-11.5447059 -> V=0.975, theta=0.0
% INFO    : Bus 2447	: V=1.004, theta=-11.7605366 -> V=0.975, theta=0.0
% INFO    : Bus 2449	: V=0.994, theta=-10.2857586 -> V=0.975, theta=0.0
% INFO    : Bus 2450	: V=0.995, theta=-10.6959634 -> V=0.975, theta=0.0
% INFO    : Bus 2452	: V=1.001, theta=-5.75465666 -> V=0.975, theta=0.0
% INFO    : Bus 2453	: V=0.973671533, theta=-7.18633327 -> V=0.975, theta=0.0
% INFO    : Bus 2454	: V=0.994, theta=-9.99490153 -> V=0.975, theta=0.0
% INFO    : Bus 2455	: V=0.99, theta=-8.36296999 -> V=0.975, theta=0.0
% INFO    : Bus 2457	: V=1.026, theta=-8.08008584 -> V=0.975, theta=0.0
% INFO    : Bus 2458	: V=1.02064508, theta=-8.54727261 -> V=0.975, theta=0.0
% INFO    : Bus 2459	: V=1.034, theta=-6.84022607 -> V=0.975, theta=0.0
% INFO    : Bus 2460	: V=1.035, theta=-7.66947856 -> V=0.975, theta=0.0
% INFO    : Bus 2461	: V=1.003, theta=-5.46054816 -> V=0.975, theta=0.0
% INFO    : Bus 2462	: V=1.036, theta=-11.002585 -> V=0.975, theta=0.0
% INFO    : Bus 2463	: V=1.061, theta=-15.0848547 -> V=0.975, theta=0.0
% INFO    : Bus 2464	: V=1.061, theta=-15.0848684 -> V=0.975, theta=0.0
% INFO    : Bus 2465	: V=1.061, theta=-15.0839207 -> V=0.975, theta=0.0
% INFO    : Bus 2466	: V=1.025, theta=-3.21253524 -> V=0.975, theta=0.0
% INFO    : Bus 2467	: V=1.025, theta=-3.56067559 -> V=0.975, theta=0.0
% INFO    : Bus 2468	: V=1.025, theta=-2.74088551 -> V=0.975, theta=0.0
% INFO    : Bus 2469	: V=1.025, theta=-3.08920503 -> V=0.975, theta=0.0
% INFO    : Bus 2470	: V=1.055, theta=0.756734987 -> V=0.975, theta=0.0
% INFO    : Bus 2471	: V=1.073, theta=0.396033151 -> V=0.975, theta=0.0
% INFO    : Bus 2473	: V=1.055, theta=0.756971923 -> V=0.975, theta=0.0
% INFO    : Bus 2474	: V=1.013, theta=-6.23937882 -> V=0.975, theta=0.0
% INFO    : Bus 2475	: V=1.014, theta=-7.32928875 -> V=0.975, theta=0.0
% INFO    : Bus 2477	: V=1.01462564, theta=-7.32949576 -> V=0.975, theta=0.0
% INFO    : Bus 2478	: V=1.0140975, theta=-6.69205573 -> V=0.975, theta=0.0
% INFO    : Bus 2481	: V=1.04, theta=-3.64638447 -> V=0.975, theta=0.0
% INFO    : Bus 2482	: V=1.02, theta=-8.9878236 -> V=0.975, theta=0.0
% INFO    : Bus 2483	: V=1.021, theta=-10.1079022 -> V=0.975, theta=0.0
% INFO    : Bus 2484	: V=1.02974625, theta=-10.2182645 -> V=0.975, theta=0.0
% INFO    : Bus 2485	: V=1.02446583, theta=-10.2182645 -> V=0.975, theta=0.0
% INFO    : Bus 2486	: V=1.02446583, theta=-10.2182645 -> V=0.975, theta=0.0
% INFO    : Bus 2487	: V=0.965465665, theta=-10.2182645 -> V=0.975, theta=0.0
% INFO    : Bus 2489	: V=0.998, theta=-5.31928941 -> V=0.975, theta=0.0
% INFO    : Bus 2490	: V=0.986428331, theta=-8.58138008 -> V=0.975, theta=0.0
% INFO    : Bus 2491	: V=0.986428331, theta=-8.58138008 -> V=0.975, theta=0.0
% INFO    : Bus 2493	: V=1.015, theta=-6.37737523 -> V=0.975, theta=0.0
% INFO    : Bus 2494	: V=1.014, theta=-5.19227877 -> V=0.975, theta=0.0
% INFO    : Bus 2496	: V=1.039, theta=-3.26147558 -> V=0.975, theta=0.0
% INFO    : Bus 2497	: V=1.044, theta=-7.77242728 -> V=0.975, theta=0.0
% INFO    : Bus 2498	: V=1.011, theta=5.10991259 -> V=0.975, theta=0.0
% INFO    : Bus 2499	: V=1.011, theta=5.10991355 -> V=0.975, theta=0.0
% INFO    : Bus 2500	: V=1.00991577, theta=-0.56101694 -> V=0.975, theta=0.0
% INFO    : Bus 2501	: V=1.002, theta=-1.24290949 -> V=0.975, theta=0.0
% INFO    : Bus 2502	: V=1.012, theta=4.09565192 -> V=0.975, theta=0.0
% INFO    : Bus 2503	: V=1.011, theta=4.12251758 -> V=0.975, theta=0.0
% INFO    : Bus 2504	: V=1.024, theta=-8.48969956 -> V=0.975, theta=0.0
% INFO    : Bus 2505	: V=1.024, theta=-8.87741689 -> V=0.975, theta=0.0
% INFO    : Bus 2507	: V=1.014, theta=-5.57890288 -> V=0.975, theta=0.0
% INFO    : Bus 2508	: V=1.014, theta=-5.4315791 -> V=0.975, theta=0.0
% INFO    : Bus 2509	: V=0.968364144, theta=-10.7415259 -> V=0.975, theta=0.0
% INFO    : Bus 2510	: V=0.968362558, theta=-10.7414977 -> V=0.975, theta=0.0
% INFO    : Bus 2511	: V=0.988, theta=-12.3581522 -> V=0.975, theta=0.0
% INFO    : Bus 2512	: V=0.982, theta=-7.63842785 -> V=0.975, theta=0.0
% INFO    : Bus 2513	: V=1.002, theta=-0.783765733 -> V=0.975, theta=0.0
% INFO    : Bus 2514	: V=1.002, theta=-0.755637674 -> V=0.975, theta=0.0
% INFO    : Bus 2515	: V=1.018, theta=-8.68012916 -> V=0.975, theta=0.0
% INFO    : Bus 2516	: V=1.015, theta=-6.70986925 -> V=0.975, theta=0.0
% INFO    : Bus 2517	: V=1.015, theta=-6.70986925 -> V=0.975, theta=0.0
% INFO    : Bus 2519	: V=1.0, theta=-9.25256438 -> V=0.975, theta=0.0
% INFO    : Bus 2520	: V=1.001, theta=-10.3614123 -> V=0.975, theta=0.0
% INFO    : Bus 2521	: V=1.001, theta=-10.339566 -> V=0.975, theta=0.0
% INFO    : Bus 2523	: V=0.991, theta=-3.9311717 -> V=0.975, theta=0.0
% INFO    : Bus 2524	: V=1.018, theta=-5.89683192 -> V=0.975, theta=0.0
% INFO    : Bus 2525	: V=1.019, theta=-7.32854152 -> V=0.975, theta=0.0
% INFO    : Bus 2526	: V=1.018, theta=-6.27265712 -> V=0.975, theta=0.0
% INFO    : Bus 2527	: V=1.013, theta=6.07142456 -> V=0.975, theta=0.0
% INFO    : Bus 2528	: V=1.012, theta=6.09994978 -> V=0.975, theta=0.0
% INFO    : Bus 2529	: V=1.013, theta=5.93102734 -> V=0.975, theta=0.0
% INFO    : Bus 2530	: V=1.015, theta=4.89085857 -> V=0.975, theta=0.0
% INFO    : Bus 2531	: V=1.03, theta=-16.2280418 -> V=0.975, theta=0.0
% INFO    : Bus 2532	: V=1.03, theta=-16.2368417 -> V=0.975, theta=0.0
% INFO    : Bus 2533	: V=1.023, theta=-16.4364627 -> V=0.975, theta=0.0
% INFO    : Bus 2534	: V=0.971219886, theta=-14.4450706 -> V=0.975, theta=0.0
% INFO    : Bus 2535	: V=0.973, theta=-13.9878086 -> V=0.975, theta=0.0
% INFO    : Bus 2536	: V=1.032, theta=-4.67095798 -> V=0.975, theta=0.0
% INFO    : Bus 2537	: V=1.009, theta=-1.55333012 -> V=0.975, theta=0.0
% INFO    : Bus 2538	: V=1.007, theta=-2.23396809 -> V=0.975, theta=0.0
% INFO    : Bus 2539	: V=1.0802145, theta=-5.53006572 -> V=1.05263, theta=0.0
% INFO    : Bus 2540	: V=1.08026426, theta=-5.52733906 -> V=1.05263, theta=0.0
% INFO    : Bus 2541	: V=1.03787608, theta=-12.6582541 -> V=1.0111115, theta=0.0
% INFO    : Bus 2542	: V=1.09405236, theta=-0.67996142 -> V=1.05263, theta=0.0
% INFO    : Bus 2543	: V=0.999074412, theta=-5.41691622 -> V=1.047295, theta=0.0
% INFO    : Bus 2544	: V=1.06179373, theta=-11.5699133 -> V=1.05263, theta=0.0
% INFO    : Bus 2545	: V=1.07889936, theta=-2.83695697 -> V=1.0386135, theta=0.0
% INFO    : Bus 2546	: V=1.07546902, theta=-3.03946974 -> V=1.0377785, theta=0.0
% INFO    : Bus 2547	: V=1.07569399, theta=-6.43508208 -> V=1.05263, theta=0.0
% INFO    : Bus 2548	: V=1.07263099, theta=-6.37810953 -> V=1.05263, theta=0.0
% INFO    : Bus 2549	: V=1.05791876, theta=-13.5355845 -> V=1.05263, theta=0.0
% INFO    : Bus 2550	: V=1.0603919, theta=-12.1945486 -> V=1.05263, theta=0.0
% INFO    : Bus 2551	: V=0.983606729, theta=1.08767654 -> V=1.044445, theta=0.0
% INFO    : Bus 2552	: V=1.02498725, theta=-28.7071982 -> V=1.04222, theta=0.0
% INFO    : Bus 2553	: V=1.07425184, theta=-6.17026862 -> V=1.05263, theta=0.0
% INFO    : Bus 2554	: V=1.00699961, theta=-15.4763427 -> V=1.0377785, theta=0.0
% INFO    : Bus 2555	: V=1.07159029, theta=-8.80370824 -> V=1.05263, theta=0.0
% INFO    : Bus 2556	: V=1.08453461, theta=-3.62155846 -> V=1.0424885, theta=0.0
% INFO    : Bus 2557	: V=1.10064265, theta=0.897295055 -> V=1.05263, theta=0.0
% INFO    : Bus 2558	: V=1.10266143, theta=1.90011121 -> V=1.05263, theta=0.0
% INFO    : Bus 2559	: V=1.07133674, theta=-6.102638 -> V=0.9888895, theta=0.0
% INFO    : Bus 2560	: V=1.03689266, theta=-3.00232963 -> V=1.05263, theta=0.0
% INFO    : Bus 2561	: V=1.06565577, theta=-11.466611 -> V=1.05263, theta=0.0
% INFO    : Bus 2562	: V=1.0446281, theta=-13.5916258 -> V=1.0111115, theta=0.0
% INFO    : Bus 2563	: V=1.05570701, theta=-14.2293642 -> V=1.05263, theta=0.0
% INFO    : Bus 2564	: V=1.01480618, theta=-20.3906351 -> V=1.05263, theta=0.0
% INFO    : Bus 2565	: V=1.04483359, theta=-14.5551647 -> V=1.0111115, theta=0.0
% INFO    : Bus 2566	: V=1.06325619, theta=-12.6948592 -> V=1.05263, theta=0.0
% INFO    : Bus 2567	: V=1.04872525, theta=-13.230777 -> V=1.0111115, theta=0.0
% INFO    : Bus 2568	: V=1.04872499, theta=-13.2305657 -> V=1.0111115, theta=0.0
% INFO    : Bus 2569	: V=1.07041851, theta=-10.7256365 -> V=1.05263, theta=0.0
% INFO    : Bus 2570	: V=1.0583157, theta=-12.4486796 -> V=1.05263, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 1279	: Vg=1.029 -> Vg=1.044445
% INFO    : Gen at bus 1210	: Pg=24.74, Qg=0.66 -> Pg=21.66, Qg=2.5
% INFO    : Gen at bus 1210	: Vg=1.023 -> Vg=1.0
% INFO    : Gen at bus 751	: Pg=44.0, Qg=0.33 -> Pg=27.6, Qg=6.0
% INFO    : Gen at bus 751	: Vg=1.035 -> Vg=1.0158755
% INFO    : Gen at bus 2777	: Pg=1.93, Qg=0.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 2777	: Vg=1.102 -> Vg=1.0
% INFO    : Gen at bus 2777	: Pg=6.0, Qg=0.9 -> Pg=4.2, Qg=0.95
% INFO    : Gen at bus 2777	: Vg=1.102 -> Vg=1.0
% INFO    : Gen at bus 978	: Pg=6.41, Qg=0.01 -> Pg=7.2, Qg=-1.5
% INFO    : Gen at bus 978	: Vg=1.113 -> Vg=1.0
% INFO    : Gen at bus 158	: Pg=0.45, Qg=0.0 -> Pg=1.35, Qg=0.0
% INFO    : Gen at bus 158	: Vg=1.024 -> Vg=1.0000025
% INFO    : Gen at bus 1217	: Pg=12.0, Qg=-0.03 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 1217	: Vg=1.017 -> Vg=1.022612
% INFO    : Gen at bus 367	: Pg=48.0, Qg=1.18 -> Pg=30.0, Qg=9.0
% INFO    : Gen at bus 367	: Vg=0.995 -> Vg=1.0
% INFO    : Gen at bus 1127	: Pg=7.1, Qg=0.0 -> Pg=9.6, Qg=0.0
% INFO    : Gen at bus 1127	: Vg=1.001 -> Vg=1.015872
% INFO    : Gen at bus 460	: Vg=1.065 -> Vg=1.04643
% INFO    : Gen at bus 968	: Pg=10.14, Qg=0.05 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 968	: Vg=1.07 -> Vg=1.0000025
% INFO    : Gen at bus 1827	: Pg=21.0, Qg=0.05 -> Pg=13.2, Qg=-2.5
% INFO    : Gen at bus 1827	: Vg=1.065 -> Vg=1.033334
% INFO    : Gen at bus 1466	: Pg=38.0, Qg=0.02 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 1466	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 2863	: Pg=26.2, Qg=0.02 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 2863	: Vg=0.987 -> Vg=1.0
% INFO    : Gen at bus 1466	: Pg=38.0, Qg=0.02 -> Pg=20.5, Qg=-5.0
% INFO    : Gen at bus 1466	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 2863	: Pg=26.2, Qg=0.02 -> Pg=20.5, Qg=0.0
% INFO    : Gen at bus 2863	: Vg=0.987 -> Vg=1.0
% INFO    : Gen at bus 1072	: Vg=1.091 -> Vg=1.00445
% INFO    : Gen at bus 1072	: Vg=1.091 -> Vg=1.00445
% INFO    : Gen at bus 1072	: Vg=1.091 -> Vg=1.00445
% INFO    : Gen at bus 642	: Pg=-3.26, Qg=1.14 -> Pg=6.2, Qg=0.0
% INFO    : Gen at bus 642	: Vg=1.029 -> Vg=1.021212
% INFO    : Gen at bus 642	: Pg=-4.23, Qg=-0.44 -> Pg=6.2, Qg=0.0
% INFO    : Gen at bus 642	: Vg=1.029 -> Vg=1.021212
% INFO    : Gen at bus 542	: Pg=5.0, Qg=0.49 -> Pg=27.5, Qg=6.0
% INFO    : Gen at bus 542	: Vg=1.019 -> Vg=1.015872
% INFO    : Gen at bus 773	: Pg=-5.36, Qg=0.0 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 773	: Vg=1.033 -> Vg=1.0000025
% INFO    : Gen at bus 399	: Pg=3.01, Qg=0.0 -> Pg=8.28, Qg=0.0
% INFO    : Gen at bus 399	: Vg=0.985 -> Vg=1.015872
% INFO    : Gen at bus 399	: Pg=1.2, Qg=0.0 -> Pg=0.6, Qg=0.0
% INFO    : Gen at bus 399	: Vg=0.985 -> Vg=1.015872
% INFO    : Gen at bus 21	: Pg=16.33, Qg=0.0 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 21	: Vg=1.079 -> Vg=0.9888895
% INFO    : Gen at bus 21	: Pg=23.1, Qg=0.0 -> Pg=16.56, Qg=0.0
% INFO    : Gen at bus 21	: Vg=1.079 -> Vg=0.9888895
% INFO    : Gen at bus 899	: Pg=-0.61, Qg=0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 899	: Vg=1.044 -> Vg=1.000709
% INFO    : Gen at bus 899	: Pg=-1.56, Qg=0.0 -> Pg=12.6, Qg=0.0
% INFO    : Gen at bus 899	: Vg=1.044 -> Vg=1.000709
% INFO    : Gen at bus 2618	: Pg=1.2, Qg=0.0 -> Pg=3.6, Qg=0.0
% INFO    : Gen at bus 2618	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 2618	: Pg=31.36, Qg=0.08 -> Pg=22.5, Qg=2.0
% INFO    : Gen at bus 2618	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 285	: Pg=1.2, Qg=0.0 -> Pg=3.6, Qg=0.0
% INFO    : Gen at bus 285	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 285	: Pg=36.0, Qg=0.07 -> Pg=22.5, Qg=2.0
% INFO    : Gen at bus 285	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 135	: Pg=8.82, Qg=0.01 -> Pg=7.8, Qg=-0.5
% INFO    : Gen at bus 135	: Vg=1.053 -> Vg=1.0000025
% INFO    : Gen at bus 53	: Pg=9.25, Qg=-0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 53	: Vg=1.038 -> Vg=1.015872
% INFO    : Gen at bus 53	: Pg=17.0, Qg=-0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 53	: Vg=1.038 -> Vg=1.015872
% INFO    : Gen at bus 596	: Pg=1.99, Qg=0.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 596	: Vg=1.069 -> Vg=1.04598
% INFO    : Gen at bus 958	: Pg=-0.45, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 958	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 1679	: Pg=17.64, Qg=0.03 -> Pg=12.6, Qg=1.0
% INFO    : Gen at bus 1679	: Vg=1.048 -> Vg=1.0
% INFO    : Gen at bus 1679	: Pg=9.54, Qg=0.04 -> Pg=12.6, Qg=1.1
% INFO    : Gen at bus 1679	: Vg=1.048 -> Vg=1.0
% INFO    : Gen at bus 1157	: Pg=-1.68, Qg=0.0 -> Pg=4.32, Qg=0.0
% INFO    : Gen at bus 1157	: Vg=1.012 -> Vg=1.015872
% INFO    : Gen at bus 513	: Vg=1.008 -> Vg=1.0
% INFO    : Gen at bus 513	: Vg=1.008 -> Vg=1.0
% INFO    : Gen at bus 371	: Pg=6.54, Qg=0.01 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 371	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 371	: Pg=3.34, Qg=0.01 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 371	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 976	: Pg=29.37, Qg=0.1 -> Pg=21.0, Qg=-1.5
% INFO    : Gen at bus 976	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 976	: Pg=26.73, Qg=0.1 -> Pg=21.0, Qg=-1.5
% INFO    : Gen at bus 976	: Vg=1.008 -> Vg=1.015872
% INFO    : Gen at bus 2754	: Pg=1.42, Qg=0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 2754	: Vg=1.045 -> Vg=1.019477
% INFO    : Gen at bus 749	: Vg=0.952 -> Vg=0.9444445
% INFO    : Gen at bus 1188	: Pg=19.0, Qg=1.9 -> Pg=12.0, Qg=1.95
% INFO    : Gen at bus 1188	: Vg=1.09 -> Vg=1.004635
% INFO    : Gen at bus 1254	: Pg=8.72, Qg=-6.06 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 1254	: Vg=1.057 -> Vg=1.001289
% INFO    : Gen at bus 252	: Pg=2.2, Qg=0.05 -> Pg=6.6, Qg=1.5
% INFO    : Gen at bus 252	: Vg=0.952 -> Vg=0.9444445
% INFO    : Gen at bus 252	: Pg=4.45, Qg=0.03 -> Pg=5.4, Qg=0.5
% INFO    : Gen at bus 252	: Vg=0.952 -> Vg=0.9444445
% INFO    : Gen at bus 252	: Pg=4.74, Qg=0.05 -> Pg=6.6, Qg=1.5
% INFO    : Gen at bus 252	: Vg=0.952 -> Vg=0.9444445
% INFO    : Gen at bus 252	: Pg=4.47, Qg=0.03 -> Pg=5.4, Qg=0.5
% INFO    : Gen at bus 252	: Vg=0.952 -> Vg=0.9444445
% INFO    : Gen at bus 504	: Pg=12.0, Qg=0.03 -> Pg=7.44, Qg=0.0
% INFO    : Gen at bus 504	: Vg=0.958 -> Vg=0.9445145
% INFO    : Gen at bus 115	: Pg=17.55, Qg=0.0 -> Pg=15.18, Qg=0.0
% INFO    : Gen at bus 115	: Vg=1.07 -> Vg=0.9888895
% INFO    : Gen at bus 967	: Pg=0.82, Qg=0.0 -> Pg=1.15, Qg=0.0
% INFO    : Gen at bus 967	: Vg=1.071 -> Vg=1.0000025
% INFO    : Gen at bus 1811	: Pg=4.08, Qg=-0.01 -> Pg=5.4, Qg=0.0
% INFO    : Gen at bus 1811	: Vg=1.047 -> Vg=1.003809
% INFO    : Gen at bus 2634	: Pg=10.3, Qg=0.02 -> Pg=8.4, Qg=0.0
% INFO    : Gen at bus 2634	: Vg=1.061 -> Vg=1.0000025
% INFO    : Gen at bus 326	: Pg=12.39, Qg=0.02 -> Pg=8.4, Qg=0.0
% INFO    : Gen at bus 326	: Vg=1.059 -> Vg=1.0000025
% INFO    : Gen at bus 1829	: Pg=10.95, Qg=-0.0 -> Pg=7.68, Qg=0.0
% INFO    : Gen at bus 1829	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 1314	: Pg=27.65, Qg=0.75 -> Pg=23.4, Qg=0.0
% INFO    : Gen at bus 1314	: Vg=1.098 -> Vg=1.005695
% INFO    : Gen at bus 71	: Pg=15.39, Qg=0.19 -> Pg=18.0, Qg=3.0
% INFO    : Gen at bus 71	: Vg=1.091 -> Vg=1.004425
% INFO    : Gen at bus 93	: Vg=1.09 -> Vg=1.004535
% INFO    : Gen at bus 129	: Pg=8.67, Qg=0.01 -> Pg=6.6, Qg=0.0
% INFO    : Gen at bus 129	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 1594	: Pg=2.4, Qg=-0.03 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1594	: Vg=1.015 -> Vg=1.021962
% INFO    : Gen at bus 1594	: Pg=8.04, Qg=-0.03 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1594	: Vg=1.015 -> Vg=1.021962
% INFO    : Gen at bus 1354	: Pg=3.34, Qg=-0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 1354	: Vg=1.009 -> Vg=1.015872
% INFO    : Gen at bus 1133	: Pg=9.1, Qg=0.0 -> Pg=10.35, Qg=0.0
% INFO    : Gen at bus 1133	: Vg=1.006 -> Vg=1.015872
% INFO    : Gen at bus 1405	: Pg=21.58, Qg=0.2 -> Pg=22.68, Qg=2.0
% INFO    : Gen at bus 1405	: Vg=1.033 -> Vg=1.0
% INFO    : Gen at bus 2850	: Pg=21.68, Qg=0.2 -> Pg=22.68, Qg=2.0
% INFO    : Gen at bus 2850	: Vg=1.033 -> Vg=1.0
% INFO    : Gen at bus 2849	: Pg=21.44, Qg=0.2 -> Pg=22.68, Qg=2.0
% INFO    : Gen at bus 2849	: Vg=1.033 -> Vg=1.0
% INFO    : Gen at bus 1122	: Pg=-0.64, Qg=0.0 -> Pg=4.14, Qg=0.0
% INFO    : Gen at bus 1122	: Vg=1.037 -> Vg=1.015872
% INFO    : Gen at bus 1708	: Pg=44.5, Qg=0.77 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 1708	: Vg=1.03 -> Vg=1.0377785
% INFO    : Gen at bus 1708	: Pg=44.5, Qg=0.77 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 1708	: Vg=1.03 -> Vg=1.0377785
% INFO    : Gen at bus 1658	: Pg=-8.3, Qg=0.0 -> Pg=17.94, Qg=0.0
% INFO    : Gen at bus 1658	: Vg=1.035 -> Vg=1.0000025
% INFO    : Gen at bus 2884	: Pg=4.17, Qg=0.0 -> Pg=8.22, Qg=0.0
% INFO    : Gen at bus 2884	: Vg=1.025 -> Vg=1.0000025
% INFO    : Gen at bus 1154	: Pg=1.99, Qg=0.0 -> Pg=12.48, Qg=0.0
% INFO    : Gen at bus 1154	: Vg=1.061 -> Vg=0.999999
% INFO    : Gen at bus 231	: Pg=1.66, Qg=0.09 -> Pg=4.98, Qg=0.0
% INFO    : Gen at bus 231	: Vg=1.04 -> Vg=1.0111115
% INFO    : Gen at bus 2887	: Pg=17.93, Qg=0.07 -> Pg=14.22, Qg=2.0
% INFO    : Gen at bus 2887	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 2888	: Pg=18.06, Qg=0.07 -> Pg=14.22, Qg=2.0
% INFO    : Gen at bus 2888	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 1666	: Pg=18.07, Qg=0.07 -> Pg=14.22, Qg=2.0
% INFO    : Gen at bus 1666	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 499	: Pg=16.0, Qg=0.9 -> Pg=10.2, Qg=0.95
% INFO    : Gen at bus 499	: Vg=1.084 -> Vg=1.0287175
% INFO    : Gen at bus 499	: Pg=1.4, Qg=0.9 -> Pg=4.2, Qg=0.95
% INFO    : Gen at bus 499	: Vg=1.084 -> Vg=1.0287175
% INFO    : Gen at bus 499	: Pg=7.29, Qg=0.9 -> Pg=10.2, Qg=0.95
% INFO    : Gen at bus 499	: Vg=1.084 -> Vg=1.0287175
% INFO    : Gen at bus 2709	: Pg=12.44, Qg=0.02 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 2709	: Vg=1.021 -> Vg=1.0
% INFO    : Gen at bus 709	: Pg=14.04, Qg=0.02 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 709	: Vg=1.021 -> Vg=1.0
% INFO    : Gen at bus 2710	: Pg=9.39, Qg=0.02 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 2710	: Vg=1.021 -> Vg=1.0
% INFO    : Gen at bus 2708	: Pg=11.85, Qg=0.02 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 2708	: Vg=1.021 -> Vg=1.0
% INFO    : Gen at bus 1280	: Pg=2.05, Qg=0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 1280	: Vg=1.044 -> Vg=1.001694
% INFO    : Gen at bus 1493	: Vg=0.951 -> Vg=0.9444445
% INFO    : Gen at bus 745	: Pg=17.76, Qg=0.03 -> Pg=17.4, Qg=-5.0
% INFO    : Gen at bus 745	: Vg=0.984 -> Vg=0.999999
% INFO    : Gen at bus 2727	: Pg=19.34, Qg=0.01 -> Pg=17.4, Qg=-6.5
% INFO    : Gen at bus 2727	: Vg=0.991 -> Vg=0.999999
% INFO    : Gen at bus 1445	: Pg=21.41, Qg=0.0 -> Pg=33.0, Qg=0.0
% INFO    : Gen at bus 1445	: Vg=1.064 -> Vg=1.026667
% INFO    : Gen at bus 316	: Pg=0.0, Qg=0.9 -> Pg=2.5, Qg=0.95
% INFO    : Gen at bus 316	: Vg=1.109 -> Vg=0.976703
% INFO    : Gen at bus 316	: Pg=6.45, Qg=-0.15 -> Pg=5.88, Qg=-0.145
% INFO    : Gen at bus 316	: Vg=1.109 -> Vg=0.976703
% INFO    : Gen at bus 564	: Pg=-3.76, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 564	: Vg=1.035 -> Vg=1.015872
% INFO    : Gen at bus 1047	: Pg=-1.41, Qg=0.0 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1047	: Vg=1.022 -> Vg=1.000539
% INFO    : Gen at bus 1047	: Pg=-0.06, Qg=0.0 -> Pg=1.0, Qg=0.0
% INFO    : Gen at bus 1047	: Vg=1.022 -> Vg=1.000539
% INFO    : Gen at bus 1335	: Pg=0.49, Qg=-0.0 -> Pg=1.0, Qg=1.0
% INFO    : Gen at bus 1335	: Vg=1.046 -> Vg=1.003809
% INFO    : Gen at bus 2624	: Pg=19.2, Qg=0.18 -> Pg=18.6, Qg=-1.0
% INFO    : Gen at bus 2624	: Vg=1.051 -> Vg=1.0
% INFO    : Gen at bus 298	: Pg=27.16, Qg=0.18 -> Pg=18.6, Qg=-1.0
% INFO    : Gen at bus 298	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 298	: Pg=19.69, Qg=0.18 -> Pg=18.6, Qg=-1.0
% INFO    : Gen at bus 298	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 2625	: Pg=19.04, Qg=0.18 -> Pg=18.6, Qg=-1.0
% INFO    : Gen at bus 2625	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 2625	: Pg=27.7, Qg=0.18 -> Pg=18.6, Qg=-1.0
% INFO    : Gen at bus 2625	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 2624	: Pg=24.52, Qg=0.18 -> Pg=18.6, Qg=-1.0
% INFO    : Gen at bus 2624	: Vg=1.051 -> Vg=1.0
% INFO    : Gen at bus 2721	: Pg=14.43, Qg=-0.0 -> Pg=14.4, Qg=-0.005
% INFO    : Gen at bus 2721	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 2718	: Pg=4.96, Qg=0.09 -> Pg=14.4, Qg=0.5
% INFO    : Gen at bus 2718	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 741	: Pg=14.36, Qg=0.09 -> Pg=14.4, Qg=0.5
% INFO    : Gen at bus 741	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 2719	: Pg=12.97, Qg=0.09 -> Pg=14.4, Qg=0.5
% INFO    : Gen at bus 2719	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 2720	: Pg=14.29, Qg=0.09 -> Pg=14.4, Qg=0.5
% INFO    : Gen at bus 2720	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 283	: Pg=16.23, Qg=0.32 -> Pg=14.1, Qg=0.0
% INFO    : Gen at bus 283	: Vg=1.074 -> Vg=0.9888895
% INFO    : Gen at bus 1506	: Pg=26.0, Qg=0.04 -> Pg=16.2, Qg=-2.5
% INFO    : Gen at bus 1506	: Vg=1.037 -> Vg=1.016412
% INFO    : Gen at bus 1506	: Pg=8.36, Qg=0.04 -> Pg=16.2, Qg=-2.5
% INFO    : Gen at bus 1506	: Vg=1.037 -> Vg=1.016412
% INFO    : Gen at bus 1847	: Pg=31.0, Qg=0.15 -> Pg=19.2, Qg=2.0
% INFO    : Gen at bus 1847	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 1398	: Pg=4.24, Qg=0.0 -> Pg=12.01, Qg=0.0
% INFO    : Gen at bus 1398	: Vg=1.018 -> Vg=1.0000025
% INFO    : Gen at bus 1398	: Pg=7.16, Qg=0.0 -> Pg=12.21, Qg=0.0
% INFO    : Gen at bus 1398	: Vg=1.018 -> Vg=1.0000025
% INFO    : Gen at bus 225	: Pg=9.0, Qg=1.24 -> Pg=27.0, Qg=0.0
% INFO    : Gen at bus 225	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 225	: Pg=37.28, Qg=1.24 -> Pg=27.0, Qg=0.0
% INFO    : Gen at bus 225	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 1607	: Pg=-0.18, Qg=0.0 -> Pg=0.87, Qg=0.0
% INFO    : Gen at bus 1607	: Vg=1.032 -> Vg=1.0000025
% INFO    : Gen at bus 314	: Pg=17.33, Qg=0.08 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 314	: Vg=0.962 -> Vg=0.9448795
% INFO    : Gen at bus 2680	: Pg=200.07, Qg=17.61 -> Pg=141.5, Qg=20.0
% INFO    : Gen at bus 2680	: Vg=1.094 -> Vg=1.0
% INFO    : Gen at bus 582	: Pg=82.0, Qg=8.36 -> Pg=125.5, Qg=12.5
% INFO    : Gen at bus 582	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 2978	: Pg=82.0, Qg=8.33 -> Pg=125.5, Qg=12.5
% INFO    : Gen at bus 2978	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 2977	: Pg=202.54, Qg=17.71 -> Pg=141.5, Qg=20.0
% INFO    : Gen at bus 2977	: Vg=1.094 -> Vg=1.0
% INFO    : Gen at bus 240	: Pg=232.0, Qg=-5.18 -> Pg=143.4, Qg=2.5
% INFO    : Gen at bus 240	: Vg=1.073 -> Vg=1.05347
% INFO    : Gen at bus 1655	: Pg=3.07, Qg=0.0 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1655	: Vg=0.973 -> Vg=0.999999
% INFO    : Gen at bus 1655	: Pg=0.49, Qg=0.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 1655	: Vg=0.973 -> Vg=0.999999
% INFO    : Gen at bus 1150	: Pg=-1.68, Qg=0.0 -> Pg=32.4, Qg=0.0
% INFO    : Gen at bus 1150	: Vg=1.058 -> Vg=1.0377785
% INFO    : Gen at bus 1447	: Pg=6.0, Qg=-0.02 -> Pg=4.2, Qg=-0.5
% INFO    : Gen at bus 1447	: Vg=1.063 -> Vg=1.015872
% INFO    : Gen at bus 906	: Vg=1.065 -> Vg=1.04623
% INFO    : Gen at bus 1474	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 1474	: Pg=4.62, Qg=-0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 1474	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 1474	: Pg=1.6, Qg=-0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 1474	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 963	: Pg=8.0, Qg=0.0 -> Pg=5.34, Qg=-0.5
% INFO    : Gen at bus 963	: Vg=1.0 -> Vg=1.015872
% INFO    : Gen at bus 962	: Pg=18.18, Qg=0.0 -> Pg=13.2, Qg=0.0
% INFO    : Gen at bus 962	: Vg=1.038 -> Vg=1.0000025
% INFO    : Gen at bus 923	: Pg=11.0, Qg=0.0 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 923	: Vg=1.04 -> Vg=1.015872
% INFO    : Gen at bus 1153	: Pg=15.0, Qg=-0.38 -> Pg=9.6, Qg=0.0
% INFO    : Gen at bus 1153	: Vg=1.045 -> Vg=1.001654
% INFO    : Gen at bus 1153	: Pg=16.0, Qg=-0.13 -> Pg=10.08, Qg=0.0
% INFO    : Gen at bus 1153	: Vg=1.045 -> Vg=1.001654
% INFO    : Gen at bus 274	: Pg=5.26, Qg=0.01 -> Pg=4.02, Qg=0.0
% INFO    : Gen at bus 274	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 274	: Pg=3.15, Qg=0.01 -> Pg=3.36, Qg=0.0
% INFO    : Gen at bus 274	: Vg=1.033 -> Vg=0.999999
% INFO    : Gen at bus 1776	: Pg=9.0, Qg=0.02 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1776	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 1776	: Pg=9.0, Qg=0.02 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1776	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 2914	: Pg=9.0, Qg=0.02 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2914	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 2914	: Pg=9.0, Qg=0.02 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 2914	: Vg=1.033 -> Vg=1.015872
% INFO    : Gen at bus 184	: Vg=1.067 -> Vg=1.033334
% INFO    : Gen at bus 1657	: Pg=5.2, Qg=-0.59 -> Pg=15.6, Qg=-0.5
% INFO    : Gen at bus 1657	: Vg=1.014 -> Vg=1.0233335
% INFO    : Gen at bus 1657	: Pg=12.72, Qg=-0.59 -> Pg=15.6, Qg=-0.5
% INFO    : Gen at bus 1657	: Vg=1.014 -> Vg=1.0233335
% INFO    : Gen at bus 1761	: Pg=0.97, Qg=0.0 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 1761	: Vg=1.091 -> Vg=1.00445
% INFO    : Gen at bus 1761	: Vg=1.091 -> Vg=1.00445
% INFO    : Gen at bus 1868	: Pg=6.0, Qg=-0.28 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 1868	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 1868	: Pg=29.0, Qg=-0.28 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 1868	: Vg=1.04 -> Vg=0.999999
% INFO    : Gen at bus 731	: Vg=1.038 -> Vg=0.999999
% INFO    : Gen at bus 2715	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 1263	: Pg=17.8, Qg=0.15 -> Pg=13.86, Qg=0.0
% INFO    : Gen at bus 1263	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 1263	: Pg=17.8, Qg=0.15 -> Pg=13.86, Qg=0.0
% INFO    : Gen at bus 1263	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 161	: Pg=3.6, Qg=-0.16 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 161	: Vg=1.065 -> Vg=0.975
% INFO    : Gen at bus 604	: Pg=9.0, Qg=0.01 -> Pg=6.12, Qg=0.0
% INFO    : Gen at bus 604	: Vg=1.027 -> Vg=0.999999
% INFO    : Gen at bus 918	: Pg=22.38, Qg=0.0 -> Pg=15.6, Qg=0.0
% INFO    : Gen at bus 918	: Vg=1.051 -> Vg=1.0000025
% INFO    : Gen at bus 1760	: Pg=10.18, Qg=-0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 1760	: Vg=1.039 -> Vg=1.0013775
% INFO    : Gen at bus 1760	: Pg=2.3, Qg=-0.0 -> Pg=6.9, Qg=0.0
% INFO    : Gen at bus 1760	: Vg=1.039 -> Vg=1.0013775
% INFO    : Gen at bus 1414	: Pg=10.58, Qg=0.06 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 1414	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 1414	: Pg=9.5, Qg=0.05 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1414	: Vg=1.036 -> Vg=0.999999
% INFO    : Gen at bus 662	: Pg=26.44, Qg=0.67 -> Pg=24.0, Qg=1.0
% INFO    : Gen at bus 662	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 2697	: Pg=27.23, Qg=0.69 -> Pg=24.0, Qg=1.0
% INFO    : Gen at bus 2697	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 2696	: Pg=27.22, Qg=0.69 -> Pg=24.0, Qg=1.0
% INFO    : Gen at bus 2696	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 1346	: Pg=2.4, Qg=0.05 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1346	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 1346	: Pg=2.4, Qg=0.05 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1346	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 2622	: Pg=4.05, Qg=0.38 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 2622	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 2622	: Pg=7.45, Qg=0.38 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 2622	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 291	: Pg=10.27, Qg=0.37 -> Pg=11.4, Qg=0.0
% INFO    : Gen at bus 291	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 1490	: Pg=10.0, Qg=0.01 -> Pg=6.36, Qg=0.0
% INFO    : Gen at bus 1490	: Vg=1.03 -> Vg=0.999999
% INFO    : Gen at bus 1671	: Pg=20.0, Qg=0.2 -> Pg=12.84, Qg=0.0
% INFO    : Gen at bus 1671	: Vg=1.036 -> Vg=1.0158755
% INFO    : Gen at bus 1615	: Pg=25.06, Qg=0.48 -> Pg=23.4, Qg=0.0
% INFO    : Gen at bus 1615	: Vg=1.028 -> Vg=0.999999
% INFO    : Gen at bus 1681	: Pg=10.74, Qg=-12.71 -> Pg=52.2, Qg=0.87
% INFO    : Gen at bus 1681	: Vg=1.049 -> Vg=1.044445
% INFO    : Gen at bus 418	: Pg=15.0, Qg=1.85 -> Pg=45.0, Qg=5.0
% INFO    : Gen at bus 418	: Vg=1.061 -> Vg=1.0
% INFO    : Gen at bus 2658	: Pg=15.0, Qg=1.85 -> Pg=45.0, Qg=5.0
% INFO    : Gen at bus 2658	: Vg=1.061 -> Vg=1.0
% INFO    : Gen at bus 418	: Pg=15.0, Qg=1.85 -> Pg=45.0, Qg=5.0
% INFO    : Gen at bus 418	: Vg=1.061 -> Vg=1.0
% INFO    : Gen at bus 2658	: Pg=15.0, Qg=1.85 -> Pg=45.0, Qg=5.0
% INFO    : Gen at bus 2658	: Vg=1.061 -> Vg=1.0
% INFO    : Gen at bus 461	: Pg=8.65, Qg=-2.97 -> Pg=24.84, Qg=0.415
% INFO    : Gen at bus 461	: Vg=1.049 -> Vg=1.044445
% INFO    : Gen at bus 31	: Pg=2.27, Qg=0.0 -> Pg=4.01, Qg=0.0
% INFO    : Gen at bus 31	: Vg=1.049 -> Vg=1.004309
% INFO    : Gen at bus 236	: Pg=3.0, Qg=0.05 -> Pg=9.0, Qg=3.5
% INFO    : Gen at bus 236	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 236	: Pg=3.0, Qg=0.05 -> Pg=9.0, Qg=3.5
% INFO    : Gen at bus 236	: Vg=1.022 -> Vg=1.015872
% INFO    : Gen at bus 1754	: Pg=0.44, Qg=0.0 -> Pg=0.5, Qg=0.0
% INFO    : Gen at bus 1754	: Vg=1.017 -> Vg=1.015872
% INFO    : Gen at bus 1754	: Pg=0.44, Qg=0.0 -> Pg=0.5, Qg=0.0
% INFO    : Gen at bus 1754	: Vg=1.017 -> Vg=1.015872
% INFO    : Gen at bus 1754	: Pg=0.44, Qg=0.0 -> Pg=0.5, Qg=0.0
% INFO    : Gen at bus 1754	: Vg=1.017 -> Vg=1.015872
% INFO    : Gen at bus 898	: Pg=0.25, Qg=0.0 -> Pg=0.85, Qg=0.0
% INFO    : Gen at bus 898	: Vg=1.036 -> Vg=1.001324
% INFO    : Gen at bus 898	: Pg=2.8, Qg=0.0 -> Pg=13.56, Qg=0.0
% INFO    : Gen at bus 898	: Vg=1.036 -> Vg=1.001324
% INFO    : Gen at bus 120	: Pg=13.01, Qg=-0.01 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 120	: Vg=1.049 -> Vg=1.002569
% INFO    : Gen at bus 549	: Pg=5.0, Qg=0.49 -> Pg=27.5, Qg=6.0
% INFO    : Gen at bus 549	: Vg=1.02 -> Vg=1.015872
% INFO    : Gen at bus 77	: Pg=-2.48, Qg=0.0 -> Pg=14.1, Qg=0.0
% INFO    : Gen at bus 77	: Vg=1.026 -> Vg=1.0027225
% INFO    : Gen at bus 124	: Pg=-3.56, Qg=0.0 -> Pg=-3.5, Qg=0.0
% INFO    : Gen at bus 124	: Vg=1.022 -> Vg=1.0013325
% INFO    : Gen at bus 124	: Pg=-3.56, Qg=0.0 -> Pg=-3.5, Qg=0.0
% INFO    : Gen at bus 124	: Vg=1.022 -> Vg=1.0013325
% INFO    : Gen at bus 552	: Pg=12.12, Qg=0.0 -> Pg=12.6, Qg=0.0
% INFO    : Gen at bus 552	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 1858	: Pg=8.64, Qg=0.05 -> Pg=5.76, Qg=0.0
% INFO    : Gen at bus 1858	: Vg=0.952 -> Vg=0.9444445
% INFO    : Gen at bus 134	: Pg=24.0, Qg=-0.32 -> Pg=15.0, Qg=2.0
% INFO    : Gen at bus 134	: Vg=1.015 -> Vg=1.0233335
% INFO    : Gen at bus 1204	: Pg=28.44, Qg=0.29 -> Pg=25.2, Qg=2.5
% INFO    : Gen at bus 1204	: Vg=0.964 -> Vg=1.00031
% INFO    : Gen at bus 1204	: Pg=8.4, Qg=0.29 -> Pg=25.2, Qg=2.5
% INFO    : Gen at bus 1204	: Vg=0.964 -> Vg=1.00031
% INFO    : Gen at bus 641	: Pg=6.46, Qg=0.0 -> Pg=6.6, Qg=0.0
% INFO    : Gen at bus 641	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 641	: Pg=8.62, Qg=0.0 -> Pg=6.6, Qg=0.0
% INFO    : Gen at bus 641	: Vg=1.023 -> Vg=1.015872
% INFO    : Gen at bus 916	: Pg=3.24, Qg=0.0 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 916	: Vg=1.032 -> Vg=0.999999
% INFO    : Gen at bus 1317	: Pg=10.0, Qg=0.21 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 1317	: Vg=1.036 -> Vg=1.000569
% INFO    : Gen at bus 1317	: Pg=8.0, Qg=0.23 -> Pg=24.0, Qg=10.0
% INFO    : Gen at bus 1317	: Vg=1.036 -> Vg=1.000569
% INFO    : Gen at bus 1610	: Pg=-0.71, Qg=0.0 -> Pg=8.28, Qg=0.0
% INFO    : Gen at bus 1610	: Vg=1.054 -> Vg=1.000839
% INFO    : Gen at bus 1610	: Pg=-0.61, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 1610	: Vg=1.054 -> Vg=1.000839
% INFO    : Gen at bus 271	: Pg=30.73, Qg=0.32 -> Pg=23.4, Qg=0.0
% INFO    : Gen at bus 271	: Vg=1.02 -> Vg=0.999999
% INFO    : Gen at bus 1123	: Pg=-3.05, Qg=0.0 -> Pg=33.24, Qg=0.0
% INFO    : Gen at bus 1123	: Vg=1.048 -> Vg=1.04769
% INFO    : Gen at bus 300	: Pg=16.39, Qg=0.0 -> Pg=24.48, Qg=0.0
% INFO    : Gen at bus 300	: Vg=1.033 -> Vg=1.0000025
% INFO    : Gen at bus 648	: Pg=24.59, Qg=-1.93 -> Pg=17.34, Qg=0.0
% INFO    : Gen at bus 648	: Vg=1.051 -> Vg=0.999999
% INFO    : Gen at bus 1630	: Pg=0.78, Qg=0.0 -> Pg=1.0, Qg=0.0
% INFO    : Gen at bus 1630	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 1630	: Pg=2.86, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 1630	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 1630	: Pg=0.78, Qg=0.0 -> Pg=1.0, Qg=0.0
% INFO    : Gen at bus 1630	: Vg=1.018 -> Vg=1.015872
% INFO    : Gen at bus 1604	: Pg=2.6, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 1604	: Vg=1.038 -> Vg=1.015872
% INFO    : Gen at bus 1802	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 1802	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 2917	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 2917	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 2921	: Pg=30.0, Qg=1.34 -> Pg=90.0, Qg=0.0
% INFO    : Gen at bus 2921	: Vg=1.077 -> Vg=1.0
% INFO    : Gen at bus 2918	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 2918	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 2921	: Pg=71.93, Qg=1.34 -> Pg=90.0, Qg=0.0
% INFO    : Gen at bus 2921	: Vg=1.077 -> Vg=1.0
% INFO    : Gen at bus 2920	: Vg=1.076 -> Vg=1.0
% INFO    : Gen at bus 2919	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 2919	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 1802	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 1802	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 2917	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 2917	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 2919	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 2919	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 2918	: Pg=34.0, Qg=1.73 -> Pg=102.0, Qg=-5.0
% INFO    : Gen at bus 2918	: Vg=1.079 -> Vg=1.0
% INFO    : Gen at bus 2920	: Vg=1.076 -> Vg=1.0
% INFO    : Gen at bus 946	: Pg=11.57, Qg=0.16 -> Pg=9.6, Qg=1.5
% INFO    : Gen at bus 946	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 1576	: Pg=13.3, Qg=0.02 -> Pg=11.4, Qg=0.0
% INFO    : Gen at bus 1576	: Vg=1.019 -> Vg=1.012164
% INFO    : Gen at bus 335	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 335	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 335	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 335	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 2932	: Pg=23.07, Qg=0.25 -> Pg=21.06, Qg=-4.5
% INFO    : Gen at bus 2932	: Vg=1.013 -> Vg=1.0
% INFO    : Gen at bus 1873	: Pg=21.14, Qg=0.2 -> Pg=21.06, Qg=-4.5
% INFO    : Gen at bus 1873	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 2931	: Pg=23.0, Qg=0.25 -> Pg=21.06, Qg=-4.5
% INFO    : Gen at bus 2931	: Vg=1.013 -> Vg=1.0
% INFO    : Gen at bus 2761	: Pg=11.63, Qg=0.54 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 2761	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 2759	: Pg=10.28, Qg=0.54 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 2759	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 2760	: Pg=16.43, Qg=0.57 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 2760	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 2758	: Pg=7.04, Qg=0.53 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 2758	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 883	: Pg=7.47, Qg=0.53 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 883	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 2757	: Pg=16.34, Qg=0.56 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 2757	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 631	: Pg=23.98, Qg=-0.08 -> Pg=31.2, Qg=-1.5
% INFO    : Gen at bus 631	: Vg=1.063 -> Vg=1.04222
% INFO    : Gen at bus 1355	: Pg=1.3, Qg=-0.0 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 1355	: Vg=1.012 -> Vg=0.999999
% INFO    : Gen at bus 1151	: Pg=22.51, Qg=0.56 -> Pg=22.8, Qg=0.0
% INFO    : Gen at bus 1151	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 2803	: Pg=22.54, Qg=0.56 -> Pg=22.8, Qg=0.5
% INFO    : Gen at bus 2803	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 2802	: Pg=22.46, Qg=0.56 -> Pg=22.8, Qg=0.5
% INFO    : Gen at bus 2802	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 1593	: Pg=8.94, Qg=-0.04 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1593	: Vg=1.012 -> Vg=1.0
% INFO    : Gen at bus 1593	: Pg=4.54, Qg=-0.04 -> Pg=7.2, Qg=0.0
% INFO    : Gen at bus 1593	: Vg=1.012 -> Vg=1.0
% INFO    : Gen at bus 313	: Pg=26.0, Qg=0.1 -> Pg=16.2, Qg=0.0
% INFO    : Gen at bus 313	: Vg=1.043 -> Vg=1.0000025
% INFO    : Gen at bus 1573	: Pg=12.0, Qg=0.16 -> Pg=7.8, Qg=6.5
% INFO    : Gen at bus 1573	: Vg=1.018 -> Vg=0.999999
% INFO    : Gen at bus 1294	: Pg=12.0, Qg=0.03 -> Pg=7.68, Qg=0.0
% INFO    : Gen at bus 1294	: Vg=1.038 -> Vg=0.999999
% INFO    : Gen at bus 2578	: Pg=3.58, Qg=0.1 -> Pg=10.74, Qg=-1.5
% INFO    : Gen at bus 2578	: Vg=0.958 -> Vg=0.9444445
% INFO    : Gen at bus 2578	: Pg=17.0, Qg=0.1 -> Pg=10.74, Qg=-1.5
% INFO    : Gen at bus 2578	: Vg=0.958 -> Vg=0.9444445
% INFO    : Gen at bus 1176	: Pg=5.4, Qg=0.06 -> Pg=16.2, Qg=3.5
% INFO    : Gen at bus 1176	: Vg=0.956 -> Vg=1.0
% INFO    : Gen at bus 1176	: Pg=5.4, Qg=0.06 -> Pg=16.2, Qg=3.5
% INFO    : Gen at bus 1176	: Vg=0.956 -> Vg=1.0
% INFO    : Gen at bus 1782	: Pg=29.0, Qg=-0.19 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 1782	: Vg=1.016 -> Vg=1.0233335
% INFO    : Gen at bus 626	: Pg=3.54, Qg=0.6 -> Pg=46.8, Qg=0.5
% INFO    : Gen at bus 626	: Vg=1.054 -> Vg=1.0377785
% INFO    : Gen at bus 146	: Pg=126.0, Qg=3.87 -> Pg=78.0, Qg=16.5
% INFO    : Gen at bus 146	: Vg=1.051 -> Vg=1.044445
% INFO    : Gen at bus 262	: Pg=1.76, Qg=0.01 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 262	: Vg=0.951 -> Vg=0.9444445
% INFO    : Gen at bus 262	: Pg=4.13, Qg=0.01 -> Pg=3.42, Qg=0.0
% INFO    : Gen at bus 262	: Vg=0.951 -> Vg=0.9444445
% INFO    : Gen at bus 262	: Pg=1.7, Qg=0.04 -> Pg=5.1, Qg=0.5
% INFO    : Gen at bus 262	: Vg=0.951 -> Vg=0.9444445
% INFO    : Gen at bus 262	: Pg=1.19, Qg=0.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 262	: Vg=0.951 -> Vg=0.9444445
% INFO    : Gen at bus 819	: Vg=0.951 -> Vg=0.9444445
% INFO    : Gen at bus 1536	: Pg=1.54, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 1536	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 1536	: Pg=3.2, Qg=0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 1536	: Vg=1.011 -> Vg=1.015872
% INFO    : Gen at bus 19	: Pg=12.0, Qg=0.9 -> Pg=7.8, Qg=0.95
% INFO    : Gen at bus 19	: Vg=1.032 -> Vg=1.0036225
% INFO    : Gen at bus 838	: Pg=10.32, Qg=0.12 -> Pg=13.25, Qg=0.0
% INFO    : Gen at bus 838	: Vg=1.06 -> Vg=1.0
% INFO    : Gen at bus 838	: Pg=23.0, Qg=0.12 -> Pg=13.25, Qg=0.0
% INFO    : Gen at bus 838	: Vg=1.06 -> Vg=1.0
% INFO    : Gen at bus 519	: Pg=12.0, Qg=-0.02 -> Pg=7.8, Qg=1.0
% INFO    : Gen at bus 519	: Vg=1.01 -> Vg=1.022012
% INFO    : Gen at bus 519	: Pg=12.0, Qg=-0.02 -> Pg=7.8, Qg=1.0
% INFO    : Gen at bus 519	: Vg=1.01 -> Vg=1.022012
% INFO    : Gen at bus 275	: Pg=22.31, Qg=0.21 -> Pg=15.96, Qg=0.0
% INFO    : Gen at bus 275	: Vg=1.034 -> Vg=0.999999
% INFO    : Gen at bus 482	: Pg=-0.03, Qg=0.0 -> Pg=2.3, Qg=0.0
% INFO    : Gen at bus 482	: Vg=0.99 -> Vg=1.015872
% INFO    : Gen at bus 876	: Pg=23.28, Qg=0.18 -> Pg=16.8, Qg=1.5
% INFO    : Gen at bus 876	: Vg=1.04 -> Vg=1.015872
% INFO    : Gen at bus 876	: Pg=27.0, Qg=0.18 -> Pg=16.8, Qg=1.5
% INFO    : Gen at bus 876	: Vg=1.04 -> Vg=1.015872
% INFO    : Gen at bus 876	: Pg=27.0, Qg=0.18 -> Pg=16.8, Qg=1.5
% INFO    : Gen at bus 876	: Vg=1.04 -> Vg=1.015872
% INFO    : Gen at bus 305	: Pg=1.0, Qg=0.03 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 305	: Vg=1.057 -> Vg=1.016392
% INFO    : Gen at bus 305	: Pg=19.92, Qg=0.03 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 305	: Vg=1.057 -> Vg=1.016392
% INFO    : Gen at bus 2628	: Pg=22.84, Qg=0.03 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 2628	: Vg=1.062 -> Vg=1.016392
% INFO    : Gen at bus 2628	: Pg=1.0, Qg=0.03 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 2628	: Vg=1.062 -> Vg=1.016392
% INFO    : Gen at bus 2628	: Pg=24.96, Qg=0.03 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 2628	: Vg=1.062 -> Vg=1.016392
% INFO    : Gen at bus 2628	: Pg=5.56, Qg=0.03 -> Pg=16.5, Qg=-1.5
% INFO    : Gen at bus 2628	: Vg=1.062 -> Vg=1.016392
% INFO    : Gen at bus 1456	: Pg=2.81, Qg=0.0 -> Pg=7.015, Qg=0.0
% INFO    : Gen at bus 1456	: Vg=1.026 -> Vg=1.0000025
% INFO    : Gen at bus 38	: Pg=44.0, Qg=0.33 -> Pg=27.6, Qg=6.0
% INFO    : Gen at bus 38	: Vg=1.036 -> Vg=1.0158755
% INFO    : Gen at bus 1798	: Pg=19.81, Qg=0.25 -> Pg=16.2, Qg=0.0
% INFO    : Gen at bus 1798	: Vg=1.014 -> Vg=0.999999
% INFO    : Gen at bus 426	: Pg=1.4, Qg=-0.0 -> Pg=4.2, Qg=0.0
% INFO    : Gen at bus 426	: Vg=1.031 -> Vg=1.0000025
% INFO    : Gen at bus 1714	: Pg=1.2, Qg=0.0 -> Pg=3.6, Qg=0.0
% INFO    : Gen at bus 1714	: Vg=1.007 -> Vg=1.015872
% INFO    : Gen at bus 744	: Pg=20.02, Qg=0.08 -> Pg=17.4, Qg=0.0
% INFO    : Gen at bus 744	: Vg=1.048 -> Vg=1.0
% INFO    : Gen at bus 744	: Pg=20.02, Qg=0.08 -> Pg=17.4, Qg=0.0
% INFO    : Gen at bus 744	: Vg=1.048 -> Vg=1.0
% INFO    : Gen at bus 1261	: Pg=2.84, Qg=-0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 1261	: Vg=1.027 -> Vg=1.0004375
% INFO    : Gen at bus 1261	: Pg=1.5, Qg=-0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 1261	: Vg=1.027 -> Vg=1.0004375
% INFO    : Gen at bus 1261	: Pg=7.0, Qg=-0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 1261	: Vg=1.027 -> Vg=1.0004375
% INFO    : Gen at bus 1261	: Pg=1.5, Qg=-0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 1261	: Vg=1.027 -> Vg=1.0004375
% INFO    : Gen at bus 1261	: Pg=7.0, Qg=-0.0 -> Pg=4.5, Qg=0.0
% INFO    : Gen at bus 1261	: Vg=1.027 -> Vg=1.0004375
% INFO    : Gen at bus 975	: Pg=1.24, Qg=0.0 -> Pg=1.3, Qg=0.0
% INFO    : Gen at bus 975	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 975	: Pg=9.0, Qg=0.02 -> Pg=5.88, Qg=0.0
% INFO    : Gen at bus 975	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 1706	: Pg=2.76, Qg=0.0 -> Pg=7.02, Qg=0.0
% INFO    : Gen at bus 1706	: Vg=1.033 -> Vg=1.0000025
% INFO    : Gen at bus 1160	: Pg=-0.14, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 1160	: Vg=1.077 -> Vg=1.0377785
% INFO    : Gen at bus 1160	: Pg=-0.14, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 1160	: Vg=1.077 -> Vg=1.0377785
% INFO    : Gen at bus 235	: Pg=5.74, Qg=0.01 -> Pg=4.38, Qg=0.0
% INFO    : Gen at bus 235	: Vg=1.022 -> Vg=0.999999
% INFO    : Gen at bus 2613	: Pg=7.4, Qg=0.19 -> Pg=22.2, Qg=-1.0
% INFO    : Gen at bus 2613	: Vg=1.053 -> Vg=1.0
% INFO    : Gen at bus 2613	: Pg=34.13, Qg=0.19 -> Pg=22.2, Qg=-1.0
% INFO    : Gen at bus 2613	: Vg=1.053 -> Vg=1.0
% INFO    : Gen at bus 259	: Pg=23.06, Qg=0.19 -> Pg=22.2, Qg=-1.0
% INFO    : Gen at bus 259	: Vg=1.052 -> Vg=1.0
% INFO    : Gen at bus 259	: Pg=21.99, Qg=0.19 -> Pg=22.2, Qg=-1.0
% INFO    : Gen at bus 259	: Vg=1.052 -> Vg=1.0
% INFO    : Gen at bus 2614	: Pg=22.83, Qg=0.19 -> Pg=22.2, Qg=0.0
% INFO    : Gen at bus 2614	: Vg=1.053 -> Vg=1.0
% INFO    : Gen at bus 2614	: Pg=22.83, Qg=0.19 -> Pg=22.2, Qg=0.0
% INFO    : Gen at bus 2614	: Vg=1.053 -> Vg=1.0
% INFO    : Gen at bus 1220	: Pg=3.21, Qg=0.0 -> Pg=6.12, Qg=0.0
% INFO    : Gen at bus 1220	: Vg=1.027 -> Vg=1.002214
% INFO    : Gen at bus 1220	: Pg=1.7, Qg=0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 1220	: Vg=1.027 -> Vg=1.002214
% INFO    : Gen at bus 1148	: Pg=4.76, Qg=0.09 -> Pg=5.4, Qg=6.0
% INFO    : Gen at bus 1148	: Vg=1.037 -> Vg=0.999999
% INFO    : Gen at bus 1069	: Pg=6.0, Qg=0.13 -> Pg=14.45, Qg=0.0
% INFO    : Gen at bus 1069	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 1069	: Pg=13.2, Qg=0.16 -> Pg=16.25, Qg=0.0
% INFO    : Gen at bus 1069	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 1069	: Pg=25.0, Qg=0.16 -> Pg=16.25, Qg=0.0
% INFO    : Gen at bus 1069	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 1815	: Pg=10.0, Qg=0.04 -> Pg=6.48, Qg=0.0
% INFO    : Gen at bus 1815	: Vg=0.949 -> Vg=0.9444445
% INFO    : Gen at bus 1815	: Pg=6.0, Qg=0.02 -> Pg=3.84, Qg=0.0
% INFO    : Gen at bus 1815	: Vg=0.949 -> Vg=0.9444445
% INFO    : Gen at bus 1046	: Pg=13.0, Qg=0.02 -> Pg=8.28, Qg=-0.465
% INFO    : Gen at bus 1046	: Vg=1.068 -> Vg=1.033334
% INFO    : Gen at bus 1606	: Pg=44.0, Qg=0.06 -> Pg=27.6, Qg=-7.0
% INFO    : Gen at bus 1606	: Vg=1.03 -> Vg=0.999999
% INFO    : Gen at bus 76	: Pg=17.58, Qg=0.18 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 76	: Vg=0.936 -> Vg=0.9444445
% INFO    : Gen at bus 1612	: Pg=34.13, Qg=0.2 -> Pg=26.4, Qg=0.0
% INFO    : Gen at bus 1612	: Vg=1.001 -> Vg=0.999999
% INFO    : Gen at bus 1276	: Pg=-6.06, Qg=0.0 -> Pg=-4.0, Qg=0.0
% INFO    : Gen at bus 1276	: Vg=1.102 -> Vg=1.02107
% INFO    : Gen at bus 1276	: Pg=12.83, Qg=0.24 -> Pg=31.8, Qg=3.5
% INFO    : Gen at bus 1276	: Vg=1.102 -> Vg=1.02107
% INFO    : Gen at bus 1396	: Pg=4.6, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1396	: Vg=1.052 -> Vg=1.0030475
% INFO    : Gen at bus 1396	: Pg=3.44, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1396	: Vg=1.052 -> Vg=1.0030475
% INFO    : Gen at bus 1288	: Pg=10.0, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1288	: Vg=0.987 -> Vg=1.015872
% INFO    : Gen at bus 489	: Pg=1.6, Qg=-0.0 -> Pg=4.8, Qg=-0.1
% INFO    : Gen at bus 489	: Vg=1.055 -> Vg=1.0033625
% INFO    : Gen at bus 489	: Pg=0.03, Qg=-0.0 -> Pg=0.53, Qg=0.0
% INFO    : Gen at bus 489	: Vg=1.055 -> Vg=1.0033625
% INFO    : Gen at bus 489	: Pg=7.0, Qg=-0.0 -> Pg=4.8, Qg=-0.1
% INFO    : Gen at bus 489	: Vg=1.055 -> Vg=1.0033625
% INFO    : Gen at bus 1678	: Pg=6.2, Qg=0.29 -> Pg=18.6, Qg=1.0
% INFO    : Gen at bus 1678	: Vg=1.026 -> Vg=1.015872
% INFO    : Gen at bus 1614	: Pg=11.6, Qg=0.06 -> Pg=34.8, Qg=0.0
% INFO    : Gen at bus 1614	: Vg=1.066 -> Vg=1.0111115
% INFO    : Gen at bus 220	: Pg=1.22, Qg=-0.0 -> Pg=3.66, Qg=0.0
% INFO    : Gen at bus 220	: Vg=0.997 -> Vg=1.015872
% INFO    : Gen at bus 133	: Pg=11.45, Qg=-0.06 -> Pg=15.0, Qg=2.0
% INFO    : Gen at bus 133	: Vg=1.008 -> Vg=1.016817
% INFO    : Gen at bus 172	: Vg=1.028 -> Vg=1.015872
% INFO    : Gen at bus 1266	: Pg=2.02, Qg=0.0 -> Pg=1.5, Qg=0.0
% INFO    : Gen at bus 1266	: Vg=1.013 -> Vg=1.015872
% INFO    : Gen at bus 877	: Pg=9.0, Qg=-0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 877	: Vg=1.044 -> Vg=1.0000025
% INFO    : Gen at bus 877	: Pg=1.4, Qg=2.9 -> Pg=4.2, Qg=2.95
% INFO    : Gen at bus 877	: Vg=1.044 -> Vg=1.0000025
% INFO    : Gen at bus 697	: Pg=2.27, Qg=-0.0 -> Pg=2.5, Qg=0.0
% INFO    : Gen at bus 697	: Vg=1.009 -> Vg=1.017122
% INFO    : Gen at bus 697	: Pg=2.52, Qg=-0.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 697	: Vg=1.009 -> Vg=1.017122
% INFO    : Gen at bus 1181	: Pg=-0.4, Qg=0.0 -> Pg=10.8, Qg=0.0
% INFO    : Gen at bus 1181	: Vg=1.059 -> Vg=1.002699
% INFO    : Gen at bus 1181	: Pg=-0.54, Qg=0.0 -> Pg=6.0, Qg=0.0
% INFO    : Gen at bus 1181	: Vg=1.059 -> Vg=1.002699
% INFO    : Gen at bus 2982	: Pg=0.89, Qg=0.0 -> Pg=5.16, Qg=0.0
% INFO    : Gen at bus 2982	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 2982	: Pg=2.36, Qg=0.0 -> Pg=6.3, Qg=0.0
% INFO    : Gen at bus 2982	: Vg=1.027 -> Vg=1.0000025
% INFO    : Gen at bus 310	: Pg=5.88, Qg=-0.14 -> Pg=4.2, Qg=0.0
% INFO    : Gen at bus 310	: Vg=1.088 -> Vg=1.0047725
% INFO    : Gen at bus 310	: Pg=5.97, Qg=-0.14 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 310	: Vg=1.088 -> Vg=1.0047725
% INFO    : Gen at bus 2250	: Pg=200.0, Qg=71.02 -> Pg=435.0, Qg=43.915
% INFO    : Gen at bus 2250	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2251	: Pg=140.0, Qg=75.38 -> Pg=420.0, Qg=79.12
% INFO    : Gen at bus 2251	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 2253	: Pg=15.3, Qg=0.11 -> Pg=13.8, Qg=2.565
% INFO    : Gen at bus 2253	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2254	: Pg=11.72, Qg=0.08 -> Pg=13.8, Qg=2.565
% INFO    : Gen at bus 2254	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2255	: Pg=23.28, Qg=0.53 -> Pg=16.2, Qg=4.515
% INFO    : Gen at bus 2255	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 2257	: Pg=83.0, Qg=1.12 -> Pg=51.6, Qg=16.295
% INFO    : Gen at bus 2257	: Vg=0.965 -> Vg=0.975
% INFO    : Gen at bus 2258	: Pg=9.8, Qg=0.43 -> Pg=29.4, Qg=9.48
% INFO    : Gen at bus 2258	: Vg=0.972 -> Vg=0.975
% INFO    : Gen at bus 2259	: Pg=54.57, Qg=2.67 -> Pg=74.4, Qg=28.595
% INFO    : Gen at bus 2259	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 2260	: Pg=24.03, Qg=0.12 -> Pg=19.2, Qg=1.545
% INFO    : Gen at bus 2260	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2261	: Pg=24.32, Qg=0.12 -> Pg=19.2, Qg=1.545
% INFO    : Gen at bus 2261	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2262	: Pg=23.94, Qg=0.12 -> Pg=19.2, Qg=1.545
% INFO    : Gen at bus 2262	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2263	: Pg=23.81, Qg=0.12 -> Pg=19.2, Qg=1.545
% INFO    : Gen at bus 2263	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2264	: Pg=78.9, Qg=3.87 -> Pg=55.2, Qg=14.82
% INFO    : Gen at bus 2264	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2265	: Pg=81.58, Qg=3.95 -> Pg=55.2, Qg=14.82
% INFO    : Gen at bus 2265	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 2266	: Pg=71.49, Qg=3.22 -> Pg=55.2, Qg=17.7
% INFO    : Gen at bus 2266	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 2267	: Pg=76.64, Qg=3.38 -> Pg=55.2, Qg=17.7
% INFO    : Gen at bus 2267	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 2268	: Pg=86.78, Qg=4.05 -> Pg=55.2, Qg=17.7
% INFO    : Gen at bus 2268	: Vg=0.993 -> Vg=0.975
% INFO    : Gen at bus 2269	: Pg=89.0, Qg=3.67 -> Pg=55.2, Qg=17.7
% INFO    : Gen at bus 2269	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 2270	: Pg=909.0, Qg=98.62 -> Pg=590.5, Qg=-41.595
% INFO    : Gen at bus 2270	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 2271	: Pg=949.0, Qg=104.59 -> Pg=631.47, Qg=-31.285
% INFO    : Gen at bus 2271	: Vg=1.022 -> Vg=0.975
% INFO    : Gen at bus 2272	: Pg=945.0, Qg=99.73 -> Pg=612.51, Qg=-36.095
% INFO    : Gen at bus 2272	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 2273	: Pg=884.0, Qg=86.04 -> Pg=565.0, Qg=-61.375
% INFO    : Gen at bus 2273	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 2274	: Pg=188.88, Qg=24.92 -> Pg=204.0, Qg=31.78
% INFO    : Gen at bus 2274	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 2275	: Pg=221.25, Qg=23.19 -> Pg=188.0, Qg=22.19
% INFO    : Gen at bus 2275	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2276	: Pg=220.52, Qg=9.86 -> Pg=202.0, Qg=22.52
% INFO    : Gen at bus 2276	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 2277	: Pg=112.0, Qg=51.11 -> Pg=203.5, Qg=35.05
% INFO    : Gen at bus 2277	: Vg=1.047 -> Vg=0.975
% INFO    : Gen at bus 2278	: Pg=89.0, Qg=9.63 -> Pg=122.0, Qg=17.885
% INFO    : Gen at bus 2278	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 2279	: Pg=43.67, Qg=0.32 -> Pg=34.8, Qg=-0.45
% INFO    : Gen at bus 2279	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2280	: Pg=42.6, Qg=0.13 -> Pg=34.8, Qg=-0.1
% INFO    : Gen at bus 2280	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2281	: Pg=43.25, Qg=0.32 -> Pg=34.8, Qg=-0.45
% INFO    : Gen at bus 2281	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2282	: Pg=42.6, Qg=0.13 -> Pg=34.8, Qg=-0.1
% INFO    : Gen at bus 2282	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2283	: Pg=42.6, Qg=0.13 -> Pg=34.8, Qg=-0.1
% INFO    : Gen at bus 2283	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2284	: Pg=237.02, Qg=36.08 -> Pg=185.0, Qg=38.885
% INFO    : Gen at bus 2284	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 2286	: Pg=125.55, Qg=-13.23 -> Pg=83.4, Qg=21.71
% INFO    : Gen at bus 2286	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 2287	: Pg=25.0, Qg=-1.45 -> Pg=29.4, Qg=4.605
% INFO    : Gen at bus 2287	: Vg=0.962 -> Vg=0.975
% INFO    : Gen at bus 2289	: Pg=36.84, Qg=-1.37 -> Pg=29.4, Qg=4.57
% INFO    : Gen at bus 2289	: Vg=0.964 -> Vg=0.975
% INFO    : Gen at bus 2290	: Pg=14.46, Qg=-1.47 -> Pg=29.4, Qg=4.57
% INFO    : Gen at bus 2290	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 2291	: Pg=28.84, Qg=0.6 -> Pg=19.2, Qg=2.37
% INFO    : Gen at bus 2291	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 2292	: Pg=22.14, Qg=0.71 -> Pg=19.2, Qg=4.21
% INFO    : Gen at bus 2292	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 2293	: Pg=916.0, Qg=177.86 -> Pg=607.4, Qg=158.255
% INFO    : Gen at bus 2293	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 2294	: Pg=880.0, Qg=171.41 -> Pg=571.0, Qg=148.685
% INFO    : Gen at bus 2294	: Vg=1.006 -> Vg=0.975
% INFO    : Gen at bus 2295	: Pg=904.0, Qg=159.06 -> Pg=605.39, Qg=144.91
% INFO    : Gen at bus 2295	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 2296	: Pg=895.0, Qg=160.59 -> Pg=595.98, Qg=148.13
% INFO    : Gen at bus 2296	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 2297	: Pg=1271.0, Qg=22.82 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 2297	: Vg=0.972 -> Vg=0.975
% INFO    : Gen at bus 2298	: Pg=1271.0, Qg=22.82 -> Pg=813.0, Qg=218.085
% INFO    : Gen at bus 2298	: Vg=0.972 -> Vg=0.975
% INFO    : Gen at bus 2299	: Pg=28.64, Qg=0.03 -> Pg=21.0, Qg=1.8
% INFO    : Gen at bus 2299	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 2300	: Pg=28.64, Qg=0.03 -> Pg=21.0, Qg=1.8
% INFO    : Gen at bus 2300	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 2301	: Pg=28.53, Qg=0.03 -> Pg=21.0, Qg=1.8
% INFO    : Gen at bus 2301	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 2302	: Pg=28.63, Qg=0.03 -> Pg=21.0, Qg=1.8
% INFO    : Gen at bus 2302	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 2303	: Pg=28.63, Qg=0.03 -> Pg=21.0, Qg=1.8
% INFO    : Gen at bus 2303	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 2304	: Pg=28.59, Qg=0.03 -> Pg=21.0, Qg=1.8
% INFO    : Gen at bus 2304	: Vg=1.057 -> Vg=0.975
% INFO    : Gen at bus 2305	: Pg=13.4, Qg=0.11 -> Pg=12.0, Qg=1.615
% INFO    : Gen at bus 2305	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 2306	: Pg=15.88, Qg=0.13 -> Pg=12.0, Qg=1.615
% INFO    : Gen at bus 2306	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 2307	: Pg=1292.0, Qg=381.85 -> Pg=833.5, Qg=226.955
% INFO    : Gen at bus 2307	: Vg=1.048 -> Vg=0.975
% INFO    : Gen at bus 2309	: Pg=1322.0, Qg=302.38 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 2309	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 2310	: Pg=1322.0, Qg=304.61 -> Pg=863.5, Qg=235.535
% INFO    : Gen at bus 2310	: Vg=1.041 -> Vg=0.975
% INFO    : Gen at bus 2311	: Pg=55.0, Qg=-4.04 -> Pg=54.0, Qg=10.005
% INFO    : Gen at bus 2311	: Vg=0.95 -> Vg=0.975
% INFO    : Gen at bus 2312	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 2313	: Vg=0.97 -> Vg=0.975
% INFO    : Gen at bus 2314	: Pg=1.45, Qg=46.97 -> Pg=1.45, Qg=91.015
% INFO    : Gen at bus 2314	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 2315	: Pg=48.0, Qg=8.69 -> Pg=144.0, Qg=39.25
% INFO    : Gen at bus 2315	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2317	: Pg=915.0, Qg=136.74 -> Pg=587.09, Qg=170.56
% INFO    : Gen at bus 2317	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 2318	: Pg=194.0, Qg=132.48 -> Pg=549.0, Qg=166.6
% INFO    : Gen at bus 2318	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 2319	: Pg=922.0, Qg=154.11 -> Pg=594.12, Qg=189.74
% INFO    : Gen at bus 2319	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 2320	: Pg=916.0, Qg=164.77 -> Pg=588.12, Qg=198.365
% INFO    : Gen at bus 2320	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2321	: Pg=1461.0, Qg=427.77 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 2321	: Vg=1.051 -> Vg=0.975
% INFO    : Gen at bus 2322	: Pg=1461.0, Qg=429.37 -> Pg=953.0, Qg=217.35
% INFO    : Gen at bus 2322	: Vg=1.05 -> Vg=0.975
% INFO    : Gen at bus 2323	: Pg=1456.0, Qg=65.52 -> Pg=948.0, Qg=-28.08
% INFO    : Gen at bus 2323	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 2324	: Pg=1456.0, Qg=58.62 -> Pg=948.0, Qg=-38.82
% INFO    : Gen at bus 2324	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 2325	: Pg=121.0, Qg=6.89 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 2325	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 2326	: Pg=121.0, Qg=6.89 -> Pg=66.75, Qg=21.35
% INFO    : Gen at bus 2326	: Vg=0.992 -> Vg=0.975
% INFO    : Gen at bus 2327	: Pg=144.0, Qg=6.83 -> Pg=76.2, Qg=35.07
% INFO    : Gen at bus 2327	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 2328	: Pg=612.54, Qg=60.62 -> Pg=432.5, Qg=138.63
% INFO    : Gen at bus 2328	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 2329	: Pg=592.0, Qg=71.44 -> Pg=460.0, Qg=94.405
% INFO    : Gen at bus 2329	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 2330	: Pg=592.0, Qg=56.6 -> Pg=460.0, Qg=55.15
% INFO    : Gen at bus 2330	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 2331	: Pg=550.68, Qg=65.75 -> Pg=452.5, Qg=82.085
% INFO    : Gen at bus 2331	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 2332	: Pg=11.32, Qg=0.01 -> Pg=10.8, Qg=1.86
% INFO    : Gen at bus 2332	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 2336	: Pg=34.03, Qg=0.23 -> Pg=30.0, Qg=3.42
% INFO    : Gen at bus 2336	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 2337	: Pg=34.56, Qg=0.24 -> Pg=30.0, Qg=3.42
% INFO    : Gen at bus 2337	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 2338	: Pg=34.98, Qg=0.24 -> Pg=30.0, Qg=3.42
% INFO    : Gen at bus 2338	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 2339	: Pg=33.5, Qg=0.23 -> Pg=30.0, Qg=3.42
% INFO    : Gen at bus 2339	: Vg=0.98 -> Vg=0.975
% INFO    : Gen at bus 2340	: Pg=32.53, Qg=0.23 -> Pg=30.0, Qg=3.42
% INFO    : Gen at bus 2340	: Vg=0.98 -> Vg=0.975
% INFO    : Gen at bus 2341	: Pg=34.4, Qg=0.24 -> Pg=30.0, Qg=3.42
% INFO    : Gen at bus 2341	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 2342	: Pg=972.0, Qg=187.88 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 2342	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2343	: Pg=972.0, Qg=187.87 -> Pg=640.0, Qg=196.325
% INFO    : Gen at bus 2343	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2344	: Pg=972.0, Qg=219.82 -> Pg=640.0, Qg=218.295
% INFO    : Gen at bus 2344	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 2345	: Pg=904.0, Qg=218.21 -> Pg=605.0, Qg=208.07
% INFO    : Gen at bus 2345	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 2346	: Pg=30.43, Qg=0.22 -> Pg=34.2, Qg=4.565
% INFO    : Gen at bus 2346	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 2348	: Pg=47.3, Qg=0.28 -> Pg=34.2, Qg=4.565
% INFO    : Gen at bus 2348	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 2349	: Pg=239.0, Qg=80.9 -> Pg=345.0, Qg=112.365
% INFO    : Gen at bus 2349	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 2350	: Pg=21.11, Qg=2.38 -> Pg=42.0, Qg=27.63
% INFO    : Gen at bus 2350	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 2351	: Pg=240.0, Qg=65.45 -> Pg=332.5, Qg=48.26
% INFO    : Gen at bus 2351	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 2352	: Pg=894.0, Qg=121.99 -> Pg=575.06, Qg=190.56
% INFO    : Gen at bus 2352	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 2353	: Pg=894.0, Qg=122.03 -> Pg=575.07, Qg=190.625
% INFO    : Gen at bus 2353	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 2354	: Pg=894.0, Qg=121.84 -> Pg=575.04, Qg=190.245
% INFO    : Gen at bus 2354	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 2355	: Pg=901.0, Qg=122.39 -> Pg=582.07, Qg=191.95
% INFO    : Gen at bus 2355	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 2356	: Pg=31.0, Qg=-0.15 -> Pg=19.2, Qg=2.31
% INFO    : Gen at bus 2356	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 2357	: Pg=1341.0, Qg=134.61 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 2357	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2358	: Pg=1341.0, Qg=134.77 -> Pg=860.0, Qg=-28.245
% INFO    : Gen at bus 2358	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2359	: Pg=40.82, Qg=1.37 -> Pg=39.0, Qg=7.34
% INFO    : Gen at bus 2359	: Vg=0.989 -> Vg=0.975
% INFO    : Gen at bus 2360	: Pg=51.77, Qg=0.49 -> Pg=42.0, Qg=0.32
% INFO    : Gen at bus 2360	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 2361	: Pg=23.43, Qg=2.65 -> Pg=39.0, Qg=8.95
% INFO    : Gen at bus 2361	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 2362	: Pg=46.57, Qg=2.96 -> Pg=39.0, Qg=10.38
% INFO    : Gen at bus 2362	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 2363	: Pg=66.79, Qg=1.81 -> Pg=42.0, Qg=9.63
% INFO    : Gen at bus 2363	: Vg=0.985 -> Vg=0.975
% INFO    : Gen at bus 2364	: Pg=1271.0, Qg=182.68 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 2364	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 2365	: Pg=1271.0, Qg=182.86 -> Pg=798.0, Qg=36.21
% INFO    : Gen at bus 2365	: Vg=1.017 -> Vg=0.975
% INFO    : Gen at bus 2367	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 2368	: Pg=122.86, Qg=60.73 -> Pg=266.5, Qg=79.385
% INFO    : Gen at bus 2368	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 2369	: Pg=26.6, Qg=-0.16 -> Pg=21.6, Qg=-1.11
% INFO    : Gen at bus 2369	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 2370	: Pg=24.8, Qg=-0.16 -> Pg=21.6, Qg=-1.11
% INFO    : Gen at bus 2370	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 2371	: Pg=920.0, Qg=324.92 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 2371	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 2372	: Pg=920.0, Qg=327.11 -> Pg=607.0, Qg=190.895
% INFO    : Gen at bus 2372	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 2373	: Pg=920.0, Qg=324.93 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 2373	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 2374	: Pg=920.0, Qg=324.93 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 2374	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 2375	: Pg=920.0, Qg=324.92 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 2375	: Vg=1.042 -> Vg=0.975
% INFO    : Gen at bus 2376	: Pg=774.96, Qg=321.95 -> Pg=592.0, Qg=189.94
% INFO    : Gen at bus 2376	: Vg=1.045 -> Vg=0.975
% INFO    : Gen at bus 2377	: Pg=125.0, Qg=22.89 -> Pg=182.5, Qg=60.46
% INFO    : Gen at bus 2377	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2378	: Pg=433.0, Qg=34.64 -> Pg=326.0, Qg=63.21
% INFO    : Gen at bus 2378	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 2379	: Pg=223.0, Qg=14.32 -> Pg=175.0, Qg=25.245
% INFO    : Gen at bus 2379	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 2380	: Pg=568.0, Qg=64.06 -> Pg=417.5, Qg=77.205
% INFO    : Gen at bus 2380	: Vg=1.005 -> Vg=0.975
% INFO    : Gen at bus 2381	: Pg=590.0, Qg=73.13 -> Pg=439.5, Qg=94.165
% INFO    : Gen at bus 2381	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 2382	: Pg=28.56, Qg=0.59 -> Pg=34.2, Qg=12.66
% INFO    : Gen at bus 2382	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2383	: Pg=36.26, Qg=0.63 -> Pg=34.2, Qg=12.66
% INFO    : Gen at bus 2383	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 2385	: Pg=23.19, Qg=0.25 -> Pg=18.6, Qg=6.455
% INFO    : Gen at bus 2385	: Vg=0.982 -> Vg=0.975
% INFO    : Gen at bus 2386	: Pg=21.7, Qg=0.63 -> Pg=18.6, Qg=5.97
% INFO    : Gen at bus 2386	: Vg=0.984 -> Vg=0.975
% INFO    : Gen at bus 2388	: Pg=8.2, Qg=-0.04 -> Pg=11.7, Qg=1.46
% INFO    : Gen at bus 2388	: Vg=1.054 -> Vg=0.975
% INFO    : Gen at bus 2389	: Vg=1.028 -> Vg=0.975
% INFO    : Gen at bus 2390	: Pg=24.13, Qg=0.03 -> Pg=21.0, Qg=-0.555
% INFO    : Gen at bus 2390	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 2391	: Pg=24.14, Qg=0.03 -> Pg=21.0, Qg=-0.555
% INFO    : Gen at bus 2391	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 2392	: Pg=24.09, Qg=0.1 -> Pg=21.0, Qg=-0.15
% INFO    : Gen at bus 2392	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 2393	: Pg=23.98, Qg=0.03 -> Pg=21.0, Qg=-0.555
% INFO    : Gen at bus 2393	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 2394	: Pg=186.59, Qg=10.01 -> Pg=177.5, Qg=-0.51
% INFO    : Gen at bus 2394	: Vg=0.981 -> Vg=0.975
% INFO    : Gen at bus 2395	: Pg=44.07, Qg=-0.1 -> Pg=28.2, Qg=3.06
% INFO    : Gen at bus 2395	: Vg=0.961 -> Vg=0.975
% INFO    : Gen at bus 2396	: Pg=28.11, Qg=-0.13 -> Pg=28.2, Qg=3.06
% INFO    : Gen at bus 2396	: Vg=0.964 -> Vg=0.975
% INFO    : Gen at bus 2397	: Pg=68.61, Qg=3.79 -> Pg=43.8, Qg=10.17
% INFO    : Gen at bus 2397	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 2398	: Pg=60.72, Qg=4.39 -> Pg=41.4, Qg=13.355
% INFO    : Gen at bus 2398	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 2399	: Pg=62.35, Qg=3.57 -> Pg=45.6, Qg=11.28
% INFO    : Gen at bus 2399	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 2400	: Pg=75.0, Qg=3.51 -> Pg=46.5, Qg=10.505
% INFO    : Gen at bus 2400	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 2401	: Pg=21.04, Qg=0.25 -> Pg=18.6, Qg=2.14
% INFO    : Gen at bus 2401	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 2402	: Pg=28.71, Qg=0.31 -> Pg=18.6, Qg=2.14
% INFO    : Gen at bus 2402	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2403	: Pg=28.3, Qg=0.3 -> Pg=18.6, Qg=2.14
% INFO    : Gen at bus 2403	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2404	: Pg=48.0, Qg=0.91 -> Pg=30.0, Qg=8.08
% INFO    : Gen at bus 2404	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 2409	: Pg=217.52, Qg=26.71 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 2409	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2410	: Pg=161.28, Qg=25.18 -> Pg=193.5, Qg=68.455
% INFO    : Gen at bus 2410	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 2411	: Pg=10.25, Qg=0.05 -> Pg=11.4, Qg=1.75
% INFO    : Gen at bus 2411	: Vg=0.931 -> Vg=0.975
% INFO    : Gen at bus 2412	: Pg=14.65, Qg=0.09 -> Pg=11.4, Qg=1.75
% INFO    : Gen at bus 2412	: Vg=0.929 -> Vg=0.975
% INFO    : Gen at bus 2413	: Pg=73.81, Qg=-7.09 -> Pg=69.0, Qg=9.185
% INFO    : Gen at bus 2413	: Vg=1.008 -> Vg=0.975
% INFO    : Gen at bus 2414	: Pg=52.2, Qg=-7.49 -> Pg=69.0, Qg=9.185
% INFO    : Gen at bus 2414	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2415	: Pg=42.25, Qg=-0.86 -> Pg=73.2, Qg=8.23
% INFO    : Gen at bus 2415	: Vg=0.966 -> Vg=0.975
% INFO    : Gen at bus 2416	: Pg=247.74, Qg=-119.03 -> Pg=305.0, Qg=23.34
% INFO    : Gen at bus 2416	: Vg=0.939 -> Vg=0.975
% INFO    : Gen at bus 2417	: Pg=43.78, Qg=0.44 -> Pg=31.2, Qg=10.215
% INFO    : Gen at bus 2417	: Vg=0.971 -> Vg=0.975
% INFO    : Gen at bus 2418	: Pg=39.49, Qg=0.25 -> Pg=31.2, Qg=10.215
% INFO    : Gen at bus 2418	: Vg=0.972 -> Vg=0.975
% INFO    : Gen at bus 2419	: Pg=23.14, Qg=8.11 -> Pg=95.0, Qg=40.425
% INFO    : Gen at bus 2419	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 2420	: Pg=5.22, Qg=8.24 -> Pg=95.0, Qg=40.425
% INFO    : Gen at bus 2420	: Vg=0.987 -> Vg=0.975
% INFO    : Gen at bus 2422	: Pg=147.34, Qg=-34.24 -> Pg=136.2, Qg=69.86
% INFO    : Gen at bus 2422	: Vg=0.956 -> Vg=0.975
% INFO    : Gen at bus 2423	: Pg=45.4, Qg=-32.97 -> Pg=136.2, Qg=69.86
% INFO    : Gen at bus 2423	: Vg=0.96 -> Vg=0.975
% INFO    : Gen at bus 2424	: Pg=98.64, Qg=-34.83 -> Pg=136.2, Qg=69.955
% INFO    : Gen at bus 2424	: Vg=0.958 -> Vg=0.975
% INFO    : Gen at bus 2425	: Pg=18.75, Qg=-1.98 -> Pg=39.0, Qg=12.59
% INFO    : Gen at bus 2425	: Vg=0.997 -> Vg=0.975
% INFO    : Gen at bus 2426	: Pg=31.37, Qg=-1.94 -> Pg=39.0, Qg=12.59
% INFO    : Gen at bus 2426	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2427	: Pg=923.0, Qg=275.25 -> Pg=593.5, Qg=165.99
% INFO    : Gen at bus 2427	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 2428	: Pg=923.0, Qg=297.68 -> Pg=593.5, Qg=193.685
% INFO    : Gen at bus 2428	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2429	: Pg=156.0, Qg=32.03 -> Pg=230.0, Qg=19.125
% INFO    : Gen at bus 2429	: Vg=1.046 -> Vg=0.975
% INFO    : Gen at bus 2430	: Pg=107.0, Qg=28.09 -> Pg=149.0, Qg=42.4
% INFO    : Gen at bus 2430	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2431	: Pg=168.0, Qg=33.2 -> Pg=242.0, Qg=25.665
% INFO    : Gen at bus 2431	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 2432	: Pg=1322.0, Qg=421.89 -> Pg=824.5, Qg=229.315
% INFO    : Gen at bus 2432	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 2434	: Pg=59.0, Qg=0.74 -> Pg=36.6, Qg=2.34
% INFO    : Gen at bus 2434	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 2435	: Pg=57.72, Qg=0.86 -> Pg=36.6, Qg=2.34
% INFO    : Gen at bus 2435	: Vg=0.999 -> Vg=0.975
% INFO    : Gen at bus 2436	: Pg=34.0, Qg=0.2 -> Pg=21.0, Qg=6.57
% INFO    : Gen at bus 2436	: Vg=0.979 -> Vg=0.975
% INFO    : Gen at bus 2437	: Pg=1341.0, Qg=375.01 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 2437	: Vg=1.047 -> Vg=0.975
% INFO    : Gen at bus 2438	: Pg=1341.0, Qg=386.54 -> Pg=865.0, Qg=235.84
% INFO    : Gen at bus 2438	: Vg=1.048 -> Vg=0.975
% INFO    : Gen at bus 2439	: Pg=1341.0, Qg=413.85 -> Pg=865.0, Qg=230.335
% INFO    : Gen at bus 2439	: Vg=1.05 -> Vg=0.975
% INFO    : Gen at bus 2440	: Pg=1253.0, Qg=401.56 -> Pg=820.0, Qg=210.31
% INFO    : Gen at bus 2440	: Vg=1.046 -> Vg=0.975
% INFO    : Gen at bus 2441	: Pg=41.39, Qg=2.54 -> Pg=25.9, Qg=13.51
% INFO    : Gen at bus 2441	: Vg=0.981 -> Vg=0.975
% INFO    : Gen at bus 2442	: Pg=1341.0, Qg=348.32 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 2442	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 2443	: Pg=1341.0, Qg=348.46 -> Pg=860.0, Qg=234.135
% INFO    : Gen at bus 2443	: Vg=1.038 -> Vg=0.975
% INFO    : Gen at bus 2444	: Pg=175.0, Qg=87.84 -> Pg=380.0, Qg=111.02
% INFO    : Gen at bus 2444	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2445	: Pg=175.0, Qg=87.84 -> Pg=380.0, Qg=111.02
% INFO    : Gen at bus 2445	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2446	: Pg=175.0, Qg=87.83 -> Pg=380.0, Qg=111.02
% INFO    : Gen at bus 2446	: Vg=0.996 -> Vg=0.975
% INFO    : Gen at bus 2447	: Pg=175.0, Qg=82.85 -> Pg=380.0, Qg=101.275
% INFO    : Gen at bus 2447	: Vg=1.004 -> Vg=0.975
% INFO    : Gen at bus 2449	: Pg=23.13, Qg=-0.99 -> Pg=25.8, Qg=6.31
% INFO    : Gen at bus 2449	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 2450	: Pg=20.89, Qg=-1.02 -> Pg=25.8, Qg=6.31
% INFO    : Gen at bus 2450	: Vg=0.995 -> Vg=0.975
% INFO    : Gen at bus 2452	: Pg=15.58, Qg=15.35 -> Pg=42.0, Qg=27.06
% INFO    : Gen at bus 2452	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 2453	: Vg=0.977 -> Vg=0.975
% INFO    : Gen at bus 2454	: Pg=166.76, Qg=10.98 -> Pg=150.0, Qg=15.99
% INFO    : Gen at bus 2454	: Vg=0.994 -> Vg=0.975
% INFO    : Gen at bus 2455	: Pg=503.27, Qg=50.1 -> Pg=450.0, Qg=57.26
% INFO    : Gen at bus 2455	: Vg=0.99 -> Vg=0.975
% INFO    : Gen at bus 2457	: Pg=13.53, Qg=-0.39 -> Pg=33.6, Qg=4.12
% INFO    : Gen at bus 2457	: Vg=1.026 -> Vg=0.975
% INFO    : Gen at bus 2458	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 2459	: Pg=18.71, Qg=0.18 -> Pg=13.86, Qg=3.15
% INFO    : Gen at bus 2459	: Vg=1.034 -> Vg=0.975
% INFO    : Gen at bus 2460	: Pg=15.14, Qg=0.14 -> Pg=13.86, Qg=3.14
% INFO    : Gen at bus 2460	: Vg=1.035 -> Vg=0.975
% INFO    : Gen at bus 2461	: Pg=220.0, Qg=33.95 -> Pg=324.5, Qg=71.865
% INFO    : Gen at bus 2461	: Vg=1.003 -> Vg=0.975
% INFO    : Gen at bus 2462	: Pg=21.04, Qg=0.34 -> Pg=24.6, Qg=2.215
% INFO    : Gen at bus 2462	: Vg=1.036 -> Vg=0.975
% INFO    : Gen at bus 2463	: Pg=77.0, Qg=0.16 -> Pg=48.0, Qg=5.695
% INFO    : Gen at bus 2463	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2464	: Pg=77.0, Qg=0.16 -> Pg=48.0, Qg=5.695
% INFO    : Gen at bus 2464	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2465	: Pg=77.0, Qg=0.16 -> Pg=48.0, Qg=5.695
% INFO    : Gen at bus 2465	: Vg=1.061 -> Vg=0.975
% INFO    : Gen at bus 2466	: Pg=19.41, Qg=0.49 -> Pg=19.2, Qg=4.57
% INFO    : Gen at bus 2466	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2467	: Pg=17.49, Qg=0.48 -> Pg=19.2, Qg=4.57
% INFO    : Gen at bus 2467	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2468	: Pg=22.01, Qg=0.51 -> Pg=19.2, Qg=4.57
% INFO    : Gen at bus 2468	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2469	: Pg=20.09, Qg=0.49 -> Pg=19.2, Qg=4.57
% INFO    : Gen at bus 2469	: Vg=1.025 -> Vg=0.975
% INFO    : Gen at bus 2470	: Pg=36.0, Qg=16.27 -> Pg=108.0, Qg=22.435
% INFO    : Gen at bus 2470	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 2471	: Pg=36.0, Qg=14.24 -> Pg=108.0, Qg=13.035
% INFO    : Gen at bus 2471	: Vg=1.073 -> Vg=0.975
% INFO    : Gen at bus 2473	: Pg=36.0, Qg=16.27 -> Pg=108.0, Qg=22.435
% INFO    : Gen at bus 2473	: Vg=1.055 -> Vg=0.975
% INFO    : Gen at bus 2474	: Pg=21.65, Qg=-1.21 -> Pg=19.2, Qg=4.095
% INFO    : Gen at bus 2474	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 2475	: Pg=15.74, Qg=-1.28 -> Pg=19.2, Qg=4.095
% INFO    : Gen at bus 2475	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2477	: Pg=15.74, Qg=-1.28 -> Pg=19.2, Qg=4.095
% INFO    : Gen at bus 2477	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2478	: Pg=19.2, Qg=-1.25 -> Pg=19.2, Qg=4.095
% INFO    : Gen at bus 2478	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 2481	: Pg=37.61, Qg=0.23 -> Pg=26.4, Qg=4.315
% INFO    : Gen at bus 2481	: Vg=1.04 -> Vg=0.975
% INFO    : Gen at bus 2482	: Pg=17.41, Qg=0.36 -> Pg=18.6, Qg=2.94
% INFO    : Gen at bus 2482	: Vg=1.02 -> Vg=0.975
% INFO    : Gen at bus 2483	: Pg=11.23, Qg=0.34 -> Pg=18.6, Qg=2.94
% INFO    : Gen at bus 2483	: Vg=1.021 -> Vg=0.975
% INFO    : Gen at bus 2484	: Vg=1.029 -> Vg=0.975
% INFO    : Gen at bus 2485	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 2486	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 2487	: Vg=0.965 -> Vg=0.975
% INFO    : Gen at bus 2489	: Pg=54.21, Qg=1.49 -> Pg=50.4, Qg=15.305
% INFO    : Gen at bus 2489	: Vg=0.998 -> Vg=0.975
% INFO    : Gen at bus 2490	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 2491	: Vg=0.986 -> Vg=0.975
% INFO    : Gen at bus 2493	: Pg=28.12, Qg=0.38 -> Pg=48.6, Qg=11.12
% INFO    : Gen at bus 2493	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 2494	: Pg=45.19, Qg=0.4 -> Pg=48.6, Qg=11.12
% INFO    : Gen at bus 2494	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2496	: Pg=126.0, Qg=0.57 -> Pg=78.0, Qg=6.33
% INFO    : Gen at bus 2496	: Vg=1.039 -> Vg=0.975
% INFO    : Gen at bus 2497	: Pg=29.98, Qg=0.55 -> Pg=78.0, Qg=6.33
% INFO    : Gen at bus 2497	: Vg=1.044 -> Vg=0.975
% INFO    : Gen at bus 2498	: Pg=1294.0, Qg=235.31 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 2498	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 2499	: Pg=1294.0, Qg=235.33 -> Pg=807.0, Qg=215.91
% INFO    : Gen at bus 2499	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 2500	: Pg=150.0, Qg=23.34 -> Pg=217.5, Qg=91.59
% INFO    : Gen at bus 2500	: Vg=1.01 -> Vg=0.975
% INFO    : Gen at bus 2501	: Pg=225.0, Qg=34.36 -> Pg=410.0, Qg=53.715
% INFO    : Gen at bus 2501	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 2502	: Pg=120.0, Qg=58.64 -> Pg=278.0, Qg=128.115
% INFO    : Gen at bus 2502	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 2503	: Pg=127.0, Qg=59.93 -> Pg=285.0, Qg=131.285
% INFO    : Gen at bus 2503	: Vg=1.011 -> Vg=0.975
% INFO    : Gen at bus 2504	: Pg=36.23, Qg=0.74 -> Pg=30.0, Qg=1.74
% INFO    : Gen at bus 2504	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 2505	: Pg=33.33, Qg=0.71 -> Pg=30.0, Qg=1.74
% INFO    : Gen at bus 2505	: Vg=1.024 -> Vg=0.975
% INFO    : Gen at bus 2507	: Pg=23.45, Qg=0.08 -> Pg=29.4, Qg=5.365
% INFO    : Gen at bus 2507	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2508	: Pg=24.62, Qg=0.08 -> Pg=29.4, Qg=5.365
% INFO    : Gen at bus 2508	: Vg=1.014 -> Vg=0.975
% INFO    : Gen at bus 2509	: Vg=0.971 -> Vg=0.975
% INFO    : Gen at bus 2510	: Vg=0.971 -> Vg=0.975
% INFO    : Gen at bus 2511	: Pg=27.53, Qg=2.2 -> Pg=51.0, Qg=19.785
% INFO    : Gen at bus 2511	: Vg=0.988 -> Vg=0.975
% INFO    : Gen at bus 2512	: Pg=55.0, Qg=1.64 -> Pg=56.5, Qg=17.585
% INFO    : Gen at bus 2512	: Vg=0.982 -> Vg=0.975
% INFO    : Gen at bus 2513	: Pg=923.0, Qg=136.98 -> Pg=590.09, Qg=194.825
% INFO    : Gen at bus 2513	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 2514	: Pg=926.0, Qg=137.12 -> Pg=593.09, Qg=195.405
% INFO    : Gen at bus 2514	: Vg=1.002 -> Vg=0.975
% INFO    : Gen at bus 2515	: Pg=29.22, Qg=0.46 -> Pg=29.4, Qg=0.785
% INFO    : Gen at bus 2515	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 2516	: Pg=47.0, Qg=0.47 -> Pg=29.4, Qg=0.785
% INFO    : Gen at bus 2516	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 2517	: Pg=47.0, Qg=0.47 -> Pg=29.4, Qg=0.785
% INFO    : Gen at bus 2517	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 2519	: Pg=53.05, Qg=5.89 -> Pg=96.6, Qg=34.06
% INFO    : Gen at bus 2519	: Vg=1.0 -> Vg=0.975
% INFO    : Gen at bus 2520	: Pg=32.3, Qg=6.26 -> Pg=96.6, Qg=34.06
% INFO    : Gen at bus 2520	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 2521	: Pg=32.71, Qg=6.25 -> Pg=96.6, Qg=34.06
% INFO    : Gen at bus 2521	: Vg=1.001 -> Vg=0.975
% INFO    : Gen at bus 2523	: Pg=151.0, Qg=6.0 -> Pg=93.6, Qg=32.39
% INFO    : Gen at bus 2523	: Vg=0.991 -> Vg=0.975
% INFO    : Gen at bus 2524	: Pg=44.46, Qg=0.18 -> Pg=59.4, Qg=-5.525
% INFO    : Gen at bus 2524	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 2525	: Pg=22.76, Qg=0.17 -> Pg=59.4, Qg=-5.525
% INFO    : Gen at bus 2525	: Vg=1.019 -> Vg=0.975
% INFO    : Gen at bus 2526	: Pg=38.76, Qg=0.17 -> Pg=59.4, Qg=-5.525
% INFO    : Gen at bus 2526	: Vg=1.018 -> Vg=0.975
% INFO    : Gen at bus 2527	: Pg=679.65, Qg=163.36 -> Pg=630.0, Qg=121.775
% INFO    : Gen at bus 2527	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 2528	: Pg=688.14, Qg=160.02 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 2528	: Vg=1.012 -> Vg=0.975
% INFO    : Gen at bus 2529	: Pg=686.25, Qg=159.6 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 2529	: Vg=1.013 -> Vg=0.975
% INFO    : Gen at bus 2530	: Pg=585.69, Qg=156.09 -> Pg=630.0, Qg=116.775
% INFO    : Gen at bus 2530	: Vg=1.015 -> Vg=0.975
% INFO    : Gen at bus 2531	: Pg=74.03, Qg=11.9 -> Pg=128.5, Qg=37.945
% INFO    : Gen at bus 2531	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 2532	: Pg=73.71, Qg=11.9 -> Pg=128.5, Qg=38.895
% INFO    : Gen at bus 2532	: Vg=1.03 -> Vg=0.975
% INFO    : Gen at bus 2533	: Pg=72.0, Qg=11.64 -> Pg=128.5, Qg=38.895
% INFO    : Gen at bus 2533	: Vg=1.023 -> Vg=0.975
% INFO    : Gen at bus 2534	: Pg=243.0, Qg=24.09 -> Pg=185.0, Qg=21.005
% INFO    : Gen at bus 2534	: Vg=0.972 -> Vg=0.975
% INFO    : Gen at bus 2535	: Pg=260.0, Qg=27.74 -> Pg=203.0, Qg=30.365
% INFO    : Gen at bus 2535	: Vg=0.973 -> Vg=0.975
% INFO    : Gen at bus 2536	: Pg=174.0, Qg=4.76 -> Pg=108.0, Qg=27.8
% INFO    : Gen at bus 2536	: Vg=1.032 -> Vg=0.975
% INFO    : Gen at bus 2537	: Pg=132.0, Qg=21.31 -> Pg=81.6, Qg=43.88
% INFO    : Gen at bus 2537	: Vg=1.009 -> Vg=0.975
% INFO    : Gen at bus 2538	: Pg=124.0, Qg=18.1 -> Pg=76.8, Qg=38.95
% INFO    : Gen at bus 2538	: Vg=1.007 -> Vg=0.975
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
